(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   7039809,      97459]*)
(*NotebookOutlinePosition[   7040491,      97483]*)
(*  CellTagsIndexPosition[   7040447,      97479]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Introduction to Wavelets for Image Compression ", "Title"],

Cell["\<\
Aleks Jakulin (jakulin@acm.org)
December 2001, June 2002\
\>", "Subtitle"],

Cell["\<\
Please note that this note doesn't cover all the features, rather an \
extremely limited (but important) subset of them, mostly related to the \
basics of wavelet transforms and quantization. I still hope that it will be \
useful and educational as an introduction to applying wavelets to image \
compression and denoising.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Basic 1D wavelets", "Section"],

Cell[BoxData[{
    \(\(<< Graphics`Graphics`;\)\), "\[IndentingNewLine]", 
    \(\(<< LinearAlgebra`MatrixManipulation`;\)\)}], "Input"],

Cell["\<\
This is the Cohen-Daubechies-Feauveau  9/7 wavelet filter, the standard \
transform in the JPEG-2000 standard. We implement it with an efficient \
lifting transformation.\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Alpha] = \(-1.586134342\);\)\), "\n", 
    \(\(\[Beta] = \(-0.052980118\);\)\), "\n", 
    \(\(\[Gamma] = 0.882911075;\)\), "\n", 
    \(\(\[Delta] = 0.443506852;\)\), "\n", 
    \(\(K = 1.230174105;\)\), "\n", 
    \(\(DWT\  = 
        Compile[{{X, _Real, 1}}, \ 
          Module[{n, N = Length[X]}, Y = X; 
            For[n = 0, 2  n + 3 <= N, 
              Y[\([2  n + 2]\)] = 
                X[\([2  n + 2]\)] + \[Alpha] \((X[\([2  n + 1]\)] + 
                        X[\([2  n + 
                              3]\)])\); \(n++\)]; \[IndentingNewLine]For[
              n = 1, 2  n + 2 <= N, 
              Y[\([2  n + 1]\)] = 
                X[\([2  n + 1]\)] + \[Beta] \((Y[\([2  n]\)] + 
                        Y[\([2  n + 
                              2]\)])\); \(n++\)]; \[IndentingNewLine]For[
              n = 0, 2  n + 3 <= N, 
              Y[\([2  n + 2]\)] = 
                Y[\([2  n + 2]\)] + \[Gamma] \((Y[\([2  n + 1]\)] + 
                        Y[\([2  n + 
                              3]\)])\); \(n++\)]; \[IndentingNewLine]For[
              n = 1, 2  n + 2 <= N, 
              Y[\([2  n + 1]\)] = 
                Y[\([2  n + 1]\)] + \[Delta] \((Y[\([2  n]\)] + 
                        Y[\([2  n + 
                              2]\)])\); \(n++\)]; \[IndentingNewLine]For[
              n = 0, 2  n + 2 <= N, 
              Y[\([2  n + 
                      2]\)] = \(-K\)\ \ Y[\([2  n + 
                        2]\)]; \(n++\)]; \[IndentingNewLine]For[n = 0, 
              2  n + 1 <= N, 
              Y[\([2  n + 1]\)] = \((1/K)\) 
                  Y[\([2  n + 1]\)]; \(n++\)]; \[IndentingNewLine]Return[
              Y]]];\)\), "\n", 
    \(\(IDWT\  = 
        Compile[{{Y, _Real, 1}}, \ 
          Module[{n, N = Length[Y]}, X = Y; 
            For[n = 0, 2  n + 1 <= N, 
              X[\([2  n + 1]\)] = 
                K\ Y[\([2  n + 1]\)]; \(n++\)]; \[IndentingNewLine]For[n = 0, 
              2  n + 2 <= N, 
              X[\([2  n + 
                      2]\)] = \(-\((1/K)\)\)\ Y[\([2  n + 
                        2]\)]; \(n++\)]; \[IndentingNewLine]For[n = 1, 
              2  n + 2 <= N, 
              X[\([2  n + 1]\)] = 
                X[\([2  n + 1]\)] - \[Delta] \((X[\([2  n]\)] + 
                        X[\([2  n + 
                              2]\)])\); \(n++\)]; \[IndentingNewLine]For[
              n = 0, 2  n + 3 <= N, 
              X[\([2  n + 2]\)] = 
                X[\([2  n + 2]\)] - \[Gamma] \((X[\([2  n + 1]\)] + 
                        X[\([2  n + 
                              3]\)])\); \(n++\)]; \[IndentingNewLine]For[
              n = 1, 2  n + 2 <= N, 
              X[\([2  n + 1]\)] = 
                X[\([2  n + 1]\)] - \[Beta] \((X[\([2  n]\)] + 
                        X[\([2  n + 
                              2]\)])\); \(n++\)]; \[IndentingNewLine]For[
              n = 0, 2  n + 3 <= N, 
              X[\([2  n + 2]\)] = 
                X[\([2  n + 2]\)] - \[Alpha] \((X[\([2  n + 1]\)] + 
                        X[\([2  n + 3]\)])\); \(n++\)]; 
            Return[X]]];\)\)}], "Input"],

Cell["\<\
Vectors are extended to allow proper transformation with filters that \
reference the surrounding area of every sample. The extension is done with 4 \
elements, as required by the above 9/7 filter.\
\>", "Text"],

Cell[BoxData[{
    \(\(VectorExtend\  = 
        Compile[{{X, _Real, 1}}, \ 
          Join[Join[Reverse[Drop[Take[X, 5], 1]], X], 
            Reverse[Drop[Take[X, \(-5\)], \(-1\)]]]];\)\), "\n", 
    \(\(VectorShrink\  = 
        Compile[{{X, _Real, 1}}, \ 
          Drop[Drop[X, 4], \(-4\)]];\)\), "\[IndentingNewLine]", 
    \(\(ExtDWT[X_] := 
        VectorShrink[DWT[VectorExtend[X]]];\)\), "\[IndentingNewLine]", 
    \(\(ExtIDWT[X_] := VectorShrink[IDWT[VectorExtend[X]]];\)\)}], "Input"],

Cell["\<\
Note that the transformation is reversible regardless of the vector extension\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtIDWT[ExtDWT[{1, 2, 3, 4, 5, 6, 7, 8}]]\)], "Input"],

Cell[BoxData[
    \({0.9999999999999999`, 2.`, 3.`, 4.`, 5.`, 6.`, 7.`, 8.`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IDWT[DWT[{1, 2, 3, 4, 5, 6, 7, 8}]]\)], "Input"],

Cell[BoxData[
    \({1.`, 2.`, 3.`, 4.`, 5.`, 6.000000000000002`, 7.000000000000002`, 
      8.`}\)], "Output"]
}, Open  ]],

Cell["\<\
But note that the coefficient magnitudes are lower with vector extension\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtDWT[{1, 2, 3, 4, 5, 6, 7, 8}]\)], "Input"],

Cell[BoxData[
    \({1.3336405054605858`, \(-0.24999998336082443`\), 3.0732667734702805`, 
      2.7577721735413305`*^-8, 4.946502455076224`, 0.18254356551703407`, 
      7.06341042466827`, \(-0.8650870084380856`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DWT[{1, 2, 3, 4, 5, 6, 7, 8}]\)], "Input"],

Cell[BoxData[
    \({0.8128930660591333`, 0.2500000109385473`, 2.9267331896609825`, 
      2.7577721735413305`*^-8, 4.572019855677429`, 1.460348234570178`, 
      8.363243925638098`, \(-9.84139284`\)}\)], "Output"]
}, Open  ]],

Cell["\<\
The high-pass and low-pass subbands are interleaved after the transform, but \
it is often desirable to separate and deinterleave them for further \
processing.\
\>", "Text"],

Cell[BoxData[{
    \(\(DeInterleave = 
        Compile[{{X, _Real, 1}}, 
          Join[First /@ Partition[X, 2], 
            Last\  /@ \ Partition[X, 2]]];\)\), "\n", 
    \(\(Interleave = 
        Compile[{{X, _Real, 1}}, 
          Flatten[Transpose[
              Partition[X, Floor[0.5*Length[X]]]]]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wavelets on images", "Section"],

Cell["\<\
Wavelet transform is especially useful for transforming images. For this, we \
apply it twice according to the JPEG-2000 standard: first on columns, second \
on rows. Upon this, we deinterleave the image matrix, and possibly \
recursively transform each subband individually further.\
\>", "Text"],

Cell[BoxData[{
    \(\(ImgDWT = \ 
        Compile[{{X, _Real, 2}}, 
          DeInterleave[
            ExtDWT\  /@ \ 
              Transpose[
                DeInterleave[
                  ExtDWT\  /@ \ 
                    Transpose[\((X - 
                          128)\)]]]]];\)\), "\[IndentingNewLine]", 
    \(\(ImgIDWT = 
        Compile[{{Y, _Real, 2}}, 
          Transpose[
              ExtIDWT\  /@ \ 
                Interleave[Transpose[ExtIDWT\  /@ \ Interleave[Y]]]] + 
            128];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Rescale[
          X_] := \((X - Min[X])\)/\((Max[X] - 
              Min[X])\);\)\), "\[IndentingNewLine]", 
    \(\(RescalePlain[X_] := \((X + 128)\)/255;\)\)}], "Input"],

Cell["\<\
We can now import the standard benchmark picture, sized 512x512:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m\  = \ Import["\<lenna.pgm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Show[m, ImageSize \[Rule] \ {512 + 32, 512 + 32}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 544 544 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.0238095 0.00186012 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
512 string
512 512 8 [512 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2C2C3742362F32333B332F3335354F6D91B8C3C4C4C8C6C6C7C1C0BFB7B29F78696E7783
878E9B9FA5A3A7B2AEB6B4B3B4B5B2B6B4B7B6B7AFB3ADA37F4E5F5E45383547302B272B
2829363E463C222636492B2F4B473F5538403E484639464845544139353A4968614688A2
5C3A35364C4325333B3A48727171322630514E4B44483F768A765D3B35407F945D552D24
32353228303245424F514340472F283635344A74602D293E5F664953795A3A394B535152
52545E5A5B595D66646B6B6C6E6E70717079767A767E7979787E7B7D7A7C7E7D83828282
7D7B7F7E7F81817D7F81807E828486848586848782858382838483878789898D8B858688
8584848A868986878A898C8D8D8A908E8C8D8B8B8F92908F9294908D8F8F918F8E8F8F95
929390929292909394979597959995959494949794979598989395989699959B9F9CA498
9C9E9B9DA09FA49FA3A5A8A5A3A6A3A8A9A9A9ACACAEB0ACB3B8B8B9B8BAC0BFC0C0C3C2
C3C1C6C7C7CBCACBCCCECFCFD1D1CFD0D3D3D2D4D4CC9D766D70665F5E585D5B5D5A5E62
5E61626B686A6966787C7E7F8285878484817E80797F7D7E7E797D80848A8B8C8C878782
7C77766C645F565C5A5954514E484D4A484E455156595B5A5D5A5C5C545753505459605E
6670777E807A8181817C7B77716560544B3E3C3B3A3A33332C292A322E34363B44484C53
5E5A61686468696C
2C2C3733362F32333B332F3335354F6D91B8C3C4C4C8C6C6C7C1C0BFB7B29F78696E7783
878E9B9FA5A3A7B2AEB6B4B3B4B5B2B6B4B7B6B7AFB3ADA37F4E5F5E45383547302B272B
2829363E463C222636492B2F4B473F5538403E484639464845544139353A4968614688A2
5C3A35364C4325333B3A48727171322630514E4B44483F768A765D3B32407F945D552D24
32353228303245424F514340472F283635344A74602D293E5F664953795A3A394B535152
52545E5A5B595D66646B6B6C6E6E70717079767A767E7979787E7B7D7A7C7E7D83828282
7D7B7F7E7F81817D7F81807E828486848586848782858382838483878789898D8B858688
8584848A868986878A898C8D8D8A908E8C8D8B8B8F92908F9294908D8F8F918F8E8F8F95
929390929292909394979597959995959494949794979598989395989699959B9F9CA498
9C9E9B9DA09FA49FA3A5A8A5A3A6A3A8A9A9A9ACACAEB0ACB3B8B8B9B8BAC0BFC0C0C3C2
C3C1C6C7C7CBCACBCCCECFCFD1D1CFD0D3D3D2D4D4CC9D766D70665F5E585D5B5D5A5E62
5E61626B686A6966787C7E7F8285878484817E80797F7D7E7E797D80848A8B8C8C878782
7C77766C645F565C5A5954514E484D4A484E455156595B5A5D5A5C5C545753505459605E
6670777E807A8181817C7B77716560544B3E3C3B3A3A33332C292A322E34363B44484C53
5E5A61686468696C
2B2B322F362F32313C352D373840527096C0C2C5C4C8C8C6C5C5C0BDB9B4A780696D7883
89909AA1A2A9AAB2B1B5B3B5B4B4B6B5B6B5B7B5B3AEADA27849575A3F2F39473D30262E
2B2C2F40413D2928364D323541394546363F3F4D473C4C464B55383636363C55574769A6
773C2F3C493826483F35487773732B223D5B4A54464F5E88785A3B372D497E8965633327
2F2A27323D3E5B44524A3F42412E29342C39536F45394C506C6E64745A3739333D4F5251
4E555953585963626A68696E7170757275777673777C7D7B7A7D7C7C7E7C817E7B7B7E7D
7B837F7E7E81827D7F82827D818082818586818782818380838484858588868A8D8B8E83
8584858A858789878B8C8A888A8D8D92898D8E8E9192919492909091938E908E8B8E9096
97929294929090959695949A94969495939498969894939496969598989296969C9CA09B
9B9D9E9C9EA2A0A4A2A6A7A8A6A4A4A8A7AAAAACADACADAEB4B4B7B6BBBEBDC1C0C1C2C3
C5C3C9C8C8CCCACCCCCDCFD3D4D4D0D1D3D2D4D4D5C58A655C605D5358595E5E5D57585C
6461656F6C686E6D7771757C7D858381857E7C787C797A7B7A78787E858288888E868980
7D7D73726964605C5B6259565157524C4F484B4B4F575D5F61565A5A545551554F545C5E
666A74767D7E83847F7D8077756960584F4E463F3A3533362E2D312D30342E34353B4645
4F505C6064686462
2E2E3232343132333B373A36374457779DC1C4C3C5C5C8C7C9C4C2BFB9B3AC87646D6F7D
878F99A0A2ABABB3B0B0B2B1B2B5B4B3B4B7B7B6B4AEAB99736460564E33373C432E272C
26272E3B3F392F2B3A493C324D3C394436433E4B4E405D464C4F342E37353F5445354F98
894132453E3031443F39517776772B284B5E4B4A4C687B86663D292C3B4F84797B693830
2723283A3C4D5A574B3D35452C2A2A38383D605C4B4E57668389805C313336313748494E
505F5353585B5C616A6D6D6D7071747976787376797A7D76797D7A787F7E7A7C807D7E7E
7F7F7C80837E7D827F8482857F817F81858182828186858287898684868B878B88888B85
86828588888789888F8A8A8E8B8D8E8C8D908D92938F8F9391928E92919394938E8D958D
928F95949593909496959795949092919892959699948F939393999296959598999D9B98
9C9A9D9BA09EA1A3A8A4A2A4A6A6A5A9A8A7ABAFACACB2B1B4B6B9B9B9C0BDBEC2C0C2C6
C7C6C9CDC9CCCDCCCDCFCFD2D1D1CDD4D3D4D7D7D5C07B554C5153575B5C5D605B576056
5C656B6F69767374726B75797F7F82857E787D7A7C78777978797A778181848588888481
7E7C757571685F5C625C5D5B555D5851514B53504B4E5A5659555858565253534D4D5766
5F696F777E7F828181807E7E7A6F656057504E483B393732372D343134313535383D3E47
4B50595D64666260
3636302F35353237393D3337384060789FC0C3C2C3C9C8C8C8C6C1C1BDB5AE8469737578
8892979FA3A9AEB4B1AFB1B2B5B6B2B3B5B5B7BBB1ABAE98776968575735343837302935
2C2D2B33383B302A383A3C3943353A483A3F3E4C534959484F473131373E41513D313C86
8C4D3C453E2E33353E3E4C6F7278292A565E4A48718D8D73432C23303B5286657E653433
33334447394E5F5B41413B3E2834354D4C5269513F515D83847E603024292A282F3D4046
4B4B4E4E5A5A5D5C696F65696C6E767271766F7B77797A7B78787E7B7D807A7B7F807F7D
7C7B7F7F80848881818384847E8185828685888180838684888686888E8C868B86898485
8483888B8D8B8C8D8D8890908F8F8D898B8B908D8E91909091949392919195908F8E8F90
958E919393919294999897969593939395929293939294939398969495979A989A969B97
989B9FA09E9DA3A7A1A4A2A1A3A2A6A9AEA9AEAFA9B0B1B8B4BBBDBABABEBEC1C2C3C3C6
C6CACBC9CBCDCECCCBCFCFD0D4D2CED5D3D2D4D4D2B26948484E5555575C5C5D58636460
6167676A6A717276737470767778807D7E7D7B7E7277757470767978777D7C7F81868082
7D7E77736F6666645A5E64585F5F635B5752554D534C4C54555856535452534E4B535A57
616E6F75777E8080837D7E7C766D6D685F545252433A383135392E35363235353A343740
434E53585A5D5E5A
30303934363632393F33373A404668819FC4C3C5C7C6C9CDC9C7C4C1BDB8AB83696D757E
859196A2A3A8AEB1B2B1B1B1B2B4B1B5B4B7B4B8B2ADADA582797E665D33343232312C2F
3A2B29363B35294B3632343D3C2D3A4136403B4B5845554351423A383A414C4838293567
8A594B4B372E30333A3F506A6A7925335F4D5345869A805E322B25303A587C648050332E
494738373B5D5B3E3F3F573327364D4F51707C485460768876502F222725262B2A31373A
3E494E5158555B5F6166666A6B69717674747473797E78797879757878777B7A80827F80
7C7D7B807F7C817E7F868484828383838787828581807D848D8886888A8B878C86888788
8686878A8D8C8D8A8A898B908A8D8D8D8D8D918E8F93919092919693949094918C8D8F97
9393909390929093969A9593959994919A9295969091949294969795969C9B9B9C9A9C9D
9A9B9A9EA3A2A2A6A4A6A2A49FA2A8A8A8ACB1B1ADADB2B2B9B9BBB9B8BEBDC0C1C2C4C3
C9C9C9C9CACDCDCDCED3D0D1D3D3D2D3D2D3D4D2CDA05D454F4D5052555357595F636863
646A686B71737073777A767A777B7A7D827B757A7475757371747677787873777B807E81
7E837975726A685D5D5B5D575F5F635D575957574D4F564F545B564F57514B534A4B4F59
5A5F6875757980847D827F7C756F6E6A615E594F4B47403D41372C2C2F3B3737373A4342
39414B4E615A585F
2F2F373532373433393D38373C476A809EC3C4C5C7CACBCDC9C9C1C0BAB5AA7F676E767E
8691969FA2A6AFB3B1AFB1ADB1B5B1B3B5B4B8B6B4AFA4A8908486715E3F3C35352C2C37
3E28273238352D2C442F323F423F353D3842383E4E42474750332F2C426B4838342E3061
91684E4C3C2B323038395B75747B2F3A574A4F5D968C703F2D2C34282F56677A672F2D3F
4F392B324D5B47464F60572C2E484E3C57777D55656E807852332524242326292D2E333E
40494E515B5D5863636A6A67656B6B77706D727878757974797D75777A7A7B7C8182817E
7F7E7D817D7E7C7F80828487818580808686848580838281848286898684888A868A8586
8486868B8E8F8D8A8A8A8A8E8F8C898B8E8E918E8D9490918F919194918E939093929093
96959292929192989697978F9696969791959495959190919196969694999B9B9B9A9A99
94999DA0A3A2A0A6A7A6A6A7A6A5A7A7ACABB2B0AEAEB2B2B8B8BBBABABBBEBFC1C3C5C6
C9C4C9C9CDCFCFCECFD1D1D2D1D2D2D2D4D2D4D3C68B4C4F5145565659565A6B65676662
646A6868717674777978757574787F767B787E7873777574736C71727572707578797E7F
7F827776706B69615D5D5F5E5E636768625A5C555358535A56574F5855494F4E454D4D4E
505962686F75797C807F797D7676696B696357585153403D3934322F2C2F333334383345
3A3D464D52525B5E
30303531353933353C43393B3A4A68829BC0C3C5C7CBCCCACBC8C7C3BBB2A57B6673737F
8291979DA4A8ACB1AFB0B3B0B6B3B3B2B8B6B6B3B2B3AAA9947B8577564739372F2F2E39
413232383F312F2E403152423A3C3739383734403F3C403F4328303154713C2833292B55
8C82503F332C302A312D54766F7E3741574B68869385542F2926292A335264764C2B3B4D
3E28283B515742486E703A23335F494758796A3E607370632B2326201E2324292B2C3334
3C44484F4E55555F666A6F686C6F6F716D6D727678797B747677727A7A7A7F7E82827F7C
7C7D7E7C7C7D7E7F7E8180858480818B868583858084868183848687858483898B878A8D
8788878A88938D8E8A8F8A8B908B8C8A8D8D8A8F91918D908F8E92958F8E8D9299949192
929392958F939595959492948E9895959193919192939691919895969699999B9A969499
96999E9E9EA2A3A5A6A6A4AAA8A6A6A9AEAFB2B1B0B3B2B2B7B7BABCBFBBBDC1C0C5C3C4
CFCACCCCCCCDCECDCED1D1D2D3D3D3D1D5D5D5D2BE7F43484A5051595C6C6B6766626B68
60646E716A767A72777A7A78767778757B777474737371756D716E6B707272727276757A
7B7C7A77736D69655F5D5A5F61606867636161535B5C544F5354564B4B4F515C4A484753
565459656C6F787B7C7D7D827D7774666B6D5E5E56534B473A3E3438343134383A393B4B
37333C4646474E56
3131363738313034373C3B3E3D48697C91B7C4C6C9CCCCCBCAC8C8C3B7AB99736974707C
858C98A0A4A9AEB1B2AEAFB0B6B4B3B4B2B7B4B4AEB1AEA79681746D4E453E353228323D
4E3A293B30332831342A40433634363B343F3F3F433B424E392933345A5F25272F2D2E53
838A5646312B31342F2947736B8240424953859189754E2C2B28272C3E626E662E3C4C39
26282B4D4F45486C7F562A293C593B56627352525F5C4A57322B32212427262A27303531
3A3D46474E58555B5A66666C6C6C6D6E7270737579787C75787872767C797F7B807E7E7B
7B79817F7C7C7D7D808584838284828A85807F8581848484818786888384888B898A8A88
898A858A868F8A888C8C8B8C8D908C928F8B8C8B8D929090918C8F92928C929293949693
948F9194979590939596958F8D95959892999595959193939398969597979A9A999B9898
969A9C9D9F9FA4A2A6A4AAA9AAABA6AAADADB2B0B0B7B1B2B7BBB8BCBEBABFC3C5C7C5C5
CAC9C9CCCECECECDCFD2D0D1D3D3D4D5D6D5D3D3B06640494E53515A63615E6464656869
666C6A6F7073797777767C76777B77757977797172747472746D73696C6F6D6E6F6F7878
7A79787471716B69626160605D6060606362645A60605A50504F5149484A4B4B4B574C46
4D50535966717174797D7B7D7B76756C6A6E64595D57494E3C3F3A393931333D433E3536
302E313E3B444B5C
3030383F3D3332373C3F3E3E4A4A687B8FAEC0CAC9CCCCCAC8C8C7C0B7AC8D7066707480
858F9A9FA6A6ADB3B3B4B4B2B8B3B4B7B8B9B8B9B4AEA9A08972685D403C3937362C343A
3E312B36312E2E2B302D372F373D3D353A3933373949413E33343A46694D26262B2D3247
7390634231293234352A3F75677D4B3F40668E8A856D3E322B242539526976592D4D4224
2124305650416C86643825293B57444E697C6F614E2A355332252E202B28242931313337
3037393E4B4D5757605E6667666C7072727575737774757474747579787D7E787D817E7D
7C7A807C7F817C7C827E837C8380828788828282848383838386858A8684878D8B898B8B
878A8887878C8A878D8D898D8A8E8A8F8A8D8C8C8F9293918B8F9393959294929397938F
928F949399939191959494948F93979493928E9693909193969593909496959997979596
9A999CA39C9F9FA3A5A4A4A5A8AEA9A9ABB0B3B2B4B6B1B2B7B9BCB9BABBBFC4C5C9C8C5
C9CCC9CCCCCDCFCFCFD2D1D1D0D4D1D7D6D5D3CAA1544D4D50505558565C5B56575A6770
6D6B666C697377787A7B777B7A7774747875767074737373746C736B6B6C6A6B686E6E71
7573757571706A6A625D5E5856585D626060636664655755535045444A4343504241484B
4647515F59676A6D757A7B7A7A76786F6C6D695E5B5C4E4F46493A40343B383F3A393733
353B393A373B4652
3232343836353237453F4243404860798DABBBC6C8CECBCAC8C6C7BCB09C8169647B727B
86919B9FA6AAB0B2B1B2B3B4B8B2B5B6BAB8B9B9B6B0A5987768524A3A363F3F38313332
30282C3A352D28372E2D34333845413A3333373D3E3B3F3E302B415669392A292B292C3E
6B896F4332232F2F313446756C79433240778D857D543F372A2D485566658350494F3020
21233C564151927A4B31232C3D49515D747E69402C2938452F2A27282E383039382F3133
323631323C4A4D545C5E6762696A7370747274747B73737375747777777C7D7C7E7C7D7F
7D808382817F7D7B80827F80808284868287828286848482858785858886878687888787
898C8E87898A888B8A8E8F8C8C8D8C8D8A8C8D8F91928E9490928B93959491949592948D
9393939095929291959394908F8F93928F909595938D9391959395959593969397979798
9B989D9DA09FA3A2A3A4A9A7ACA8ADA9ADB0B1B0B4B2B3B4B7B7BABBBBBEC0C1C3C7C9C9
C9CCCCCCCECFCED0D1D2D0D1CFCDCDD7D8D5D3C5884B41515551595452616868666D6B6A
71686B6C717370747976777A797B727374737271727375756F6F71726B69696B6764676A
6F727875786F6A666162585655535B6262625F65626256595050434148454A4747494744
61454B565261666E73777A7A7B7C76736F6E6D64615B59534B41423E3C36393A333A3E31
3436333833384140
3434383B3A3A343D423C3D47444866758DA2B2C2C3C8C8C9C4C5C2B8A3907D6968707580
87919A9FA5A9B2B0B2B2B5B0B6B5B5BBB7BABCB9B4B1AB9E7F5B443F31363A3E372D3B3B
312E373E3B2D2D302D303A333640433537393933383E433D32304D655532282D3137293F
577E6F3B442634312E293A686978432F548A8383663B383328275172657877484D3D2225
232F44534A7F86572A24293656535E6B796B41312D273D34292E342828332635342A2D2F
3233322F393D4E51545B5D6464666E6D6D71747377737273747676787A7D7E7E7D7C7D7C
7A837E808086807C83868081828083838080818288888185888B8A8486888A83878E8B88
8A88898C8B8D8A8A86888F908C8E8F9090918D8E8E9592918E928E92918F8D9494959391
9093909294939290929393908F8E90918F8F919890919293939393939498959597969695
9B999F9F9CA2A3A2A4A5A7A7A7A7ABA9B0B0B1B6B4B5B7B3BABBBABCB9BEC1C3C8C6C8C8
C9CAC9CFCECED2D0D1D2D1D3D0D3D6D6D3D4D0BD7846434D565155625D5E66696B6A6A69
6E706E6E6E72727E767A787774797874707575757076717171706C6F6B69686462626364
6D707071726A6B645E5B5A595456515C5B5A626662635D5C57554D4C4442404A484C4643
5142484F4D57656A7071787276A573777571696263565C565346463E3F3C363B3B394238
3437373832373533
35353A3A44413B3C423E45494A5467748D9EAAB8BDC3C3C0C0BCB6AC96877568626A757D
86909A9EA5ABACB2B3B3B2B3BBB5B4B8B9B6B9BAB3B5B0A697754E463A2E4149403D3436
2B313036342C34312F2B3C38313C4238373535363541453B31365B60382F2B2F30272942
496F64332F24252A292A3D61707040366989827B4F312B2A2F31456965867652482A1D1E
1F3B575A61826633252B3F4A656973716C554F444035492D2A2E30252D302E2B2E32312B
2F36362F343641444B535A5C5E65606C707270757574727A747678777A7B7C7C7D7B817F
7F7C807F8185807F80827F827E8283827F8284838E848485828C8A86878A898283888A86
898987908B898D8689898D8C8F928D8D8D8F8C8C8C908F938F9294938C8F8E8E92949391
93908D949496978E8E9490928C9593908E8F8F9092969393949B9492939699999896999A
9C9A9D9D9FA0A3A4A2A3A7A5A7A9ADA9A9B1B4B2B3B3B2B5B7BCBABBBCBFC3C6C3C3C6C8
CCCCCDCFCFD2D3D2D2D2CFD1D4D5D5D4D3D3CFAF61444449525358595E64626468696A6C
6C707071716E6F76747A777771727B7873766F7271786D6F706D676B6868646965616065
636B686F716D6C6C61615B56544C4B5052575E5F5D64655E534F4D5048464A464C484A49
4948414A4E525A62666E7774737C747878716B6869655D5A544A4145383C363C3B363A36
303435302C302F37
3232433A3F3F403D454D4D514C5B6E768C9CA6AFB3BABFBCBAB3A89F8B877B6D616C6E7F
858F98A0A5ADB0B1B4B3B1B4B4B4B1B8B9BBBAB5B3B1AAA6A29C755A473B45483C4A4531
312C2733362A2E36302C3639353A443F39343A3B3E3E3E333440655132322E282D2B2E3F
446662382F282E2B273244646E6A3D4A77827C69362228272532646D66926F442D241E20
2A3E62567477482330434765726B77797369554C444947292926272B25372E2A29282E31
3C2D2E2F35383A3B444E4F56555B63626C717071707170706F717676797B7C7B807C8280
7C8080807E7E83827D81817E82827D81828082848988868688878B9388898C888A88878A
89898A8E8D8D8D8D8E8C8C908D8F8D8D8F8F918D8D9296919190929291968F9393939591
928F8F96929A938D8E918E929291948E8C8E9290928E929690909292949399969497999A
9A9B9D9A9F9FA1A4A4A7A3A7A9A5A9AAADADB1B3B1B2B1B6BABBBCBCBDC0C3C4C4C3C6C7
CBCDCAD0CFD4D3D1D1D2D1D0D3D7D5D6D8D3CC9D56464952535A5C5D5D63636468686872
6E6F6C6B6E7470767273737675797A7A78747174747171766D6B6A656B69666965626261
5E676A6D6A6A6763625E5857524D52545456565E6163646157505650524C45454B4C4E44
514B494C414F5358626A717471767A7A79756B6B6F6E615E534D46483C3A393C37413936
3334303833352E2D
3A3A3B383B3A3D3F494E525152576E758D9AA5ACB1B5B4B3AFA9A193867C7266636D6F7C
848E999EA6A8AFB0AEB3B4B4B2B6B5B7B6BAB8B4B4AEABA7A59D865E443C494838363238
303A282F342F313B23282F33313A4538363B4B30323C36363A50633D2D332F2C3632343B
4A616C422B312E28292E3E64725A3C6C7E7B774F2C26292024456D696E8C653B1F221E27
3D4E495575602E354644477068707982674C5369505D44332626262C284E38232724262C
2E2A2C343536393443464F54565B595865676D6E6C6D6F777275767A7C787C7C7D7A7B7D
7A7F7C7A7B837F81828482827E7E7F817F7C8382868383858686898C8789898885878885
878C88928B938D8C8D8B8F8D8F8F8C898E8F8E8E958F91938D92909093948D9191929292
8F918F9195948F909091909089918F8C8D8C9293918C9092929392929494969295999C9A
9C9D9B99A29FA2A3A5A8A5A4A8A9AEAAACADB0B5B2B4B5B7BDBBBDBDBDC1C4C3C2C4C8CA
CDCDCFD0D1D5D3D4D3D4D5D3D2D5D7D6D5D6C58B534A484E5A585D5B5E64625E6667676E
6F6D73706B6D6D706F7074717975777672736F72736C7074716E6B67696967605C5D5E5B
5C626668686564696057575D544F4A55545154575E626D6A64605E5851554B4D4F4A534B
4E3E4A484444535D63677A746F757B777F756E6B6C6965615E544648433E3D3E3D3B363F
3B353832333A3433
32323A38362F41434E55575853647579879AA5A8AEB0B3B1ADA69D9285827964636B727A
848D959DA3A8ADAEAEB5B3B3B5B5B4B6B3B8B8B7B2B0AAA6A49F936A403E4F4632323930
2F2A2D3A393534372A2B2F32384143494A393F3338403D2B3F6D5C3625382E2830303A40
545D5F54382F2C2B27354A5E715B4A7D7C786933242F242032595B6075804E2B20273B39
594A3A787A3B31564C3A6478627A7D6238406F71615736362E2D2D2D2E312A2A2825212A
26232C2C3539394046494C4D555858575E606665636B6E6F74737874767876787A787B7A
7C7B7F7F7E7D817F848683817C7F82817F7D81837E848987878789868588878985858685
888A8F908D90898F8B8C8D9090908F8C8C8C8E8C8D94929190948F91918E899194938E90
90908D9296928E8C8C918E908B8E8E8D8B8D8F938D908D909094959190969792939A999C
9C9D9B999FA0A1A2A5A7A8ABA8A9B0AFAFB1B1B6B2B9BCBCBEBEBDBEBFC4C4C7C8C5C8CC
CECDCDCFD1D4D3D3D3D2D4D4D7D5D8D5D4D3BC7C4E4E4B545752545C5D61626266676E6B
6D68736E6E6F6B696F6C73727473737471746F72737477716D696E666868676260605B5A
5B596161615F67625F5B5555584E4E4E52515156595E676768676368544F5B4E4F564B4B
4A4043413D3D4F545D67696C6D7577787A7D71716B686965625353454B47423C38383D3F
423C393638373B30
2F2F3935353A4249505159565964747D8D9BA2A5AEAEAFADA9A4998D81786E616069767C
868C959FA7A9AAB0B1AFB2B4B2B6B5B4B4B5B8B6B3AEA7A9A2A2946E3E3A47522E2B3034
2B342D394A47312C2C293832364045443B383D3838403F324B774F2C272F322A33313D3E
464A5B5E3A34272B2C364A5967626C7D6E796433272E252E4F604969826E31251D273152
55405B7D5D2F504E3147797A5F7B773F3660766A714C3339302E2D36393B3D4239392F27
292828262A2829313B3D414A454B534E5955565A63605E666F73727275787D7C7A787978
797C797E7C8180827E82857E7C82808082807E828189888982848685898A898C89828789
868B878B91928A8E8E8E8C8A908C908F8D8B8D9790929590949492938F8E8B9093968E8F
91919091938F8D898F8F918E8F8B8C8F8F8C8E8E92908F8F908F929698979693959A9A99
9C9C9B9B9D9FA7A6A1A5A9A4AAACAEB2B0B4B7B5B9BABBBABDBDBCC1C0C3C4C5C9CBC7CA
CDD0CECFD3D7D5D3D3D3D3D4D7D4D8D5D4CFAD6748524F50535D5A5C6460606165656E6D
6A72706D716C656A6B6C6F6A78717474747870787170726E6E6A71706F6F6A67615A5658
5A5A5F5B575C64625F555B595850464A464F4D50585D5F686E6D63625B58615350474F49
4C463C43403A49505B646C67736F6B727679736F6E696E65605C544F4C4B413F3C3C3B3C
3B3D3F3636333F38
3333323B3E3A44545952595A5A6A737D909BA5A8AEAEAEACACA49C8F8179755D636D7278
868D999EA5AFB1AEB0B3B5B2B5B2B3B4B7B7BABAB6AEA7A6A5A2956F3F3F4E4C2E232D38
2B2E272D322E33332D2F312E3A393D3F3E343F2E2F443732536A3F282C39372F33354546
493C606B4235252C30335D5F696F746D646A4D362D2722315B4153707F4A22241E2C3D50
344C726639424E35344E81756A82644A657D6E6C6739293A2B2A2E342E312B2A2D2C292A
24262B252824252E2F32313B3F3D3F475153545B5E58595E63696D6C787375787C7B787B
7A7A797A7D7F7E7F807C80818080818385837F7E85848485808787858589898B8A878787
87878B88898B8C908D8E928E918A8D929390918F9293949592929695918C8F8F8E958D8F
93908C8F9291908F898D8E918C9090908E8C8D8F918B8E8D8F9394969697979598979A9D
9F9F9FA09EA2A5A9A4A4A6A6ABADB0B1B1B6B8B5B8BBBDBBBEBDC1C1C5C2C5C6C9CACACD
CDCDD0D1D2D4D5D4D4D3D5D4D4D6D6D8D6CC9D5946575257565E5D5963626167666A6B6E
686D6C6E706A6969696664726F7074787171706E6D72726F6D70707276716F69635E5A54
555854525554555E5C5655505656504E434B464F54585E6564686C735B665351494E4746
43463E433D40404C525C6A6B6A6F6D7072777B7477716A6D695D594F494546423E3E4039
3D413C343535322F
2C2C33353D4357515D5B5F5E606F7A84959EA8A9B0AFAFAFA8A69A8D8379695A606B707B
88939B9FA4A8ADAFAEB1B3B4B5B7B5B5B9BBB7B8B4B0AAAAA39E8E6A3D404F4C35292832
2E302D2D3027312F372F392F2F38403B3C2E3539343936325269322C2D36342E31352F3E
3E375A704B362F2835385D62697475636C674B342D2F2A35432E62706130252D22284D35
418479414C4D3A3D48557F6C7A7A637C91886F614C35334A292A2A2A2B292D28292B312D
333A29292A3128262527282A3934373F4C4C4E525656595D5D6465636970727676797779
7B7B787C7D80818380817E8280807C8282848383858486847F878B89858E888B8B8B888A
878785898D8D8B8C8E8A8B8F8E8F8E8E95938C8E8E9392909293959194939090918F8F8E
8F908D8F8F8D8C8A89908A8F928E8E8F8C8F918E918C8F91938F91939A969A9997999EA0
9FA09FA19FA2A3A6A9A7A9A9AEB1B1B2B2B4BAB7B9B9BABBBFBEC0C3C2C7C6C6C9CCCCCE
CFD0D0D6D2D4D5D2D3D6D7D7D6D7D8D8D6C4864A4D525354565A626063666564666C676A
6A6E716D686663626665676D6D6C73746F726C6F6A6A6E6C70737B7D827E787166585656
514E5153504E555453565A5A505450514D414749545862656F67676A68665E5B51504A42
4441493A3B3A424652546368666E707277737372726E656667605A544A4A483B43413E38
393B3F363738312D
2C2C36433F4A4F565D58655B69707C8394A1ACADB0B0B2AFACA59E8F7F7462595F666F81
8692989CA5A8ABAFB2B0B1B5B6B5B5B5B5B7B9B9B4AFB0A9A79F88664549584D382A3233
352A272B2E2E2E34312D343A3938464047342E33313236305065362A273333352D393746
45344A6C4D3D2926334E6455687E7866756049383C4236302E386968412847222C413936
758B4E335836333D525E786F716B85A1957D663E3B232C453723212E2F2D2C2626343430
332D2C312C2C2C2C242C2C2928282928363A3A41444D554E555D6059626E7073767A7B7F
80827E80827D7F81838480808280817D848487848787888583858F88858985868E8B8E87
8C898D8A878E8A8D8A8B8C8D8A8A8D8F928F938C8F8F93919191929191928E8F94898D90
8D908E8C918D878A8B8C8B8B918D8F8E8B8C8E8C8F8F938F8F938F95959696949B999D9D
9EA19EA0A1A2A5A6A4A8A8ACAFB1B2B1B1B3B6B5B8B8BABABFC0BFC3C5C6C7CAC8CCCDCC
CED0D3D3D4D5D3D4D3D7D5D7D7D7D6D5D0BB7148505359555A5B5C6360616164676F6C70
666B6B6C6A6A66656569626A69676B6D706F6F6D656B69666F7F8A9A95918E8578675955
544F484B4A4B4F4B4D4F5552554F4C4D4B47474F504F53615F666C6A6F6F645B5B58464B
46454546403D3F40494F606768736B71737479777174696662695B5449484442423E3C40
40424042393A3130
2D2D37444950555F595962606C767B8894A2AAAFB2B3B2AEAAA5998E816D5A565E69717E
859498A1A6AAABB3B1B1B3B3B2B9B4B7B5BAB9B5B3B1AAA8A89D82604E4C595D4B2C2931
35302D33312E3838333A3B3327303F413E3B2F2B3334332D505936262D35323033314149
4833427453362C21314A5351697A66666B5944372E33302F2B4D70592B2A293641443159
956F3142443636434763716F716E9FA99269432F383031492F232D2928303F2E2B342E30
2E2E28332F2F2F2F3131312F272F2D342725292D393F4452515A6368686D6D6F6C707376
797C7A7B7F7F797D7D7C7C7E817D7F85848281858586898A8488888B87868A888C878B8D
8B8E888B88858B918D8B8D8D8C90908F918E8E90949291919394949093978B918D8F918A
908E8E8E898C8B878B8C908F8F8D8C918B8C8E8F8F8E8F928F90979295959A959B9E9C9D
9C9E9E9EA3A0A4A3A6AAA8ACB1B0B2AFB2B5B4B4BABBBBB9BFC2BFC0C5C7C7CBC9CCCBD0
D1D3CDD0D4D4D4D3D4D4D6D9D5D6D6D3D0AC604C5254585A5A6160625E65606A686D6A6A
6467686A646662655E5F636266646C6A696C6D6A646A646A738399A3A3A5A19D8C705F5A
505348534E4D4450494E4B4B4C4851524E4A48454952555964676870737262625A585551
484A4D46404040424750535E656C6A6D767771747872696668655C575045424040433B44
453D41453D32392F
2B2B3D4850595F58635E62636873808D9AA1A9AFB3B4B4B2AFA89989836A58565E63717F
879395A0A7A9AEB1B0B1B2B4B2B6B4B3B6B6BAB3B0AEA9A9A49B7B5D54635E605B34282C
2E292A2B362F333A2F3A3B2D2A2D49453C332F2E3531302F4D5236292E3030352E2F344B
553C3C81613F2A283944564F6D684F695E3F30282F312C2B345D665326272B3D41324492
8A422E4B2D36394F486C676C738DA5957B562A32442834542F2624242D292D2C28282E3F
28272C2C292B2F3235383834363635302B27292828292B2E3245504E585E5E61666B6B6E
71737578827C7B7C7B7A7C7F838281848586808484898888888C8A8C8B88918A878B8B8A
8C8C8B858A8D8B8C938F908E908E918D9190938F939490929192988F908F8F8F8F8E8E90
909291908A8C898B8E908F928D8D8B908D8D8E90968B8F90909695959698979696979B9B
A09AA2A2A0A1A6A9A9ABA8AEAFAEAFAEB2B2B2B7BABABBBEBFC1C2C5C9C8C8CBCACDCDD0
D0D4D0D1D4D4D3D2D4D7D7D5D6D3D5D5CC9F574C55595A595C6163636466656C6D6C6B68
64666B656B696466625F5D65676466676F686567635E5C6C7D8FA1AEB3B8B7B2A7957E60
5654545D555E504F43454A4D4F4D4E4D4C4E4A49464D4B5C5F5E676B74706A6B615B5B4D
504F535147463F433D4A4E57616569696E797170706F696968636260575042433C3D444D
49433F40403C3C37
30304252565D66696667676667757F8D99A2A5ADB1B3B3B2ABA5988779665A57616A717D
8A8F9A9EA4AAAFB1B0B1B2B3B3B5B4B5B5B7B7B3B0AFA9A5A39B7650556F676D5B332C2B
2A2B303930323E353133363627343C4737392B29303034334C4847362F2C2F33332A3B55
55413E7E603B302F3A415758695E505E4C2D282E37342C2A466E573C23252C3736396090
5B283442372B494C535B4F6C799D966E5845373E52344642322C2A2531362F322A25292C
2D282F34312B2B30353A4244495052463A3732312C3426252C2D363B4A53545B63666369
6D72747A7B7E787B7D7D7E82908483847F85818A888A878784868C898C8985898B8B918B
8D8D8E86878B8A89918F8F8F8D8F8E918F9091919494929491919391909092908E8D8D8C
91908C918B8B8A8B8C8C8E898C8D8C8C8C898B92918B8D978F9092959397989B9C99999C
9DA0A1A19FA5A5A8A8ACA9ADAFADAFAEB2B5B6B7B8BBBFC1C0C1C3C7C8C7C8CCD0CDD0CE
D0D0D3D3D3D3D2D2D3D5D6D7D8D6D5D6C186514D51535A636166656466616D66676A6863
6364676762676560625D5E625E63626267645D5E5B5E626E839AABBAC4C6C7C2B9A99682
6258524850554D4846453D454D49464B4C4C474A434B4D51575C646D736E7073685F6052
4E4C4F4C473F3E403C484D515C6160656C7170706F6E6A6A67636160584F454338413F49
4542424A46403F39
37374D555E68706F71736C6A6F77848AA0A4ADAEAEB2AFAEAAA293867763555860676E7F
8F939CA1A8AAADAEB2B0B2B0B2B1B3B3B6B7B7B4B3B0ADA7A59A704456766D6B613E2C27
2529302B2E2D303E2E2D3F3A2F333B43392E2A332E312B454C47443330282D332F2E3650
52423C806140302C373C4E566354535B3F272A332E362D305C5F472A2D3831302F4B7A77
3E323F4443395A4F554246618C9682484F4728394942533929292723282D31312D29262B
24252D2F262C282A2C364748505057525D5A52433A394A2A262E2724323B43545D606464
686C6F75777776797D7C7C7E7B8483828484848288898886888A8687868B85868788918B
8B8D8F898B8F8A8D918F8E8E8E908F908F94938E959092949690929191918F918F938E8F
8F888C8B8B8B8E8D898C8C8B8D8E8B888C8A8F92908F919693969297959599989A9D9B9E
9D9E9FA0A1A4A8AAAAA8ADADA9B0B0AEB2B5B9B4BBB9BDBEC4C1C4C6C7C9C8C8CFCDCECF
D5D1D3D6D6D6D6D4D3D6D8D7D7D7D5D2B268494D545960615E6168636466626864676766
625F69646163676564555857565B58625C5E605F5B575B71899EB1C3CACFCECAC1B9AA97
7A615B4E4E4B4C4041433B3A42494A4D544D4A4F4A464946585662686C6B6E716969655B
59584A4B463E42493F444D53565D5E5F6B7172716B716D676563605D5D534C494038393E
4B45444647453A36
373750585D66706E7373747075778B93A2A8A9ACB2B1AEAFA9A2978476695A5B5E696E81
8B93989FAAAAAFACADAFB1B2B0B4B1B4B7B6BAB4B2B0AEA9A1986D4661796C6C674C2C27
262D32272B2E333B32393F402A283A423A392D3231394639473F362B26272D2B352A3346
5345417A543B342D413F5A625B5954492E272F28312C2C4261584131424635342C467652
2B3B424D31305B524A40586A959384485C49263548585B34282A2526262D2C31332E2627
26242F2724252529292D3A40515154525F62655F605B4D3E2C302D262E2F2D4048546265
69686E73767877787D807B7D7B817F8782868A848587838B86868887898D87888C88918A
8E90908E8C8D8C8A8B8D8F8F8F928C8F8F8F958F9090949091908E92928C8D919691928C
8F8D8F8E8A8C8E8D888F8B8B8D9189898D8F8E8F8D909192939192939196959B9A989C9F
A0A0A0A3A3A4A8A9A6A7AAAAACB2B0ACB3B6B8B9BABEBEBBC1C1C4C5C7CBC8CECCCDCED0
D3D2D4D4D3D5D4D4D5D5DAD5D8D9D5CEA05A4E5255625F6264656565686268696F6F6367
605F60635C6262615A5A595653585C5E575E5D595B595A788CA1B3C5CFD2D3D2CBC3B5A4
8F7D69555144413F3C423A343A3F3E4A404E464A4643414C48525A5E6469686C69666160
5A63544A4645484445445351545B5D5D696E7172736F6C656966675F5C5E504848423640
44404448454B403A
3F3F515F5C667172767275757F7F8B98A6ABABB4B1B1AFAFABA2968A766C51515F687380
8B929EA3A7B0B0AEAFADB0B1B1B2B4B3B6B7B8B7AFB0A9A5A0956C4B697E777568522B2C
2D2D34332A303E3A2F2D40362D2E394135312935323136383D3732312F272C2D312B3846
5A543D605E3C3230403A4652565B533B2A2D2B2D2E2B2A435B4F475448413C48325D6232
2E44453A3451504D45505B849C8C6B4D583A24334D69472C343128342E2B2D36342D292A
27252A262323232A272B3037464B4D51555B65656E666468544E3A2B23201E272C3B4A55
5E6466696F7375767A7F7A7F8281848385848486858B878A858B898C8A898A888D8A8C8F
928B8B8C8A8B8D8D8E8F8D8E8F8E8F948F8F94948D91909391908E8E8C8E8F918E8B918A
87908E8B898C8E8E8B8D888B89888A8C8D8D908D90939499939092959699979C9A99A2A3
9F9FA2A1A1A6A8ACAAA6A9A7AAAFAFB3B3B5B9BABCBEBEC1C3C5C5C6CAC9C9CDCCCCCCD1
D4D3D4D4D4D5D4D5D4D7DAD8D6D8D6CA8E5153505A5B5F5F6668626D6A6566676B6A6463
656365655E63606258585357545055535A585A5552525E758EA2B5C3CED5D5D4D1CAC1B0
A08F82705D554D4A433F3C363C3B374A45434A4D4C3C4543454E5657576564706A696865
5E5C544F4B4747414B4C504C4F575E5D5F6D707474726B6568685E575C60584A5448393B
413D464E4D454138
44445157636771707372747A82848A9AA6ACAEB0B2B0AFB0ACA19687796251535B697184
90959CA5A5AAB2ACB0B1ADB3AFB1B4B5B9B7B8B7B1ACACA7A293634E7880736C5C503429
352A3A36292F3335342D31382B30374038352D343135394338312A2D302C352E2E35463E
5151424F4C3D2C2D393D4C5656543D2A292C37362B252F54485967513E373A393D6D432A
384B3B4258574F435057788B9676403A4F30354662633F2A312E2C2E2F292A3131342D2B
2B252A232223252B332F323B45464E4C51596862666D6B6A6B72654F3627222E232B2E3B
4F5D626669707575777C78847F80848388828486868A898B8788888C88908D8888878A8D
8D8B8A8B8B8D8C8D8F8E8D8D918D8C8C8C8A908C8E8D8F8F908E928D8C908B8C8C8D8B87
8A918C89888E8F8D888A8A8C89898C8B8E8F908E8E93919695939191959E9A9B9A989FA1
A2A0A4A0A5A8A5AAAAA5A7AAACB0AFB4B2B7B8BFBCBFBCBEC4C7C6C5CAC9CDCECFD1CFD1
D2D1D3D3D5D5D4D2D3D7D9D7D8D9D5C37C4E4E575A616660636469686B6766666C656860
5C5D6368606062635F535552534E4D4C554F56504F575C73889FB5C5CFD3D5D4D4CDC6BB
ABA492867D625D554D3C4036353435413F434C514A48464441444B52565A61676A6B6D65
69605B5449494B484A494F524D565B5B63686B6F75716F6468625E58625A59514F4A443B
3D434646423E373C
4949565D63636B6B6C747A7B84878E9BA8AFAFB3B5B4B1ABABA198897B664B5260677481
8A929CA0A8A4AEAEAFB0AFB3B2B3B6B6B7B9B8B3B3B1ACA7A1955A4D7B7E77685C4C3429
292838333130352F2C2D303328342D3B3A332A2A3930364137302D2E34342D2A3031333C
4250404454402B323438505B5758322C2E2F322D27243549586F59443430343451622D30
3C3839576D60363A4463767E8B5E374553535D6D68503B2C2E352E2C302A2F2C2B2D322A
292B272825252F252F4131333D4A4D504F4F61646668626C6D7774726657382723272027
3349575B65686B737A7E7B7C83817C8283868285888987878688908D8A8B8B8B8E878B8A
8C8B898B8C8C8D8A8B8C8E8D9394918F918C918A8F9092928F908E8A8D8C8C8F938C8F88
898D8D8E8B89918B8D8B8B8B8885898F9090928F8F91939193939293989A989A9B989EA2
A2A3A2A3A2A7A9A7ACA9A9A8ACAFAEB1B8B9B9BDBFBFC0C2C3C5C8C9C8CBCBCDCFD0D2D0
D2D3D6D3D6D4D3D3D4D7D5DAD8D8D4B16A4B54565D5B606763676B6A6B67696E67656061
5C6764635B5C5C5B5350504F514E494D4B464E4B4A50576B83A2B6C7CCD1D1D2D4CDC8BF
BAB0A0949283725A4B49453C37363635443F454548484943423C484D515258636A6D6F66
65656155554C534A484C4B4D4C4F515A626E697073706F6B66665E5A5E5E5A524F4B4C43
403C414249413C3B
5252585960606169696D757985868F9DA9AEB2B3B6B6B4B3ACA6988779654A4D6066747E
8A949DA7A7A8ABB1B1B1B0B1B0B2B4B4B5B8B8B3B1AEADABA190564F717F766D59533F2D
272D412F2B2D333A2F302D342E2E2F3136302B2B322E34413C3930322D3530303233352E
374E3B3C4537312C33344B515A552D283437372821293C405861472F2C30373F5E4C2C3A
2F2E405D6E4B303840675D687F5042556679969B7340323333302F2F2D32302F32312E2A
272B2C2A2729292A322D2D2F383A494B454D515E6765656E717979777071674E2A292127
2B32404C52646572797D7E7B7C7E7D81858480838984888582898E8A8B8B8C8C8A88888B
8C858B8F8B8A8A8C898B8B919290938C8F8B8C8C8F8F90918E938D8F8C8E908E90898B8A
8B898A8F8B8A8F8F8B8B908E8D8A8B90909094939190939093939496989998999E9D9FA1
A39FA4A7A0A2A5A5A9ACB0ADAEB1B1B3B6B9BBBFBEBFBFC2C5C6C8C8CACCCDCDCED0D2D1
D4D6D3D3D6D5D4D2D4D8D7D8D7D7CE9F615154535B615E6766696D6C6F696869676C5D5D
61655E625E59615554524B48544A48464342444C4A4B4F60809FB6C4CBCECFCFCFCAC6C3
B8B5AFA7A1988B7460544B3A3632343439364040424A4C3E414141414C54585F616E6968
69675C585A4D504F4A534C4D4C524E515965626C7272756F6865615E5E62565951494444
3E343F3D444A4745
56565E5A57626362656C6E75838A8CA0A7AAAFB4B5B7B6B3B0AA9789775E48595C667483
8B939AA7AAA9ADB2AFAFB2B4B3B1B5B2B8B8B8B5B3B1ADA7A68B5C596F7B78715B584A2C
2E2E2E39302D2B302E312B32392F2E322D302D32363237413B2E2C3A333736302F2A2C2B
323C3B3F443936392F2E4648525335313237312B252F433B554B382A2E2F38495833333B
2F3547685B3730455359454D7747486478898E826B342B2C2F31362D2C29312B2F372B2A
2B2F2C2C29242221292B2C333536424F4C4746565F6368696E77797673757572593A2C21
232A323D4C5C636874787C7D7C838085858580858988878C8988908C868D8B8F8C878A8B
8C838C8F8B898B8A8B898C90909592928F8D8B90928F958E8A8E8E8D8F8D8B8E8B8A898B
858B8B8E888C8E8E8C8D8E918B8C8B8D92918E90919291929593939896989D9B9B9AA1A4
A0A6A6A7A2A4A6A8A9AFB4AEB1B4B3B6B7B9C0BFBEC3C1C3C6C8C9CBCCCED0CFCECED2D4
D4D5D6D4D3D6D3D1D5D6D7D9DAD4C8894F515658595C65676A6E71716C6D686868676362
625F5C5F57555757504D4C4B4B4342413F343B363A3E495A80A0B7C2C8CACBC9C9C8C1C3
BEBBBFB4B1A9A08F76694F454032343639353A4045454C45414342484757556260626668
6766615D5D57544A46504B4B4E525452555A6068686C72756C69615E5C5F5652524C5044
453D3A3C47484746
56565B5E5B595B6263666E727B848D9DA4ACAEB3B6B8B7B4AEA59488775D475160677480
8B969DA3A6ABAEB2B0B0B1B5AEB2B1B2B4B9B8B7B2B0AEA9A188646E66747B765A585134
372E33392D292D322E2E3431302D2E3127332B2E343536413C343230332F31302A302B30
333A4846523B313A37323E4146402D28303131252636393F463A252D323A41494A2C3632
313F43563A3B414A553A3B48734C68868C7B787B3E34302A3031332F3333292E3635292B
2632292826222126273132352E363C48494B545A585B696A70717D79777873756F5B3E2F
2322212A344F57666B757E7F81807F83828285858887868C8787898A8C8B868D8E898D8B
8C898B8D8A8B8B8B88898D918D95908E8C8A8B8E908D93908C898B8C8E8F898B8A878C88
88868B8D8C8A908C8E918E8E8B8B8A8F8E9190918F9395989893949599999D9A9EA0A0A1
A0A5A3A6A0A3A8A8ADB0B1AEB3BBB7B9B8B9BDC1C0BFC2C4C8CBC8CCCCCECECFD2CFD1D1
D2D2D5D4D5D6D2D0D3D6D9DAD8D4B66B4D53565E60686A6E696E6D6B6C686568626B635E
635E5C5E58525558554D4647413E3B3634342D3037384A6385A1B5C4CACBCAC7C6C2C0BF
BEC2C6BFC1BCAEA5907958453E3633333434353641474C434C424145444E4E545A5D636B
6B6C5F636653514C4B4C5052524D4C5250565A636B6C727373686768655B565451525349
45393A3E403E4340
545459595A555A5B6462646C7B848D9DA5ABB0B7B7B7B6B4AEA49583735A455262667180
8D969BA3A9ABB0B2B2B1B2B3B2B1B0B1B6B7B9B6B2AFAAA6A086666D62727C765B56523E
2D2D2A3434322F2C2B2E313135362C2D2D302A2B383734433F313432332A2D2A2E3B3132
2F393F424E3C344237313C3C3B392A2B2F2D322A2C364140373223303D4B3B4A413D3C36
3A424141393E474F3E464A6480758E97805E6277584C41332F33352F2B2B2A2B282E2D28
2D30312822222423252A2D362E2E343A45494D5053546C6B6A747A7D737671797475663E
2A2423232C3D4C56656F7B7F7D7E8182868585858887868A86858B8B8A8B8D8C888B8A8A
898F8D908A9387908E8D908F8D908F90908F8D8F938F92908B8B908D8F8D8A888A8B8989
89868B8C8A898C8E8C8D888C8A8A8E8E91939094919295989995999896989D9C9E9FA1A3
A29FA4A4A4A5A7A8AAACB0AFB3B9B7B6BDBBBFC1C2C1C5C4C7CBC9CBCBCFD0CFD1CFD0D1
D1D5D4D6D7D5D4D3D5D8D6D8D8D0A2624A51585E5F666B666E6B6B6D6D706B6B6863635B
645B5F59554E5052504A483F463B35332E2C35313939476C90A7B9C2C8CBCBC6BBBCB9B9
BAC5CBC8C8C6C4B5A395775A413B3837353136373B454647504E464341464D495458616B
6A6B69625C58514C484D4A4A4F4A4B4F54575E6363656B7270746A625F5E545354565651
4D3F3C3B393B4442
59595A605D5C5A5B66625D68777A8899A5AAB2B5B7B8B4AEABA3958070544B5762657383
8F969CA0A5A8ACB0B1B4B3B0B1AEB2B0B5B9BAB7B2AEA8A6A187727061707D7C635D5B39
2D2C2828362C323E322F3334302C2C333330313230302D33333133313133303232444138
2B2F3E49503B3F493C3E41422A2C2F30292A2C29313839372C28273B504635473D373C34
2F2C3535444043465B747E8B989D9386654758677F80784B322D35362D31262F2B2A2C2B
2B2B2A2F28242528232329312F2F31373F4D4D4D4B525E6867757374707E7675777A7762
4B2A28242A2D4E4E5A63747A817E7F808580888587848A8789898A8C8B8B8F8B8B8B878B
898B8B8E888E8E8C8E8C918E918F8D8F918E9090918F8F8C8B8E8D8B8F888F8A8B8B8987
8886898A8A898C8E8E898B878F8B8F8F8B90969093909696979797969C9B9B999DA0A09F
A2A5A6A9A8AAA8A9A9AEAEAEB1B6BABCBEBEC3C1C5C8C6C4C9CBCBCCCDD0D1CECDCFD2D0
D4D4D4D6D5D5D5D7D7D7D9D8D6C88B4D50555A6261696C6C6A6C6E6C6C69686262606A5D
575A5C5B5558514A524B4242403B2F2D282D2A292B2D4A7095AEBFC5CACDC9C2B3ACAEAE
BBC3C7CACBCCCAC0B8AD9475554739353635353A3D433F45515343414543454C50536162
676D6D6E6A60585150544D504C4F4F4E4F58586061686A72757665625F60595550534F54
44413E383C3B4543
5F5F5D5E5855535A5B555B6873798799A4A9B2B6B7B8B4B3A59F8E7F6B4F445257697686
8C969EA4A7ABACB1AFB0B0B0B0B0B0B2B5BABAB8B1AFABA8A28A707C606D817A5F54562F
27262B3232283A423E393C3930382D2D342C2E2B3530322D342A342F382B373936424842
32353D444D393B443B403D302F2A312F2F312A2D3536362C2523364C49353D4F3B353231
2B31312B44444371817D82A1ABA185735B65546474798D75362F2E352D2D292F2C2B2A2C
2F302B292D2A282320272727292C2B313E494F484C5056626872737671777377757B7A72
663E2C2A29402E3A505765767A8382838581888F8589868586858A888F8D8D8D878F888A
898C8F8D8A8D8B8B868C92918C908F8D8F8D8F8F8C8E90918B8C8A898C88908D898A8B89
878C898D8B898B8E9189858B8A8B8F92928F94939091919798999A9A9D9B9D9B999FA2A2
9FA1A7ACADAAA8ABADAEB0B5B5B8BCBEBEBFC1C2C2C6C5C8C6C9CCCDCECED1CFD0D0D2D0
D2D3D6D4D4D7D8D4D8D9D9DAD8C4764F54545862686A6D6C666B6B6C6C656868675E615E
545A5D56554E4A5149443D3C3B352F30272D25282C2B436C99B3C3C7CECDCBC0AD9D9EAB
B6C0C6CED0D0D0C9C4BCA48D745942364036353B413F4A444C4A4C44444447424B545863
666A6B6E66605C5B555552524C4D51544E5658595C636B7571726F6967635F58524C494F
48443E3C3A393B42
5A5A5D585858515358575D61707A899AA7AAB4B9B8B9B7ADA99A8B77644B434A5A697487
8C979FA2A8ABB0B3ADAFB0B1B1AFB2AEB8B4BCB5AEADADA6A08C6F715D6C88856B5D4B30
2F2D253333323037363B414F363730333133292B303733343C34372E2D343C352F3C4547
3A313B43483838373D4442332D2E2F2F2F2F272E332B2C2E2728354639344D4C3D352A2F
292C292A3D486C8A768393959C8F73697169635D576F7D76332B3132343531262D2A2B2A
2D2626242C2A2425253130302A2D2A2E3545504E4D4F5B61656E7274757A7474757D7874
7860442F2F28282B384C596E797D8086827E84898888868485888A888D8E8C888B8B858B
8B8C8A8D8B8D8D8A8B8C8F9390909392908E8C928C8F91938D908A8987878E8A8B898D88
8B8A8889888C8A8C8F898C8B8B898E918E909294909194959898989B9E9B9B9A9D9E9FA1
A4A1A5AAABAAAAAEAAB0B4B6B2B5BABCBEC0C0C3C5C7C5C6C7C9CACDCCCDCED0D2D2D3D0
D0D4D4D5D5D8D6D7D7D8DADAD4B06651535E5E6561656C696B6970686E646764625F5F61
5A5B5E58564D4849413D463A302C2F2D2A282826242A446C9CB9C7CDCED0CDC1AC9B99A1
B0C0C7CDD0D3D4D2CEC2B6A78E70513E3E37363C3737404448494E4E4D494946494A525C
5F67696B7367625D5654504A535455515252544F5460666B6D7475666660595A564F4A50
4D45403C3E38363C
4949545650544F54504E535A66778899A8ACB3B7B8BCB5B1AA9B89796249435354687581
8E93A0A0A5ADAFB1B0B2B1AFAEADAFB1B2B9B6B8B0ADACA79D916C6F635F868B72494532
382E273535362C2E372E474F483F302A292D2B2F2E343F3D362E2F3735343F3E34383F45
3C3635414B39374E37433E3231302E2F2A2F2934332C27252B343C382E365D46353C3331
312424334D68838176918E828678685C5F7A653F5D82786C2D2A2B2C33382D2E3429322A
2E292D2829282F2625242B2A3129292D2E3C4A504F4D5B586668727671777671747C777A
7474634B342C2C292C415363717981848480858A8789898486868A898B8E8A8A8B8D8D89
8C8F8A8B8C8C8E8D8D8B8E938D90909090908F958D8F918E8E8E898D898B8B87898D878B
89888C8E898D8890898B8B8B8C8D8D9293909392919294979C9D9B9A9D9D9B9C9E9C9FA4
A2A7A5A7A9B0AEADACB2B4B7B2B8B7BCBFC2C2C4C3C5C3C9C8CBCACFCFCFD0D1D2D3D1D1
D5D4D4D6D7D8D6D6D8D9DBD8CD975856565B606562686D69696C6D696F6465656065625A
555756505050474A3F383631292D2F2C2C252320242C457399BBC5CDCED0D0C5B49A979C
AEBEC7CFD2D5D7D4D0CDC2B59C87624B4A413F35323F3D3F4849504D4E505046444C4C54
595E676F716E72595B525A515551565054565257595D65676C70716B6460565856494947
443F3F3B34343C3F
3B3B4D514E4C4C4A46484656677B8F9BABB2B1B7B7B8B4B2AA9A86735A453C4E5A6B7681
8D949DA0A6ABABB2B0B2B2AFAEACADB0B1B8B7B2B1ACA6A5A39579606756868F6B494334
3638272732412C2B3532343A4442363331292A3130353B3B2D2D322F2E37464032313B47
3F3E36443F34343C393C40313332302C2A2728342B26292E3C4A39302637503A302F2F31
3126315265808B93918F83848272505165727C6D8A8C69512D2821283237372B25282D2B
2D2A2328292C292C2825272B26302A2C30343B4A4B4751576164696C7374737177767672
77776F603F2F2B292A354D5F64777F8286818287878B8787858989898B8B8B8888888B8D
8C8E8D898C8A918B89918F958F909192938B8C8F8C8A8F8B8D8D8E8A878B88888A8C8986
888C938C888C8C8E8B8B8F8B898C8F8F91929292939395969997999E9FA09B9D9F9D9DA2
A4A7A9A9ADB2B3B1AEB1B4B9B9BBBCBFC1C1C3C6C5C5C4C8C9CDCDCDD0CFD1D1CFD1D3D2
D4D4D7D3D6D7D9D6DAD7D8D6CA815456585C61656A6A686C70686768675F64635A615F59
5855534B524840393E392E31302A322425253126232A447394B5C3C9CECDD4C7B9A29995
A3B7C5CCD3D6D8D8D3D0C7BEAB947B5D564B49353B3C433A49474E50534E4F4B4942454B
575C606E6F6E6A615E5B59544F55545655585152585B65656A6F6E7267635F5C564A4643
3F4839343434363D
2E2E39464347454341434455677990A2A8B0B2B6B7B7B2B1AC9B8368553E414A5A687885
92979E9EA6ADAAAEB1AEB2ADAEAAB0B3B2B6B8B3B4B0ABA7A399805C5E587F916847413C
313E2B2D3237252C282B2833313A3F372D2A3032322F373F2D282C2D31373E382B2A3748
4447383F3F383A39373D4038303842352F26282C2323273041483A272B363A352F2F2E2B
253C5C6768839DA5907F70848D754959625E79747C705540282526373437373029272531
282B2A2D2A292624252E27252728282F32303A474C464D565B626A6D7074737476767574
8178796A56382C292B2F3E4C5E6B74838181848387888B87898D88888989888689888789
898B8A8A868C8D8E8E8D8F948F8E9194918D8F8E8D8E8E8B8B8C8D8C8989878889898686
898B8B8D8A858B8A8B8B90908E8D91909493949194989B9A9699999E9B9A9E9B9EA0A2A4
A4A4A9A6ACB1B2AFB1B3B7B7B8B8BBBDC0C1C2C5C3C4C5C7CCCBCDCECFD0D2D0CFD2D3D5
D7D6D7D7D8D8D8D8D9D8D8D4B86651565C5F64626A6B66686466686666675F605C5A5856
515251484B453D3D373235332E2E2527222325272E3641658BA9BFC5CACACAC4BDAB9F98
9EB0C2CBD1D6D6D9D6D3CCC0B7A28F78604F463F3B393F3942464E4D545354524740444A
535A5A67656F6C6B66625C5956565353505B4F505F5A61616B6C686767645C5C5752453B
3A4136363A343339
3030303138363C3C3639374C6C8094A3AAADB3B5B6B5B0ABA69E886C4F3D3D475B647785
8E9A9FA4A5ABADB0B0AFB1B1B0AEAFB1B3BAB7B4AFAFADA6A4998960595B7C865F443E3C
3C32272835352A2F2C2F2F392C2B32413539353C2F2F39423A2C32343D413B302E2D3641
45423E373C3E3D3E3B38302A3A3C433D32302C282D27323D3E393D2F3337312D28262C2C
435C6A686F98A69379657189856559614D625A4B635E4E4B2D29272A2C3537322B282C2D
30333E3B3A392C2D2B322826242A2A2A28282E3C434B475559616968716E797273767678
77767A766B4E362B2828344254646D7E80858382858C8B888887868A8989888B8F868D8B
89898B8B8A89898E8E8B8F91918E91948D8C909191918E8B8A8E8C8A858B848E8E878688
878A8A8D8987858A8C8E8E8E8C8F9294939896939497999D9B9C989B9D9C9FA1A09EA2A4
A8A4A6A8ABB1B6B0AFB3B4B4B7B7B8BCC0C1C4C5C4C8C8CBCCCDCCCFCDCFD0D0CFD2D5D6
D4D4D4D7D8D9D9D9D8D9D9D3A65A4E565B6061646D69696666656665625D5E595D58514F
4D48494A4A403C3A352F343126272A2A23262B35343643607B99AFC0C7CAC6C3BAB5A9A1
A1A8BDC7D0D2D3DAD3D3CEC7BBAC9685695952464A413A393D4A4A4B4E52584F4F4D4A45
4C575A5B5E646B6B66665E5F59565B5D51535C54575A5B6166636D6669645E5E54544A48
383E3D3834333335
32322F2E2E2D3532383635506986999FA7ACB1B6B4AFADA7A19A8B6C4C3E3C4F58677C89
9097A0A0A8AAACADAFB0ADAFAEAEAEB1B5B5B5B5B0B0ACA6A1998C654D5A787F5B464346
4630292A353D322928262C302C272B2F374A453E392F343E36302E304140362D2D2B3145
50463F333A3F3639383F38343D3A343132332D27292F383F3D342A2C3238302F24282C4C
636D6D7187999378647592876B6E7250585F39436E7056442A272927302F373B312E2A37
302D332E2E292A2A2E2F2B2822292A2D2B2A2C333A434451555B5E696C717272776E7777
73787773716847322B252B374F5C66727D838482848688889085878789888A8C8C888A8D
8B8C8C89888C8D908E89908F8E8D91918E8B8E8E8D8E8E888D8C8E878B8B888789878885
888C8B8A8C89878B8B8E928E8F909491939A989799999A9A9C9A9A9B9E9EA19CA2A0A4A4
A2A4A9ABADADB1B0AFB3B8B6BAB9BCBCBDC4C3C6C5C8C6CCCBCDCDCECED0D0D0D3D1D4D4
D7D4D5D7D8D8D8DAD9D8D8CB894E51545D5F5E64666466666A5F5A625C5A5B585B545250
4D46443F3F3D3B3A34392F2D2F2E312D2D2C31353B415C576F88A5B7C4C5C3C1BCB3A8A0
A1A6B9C4CDD2D6D8D7D6D3CCC0B1A18B796B574D4B443B393B3F3E49504D53524D4F4B49
4E5A5F6368646F6A7169655F5B5B5855595653595D5E5B6165626A696263626058554C49
3B3A3C3833333032
2B2B2A292A262C2D29293147648697A2A8ACB3B4B6AEABA49E90846E483D394B5C637A85
8F9AA1A3A6ABA9AFB2B2B0AEB1AFADAFB4B4B3B5B2AEABA69F9D8F64425F76765E535451
5639292D2E3838282726272D2C252A2B30394D5235323B362F2B2F31494636312931363E
47433B384B42363E3B3F39373C362A29323E2B2D3A3E3E3A392C292F353C382E242C476C
6A5E6F7F898D7B7387948B68738B5F665E4F4E63705D492F282F282B2F3033363D332C2E
2C292B36312D2927262927292727292B272C2C323C44464B58595B67656C766F73747578
7179747677745F442C24272F47595F6873848588898488898B888586888B8C8A8B8B8C8C
8D8D8A8B8B8B8B908E8D928A8F909092948B8E8C908C89888D8C8E8A8C87878887868B8A
8C898A8D898B8A888E9292918F909391939A94969795979A979C9E9B9F9C9D9CA2A3A3A5
A9A8A8A9ADB4B1B3B1B5B7BCBBBDBBBDC0C5C8C8C8C9C8CCCCCFCCCDD1D1D1D2D2D3D4D6
D4D4D8D8D9D9DAD9DBDBD7BB6A4B535959605C6B636263615D605F5F5B5A595457594F4B
494941403F3438353238352A2B333131313839404C516263677692AEBDBFC2C1BBB0A697
9FA5B2C3CDD2D6DAD8D7D3CCC3B6A894846F5D594F4C403D39363A47514E5055534E4D50
4D555C5E6067696C696A635C5B5B57565A5655585D605D5A63656766676362615C5D514C
3C383B3834353533
29292328211F202322293045668E9A9FAAA6B0B1B6B0AAA29D917C7946383B4653647686
8C9B9FA3A7ABADAEAEAFB1ADB1B2B0B2B4B3B7B6AFABA8A6A19D8E714B52797D64515159
5C332823303B3A2F2A302C342B29262A2D313D58403C3A352B2A2D2D504D3837332F2D39
42443C3D473E4145433D333A3427292E373D2A38343735323024242B242C342E293B6167
5A667B7E717D818F8F91674A7180576A57667D735D48312724302B2E2E3137343B342C2E
282D2D323129282826262D2A2C27292C29292F33373B3B48585857606870757772727578
7476767878756C4F3527242F344D57666F798482888188898A89868A8688888B8A8C888D
8B8C8E8E8C8D8D8E898F8F8E9392908C938A898D8C8B8C8B8B8B8F898B8888898986898A
858D8C8A8E8B8B8B91939391919190939296939697939897979B989BA29A9FA2A3A3A5A5
A8A8A6ABABB3B1B3B4B7B8BDBBBCBCC0C1C2C7C9C7C3C8CBD1D0D0CDD1D1D0D0D4D2D4D6
D4D5D5D7D8D9DAD7DADBD4AC58454E5A58645C5F625E61575D5E60575752584C554D4F44
4B443F433F3B3E343A383632342F34343C424A505B6568707477889BAEB8BBBAB5AFA093
98A4B1BFC9D3D4D9D9DAD3D0CABEAF9E8C7C6A5F544F463F3F393C4157505159594C4A46
4A514D555C566B6C6F6966605B5D5F5A5C585B60595C5D5A5D6566656A6661635D5B594F
453F3F3B39373435
2727262221211E22222A3447678D969FA8ACB0B0B2AFA8A3998F7B6A45353D4B536B7586
8F969DA4A6AAAEADADB1B1B0B2B1AFB0B2B4B4B4AFB0A9A29C9B937F5E5271826553595D
5F39272529323B34292D312F2E2E292D292C304848483F36302F34344C4B392F30343433
3946413C47433A3845423C3529282636333432333A383436312D33252626272E4E565E4F
607582716090A68C8778443E4C5567625C80846A403734282738302B2B2E343837484133
2D2B2B34392E2F2A2B2926292726292D2B2D2B34363D3B445555505D6669717676747877
767680797875776A4F3725272D4552696A717F848688888688868784888A878A8B898D8E
8C8B8D8F8E8D908F8D908D8D8E8D938F928E8C8C898A898C8B898C878B88878484868A88
868690898C8E8E8D919292918F92949993959897969699979A9C9A9FA19BA29FA3A3A4A7
A6AAA8A9ABB0B0B2B2B9B9B9BABFC0C0C2C6C4C6C9C8CBCBCED0CED0D1D2D0D2D3D3D5D3
D5D4D4D8D8DBD8DADAD9CD8F4A464E5A53645C5F60625D5B555158515E51504E4E484C43
3C3E43453F443D3F40443F41423E42405256585C6B77797B80878D939DABAFB1AAA79A95
939FACBCC8D2D5DBDADAD9D2CAC0B09E938573695E534E4A413A3E3D464B4E5556534D4D
504F4B54525662666A6D6E5E5759555C5A5D5C5E5D575B5B606367686767615F5C5E5857
4B423B3B3A37383C
27272525221F1C1F222730476F8A979FAAABB0B0B1AFAAA0938B7E6B433C404657677885
91959DA3A8AAABAEADADB1ACAFB5ACB0B4B5B4B5AFAEA6A0A09B91877260708160445B5B
60382823232C33372E2727302E2C282D2D2C2E2E40454740332C2E2F3D47413032333335
3F444044473F373D36423C2B2929262F2F31323534343039324255262022284466614954
647F80648EAC996A70582A313757675A6D8273623F3D5A3D2E30302D2F303736303E3133
2D29262F2F3531292D2B2B362C2E292C35292B2E2F3C3A3F4A4F4E575F6B71777A78787B
767474797777757163432F2A2632455E696C797F828585878687868684868B88848C888A
93898B8C8D8A91948C8A898C8C8D8F8F8D908E8A8A928D8C898A8B878D87878483848987
85888A8C8E8D898C92928A8D919193929595919998989896999D9DA19EA1A2A4A4A5AAA9
A8AAA8ACA8ADB1B5B5BAB6BBBCBEBEC2C2C6C7CACACBC8CCCECFD0CFD1D2D4D5D4D3D3D5
D8D5D8D9D9DBD9DBDBD9C6794D4A545651605F555A5E59545752534D574C4E4449404B47
4A413F44464A484C474B4851504A495357616575777E888C8C909096949CA1AAA5A19A97
969AA3B6C6CFD4DBDEDBDAD3D0C5BAA6998C7E70625A504C483C3E3E46495055585C5A53
564F4A4C4C505C61636C6E5E565D5B5E605D5F645E565B5A5B6165676964585E625E5C51
504E3F363A333335
21211F2423252722252736466E899BA1A6ACB1B2AFAEA99E918278603C353D4D55697D84
90959CA5A9AAABB2ADABB2B1B1B0AFAEB3B3B2B3B0ABA5A39A99928D7C6C6B7B5C445259
5F3B272E2B2C303F3C282A2A2D2D2B2F2C2C2C2F33394848342D312F4445393038313035
414A3E40473636393934362D2E2F2B302B383939313125313047742F2224325F745B505D
6A847077AC9E70554E37302F414C435A56605B525E6297752E2A36343B3737373537332E
2B2A252831412E28282C2F2D2E2B2D2B2E2B31293B3A3A3F48544F535B6473707773797B
7A71767478767874735D392D2D3045596366767F8286888883858A898884868A8886888A
8F8B8B8E8F8C9091908B898D898C8F928F888C8A8A928F8A87878A8B8A85878689888889
88868B8F918D8E8E8E92929292939195949299959A959B999A9FA19CA0A0A1A5A6A7A8A7
AAAAAAACACAEB2B8B8BAB6BDBEBFBDC5C4C6C9CBC8C9CCCDCFCECFD1D1D2D2D3D3D5D6D6
D7D7D9DAD8DBD9D9DBD7B8624652545A54585F52535153524E51534A52534D4A4A4C474D
48484E4C4E50515153564E5E5E5960646C6D707D81868D95999B9B9A908E97A3A09B9A95
96939AADC0CBD3D9DDDDDBD6D3CABFB39C8F83786B615F55514B48454A5054565E605A57
57514F4B4B50535D64686B676364605F5A5F615D595B5A5C675C66696F695F6762615A57
4F4549403A2D3534
22221E211E212426332B3645638C9BA3A6ADB2AFB1AEA89F8F85765C3B353A49556B7C86
8F9C9CA3ABAAAEADAFABB0B1B2B2B2AEB1B3B4AFAFACA8A49F96928B7E7C73695E4A4C5C
5E4427292A272D3E43333232302E2F2F2C372E2F2C35414C3738332D43453E342D33383D
3C473F43483D3B3233332E2C2F2A2E303532343432322D2D2E4A75412130497B76706061
7B8368989F7A563C303947554834424A454A4B38436997983F2D3E45555C33322B293332
332924262F39302F2B2D2C323032292C2729292A38393636474E4E51555D6B6E71767879
767477747776787B7D654B36262B3E57585F6F7A7F86858681848B8A8486828789879389
8E8C8F8F8D8E8F938E8E8B8C918B928F8E8D89888A8D8988878C888B8B8889848A85888A
8D888D8A8D8F8D8F8C94929290939497929597989A989B9C9C9C9E9E9FA0A3A5A5A9ACA8
A8AFACAEADADB2B6BBBBBBB9BEBFBFC2C3C6C7C8C9CACBCCCFD0CFD1D0D4D3D5D4D4D5D6
D5D7D8DAD8D9DBDBDAD5A55E4951545846575F53495250514E4C4F48514A494C52525653
5352524F5855585D5C625F666364646F6E7B7A86898C91949E9EA09C989390919195968F
8B8F94A6BDCAD2D9DADCDDD7D4CEC4B9A79A8A81776B5F5C575652494B474C5359626360
5E5A534848455059616763686D665D5D5F5C615F5D5D5C575F5F6563696565605C645D57
4B4B453C3732363C
232329211E1F23212E33334D6B8A9BA9AAAEB1ADB0ACA69E8B816F50393A3C45526F7D85
91999DA2A7ABAEAEB0B2AEB0B1B2B0B0B0B5B4B1B1AAA6A59A9A9088807E6B66574E525C
64442B262D2A2B30423A2E2C2D272B322D2B2F2D33343F474935302D40463F3336383736
43403944513A3736352F2C2D282C25283631292B283E2F2D333453462B49757C6F6A5C64
8784889C75433A313548634B2B314634373F3C2C3C486A8D4D3D5A6872863F262D2A3139
333127262A36362D2A32312828322A2B2826292D2E30323E48494C4E565C657573767977
71767475747C767579715D49302C394B575B6672828380868386888A8687868C888D8F91
8F91918E8E90939591898A8A8E8F9292908D8B8E8C8E8C898A8C89888B8584878B88888B
8B8C8C898C948B919195949091939A9593969A9997A19A9E9D9B9D9FA0A2A3A3A8A8A9A9
A8A9ABACB0B1B3B4BABEBBB8BDBFC0C1C3C4C6CBC9CCCECCD0CFD0CFD2D3D3D8D3D5D3D7
D4D7D9D8D9DADBDADACE9057444E53534359614D474A47454544484C524F514F545A5F57
595C5D5E60606464696C6E6E6E6F737A837F878A9090969C9EA5A39E9A94938380808785
858498A2BDCAD1D5D8DDDEDBD7D1C9BDB1A091887B726A5F585C545351454E5155575B61
5E5E545044444E55576461697366605F5D5A605C5F6160595B60606165696A636061615F
4F494B3D36383539
242426252323222529303C55697E98ABAEAEAFAEACACA7978F826A4B3F3C3A44546C7B89
8D989FA3A7ACABABB0ADAEACB1B1B2B3B1B4B7B2AFABABA3A09992837F806F6D51455353
553A2B25262832343A4233342D2D2C2F2C2F2E2B2F343D3F444434323944424030333231
39423941563B353330302E2F2A2D272C372D2A2828393A3338283A39436862615F5D5779
8674918F5335302F3F584A29293941323A34302D3839528553445A6E667D532826302E33
32342C22262F3333332B31332C2A292E2F24262D3132323C4B43484950545B6A6F747271
77747372767E7D797A7A6E5532283148525A5D6E8082828583878586868B858A8B898D8E
8D8F8F91919091958B8D8C8B8B8F8F8F918E8C938F8F8E8A888485868B8A878788888A89
8D8F898C8C93938F929091909896969398969599999D9A9C9E9C9FA09FA1A6A6A6A7A9A8
A9ABAFABAFB0B6B5BCBEBCBDC0BEC0C1C2C5C9CACCCCCECED1CFD2D0D2D5D4D5D3D3D6D4
D4D8D9DAD8DADCDAD9C4845A49494D4F4A4A554C4243464B4D4B4F515B4F55595A65605F
60616B6A68666E6E7576747781777C808688868A9093999EA2A09D9B979290867D797E80
848793A1B6C7CDD3D7DBDBDAD7D3CFC7B9AC9A8C80786E68625B575252475150515B6562
655D59574840484B535C5F666867625D5F5F625D5D5E5B5F5B5E5D5D656E6A66625E5E57
5C4F4B453A393A39
2323241F212829232830475D6F84949DA7AEAFAEB0A8A29E8A7861423E42424A576C7F8B
949AA1A5ACABAFACADB0AEAFB1B2B1B3B3B2B3B3A9ABA6A3A0978E817C827761534E5F51
4B402D25282A292F333A3B41362F3136303A2B2D302C3B363C4641333845403A32353539
3A4C41494E3937322730282A3736312F2C282926283B4D45292C2F3E4B503F373C48647C
816A9E733435393F453B272A2D38404E453942322A40567E6E5C64685F80752F272A3330
343831292E282F322B2C2F363239292A2326252B342D343B434544464D4F5D676E727074
7378747B7A7A7D7D7E7B76624C312F354E585E62778787878A8885848886888E8B8B8B8C
8E908F8F8C909091908F8F918D8F8E8F8D8D8F8F8B8C8A8A87868B888C8B868889888A8D
8C8A8B90908F9291959192949493969795999B9799979B9A9F9F9E9FA1A2A5A4A7A7ABAA
A9A9ACACB0B1B6B7BBBEBEBCBFC1C1C0C2C5C7CBCECCCCD0D0D0D2D1D3D3D5D5D4D3D8D5
D8D7D8D7D8DBDADAD8B97E645152514C3B3D494D4543505150515A595D59556062666369
6E6F7376757175817F7F7C81817E8387898D8A9490979B9C9D9A9F98928E8E85817D8181
8388929BAFC1CBD3D4DADDDDDAD4D0C9C0B2A68F8379756D6566595B574D4B58515C5D60
635F5E574949474A4D5552636B6B69645E605F65635E5D5F5C565C5E686A6969615F5E5D
525B4E4D443C363B
25252721232124232B3546677386929BA3AAAFAFAAA9A297896F5A443D3D41505D6C8188
939BA2A3B0AEADACB1B0B0B1AEB1B1B2B1B5B4B1B0A9A2A49E948B807C868761484D6149
3E442C27282D2E2C33323335342D38302F302A312C303033323D483931454A3D34302E35
39475052483B2E2C2A312A292F3837312C2C292B2634505930273141433631383D4F797D
7B7D8A4932454C402C2720272F373C495B624731293D5C787F795C5B52887F3A23293333
3C3C3525352B31342E30332F322E2E2D29242727292C34393E3D4346464F555F69706F73
7773727579817E7F7B7B7971564436323D515C616E848A8784848885868684898B878D8C
8C89908F908D8F91918B948D93908E8B8D8B8E90898B898E8B868E898C8688868A89878B
8A8A8C8C958F91919691959E9395979B9B999B999B98999C9EA2A4A1A0A4A3A5A6A7A8AA
ACA9ACAAB5B5B6B5BCBDBBBEBFBEC4C4C4C4C8CBC9CCCECFD1D2D3D2D2D3D7D7D6D5D9D5
D7D8D7D8D6D9DCD9D3AE80755852504E454F4E624C4C52575556615F626366676B6D7071
737B77797A7D7F868484858987868A878B8C9091929791939B989A9A91918C8A89848685
868B8D97A5B8C6CFD3D9DADDDBD5D0CCC5BCAD978A7E75706C67665B564D4F4D4E56595F
6665625A534D47454B534F5B616E666561645F5B62645E5C5D595F5B61686669635A5E5E
5456514C403D4135
272727211E1F23292A334F697D8B93989EA3A8A7A8A59A8E84705A473B40414D5E6E808B
91A0A2AAADABB0B1B1B1AFAFB1B1B2B1B4B2B3B0ABA8A6A09C988D808494926443526041
424B33362C3128302D2E3134313C332E312E2B2C2A2E372E2B3B4B3E2C40473C36333E3A
394460554B3B332A28312B2F31332F31332E2B26272B525A372C3736362F2F3646647C79
7486693843553C303430232E2F36457891753B332F3E666C70684B4D559A7B4B29273130
35443C2F25282631352F31332E2C27302C282D2B2D2C32363A3B3745474C535A636A6F71
747475747B7A7D7F7B7A7976694738343952595F697E8285858488888A84888C89898F89
888E8B8E918E8E918E91918C8E8D8D8C8E8F8D8F8D8E908C87898A88878C8987888E8A88
8C928E8F918F9094969797959096959A9A969C9C99969B9E9FA4A2A3A4A2A9A5A5AAACA9
AAADAEACB3B8BABBBDBBBDC2C0C1C1C7C4C7CACBCBCAC8D0CFD1D5D4D2D1D5D4D3D4D5D4
D6D7D3D8D7D8DAD8C99A8580675A5C4D4B4F55675351585D5E5E64636E6F70767578787E
7F7E8687828588888989868E8E8D8E8C8E908B8C8D8D8E93989C9C9B9897938B908C8886
878B88929BB3C4CED3D7DADCDCD7D5CEC7C0AF9A8E807871716868645F5853584F55565E
6165675B574E4D42464A555B636C6D686665615D6061635A54575A5F5F656B68675F5E5B
595A564B47423E34
2727262A2720222826304E69818F979BA1A3A4A29EA1968D86756149423D3D4C566E7C8C
9398A0A3A9AEB0B2AEB1B1B0B0B1B0AEB2B2B1AEAEA9A4A39B938B7D889D925D3B4B5D40
3441362E2A2929282D2E2F322C313337302C2A2E2C373E342B323D4B3539434139373634
373F4C5043392E2D343931354144372C2B292726292B476850313436312C2B36486B7B78
776F43365F3D2B3D3A332929243E5D9B965E332F35425759465C4257809F805B26213133
3139362F27252A393F383333342A2B372F2C2C252E282F3C2F2B313C46495155636B6E6F
6E7676787876817A797F7F796C504234334D5C5B69757D8483838B89898687918A89888B
898E8A888E8E908E8D9091938E90908C8D8D8C908C8B8C8C8988888A878D8A878B918C8B
8F8E93908D918E9295979395919896949798979B97999C9D9C9FA09FA2A4A3A7A9A8ACAD
ABAEB5B0B3B6B8B8BDBCBEC0C2C4C4C4C8C9CACBCBCCCBCFD0CFD1D3D3D3D5D3D5D4D7D6
D7D4D5D4D7D9D9D5BE8C8A88726A69564E5360685A5B5C63656A676E6D77787B7E818182
82858C8D898C8B948C8C8C898B878E8E8C8B8D8C8A8B8C949697929997909591908C8B8C
8885899292ABC1CBD0D9DBDDDDD6D6D2CBC2B4A595827571716E6E6762615F5B575D5A5D
6063636262514E4D524D54595965676668656561635E615B5854555F5B5F626266635F5B
60635C4F4D46363D
252529232723262B252E4F677F92989D9FAAA2A4A2A0978C86765B463A3B3D4D5D707F89
939AA2A6A9B0AFB0AFB0B1AEAEB1AFB0B1B3B1B0AFA7AAA49E9487828CA8926238476045
3D3A322929312A322B383232332E303530302F31292C3C2E2A2E343B3D323D4A3E41383C
32423D4F3A3D2E383C323439363F3A3E2E272C23242A3B5B6741372F28292D364C577579
6F5A34524D252E413330292837507398905B3C2C373B534F34597178ABAAA97A3521272D
30303B2F2B27263246373437322C313232302A28282C30352F34333A404E4A4F5A686F71
737475757A7E83827D7B7B796F5C42313245565F606D7D82818288858486878B8E8A8886
8B8E8C8C8B8D909093918E8D8E8D8C8E8C8F8F8F8F8B8D898C888489868E8B8E878C8D8E
8D8C8A8F8B9290919396959496979795969597979A999D9D9D9E9F9EA4A4A7A7A8A8ADAB
AFB1B2B4B6B6BAB7BDBFC0C0C1C8C5C5C5CACACACCCDCCCFD2D1D3D2D2D3D5D1D4D7D7D6
D7D5D5D4D6D8D9D1AD7F8A9087766F5C56585F6F5E676A6E6B717577757B7F828480858C
888E8B8D9194919590918E8C908E908A8A8B8B8786908F919293949A95958F918F8D9089
82858B9895A4BCCACED7DEDCDDD8D5D4CEC5B8A89A897C757471716C6962655E5B5B545D
5E6669626058504A4D4A4F545B5D6162696B6764696667615F5B575F5E5A626165615F5C
5C5F58585049443B
2828252221212D292B35465B7290989CA2A7A2A2A59F998F80706443323B3F4E5870828D
949CA3A6AEADB2B0AEAFADAFB0B2AFB5B1B2B4B0ABADA4A29B93868B95AE916B3A4E5D61
3339382B2A312B3132383D373C34343339322C332C3035302C31313A4337374F49453736
31303C434237373F37453F3D3338434641342F2724303E556F57352C2C272B3734476A6B
6241434F2A22312F2C363844627F95836E52392C30313F4548847C9DB3ABB4A36A292C33
32343B3D2E302B34403639413435303337302D2E2B342E302A312C38404B50505564706D
6D7075737B7A7F7C7A7B7C7B796952372F435563586B747E8283888A8489868F8B898A8B
8C8C8E8E8C8B8F959791918D898D8A898D8E8C8C908B888B8788868B898B8D8B8A878B8D
8E8D8C908F90939395979596949596979A999B999E9D9E9A9E9E9EA09FA0A4A6A4ADADAE
ADAEB2B2B6B6BAB5BCBDC1C1C0C5C4C3C7C9C9CACBCBCFD0D2D2D3D1D2D4D3D4D4D6D5D5
D6D8D7D4D6D8D8CA977A8F958B7B766162676B70686F707574777E817E8286868A8D8F90
9090928F9195909090938C9091888D8A878E8F86888E909491958F97929492918E8B8D8A
8585859090A2B8C7CED6DCDDDDDAD7D3D0C9BEB0A38E8278726E716D6C6A6A655C60535E
5B5D66646660565458514C4F535A5C6468696A62675F605D5F5852585D57585D60615F5C
595E625B5B54473F
272729262828202732364A65748D9A9BA6A9ACA6A2A49A8F82775D47393B3F4B5D71828C
9B9AA9A7ACAEB4B1B1ADAFAFB1B0AFB4B2B3B1B2ADA8A59F9A9287909FAB8B6841485D5C
2F3D32322A2A312A304450504F44363032312F3130323330302C3239454238434E413B37
333C3E3A443D44453E3A3B302C2F3F493A4839282A2A344C6E6838292B2E333930435E68
5F3D432A2A313F3A38505F6C747E926A52453C2C3933495774837FAD9B9397B09439242D
32313B39302D292C3B3E373034342E33322E3A2B2F2F332F2E312F383D4348505E616A6D
71737676797B827E7B7D7A7B7C6F564436374E5F5F62727B808482868588898A88888B8D
8E92908E8B8F9092938D908D8C8C8D8B8B8F8C8B8A89868888888A86858A8B88878A8F8F
938F8F8F918F91939494979193979898989B9B979B9A9B9D9A9B9FA09EA1A3A7A4ADB1AF
AFAFB6B5B8B8B6BCBFBFC1C3C3C5C7C5C5C9C9CACBCFCFD0D2D1D4D3D4D5D3D3D4D8D5D2
D4D7D7D5D7D7D4BF7E7A9192928381696A6D73797178787B7C7F83847E86888F90929091
919395908E90928E8B8E918F8D8E898A8D8F8C838A8B888C90918E9592939591908A8989
8381838D92A3B3C5CDD1DADDDCDAD9D5D0CBC1B7A59186767473726E6B675E6266615D59
585A606660605F554F544B4A525858676966676C65645F615E5B5957545E565D5C605E5F
5D6163665A544B45
2A2A2620241F1E2428324F697C8F9A9EA4A8ABACA6A59A8D86725E413A3A44495C71868C
979DA5A8ADAEB1B3AFB0AFAFB0B1ADB2B3B0B3B1ABA8A19D998E8F95A3A486623F3D6057
3935322728272A2A2B3F4E4E5A5C4F3E40302E2E302A2C29292B2B32424935384A3D3133
2F36363B45404346483B33292B2B473F31373D322E292D5360613D31303537373845667B
593623252B486370556E88736F7C8357544B3B313F335E7A82739D9F7C7C73A8AA592625
362D313A33292E27323D37333031303133372F322D29333530272F323A3F4A50595D6269
6C75747A79797D7E7B7D7C7E7B726250382C44545F6372767B828685888A8888898B8D91
8D8D888E8E909194928B8D8D8D898D8D8B8A8A898A8A84898A8687838689878684868A8E
908B8C8E8F92949091929A91929898979A979C989B9EA19D9FA1A3A4A2A3A5A9A7ADACAD
AFAFB5B9B8B9B9BEBEC0C0C1C3C5C6CAC8C9C9CACCCCCFCFCFD1D2D3D4D6D4D6D4D4D3D5
D4D7D7D7D6D6CDAB6D7789918F8E88786F76787C81808282848C85898C8C8D909490948E
92958E948E8D93919093908D918A8D8C868D88858D89878A8C8C8B8E948E8C8F8B8D8C87
82878D90949EAFC2CBD3D9D9DDDAD8D6D1CCC6B9AA9B877C76706F6E6B6E65615E61595A
5A645D646062645956524E494F535561676C6C6F6B66625C5E5A585B59585A5C5E626261
5F5B62685B555148
2C2C2C2F282523282C38516885909CA1A7ACABAAA3A3978D846C58413635434F5D75848D
919CA8A9AEB2AFB0ADB3B2AFB1B0AFB2B2B2B4B2AAAAA59F9E8D8D99A59F855F41396555
342C37242525292D23283B3640555E5D4F382D32272A2E2B2E282B363E42413D3D3E3433
2E3931343B453E3A3C382C332E375E4327343A3C352A344D4D524936393A3C3C3A506F68
38261D254D8BA6A1746CA1826A82725B6455473B4244698171799E7B77804D86A48A2622
2C2E353B3A34312F353F313E3F36332E393530303433382C2E2C2D3234404B5556555665
6D737674797A807D7E807A7F7B766D573A3142546161676D7A8385828B88898C898B8F8D
8A89878B8C8E93948F898C8A8C8A86898D8789898A8A8788898D888A8987868787878B8C
8E8B8D908F8D929792949B96959596999A949E9C9E9E9F9CA19EA1A4A6A5A9A6AAAEACAE
ADB0B0B5B9BBBABCBEC3BFC0C5C4C5C7C9C7C9CECDCDCFCFD1D1D4D2D2D5D3D4D6D4D4D5
D7D8D6D6D6D2C98966788892918C8A80727A82838686868788918E8C8E92919395959191
90948F8F8E8F8F908D8E8D8F8B86868A878985838886848C8C8B8E8C8D878A8D8D8B8A8E
8A92999D9EA2B1C3CCD1D4D6DDDAD5D4D1CDCAC2B09F8C8078717173706B6665675F5E5A
545E606268645E5D5E554D4B4B54535D63666F6E6B6968626062595D58565B585B655D64
5F5F5E615F5B514B
2B2B2826282325232F39566D829199A3AAACA8AEA9A298887E6553343435424E5B72868C
969EA7A9AEB1B2B5AFB1B2B3ADB0B2B1B1B5B7AAABA7A59F9D8D8B9CA39884693933574F
36323D2A2A262E262C2C2F31323A4851635A48393331322D2A2D2B363943453F3D4D3B2F
35302D323D3D353A38372F2D374467352A2A3237362F3A41353A58493E453B464B69724E
272625478593949C7F6B8E77598A7E736C625A3C4342727F6C8D87626C723A5E82762B21
2A3B3C4038353B302E443C3D4538362E30343630373A342D242F2D313841484F54515960
6F6C6D74767A7C7B7D7E7C7F7C77765A45353E4F5960646F788182808489848B8C8C8D88
908E8B8E8B938E908B8D898B8A8A8C8B888C8B8A898B87868A8A8C8483898A878B8A8B8C
8E8E90909290929395989A97999B989C9B9A9C9D9C9D9F9E9FA6A0A2A4A1A7A9ACA9ABAB
AEB4B1B8BBBBBABBC1C1BFC1C3C9C6C9C6CACCCBCCCFD0CDCDCFD3D2D3D4D5D6D5D4D4D5
D7D7D7D7D5D4C26B5C79848D918C8F867B84898A8E90908E8C91918F9091968F94969093
918F8E8E918C8C918E8D8E8E8D8788898687837E85828786878688898B908B8A8C8E8A90
98A0A5A9ACA9B2C1C9D0D5D6DFD8D8D5D3CEC7C0B4A28D817B6F70696C6B68686D616361
585B5D5F646960615F5D5A504E46525862666E706A68636665635A5A5658615A5E605E65
595C6163675F5955
2525222026262226353E5A75839799A5ABAEA9A7A49F9A8C7C6C462E2E3B3E495D798390
989EA1A8AEB1B2B2B0B1AEAFB2B3B3AFB0B2B5ABABA7A19D998D92A09E8F887937314746
30283D332A2A2E252527293935323437546364563B38362F2C2D2D2C343E443C3D3E3B40
36313031402F303C333628332F435629232C2E2D343D3E35262C5663464136444D666241
27253C7D7E69677F825B73877D88856E585045374055737789946F5359602E39473C2426
2533423D3A36352F293B3E36493A3536313431313342333027362C2F343C404A5057585C
6D686C71747F787E7D7E81808080765F4A3734495462676C737D8580858987878F8E908B
898D8D8B8C89908F898E8F8B8D8D8C8B8C8B8A8589889086878C888B8B898887898A8D8A
8B90908E948E9395979293949498969F99999B9C9BA09FA1A1AAA6A4A5A4A3A9ABAAADAC
B0B6B3B9BABCBCBDC1C3C1C1C8C8C9C8C7CACBCDCDCFCFD1CED2D2D1D2D3D5D5D3D4D4D6
D4D4D7DAD5D1AE49537B838F8F90908B838C95929193928B91919190919491908C919496
928E908C908B8C8F8D8F8D8A898885878B83868781818589868285888A8B8888898C8F9A
A5ADB4B5B6B3BBC1C8D0D4D7DCDAD8D6D2CECBC5B8A29383796F736C6A706F6969656462
57625D5C60656668615E5A534E464E535B63666E6E69656367675F585B575B5E5C5F5B64
635C626062616054
21212324221F222C32425F74889598A2A8ABABAAA2A2988A7A6149352F343C4A5B758192
979BA5ABA9AFB3B1B1B2B1B3B1AFB1AFB4B1B5AEB1ABA6A0988A97A4A0877A743B37383D
2C30393231272C2726272D343C2E282C3B46525548423A302F2D34292E3144403B363641
413F36373236333331362F393C4B3624282B2C272C3F45332C2F4F6F58333B3D616D5134
31315D7D6A42475658405C938E7D726961423D416372818794835236596C363B34282226
2843453641302D2B243B493A443D33373433343A374536332F352A34313439454E4F565E
6A6C6771777D747B80807F807E7E7C68523B2F3E505D6465707983838583828688898A8B
8B8E8B8C8B8B8A8B8E8B8F8D908F8A8C8B8D8B86888A8B87838888888F8C8A87888A8E87
8C8C8B8E959792919594929695959B9C9C9D9E9E9D9DA1A7A1A5A8A4A7A9A7A6A8ACADB2
B6B6B5B9BABEC0C2C3C3C1C4C7C5CAC7C8C9CBCCCDCCCCD0CED0D5D0D3D4D6D6D6D4D6D6
D8D8D7D6D5CE93304E797A8D928B8D948C93959296918F908E8B8F908E8F8F8C8A928F92
9090908C8D908E8E8C8B8C8D8B8E8A888A88848482818384868186878788888689929DA8
B9BEBDBDC0C0C0C4C9CDD3D7DBDAD9D6D2CFCDC7BDA798857D7473716F70726D6B656963
5C605E595A6065666660595046424C505C646868686967656661655C5B575C5D5E5E585E
605C645B5F645F5B
262625292221262732436077889C999EA9ABABA9A59F9B89795E442E2D34414D60778292
979DA7AAADADB1B1AFB1B0B2B1B2B1B3B4B1B7B0B1A9A8A29A8A92A1A37F7169363B373B
342734352B2B2C2E2928293439322E2B332D3A4545443D4231283036303440473D3D383F
3F43402D2B293136313133334A5B3529272A2B2D333E422E23293E5E5B3E36556C543C3D
3E556866534F654E4155658A83676E6A5D4B5A727D89958C8C582E3658732B2C362F2A27
302E3C443C33353F2934453E3B3F36382B303B3E3642353532282C2D2D33394D4F535655
63686971787C7E7A7D838085807C786D53493538565B676E6C7D858481868285888A8B86
858C8A8B8A8A8E8F8F8E938E918B8F918F8C878985878A88858789888C878E8A8A898F8C
8E8D8F908F93909696949798999B9A9C9B999BA1A3A2A3A3A4A7A5A4AAA8A7A5ABACB1B1
B6B7B7B8B9BCC1C2C1C3C2C7C7C6CAC9CACACBCECCCCCCD1D0D0D3D1D1D7D4D6D8D6D5D7
D8D7D8D8D5C06723457B7D898E8D9194879B929694929295928D908D8F908E8D8F928D8F
8D8E8C90898F8C8E8E8F8B8A8D8B8882888680817F848780848785838A8488888E9EACBA
C0C6C8C6C8C5C8C6C9D0D1D7DADBDAD9D5D1CDC9BAAC99897F78727472716F7370666D6B
6261615C596365646A655D564D494B4E555E6367696C686C666364635E5A5562635B5E61
5F635D585D656263
2727222527282A2C2F4D69788A979BA2A9ADACAAA59F9989776135292D32464663778590
999DA6AAAEB2B3B0B3B4B3B2B3B1B2B2B4AFB1B5B1A9A6A09B948998A4776D603439372B
333137462B28302E2C2C2D293930292C312C323D494B433D302A34323232404340433D49
383F41302A2A2C2C2B2B37394A542C2729282E2E293B4C2D292639515F4D3F5D5D34262D
566C56474E6172616B7474787B646A69607275757A938F8D6B312B316A76292A303A2927
272F3B443E3D3F3B2E344C3D2E3C3F3D3C314E544643372D322F2A2A2C2D3A4348505658
5E636B74777C807F7D7E848083827F74584D3733525669676879808185838483858C888D
89928A8B89898C8C8E8C8E8A93918F8C898984908587878B85888C88898B8B8A8B8A8B8D
8D8F8C93938D92918F9A9991989B969C9E9A9D9D9D9FA2A3A4A5A7A4A6A6A8ABAEACAFB0
B3B6B8B7B9BEC0C1BEC3C3C4C8C7C7C8C8C9CDD1CFCDCFCFD0D1D2D3D2D4D6D7D6D6D5D4
D7DBD9D9D4B345203E7F7A88939091979195999295908F90938D8F928D928B9497938C8C
918D8E8E8C8B89908D8D8A8986858985878284807C808284868782808581828B96AAB5BF
CACCCDCACCCBC9C7C9CDD0D6DBDCDBD6D5D3CCC6BFB1A18D7B7576767871706D6C687068
67615A625F5D6261696A5F5A5D544C5258576663666B6A6A636363695F5D5D60655F5D60
5A595D595C5D6060
2121201E2221292C3346667E8F97A2A9AAAEB0AAA59F9886795D452526333C4768788390
989EA8ADAFB1B2B2B0B3B1AFB4B4B2B2B3B6B2B3AEA6A59F9C8E86949D7C6D593737382D
2C343C422C28302929282F293837322E30302D34393F3E3F35302D313138435043473A3A
32333C3C332C2F372E3143464B422C312B252827263648352B272D3F576A48533924223E
6C5D414B505B61677A78797873617682766971838F8D857B4329313D7060272929463625
2E292D42474941312C314C4432343F3B3E477D694341392F2F2E332D31323943474B5358
5A5B6B71797B7A80807E808280828079625336305057656666768186838584848288858B
898B858A8A928E8A878D8A8A9090908B8B8A85848489858988868C8A888F8B8A8D8C888C
8E8E8F8D928E939595959794959B9D9D99A09B9F9FA1A4A2A3A7A9A6A4AAB0ACABAAAEB1
B6B6B9BCBCC1C0BFBFC7C6C5C7C7C9C8CBCBD0D2CECFCFD0D0D1D3D5D7D2D6D4D6D6D6D4
D8DBDAD8CE9C29213C817883928F8B978F9596949692948F8E8B948F8D899092948E8A89
8C8B8E8C8E8A898F8E898F8A898D898586848681837D8181858186817C838B8D9EAEBDC8
CCCFD2D1CFCDCBC8C8CED0D3D8DBDADAD5D5CFC6C1B6A09081797A77737370716F6C6B69
67625C5B5A5E626467646768615755555B575A5D63646B646B67686864645F5B61665B5C
5F585A615B5E6163
1F1F2121252023302F4E637E909AA0A5AEADAEACAAA1998A71574426272B47475F758890
989FA5ADADADB3B2AFB3B3B0B3B1B3B4B3B4B2B2AFA7A6A49D928B909B7B6B5534352F29
2E34353A332B2D2E2E2D2E2D322E2F332C2C38313039413D3530312B3A41474C48433A3B
342D35373C31302B303C374445362A2E272D282324313C3F282B2D365C74634425242B57
563D4149535B6161797C60668281837965597B8E7E788B5A2B262B3579502629264A4626
211E243D3F463B35373347434C323C4967727D60443B383A3630392D2C2F2D3F4B444C59
5562656D777B777A817D7F828282847E67543F324C54616565727F848585848487858289
8B898B8E8A8D8B89888C8B8A908A8E8C90898989848A8589868889868B89898A8C8E8B8D
8D8E8B939392909593929796959E9E9F9E9F9D9E9E9FA3A0A1A6A7A5AAAAADACADAFB0B0
B6B6B9BBBEC2C0C1BFC2C4C4C5C5C9CBCDCDD1CED1CFCFD2D2D3D1D3D5D6D5D4D5D7D6D6
D8D8DAD8CB822120347D817F918D89968A97949294929D938E8E8F8F8E9690938E8D8E8B
888E8A8C89888B8C8E878C88898A888A8683818383817C7D807E827F7F80858CA6B3C1CB
D0D3D6D2CFCECAC8C8CDD1D2D8DBDBD9D6D5CFCBC4BBA997857C7A7777737373736E6B69
6961605D575E656568636B6862605755595355595D6065686C6D6A696366625B65615F61
5A58555961615F63
23231F231D22232C3A4E6A7D909DA0A6AEADAAAEADA3988A72573A242A2A384863798591
9CA1A8ACAFB0AFB4B1B0B2B3B3B1AFB2B5B1B2B0ADA8ABA09D988F959779645A39373F2C
30383133332A39392E302E3032342E292B36302F2A2D383C4335302E27384A4949473F3F
2F3331363F4334322F2C324344342A2A282F2A2E233638453C382E315973683421233E53
2D2B3541455B5F7485724C648D8F715D587992835D7F7638262C2F3C7B42232D2A33572F
2120252F44424135353A4F65583E49658369554E3D35343638383D332935353347444B55
55576369757C7C7A807C7F8381807E7E6450482C3B4D54675E6C78838485818386858488
88888A8C8C8C8F8C8C8E8C8A8A8A8A8A8B8E888882848587868889888B878B8D8B8C908D
8E908D919291919698969B9496989C9F9F9C9E9D9D9DA0A2A7A2A4A7AAA7AEAEB0AEB1B2
B5B3B9BABDC2C1C4C0C3C6C5C6C8CBCACDCECFCFCECDCFD2D2D3D4D3D5D6D6D6D6D7D9D8
D8D8D8D7BE5F1B1E357584858D8D89928B9297939394A08E908E93918F91908E8C8C9189
8A8A8D8C8989898B8F898C898E878B8586878A8780807C807D82817D81868190A7BEC5CB
D1D5D9D7D1CECBC8C9CDD1D3D8DADCDBD6D4D1CEC7BCAD9A8E817878757077786A6B6766
66635C5B5F6662656A666F666464625D5A555556585F676569696868696B5F5B5C5D625C
585C565E5D57605B
1F1F1F1D1E25283044536D8496A2A0A9B0AFB1A7A7A19888775738282B2E3B4C637A8691
9CA3A6AEAEB4B0AFB4B0B0B2B2B2B2B0B4B4B1B0B2A5A69F9A8F8C9B9A7D6B623C3E452C
2D37352C282D3B2C2E2D342E3433312C2D293030323433353E36372E31344E58544F4841
3540372941413434272F2E443E2D3738312D2B23262837413B312839556F6A3925354937
202738354153627D887554718C926E5C6B9288646274502A22252C477C32242D2E2A4D4F
2821222D4C4A5949444879A8A77E6D6D68463C44443738323F3737342A3737353B49484C
56595E6B747E7D7C7A8081827E82817F75534735395257676967748185837E8485848887
878387898C8A898A8E8B8B8B8D8A87878A8E8A8A86868686878488878A86848B8E8D8F8F
91908E919495919694999B959A97999F9D9E9D9C9E9FA1A2A4A7A8ACA8A7ABACB4B1B5B2
B5B6BABABCC2BFC3C2C4C5C6C5C9CACCCDCCCECDD0D0D2D0D2D3D3D3D3D6D6D7D6D6D9D7
DADADBD4B2481D212F7985848E8F8D988D909293929B998D918E8F8D8E908D918F8D898B
8C8A8A8D888E8E8A8E898B8B8A878B85868C7F847C808182847C83807E808390ABBEC9CF
D3D5D9D6D1CCCDC9CBCECFD3D8DFDBD9D9D6D3CEC8C1B49F8E857A74717074757269686A
686B5B5F5F65696B6B6A70686A65645E5B585855545A616667696A6C68675B575D62605F
555855605E5C5A5D
1F1F1E1C1D23252F4C597184999FA8A9ADAEAEA9A49C938776563025262A3B4B63788494
9BA1A9ABB2B3B1B3B0B4AFAFB2AFB0AEB4B3B1B0A9A79FA098938D919A87816B36464F2C
2A292A322D29392D2D2E2B2C3639372D2B313047303A2F31353A35352B345D57564F4640
37352C2E3E424C38333037433C2B2D363C2B39332E2C324D43262E3857697341243C3F26
22222A30455C6B7D8F937F68898D856A7C8E6F4D6B5D281F23242D546A2C28272A293465
48343B49717D7F837B7E97A39A85827453412F3C4633383833313C362F31363236414645
525D5B6B71777F807C7B7C817D847F7A765C50362E4A5B5F6265717E7F83848484888785
89818487888B88898C8F8D8B8C8D8C8C8A8C8B85848B8688838689888E8B888B8E8F908F
8C8D8C909497969695979B9A99989B9A9F9D9E9E9CA0A1A8A9A7A9AAAAA9ACA8B2AFB5B7
BAB8BAB9BEBFBFC3C5C6C5C6C7C6CACCCDCCCCCED1CFD0D0D3D3D3D6D5D7D5D6D6D8D9DA
DBDAD7D095281E21286D82878E8D8B958D91938F919F9291978F8E908F8D8F90908F8A8A
908B8A888B8C8D888B8A8C8B898681858788837D827C7E7B7C7B7D7C7C7D808FA7BFCAD0
D3D7D8D7D2CECBCBCBCED1D1D6DADCD9D7D8D4D1CCC6BAA8968A7E7676747B746D676A67
636460655D606767686A6F6E6E6A6062625D5C5857585D60656A6A6868655C60615C635D
5555565B5C5E5E54
1E1E1F1F25222434405C6D8994A0A9A8ACADABA6A39B9185755D3424222C384B60728493
9BA2A8ADB0B2B2B4AEAEACAEABACABABAFB1B0AEA9A7A39F9A948A868C8893713C474D2D
2F2F2B2B2E332B2A2C2E2B2B2D3733382B2D374D47352A2E30313232333B60555959574E
3B28332E30373C332A2E343C3A2735332E302F2F352E2E524B28363C465D65472F413722
23272A34404B74818F97897084768F867A81615B734725222627326059323A3F5249467B
8C7089868A8E857E73676A74684D5C6A645F3B3E3D392D2C2E353A36322F30312F3E484B
4D5358656E767B80797C7C8280817C7A795F4C40314655636D67727B7B817D8185848688
8785808C868C8C90908C8C8F898B8F8B8B898985828885868689898C8B898D8790908D8D
8D8F8E929497999994989A9D9C9D9D969D9FA1A2A0A1A2A5A5A8AAA8A8A5AAB0B5B1B8B7
B6B9BEBDBFBFC3BFC4C3C6C8C8CACBCACECECDCECED0D2D0D4D4D5D3D5D9D6D8D8D9DBD9
DADCD7C87A22201E255F83818E898C978D909493989F92928F8E8D908D8F8E918F938C8E
8A8B8C888C8D8A8F8F8B8A908E8B8A858A8481827C81787D7C7B80807F888192A3BBCBD0
D3D6D6D5D1CECDCCCACDCFD1D6D8DAD8DAD7D5D5D0C9BDAC9C8D827C77727779736A6A6B
66616663625B6364686C706C6D6E6D615A5D595C5B5A5F625E6D6C6868696367625E5D65
605454575D595B58
20201E1C1E22272D48637494959BA3A8ADACACA8A29B8F837857322C272C364364768795
9AA0A6ADB0B2B4B2AEADADADADABA9A7ACAEB1ADAAA8A19B99978B83867F937A433F3B2F
3733292F2D322D302B2D2D30323F322F2E323F57694A2D2A2B322F332F3E5D4C4D5D5B4B
2E263831342D3C4135303546372C2D2631332C33333340523825363E3B545C543D43312B
2C27343B415978808E8F8C797C70898E7886636D68463E3238506974596A818FA3978A95
929F88726B76746753403946482E3742485C5B4A393B3332353838372F31332F2F364849
494A515C69727E7F7B7A787E7D7D8178785F48392B3B546062656C7B7B7D7C7E81848484
84848589888D89908F8F8F8B8C898D898990868482878586878C89898A8B8D8B90909090
8C8D8F9393949796969B9D979C9E9D9CA1A09EA3A19FA4A4A4A6A9AAA7A7ABB0B5B3B8B9
B8B8BEBEBCC0C2C0C5C7C9C7CACBCECBCECDCFCFCED0D2D3D9D3D5D5D6D7D6D7D8D9DADB
DBDBD7B6571B1B1F245D7F83898B8C958C9197939E99928E8E8E918D8E90868D8E8B908C
8C8B88888C8D8C89888A8C8B8988878A8689848380807E7E7E7C7C7D7F80838C9DB6C9CE
D4D7D8D7D3D1CECBCACDD0D3D4D9DAD9DDD6D6D5CEC9C4B5A89489807A77757B71686768
5F5F5F636363686C69666E6E736B6E6661635C5F5B5B5C5C5E676C686762696C64626369
625251555C585151
2121221E2322282F42678189969CA7A9ACADABA7A09B917D745A3729242F3E4F63798695
99A3AAAAB0B2B0AFAAACAAACABABA7A9AAA9ACABA9A1A19B98998C8C837A7F77473B2D2F
39312E2E312C30302B2D2B2E343634312D2D37535F5E3E36322F282C3B39645B4F5B5B55
382C382C2629344D5232404334262933302A252E30333E49312D34272E505F5941352F2F
2F3836374261787B8B8E807F817286957D7B6B6E565266676F8D998F7992A9B1B6A58D79
7288723F353D524E39323134423034403C49534E363D383230443C39332F322A3033424B
434D51596772787B7F8077857C797E7B7C6E3F3A2F38545D626C6E797D7D808484858386
8383858D89908B8C919190898F8687898A8C86868188878688868A898A8A8D8D8C8D908C
8E8E8F939094939494999B9897A09D9FA19F9E9E9F9FA3A2A4A5AAA9ABACA9ABAEB5B7B9
BBBABFC1BFC1C2C0C5C6C7CAC9CACDCDCCCECFD1D0D1D2D3D2D4D4D5D7DAD8D5D8D9D9DD
DEDBD2A5401A1C1F224E82888F8D8B949091979A9C92918D8C8D928D8E8F8D8F8F8F898E
93888E878B8B8D8B8C8A8C8C8A8584858986807D8083837D7A7C7C7C7B7C85889BB5C9CE
D4D7D7D8D3D0CECCCACDCED2D6D9DADBD8D8D6D6D2CDC9BFAE9D8F8078787679736A6967
625B62635D62676163656E72726E707167605C5C59595E6063676A6765676B6C605C5D5F
6359595B56565051
1E1E22201E2528324A6F7D8A969DA5ABAEAAABA6A2968F7D6C563427272B3E4E637E8894
99A3A7ADB0B4B0B0AEB0B2AEADADADACACB1B1ADA5A29E9D989B928C7F7574654B3C3F37
3C372E282E2D2D3032322D2B2E322A2A3C2C2C424A4C534A3C303229303A6F7A5159543E
302F302D2C242F46583C3A3B302629302A2C2A2829353947413628222A4F63573A362E2A
333D3D42676D7B7F88887C7D89818F9B806F5F594E617E817A88949A969397A598805C49
3C5A74382832414B38332F3C483831403D3F433B3743353A303B3D3E3230313236303D4B
474B4D57666F797D7E807C7F7B7A7B807B6C4839303052595E676A727C7F898084858585
8186858B8786898A8F908C8D8C8A91818988898987868A898B89898B8B8D8A8B888B8F8D
8F8F9394939891939A989F989B9E9B9E9FA1A1A2A2A6A7ABA6A9A9ABADAEB1B1B0B4B5BB
BBBCBFC1BFBDC2C3C5C6C6CAC8CDCDCECDCDCFCFD0D2D0D3D3D4D5D5D5D9D8D7DADBDCDA
E0DDCD86231E1D1D21478388898A8B95908D969C9F8F908C928C918F948E8F8A928A8E8C
8D8A8B8F8B8A8E8D88898A88868785858689848280847E7E817F7A7B7B7E878499B7C6D0
D5D6D9D5D3D1CECDCDCFD2D3D6D8DADBD9DAD8D6D3D2CDC2B6A499867E7875746C6E6766
6664616161606165656B6B7171706F6F6964605D5A5B5F5E5C64696768666669675C5D61
605A575B5452514C
1E1E22211C2228364F5D7D8E969EA5ABB1AEAAA7A0968E7E6F462C252428335064798A97
A0A1A8ABB2B2B1B2B2B0B2B2B0B6B3B2B2B2B4B1ACA9A2A29C98928879766B53433A3B44
48372C2B2B2B2B2A2F302E2B2B2E2E362D262D29383B3B4A594C2F272A345E8D5751533C
3531302C312F303F535044382F272935302F2B272B3436434C3C27232B53614A303A3437
4B58505D7279827B8179718586808F98906F513E5180857C86979EB0B8AA8A7857402924
27335A55322941483E34333D4E3D2B3D3A4140303A3F3C322C353E3B312F323432313543
45464F56646F787C7C807A7D7C7C7E7B766D4E3B2F2E545D58606A6E7983828380848588
828484888C8E8B898C8D918B888A87888E8789898C86888B8A8A898F878C8B8E908B8A8F
8F9092968F919295979D989A9F9D9D9B9FA1A2A1A1A6A5A8AAA9ABADAFB1B0B1B1B3B4B8
BBBBBEBEBFC0C3C2C4C7C5C5C9CCD0CFD0CCD0D1CFD0D3D4D4D8D4D5D6D5D6D8DADADBDC
DCDAC46A1B1C1E1E203D7D8783908794939291999890918F9490958F908D918D8E8D8A8E
908C8D8C898B8C8E8E8D8C8A8A8587848483838484817D7D80807B7E7B7A828193AFC3CD
D3D7D7D8D6D3D0CECDCED1D2D6D6DADBD9D9D9D8D5D3CCC7BCAF9C8E8779706F6A6A6A63
6A6662616462615F636D74717475726F696A6960615C5D605F616168686C646A68686269
5B5F5F555652544F
1D1D201F20222B344A6B798C999FA6B0AFB0ACA7A296907F6946272426293650667D8794
9CA3AAACAFB1B3B1B2B2AFB2B2B1B4B6B4B6B5B0B0A9A59F9C9992877C7C74443C393D45
47343231322B2C2B312D292B2B342F2D2730342F352F31457D79563E2E2E4D856249554A
302D292E2F33383D4B5148362E2638362B2624242C313A444635281C294F5F3B40383E5D
786E696F777A7669706871858A8688929075443F738B8A949C9C9FB8BFB19F5F39292324
20223461422A364C3D312F373D3E303C3840392C393B3C32312F3F3A3739323135363943
45414B4D5A71787B807F7C7F7B7B787A7366523C302C4F5C5B5D66707D7E7F80847F8682
84848688898B8B8D8B8B8E89898B8A8889878B888E8A89898D8D898B8E8F8E90918F8E93
908F9195929893939B9A9A9A9D9BA0A19F9DA4A2A3A5A4A5A5AAAEAEAEB4B0B3B4B2B5B6
BCBCBFC1C1BFC4C4C5C8C7C9CBCDD2CECFCED0D1D0D2D2D5D1D5D5D4D7D6D7DADADCDCDC
DCD5AF451A1C1E1F273E808C848C8C938F8F979A9691938D91929291938F9093928D8F8C
8A90898E888B8B8D8B8C8C878B888A818983838685807A7D7E7B7B7C78787A8094B1C4CE
D2D6D9DAD8D6D3CFD0CFCDD1D5D6D9D9D8D9D8D8D6D3D0CBC3B4A8978A7C716D696A6B66
66645F5D605F5F62616E727776756F696B67665D5F5A5B5C5F62666A6B6C6C676761645E
5E5D5C5C5A525250
1D1D20241F2D2B3C4B667C9199A5AAAFB1B1AFA89D988E7966482A202629384F677D8B93
979CAAABB3B0B0B6B2B3AFB3B3B4B3B4B1B3B5B5AEABA89F9B978E827D88744737323542
473C342F332C2A2B2F2D3D2E2A302B2A2E2F2A2825262C3461817A5D42383F7B6E4B3E33
312E2B2929323336465046372628333A2A272F28302F37453A3527202F544A35343C3C64
7C70746F6C6153556A5A5F8A898C888C9690827A8F8E8C85888E7F9FBCACA583402D262D
2829253B4E2F394F4C3630333E42383E3845322E333F3B3631373F3A333235313138333C
4C404A50586E7A7B7B7D7F7E7C79767676705E37312E505B5D6068727A7D7C7C81808585
8787898A8888898C8A868A8A8D8B8B888A898A8A8C89908B8D89888D8E8C8E90928F9192
928F9297959595979D999A9E9C9C9F9DA0A0A0A2A2A6A4A6A5A8ADAFACB2B3B5B7B5B6B8
BABBBDBFC3C2C6C5C6C7C9C8CBCACFD0D0CFCFD0D0D2D0D3D2D5D4D7D8D8D6D9DADCDDDB
DBD09B2F1C1E201D2435788F858A8B968E8D9E9D938F9090938F8F9291908E92918E8F91
868C8B8C8A8E8C8C8F8C888A8889888084848385827B837E7C787C7A777B7A808DACC1CD
D3D7D8DCD9D8D6D2CECFD0D0D6D6D8D9D9D9D7D5D4D3D1CDC7BBB19B8F7B706C6A686768
655E5E635B61626167686B73757672696A6660605A5D5C5C5E636869696A6B676A68685F
5C62645F56515A5D
22221F201F2726364B677B8C9AA4A8ACADADADA79F968B7C62432824282938536D7B8794
9EA2A7AAB1B4B2B5B2B0B0ADB5B7B1B5B5B5B5B1AEABA6A29C9689858194804431322E3B
443E4037392A24262B2D2B2C2D2F2C2C3130332A28252E293D587A7F71493E6E72433933
292E282A2F2E2B393C494B40272E3B37232725272E373E483B3C29233D55413847453442
67797F71573D404E6560628B8A88878B969CA199928A78607C8C5B63A0A99B9D754D515E
4D3B282C2F2833474A3C362E3F3D314E44403332323E3D353A363F3E322C31352E322E34
49403E4F5365727B79777F7B7D7A7C7B7C715C46332C435A5A606A6E7C777B7C7F818382
878388868889888B8C8B8A8A8D8A898686898887868C8C8D8B8C868E8E8E8B8B918D9090
958F9D949793969A9D9D9D9D9EA09D9DA0A3A19EA6A7A8A6AAAEB0AFABAEB3B1B7B6B8B8
B9BCBEBEC2C2C5C5C6C8C9C9C8C9D0D1CFCDD0D2D0D2D2D3D4D6D6D6D8D9DADADCDEDFDD
DAC574241E1F1D2220346B8D878B8C938A8F9E9B958E9593929291939090908E928C9091
8B8B8E8C888B8D8F8B8B89898484828084848485827E80807C7B7B777D7C787E87A5BECB
D1D5D9DCDBD9D5D3D1D1D1D3D5D4D6D8DAD8D9D9D6D6D2D0CBC3B6A39685756668665F63
5F5D595E565C605B626B6C706F736F736E6C635F5E60605A5E5D6165686A676967676B61
626562615E595753
1F1F232021232A364A657B8E98A4A7ADAEADA9A59E988B7B5F3E241E242A37506D838991
9DA2A5AFB3B7B4B4B3B2B4B2B3B5B3B4B6B5B6AFAEAAA5A09D938D8780997D3C31282E32
35383A443F3829292B39252C29332C2D2F2A312D2F2228252C38537E8F754E7377543F34
242C28272C292F363A454D3D272B3933212726282F2A374737382A26404A3E4235323446
6D87866E452E4246554D5D888C8D8D8B92969CA195774A548F81443C719CA79F9C8A95AD
AC7B30272D282D464D3E35303B3C333D443D3C34354246383231363733342E3337323F2F
423E3B4A535F6E787B747D7C7D8079797B745E46332F4B595E5F6D70787B7C8183808082
898A8C8C8C88858B8B8B8A888989898788868A898A8B878A898B898C8D8C8D8E908E9093
93929295959296979E9A9E9F9EA0A09CA3A4A6A0A1A6A4A8ACABB0B0ABADB4B3B6B6B9B8
BBBEBCBCBFC2C2C3C4C5C9CDCCCCD1D0CFCED3D0D0D2D5D6D4D7D7D7D7D8DADBDCDDDFDD
D8B84F21221E1F1D202D628F888B8D928B929E95918E9795919392918A908F9391929292
8F8C928E8B918A8E8D868B8E858481868C868385827F807B7B7E7B7A7775767A83A1BACA
D2D7DADBDBD9D9D4D2D1D1D3D5D5D8D9DAD9D9D9D9D6D5D2CEC7BDAB9B87796664606263
5D5B5C57525A64655D666C6D707575746F68665F645F5C5B595E62636A6A686868676865
686F616A6B64564F
1E1E1E201D222A3A4E70818F9AA1A6ABAFADAAA79B988E795D382321232934536A818C93
A0A2ABABAFB4B3B5B2B0B0B3B0B3B5B4B5B7B0AFABA9A69C9D928B84899B77432A252D31
373937384139342D2E322C27263230242F2F30302E2A2026212638638B906B7C86665232
28282B2C292B353E2F3246402E343731252A2D302B313A3A33332F294244413E46413864
7D867F643C3439393F4656889B8B8B8A8E9899A07D51357A8E843E567A9CB3AB9C828BB2
C8A84623232328464D3D3F313E463844413A39313A4344342E2F35323A31303430353E36
3038373B4E566A717A767D7F7C7B7D78787664542E2B3C5456626670757981858187867F
8A8B8987868E858B89868989878C8986868D878B848B848A8A8C8D8D918D8C9090908F8F
94939392989599999A9A979F9D9FA2A3A0A2A59FA6A6A5A5ACACB4B0AAB0B1B1B5B8BABC
B8BDBBBEC1C2C5C2C6CACCCECCCDCED1D0D2D0D3D2D8D2D5D4D7D5D8D7D7DBDDDDDEDEDC
D297341B1B1C201F1C2E61908B8D8F9A8B94A09793939796938E90948F948E9493958F90
8E8D898F8B8D8B88898F8A8C87888786868689837F83837D807F7F7D7C78797B7F97B8C9
CFD4D9DBDBD9D7D6D0CED1CFD2D5D7DADADBD9D9D8D7D6D4D1C7C0B6A4917E6D62616164
5B5C585A58575A5B5F6C686D6E6D73726F70686360635E595A585F62656D6A666A695F64
6B5F606C6A68605B
1F1F222423242C3A596A8595999EA4ACAEABACA8A19B8B7557372123282F37576B7E8796
9DA2A7AFB0B3B2B5B4B1B4B1B3B1B4B5B8B5B2B1ACA8A59F9A938C898F9F84482D29262C
38362936353C3A352D2D282C292C2F2D27282338312E27232823273E7297857A8A6E623E
242A2427282F3635372A454C34323B36272E32372E2D363F2D2B31314946384860424C6E
8879745C3A36393C363C4C81A18D8B89889A9A986834428C9B8A72786E79A8AD9771579A
C2A84425252B2B3F504A472F3F473C3E38343C333343402E3336303237363434333B3A32
3A353A3C4A505D6973757679797F84787777674F302D3459565B6870747B828581858485
898A8981878A89898C89888988878983888D8A8C8A88868B87898C908F8F909092919191
92929390969597979A999A9D9E9EA2A4A2A1A5A3A4A6A3A8ABB0ACB0B0AFB5B4B4B5BBBB
BBBBBBC1C0C6C3C4C7C8CBCDCBCFCFD1D2D5D4D1CFD3D5D6D5D8D8D6D8D8DADCDFDFDEDA
C97526201B1C201E1D28558C8F8A8F9284949F93969795919294918F938D8E8B97919195
908C908E898A8B8E8B888C898985867E858884827E7E7F7D8383787F7E797A7C7F8FAFC3
CDD2D6D8D9D9D8D5D1D0CFD0D0D5D7D8DAD9D8DBDAD9D6D4D2CCC5BAAF988873675F6060
5E5C5C5B5959605E61676A6D6F7370727373716862615A5C58575962636768666D6D6B67
6567666664696257
1E1E201F21252D3D57748999999EA7A8AEACABA69D9586705338202325303F52697D8A98
99A1A7AAAEAFB6B3B3B1B2B4B2AFB4B1B7B5B6B0AFA9A5A09A978D8596AC826848462B2E
3A302730313D443B3133362A27332A2C2B2A272D3835261F24252E2D558881818E6F5B3E
30322D30333541322D2946553736353434323140342835382C2F2C384F4B3E5762435972
7B766C4E444B45463A3E5074A49881867F8D9698795973A49F795E513E478AB69C833D71
A28F2F1C241E254B584F4C32454C413F32333936313F3D2F2D3334383834363035433633
3137403C3C4A545E6B75717776807E787A74654F2D2B31515B64696B6F797F8485838286
86848580878F888A89848A8D8C88868B88878B89868A8A88898A8C8C9097908E92949191
919394949599959C989A9F9D9F9BA2A2A0A2A5A8A3A6A7AAAAACACB2B0B2B2B4B3B5B9BD
BBBCBEBEC2C7C2C7C7CACDCBCCCFD0D1D2D5D2D2D1D0D6D6D8D6DED8D7D9DCDEDCDEDED9
B858201E1D2024231E26488C908D8F908796958F959493919094909490938C909091928C
8D90908F86898D8E8C8789868B8588808386817D817F7D80847D7984857C7A77808DAABE
C8CDD4D7D7D7D5D3CECDCDCDCDD3D5D7D8D8DAD9D9D5D5D3D1CEC9C0B79E907F6D605E5C
5A615C5B5E5F5F5E6466666C767673757673767062615C5955595B5B60636B69686A6466
6964616765625F5E
212120231F292D455B748A95999FA4AAA9AAABA69C8F85765B392420243040556E7D8795
9AA3A7A9B1B4B3B4B1B2B4B1B2B0B2B4B5B5B5B3B4A9A8A09B938D829FAE73757133282C
3A36302B2A3542403536302B2D31362C3234292A393429272626292939657F898A705835
2529302B293843362D253C553C34362F3535393C2C2C2F3430332E3C504934556847606E
7472655B4E52574B334C6278999A82736B799AA09E827F957944342F2F3668BCAC9B5542
6B6A29222820243F534F4E34414A4B4B343237392D333334342E2F3D3A3235413836342F
31363B3C37454F52626B6C7278787B797971654C302B2E4C5E596B6E7278838185828585
848789838987888687878B8789878A8A8C8586888888888D85898C91908F8F92908F9295
8F919398969A98999C999BA09F9EA09FA1A7A6ABA4A7A8AAADACAEAFB0B2B0B3B6B5BCBC
BBBCBBC0C2C3C6C5C6C9CBCBCED1CFD0CFD3D2D2D2D2D2D4D4D6D7D8D8DBDDDEDDDDDCD1
9E3E2C2A2522222520223E8E93908E92899B92909793969595949593949293949594948F
8E928F8D8A8B8D8D8D8C878788858486878687877E8080818281817E817D79787C869FB3
C2C9CFD2D5D5D2D1CCCDCACACFD1D5D9DAD7D8D8D8D8D6D6D5D1CBC6BAAA98876F605E57
5C5E5F5D5A5A5960656565656B7172707074727267665F59595A5C5F6162696B676A6968
63605D6568696662
1F1F2025242E44425D768A939CA1A8ABAEABA8A1998F83765736231F242B3D596F7F8890
9DA3A9ABB0B1B1B2B3AEB0B4B3B1B0B1B6B4B6B4ACA9A2A29C918E869EBA797F7237302B
363C2A27292E3749423435302A2C3E312A26242E33393A2A2B2C2D26334D7C958E765938
242D282A324044392A21394D3F332B2A3F4A3E2C2827323B3030374E613F3B546759606A
787361625C584F483856697A90928D7E6B839EA19E6B67804E2E312D2B3154B7B6AD6E3D
343A282223262B335652472B3A4D514B3030393C30302D2D33332E3740413C423C2C2E2D
2E303A39353D58575B6663696F737C797872654B3328313F5C5A63707177828487807F81
828586878F888C8785898B888A8D8E8985888B87888B8C88898F8C8C8B8E919490909294
8F95959798989A9A9D9A9D9E9C9FA0A4A8A4A3A8A6A9A9ACACADADB1B0B3B4B4B4BABAC2
BBBBBDC1C2C3C3C6C8C9CACBCDCDCED2CFD1D3D3D5D5D3D5D5D6D7D8D8DCDDDEDFDDD9C6
6A272F3223222527212139859391958D87968D9897989793919295908F91919195929293
8A928F8C928B8B8B898D8588817F8387888486818584848081837B7A7C777A77788092A8
B9C3CBCCD0D1CFCEC9C8CACACED1D6D9DAD9D8D7D7D7D7D7D8D1CFCABFB1A1917A656059
5A5C5D5C5C5C585962676B6B68737270737674706F5D5F595C5C5A575963646967666B65
63616763686C6A67
212121262E36404860758C979CA3ACABAEADA9A5999381725133211E202C405A6E828F92
9AA2A8ABB0B4B2B2B1B0B0B1B3ACB6B5B7B7B6B2AEACA6A09D938D8195B37F7A7136312C
353A2F25282D303A413D31312F2E362B2B2B262D2C343531302D322B33406C92927E6439
2324252840574D392B27324B41392F353D42392B242A32373E363459583E43656C655972
766458645C4352483D56646F8C88908A6C7186A89F6B726E332630232B3154B8BABA9A55
2A26211D22252938575557293B4A554D2F2F393B343738313232323741483D40332D2B30
2B303B3A353D525B5C635D646467767E7B746449362F323C645D5F6D737E818082828182
80818284888A8889878A8B8E8A8E8C8684868988878C8D8A878B898E908B96909490938C
9294969596989B99989D9B9F9F9BA2A8A4A6A7A4A9AAACAAA9ACB0B0B5B3B5B2B6BCBABA
BEBABEBFC2C3C5C7C6CBC9CDCDCFD0D0CFCED2D3D6D3D4D5D6D7D8DADBDCDDDEDFDCD4AC
45202628242023281F243377919098948E8E8B989491909593939999939494948F919292
8E8D8E8E8C8D8F898D8C8C8885848681878586888386847F807F7E7C787E807D797F8A99
B0BBC3C7CBCDCBCACBC7CDCBCFD1D6D8DBD7D8D7D8D7D7D7D5D4CECEC4BAA89C866A5E59
5C5E5C5E5A5A5F565D666767696B6E71707476716F635E5F5C5C5B595E5F616A63696B61
6363606272686E65
242429312B30344960788A9B9FAAACAFADADA5A29D92837154352524282D475A6C7E8C93
999DA8ADB1B1B4B7B5B1B1AFB3B3B2B6B5B6B5B5AEA9A59E9C968B8186917F7F9146292B
323A392A2A2B2E30393D3B3031343C34312B2E2F3135373639302E2E2E3A5A8B9780643C
2B25222B47594A3E242830473E3026333E44382923343D322E30386450364F666760566C
6B5B585B4B4C5951505162708F84979A856D73AFA582774D2A2D2E2C30395BB8BEB8B972
2A2822282C2B2D375753563337475F4F3B38353A353535373634313D3B433C362E2C2A2D
30302D393A374C57616A6B62605F6E73757460442F312A3F605C636671787C808482827F
837E7F818689878B8989898B8D8A8B8785868A8D8B8B8E8D8C8C908F868E928F9394908E
8F929596999D9C9D9B9B9A9F9E9C9EA0A6A8A8A9A6A8AAAAADAFAEB0B2B2B7B9B8BBB7B8
BBBDBDBEC2C5C3C9C7C9CCCDCED0D0D1D0D0D4D5D3D4D1D6D7D8DBDCDCDCDCDEE0DBCB88
31202529212425282123336C91929F958E848E919394959597969893928F929196938F98
908E948B8D908E8D8A868B8B808884878586848A85888280837F7E807C7C7C7F797E8392
A2ADB9BFC4C5C9C7C8C9CACCCFD3D7D7D9D9D8D9D7D6D7D6D5D4D3CDC9BEB4A28B73635A
5C56605A5B5E5D5A5D64636A6B6C6C6E707075726E6A655F5B5E5B5C5E5D5D69626A7063
67605E5E6B656C69
1F1F28272B323651607A9198A1AAADABADAEACA5A09C866D502E2625262F485B6F858E95
9AA3A4ABB0B3B7B5B4B1B4B3B2B3B2B4B6B1AFAEAEABA3A59D9791837478687AB2692F35
3134332F2F2D2E323A3F403A2E3437322F342D31342D30312F2D333228364F7D988A6E36
2626272E4B5942352324283F3B2E232F3A393735373D483C2E2D4E5D3E3A596A5A566671
6551635547525D594C566275928D9495959579A1A6906A28203244362D3167BBBBB6C58F
2F202329272825294D504E2F3948675D332F3838352E333D2B2F2E3B3C503B352E2A2932
362C2D3B3D354457626C726B646063676D6F6442332B3240545C586B74777C8488848682
848480858588888C89898C8C898F8A888A8E88898D8B8C8B8F908C918E8F8E9193939391
95959898999B9D9C9BA09DA2A09FA19FA2A8A3A6AEADABABB2B0AFAAB1B7BABBB7BBBABA
BDBABDC0C3C3C7C9CACDCCCECCD1D1D3CFD1D3D7D3D5D5D6D7D9DADADDDEDEE0DCD7B253
2726292922232A2520202F6195939B9B918091949599989496949B928E9394909395918E
918F90919092908F8B8C8A8F8B8B878A8A8A888A858684828285817D7C807D7B7A7C7E8E
97A3AEB2BDC1C5C7C3C8CBCBD0D1D5D7D7DAD7D8D8D8D5D8D5D2D0CECBC5BBAE967A665B
5E565E5D5B625F575B6064616A676A6B6E717274716A66615B585658585F5E6462686D66
68615F626764626F
2222252827373954677B9299A3ADABAEACAAAAA69E9B8A7B502A1F28253347586D839094
97A2A0ACB1B3B4B8B2B0B2B0B2AFB2B3B6B5B5ADABA9A59F98968B826E6B686DA4893328
2D2B32352E2F292A2F2F3D3E3036342E352D2D2C2E323A2C39312E2A2C334D6C8F8F7236
24262B3A544E323128282932353129373736404F55565B4A3A32594F36485C655760736A
695B5E5350515B5D4E505A76929896978C979B8FA1915327242D5D5031326ABCB4B6D0A0
2E242924252223294B464A31344F6859312B30382F2B2B36322D2A36374E3E33342E2F30
382E32333C383D545E6A73726F6A615E646D654439272C38535F58747877767E83828482
7D817F848486878D8A878B8B898C8989888D8C888B8A8B908D8D8C8F92938D9593978E93
949A929697989C9E9C9D9C9FA1A19FA2A5A3A8A8B2AAABAFAEB2B0B0AFB3B6BDB8B7BFBC
BBBEBDC2C6C6C7C9C6CBCDCECED2D0D0D1D2D6D5D3D5D3D6D9DADBDBDDDDDEE0DCCF8C39
292A2C272524272B1E202B5B9E94999C888190949798999193979899909191968D909093
918D90928E8E8B8E8887878A87858686878787858786858685847F7E7A7C817F7979797F
8A98A1ABB2BDC3C4C4C5C7C6CCD1D3D5D7D8D9D6D8D6D6D6D6D4D1D1CDC9C2B4A48A6F5D
58595D5B5A5E665F5C5F60666A65666C6C6E7073716B6863625A59585D59596261656C65
6764645C66696667
262627242E3539516E7E969EA5ACACA9ADACAAA39E938A7758332229282D3F5A71819093
99A4A5A4B2B1B0B4B3B2B4AEB0AFB2B4B4B0B3B0AEA9A5A29C98897C69677C6672752E27
28293134312A2A2A32313A463B363A31302B3332332C342A2A2E2F2E2D2C3A608492742E
2A2E2F3C5F4D362D2522292B47262A363E4D5C68616960442D314E413B576A574A72736C
6E666A624D53525A524958759396A19890879B9A947F3C23283A544A343A6BC3ACB7D3AD
391D22201F1F2229474E3D30364C584F3133322E373228332E3D373636444336332D3034
39453F343839384B58606C6D716A686663635C403627393C516260707A797A7E827E7E84
7F7C7C8286888389878789898E8A8C8C8D8D898D8C8B8D8C8B8E908F8E96959A91918F91
9793979897969B9C99A19EA09DA3A1A4A3A4A6ABACACACAEAEB0B5AEB1B1B7B7BAB8BBBE
BDBBBEBFC5C6C6C6C9CBCDCDCCCFD2D2D2D0D5D5D3D4D3D6D7D9DCDDDCDDDDDED8BC622A
29292F322628292E201F2B4D999297A285828B949894949690969092968F9490938F9492
94928B918D898E8E918B8E8D88878A8686888C8888878385848883817E7A7B7B797A7B7D
81909AA4ABB0B7BEBEC3C5C6CBCCD1D3D6D8D9D7D8D5D6D7D7D4D3CED1CDC4BCAD967E65
59595D575C62635E5B5A595F676664686B6C706F706D6E67655E5B5B585D615A61676D63
686565655E666A69
2222202329333D627596959EA7A8AAA6A8A9A4A29C93887B62412723232A3F5B6F838D90
9AA2A6ABACB1B3B2B3B1AEAFAEB0B6B4B4B4B1B1ACA8A49E99958C7C6D6CA6814D553A28
283031302B2E28293B34334041313B302B2C342932392E2E2A282D292F2E3A58798A7839
27273A485A48382A2126232B3022233948646953476658432C344E404D5D614D4B7C6D6C
6D736F573F4C565B57496284908894A18E779C95816A34283746352D3E4573C39CB1D7B7
3F2C2C2B281F2528445544343B454F4F32303436342D30333039343B384742372A322E2F
3235322C3635363C4F5E606E6A75706F5E655A3B312B2C40506562677B7A7177817D8084
7D79818387898881828485858E8A8789898A918C8D8D8C8C8A8D918E9391919795939198
919498979A9A9B979FA09D9F9EA2A2A7A8A7A7ACA9ABACADAEABB0B4B4B3B2B5B9B9BABB
BEBABEBFC6C4C6C8CCC8CACCCCCED1D3D2D0D2D4D3D4D6D9DADBDDDADDDDDFDCD09A3A23
2E26303327272C2A2B272B4A8F959BA585898A8E98969795909491918E90949291928E90
918E908C8C8E8A908B8C908A898B8985888489878A8185858685817D81807B7883797973
7B8891999FA8ACB7BABCBDC0CBCCCFD3D5D7D9D8D7D6D6D6D5D4D4D2CFCCC8C5B29E8A6D
5B535858575B6060635C565A62646767666D6F6E72706E67645D5F5B5353595A60606868
68666C6761636A65
1F1F1E2530343C5A6A81939BA7A8A8A9AAA8A2A09A8F7F7B62392620262B425373818C92
9B9EA5A9AFAFB4B2B1B3AFABADAEB1AFB2B5B6B1AAA8A69D99928B806B7ECC9547453E2C
29282B332D2C272E303F33394B3F35302B2C2D2E34322F342D2B302A3031305275877345
2B2E2F48544C3F27282822272F232C4A63635A3D3F674B382E3B4F4D5B5B584C5E737471
766D6E4C3F535B5E574F668D93807994947A97A68E5C3E3C4E3D2327394F86B880B4D9BC
4D282027262425263B534A333C3C4C4937332E3534302D31353033393D4C46353432372F
34302B2C3337343D55605E6C696A747B6B645B343329293B4B61646B7871797E7E817F87
827F8086868A888A8186818A8B8B8989928F8C8A928C8D918F8C8B8C96949490969E9796
939798989B9C9A9C9E9FA59FA4A3A1A1A7A5ABAAAEADADAEAEB2B3B3B7B4B5B6BAB7BDBD
BEBDC2C3C6C9C6C6CACACACCCED0D0CFD3D1D0D4D3D6D5D9DAD9D9DDDBDDDDD9BD672B29
2A2E3030282C2F2B231F2B44899B999D81868F8B969596958F9391938F949292918E918F
9493918F8C8D8F8C8C908B8D8A8986878C878C8F8988858A8786837F7F7C817F7A7F7C78
7F7C858F989FA4B0B1B6BABFC7CBCFD1D4D7D5D6D6D6D5D6D4D5D4D3CFCCCCC6BAA99177
61535054595B5E605D5B595B5C666765686B6E6F7273736E68615E5859575B5858616568
676A696365696268
23232A2B323748657086959EA6A8ACAAACACA29E999485785D3C2B2829344253707F8E94
9B9FA7ABB1AFAFAFB0AFB0AFB5AFB1B3B2B3B0ACA9A79F9D99968C806579C29F4C5A4B2C
25232C32352D2D2A2C2C353544533C34312A2C2D2E333C3128312D343130325970847456
372D375345463C252B2723282C3042636146362B525C423637485C6861564E5B6A686F71
78695B453F596B68595071928B826879958599B39D7D5D6555342823384C8CA060BBDCBA
46252B2B27222526365049393C3E4E4F3236342F352E2F3336342E32394A543A322F3836
382F2930373B373B4E5C6873716F71756D5F502F282725424A59686B7570718081818585
7D808288858686888484818B8A898C888F8F8A8C8A8F8F8C8B918F8B919291918E959293
93989696969B9D9AA2A0A09EA5A4A6A3A5A5A9A8AAACABAEAEAFB3B4B9B6B4B4B7BBBDBD
BEBDC2C3C6C3C6CAC9CACED0CFD0D1CFD0D0D3D5D4D8D4D6DBDADCDDDCDDDBD19A443A25
2E2D33322F2A34302721283D7FA1979887828C8C9899929592959594929092918D8D8F8E
92908C8E898D8A8E8C8D8B8C8A8A848C8A8A8B8E888488848888857F8482817C7D7D7C7A
7C788087919C9DA4AAAFB3B9C1C5CACFD3D7D5D8D7D7D8D6D5D7D4D3D3D1CECAC2AF9A7F
6A584E5055585B5E5C5A575B5C6064676B6A6C6F7273706F69605F61595853585A5E6667
676767685F626863
2323272C34424F65728997A2A9A5A9ABA9ABA29D928C837C5D4429262D324D61727F8D99
9DA0A7ABB1B3B2B0B2AFAFB1B1B6B5B3B2B0B2ACA9A4A59C948F888086719D8D4B937832
2225232E352B30282B33312D345B5242342C2A2A3235323631322E342D2F344C6E83734C
2926344B3B482E272B24222A374560614A31252F6156453A384B6468594F4D6766656665
5C4C4044536074785D52708D85826A68828E91B6A69078643827211F2B48897D4EBADCB2
35223324292428253A4F453E3C344744322C32342F2D2D2A33333436374B5A3A2E3C3739
323A2D2E373F393C47586574767778786A6352382B2A283F446169687579727B81828587
8784818687848689838B88898C8A8E8D8C8C898D8D8C8E8C8E8F94898E90919191959795
9296969B989D9C9FA1A0A29FA5A6A7A5A4A5A9A8ADACAEB1B1B4AFB0B7B9B6B3B9BDC0C4
C0C0C1C2C6C6C6CACBCBCCCCCCCFD0CFD0D0D3D6D1D4D6D8DBDCE0DEDDDDD6BA6A282C27
2B303238292D373D2B2626396C9E9794867E8B8C969699939192939590919191928F8E8D
90958C8D8A8D8C8C8C8C8A8B8C8C89888E888B8689898B898883858082827E82827A7C7C
767983808C94969B9FA0A2A8B6BDC7CFD5D8D8D6D5D4D7D6D7D7D2D3CFD2D0CDC6BBA28D
6E584D4C505355565D6356575C5B5E6969636B6C6A6F74716965655D565A585E5C5E6568
656767676A656B66
26262A344353636E788698A4A59FA6ABA7A8A099908682725E3D2D282F3A4B6073828F97
9DA1A7ACB0B2B2B2AFB3B2B3B1AEAFB1B4B5B3AEA8A79E9C9591898EBB8E8373497B7F28
1F26212B2A312628283630252C466652322B2932312A32403039323232302F55737E7153
2C2B3A4E3E3B27252823212C4A62624333262E3C6B57453B3D5862624B3B4E7263605950
433E454A5F5D70805E516C828480716C759997AEA6957B502C242425336388694FB9DA9F
302425262423262A33503C3A382F454432332E34372F2B2D3531343B445152412F343B38
3E3C2B2A383D3A3D3A526070737678756D6155382E28273C4B506767757E77797E818287
898583828584818285878988898B8B928D8B8C908C8C8E8E8D8C8D8E8D91908B94969995
99979B9A9C9EA09FA1A1A1A1A1A3A4A7A8ABADAAAAABACAEB1AFB3B5B5BAB7B7B7BBBEBE
BFC0C1C2C6C5C6CCCACACACCCDCDD1D1D1CED1D5D5D6D5D9DBE0E1DDDDDCCB953E242528
2E396D3A282E3742332426376CA39C8E86828D88929794989093919291919293938E9391
96928F928E898D8E8C89898F8C8D8D858B898C89888B89878485858185817E847C7F797E
79818482878C8E9190918F98ADBAC7CDD4D7D9D9D5D4D6D6D8D6D4D4D1D1D1CDC8BDAD97
745D4C4B4B4D58555E605F595657616665646265666C73756E706960625B585E5A5D5E65
666867696B696A64
25252E394F5D6E737F8D99A3A4A2A5A8A9A49E9491847D70573A29223041525D71818D97
9F9FA6ADADAEB2B5B6B3B2B2B2B0B3B3B4AFADAEA8A2A29D96918DA7D79E6F63465B632F
252D25292F2E2A2B2B31372F2E315467363132342E2E453D3337322F2A2A3351697E6D4C
322A3D58403B2B242925273D616E543C2D272A3B6A4F4039526E614632435E665F535347
403B595B635F75805C516B767181867779A3A8B0A09475512B27262950A0914E4FB7D38A
282422202220252437503C4A443341473430343833292B2B2D2B3037474C443A3738382D
3E3E2D2F2E413B37374F606876787E71716C51322629284F495366636B7B767E7C7E8287
898585858A85868289898989878D898E8D8E8E8D8E8F8E8E8E898C8C8B908F8E909A9495
999899989C9B9EA0A0A1A2A2A1A3A5A7A8ACA8A8B0ACAFADB1B2B0B4B6B6B7BBBBBDBFC0
BEC2C4C4C7C9C9C8C9CCCCCCCCCED1CFCFD1D3D6D6D7D6D9D9DDDEDDDCD3B4663126272F
2E333D3B2E2D334635252639619FA28E8C828A8E908C969297938E94948F918F918E928F
90938C8E8E8B92928C8D8B8C908B8A8A8C8C898887899085868588827F7E8582808A7D7F
7D8184888689888B8A8A868AA7B7C7CCD3D7D9D8D5D3D4D5D8D8D5D4D3D2D1CFC9BFB39F
856A564948505053545B605E57585E6363615F63666A707272736F6C615E5A57615B5F5C
61656367686C6466
282834475464757B818C959FA5A3A3A5A8A39D978D86796B583C2B2A3441556175828A96
9AA2A7A8AFB4B3B1B0AFB0B2B1B1B3B6B1B1B4ACACA3A098949289BDDA8F6D72484D5137
2F282C2B282D2D26262A3A2C312A446741312C333C2F2E343A312D2B2D272D5064766C4B
2B294F5A4C37282B2724294D7666423326292A4C624E494C5D6549393E475B585F4A404C
3F436E695F5A7D7D68636F6B6D7D918C78A0A9AF9A8B825F30242A3690BE7F4251C6D171
272123252725242730583C3C42323F4130313534342C342A31362E38393E4437373E3834
3333272D32424A3B354D586F757C76716B634B362D292E4A4E56646C60756E7A7C7F8086
878384828183868786878A8C8E8E8E8F8C8C8A888D8C8A8C8B8D8E918B8E8E9490919698
95959597989C9FA09EA2A0A5A2A6A7A7A8ABAEACAEB2ACB2B1B4B2B1B5B6BDB9BABBBFBF
BCC2C3C3C6C6C6C9C9CBCDCACCCECFD2D2D1D2D6D6D7DBD9DADCDEDCD8C1804A2C282A30
34303C362F2E354040252A35609AA4938981888E928A94939091909390988F8D90919290
929490918C918E8E8C8F918F8D8A8B898A8B8C8A88878A8B86858581867C7C7F80837A7C
7F83858885898887878B80869CB4C2CED2D7D9D9D7D6D5D6D7D8D4D4D5D5D2CDC8C1B9A4
8C7560504E4E5250555A65605F575D636264626465686D717576776E69625D585D5D5F5C
6160696A69696968
3333384F6069767C8687929DA3A7A3A5A4A199938983776755352A263542535D6D818B93
9D9FA7AAB1B3B4B2AFB2AFAFB1B1B1B2B4B3AEAFABA39D99A0908EBFC57A7D824D543F2C
292A282A28332B2B2B2B362C2E2E3B5F4E332F303B3C353835312C2C2F29304A606F6C5A
342C4F53462E27282B27335276533127302A31535D4C545A65433138424F4E4C4B494755
435B74685E5879777973756F7774958E7D8EA4A7907C8B6A402C3B66C2AE5A3B55D0CE66
2C2825262B252A2E3759423D40363A443637383639332D3236353A353E41443B353C3C36
352E2B2F3749493E3F4554696F7A7873696149332F2B31505456627368736775807E858D
8A86847E818487888A88898A8D8B868E8D8D898A8D8B8A8B8B8C8F908D8E909191909596
999899989D9CA1A59EA2A0A3A2A5A5A5A7ABAEAFAAADB0B2B5B5B3AFB6B9BEB9BABCBFBF
BDC1C4C5C6C2C6CACCCCCCCCCFD0D1D3D1D4D5D6D6D7D7D9DCDEDDDBD09B5436302D2C30
333C443C30333844412C29355292A9978A86898B8D90939492969395959492949392908A
9096948F908E8D91928E8C8F8E8C90878C8C898A8288888B85828082837F808181847F7E
7D82868D8C898D8B887F838096B1C1CBD2D6D9DBD5D6D3D4D4D4D4D4D4D6D1CECCC5BCA9
95856A574944464A525E615E5D59585D645E5E5D63646A6C707274747369635F5F5D5F5B
5C62666A65646665
3C3C45576A727E82898C939AA3A5A2A3A49E968F8481746148322D2C3540536275808C98
9EA0A5AAAFB3B7B0B1B0B1ACB0B1B0B4B4B5B1AFA7A4A09B968F8CB8AB747A774356372A
2A292A2729352727272A362F2F272D455D40302E383B3939332F2E2C2B2A2A3F626F6564
3A384B49422C29312A293763644027252C2E3C5063655761492E2F424350474B47464A55
466F78645A58768194857C817A839588778C9A957C5782794F2E3DABC686383464DABB4E
2923262B3024252A375D413A3C35384033333032372F2B31353333363B414E3F2F303134
2A2C262D34494A3D41425C6673767D6F6A5E412D30292F4951575E79737D65667875818A
8788867E7F8187888B868A888B8B878C8F8C8A8B8A898C8C898F8E8F91908E8D93959596
949A9A9C9F9D9FA59EA2A3A5A6A5A7A5ABADB2AEADAEAEAEAFB3B5B8B5B6BAB4B7BDC2C1
C0C2C3C3C7C6C7CCCDCDCCCDCED1D1D3D1D2D3D6D6D7D9DADADCDCD3B16C41362D2A2833
2C3B424533363F453E262630498CAE9B89878B8796948F958F928F95938D94929191918E
93918F8E8C9090908D8D90918C8B8D8D8B8A898B8685878386897F827E8481857D7E7D7F
7D808585888D8E88877E7D7C8CAFBFC9CBD5D7D8D7D4D4D5D7D5D7D4D5D3D2CFCCC9C0B2
9C8C7B62544647454D5B5F63635D545B5D5F625F616463656A6D74706F6D6A6465625B5F
585F5F6262676768
47474E5E6E787E84899098979FA29FA0A1A29D8D877B6E584831292B37455761707A8997
9DA1A5ABB1B2B1AFB2AFAFB1ADAFB3B3B7B2ADAAA9A7A09A93908DACA6907164404D5928
26262632302F2E272B2E33322E2E2D374643343339413F302A2B322C2D242E334F67665E
4136403D3826252A2D2C396E5C3C2B25282D3D516E6D66562F2B3A414B4D4C50483E494C
637674655751728B978A807F85818C88738A918F6C3B697D503864C3B0552E3471D3A137
242826242D28252D3C61493A3C36364434322E343B2A2D2E31323235414449433835332D
2E322C2E37434A424B394E5D69757B6B6C5C422B322A304E565B6C7A707F726A6D6C7984
878983807E848A89898D8C898F8C8B8A8E898C88898D8B8D88878B9190918D8F91949698
9696989BA1A39EA1A0A1A2A2A5AAA9AAADB1B1ACABAFB1B0B4AFB3B5B8B7B9B5BBBEC0C2
C3C3C6C6CAC9CBC9CCCCCFD0D0CFD3D4D3D3D6DAD9D9D9DADADCD8C17E3C39302E292B33
343C464334393D3E3C2D26304183AF9F8B8D8E899191949694969591949193909692918E
92928E8C8B8D918D8F898C908A8A8D8B8D888A8384888A838486857F7F827E797D7E7F7D
7C8183878A8A878780807B7C86A8BEC8CED3D5D6D6D3D4D4D7D7D5D5D4D4D3D1CDCABFB6
A197836F594A42404C4E566163605A59585C5B5B5D5F63646A706E6A6F6E6E6A645F5E5E
59545A6062676868
59595E67797F84889391949C9DA09B9A9C9F988D8175644F42352D2C314B566573818794
99A0A6AAACB2B0B4B0B1B1B0B1B2AEB2B2B5B1B1AAA5A39B968B8DA5BCB86C5C4367953A
262526252B322A2C312F362F282E302F4449383944483C322F2D36342D2B293747656453
3F3737363126292A2B2B40634E3023252839455C72685B372F30423F3E4249564C41455B
7A72675C555377878F8B828188817F70688D8A8C614F6B7D5F5079AC80322E358CC57636
2E2B2D292C28272C3F62453F39403C3F30342D303732312B323B363E3A3C533E3838392F
30302E3438424643433F4B5C697676676450362A302B36514C57707A767E7472716C6D7B
80838083808986888C8E8D8A8C8889938A8B8B889288888E928C89908E8B908D96939597
9B989B9FA1A19F9EA3A4A5A3A7A6A7ADB0AFB0AEAFB1B1AFB8B5B3B7BAB6B7B8BBBDC2C2
C6C4C4C7CACACBC9CDCECDD0D2D0D1D5D3D3D6D6D7D7D9D8DBD8C99147313A302A272D33
323F4C423C3C433945302630407CAD9E8C8B8D8A9095969499989493908C918D918F928A
908E898F8C8D8E908C8E8D908A8C8A8D8B8A8783868586888585867F7E818182787C7E7A
7E7D7F84878B84847F7F7A7983A2B8C5CBD0D4D8D5D4D4D6D7D4D7D8D5D6D6D1CDC8C2B8
AFA38F7B6451403C3F4C515F5F605C5E58595B5D5A5C5D62656D6A716F6F6C68675F5C63
5C5C605D656A6766
67676B707B83888C8D90949B989D9993919592888070655042342A2F36485865707D8693
989EA4ACB0B1AFB1B1ADB2AEB0AFADAFB5B1AEACA8A2A09C948C8EAED0BF674E4D8DC54F
2429242D292E2D2C343336312C3431414D474741424134313536373B342C313447555D49
4641393732242B2B2B2D3F4C352C2C3434475267755B352F333B47443F48475549494B6F
766660564F5D76888F8D838985807E64698D828A756E63797A7C978C5C303240A9AF572E
303232302D332C323A5E473F423D38473436373136322D2E2F33353C3C41484032393A39
3437333338494545443D4B60686B6F685E4B3D2F2A2C3D4D48647478777F79767571716F
7C7F82828585838888878A8C898B8B8D8C8D8D8E928F888D8D8C8F8B8D8D8F9297949598
979BA09EA2A4A0A2A4A5A5A4A8A9A9AFB0AEABADAFB2B1AEB3B5B2B5B8B6B7B9BDBFC0C3
BFC5C6C7CACACCC9CDD1CDD0CFD1D3D5D6D4D6D8D7D6DAD8D9CFA35B30313B272A2D322E
38414E4B3D4247464A362D32436DACA08E8B89878D909893949596939695948F91918E8D
8F918E8E918D8F908C8D8E8C8B8C8C8A8A878785858886857E8283847C7C7E7E7B7C7D79
787C7D81868786857D7973767E98B0C1CACFD5D5D5D4D5D3D5D6D7D6D6D5D6D2D0CCC5BE
B3A99583715746353D494F566160605956565D5B5C5C595D5F686D7575726F6B6863605E
5B54585D63636765
7979757E7E848D92949698999996958F898D8886796D5B5946322D2C3E49515E6E7E8996
9BA1A6A8AFB2B3B0ADADACAEADACAEB0B1B1ABAAA6A59F97958E95C7DCC7755C748EC669
242522272325303138383C3C3C3B3941493F4F4B47372F273A5248403C3833333A434340
4440363D2D2B2B2F32303E43372F2E384E706B70683D292D3847524A4C5449504B4E6079
6765655355677685928C848A7C8B895F7587856E5D54458987B2AF746042395BB88C4033
2E2C2C2D313634333D624B453B3D3946353E363D3C3835393437383C3C414449393B423D
3E3F353B425E494943404E5A646869675C403838352C3F525060777B75837B7673767974
6C7478818789888588868D908988898C8E8E8E8F908F8A89878C8D898E8A8F9094989598
999C9C9FA1A19FA2A5A7A9A6A9A9A3AAB1ABAEB1B2B6B2B2B2B5B7BABCBCBBBABFC1BFC1
C3C3C6C8C7CBCCCACECFCED0D0D0D3D2D4D3D6DAD7D9D9D6CFAF66392C3F432E332F3B2E
3648464A403E484E4F3C29313B69ABA38F8D90878B8C9390959B96919392929593918E8C
91908D928F8D90928F8D8A8E9088888689888B868B878282827F827F7F7C7F7F79767978
75767A7A8281867E837A75707089A8BCC9CED3D3D3D4D5D4D6D5D4D5D6D4D5D4D0CCC5C0
BAAFA08E7C5E41323138444F5C615F5C5B5B5F5F5F5B5B595A666B6F6C73806E6A656063
5D5451545D606160
81817A7C80888E9499989999989693888586867D7162574D4136292A394153627181878F
99A0A3A7ACAEB1B2B0ADADAFACAEB0ACB4AFABAEA6A0A297968F9DCFDBD18779918BA15F
25242938262B31343A3D3B3C363535443D414C463F342D2B39586051433E38393F3A4041
423436383B31342C2F3E32322F292C3A56898E72503329383A4452514D494A4144556F6D
5A5B50555C697F8C9288807F8C9A8A5D938773473538499BA3C8985879553E83B86B383A
35382F32343531373B584943383E373C363B3C3C3D3935393B3B3C403F45434938363733
38333939405B484740394B5562686965594037322E2D3F544E5B727A747A7776767E7979
73676F79858A838487858A898B8A8A89898A8B908D8D8E8A8B8A8C898B8E909193949496
999A9CA1A3A4A29FA3A9ABA7A8ACA7ACB0AFB0B2B4B8B1B2B5B8BBBFBCBDBDBDC0C1C1C2
C3C3C8C6CDCACACCCFCFD1D0D2D2D4D5D4D2D5D7D9D9D8CFB3703B383748412F31343E37
35404450463B4D4A4E4729303861A4A78D8F9487899396939294949993929391928C8F89
91938E908E8E8E8B8C8E8B8B8B898C898C88878A83848480848180807F7F807D78797A74
78777D7C818485827F7E706F6E859FB6C4CBD1D5D3D3D5D4D5D5D4D5D3D7D6D5D0CECAC3
BDB4A79A8367483535303946565A595B575D5C5F625C5B58555864696A756E6A69685E5F
5D565553575F605F
7F7F838286909091979997979795928881847C77695E554840372E2B374B54626E7C8693
9AA0A4A6AEAEADAFAEAFACAEAEAFAEB0B1B1B0ADA7A49D97958F98C7D6D9967178806956
2D322C373632313435403633373A2F3B4040494D372D2C2D384C594C4742423A3C353430
303D3F42464943403B403A342324253D62889F73402F30463F40584945443D424C677368
5658525C6770848E8A8479889C9D808CA57D4A28282C5EA5C0B4633E71554CA59F472F32
2E292A2B302C2A313556484433343339362F37343938352F3437373C3E45424433373331
353734393B533B4543394F4F5E6367664D36332C2D2B434C4E53707671787477777E7E7E
7A7170727880868389888A928C8989898A8A8B8E8F898D8F8F8B908D8B8B909292949498
969B9AA0A0A0A4A3A7A6AAA6ACAAAFB2B2AFB4B2B2B8B5B6B6BBB9BDBEBDC1BEC3C1C1C1
C2C5C7C9CACBCACDCDCED1D2D1D1D5D5D3D4D6D7D6D8D1B576442D3941503F303B343C35
3849505452454A4445472833385D9EA993949384888D959494969A95908F8F8F9193918E
95938C8D8E8F8D8C8D8B908C8A8F8A87878E8888868381818282847D7D84877777757672
74787C7E7D8084817B747065687A99B1C1CBCFD2D4D3D4D2D4D5D4D7D5D3D5D3D1CCCBC7
C3BAB3A4917051392F2C323F4B555A5C555E625A5E5A595157565F60616B6C6A69625F5E
58595D59545E655E
7C7C85858A919193999B979395938D86837A746B635647423B362A2636495566707C8693
9DA2A5A9ADB0ACAEAFAFABAEAEABACADB0B2AFAAA5A6A0998E8C8DC4D7DEAC635A644759
3B3B3F4138322F2C2D31292F29262A30334150513920252533464E433E4240433A3D3338
3C49555D696C726B6C5D48392E20252E55809B76362B36403E41563E423E3F4C656A6753
565D586471738684848C8283A39784A49F673123253C8AB1BD853B35605762B880363836
2F312D27312B2F2D3955503B3A34363C353136313B32363533332E3C38443F41372C3235
323931353B52404C3B404752595E605942392D3232314D564A5F6F7374737276787A8383
8174717174788485898A8A8C898B8885868B8A8C88898D8E8D868A8A898E8A8E8D939396
9A99999EA09DA49FA0A5A6A8A9ACADB1B0B3B5B4B4B5BAB9B8BDB9BBBEBDBCC0C0C3C4C3
C5C4C6CBCACBCDD0D0CECCD1D1D0D2D4D6D5D8D8D7D2B9864D3535464E5843414540443F
404A5050554A4C4B3F492E373A5694AD9299978789909692989397959194929790928F8F
978F918D92928F8E8C8B8E8A8688858A8D8B8A86827F818184837F7A7B7B7A787A737070
74757C838482867F76716E66626E8DAABDC8CCD2D4D4D5D3D4D5D5D5D6D5D4D6D2CECBC9
C3BFB8AC937C573B2C252D36474E555B5E5759595554525853555D62686668656669605C
59595C53565F6566
7E7E828C8C8C9396999695908E8F84817A7670645A5147433C2F292633475567777E8792
98A1A7ACB1AFB1AFADABA9B2ABA9AEADB2B4AFADAAA3A3978C8A8CB6D6DBC06E44664558
4E4C403D302C2E252F2A26272A28272F2C323E483C27282D3749555A4D4E403D3A44464B
3C383D444F566A70797F6C4C2E2C272A3B638B803B38393B3B4D46393A3B405A65675957
5C616C727D86838489857B8C9C8D94A3874B2421266BA7B2994E2B35555098B65C363235
38382F2D2D28292936584F403A32343633323A3D373933353E35323E3F463D41332F3239
34353536394E353F433F3F55565E63493E3231312A375753575A7073717371767980847E
7E7C7E726E767B7E87888B8B8B8A86878A8A8E8E8E8A8D908C89868786888A8B878E9194
969C9D9CA0A0A2A2A6A8A9A8AAADAEB3B3B3B6B7B8B9BAB9BCBCBBB8C0BDBFC3C5C6C6C7
C3C4C9C9CACECFCFD0CED0D3D3D4D3D5D6D4D7D7D1B9885431293641505442323E394237
37404C4750433F4B3B44292E354C8FA8959D9484848F9A9595929894918F929092949091
8F8E8F8F8C8F8D918C8B87868985858686868580847B7C7F7E8178777F777A7775746E6B
6D717A7E81848481766F695F5A6388A4BAC7CCD1D4D2D5D6D6D5D6D4D3D5D6D6D1D2CBCA
CAC8BFB2A081674730252B313746505B5B5E5A5753575A565151535C616167646F65605C
5B595C5A53575D60
8282808A8C8F91959A9493908C857F7C73706A605A524A443531292D36455663767D8C90
98A3A4ABA7ADADAEACADABACABABADACAEB0AEADA7A2A096908B8497C2C7CC9E46746070
5644393931272728292A28292F2C262B27303D42443C46545F6B78817E7562494C52535A
3D3A3C3F45363B4A668183683E2D2E32404A7A91564D3A394545373C3B3E4F66635F4C4C
617A737E7F7E8793868881958D838D976E332A26378BAF9C612E2B425C5EAF96422F3F3B
38312E282F2A2F2E355E4B44423130403634363737332B2D312E34413D403C3D3A393834
3232322E3C4339414C403C4E56575E423A3A2F3931405651525A6C6C73747477767B7C7B
7B8180817E757B7D8789898A8788898B8D8C8C8F8C8D8D8C918E8B8A8D8B8C8C8C908F93
93999C9C9F9DA3A2A3A6A9A6AAABAFB6B4B3B7BDB8B6B9BABDC0BDBDBEBEBFC0C1C4C4C6
C6C6CBCCCACCCDD0CFD1D1D4D3D2D4D5D6D4D5CFB98550352F292F4356543C323B3D483E
3B394A4A544940513F452C2F364688A8959D9387858D95969195969393919095928F8A90
918C9190928A908F89888B8A8984858A87858081837E807B7D7A7A797576796E7E6B6769
6E7275808487897F776B6458565E7A98B1C5CDD0D5D5D3D3D4D2D5D4D4D2D5D4D3D0D0CB
CCC9C6B9A39077543A2C2A2A3B3A4F5A5C5B5E5A5C575551524E515B615F646065636261
5D5A544F53505B5E
868681848C8A96929893908B86847A74666A665A594B4441352E2B353642576673808C93
96A3A6A9A7ACABACABADA9ACAFABAEABAFAFB0AAA5A49F96918A8282A7ABBEB9545F6E74
593A2E2C2C2A2B2F322C222729281F21282E3F596A70848E8C8380828791836445464D51
3E4542485743292C3D677D7F5D3F393B3E49668E7A62483C4E463C3C3B475A575C514655
717579827A7D8D9E838E8E918480888A572F2F2E3D81A26B35262E516781B26E3231403F
383634332B2E2F323E604F3E3A36303C35353A2E35332F3038313939394239393E383534
33312E323C43374446433849564F5235373838393142574F575E676C7176777675787979
7F837B817E7F7979818283848B888B8D8F948F8F8E8C8A8A8D8D8988858987878F908F92
94969C9A9F9BA3A1A2A5AAA9A7B0B5B5B6B7BBBAB8BBBABCBEC0BFBDBFBDBEBFC1C5C6C7
C9C9CCCBCCCECCCFCFD1CFD3D1D3D3D5D5D6CDB7814E34302B2A32485C5640373D414A45
413C4B46564D3F4B47463232393E84AB929994868C8E9698939991949490919495939191
8F908F8E8A8B8B8C8D888789898789848580838183827D7877777679757175716D6B6565
656D777882868A7D776F685853556A8EA9BFCBD0D0D2D2D4D1D5D4D1D3D5D5D4D1D2D0CE
CDCEC9C2B2987F5A44302B362E323D4B545E5A58574E4F4F544C4F53595D615D63666160
5F5F53545354585B
8888818C8B8C8D8B908E87867D74716A615F625953504B3C2F2B2A313A445465737A8793
959FA3A6A8A9ACACAAACA8AAACADABB1B0AEACACA9A49D99918B8077949698C56D607C7A
5B35292E2D2E2C2C2D27262724202425293C648088837F7B71695D5C687E87846D4C3E48
43514446505930272D3A5F78754F3C3A3C43517783826E4E514C3B3B51524E5853454E68
75757B7B737E869B88998B877D8691763B42403D77997E392E34346A66AB94423336413F
433D373533312C32435C4B473B3638403C353831362F2F333A373B383940403E38373637
333233353E403D3E4439374A4F4F483734363D38323D58525B6364717175737478767574
7881827F7E7B7C7E7A84828786888C8D8C8D8F90918D918E8A908687888B8B868C8F9092
9291989A9E9DA2A2A6A8A8ABADAEB3B5B6BBBDBABBBBBCBBBEBEBEBEC0C2C3C1C3C7C6C8
CCCACACBCCCDCED0CFD0CED2D2D4D5D4D4CAB1804C302E372F2B2E4E5C58413D46444546
3C41463F4E52484545483234483C83AF949A918B8A87969F9297948F958D9292928E8D92
8B8B908A8E8C898D8B888983888984828682817E8079777B77767775736E6A6B6867605B
5F726E7E7F85887F746E6057514E61859FBDC8CDD0D4D2D2D1D4D5D3D3D4D5D5D4D0D1D1
D0CECEC7B9A28D70533B40272628343B4D5A535458534F4C4E4D4D4E525A5A5C5B5F645D
575656564E515456
878783868C8F8C888783847B776F7363625E605B534F463E2F2C2B31404B55657179888F
989EA3A4A9AAA7ACABA9A9AAACADADACABABAEADA7A39F9B958B7D7987927EB38E60749B
742E302C2B293029282624272921242C356A7D7B757C6D58442E2D2B334B70889076483D
485A594A3D40362D2D2A3C6670614D41363A45676C85877E574039394749525240456082
7C7B76716A6676889F957F797F8587644E6D6371A28F4B252E314E727DAA653834353F3D
3E35332D2D2C2B2F3D5A4F483A32333B343338323732333235313D3737404B4435333734
3934333A3E3D344241383F4D5151453C39343935373A514F605B66696E7474737877777A
7B7F7F817E7E817F7A7A828487898B8B8D8A8D8F8C8D948B8F8C8D868B8A88858C939291
939395979B9E9FA4A5A9ADB1AFB1B5B8B6BCBFBFBCBCBFBCBEBEC1C4C2C4C3C1C8C5C9CA
C8CCCECBCECECDD0D0D0D2D1D3D3D6D4C8AB7A492D2C3538303039576661473E4E474750
434252465053434445463536463B7BAA989D94898A8E939B8F9C9492909193928F918B90
8C8C8D878C898C8B89878B858784837C827C7B797B79787B73756E6F6F70736764665A62
636C74788087827D716E62534E4556759BB8C5CAD1D1D2D2D2CFD1D2D3D6D6D4D3D2D2D1
CFCFCDC9BFAC9A866C563C30272C29333D4D50505557544C4F4A4F4F5859595B5B5F5B5E
5D5C53554E52575B
8C8C888A8C87878584827A786E67605A555254534F464738322F2A2F404854686F7D8791
9AA3A3A7A7A7ABA9ACA6ACABAAAAACACAFABAEACA9A6A29D968D81746F7A708FA1556CC0
9E3B2E2E27262C2B282E2C272A2A2D254069635C58766940271D211E232A41718A8D6343
49556E65442E323A2F232B4463595D41394657756D6A799A84614D42425456473E5D827A
7276707562566E93A287757E83887B5F65717EA196623329344F656EA38543323939454B
3F33372C2E282C2E395F494431313338383636333A2F312E313539363A46453433373335
2B3235343632363E3E3B464C534C3A38393A3431374454515863656A777677727274747A
787D7A807C7F83807C7A7B848785898C898F8E918B8F8F8990868C868A8E85888B8B9092
8F9293979B9B9CA0A7AEADAFB1B6B6B8B9BBBFBFBDC0BDBCBCC2C0C4C4C1C3C1C7C7C9C9
CACACCCCCDD0D0CFD0D2D1D2D5D4D0C39F7342312E312E3A3A34395D635F47404C4D4E50
484551495B544A40484C3F34463D74A8A09B948A87848D979192918E9393918F8E8F8F8B
868C8D8886898689868B86898384808081787A797A7E757070726968676C6C665D5A5659
686A697282837E7D736A6A554946516997B1C4CAD0D2D0D2CED0CED1D3D6D5D5D3D2D1D0
D0CECCCAC2B0A89A897959402F2F2A32363E454B4F51524B504F544E52525657595F5762
5D59555253575156
8A8A85848C8685827E79776B5F5D55515152534D49443D3B2F3632343F4C58676E7C8792
9AA0A2A7A7A9ABA8A9A9A9AFADABAAA9ADAFACA8AAA7A49A938F867A6E5E5E6CA06561C0
C25E282C332927282F292E2A2C2B2828353E3D48477E74422620242324323A4B838C7447
494E617663372D372B272834495158554D6B8D8679636381958E7F454450413D527E7F6B
706E796C4C52879E907876828788786C696C9A9B67352F2F5A84649CA157332F373A4748
4E34332B2E2824283D63573F38332E373C3C3231362E2E2D353E38333A4F473233323230
3432342F3A353A3A3D3B41464C4338413A393531383E4F50595F636D6F6E707676747A79
79807C7E7C7F8482817E787F8184898B858E8D8B8C8D918D8C8C8D8C8B8D8C898C919393
8A929396969C9C9EA3A6ADADAFB2B6B6BABBBCBCBFBEBDBDBEC1C0C4C2C4C4C1CAC7CBC8
CBCBCECACBCED1D2D2D2D2D4D4CCBA91633A2E22252A2C3D3C30415C6563413F4A4B4C51
42494E454D544B47464B3E3A433A72A0A399958D8983899593939490908D8F8E918C9289
8B868A888889898885868689867F7B807B787E79727572746E6A6E68675C66635C565956
605F6A7679817A77767166594F4C4C6390B0C1CCCFD2D0CECFCECED1D2D4D4D3D0D0D0CF
D0D0CFCBC6BAB1AAA3918360503B2E2D33314046484D4F56504A504D525353555558595A
5B59515159585455
8B8B85878284877F736F6D635B59524F48464E5148403A3935312E30404C5B6070808992
9AA0A1A5A7A9A9ACA8ABACABABA9A7AAB0B0B2ABACA6A2A095918172695B546481815AB4
D37F372F2E2D2B2B282B2F282A332C29282A354450817F46211F2426262F354179837151
4B4D4F767943312D2E2427363D557D8E84908C7C69655B59758B9147434539587A816D63
67727B5D476F978F766F7975828B7F818A90A57B4F342E3F686463B3823936363436414A
4F3B372F282625283B574D37363332393B322E2D37342C2D373E393C39393A313A353232
353336393733383E4543484D433D363F3D3234363A414B546566696B6F746E6E7472797B
797E7E7F81818085867E847F8288898786898B8D888B8F8E8C8B8A8E8B8F8C868A8B8F8F
8D959494979CA19BA3A8A9ADADB1B6B6BBBEBEBDC1BDBDBDBEBEC0C4C8C3C5C6C9C8CACA
CBC9CACCCECED0D1D3D5D2D1C6AC8854332C27242434394B463857576666444149514653
49444A414A5241484C51453848366696A5A0948F8A87889A909193908A8C8F8D8E918F88
88868687838785868482847F7D7C7B7C7B77737170706D6E65686262645C5E6060595A5A
5A606370767B747971695F534C4752648FADC3CACFD0CECECECCCBCFCFD2D3D4D2CFCFCE
D0CFCDCDC9C1BFB7B2AA9B85725442332D2E3840454B4F4E4F504A474D4E495353545955
535C535B5A5B5957
85858484837F7D786C625C56574F4742433F4E4B3B3F383930352F3742465667727E8992
979DA2A7A9ACACA8A9ACAFACABADA9ACB6B4B4B4B1A5A19F978B85796A5B515161896890
CDA23C332E25272E26282828262A30292A29334D5F7777471F1D21262A32394477786A55
494F4C627241252223242A395175938D84867765596B5D405A7C8E69403356797F676764
69746C545A86817D6D736E7077826B86A4A27E5A694435535F50939E5733373634384446
53423331302C272A38524F35352D2B35342F302E312F292C3438373D36323334332E2E32
3034393A3A363E3D3E3F4C4A4138373836323132373E46515F626767737472777A787C7B
7A7B7A787E807D8083807D7F878A8487858B89878B898A8E8B8F898A8D888D898A8D8F90
9090949696989AA0A3A3A7A9ACB2B9B7BABFBEBEBFBFC1C3BFC1C3C4C7C6C7CAC8CBCCCE
CCCACCD0CBD0CFD4D4D3CFBF996F4A2C2B2921242537354E47485752686046484A56474F
47484B3C524F464B484F4C3C4B33608EAA99928F90898698908F8E8C8B8C8E848E968B86
888685848486858280807E817E7A7475717371726D68676C6463635F625D63626159595A
625A61686F75716E6E685D4F4C4950698CADBFC9CFCFD0CECCCECCCECDD1D3D2D2D0CED0
CECDCCCDCAC7C3C3BCB6A99D8E7353382F2830334049514C4D4B4A4C494C485055515852
4F59525B5C565656
80808083807A716A605956565141453A3D404745403A3538342F333A424C5669707D8890
979DA1AAABA9AAABAEACADACAEABABADADB6BDC3BCA9A39F9A8A82786D5B4F424F6F7572
B7AC60402E2A24252729292726262D2F2A2D41586261714D202023313139394D756C6255
4D4B42516B4325252128384C8384837B7868564A4C54624B517C8C78394165716160635A
636766637C7F70756F73706C70735F96AB885242574A514E4B6B9664332F343A35313F4C
5B40352F2D27242C3A505F3A312D2E3832312D2D35322F31363D3738383A323431302E2D
313C383836363E3D373A45494037343C3932303335474D515C5C6B6C707374757A7E7E79
797E7D787C7E807C828381848789858B858A878689898D898E8C898E93908C8A8B8B8C8D
928D8F9494929A9D9FA3A9AFB0B5B8BBBBBFC0BEC1C1C2C3C3C4C4CACACBC9C8CBCACCC9
CACACECBCED1D1D4D1C4A9895D37312B25252626253133484A4A5C526C66434F4B594A55
4A4C4C425255494945484A4151315D91AF959595938982928E8C8C8989898B8E8A8F8984
8888858484817E7F84797D79777A6F6E716B696F6A6A626563616261615E63605E63595D
60645E686E6B726E66645C564E4D596B90ADC0C9CFD1D1CECECECCCBCECFD1D2D2D1D0CF
D0D0CECFCDCAC9C7C4C0B6A79C89694C2D272D2B2F35413E4142474544474B4E504F5654
5353515855535354
81817E79726F685957504F4D4A3F3B38353C46424038383E37303739444F5C67737E8A95
9CA0A5A8AAABACACADADAAABAAAAADADACB1B9BDC9C1B49D988D8276685B4B4448557B5D
8FA8905E3E2F29282A232927292B2F2D353C475D504A5953241F262B34313C5372666251
4C4B463C5A5328211E32477F927B84786148343D434D5848558C928C49495E585B5F6C63
595F6284826F7268796D676D787C70B0B97B5E515D4D41467DA87E332B2E313C3E3C4546
58473030312C282E39535C3F2F312D35372E2F2A36342D313D3E363531333036312F2D31
2E33383A3A3F3C3D363E3C3D3E4139393A2E2F32394E51545B5E6A6F767D79747C7B7A7D
7B7E817D7F7D8180798581838B888C86888986878B8A8E8C8C918C8A8C8E8B8D8C8B8D8B
908E8E8F959399999FA2AAAAACADB4B8BEBEBFC1C1C4C1C6C7C4C5C8CAC9C9C9CDCBCAC9
CBCCCDCCD1D1D1C9B4936A48322926262A242324283230424F495D556C5F41474F584F59
504D504450554649414F433950315B8BB39A988C93897E8D898B8C88868B898A908D8583
86817E837F7F827E7B7974757A73716C6B626869666563646467616060626663615F655D
636461646E6E6C6E6F635D5A5854597797ACC0C9D0D1D1CFCBCECCCBCECECFD1CFD0CDD3
D0CFCED1CECDCCCACAC5BBB2A998846045342E2C333332373D3B4542464343494C495657
5550515457575959
7979747163635D52514C493F41393834343837403C34383C362F323B414A5C6D767F8891
999EA3A8A9ABA9AAABADA7AAADA9ACAAAAB1B2B1B8BFBAB2AB98817367564E4247426062
5589978456312B24302E312827282D2D3B4C5554403047542B252D2D362E3B596C66553D
494A3F384D512C22243C6E988779745B573D3C4E5B697A727B909EA1805440474F66695D
4B5672776D656A6E75636461757E93B3C59B7B7F5F3B408BB29E573329302E393336424B
584C372E2E28313338555B3A2E302F3835312D32352E2B303337363433312D3333353130
343333373D423E46383B3A40343437393C3132343E4F495957626D76797A7A7A72797E80
7D7D7F7B7E7D7D7C7E7C81848C8A8A858785878D8B878B8D8C8D8E8E8D878C8C8C8D8B92
8D8F8F8F909094999BA2A5A8ACACB5B9BABCBEBFC4C5C3C7C9C7C7C7C9C7CACCCBCBCAC8
CCCDCFD1D0C9B498795739322F292724282524242A363141514E4B527361444A4F5A4D56
48515041515C4D49404A4B404935538AB595989493847D8583898B878484858C91888281
8282807D7E77767E74746F726F6A696A686962666365666862645A61646C666E65646566
65696965686D6B7169646060655F6182A0B5C0C9CED1D1D1CDCECCC9CBCFCFD0D0CDD0D0
CFD1D0D1D2D1D1CECCC4C0B6B2A899796146332F2D2B303032373E433D404145444A5452
525151525556555B
6F6F636758574A4247423F363634312E313534424440423B353A3D414B5669737E838F94
99A3A5A8ABADA9AAADAAAAACABA9A9A8B0B0AEABA9AAABB0C2BF9A7B6658463E41414C58
3F608DA88136272127242A2D26222B3147574F4A2F2B393E3B2D30343038486B716A513A
3B45433C3E3E292A304E888D84735A596A746F768989908E8E969E9D9D6C404253635D4C
5B736C606164747B7863504B64949894B79F857D533579B7AA713D292B2A303A36344149
57483B2E322B332E3754553D36322F3A38312C322C302E363B363735352D30332E342F37
332F2A2F363E3E3F393C39403D37333D392D3537464B55565C5E697775727A7A7C767B7F
80807E7B7D7D7B7D7D8484848A838C8B8A88898A8E8A8A8F8E90908E8F8F8A8C908E898A
8D8E90918F91989898A1A4ADABABB4B4B8BBBFC1C5C5C5C5C9CAC6CACAC7C8CACBC8CCCB
CCCCCECBB79A786241302E31322D2A26242628242A353A43555B4958755A47514D5D4C57
4B4E5644565C51524443454644364D8AB6A1959496837E817E868F838184858C8A88827C
7E7D81777877797A757375716C69686A6C6966676261675E676A6A696B6F74686C696969
6E6E706B6F706A6D6F6F6D6767676B81A3B9C4CECFD4D1D2CECEC8CECCCCD0D0D0D0D2D1
D2D1D0D0D1CFD1D0CCC8C1BBB7B0AB947C64514135382F2B2A2B313A39393C40464C5053
5557575351535959
5F5F525147454B413D3E32383538362F312F3443453D483F39403A47525C6C777E858E94
9CA0A5A7AFABABABA9A7A8ABABADABACAEAFADA9A9A4A09BB5CFCCA076554640384D4849
374166A7A455332825292824222434485B584E3E2C2B35453D2E3535393643786C554941
3E4C4038373E3539477184867E65525A838F84787B787A7E78819A9CA6925D49524F4F55
776F58615B6A80928057423E5E917576A19077765758A6AC82493C2C2C3236363C3A404A
5345332B272A2A2A3A4C5C3E352F2E333A34323332342C34393C34322F35383636332E34
393431363C3C3B3A393B393B3B353439392F3334454852595C6469756F777C7C7F7A7E7D
7B7D7F797B7C7D7F7F8384858487878A878C8B898B8B8C8E8E9394919193898B90908C8D
8F91918F8E92969897A0A5ABACABB1B1BABBBEC3C2C5C5C7C9C7C5CAC9C8CCCACBCACBCC
CAC3B29C7A5E3F3431312A30352B262A322A2A273333363E51594B5F775B464C4C585054
4A4A5245525E535047424F5A4B374A86B6A3959793857F7A82808B858483868B85817F7A
7F7E7B787B7471727267696E6C67696B6D646B6B676A69666D6B7271707777737270746E
7472737876747378786F6F6C6D70737BA4BBC8CDCFD5D2D1CFCBCECDCECBCECFCFD2D1D2
D3D0CFD1D2D2D1CDCDC5C4BEB9B5AFA5968571604935262B262C2E30373F3D3F4148494D
5257554E58505B5C
4B4B43483E3E433D3C373B353637352D322F3137434443424340434C5D64707E81898E95
9BA2A5A8AAAEACA8ABACADA4ABACAFAAAEB0ABA9A3A1A0989CACCBC9A36A4E433D525D4A
3F354385A96F32292E2E2D28282C344B66584D383332364949333838393A406E6A4F3E3B
353937303649444B6980818A745861808D8E755453545655617086919F9D84564D434868
6E56535C657B89896D4749466360527398997777799DB28F502E2D2F3731363F3E44434B
584E3C39332A2D2D384657403F342E383C36302D312C36363A3F32312E32393435353734
332F313839403C3A37393C3F3A36363B3531393D4950545A5760697472767B7A7F807D80
817B7C807F7F8280838583838A838B888B8D8B8B87878C91909493939494908D8F938C90
8F908D8F909394949A9CA2A8ADAEB0B2B9B9BDC0C4C5C5C6C7C7CAC7CBC9C9CCCCC9CAC2
AE94775F473E3633343331353C312B303326302C323B3D415A56576471594A594F5E4F55
474C4F49555F544D454455554E3B497FB5A79398948780737C7A8B828183868178777D79
7A747474736F6D7270696E6B69686C6A6C6A6B6E686D69696D7270737273757179747A7B
7D75787C7B7B787C75747874726E7381A2B9C8CDD2D4D4D3D0CDCFCECBCCCED1D0D1CFD4
D1D0D1D2D1D0D1CECBC6C4BFBDB8B3B0A69E8E806655372F2A29272F2D353C3B3B424C50
4F5559595A4D5254
40403F464942413A3935333532322E262A272D373B404A4A46414B4B596A767C838B8E95
9BA0A3A8ABAAACAFADAAAAABAAAEA9AFAEAEA9A9A6A09F969192A0BBCDAE6B4736405056
4A3230579B77352825272925212739545C59494445383D3F453E2F38383A43765D403D3C
2C3A35313C455567837F8380666B858D86774D292C333B5B586E7F8291A1A071414E6167
555863637582837151636C5E4D354B69869F8583A0A49967312B2D2C2C2E36394B42464C
61503C3531292C353840543738372F3C3735352F303135323A39393530303832373B3D37
382F333A3E3E41443938373832353E363032353C4D535653555F676F777A7A83827B8280
80787B7F7F7C828088878483888288878B87898B888E8D9090909395989194929192918D
919290948F90919399A0A0A6ADAEADB4B8B9C1C3C4C7C6C5C4C7C5CACDCBCED0CCBDAC92
7357453D3C393536363939373A38333335353B3235383D465A585A6F735F4B54505B545E
4551544D4E605B4C4B4E514F53424974B1A9939B968A81787E75867E7D80817B75757B78
71737373736C7070706F726E6E696D6B6D696F6C6E756F72777B787879787D7B79797D82
818183837F817E7C7B7C7B777275737FA3B9C6CED1D8D7D5D3D0CECCCDCDCECFCFD1D2D3
D0D0CFD2D1D1D1D0CAC9C6C2BFBDBCB8B1AD9E9377674B3B2E2D272F2F2E3237393C3E42
4B4D554C534E4A49
39393F413D42363835322F3033322F2727262E39384349505045495360727F85898C9197
9EA2A5A7ACABB0AAABACAAAFAFADAEB0B1B3AFB0A69E9A979385899CBDD3BE7C4A3B4653
413631376E844A33282A2E272F283F605B5446483D343A404732383A3A394C6D4E313944
36372E31364F6681837E826B6E8B8F8C75563A342A2D384C60818A76809A9E8B575D6958
546F6C6F7E86705D5F8078593835497F8BA197A2A6916B3C2E3134333430363C3D42464E
5A523E332F2E332D4047523834332E32353A2C3031323538372D2F303433312B2F323434
3635363A3E41403A3B3B4038313834363933363E4A515551575C60717476787A80808283
7D827E7C7E807F8180848586878684888985878B8C8E8D9091959492969294968F939692
919391919196959597A4A1A0A9AAAFB2B5BCC0C3C3C6C3C8C8CAC8CACDCDC6BFA68C7656
4A3E403B35383B3637363D3A362F322D34313D353B373E5450535A677257485151585563
4F55524D515F5D4A505254484D3E456FAAAD929999907E7A7A757F747A827F7972717472
6F6F777571736F7074706F726E6D70717374747676797F797B80807E80837E8588828784
82858684848484807C7B797773767481A3BCCAD1D3D6D6D6D4D1CECECFCECED0CECCD1D1
D1D1D1D1D1D1D1CEC9CDCAC5C3C4BFBEB7B1A99F8F7A614A40312C2E2A2B2F2D33353D3E
454D555255514F49
37373637374045333C31352C2E262B262928383B3D42484C4A4D475061738086888E959B
9CA5A8A9ABABACACAEAAADAEABACB2AEB2AEAFA9A7A299928A89827D9ABCDAD0994E4054
5146433951755732282A2D2328303B636057493D39393F4D533E37393C335A563A333035
2F37352F3E6C82887982716288948D815B48463F2B292C3B50777E656E919B99716B5551
5F717E7F9898786983825D4A3B4156A9ACB3AF9E97753F2C302F322E342E37343A44444F
565240373629322A3B565F322E3031343532373133393A39322E2E302E32313236303331
35393938393D35323339453B35392D30352E2E41464A52515560666A7072777D8283807E
81857B79808182848583868786858A848888888E8E8D8E939595989495999B989B969599
9693969395949698989D9FA1A8AAAEB4B3B9C1C1C1C5C7C7C8C6C6C8C4B7A1886A4B3D3A
333A363A34352E36333937342E332F282A2E312C342F3453404F586972524C5455574E64
47544D474F5A5D494A4D50414848406FA2B19799A0927E7A73697A6E7B796F66716E7274
6F6D76726F72717373737578707376757474767B7B7B827E817E8483858888888987898A
85858C8684847E807F7D7A757470747E9CB5C7CFD3D5D8D9D7D5D1CDCFD0CFCFD0D0D2D3
D0D1D0D1D1D0CFCFCBCCCCCBC8C9C1C1B9B2ACA29486735C4537303127242629292E323A
3C45484C504B5049
39393436373A3B352E2F30292B2B282A2B29333D44464B524F4C4A5262757F878A909499
9DA1A7ABABAFAEAEADAEAEAEAEAAAEABAEB0AEACA8A29B908A8576747191B1D9D5974D44
76664A3C4C86664A352B37292B26436757454A3D3A3F3B4A524738323534524E33302931
31302F2F42708D80777F687E988F7E684B4F523C302F3739456966566A8C919E83625659
4D768397A998908A7661482C2F547AAEB5BCAF936D3D2B282B2F303030303732353A4A48
4C57473330282926385354352D30323133352C30343C36362F31363431372C3232373032
3B393A363A433B3238483C36373433303131354A49514D4E50575D676B7271767E7E7E80
83847F80818283858885878688878688848C8B8F8C8A8E8F909B989597999B999A9A9997
9B9D99989C979B9B9B9A9BA7A7A8ABB0B5BBBDC3C4C2C6C9C9C2BCAF967F6B4D37313C35
3434373536323333303834342F3A3129343546392F3038463F4B596B6D5452546061515C
4F4C524D4C5D5F484552503F4A3D3F6B9BB198969F967A7F6E6A74767D7165726D6F6D72
7372707275767673717675777374777E7B7F7B7B817F8784898B898B898B8A8D898B8A89
88898A888782867F7D7B7979796F767D9EB5C5D1D5D8D8DAD7D5D1D0CED1D0D1D2D0D2D1
D6D1D1D2D0D1CDCED0CECDCECBC7C5C5BBB6AEA59F93816F5642342D2F27262826293131
323640474E504B49
32323B3E373334392F2D2A282B26282D2C29343F44494E56504C4D57687980868B909A99
9FA1A6ADAAB0ADAFAEADACAEABABADAEAFB1B1B0A5A49C938D83766E646C87ADD2DB9C49
5958423F5DB28B4B403741322730465D5A4B463F4242433A434F3732343A4045342A3137
2E3433293968917A777970909879604A4C594F3D39333E4755655B4B526F8AA49A80614A
557C989DA490897646403E353F74A3B4A0A59372442B28292C312D2F2D313332373E4B48
4F5746312D26262E334A503332332D312E2D2F36343835382D31313030312D2C32353332
3339373A3C39373540423839343332313131344A4547525A575258666B6B6E6F78767A7D
8380838382858785918E8B8B8A878C8A888A8D8D8A8B8D8C8D979798999B9F989B969996
969D9C9D9CA19E9DA2A6A0A4A9ACADB7B6BBBDC1C4C6C1B6AF9C8B715A44403739343737
32373D37353633343C373D3E3234352A273338332F33493D3B4E58716D52535057635159
4D515355525E624D4A4A5148473D44659EB29C8FA499817F736579767369696D706D6D71
717A79737977797A71777B7B7A7C7F7B82818487848C8A898E908C928D8D8C8E8C8D8F8A
888D888E87847F7E7E7B7B77786E727B93B3C1CCD4D7D9D9DAD8D1D1D0D1D1D4D1D0CFD1
D6D1D1CFCFCECFCFCFCFCECCCDCAC7C3BFBBB0ACA89B8C7762503A2F2D2B312E2C293A25
2B2B323D46454245
2F2F3631343533323431292B2A2C2A2B2A2D343D474E5A565A544F5763727C848E90969C
9EA3A7A7AFAAACAFAEABAAB0B0ACABAEB1ADAFAEA6A49C989284796D61585E80ADD4DD99
51473E3E4E929F46322B2B262A334B61524240393B4145403945493933323938352B2A2F
2A322B292E5D927B877582A090684A4854504A3B3839485E797A6744435D749A97825948
6791919F9C867D6035444D536E9BA8A28D82644029282B252D2F282E35352B2E313C5147
45574E372B25292A333D453A2F302D36303232333434312F2933313632302D3338362F30
33393D3B3D3536333B373A3D3C3A362E30313D4441444E4F5459505D64656E6D73737977
82838584838986868C939190898C8A878A8B92918A8F90948F989C9A9E9B9FA09B9E9F9C
9DA2A0A6A2A4A6A5A7ACABA6A8AEB0B3B7B7BCB9B6B09D86726350453B34393E3F353238
3B3635353A3A35373B3D413637353530313938352F374A393A535C6C6D525350576A5654
4C4B4D5B565C5A483D4649464B463A6499B5A98BA19D868073667B766C686D7173717478
757C7A757C7881817B7E828385838283898787878A95929692928F958F908F8F8E8D8A8A
8988878A868681807E7F7B7A767275768FAEC2CBD4D7D7DADAD9D4D3D1D1D2D0D3D0D0D0
D4D1D2D0D0D0D0D0CFCDCFCED0CCCAC7C3BDB9B2B1A39A88705E4839302C2429292B2A2A
273131303C3B3C3E
2F2F2E2F31302C30282929292C2A2A26272F3340494B575D5D575E5E68757E858E8E979B
A1A4A6A8AEADB0B2ABA9ABB1ADAEB0B3B0ADACAFA79D9F9B9087796D5C54495679A4CAD5
9F524D4B47839963352D2826273A4B5F5843323136464438373C49403C2934362F2A2D30
2B2F28262D599684867D949B8A705058554E4536364359758B9479434255688181664F61
8D9E949E927E77524662718694ADA28B71543D352F2B292C2D2E3334313231363241514D
46574D3831272A2730464A363633343134302D3338393C342C363336362F2B3534333236
373A3B413C413E39403F383C3C3B39363640474B51535147444B4A52565C6E6D6B6B6D6D
7479817D7E88868686928D888688858A86878C86869293959096A4A49B9CA2A29FA0A39E
A3A6A8A8A8A9A9B1ADB0ADAAAAA29EA3A1A4A5A09583704A403E3B373537373C423A3C3C
3937363B39373539394140343740352E2D3A2F362C3547353B4E5D717156525C57625159
50544D5955545741414D4A4A404C3C6094B7AE8E9F9D8C86786E7E73706C6E7173767C7E
7C7C7B7C7C808B82817F8385898A888F8B8A8B8F8E94939697929394908F918F908F8B8B
8E87878784838482817C7A777373747285A5BCC9D0D7DADBDCDAD7D5D2D2D2D3D4D0D2CF
D3D3D1D0D1D2D1D0D1D1CED0D2CECDCBC8C3BFBBB7B0A79F8B78624F3D32352D2B282624
28232A3432363735
30302D2C2F3E333030292C2C312829272A2E313F464C586360585B646C7B80868992989E
9DA3A6ACADB0B0AEADABADAFAEAFADB2B2B5B2ADA9A09F998F877A726154453D4C769CBB
D4A15B665B89A66632272B2E2F3F534E5A4134353C493F3F3940474830333136342A2F35
2A342B2E355C9B8F848D998E7A64616F5F4C43393B5F6887849273513E576C71696C7083
9496A39A8B838A797A96ADA09CA69D70473C353734363334333532333332313636435254
4454523731332C2D2D3F4C3C32312E37342E2E333A37362C312F3138352B2E343439323A
3C3E3D3E3E3938393E3B3B4041352E36363C47434E58584A4140423E4649575E605C6066
64626B6D6E72737975787975777879798386837A7D8A8D8C8B8A9A9B9997A09D9D9EA29F
A5A9A8A6A4A2A3A3A0A7A49C968D8C85898689897E6B6041322F303633393B3842383F43
333A37413B382D373B504A393A3A3B30343E38322D364437414F5E73674D575E5A605655
48544F515259574B3B4C49533D4735598DB3B0929F9F93867B717E726E737071747D817F
7F818383858B85858782878A888E8D938F8C938D929298959790908C928E938F8C8E8C8B
8A88868A8787858380807D7B767375747FA0B5C6CFD3D9DDDBDADAD8D4D4D3D2D2D3D4D1
D4D2D2D4D1D2D0D1D0D2D0D2D0D1CDCECCC8C4C2C1BCB6AEA19987755F4940372D2E352F
2327262F2E312F33
2F2F302C2D2D31302C2F2A2D2F2A352A29323F4042545E5F5F5C5A64747A83898B94969F
9F9FA5ACACABAEACADACACAFADB0B0B1B6B4B1AEA6A29F9A928B7F7065594339414A6C91
AEC88D5E6573A077302D2A2931465155473C3A3C423A3C39333846493C2D2E3F362B2E32
2E33292429639F938B94987D594F516260514138415D7486718A6C514E6584705B6C8086
8E8DA59A908B8C8598ABAB9B989A874C35362E2F2E30313638303539393237343342494A
45504E39312A282A2E3F583C3133303C333130373A39362D323434342F35332F35333137
383C3F43413942473D473F444039353C354A4A4551594A42463A3C3C383E3F413A404045
44484E525E5C5A606062675D666D72787974777F7F82828585868A93948E929696949C9E
A2A6A1A1A197969692989991928B87818682828A7F695C40393334383535363B37383735
39323F37353A3A36384D3E33373A372E2D34342E2F38413F3E535C716D51545754625358
4D564A5950585E4741454B52434D34558EB2B0949CA39493877C7F71707778797A83877D
848884868A87898E8F8A8D8C9395929190939295929896949293959292959292908B8A8D
8E8986858581848981797A7B777573767995B3C3CDD2D6DCDDDCDAD7D5D5D3D4D3D2D4D4
D5D2D3D3D3D3D3D4D1D2D3D3D1D2CFD0CFCBC9C9C7C5BEB8B1A8A09987735F4B3C342B29
242729292A2A2A2D
29292C2930342E312D2E2B2B2C282A332C33343C455760635F635E6B7480818A8F969A9F
A2A3A6A9ACB0ACABABACACB2B2B1B3B3B1B4B1ACA7A5A39A938A80786B5D493936354761
849E9E5F5F59827331322A2F394C5F5E4B3D4147413C3D403E37394B423C383934292C36
2D382C2E2D7EA58E83928C604940405A584D4441505C7A73787D65555B789476536E7B87
868A9FA0929485858D988E808D8B653F2E292B292B2C2F2F31343239393433333542444A
464E51332B272A28353F533B332E2E2F2F31363A3C37302E2E2E35312B2B303436363438
383E3D3B3E3940484541424241343C3E3E4D49474E4D473D3D3A3E443C3940403D384239
3A3E3C434A4A514F5B59605E63666A7A7A76798183888B8A8E8C8F9A98909392969CA0A3
A2A3A2A5A09B98989598979A99948E8B8E8C828A876F594733332D37312E35373C343437
3B3B3B3A3B3B36393B51443537393939343A362D323B3B42445460726F525D5E4F615154
46524F5B4F5D5F4A424A564E3E3D31598EB0AF959AA5959288807D7877787D8284858388
878A8C8D8F94928F90959295979393969597949A9594939494948F9093918E908E8F8C92
908F898A87838389877F827B787771757C8FAFC0CBD3D7DCDDDDDBDAD8D7D6D5D1D3D5D5
D6D1D4D3D3D3D3D3D4D4D0D2D1D1CFCFD1CFCFCCCBC8C5C1BEBBB5B1A69B887F664A3A34
2C2B2B2B2E2E2B2B
2D2D2C362F2F31323633302C2A2B34373131393D4C555F6163696B707A82808C8C969A9C
9FA5A6AAACAFADADAEAEABB0B2AFB0B1B0B3B0ADADA8A59A928F8278695A514436374149
6576826257465865322D2B2B4350606C4C3D4C4E3E323941463B3E41553E394532292B38
363B24213079A489788A8357403840514D474541566B79687F715B5D6585998572707B7F
7A8C979BA3A576737A887771816F423232302E3032363C34343533333831313637383845
424E4E382F31312E333F4B3E3438323633313A34383934303333372F2A2F322C38333638
3D3A3B3836363D3F413A443F3934393941534A4849463D3D353C2D342B34383A3D3A4145
4647454441464D545A5E5E6670737871797B79838583878C8D909398969997909C9FA2A6
A6A4A4A7A29F979B9B9A9B9B9E9693908C8D8988877661412B2C2E2F3939323638393633
37333B383837313A364B40343334373A34362F333835403D40556172664F57554C624D5B
4A4E5560525C5A49384D5C483C3C2E5790B0AC9A9A9F9C9B8D868780808384878B8A8D93
8C8B8E928F94918E948F9797949597939C9A91979797949593929494959292928F8F8E8C
8A8C8B888C87868B87847E7F7B7576757786A5BBC9D1D6D9DEDDDEDAD7D9D6D5D2D3D4D3
D5D3D5D5D6D4D5D4D5D4D5D3D3D4D0D0D0D0CECECECECBC8C5C3C1BDB9B3A9A390806B56
41333331302E2B2B
38302E2D2C2D2D2E2F2E2D262C2B3035353739434B595F6066686F7481827F8A8D949799
9EA3A8A7B0AEADACAAB0AFB1AFB2B5B3B3B0B2ADACA4A69C9691837B6C594E443F434044
4C637C7253413839382C2D354349486852425746353039423A40434047434642332A2938
3532272D3F82A286778A7E5B3D38445D4E4A52575C786D5D7F6E5C6C859A959A997A7972
798B969FB5A25D464D6B6E6B795A39333330373032333236323136323836333938393D42
4348514137383031383A493F372F33353E333A393C3B333335323738373532353A3B3B3E
3C424138393538393D3A3F393938333C4A4647474B3633332F2F332F2C34363E3F4E4949
4C5C565D585B606B707670747B7673807F808385858B918B919494969C9897989CA8A4A8
A6A7AAA8A3A19F9F9FA0A39B9FA19893908E8D8C8A7C6A552F2C2A34403B3D403A363C3D
35393C3539403B36405449393A343B4833373C33352D313C3E54626F674A585552624E5A
4C4A51615156544A3F535C473F3B315088ACAA9E9B999E9B928A87838289888C918C9191
8F918F9290949B939692989895969693989395949694959598919591918F90918D8E8C8A
8889898C88848B8787877F7E7D7A777374809EB8C5CFD7DADDDEDBDBD9D8D8D5D4D4D2D5
D5D5D5D3D2D4D6D3D6D6D6D6D3D3D3D3D1CED0CECFCECDCECBCAC7C6C4BFBAB4A7A19482
73604C4239333130
343433322F31312E2C2C2C2D2D36373034323C4B51575D6463646D79808681878C91979A
9EA4A9AAABAFAFAEACADACB2B0AFB1B6B3B4B3B2AFA6A39D978D89796C5A51403B3C4543
4455697D60443C34302D32314338386769525E4230323E3D45493A314A484243322F2F38
342E29284B889884788B744D392E4E534B51665C617A59637C787B8A9597878690896F72
858E8C99A583514247565C545D4F3F3536343C33353036383B373936373132333B383E44
43464D4032332C2A2D37453E2F2F32343A35353339332F302F373333302E32373C3B3638
3C3D433A34393C3D3C3C453938323C4952464C4D3F3E383435342E2F333D373F4E505759
626466636B7072797C7E7C81848482868B8A898F8D919392939298969B9C9D9AA5A7A6A8
A4A8ABADA5A1A4A3A5A7A59E9F9D999A9293918F8A7D6E582D2C303442393534393B3C36
3A393C3838393A3136464E3C38353941302F323A3939373545556471675058574C664953
4B4E4F5B5255574E3F4F60493C382E4683B0AB9F9E99A09C8E8E908C8B8C909292929594
9395939798949799939095979594979796939395919296979395949094938F8C918F8B8B
898C8C8B89898988878480817D797875767B92B2C6D0D4DADDDCDEDDDAD9D7D5D2D2D2D3
D6D5D6D4D5D3D5D5D6D7D7D6D4D6D4D3D2D1D1CECDCFCECECDCDCCCBCAC7C3BFB6B3AFA6
988D827363523D3B
33332D2F363435353230312F31312E2C3236434C555A616063687276818486878991969D
9EA3A7AAAEAEAFAFAEAEB0B0B1B2B2B2B3B3ADB2ABA89F9E968C857B6E5A4F473C40424D
4E585D72784F3B32313438333C2D315A7D5E64493033393C474231314452414532263037
2F2C213C5D80907A7F856A3931364647415E6B57706D6A707883888F898B726A727A737D
868B8B9A865C54574C5F6B5A413C463C353F38353332302F34353232302C30302E383B41
3A40433C352F2D2C34344740302D3233372D333B392F2C3132382D2E3331373F3D383237
3B39333330373D443C3C463E393438404C45504B3B33302D2A292930373F4046514F5B63
6A6F7571757674767D7E7D858484828B8A8F8E93929493979397949A9C9D9FA4A4A9A6A9
ACACB1A8ABA8A5A5A8A8A6A6A1A49B9D929193968C826E522D282B2F3F393333383C3D37
3A373936353A37383D405241312E3838343038393035303C484F687465504E514E6A4950
4A4A4C594E4E5849334B5A4434362D4284ABACA09D9CA3A49493969392949597989A9895
989899949694979B939799959A939696979494959899989793929690918F8F93928D8E8C
8D8A8D888C8A89898483827E7D7D7675757B90AEC2CDD5D8DDDEDDDEDAD9D7D5D3D2D1D2
D5D3D4D5D3D6D6D6D6D8D8D6D4D5D4D5D1D0D1D0CECECECECED0CACCCBCAC8C4C2BFBEB8
B6ADA89D91817161
31312C2C2F373532323430322E2E2D313F3A4A4E525F5D61636466717B84878C8E8E939B
9EA2A9ABACAEB3AEB0B1B1B1B2B0B2B2B2B6B2AFA9A6A19F978B837B6B5C4F4C4444464C
51596065796B39353635393B362C344E806E64412A353A41443A312D39554742332A313E
2E2E293C668397747B8658363239463F3F5A5D5B6B6C807E797F808C8782726C70728076
8A968F92694D6E6B57737A5137374348383534392F2C36383A393B35332F33302F343540
3B3C40402F312A2E3A38483D353233343531424238392F2D32312E2F3430393B3E3C303A
433433333B3F3B383540463C3930354A434845422F31312D2B35353D3E45515355575D6B
6D71787A7A7B7C7E82808687868B89888A8F95918D929097969896979BA7A5A4A1A5A8A6
A8ACACAAAAA5A6A8ABA9ABAAA9A59C9D919292978A8470522C252B32454031353632393B
3A3635343638393A3B424C38343231373831373234392E3B3F4D687568474A504D6F444D
464151574F464D4B37465847343C2C4589ADAEA3A29C9FA7918E929797999A969B9F9C9A
9C989796939596979A9897989797999496939398999393969697939591908F8F8E8A8E8C
888888888C88888786837F7F7C7C7774757887A5C0CDD3D9E0DEDEE0DAD9D7D6D4D3D2D2
D5D3D4D4D5D5D6D7D8D7D8D9D6D5D5D4D5D1D0CFD0CECCCECDCFCFCACCCAC9C7C7C5C5C3
C0BDBAB4B3A89F8E
30302E3235363936302A2B2E3239313741415151595D605F6062636F798189878891939A
9BA4A8AAACB1ADAFAFAEAEB1B5B0AFB3B4B3B3ACA8A1A39F968D8378715C4F454141484E
51596A63747658363837363B3938314E827357322F3B303E383131303C4E4E432F2D3141
332B3D4E608C9B656F7850302F423F364052546D748A84766F6C7F8A8E84756F6C818C77
8896908D5A5971664C68734B37393A4B483C343533313535423B34312D36313634343B43
4040423F342E302E3436493D2D3232343731393B322C2E2E30302E323B39363A3C343138
3834393539483B333644404439333B4A424B3D332E2C302D30383F414B4B54525A61656A
7472787C797D7F8281838986878C8B918E8D9491918F9397929B999A9EABA9A7A5A6A7A7
A6AEA6A4A8A6A4A9A8B0A8B3ADA8A09C9690979B939178542F2D29354141353338363A38
36333935353636384237503634322F313A393B2B31342D3B394B6674684352544F6F4A53
524454524C4A4E44335758463A452C4781AFB1A69E9F9DA8948C949598989C999A9F9D9C
9E969B99919291979896999797929596959494929397949299949595989492928F8D908F
8F8C8A8E89888D8A878885817D7A7972747C86A3BBCBD4D9DFDDE1DEDAD9D8D6D3D1D4D0
D3D5D2D4D6D7D4D5D6D7D7D8D6D5D6D6D4D2D0D0D3D1CECDCDCECECDCCCCCACCCBCACBCB
CAC7C6BFBDBDB5AD
2F2F2E2D313932332D2E2D2E2C33352C36445555575C605F5F60666F7A7D8488898C959B
9BA3AAA9AFB3B2B0B0B0AFACB0B0B0B3B5B4B1B2ABA7A39B938E8581705F544947454851
545A61636065564B493C3C4645342F487880512F333F3D3E352D3033405A55442C33363F
372D3B515B7F995662654639323837334A556C858B898C886A70808282786964649A947D
777C9098836E5E4D48795D4256513A406B46323333383533413A333230313736372F3941
3D3C3D3A3D2C2E2C31383E3A303338352E323E37332E322E363234353B3A34433B373738
373839363B3B3B363A43404236353C4D4A4C4131352E2D2F32374249515857585B5D686F
7675777B7E858183848787878B8C888D90919091909593989C999DA1A7ABAEA7A7ABA6A6
A8AAA6A7A7A6A5A5A8AFADB3B0A9A39E9C8E92969992845933292D2B374B373334323934
36333230363E33383F3E493834322A31353F382B3032353736445B7A69524F534D734D4D
4D415258495256462F4A573C38402A4183ACB1AAA29BA3A48F8E95929C9EA09B9F9D9E9D
9E9A9B9699979496989798989B949995999695969597999498939598949495938F908E8C
8C8C8B898D8C8B8B8389847B867F7B7576737F9CBAC9D2D9DBDDDEDDDBDAD7D8D4D4D4D2
D2D2D3D3D3D4D5D5D5D7D7D7D6D6D7D8D5D3D3D2D1D0CFCECBCED1CFCDCDCBCCCBCECBCC
CACACBC9C7C3C2BE
2F2F32332E35372F332E2E323230302F344B59595C6468666561646B7A8186898D8D9398
9CA3A6ABB0B1B3B0B1B2B0B1B2B1B0AFB0B1B3ABA8A4A29F928D817C715C544A4040494F
505A646A655C5C6949383851493930446D7E50342F373A3C3C2C32293D635743322C3B42
34344454577992536966412F383B3C435477867F8595948572817C7976685D4F6AA5936E
6877969F7F53454C50866B51A5A74439505C38333036303637363536343231352F2D3C3F
403A3A3938342E2B33393A42302E292E32383D352D2F2E2D343030303538383C32363A38
343837393B38383A3B3F4041313945474F4739322D31343A44494C50585C5B645F6B6D74
777C7C807D7D7E85878489878687928D9393939492959B9A9B9E9DA2AAA7AAA9A8A5A4A2
A6A9A9A9A8A4A5A6ABACA8ACACAAA49C9D8E949798948B6C3726272F334F3F2E2D2C3330
33343030323935393F413E3D40342D30354B372F392E3036374D627D6B4F4E4B4A714A56
4F40514F4E4D53413349593E31372C3E88A9ADA79E9A9EA191909597989DA39AA29B9C99
9A999B92979C979A9898969396939498959594969799999994919592939194948F8B8E92
908A8E8D8C8B878A8B82857E807E7B747375809AB8CAD0D7DBDDDEDCDADCD9D8D5D2D5D3
D4D4D3D4D3D5D6D5D6D7D5D7D6D7D6D7D5D4D4D2D4D0D2CECFCDCDCDCDCECECDCFCECCCF
CFCCCDCDCDC9C7C8
30302F2F2C2E2C3130322D2F352E312E3341565A65716C6A6865616A757F87858B8D9499
9DA7A5A9B0AFAEB1AFADB2B0AEB6AFB3B4B5B3ACAAA89F9E978B82796E5D504942404554
545A67746A5F696F55373744523E374A60725D382E4137353526262E406454402D27303A
373F4C504F6E9B576D6E47364143465D7B847B6E85877F7C788177756B56485275A28963
60808DA16D2E3B605B7D7C86C4BE5532365B41312C3235343835353A312E383830373760
413E3B3B372F28253137383D33322F30333F3533312E30353330323B353B3F373C3B4133
333B3432433D3A36434140372E37464F4C40352E34373A44454D565A615E5F64676B7072
757D7E807C8480868386848B8C8A8F8C929591938F919897969EA1A4A8A6A7A4A3A4A2A2
A5A6A9A7A3A6A1A2AAAAA5A8A6A3A69D9E9090969B96918440282B2B3252442D302F313A
3634302D353A343C47393A3A41372A3136563D2B342F353B374B5D796B465B4C4C6E4E55
4A424D49454A4F42354E583D2F3131468DA6B0A4A09CA1A18C919A96959B9E9F9E9A9F9E
9C9C9C969393989896989897959A92969595969997949797979799949497929490908E8C
8D8A8C898D8A8688818788837F827C7873747E92B6C5CED4DADBE0DDD8DCDAD8D6D4D3D2
D4D2D4D3D6D3D4D3D6D7D6D8D5D6D8D6D6D5D4D3D1D3D1D0D2CFD0CFCFCFCECFCFCFCFCE
CECDCFCECECCCDCA
2D2D2E322E313033352F303030313A343641505B676D6B6A69606771788483858C8E9799
9CA1A3A9AEB2AFAFAEAEB1B0B1B1B1AFB4B2B3AEA7A3A29A958B82776A61554C42434C4E
5659616E6B5B636C5E4A45474B4D484C5B5F564034413A313227232D42645B4532303634
373F474A4F78A15B676E5A4C5D6872817C6E78798A777E827F76706B5C4C4A4D76987E61
658885946C2E446E5E73859ABBC35B2F2E3F43312E2B2C2E312F30353430352E312F3548
48403437362C2B2B2F36393B342D3135303B32322D33333233313A3937323934363B4038
353831353F3D383C3C3C3B373542474E4C3A3433383E46554B52556162625E686D6D7074
767B8286868783888185858D8A898A8C8F92908F8B939595939D9D9FA4A3A19C9C9FA0A1
A7AAAEB1AAA8A1A8A9B0A5A7A5A3A3A29D9595929A97928B6033312C2D4C50313129302E
2E31342B343D353D4539323541412E2F38464427312D2F39384A5F7869464E4F4A6C5157
494047434C4C534531504F3F3334334D8BA1ACA0A198A5A0868F9196969AA0A19A9D9F9C
9A979C9E95989999969696949696959692979A9A9897989B969C9A959596929390948E8D
8B8D8C8F8C8C858988868782817D817873747A92B2C4CFD6DADEDEDCDADCDBD8D7D6D6D4
D4D4D4D2D3D3D3D2D4D5D5D7D6D8D7D7D5D6D5D3D3D4D3D4CFD0D0D0D2D2D0D0CFCECFD0
D0CDD0CECFCCCDCC
2D2D3131322E2D353A33382F31333330363C4E5A66646866645E65727A8284858C8D989A
9CA0A6ACAFB1AFADB1AEAFB3B2B1B1B3B3B5B4ADA8A7A699958E8479705E554C423E474D
545D686E6C65636C6448494F45585D5F5F60563B353E342E2927282F49645B412B2B2E34
3C41413D4180AA605F6454666F7A79706A6F8F8B7E6D797E6E6A6D5E4E4A4D5289907E70
68877E896635507E676D7B8FBAC77A3434323D34303333343934322D32332E362D2A373C
4237354236302F2A31373C3F2E303330383E302C2C3231313038373938373A3A453C3733
30312F393D3F364139453732303A474F4539333742464F59595C5E6265676A6C6C73737F
7C8182878381828686878A888D8A8C8D8C928F8C8C91959293999B9D9F9E9A9E9C9E9FA5
A8A7AAA9AAADA7ACA9A5A0A4A4A8A39F9F9896979699928D712E262A293E4D342D293029
2D342C2F313C373B403B3C3E3D3B31303B41473E2E2D33332F455C71654550524E695459
4D4045444C4B5B4D334D423F373C2E528AA7ACA1A397A4A38F8D93999899A29F9F9D9F9D
969C9C9C999A9D9C9D98999998989B989996989B99959697929597989399969492908E8D
8D918D8B8B8E8D8B848A8A827F7E797A77717A8AAAC0CED3D8DADBDBDADCDBDAD9D6D7D6
D9D3D4D4D5D4D3D2D3D5D5D5D6D8D5D5D6D5D5D4D4D4D5D3D2D2D3D2D0D2D1CED1CFCDD0
D0CFCECED2CCCBCC
303030342C302E31333134343435333134435261656668676761676E7982828A8C909497
9C9FA8AAACB0B0B2B4B1B0B0AEB2B2B5B3B4AFADA9A4A198958B897A6B61584C4540434B
505D6F78726867695646414E444E64615958633E3C342D2D2A282C2D456361463329303D
403E3737418AA7686468567278717161698599847570796C63655B5750494C568B7E8173
70808185673C557D63637CA7C5CFA04837333932342E3333343636373A323536343A3037
3F363741393435293036373E2F36313639382F2C2E302E31373D393935383844433B3731
3130373A42423B3B41463632333D494E433D3C414A5157595A5E62666B6A6A7272767A7A
7E857F8582848784898A8C888A89898D8A8E8F8E8F90929494989C9D9C9A969597989EA9
A4A5A6AAACACAEABAEA29EA29E9CA29B9A98959392979591844325262D3749352E2B312B
2F3332312F36363A3A473D3B404B343234333F3037313635313F617361494F504D694E55
4E484446504C594D3E4B3A3B3A372D498CA9AFA4A097A5A291899B9B9797A19EA09A9D9D
999A9C9E9B99969C9C9A979697999B9497969696999A989993919493989796948F919590
908F90878E8E8B8C8B8A8980827E7B7976707688A7BEC7D2D8DBDBDAD7D9DADBD8D8D6D5
D4D5D5D5D5D3D4D2D4D5D4D5D6D4D4D4D4D3D6D4D4D5D5D4D6D3D2D3D1CECFCFD0D0CECF
D0CDD0CFCFCCCECD
3131322E2D343337353033312F3033323540505F666666636763686B79827F868C928E94
9BA3A7ADADADAFB0B2B1B0AEB1B3B3B1B5B3AFACA5A7A297978F83796E64594E4846434D
54667880796D696F5A4D4E46424A5E6A584F5E3E3536342A2926292A40585C472B2E3244
3E383233478AA56C6D7563746678785C759A92826A707969665F4E4F58545661847A8360
63637486693367836276A5CFDACFD1A1523531332E31333535353B3D3D3236302C353439
3B3B393D36312E2A30333F38323536373D343033312E2D323B3B38363440393F483A3634
3030323B3F3D3C3B4A483833324343473C44455256535E64626369696D6C716F70787B7F
7D807F84828789848989878A8B8A8C8B8D8E8E8E8B908B929192979A9595909892999A9F
A1ADA5A5A7ABAAAAA1A1A1A09B999F9A999A9893919296918C652B2728334737342C2C2E
2D2D312F2D2D323C373D433441483B39303238322F2E362E2F4061796146495049664C4A
4B4A44444D445756424738343B3F324B83A0B1A4A697A6A39687939A9D9AA09D9F9D9C9C
9C9D9E9B9B99999D9D99999697979996949998999A9B999B96969498989593928F8F9090
8C8C8F8E8C8E8A8D8A878681807D787579767288A3B8C8CFD7DBDDDBDBDADADADAD6D6D6
D5D7D5D6D6D6D3D3D3D3D4D4D3D3D4D3D7D2D3D4D4D4D6D4D6D4D4D3D1D2D2CFD1D1D1D0
D0CFCECFCDCDD1D0
343430373337313230312F2F2E292D2F32374E5A666967696564676A7C7D83898C919098
99A2A6ACB0ACB1B2B0B1B0B2B2B2B1B3B8B3B2AEA9A5A09C958C857E7160554A3E424846
5670817F726971625A5F56474144575A4E446443353F3A2E2E2929293E5A5A4C2F313E46
3D382C334E94B3827A7F5D6176866A5A91A2887B6D6F7473715A484D635A5D7076918356
50486A8471497682758AC2DAE0C8CBD09B493836322E312F353434362D32303032363537
3E3A3A4038392D262E303839322F36383B322D303733333D3E3B3B363B3E3A443F403A2C
2D32373C3F373D3C4D3E3A35394746443C4C555B57595E646868676A6D6E6E70737B7D80
7E7C7C84828488858A888A878C8A8C8B88908D8D8A8B8E918E8F9195928F93919597999E
9FA4A5A5A9AAA7A4A09EA09D9B9D9F9B9B979892939394918B7F3B2C2B334E442F2D2E2B
312C2E333231353231364C36383A3F4131313F382A33362A323B587760444C504862514D
4B4E49474B54534F46413031403C2E5189A2ADA9A396A5A296898F999A9A99A09D9B9E9E
9E9C9D999B96969E9A9A96999597969494989999939D9999999496979493959B8F8F9291
8D93908F8E8C848D878987807E7C7A7A74777480A2B8C8D0D5D8DBDBDBDBDEDAD9D7D8D6
D6D7D9D8D6D6D5D5D3D4D4D5DAD3D4D3D4D4D2D4D4D4D4D6D4D4D5D4D1D3D1D5D3D1D2D1
D0D0D1D0CFCFD0CF
353534322F3237312F313330303131302B33475764696C686561686E7281868788929097
9BA1A3ACADADAEB1B3AEB4AEB2B1B2B6B1B4B4ABABA6A3A2979087796E5E4F47404A444B
5A788E836D5C64615960594A423B47504A4D64572D37372D2D2E272A3556624A34374149
35394342699DBC8781895E768B75526BA19A847F676D667E826C424757567C8375937A41
37385E857D66728C7C82ADD6DCCDB6D6C27E50382C29292D2E343A37303135302C2E303E
39352F3B39313226323342332F2F3332373231323034383A3C3E393C373C3B423B3F382F
2C36353E3F3943424B3E3A343B444A47464E545A5C58616A67676C6D716F7473777D7B81
80798284898787848B8E878788868C8A8B8D898A908D8B8A8A888D8F8F8E8D8F94999897
989AA19FA1A6A1A29F9C9D9C9E9D9D9E9C9895939090918E8C8858312C33544434322228
2B2B30342E2F33363631433937393E40323235372B343D2B313B527461454C43425F5854
4C4D4246464250554D3934303B38285289A3ACA7A296A1A1978D8E989C9D999B9E9A9B9E
9D9D9C9D999A95979C9A98999A9C989499959A97999A989A939397969691939795928F95
9191908C8E8F91898E8384847F7C7E7C7376767F9EB8C4CED4D7DBDBDADBDAD9D8D8D8D7
D8D5D7D9D7D6D6D6D5D6DAD4D4D4D3D4D1D2D1D1D1D2D4D6D4D3D4D4D4D3D2D3D3D2D2D2
D2D3D2D2D3D1D1D1
3E3E332F3635323531343230353430332E35405466626962695F676D767D83878E8F9397
9CA3A3ABAEB1B2AFB4B2B2B2B1B2B3B5B7B5B2B0ACA7A49A9490827E6F5A56473D43404A
62859679655761635758554D493A3B43444A7266363B3235322B232A3751605337344345
362F31417EA2B986818B7791724C48899C87857A6B69617686805C505451817E758A7247
373C70898570698B787A96C9D8C3C4BBD5BB7B3732322F343030352C2E322D322E30383A
3834313B3B34302B30313C3B3433333631343832343A393539393933393B3A403D3F3D2C
2F313D403C394C44473937373D484945535359575B5A66656566696F716F7378787B7E82
817C7F838783818289878B89878B8C8A8B898988898A8B878788888B8688888C94919594
9694979C99A09C9B999B9F979A9D9E97999C94958E898F938D877A3F282D4D44303E312A
2A2B2731332D343A34333D3637383D37313438383033372C2B3A4F735E4753504A5E5948
4847424242444E574F34323339362E5985A2A99E9C92A29C97909093A09B98989C9A9F9C
9B9B9A99979B989A9B9A9A989B99959B9D95999798969798969195949793949792949090
95918B8D8F908B8B8B888585807E7C787A7375829DB5C6CDD9D9DADBDCDADADAD9D5D5D6
D7D5D9D9D9D7D6D6D8D8D9D5D2D4D4D2D1D0D2D2D0CFD1D2D3D3D4D3D2D0D3D4D1D2D2D3
D2D3D4D3D4D1D3D1
2D2D2F313236353334323534333131322E313D556E636365615F646C737A81888A929598
9CA1AAA9B1AEB0B2B2B0B1B2B1B4B6B3B5B5B0AEAAA89F9C9690857C6D604A434041454F
608CA176605F60695E4F4A424A36343347587A7D42383435312C2427304F584D3834433D
392B25356CA2BD8A7C99857D543C65978A7D8A7875616168717B75665562787D77846A54
4A55778C866B67806A6E98CACEA5A7B6BBD8A15235363338333435353531363532353A3D
393A3B413D3634323536383C3834393D343733373C403F3D3C3A3E40423A3E4345423B31
3635424236414F53473E373E4755564E585B5D59636569676C6E6C6F717279777B7C7F81
817D80838589888688888C8E878C8B868C8B8B87868D86868C88888B89828487888D8E8F
8C918F909192978E95909497959A9A99969E9D958B8B8D918C8D865D2D2F3F50362D302D
2B2B2C332F2B2E3E38313A3435404536343531312B313B292D3649715B454D4B465D604A
43483D3D3E394D5F512F322F3532315C87A9A6A39A92A59C999493929A9A97989D9D9D99
999A9C99979998989C9A9D99989C98979C9C9C9A9A9A9698989596979394929690939190
8F8C8F8F8F8C8D8E90898B847F7F7D7C7B7578869DB0C2CED5D7DADBDCDADADBD7D6D6D8
D7D5D7D8DAD6D6D5D7D8D9D7D6D7D5D5D3D3D0D0D3CFD0D2D0D1D2D0D1CFD1D2D1D3D2D4
D3D3D3D4D3D3D3D4
363633323135383A352E333534312F2F3134364B57605F615C5D5D63727C838A8D91939B
9B9FA6ACAFB4B0B2B4B3B1B6B3B4B2BAB6B4B2ADABA3A19D958E82796E5A544540414A4D
608AA173615F63697268573E38353338425B7C8B5B452E2C30292C26344F635940423E33
332B303D6498BB967D9C7B5C395782987D72808170555A585D546B8270778289807E6562
584E6D857C5266886D75A5CAD19C83B69BCEC78A43342C333531393C3B3833352F373739
3838363E38302B322C3638372F293230363032373A383C363439363B3D3639403D363A2F
3536444437434F5542413348454F534E555B5A5B606563666F676C69717273757A787E7D
807F8083878285878B898B888A8A8D8D868C8F8987878C848886858589827F858685888D
8489878181808685838A8C8C949199949995969A93878B8C928E887F412E3C5736302F2B
302B2C2F2C32333F393A3831394E413A323A34373438402B30394E745F4A4F5046635D4B
404B383D48414E624635402F3434326184AAAAA39696A3969B91938F979B9C999C9CA09C
979B9C9B9B9A9D9D9D99969D9B999C9C9D989B9D9A9C98989A9797979794979391909393
8F8F8F908B90918B908985837D877E7A767579869BB2C3CDD5D8DADBD9D9D9D8D5D6D4D7
D5D6D5D6D6D6D8D7D7D8D8D8D7D7D7D4D5D1D0D1D1D0CFCFCFCFD1D0D2D1D1D1D4D2D2D0
D2D0D3D2D4D4D2D5
32323031323835393037382E33332F2F33353845515A605D5A5558616F7C828C9690959B
9DA1A9AAAEB3B2B3B2B0B3B1B4B7B7B4B7B9B1AFABA0A09C948C83766E5A50433F3E454B
6588A47D655B646D6E6B6645322A353E3D58719575412F2E2F352F2E2748645E403B3732
292D3F506186BBAE899467433D5A908E747477806F474C4C54384C798B858F857A6B6075
663A6E8A7B567A8E757BA3C3CFAE879AB39CCBC88C3D302F2E3131322C30353030353336
3A3C37413A382C2A293239373336373346353A373A444A3732443C3B3E38413F38333533
353F4C493D49595240393B474B4E5051555D6269696869696E6A6A6A74767776767E7B7E
81848281838486848D8A8A8E8C928F918D8C888984878788858181848581808286858185
807E797875767A757D7D7E7E7F888F95999C9A9B98908C898C8D8887613139563B2B2B2D
2D33282F2E2C2E3731343834334C4337343F3733383641292E3A4A745B3E484D435E664B
4847423D403F4E5B432E3D4837373C6587A5AFA19595A4979A979792949F9D969B9F9E9C
989CA09D9B969A9A9A999A9C999A979A9C9F9B9D9E9B999A9497989697959593948F918E
938F918F8F8E8B8E8E8A898285807D7B766F75849DB0C6CAD4D9DBDBDBDAD9D6D5D6D6D9
D7D7D5D7D6D4D6D6D9D8D9DAD9D8D6D6D5D3D1D2D3D1CFCDCDCECFCED0CFD1D1D1D0D1D0
D0CFD2D4D1D3D1D2
393933333435363230333C3438353A323C37373F4F585D5D58575662717C848A9292989D
9FA0AAADAFB1B5B5B2B4B4B2B2B0B5B5B5B3B4AEA8A69D9A958882776C5753434141464B
6187A784695E606A686F6E583F31323D384B729D86472B263233332A253D675B4538312D
29364F5F5874B7B88B8A57384B6B917D626F7B8666433E444B3244608E9A887D5F58798F
7335789184698E93787B92B6D2C1A790B39EA9DCC2763A343234372F2F3335393B383634
323734382F2B2E2E2833353B303034302C383D3C3C433B373842433B443E3F4437353035
383E524D394C524A3D3A4041474754535964666D6C6866666E6D6E707875767A767A7B80
81808281878583878C89878B8B8D918D8B8B8F8C8B8886878485828280837E7F7E7D7F7D
7F757574757377776F74737477777C858A94A0979695908D919490887C4536593D292C31
2D28262B2E3131302C30373C363A45382E3538313334392E2C3D586D5B44465345635E47
4F444040433D55583F30363435343B668C9EAA9E9196A2959D979494929C9B989C9B9A9B
99999C9C989A999D9D969798999C969B999A9D9B9B9A98959595959594979A9095919092
8C938E918E8F8F908C8B8B8885847D7A7A7478859CB0C3C8D2D8DBDBDAD9D8D7D7D5D5D5
D4D6D5D3D5D7D7D7D8D9D9DAD9D9D9D5D8D5D3D2D4D2D0CCCDCCCDCDCECDCCCFCDD0D0D0
D0D0CFD0D2D2CFD2
414133332D30333136373F3F383A3C343538344048525F5F57535568717D839092969B9E
A1A3A8ABB1B1B3B5B3B1B1B4B3B2B6B3B7B4B3B1ACAAA096948E81786B5B524644434147
5B829C976E656364667379664A3C353B364B77A18C4B262531332E2322385F6F5D443735
305453585455A9B685816239597F8C6E6C717B7764454B414237628285858B776B708581
664B86A0926E8F9575778CAECCCA969EA0C291C8D7B0653E3937353738363A3335383B37
3C3C433B3E37322D373B3F373734352F353E3D3E4437363F47443B373D4643433A3A3235
3B434F453A595552433747494A48545762666C6C696A686C7073707775757577797A7E82
837F808288898487868B8F868E92908E8C8B8C8A858785858187838187857F7F837A7475
777375777976777D7C817877757B727A8087979C969B94918E8E8C8B816F3A5542362D29
2C2E2B27282B30342E2A313939373B3A32323537393A312F303F516059464955405C543F
52463F363845505F3E30302F2F353D69899EA69C8B9A9E919C9B949698979E979C9C9898
9B989D989898999A999B979C9B9A9A9896999B9B98999795969498959495949791919294
908E8F8F8D8E8D8B898B8788837F827976757D8E9CB2C4CBD1D8D8DAD8DBD8D6D6D6D5D4
D5D4D5D5D5D6D6D6D7DAD9DAD8D7D9D7D7D3D3D3D4D1D0CFCECFCDCECDCDCDCDCECDCCCD
CFCECECED0D0CFD0
3030342F33333732373639353A3639363735363A4552585B5A5B59667181888F9396999F
A0A2A8ADB0B3B1B4B3B2B5B4B5B2B2B3B7B5B2AEACA6A39D988B7E736B584C4B4244494B
51708DA0836F626765717D7058483035313E6F9E8B512D2B3434362E2C30526E69462D38
3B5A505857529CB37F7268437193795B5A66797B5D453F3E3A5885886E618A84817D8266
617B98B2AC7D8F8E747180A8C4C88F8795A8B19BD1C790593E373539383936363632373C
3E3E37374C3A3634343639353A3933303C3D3F3C3D3D37404241363F454B4B4A3F3D3431
4044564040594F50463D46514E4E58616367656868696E736F78707B7A757C797D7D8484
8283848588878A8C8A8B8D8C8A908E8E8E908A878586838486828182827F7B7E7B7A7776
787B7C80847F81878B8C8380817D7D7F7B818795999696938E96908C88835D4B4E342627
322E2C2A312F2D3A32272D3840302E3B3732363F393B32312C3C4B565C47404F465E573C
4F513C3C383E5669402F342C332B3A6589A6A3A09096A390A09A95979B959B979E9C9B9A
9D9A9A9A9B9A97989D9A9F9C989B979796979698959898989593939595979490928F9490
908E8D90898F8A8A8C8888818383867B7A737C8CA1B1C2C7D0D6D8D8DADAD8D7D6D6D3D3
D5D4D5D5D3D6D3D5D6D8D7DAD8D9D8D6D7D6D4D5D3D4D2D3CFCFCDCECCCECDCDCBCECACC
CECCCFCACDCDCECE
34342E31333A383737373B393C383936373938414A5351585F6A5C657381888E949B9C9F
A1A5A8A8B0B1B4B2B3B1B3B3B6B5B3B7B9B5B5AEA8A99D9A9A8C837A685D4A464A454C4D
5062869A9F7F6861646C7474674A3741323163968C5D3227242E35322B3A44676F492F39
595B4B575C488CB28F6D6C568790584A4E5F6D734E3D3A53547D827678548685887D7B51
6E9A9EACA4889786716D7FAFBEC58E668088A1ACACCCBB91673430323A372D3535343134
3D3535374034392E34353A35333430313437343537373541443E39474640463C35352E35
4151563E4456444C3D3F414D4F515C65666A696E6C6C6E737376747B7879807C7B7A8482
87868589868A8889858B8B8B8D8F918D8F8F88858B8485858383807B817C7E7C7A797E7E
7E7D8188878487898F8F918B8D8C88848380818789939695909391948A877E634E32272B
2F312D353230333D3A3335363F352F353B3430394138372E2F3A465665443B4D48625845
4E43463D3A3C5B62392B3738353242718EA59FA19396A08E9D9B95969A949F98999A9F9A
989B9B9F9798999A9C99999B9A9A9A959B969A939893959697959296979293929391918E
91928F8C8C8F898D918C8C888486847E7A7D7D8C9DAFC0C8CED2D7D8D7D7D8D5D5D6D5D4
D7D4D4D3D5D5D5D2D7D7D7D7D7D6D6D7D8D5D6D7D6D6D5D3D1CFCFCFCECECCCCCECCCBCC
CCCCCBCECBCDCCCD
3C3C37323936383B3C3B333B3C3B37383A363740434E5559585A5A687281898F979AA2A2
A5A7A9ABAFAFB3B4B1B3B2B2B5B4B6B3B5B6B3ADADA6A5A0A39D8B80705F50424144474C
4F596E8AA0956C6663667074634633373837508C9159362C2B30372B302B38586E533242
6A5839615D437DB49D746F698B723E3B4F515D6541334A6081816A78954E746B7D746E60
7FA4A09F90909D89726C84B2CDCC9F5D6E7E85ADA9B0D6B19451353A363A3A383A353B39
3740393936392E322D3238373533322D3737343434313A443738374248474D3B322E343A
4952564155574F433B4446484E5A60696E696F716E707272737377757778807B7A7E8180
7F8182848D8B888C8A8F8B8F9391948F8E8B8B8487858680807D7F7A7E787B7E827E837E
867D84898A8B8E899193938D8E8F8D898C88868289909596939396958B86867B623D2B32
2F3030302B2D2F3A3F2E312E33332D2E3E322E3A453731372D39455566423E4A4561534A
4F4545403B385F5E322D392E2E2F466B92A59D9F939AA18E9F9C93959A959A9A9A9D9E9A
9C9A9B9894999B969C9B96999A959B959C989A94949A96929694979994959292928F9395
919290929391908C918D8C868383857F7B797B8EA0ABBFC9D0D5D7D8D8D7D7D6D5D4D5D3
D4D4D1D3D4D2D6D6D7D8D6D6D6D6D6D6D7D6D6D8D7D8D7D6D4D2D1D2D2D0CFCFCDCDCDCD
CCCBCBCBCDCBCECD
3A3A3832343A333B3939343E3B363F3A3736363D465051595E5E606978818B92979A9CA0
9FA9A9ADABAFB2B4B1B2B3B7B4B6B4B6B7B8B2B0AEA7A7ACB5B49A8B796952413E404545
50505A748EA2886F69666A6D6D4F383D4054467B9562473D3334342F30292D536A603A47
634A3369603F62A8AA88707B845735374B555A574040577D8372596A7553604D6764636B
8B9A979384999D89776E7BB0D6D4BE5C5F757E8AAD94CABB977936342D35312F2E2D3135
3538373C38322E2D2C32333539353D3637343031323A4A443B393B3E4440493B31302E37
4954583B4E5554493943484E5B5E63686E6B6F707671737276717978787B7F7E7E7C8384
827E8487838A8C8E8E8B91929493908E8C8C89858585867E7E7A7B7A797F7E838284817D
7E818C8B8D918F8E97989693938D918E8F90948987888E8E94939899908A8983693D2F29
30322F302D2D2D333D302F3431332F2F35362B3844342E2E2E3943516D463D4847615547
443F44493D38545E3A2D312D36334B6093A49D9997999D909F9B92969794969B999E9C9B
9C9D9B9A9B979A979C989A9B979B98989A98959699969495979398959693959292919592
919290909090928F91938C8A888983817E7A7E8B9DAABCC8CED3D5D6D7D7D7D7D5D5D6D4
D5D3D3D3D0D2D3D6D6D4D5D6D6D5D5D5D6D6D7D8D7D7D7D6D4D3D2D1D2D1D0D1CFCECDCF
CECCCDCCCDCDCDCE
3A3A3836343536363B3C3A413F41423B3A343C3E455454585B5D606D7C828A9295999EA4
9FA7A8AEB2AEB1B5B4B1B1B6B2B3B4B5B6B2B0AFA9A7ABB1A69F9488917D634945414347
4C51556A81899E816C686E6A615844414C563F66987750382729252D2C2832526863384F
4635416E503C579CAA977B7D6642383C5A50524B4558807F76695B5752544E48505A5267
8E8A8D868AA29685807277A0BFCECE894E6474778A97ACBB9E9E703C2B2E3337312C2F35
373C3A3533312B2C292E2930373037353233312E313A433937393D3F45454644382D3037
3C464B35544F4E4E3A4B50525B63606A6F6973707873747576767C777B7A787C7E7E837D
7C7F85848B908A918F8F959692918F8D8A8D88858181857D7B7C7C7A7982828581807D80
818E8F8F90959995999D9E999590928E98979A8F87818C8F90909595968F8D8880542E32
2B2928302A302F303A2F2E322A302E262F352D374B39312E2A3B40526D4E3E514C5D5F46
403C40483A415C553131342F3632525E92A69F9591979F909F9A9392969792999C9C9C9B
9D9C9D9E9C9CA19D9B98999798979795989898999794959697989C9495948F92928F958E
95938F91909091928D8D89888488827D7E797E8C9DACB8C4CDCFD5D3D8D7D6D6D6D5D3D3
D4D2D2D3D2D5D6D3D6D3D5D6D5D5D6D5D4D4D4D5D6D7D6D7D4D6D3D4D4D2D1D0D2CED0D3
CECCCDCECFCDCFCD
3535393A37363B3D3B3E39403A3B3E404037353D4554575B5B62636D787E8B929C9A9D9F
A2A8A8A9AFB0B0AFB3B2ABB1B5B6B2B7B4B1AEAEA9A6A3A59C82828791907C5C4B474749
4C4D545B6C8297906B68686C626855414A4A364F8C8346432D27272E33252A4266634546
3B39516C3F2E4297B19B816E4F312C425157595A6C79796B5D5C62483C543A435A606069
8C808582929B95888577748E9CC1D1B969556C737282A2A6B4ADA270322F33332B313535
31333535322F2C30282F2B333C363539312C2C2F363C3A39423F3F3F464C433F2D292A38
415148355B5157523B454E575A65696A70737671777876777776797E767B79807B81867E
8083888588908891908F9297969393908A8B8A867E7C7B7A777C8083827F867E7E80807E
8390949896999D9FA2A8A39A9C98A09EA7A4A3A092848A91908E97969792908A8A753C2A
2A30272F2C2F2C2F43322F342C2C2B2A28312E3B473C2C2C2A363951704C425551585549
494039433C4A5859382F302D2C33506096A89C938D9898949E9A9096999694979D9F9F9B
9B9F9A9A9A9B9C999D97999B959A96969998989D949499959395979693978F93928E9092
929490918C908F948D8B8E888A85828183797C8E9EACB8C4CBCED2D5D7D8D5D5D5D4D3D2
D5D5D1D1D3D3D3D2D2D3D4D6D4D4D3D4D3D6D5D5D8D8D5D6D5D5D5D5D5D4D2D1D1D2D1D3
CFD0D0CFCFCFCFD0
353538373B373841393F4044443A413F41343B3F494D53545D5C62707A848A93969B9DA1
A0A4AEAFAFAFB1B4B3AFB0B7B1B5B5B6B4B3B3AEA5A8A09A98897D7B89939685644A4948
4C53535563818E9B756667746B66643F40403240707E413E3C2E2626322927335167513D
383A5E68342D468FB694856D463C3449515C6C6C77756C5B555C5E4B3D3E374E5F70636D
837C847F8F9B948E8781747782ACD1CA996D5B6A726A8D95AEBEBCAA562E2E3739363A37
3533363236272B312D2F2D363E303C362B2C2E32363B353D42363F43444E483A2E2E3138
4757443856505350434248535760676E7071756F747C76787C7A7C797E7B7E817F80837F
81868B8A8A948F8F9190929294949189898583827C7E807E778182837E76787A7E7D8581
86939D9CA09FA6B3ADB4B3A3A6AFB9B1BABBB5AF9589838D8B8E8F979A968D8B89865B35
2C302F2E2A2E2E2F363235372F2A2A292C38353C393E30343336454E6C4D3D4E4E4F524A
3E3935424C3C5A55382C2B2E2E2F4E689EA39F8E889E93909B998F93979797989D9F9C9D
9C999C9D9B979C9B9796969A969A9C94939B9797979895929297978E9494949493928E8F
9097958E908C8F928A8F8F8E8688837F7B7A7C8F9DABB6C0C9CDD3D4D5D5D5D5D1D4D4D3
D4D5D0D3D2D3D5D2D3D4D5D4D3D4D5D4D4D4D5D5D7D7D7D7D4D7D4D6D5D5D4D3D4D4D1D1
D3D2D3D2D1D2D2CF
39393B383F39393C3B3F3D3C43473F463D3A3845434E55525F5E636D79858C93989C9DA1
A3A6ABAEACB1AFB1B1B2B3B4B4B4B6B8B7B4B3AEACA49F9E978A7E79788594A1825F4D4C
4B5452565C7085988D7071757262635444453E3E54644B3C43332A27342C2A2F45634C3C
3D3A615D2F353D88B49685684A393B4B5F6D6E696C6B5C514D5564563C3B3D5273735474
7078817B939D978B85867B7179A5D8D3B9946C5E6A676E7A82BBBABE9F41342C36322D34
373438302E2C272A262E323A3638382A2B2C333241403236423C383B42493E312A2D323A
4D5D4A3E56544E534C484D5860616B7373767571767F76767977827A807B7C84807F8381
87878B8B919196939191919098958F8C848485807D7E817F7E827E7C78777A807E808988
8896999EABB6B9BCB1BEC1B4B9CAC6C5CBCAC4B2A38E878787868E948F988E8C88837843
2E2B2B292C2F3135323335362C292A2A283733393134362E3338404B664B434A4E4C534B
3836303745475A4C342629322B324F649CA69F838C9F928E98989095969695989A9C9C9C
9F9C9C9B95969B999B99959A969B989B9797969495959B93959593949A96938F93929390
93969493919293908F8E8E8884848685827B818C98A5B6BEC8CBCFD5D4D3D5D6D2D4D3D2
D2D3D2D2D2D2D2D1D3D3D2D0D2D3D4D4D3D3D3D5D3D7D4D4D5D7D5D7D5D4D4D5D4D4D3D5
D3D2D3D2D2D4D0D0
3838353C3F3A3D343E393D3D403E3F3B3D3C3B49494F57535F5E67737F878C92979A9DA7
A5A6ABB1B0B1AEB0B4B1B0B3B7B9B5B6B8B5B1ACA9A59C9D958E80766F6B82A59C806550
4D505155576D7F8C987B767675645D4B3F4542364B513C2E38392D23342F2E3140614D37
3446624238313F89B095876F4F395455616669666D62625F555861563E3B406979543A64
5D7A7A849B9C9589868780757CB2DDDACCAC915F5D6E66656F8FAFB6BD7D39312D333037
39363535352D3127273442383C38322B2D30333C403C403A42363A3C464E453032313137
565E41434A53545050534F6263667074737673787C7E7A7B7B7B7F7A7F7F827F7F858288
8A898C8C92909491928F949194938E8C81867E7C7C7E7D82837E7C7B767A7A8487838C88
878A939FA4A8A9B2ADB3B7ABB1C7C1C8C8C2C5B4A5938D85898E8F8D92958F8E90888565
3B2D2E2C322E342B36333032362F302E2B2D333D3338423438383C4B5B4B434F474B584C
41433B3739515F45342528302E32536A98A69E818BA18D8F99999094949995949F9D9B9C
9B9899979896959D9C96979C9A9794989B96979394929694939191959094939392918E8E
949593908E8E95928E8A8A898A8681837C7D7D8996A8B3BFC5CBCBD1D8D3D2D4D4D6D4D3
D2D2D2D2D3D2D2D3D3D3D2D2D2D3D2D4D3D5D6D5D7D6D6D8D5D5D6D7D6D6D4D5D4D5D2D3
D3D3D3D4D4D4D2D3
3636363A37383B3B3B403A3B423E423E3C3D3942444A5C5B5F556A767C868E93999AA1A1
A7A9ABAFB3AFAFB3AEB0B2B3B0B5B6B6B1B5B2AEA9A29D9B948A8174695C647D9B9B7B5C
514D4F565B5F728794907A7A7B675D453649473B4145372A2C3A382F383B2E3540564538
3B4A663A39323A84A5938C6C4C4F635F645D615865626B6F69615F65545C536C663C3D63
486668809699918D83867F7B91D1E3DFD4C1A57C59696F5B5F7390A1C7B755282A2F313A
333437322F2D2C252A3B39423B3E2E293031333D3940384140323B454A50422C2C282C34
4D67424A5159564C4F505662626571737578787E7B817A7A7B7C7E7E807E7F7F85878586
8B89898A929195939393938C908C8A878080807D7F7F7C807B78787B787A7D8087838985
82858C94918F8D9198999A999FA9A8B4B0B3B6ADA3928A8682878E909392908F948E8C7D
4C322C2A2E322D30312D383C2D2E312E322F333C3D3E4E3F333A3946604A454B52495355
4E4530323B4D613D3231322E29304D6B95A3997C87A38D909B979094949797959D9D9C9B
9C99999794999D969B999792979896989999959194929492918E90909195939294949390
928E9393918F8E9096908B8B8E8885837F7B7C8C99A5B1BBC4C8CBCED1D4D3D6D4D4D5D3
D4D2D0D3D0D3D2D2D1D2D0D0D1D6D3CED4D3D3D0D3D6D6D4D4D5D5D6D5D5D6D4D4D5D4D4
D3D3D3D3D3D4D3D3
33333A39363E3A3B3F3D3D424547423F413E4043414A5959575A666F7A868E96959A9EA5
A5A9ABAEAFAFACB3AFAFB1AFB3B5B6B4B7B6B4AAA9A1A09A908D85787159555A75A09871
62564E53525C65848C93897B7F6F543D2F3E543A383F3832262B433C3C393A3B47584734
3759553F3D3C3D7C9880906E63646463635E5968766D6A635C555E6D7D8777564A464252
3849536F828E91908686847CB0DAE1E0D5CEBC9A6C5D6A5F55637595BAC79F3C2C29302B
32302E34302C3228293135433E3C2D2B302A343D363A383C3F383F4247503E2B2B332F32
52703951575656494D4E5B60656670717679787C79847A797A7E807E80838382828C8886
8687858B939691949490928F8A838180817D817E7C73746F6C6E6E727572757A7E7C7C81
7E8081827E7D7B817F807E82878B909493959B9E9B88868281878A8A8A8D8B8F91928D89
7538302D2F2F342E3230373B342F2E2F3132333C3A394748383738445B484C494C4B5355
493931383E5D613F2F2A2C2F2B34517997A390798CA2889098958E96929697939D9E9D9A
9A9C989E979598999898959A959896979A9C959394919394909292949694959691919294
928F9291909293908A918C87868B8582837B848998A6B2BEC1C7CECED0D2D3D3D3D2D3D3
D1D1D1D4D2D0CFD2D4D3D1D0D2D2D3D2D4D2D2D2D4D3D3D4D5D4D5D5D5D5D6D6D6D6D5D5
D4D3D5D4D3D6D4D4
3A3A37363539353C3C3A403F453E4040403C3F413E475150545B64717B828E92979C9FA3
A4AAADB1AFAEB2B2B6B1B2B1B2B0B3B6B5B4B4B0ADA59F9993898377705F514C557C9E8C
745E5851545A5A748C969E8A857458402E37514F3C402F30282B393E4C4E5936444F4836
34583F3C383743758E728A6F60645A5E686466706A62584D514D58688F997A4137364E46
2E39445B7581848283868B8FBFD4D9D9D4D3C8B9844D5D6956585F7794B6C584322D312C
2C37332E322B292A2B30394944342D36382D303535383A4035353E4A5053392A2B2F2834
55674252536259534D535D596569737A797E7E7D7F83807F7D7C7E7D8380858488878986
89898E8B8F9793919391908D85797B787D7C746E6B625E5F5E61606A6B68717173736E70
716E6C706A6C6B6C706D6B70737A7E7F83808283827F7D787882848F8380838F9291918B
8754342A2E322C2B2D3132333B2E2B2D2B2C2F383134474A4139363D574D48503F4A5352
443B2C32374F503E322426312A32517C9AA18D7C8C998A9199949194979593929E9E9D9D
9D9C9A9A989899989A959799969692969895959091979596959194949695959693939091
8F8F948F9291919090918A898989858381817F8695A4ADB8C1C7CACCD0D0D3D3D5D4D5D3
D3D3D2D2D3D2CFD0D1D0D1CED2D1D3D5D5D2D2D1D4D4D1D4D3D5D5D5D5D5D6D4D7D8D5D5
D5D5D3D6D5D5D4D4
3B3B363D363735413F42424642443F3E404041403E4B4F4F516162727C838F95999B9DA3
A4A8ABADAFAFB2B2B4B1B2B3B6B1B4B3B5B4B1ADACA6A09B938881746E5D564C4359829E
896C5D5056545D677D97939E8B775A3C3534405956442E2429312F36404E4D34434C5531
3648383B39354875917F876C6A6659676F7366575E55433A404D5D7B84857D49463E5D4C
414140536F7B7A78777A90AEC0C8C7D0D5D5CEC0A4575768725A62657694C5BB60262628
302C3032312E2C2A2E333E494730272A2B312C3535383A3F37423F4C524E2F25262A2832
526D3E515263584B49515E666B69777879797F82827F827B7F847B7D8382848387878D89
8A8F8A918C94949090938F8D82756C646E6462595A5352575452565D5A5D64626C706A68
6766606360575959615F666F70737775757B746C6F6E68646C7482817E787C8A8A8F9391
8B77402D2B2D302D312E323437322C2A2A2F343B3232404B423D313B53574050484F514F
3D3A2C2B3A584E4031272E312C3559849FA2887E919184919895939594949591A19E9C9C
A49C9B989C959A989997999898989695969394948F98969295918F9192999591928E8E91
8C8F93929090908F8D8E8C8A8D868483807F7A88929DB1B7BBC4C8CACDD0D2D3D7D3D3D2
D3D2D2D2D2D2D0D0D0D1D2CECFD1D1D2D3D2D1D0D3D4D5D4D4D4D4D5D4D6D6D7D7DAD6D5
D4D6D7D3D4D5D4D4
393939373A403C3F3F3B41404A4141403C3C3B3B45474D4B5359606B7E838E9599999DA1
A2A9ADB0B0AFABB2AFAFB2B3B2B1B3B4B1B2B4AEACA9A19F958B817A6E60524846486C90
9A82695B5656585F718A9094A17C5F453C2F393C625537283644433C3B404337484E5240
3E3E31323D364D6E8F817B676E6C5C6769665B4C4D4E3F3E4D587A7863797B4F3A476173
604A3A5F89989A907D738AAAB7C1BAC5D0D1D1C0B47A4D606F6C625D6481A5CAAE3C2427
30313232393226242C364A4E3D30292C352C2A322E3A39413144424C4F4B2C2A27272D36
54703E4B586C574D455359666B707676797880828586837E7E817E838282808889888A8B
8B8B8C8E8D908F928E91909182725C5754564D49484D555C6168686B6B6B6A716F736761
5F5D5F5A5B5451585B5C6467707676787D7A74635D5A545B62636E747070737D8C8B9193
8B8961352A36302D25312E353D332E3533312E363C363A464B4E37484F533E4C45515452
47402D2F3F55473C3124292C2B3662899A9C82779285829292918F93959595939C9D9A99
A4A19A97989796999A9A9797969296979392969291939397959190919391939795939293
90908D8E9093909291928B8C87888482807C7F8592A4ADB7BEC3C6CACDCCD0D2D2D3D3D4
D3D4D3D1D0D2D0D0D0D0CFCFCFCFD2D1D1D0D2D3D4D4D3D3D4D3D2D3D2D5D8D7D5D5D4D4
D5D5D6D7D5D7D4D5
353535373D3B373B3C373D41424244413D3F3F3F3F46484B4D545B6875838893979CA0A2
A6A9AEACAEAFADAFB0B1AFB3B2B3B3B2B3B4B1B4ABA6A39A968B80796E624E4044445669
898D786557575E5D6572838F9B826042352B2D33485D3529435749413D3E393B41514F43
39363231373F4969847D65616469646A6350505049403E485D7B6F5748627058515C7779
615557748994AFAB9D76768BA7BEBDC5D6CDCFCAC1A965566A75675A616B84B0C67C2D29
2F302B2D342F2D26253D514E30262A31322F2E31323C3E443447424A53462C2B2C2A2F32
567A4552576B4E4D4A5961636C6F7775787982868289857B7D837C84827F83858584878A
8A8F8C93918F8D8F8C92948F87755E46474F59656D6F727A797F7C7D81787977757B7570
736E71726F6B6B6A716F6F70747E7C7D8A838972584D43575E61696E69646C7380899294
8E8A7C442D2E312D2B2F2E3537362D312F322D333A31393E4949333D47553D4F3F495352
40483433394543332E21272829376693A0A07F6C957C838E958E919198959091999A9C9C
9B9C9A9C94969C989899959B9890959693989490939B9294969592919694959693948E8E
929290918E92928C8F91918C8D8888857F807F84919DAAB5BEBFC7CACCCECED1D1D4D4D3
D3D2D4D1D0D2D0D3D2D2D1CFCECFD0D4CFD2D1D1D3D3D4D4D3D4D4D4D5D4D6D5D6D5D5D3
D6D3D3D3D5D5D9D5
3F3F403C3C363B3F3F3B3E3E4448424840403A3C3B42484B4F555B687A848D919A9BA2A7
A4A7ABA9ABAFAEAAB0B1AFB0B2B4B5B7B6B0B3B2AAAA9F9A968F857A6E5E544947425053
6C8E8D6F5B5A595E676A72829188654333342E29325E53326A6B4D3435483E4141424333
3B3B3439393C41627E75545B6C64636155504749454244577A6D513F3C4D6E6064738274
617C7C685A62919C847575809CBFBCC9D3CFCAD1C9BDA1585F6A6E595964778FBDB54228
2226202A2C292D282F4354492E312C2E302835352F3C3C463C4D3D484E3C29292B2E2E30
5F774E5B5D625247535C63666F6C73747980808180827F7D7E7F7E82868084888484838A
8B8F908F918A8C8F8A91968D8A7C7369696C77787D7F828384868988838386848480807C
7D7A7A7F837C8078767C77727984877F9187908A7F72656D71797A74635C616876888C92
918A825B3435312F2B2F2D3039362F302D36302D383731365151393842594155434E5159
3D4334344445432E28222C282B3F7095A09F776B8A71839295919093958F8C8D9D9C9E99
9B9C9A9D979795979A979393969896939394949192979493919993959696958E91939290
92908F90918E8F92908E8E8A8C898883827F7B7E909EAAB1BBC1C5C7CBCECFCFD0D3D3D5
D1D2D1D2D3D2D0D2D2D0D0D0CFD0D1D2D0CFD0D1D3D4D4D3D5D5D4D5D5D4D5D7D5D5D5D5
D3D2D6D3D4D6D6D5
46463D3E3C3B3943413D45424046434446433A393F414D4F4952596E7D808A92979C9EA5
A4A5A8A9ACACADACADB0ACB0ADB1B4B7B6B6B2B1ACA9A19C968D7E796E604F5045454950
5B7693886C5F5B5C616369748E876D45352F2A2830576C5E816A3C303142383A3F444338
393337404643405F7F60536168675F5655584A5044425B776D4B3432394A605B6683827D
887E55342A3A7086675D6F84A3B1C5CACFCECCD2C8C4BB8C545C69675A5B647C99C7912F
1F252628262A2D27374B62492C2B2C352C273438353835444A5146484C372F2F2D2A2C3D
60704F58645D544854585E6A7170737B7B7E808482848381808084838588858787888B87
8E8D908F8B8A8C8B898B8F8E8B8385807F7E7E82837F848583898E8F88878B8C8A888B8A
878286878780867F827F7C818B8D8A8990969B928E8B878887888F8C8271666876838990
8E8B88783A302D332A2E322B3133312F3830343631382E39474B443E465547584C49505A
42413E373C48332D24262C2C31407B98A39E726F8466818D91919393919093909A9E9E9C
9B9C9D9C9A9C939995969792939690909494948F92959696939394939595958F93909190
90908D928F8C90908E8B8D8D8C87868681827E7E8B9BA8B4B9C1C4C5C8CDCDCECED1D2D3
D3D2D2D2D0D0CFD0D1CFD3D1CFD0D2D2D3D1D0D1D3D4D5D3D5D4D3D6D5D5D5D4D5D5D4D5
D3D5D5D6D3D4D4D5
46463D3B3B3F3E3C44453F46444B4343444240424146444D53555F6A7E81898E959C9FA4
A2A3ABA9ABABAAADA6B0AEADB2B1B4B6B5B2B3B2AEA8A29E9892857B6D64524B4A4A4B4F
5667859876625E5F5E65657182836950413D3928283C72777D6E463A3944333C3E47433C
38374D45403F4162765653605F55564D5050504640486D7453413B3A425558576D84818B
835E2B1F1F27537362656C84A4B0C6CAC5BDBFCFCABFC6B37F575F6D5B525D7280AAC575
2A28282D25262A2A405F7152352B2D332A2A3B353538363E3E47484744342E352C272B39
54674F5869625B48565F646C71737A7F7D7C7B84818384817E7F86848385888489878A8C
8F8F8B8E8D868A89888C8E8B8B878788878282828587898D898E8D928D8B9091928D9395
92938F93918E89888C8689898F949192989FA29C9999939190959A9A9D917E757B7E878E
8C8F8B83593031322B333130353A333631323433353A333E404A453B3F544C5A48444651
5043413B4648372D262625252E427E9CA3A0737786637E898D8D9691918F9391969E9C9D
9A999D999898989B96969A93979594909495919193949799939093929598959590919293
95909092918F8D8F8C8C8C8A8B878788847F7D818C9CA4AEBEC0C2C5C6CACCCCCDD0D1D3
D3D2D1CFD2CFD0CDCFD1D1D2D2D2D2D2D1D2CFD0D1D2D2D3D4D2D3D4D5D3D4D6D6D3D5D5
D2D3D5D3D5D4D3D5
4747423C3F413C4041464B4B494242413E423E403F44494653565E6876818893999B9CA0
A0A8A8ABAEACADAFAAAFB1B0ADB6B5B2B5B5B2B0ADA9A099968B837C6E655345474A464C
4E587490986F5E60646469707B776B4A3947433527346B7868583A323743323F4D48423E
393C5C4A3F54516B674A5E5D5352484B4B524E484C5C71543838334B607779737787948C
6B332A2B2A2843627888869AA2B7BDB4AE97ABBFC8BFC2C4B777505E71575C6C748AB6B4
452D302E28262A2A425F6B4C32303330272A3A35373635414444564F4D2F2A2C2E2A2A3B
5B6A57576667544E5C5E616F727379767D7C7D8382807F8282828381889187868A89898C
8E8D8D8B8F88868A878A8D898B928F8C8884888C8A928C8C8A8C8F91938F90908E8F9191
999A9D9D9F9D999C9B969696A0A09EA3ADB9C0B4A9A5A09C999EA4ABAC9D8B7D7E808586
8F8B89847A3E302E2B302F2B323536392F2F30312F38323645463E484955505A48424758
5243413B4A452F2F2428262529547F9BA7A1757D845D7D888D8B908D928F948F98989AA0
9C9C9A9B999A9B9B95969B98979B9593949194959599989994949494989694928C919290
939293918E92908F8D8B8B8B8A8E898B808283838B99A6B0B8BBC3C6C6C8CACACDCDD1D2
D3D3D3D0D2D0D0D0D0D0D3D1D1D0D0D3D1D2D0CFD0D3D3D1D1D3D1D5D9D6D5D5D7D4D3D4
D1D5D3D5D4D2D1D4
4A4A413C3B3F3F463F45414845494A424343403F454643474F545C697B83878D959C9C9E
A4A7A7A8A7AEA9AFAEADADB2B1B2B3B7B6B4B3AEAEA8A3999590857D7368514A47484A4F
5255607E928B6D616467657084776B543B4A58443439547C6856442A373C353449514239
3F3E53453C4051614E4A5C4B4E423B47494D535155715E3F2D333B58829B866E7A8E9C86
5B271E1F252332566C828791A3A3948C887E8AA4B7B7B6C2C4B4695A6C665A636B788EBE
9B3928312B2C262A40556346373A33342B2C3F2F332B353442425351483132292C2A2838
605A625E6F645C5A5A64677770717779817D837F817F85828182858588898A8C8889878D
8C8A8B8B888A89878B898E8E90918D8F8C8C8F8E8D938A8C8A898C93908F918E8F8C8D90
94969B999FA1A2A1A5A7A9AEB3B9BDBCCAD4D0CBBEBAAFB0AEADB8B6B6A68D8986848788
898F8E887B583E2F2A30282C2E35364B34312F2F323937333E4545484B534F5245414A4C
454B463B473E302D242427262A5E7B9AAE9B78867E4E7D848D86908D8D92938C989D9D9C
9C989B9D9A9B989799949994979797949194959195969A9396949294939395938C8F9394
908F8F959091918B8F908D8D8A8A888782857D808796A7B1BABEC2C7C4C8CACBCCCCD0D0
D1D7D4CFD1D0D0CDCED0D0D1D1D3D1D2D0D1D0D1D0D1D1D3D2D3D3D3D7D3D5D5D4D4D3D3
D5CFD3D6D3D4D3D5
4343464144423F4B42484746434845413D3F413D4748444A4E5B5E687C808892949C9D9E
A2A5A8A8ABACACACB0ADAEB0B0B0B1B9B6B3B3B1AFA6A69A958F837E6D62534545474D4A
5351586B8196886C6B68666F817C7556344C565A4A464F786862452D37363C303846463F
3B4550463C444F4D4655584C433A3E444746545F5E633A2E303E5275949477717C93908F
813B1F1B1D27293147687C848B7E716D6974838BA7A6A8B8C5C1A9565A725658636676A7
BE722A2628242628374D51413431302F282B38303732343A4748484741302E32262C2835
65675F5D6F5F4C515B61677870747979797D857B7F81828282898387858C8A8D908C8C8F
898D8B8F8A898888888B8D8C918D8E8B8E8D918F91919194928C92958F8E8D91928E8D91
9193959B999B9EA4A5B3B6C0CACDD5D1CBC4C2C5CDD4CAC1C1C0BFBFB5A8958E898A8A8B
898A8B88817B3D2C292F2B2E342D39443432342C2E3037343D40464C4A514C5643414C4C
4142423F473930302C2627262F6B7B9CAB90758E7D4B748288888E8E93909792959D9B9C
9C979A989C9A9C979898979A939491919391939394929490969790939394949A93949292
9291948F8F9192908E8B8B8E89888C898484817D8B97A3AFB7BEC4C4C5C6C8CBCBCFCED1
D1D1D1D0D2D0CFCFCFD0CFD2D1D2D1CFD2CFCECFCDD0D0D0D2D4D4D4D4D4D4D4D5D4D5D3
D3D4D3D4D6D4D3D4
4D4D4A44464A40484644484644434345413C3E3E42434E4E51535D70777D848D95989D9F
A3A5A6A9ABA9A7AAADABAEAEB3B0B0B1B6B2B3B4ABA5A09C9493847B7362544845454E53
5755595D6E889B816667666E86807758343C445365685F6D7A78583A2C373B34323F594E
3E454C4746463D3C41614C4E46414B4442485E68654339333550738789756B6F7A897E92
9E7D2F212B402B20265274726B695E605F6F828A94A09BAFBEC6C09053626057575D6685
BBB54029292428262D425238333932392F2F3835392F3A37434B513F3B382F2D262B283E
6A66665A7165535C62676A736F76827D7C83837B837D81827E83858889898888878C8E92
8B8E8C908C88898A8B8E8A8A8D8E8A928E8F9292929293908D9195938F8E929295909099
9493969B979B9B9EA0ACB1C4CFCBD1CFBEB1B1B8C9D3D3D0CCC9C0BEB4A4998E89918F8B
8C8B8B8D82814D35292D2E2F2E2C3A383332312D2D3243373F3C3B4348504C4E46424944
393943393B3A2C302A272727376E809DAD8D709275457184818C8B8E8D8F93929C9B9CA2
9A9C9D99A0969B9F9695999A979395959496969295939495959497909391919591918F93
9094918D9091918E91918B8E898B8682838483818599A3AEB9BEC3C6C4C5C4C7CACCCDCE
D2D1D1D1D0D0CFD0D0D0CFCFD1D1D3D1CFD1CECED0D1D0D0D1D5D2D3D4D6D4D3D5D4D4D2
D2D3D3D3D4D4D4D4
4A4A454A4747484B404A4446474849454941423E3E484D504B555F70787C888E959B9B9F
A3A5A6A7A9ABADACAAACAFB0AFAEADB3B3B1B5B1ACA6A39D9794837A6F60564A48445050
5252525D5D788A9371706C6B7B86765F343D4240576F6D707C7E683629303A3B353C5454
484344405041353154604B4A38494F443F50677554344943517B807B7B69756D837A5584
A7923A24313C28212B41595D6365606C61677887959F9BA8B6C1C6BB765765635B5A5970
93C19C3E282C29242A373630343837372B323B30322F4135444C4D4236372F2E302B2742
696164607A644A5C62696D7575757C7C7E7A82847F7F7E807F8586868A8B88898B8B9090
888C8A8F8B8F87888B8D8B8F8E8D9191939595928F919292909698999195949492929397
9798969A9B9BA0A1A7AAAEC4CFD1CDCCC0ADAAB1BAC9CECBCDC4BBBDB2A59C8F8C8D8D91
8E8A898E8483703E342D2E2B322E303231302E2B353834333E413E474B5051514D444B4A
382F4539363F32332A2B28293F708A9DAD8C7492684974848389908F8E929590939A9C9A
989A9F9E9A9A989599989C989C95959595969C9494939493949494949293919493929190
908F92948D9391928E8A8F8E8A868782837F81848696A2AEB7BFC1C5C3C4C6C7C8CACECD
D2CED1D2D0CCD2CFCFD0CED0CFD1D1D0D1CFCFCFD2CFCFD0CED1D2D2D4D5D4D2D3D3D3D1
D2D3D3D5D4D3D3D4
49494649484947434747434043444543423D463D4342474E4F5862717D838C9196989C9F
A3A3A4A8ABA9ABAAAEACAFAEACAFB1B3B3B4B2B0A9A4A299968A8379705F544F46484E4D
555F55575766789092746F67778476653B43433C455E6E6B7B82713D283033353B5E3C52
453D393E49423B375D53413E454D4648415279713B324C58747F86806F827C7C8965376A
9D99532F382C282C3F4B32344457666D656A747E9097A2A6AFB8C3C0B1655D5B56595A5F
729AC2953A2A262A2D38342F364438322E3335332C343D384A413D422D2E34302C292A41
6364675F7B59515E69766E6D7777787D7E818281818087837F8284838B8786898B8F8C90
8C8B88898B928A8A8E908D8B8E8E9694939595949595979292979C9C9394979690949196
94959B9B999B9A9DA4ABB0C4D4D3CECDC5B1A7AEB7C7CCCDC3C0BFBCAFA59C948F909293
8C8B868C89847E4E2F2E372D312E2C382F2D37322F2C333C4543383753525B4B47434550
3F36474332413134272C2726466E89A1AA84708C664F76838188908E8E919291949B9F9D
98979A9B979C9B959B9A9896969A939393959798968F9497979296939392929290939195
93938D96969190928A908E8E878A8484828486818196A3ABB7BEC4C4C6C4C2C4C6C9CCCD
CDCDD2D2D2D0CFCED0CFCFD0CFD0D1D1D1CFCECFD1D1CDD0CECFD0D2D3D6D6D4D5D3D3D2
D0D3D2D2D1D3D4D5
48484C4B46484A4C4B4643494A4A443F3D41443E4240454C545B64737D858C8E9B9A9DA2
A7A4A6A5ABACA9AAA9AAADB1AFAFB4B5B3B4B6AFACA8A09B948B8A7A6F635C48434D4B4D
5356525C5A5F69849797726B707C78603E3644423852546779867C4D252B2B2D5B64353C
45383038494635465F413D424E53424C574D7C7037404B5F66868C72799A797F7F49324A
8A9062423C2C2F323C2D282736465B5A67797E8A8F9798A6ADB0C1C3BE9F5B5D6D60595D
667CACC06E2F2A24282B2A2B3D4030333031312A2E363E2F4E443E3C312D362F27262A46
6C65685C77585B63656F70717276797D7B7E818082847F82828088878B8889898E8D888D
8E8C888C90928D8C908E938D949196949499979593939998999899A09A99939392969097
97949699969A999DA5A5B0C2D2CFCECCC1B5ACB0BFCDCCCAC5C2BEB9AEA9A199908F9294
908E898A8D857D68372E2E2E2F2D2E30322F342D2D2A3036414842394A505A5148424050
43394245393531312A2C242F3E708DA2A37D778B664E6F7B778690929294908F93979BA0
9A989997989E9A9B97969699949691959695969293979495969694979393928E8F919790
8D8B90908F8F9290968D8F8A8C8D8C8887887D8584919EA9B6BDC2C4C3C6C4C4C4C8CACB
D0CFD1D4D3CFD0D0D0D1CECED0D1D1D0D0D0CFD0D2D1CED0CED2CFD1D2D5D3D3D4D3D2D1
D1D4D0D2D4D3D3D4
4E4E4F4446474D484648474D4E4A494643433D3C3940454B596066708183899496979EA1
A1A7A7A7ABA8ABAAA8ABACADACB2B2B8B6B5B2ADACA59F9D968C87796C665A4B46464A4B
535E57605D6467748A998C736A777A694E33384140524A5876898967302E333746443235
3C3235374F45384B523F3D495A4E474B5C60776C4E45515059848269889F7881673A364A
747E6C4E47393F45251F1C263D37444C5870959C9A9592A1A9B5B8C5BEBC86546C5F5A5B
59708DBFB35B2C27242B2D32342E30292C32332B2D3133324B433936303134322827304C
74606A676F565E636A6E7073787A7777817F7E7E858382827C7F85888B8787878E8B8889
908B8B918B8F8C8F8E8D8F8E95949796949598969794999898999F9B979593928F94979A
9A97909897979C96A3A5AABECED1CEC8BCB2ADB2C5CECEC9C6C1C3B7B1A5A19C948F908F
928E8A8988878377472D3031312E3731323135312D2F343A4043463C3E554F58483C4058
483547433B2F332F2228232C3B7392A8A27E818D624A6B6E7583908F9394918F9593989F
9E9B9B9A9B9B9A979A99969397939794959294938E9399909795969392948C928F948E93
928C929592958F918E908D8E8E8C8C8B8787838582919FA7B3BDC0C3C3C4C4C3C5C7C8CC
CCD0D1D0D0D0CFD0D1CDCECDCECFCFCFD1D0CFCED1D1D0CFCED0D1D2D2D3D4D3D4CFD3D2
D3D3D2D4D2D2D4D5
46464C4B4A46494D4A46464E4D474A4B3F423E3B3C42484E515C677480848D92979B9DA3
A6A2A9AAACABAAA8ACA8ABAEB1B1B3B7B3B0AFADAAA8A099928C8378715F575149495350
4D54565D60605C68738F988C75707C6751435143394F5348617C898459463F3444473031
403230314A4B3A594B42414B534652435F7C66685B575747658A6F5F96987A78613E3F57
697061564F4B534A2B2424374733282F405495B6AA9291A6A6AEB5B4C0BCAC5F58625A58
5F6176A0C8AA3F2824242934312D2C2C3135343032383C3D4C403D433A33322C30302D4B
77696E6169515E6169737273747D7A7C827D8080837F8182848288858B898D898D8D8F8D
8D8A8C8C8A8D8B8C918C9294989A97979997979A94979C9696979D999899949494939598
959294939797989A9EA4ABB8CACECDC7BBB1ABB1C4CCCBC9C5C6C2BAABA8A1999893908A
948B89888587887867352E2A323134322D3131302B302D313F45433739585955463C4A50
4C36404243342D2B2924202C3D7898A9A57F89895950726774828F9395938F8996959AA1
9E9D9A9A9A9A9A9B99989A97929B94969A9697939698959492949198948F8D9590939093
92929194928D939089918D8B8D908F898987848785909CABB5BAC3C3C2C6C5C6C4C6C9C8
CDCBCED1CFD2D2D2D0CFD0CECECFCFCFCFCECECFD1D3D0CFCECFD2D2D3D1D4D5D4D2D0D0
D2D3D3D3D4D3D4D4
4C4C4C4A4546484B4A4B474A4E4B4B4A45413F3B3D3D42495355657380878A95979BA0A1
A3A3A9A8A8AAAAAEACACABACAFB1B3B3B3B5B0AFA9A89E9B938E827C6D61584E4E4D4C52
5857595C5E625F616A82919B8E726C665640323B3D4C5840426275837E72623437392C2D
312F30384B46424B4C473C525F53484357775C6E7356514C85815B6E99867A7555444356
605E5760625E5E4E3E322E3E422B2524344A7BA6AB898C9FA4A0ACA7AFBCB088535C6A59
5A62658AC3C791372C31262C322834312E31332E2D313731413D3C3B2E322F2C2B28264A
706F6E666654616C6C717170767F7A79827A7D7E7D7E797E83848582858C898991898D8E
8F8B888A8C8E8C8F918F949697999897979B9A9694989D999C9B9C9B979794929A989593
9294949491909497969CA9B6C6CDCAC1B7A9A9B3C1C9C7C5C3C5C5BFAEA7A39A97959190
97928D89898A897E7542362E363231332D2C302B2D302E32384C443B38525B54483C4950
4440393F44352F3227272230437798AFA388888E575770576A7D8C9394928E8D969498A1
9D9C9B9C989A9998979B969694969B9392969693919692949394919090928F95908E9491
93908F91919194948D928D8E8E8F8B8E8B848284868D9CA6AFB8C0C4C2C4C3C3C3C3C7C8
CACBCED0CFCFD1D0D0CFCECFCFD0CDCDCDCFCECFD1D4D1D0CFD1D1D1D2D1D3D3D2D3D7D2
D0D2D3D5D3D3D3D1
4E4E524D4447484F4D494E514B4A4949464443393C3C454B576267707D878892969B9E9F
A5A3A7A3A7A9ACADABAAAEAFAEB2B2B7B5B5B2AFAAA39E9D9590837D6B67524E4C484852
5953595F5F616267687387929991706256382C3B39435E4C3A465B7175808061423B422E
2D313033404043483F444353605D504565716D77724C47739D79567C977E7C66513F484C
5D5046565B5466494A413941462B23202E34497791878A8D979BA6ABA9B8B5AC5C4E6955
515A6994B3C7C57E3927252C2B2A313238383B39403E43424C4142423C3A3A2F393A3A5C
72746770625D636B6B6F72787B807F7F7D7F828584838386818588888A8F8A8F918A8B8A
8C8C8B8E8D8C9090959099999A9A9A9C99999B98989B9F9E9C9F9D9B9B9897979A989597
95929493918E8E95989FA3B1BFC9C8C0B0A5ACB2BEC8C6C4C0C5C5C0B0A8A09D9A918F93
92948F88888B8A847B5C372F303130323032332F2F2F2E343953473B35526056403B464C
483A3A3E4137333A2C2E2E304E859FAE9C828C90595C644D707B8B9199918C8D9693959E
9EA39B99999F9B999B9E9994979798929599979694949697969396989196939091939491
929791939392949291918C8A8B8B8D8B8B858281868C97A3B0B7BEC3C3C4C3C2C2C5C6C8
C9CBCDCED0D3D0CFD1D0CFCECECECDCDCECECDCFD0D1D2D1D0D1D1D1D0D1D3D3D2D2D2D6
D4D1D3D6D2D3D3D4
52524E4D4B47464C5153534B4E44484B4548423B3E40464D5762636E7B808A95929C9CA0
A2A3A6A7A9AAABAAA9ACAEB1B0B5B2B5B5B6B0AEAEA6A09A948A897D6C6355504A4E4C55
575D62606261616B686E76878F9F9372563F31353A4C635C4D465350616E937E5C3D3C35
323535414A4A564E45464D5C676F685A726E7E76694A4A8DA06B5D82967F7F594B3E403F
4D4C476C6A6F704438433C494E3A2B2A28313853808C857E85949FAAACB2B6BD8F516063
596276939CC1CBC374383537363641403E373733383A343D3F3836342C2E32272D2C325A
6F705D6E565660646A707476787B787D827A80807E7F8280848384888D8B898D8F8A8E8D
8A8C8F938F91919397969B979D979999999A9A9C9B9F9CA09D9D9C9D9A96949A98999796
949697929291918F959EA1ACBAC2C5BBA8A1A7B5BCCBC7C1C2C0C0B8B2A8A29E99929093
8F938F8987878A818275423132303435332F3631352F33343444483D35455F5D49414658
453F3F39463F353C2C28232F588CA0B49A7C8E8A51595C4467748B92939291909490929D
9D9F9C9B9F9B9B9C99969A95979493989797999594939495959696939699908F93939691
939392969593918F918E8D8C8F8A8D8B8684848581899AA1ADB6BEC2C3C7C3C4C2C5C4C4
C8CACCCBCFD2CFCFD2CFCFCFCDD0CDCECDCECFCECFD1D1D0CFD1D1D1D1D1D3D2D2D1D2D4
D1D0D3D5D3D1D2D4
525253565050505353505254504E4D49474648434141464D545E636B7B808B97989E9EA1
A3A4ABA8A6A9A8AAADADACB1B0B0B2B3B2B3B5B0AEA5A09A988A88807062564E4A4F5052
54575C5A5C5F62666967707885959A8751372A2C30495753473E4F484A46789370584438
352C2E3E474D4D4C3F525B5C6B716367736C7D6E574250969A6B70938D8571482E292F40
34364B6A877B64492D3B252F44473423212B36577C7E76707981878FA09FAFBEB265586F
6A63748789A4C2D0BA4B2F2E303030343431312D353433413638363632322F2C2C30345C
73735F695554646169717076777B7D7F807A7F807F7C817F8482848B8B898B898D8F8D90
8F8F918E93948D8F919398999B979E999C9D9E9EA1A49F9D9D9D9C9E9B9A989A99999693
919691918F8F8D8D949499A5B3BABFB1A198A4B1BCC8C9C1C2BDC2B7B1ACA29E9D969393
90918E89858481827D78603B31343435312F312E2A2B2D313442493B373F635E4A3B4759
4439413641422D36292822316891A1B3986F8B86515E543F5C6B838F939391919491969F
A09D9C9E9E989D9A999B9D9C9495979B97999D9391959196949894959299978F91969290
949593919394928D8E8A8D8B8D8E8D8C85848782878498A3A9B3BCC0C3C5C3C3C2C4C4C5
C8C6C8CCCDCDD0CFD1CFD1D1D0CFCECCCDCFCDD0CFD3D1D1CFD1D3D2D1D2D3D3D2D2D3D2
D0D3D2D0D3D6D4D4
4C4C4D504B4A494455524F5151504D49454C484444474A51565C626C7B8288969B999C9E
A3A7A5A9A8A8ACAEA9AFADACACAFB1B1B2B2B0AFAAA6A099948A8679705E5A4A4B504C58
575A63565F5D646465676A71799090825A2A2628334D5B57404246413F2C4E838E6F5033
2C2B313D514D54403F507656707D67696B707A685449559C937081988A8659322E293440
2E364F728A7B7267483724282F43573E2F354D4A626B6470726D6F778C99B0B1BA9E5B63
705F6A777D8AABCFD4A13A322E2D34383635323A393E403E3A3833393435312F31313860
77815E6751545C656D6D7275787979797B7D7C7D7B787D828682828685868E8A8C8A8D93
8E908E8F8E918F91958E94989A9B9A9A9C9A9F9E9D9EA29B9D9E9D9E9C9B9BA096969896
969690958F8A8D8A8B8D919DA4B2B6A59A96A3B0BDC8C5C2C3C2BFB9B4ADA49E9C989695
908E8C8A858483868081744936323530332A2F2F2B3231362B38413F38425D62443E505C
4D3C37303E4C292F2E2622367091A6AC966D8F8654604A3A4A64839393909092928F929C
A09D9B9A979A96999B9A9A97969B96999B98949496979695958F93909393989692939192
909192919495918F92948F91918D8F8B8684898284878F9BAAB5BBBFC3C3C4C5C2C3C2C4
C4C6C9CBCDCDCFD0D2CFD0CFD0D0CFCDCECDCED1CFD0D0D2D1D2D3D2D1D1D1D2D2D1D0CF
D2D2D2D2D2D2D2D4
515151514E48484E49474D514F4D4B4A434746494347484D54555D6C78818B91959B9AA0
A5A2A9A9A6AAA9AAA8A8ADADAEB1B0B0B2B5B2B2ACA39D9A948A84786C5E56534B485252
57575B5B645E5F656B6F7472727B817447292D242B5056514D45453D392D2E5985836340
392F323E4754563E3D5C79505B7E73645D637A7A664A679C8A65868F8879362924263238
2C3057809C939D833929211F2329586236283B3B4A5353646362666E74819BA6B6B48A60
646A5E65757D8EC0D4CB7730292A292E2B2F2A3232332D4641343436313332292A2D3164
777957664E575B606E6D73737A79797F7C7D7C7E7A8181847E7D8381818A898588908B91
9591908F92909095949495969F9A999C9C999B9B9EA09F9B9DA19C9E9A9C9E9A98969396
908F918F8A868785888D8F9798A6A49693949DADC1C6C7C4C3C2BFB5B4ACA9A299979796
968E8E908B878683817F7656313231302E29303430332A30333C3B3E3C455F5D45424552
43413A353D4D2D2E312929407796AAAA927391825765462E3D63828E909991909A969199
9CA09C9B999A999A9A9D989896969995959996949698949696949591989792969595958F
92949891938F909192928C8D8B8B8D8B86868982858B8D9AA9B4BDC1C1C6C3C0C0C6C3C4
C5C7CACBCCCDD0CDD1D1CFCFCECDD0D0CECFCECDD1D0D3D1D3D0D2D2D2D0CFD3D3D2D1D0
CED1CFD0D0D2D1D4
4A4A4F4F524E534B4B47544E544C4A4D45434045484C4C4B535259687A7D8B8E959A9BA5
A2A3A9AAA8AAABA9A9AAABADB1B1B0B1B4B4B0AEA9A59C968F8E84787060524F4C494D54
565A5E5B626060656975777073766C61442B2927324E61585A484D3C3C3025345C7F795F
4832304048635D4347516A43486E6F61565677846A5485A77A6285838C633123242C3E2E
2A306992A5AAA07D371D1B1C1F1F397861353655463033455A5D6C6D68777E919DADAC72
647566636C7283A2D3D7C05225262A272426292D31383D41343031302F31272529262E67
76795E644B555B676A7374737576747B797D7E7D8081827C7F83868986898987898E8D93
8E8F918D91929394979893949B99999A9A9E9A96999E9E9FA29C989C999D9A979C959294
8F938D8C86838B828385878D8F968F848691A0ABBCC5C7C3C0C2BDB9AEAAA5A39D949796
9392918E8C858786817E786C3E342F312F2F34312B2E2C32343E373A3F3B53584D4F4B53
44473A3631422A312B22253F859EABA78D788D8355633D2F30577D8B8F93919394939199
9DA09E9E9A9D9F9A9D9A989994999996989B9B9594949497929392969394969B94909494
9393958E918E939191908E918D8E8A8C88898588827D8A98A3AEBAC0C2C5C4C2C5C7C4C6
C5C5C7CACCCCCCCFD0D1D1CDCECFCED0D1CDCDCFD0D0D1D0D3D1D1D0D2D2D1D1D8CFD0D0
CFCDD0D1D0D1D2D3
4F4F5452544C524D51484B4E4F4E4C4741403F46474B474A4E525A66757F8D8D92989BA0
A3A4A5A8A8ABABA9A6ABABACAFAFAFB7B5B5B5AFAAA69F969290857B6D5E544C47475253
575B5D5E635D63656B767A797577675A512E35353E55615856424C46423125243768877A
69483F3E5C5555444F47583D3E6A7C60585463847163A19D6F637E85864F231F202A3D36
2A2F728DB59A77712F1D1B1A1C1F2657795E465E4F2823284A62606469756F7376879794
616A746B6C6F7384BBCFCF9D2D29252C23292A323A434E5A3435312A2730232A2B2F3563
7D7563634F52596970716F717578787A7D7A7F81817F82847F828685878B8C868C92918D
918E949393909493959A94969E9D989A979DA09D9C9F9E9F9F9E9F9C9D9897919594958F
8D898E887F7D807F8082808587888176797F8E9CADB6BEC0C0BEBCB7B2A8A6A19A9A9B96
9292918D8A8A86878084787655362C2F2D2B32302A322D2F313B33373C3C495C60483E4A
4540362D2D3C2D2B2E222C4987A3B1A28C7C8C8C6262372B285379828F939491908F8F97
9CA09F9E9A9E9C999D99969A99979B96969A969694959598959794969693919494939790
8F9394919490918D8E8B8C8E8C8F8D8F8985858484888599A3AEB8BFC2C4C4C5C3C3C2C4
C5C4C5CACACCCCCDCFD1D0D0CECECED0D0D0CECED0D0D0D1D0D3D1D3D4D2D1D2D1D1CFD0
CFCCD0CFCCD0D1D3
4E4E514F4A4852504E484A454A484C4744424142434A434D4C4B5666707D848E91989AA0
A3A5A6A8ABAAA8ADACAEADADAEAEB0B2B6B6B4AEA9A39E959090847A6F64574F494B504F
545D565D62646468656E7A7E7271655862533A393E555D57563E4E5645342B232B4B7189
756A4E445D485957524A4335447584694B46657B7180AA8F59587B957F32211D272C3736
27306F99A78C4C50351E1D2426232432707C6D4D2C2F23224A5B444D65695E656D606F7E
6D6D7A7F84847A879BB5B4B7633127232324262A3B524B4B46452C2C2D2D27333B342C57
7179685D53515C61696B70777674767E7E7F7E7B7E7F88818580868687868C878D94928F
9191989294909491959493989C9A9397989D9C9D9E9FA3989B9E9E9A9794969893938D86
8686827D7A7A80828287848686827C7477767A8089919DA9B4BABFBBB4ACA8A2A09C9C94
94978D8C8B89888486867F78693F2F2C2F342E39342C2F332D3D333B39384E5E4E413950
5244322D2C3B312827242B4F8EA6AF9F8E7B919465593B27275070818F94959595918D94
9BA09E9E9D9E9C98999A9C9D99969492969598959495949496949695969A9B9697939094
918E909393948D918E8D908F8C93908F8C8A888683848A939EAAB6BDC0C2C5C3C4C4C3C5
C4C6C4C7C9C9CBCCD0D0D2D0CED0CECFD1CECECFCED0D2D0D1D4D4D4D2D1D1CFD2D3CFD5
D0CFD0CFCFD0D0D1
4E4E57504F4D4E504F4D4F4F4B4646494A45444648434447424453606F7D838C95989C9D
A1A6A8A9ADADADAEABAAB1B2B1B1B5B1B3B5B0ADA7A39D9A928681796C5D564B48465054
595C6160676165696B6E6F7879797153576055423D635A524F425062503B3D312D274682
8C7662554D3B566163503D323D78806E62527075739CA878464F70A56B221E1D21272A32
292F6D929A7B43302C2825212420222B57897A5532292620324233314E3D3B55534C5E64
70707B8B949694999FA8A4AE9E5F3727262023282E383C2C312F2B2A2B31262F2F2A3163
747368524A505E666C68746F717577807E817B7B7C807F82828188888A898A8B908E9593
9294939595939187969693969A97969C989B9E9CA19F9E9AA09E9A9C9594949592908982
7E7B7A7E7C8082848784868685847E777776747078767E889AACBEBCB3AEA8A49F9A9B97
9892918C88898884848187766D5A3430332D303833312B2A3040373540394A4D55424049
4D43322B2C37382B25232D5E90A6AF9F927A918D5B532B262E4F647B8E92919593908E94
979DA09F9E9E9C9C9A9A999C9692999997999994979798959D95999695949B9592969793
96929390968F909391939091918D91898F87868E898085919FA9B1B8C0C1C5C4C6C3C5C4
C3C5C2C8C9C8C9CCD0D1CFCECDD1D1D0D0CFCFD0D0D0CED0D3D1D2D4D2D1D2D1D1D2D1D1
D0CFCFCFCECED0D0
4F4F5552514E4E4E4E4D504F4D4E4A4741454B4845453F424245525B6D79818B93989B9B
A5A4A9A8A9AEAFAFAAACADACAFB3B0B5B2B2B1B0ABA6A2998E8C847B6C59574E4B4D5355
54605C5A616567666F6C6F6E73746D4E4A666449415F5C55524E4F6D5A48504826233857
8D89716D4134486A6E5332304B7478646458797976A59B673D448BA05F21202C23232D32
31375864765F3131282A2823202228315967817F54362C29343F3F38332D242D2E2C3B46
698D899399A1ADADB1B6BEC0B9AE8129252627242A2F2B2C342E2C2E2F3228312C313060
6E6D644D4E506365666C75777175767D7D787E818083828385858A88868A8E9190938C8F
8F909597959795969D979A9C9D999A9C9A9B9F9EA09D9D9C9EA29B97989194949090817B
74787D7F7F837F807C7E837F817D776F6E67626D79787A7E869BB1BBB5B1ABA6A29C9894
94908C8E8F8F918580828481736240302F313137382B282D2A4232333C394648553C3943
4D46302D2E3741282922326594A5AB9E8E7D988C6B483022294E57748694949395979394
939D9F9E9D9D9BA19B999A99989896939795979498949497959695989695929193939593
9392919293918E8D8C938B8B8A8F8E918D8A85868481848D9BA3AEB7C0C3C3C6C4C3C4C4
C5C6C0C5C6C7C7CCCFCED0CFCFD0CFCFD1D0D0CECED1D0CDD1D2D2D6D2D2D1D2D4D2D1D2
D2CFCFD0CDCFCED0
4E4E554A5049504D4C514A4F514E494A4741443E4047463D3C404C5968787D8B9295999E
9EA6A8A8AEADB1B0AFADAFB1ACB0B0B2B3AFB0ADAAA79F96918B847C6F61544C48444E53
51545A5B626063626769706D6F6F6B544962604E3D5D5E5E546E7E7B66594E482B23272F
6794816841353C676F462E4E426D745D555A7A7D8DAC8F543041949250252531242B4345
4032473F473C26212324232524292C46564F759C7B56372C2E3234343835272620221F23
5192979EA2A2AFC2B9BEC0C7C6BCA23C2325232728292727272B2B2F2D2E2F2F2924295F
6B70664D4E535F66636A6C706F7875787A7A7D7D7E838283848389888A88909090929094
92919796989696939599979A9F9C9B9F9D9F9D9EA09D9F9F9E9C9B96949494938C8B7C77
7A7E808278736C6560666D78746F69606457617177787B85869AA8BCBEB0ACA7A2A09A92
9193918D8F8C898A848383837E6C543031332B2C2F312B2E2C3C3330373E4746533A3645
543E312F2D383C2524213B7597AAAC9F837D9B845E3D2A2737484A708191949591938F8F
919AA29B9F9C9B9B9A979A9599969496979895969593979494979A989796969392959395
91919192908F8F90959091938D8F8C8D918C8A868886848695A2ADB9BDC1C4C4C4C5C4C3
C3C6C3C5C4C7C6CBCDCED0CECECFCED0CDCFCDCFD1D0D3D1CFD2D3D4D2D2D2D1D2D1D1D3
D2D1CFCFCDCFCDD4
5353524F554E53474A514E545054494745404340433E3938373D435767757F868E96989A
A0A3A5A8ABAEACADACACAFAFAFB0B3B2B6B3ADA9A8A69F96918A817F7165594A4B494E4E
575D5D5B5D6167676A67706E716F6B4F3C525A523A5C5E55546D8C93775C4E4C3E272031
3B7D9D70523F334D6F422D4947766E5C635973879FAF7B41354993853E242B37273A4365
5933473C2E242323252123272D30485F4D4263B1A4763D292E2A2A2D2B31322B22201C22
2F81A4A6AAB1B4C5B7BEBFC1BEBCAE6534232128282A2525262B2A3432342F2C27272E5A
6D7069474F555C626466696E7473797C79807D7D7F83828180858787888B8C8B9393938E
9493999796969598979494989D9C9FA09E9F9B9E9C9E9D9C9FA296969895948F8B857B75
7A848384816957463B4751615D5C5755595D7276767C7E8995A1B4BCC6BDAAA1A5A19490
959293908A8E8C8B878781817C7760392D312F302C2E2B2E2D39342F343B43464B404049
523933323034352A26243E7B94ADAD9E7C7D987E60362328403142647A8E949494948E8E
949B9E9C9C9D9D9C99999A959B9598979398979695959398969298979697979693969296
93948F9192918D9290929290938D8F8E8B8A8A8584858787949CA9B6BCBFC2C7C6C4C6C4
C5C4C3C5C6C4C6C9CACDCDCDCECDCFCFCECCCECECFD0D1D0CFD2D2D1D1D0D1D1D2D1D3D1
D3D3D2CFD0CECECD
4D4D5350514E4E5353495148484D4A464442433B4441393A2F354054626F7D838B929698
9EA4A6AAAAABADB2AFAEB1ADB0B1B0B4B3B1B1B0ABA59C968C90837D71696152444F4C4F
54565E5A60626A69686B6B6F74726A5D4D4E544B4055655951667A927D6356504F352624
3667A5875D583B405E3E2B3952796C5D63586C94ACA96B342E519D7E3B292E313136484D
423D4F3D25232328211F21292F3B4F42303567B0AA7E34232522262B2A2E2C2C2625221F
2158ADB1ADB3BAC4B4B7BDBCBEB7AEA27430292A232126262525262C382E2A2E2B2B2D57
6A625F4B4951605E60626B70717579787A7A7B808182808282868A8988888B8A908F8D8E
9A9696939999969B9C98959A9C9A9A9D9CA09F9E9F9F9EA09FA1989394918D8F8A827779
81848688836541323132404D59605A6371757A7E797B7F8E9FA8B9BFC8C7AD9F9E969596
9498959392908D8B858281807B766A4B312B282E322E2D2830393635343C434550463643
513D303233322D2C26284A8894ACAAA183818F795F36252F37273A617B8296989794948E
909CA2A19E9B9D999D9C9B989A9C959594999C9595959495959495959096989794918F94
9293948F9095938B88949091928E8C8E948A888486858185909BA6B1BBBDBEC6C4C5C6C4
C4C2C4C2C3C4C6C6C9CDCCCCCFCECECDCDCCCBCDCFCECFCFD1D1D1D0D0D1D0D1D1D1D1CF
D1D1D2CFD0CFD0CF
57575B50504F544C514F4E4B4D504E45443F42423B39383633313B4F5C6A77848E8E9699
A1A7A8A8A9ACADAAABAEACB0B0AFB3B3B4B2B1AAA6A399978C9081796D69685A534B4F50
58525B5A5F5F666264696D76757D8D5C5D5048423F4D57655F5F6E817765524C44402224
385892986E61513D52352E3357826E5E575673A0B59A5C40376DA373382A32312D334D3C
39335C4D27202427332C383F4A3D332B2F335481897344282624272B252B2C2A25201D1D
1F37A2B4ACAFADBFB3B3B8BDB9B3AFA7A15B3C35272521222226292D2F2F252729252E5E
6E585B47504C565D62656A777379777D7C7A7D82807F7E8284878A8D8C8B8A9090919090
959B94929A94979A9C9598999D999F9C9E9C9E9C9E9D9D999F9D9C9692948A8A87807478
878485848A78563A38394959667273777E797B797E83838D9FB0BCC4C9CCBFA59A949693
919392948D90898B85807F7E7E7B725D3A33282C262F2F2D2D373B38333E43414D4C3740
4E3C30303430242A282658909BABA7A08B8B8D7B60312833282C2F556D8B919095928F90
8F979D9EA1A09E9C9A989A9B9A979C9794949394979796969797969899969694958E8D93
9390939A92938F91918F918B92908F8A8B8E898A8783817D8899A6AEB6BEC1C3C6C4C5C4
C4C1C3C5C2C3C3C5C9C8CDCECDCDCECFCDCBCFCDCDCDCECDCFD1CFCECFCFD1D1D2D0D1D0
D2D1CED1CFD0CFCD
5A5A514F534D505C524D535247484D494244413C3E3F3B312D2C3A4B58657B7F868D9597
9FA4AAA8ADACAFACAFAEABACAEADB4AFB2B2B0ACA7A3989A8D88807D6E6265696067645C
5D5A5D5F5E616564656B6F787D767B6457534A32354A5D636962687A6B6A584C414B2F25
33516C8F855A533D422E2A36617E6D524955769FAD844337357EA65F31292E342C2E302E
333A5F482520272B2B3A4C413F392B28252A33434B71624F47332929272726262C292021
1D258CAEA5A7A7B4B4A9B0B0B4B9B4B6B4997B4C2D292620222222302D2B262829253460
6F645C464D4C555C5D666D746F797A7D807C7D857F7D83838288868C8A918D8D8F908D92
95959697959A9895979597999C9C9F989D9E9E9EA09FA09D9B9E97968F948A8A84716C71
817F89878585837770757E7F8082847E7A7A797981848F95A7B1C1C8CDCCCDBA9992978F
929797929093908B898B84827C79766849312C2A282C2C2D2D30353233363B3A48473A3D
4C3D2830362A23312A2C578AA2A9A9A18C8B84765629242F22212942658194909690918E
8C959DA0A0A19E9D9D9B989797979997979494959A95979B9897959A9998979994969692
92919497959393959790928E928F8F8C8D8C8E89848485828594A3ADB5BCBEC2C6C6C5C4
C2C2C0C2C0C3C3C5C5C9C9CCCBCBCDCECDCCCDCECFCECDCDCFD0CFCFCDCFD0D1CECFD0D3
D1CFCECFCFCECECD
58585653534D4D57504A4B514B484841444242403F3E2D2C2B2B3A4D586975818490969A
A1A7A7ABACAEABADAEADACAEB1AFB1B3B5B5AFAEB0A29C9C8F877F7771625B596D7F7F79
7F6F675F5E626465676C7175787A776A58454C3D3C425B60606F67796D56574F48443631
394C40648F694E3F332D2F396B81654A4152819EA16A392E3E8B8C42312D393F372B302B
323B50432A2021282A364A37382F2F2C28282A323F69827270472D27242427222E2A201B
1B1D62A89DAAA8A6AFA9ACA7B1B5B5B8BDAD8C774F3729242626272C2931312F26273258
695B563E3A47555A60656E7473767D7C7F837D84807F83808586838B908E898D8D978D8F
988F96999397959797949B9C9CA09A979CA19F9F9E9E9C9B9A9B969192908B9480746C74
7C7D878A8786878684868D89848B847E7777767A859194A0ACBAC4CACED4D2CBA7909394
919491908F91928C888A80807E7E786F594431292A2A2C29293639333235403D48523D46
503D2D3230292634282A6790A5A4A8A08F93787250322E2B2525253E5D7F8F919394938D
8E949EA19E9F9C9E9B9A9A9A999A98999A9A979499979898969694969A98959496989595
9195969893949693918E948F8F938D8A8A8B8B868A858083848FA1AAB1BAC0C3C7C3C2C4
C2C3C3C0C0C0BFC2C3C9C9CBCDCACDCECECDCFCFD1CECECECECDCFCDCDCCCDCFCFCFD1D2
D0CFD2D1D0D0D0CE
54545856554F504F51494B4D4B49484B49473F413D3B2C31292834445469777E8591939A
A4A6A7B0B1AFB0B0AFAFB1AFB1B4B1B3B3B3AEA9A9A09B978F887F746B5A544D56606E7F
8A908474656069696B687376787573715D444F46483B5B5A546E797577554C5A4F443D48
435230468283514B2E2C324D748B63484066919A956032353B8D662E323F4A4744312F28
2D3A493D23252929303A47406B524F3C2B29353C4C5E746E51312E252022211F2528261D
1D1C3BA0A3A3A59F9FA6ACA19E9B9FA9BDBAAA8F5D412621201F2635282F282A2928345B
6A675A47443D53585F697072747676837B7F84817F7F8383868686878D8D8D908D928D93
9091949C9796989B9C9C979C9D9E9B9E9D9EA59E9E9F9CA29D9A9794998F918F83756B72
787D858F8D8B89888A928D8F908C837E78777A7E8A949AA7B3BCC7CED5DBD9CFB78D8F99
97929696938D8E8C8C84837F7E7E7E70684F3A2D272A2E2C283532322E3840414445404A
4B3E2E352E25293830347292A6A59F9793967E6F50332B231E232634548288939193958D
8C8D9AA1A09F9C9F9B9B9E9896989B999795969693969596989598969596949691939292
9A949493959794969091918D928E90918E9187888B89847E868D99A4ACB8BFC2C6C6C4C2
C4C3C4C1C4C0C2C3C2C6C7C9C9CCCFCDD0CFCECED0CFCFD0CDCDCCCCCBCCCBCFCFCFCFD1
CFCFCFD1D0D0CDCF
56565555515450505051504D4B4A4740413F3F3936352F2E2B272E405066797F868E969B
A0A5A7ABACACADAEB0B0B0B0AFB2B3B1B3B2B2ACA8A49C99938B7E7A65584F4B424A535F
71878B8A83696A636B6E6B6B7175776E674F434A3D3F5C5E48527874826E42505D5D4A41
52492F38788D5D4D322637546E8C623E497F949A8F5532305088462B323139484C36342E
2B2637392420233538414F68A1939F6940354050596771653F332A2F2927212724263127
20212A78A9A1A6A49996928180757782A1ABBDB191653124242428263227232728252C5D
71635943454A4C5C5A696D6F74787B80787D7F8280818581838887898C8B928F90908F8F
9395979796999598A19B9D9F9C9F9F9F9F9FA29F9E9F9DA19E9A959292908B8C7E786870
767D86868D8D8E898C8D8C908E8A827C797C7E828B939DACB3BDC8D4DEE2DCD4BF918E93
9695929390908A8C88868180827A7C7A725B3F2E2429292626302D3330383F3C404A4849
4D3B2F392A22223329377694ADA3A0969192876B413232232227242E5B757E8E92939391
8D8992A2A09DA09C9D9D9E9B9DA298979895999699959299959594959696989394949495
93989492919494959192918F9190918E8E90888A86888282858691A1A6B3BCC2C3C4C6C5
C5C5C3C1C3C3C2C3BFC3C4C6C9CCCECFCFD1CFCFD1CFCDD0CDCDCDCBCECFCCCED1CFD0D0
CFCECFD0CFCFCDCE
5454575154514E50514B504C47474343413B3F3B3C392F302C27303D4E61777E878C969E
A3A5A7AAACABB1B1ADB0B0B0B0B0B0B4B5B3ADADACA09C97928A7E7A6B5B504747464C57
61777D8B8E827068686A6C6C78747672654A454E4C495C625C3D5D737B794F454D5A5142
4D483B3964907A4C2F283658778A5F3A5487879B8A54313867823F2B2F2A30353C4A443C
362B2B2F212225484E3D595A6C859F5846545E6D96A294805F4B3D45332F28272225302C
212225478C989A968881766B6D6476838792A2AD9C6E372925262323272E242F46252E57
715B4E4643444E5957636B7672777A7B827E7C827F80828686868C888F8E91918D8E8F93
9C9399969695979A9D9C9F9C9F9C9D9E9EA0A29E9F9D9F9F9D9A92938E8B8D8A7D746B6D
747D83878A8D8B888B908D8F888680807D7D83848A949EADB7BACBD7E4E8E2D3C2928F94
9692949393938E8C89878380837C7D7572674C312E292930312D37342F384342484E4C41
4D433536242321312F3E8493AD9F9F969D958B5F333C37252222272F58717E8C90978C94
8D89949CA0A09A9E999A9A9899969B99989491999693999B9695959498999A9795969998
95949A929195939693959194A29194928F898A8E8586828085848B9CA6B0B9C1C1C5C8C4
C5C2C2C2BFC3C3C3C1C1C4C7C8CBCBCDCFD0D0CFD0CFCFCDCECDCCCBCCCCCCCCCECFCFCF
CFD1D0CFCECDCECF
52524E4C4D4E4F4F4F4D51494B4E4549413A3B363635302B2A24323C5461767A838F9699
A0A5A8AAB0ADAEB1ABB0AFAEAFAFB1B3B4B4B0ACA7A49D9790857D76695C4E4944424A53
565B687E7D7F7F7A6C6A6D6B6E7374726D553643475556585632476B7F78624C3F585C4F
4644403F477E905933333D4E717E563B63868AA0864D393C856D2B24272A322D2B384C4D
402A27241F24263739365738377172425085A9A29D84716862676D685B43312524242432
26221E224C7883787A7A67656C6C90B5ADA38D909A875A452D23222B252B282822232E5A
6D5A43404B4E51535F5F6A747176767D7F7D7C827D81838685878B8D8A8B8F9493948F93
9B97979A98969A9A96999C9A9F99A29F9CA19FA2A4A3A1A19B999899928C8B8F7F77726E
737C8087868B888A898B8F8484817C7D7F84878D8C91A0ACB1BBCEDDE6E8DFD4C3919391
9193969798968F8C88848681867D7E76736B5D3D312C2D272A3239312B2F443F46494B46
474731352223232F30478099AB9A9C969E92865D283D2A21222D2B2B5168778792969393
8D908D9C9DA19E9B9D9D9B99999A9895969A959897959A9695949497999695959697989B
969696959695939890918E90958E8F8E8D8B898A8C888380868287979EABB9C1C1C5C8C6
C5C4C3C3C2C3C3C1C2C5C5C5C6C8CBCCCED0CFD0D0D1CFCFCDCECCCBCDCED0CFCCD1CDCE
D0D3CFCFCFCED0D0
50504F4F504D4F53524D5150524A4A4D403E403837332E3529272E3E4E61787F848E939C
A0A4A9AAADB0B0ADAFB0AFB0B4B1B2B6B2B4B1ABAAA49B92908B7E766E5A4F4845494B4D
51585F6169757F84786B686D727A7B7C7767393A4C56635C5A3D44657473655C403D5368
5D4D43433B64926F3A2F32416774573D668892A2724635468A5327282631412E262F2A49
3E3C302C2528232A2C3A62342E534F4F6079A88D7763514842476F87734F3A2F28232330
2F2B1E23285165677E856A6E727290B9C9C3A682977D3424231F1E232925222A25292A5C
6C5C413847484F565D67686C737575797D7F808482838287858886878C8B8D9091939395
9A9B99989897999A969A9D9E9DA2A39FA2A69EA2A4A4A3A19D9C98989691908E857C7975
72767C84858387868483827F84797B7B8186868D8E96A4ACB3B7CBDEE6E6E0D4C696938E
909197969895938F8E888685807E7E797173644A312C2C282E2D35372E303B44434F5342
4942392E222224333B54859EA99B8F98A08C805F373529272328232D4A597486948E8D90
8D8D8E97A4A3A19F9E9F9B9C9B999B989C99969798979896939491939596979595999A94
979692939495939691969392968B8F8D8D8D8C888D8E8885858483929BA8B5BFC0C4C6C6
C6C3C2C2C2C3C1C4C2C0C1C1C6C6CBCCCCCFD1D2D0D0D0D0CFCFCDCCCACCCECFCFCDCED0
CFD0CECDD0D0D0D0
54545151504A4A4D4D4A4E484F494E43423E3F3C393530332E2431455765737E868F959B
A1A4A8A8B0A9AFB0B1B0AFAEADAFB1B2B5AFAEAAA3A09F99928C7F76665E554D4B494B53
53555C5C5D676C7C826B6B7585848D807A75583F3A3E485F56534D57646C605F66423959
6062554A404B7A8546464E3E5C715346688893A36C3F3262823624272F2F2F342B2B2C35
312F3933302F2F2A315367483F454F475263858176616359433244595F473B322A25312C
372F1F1B212E4F4B6D877672807B7E9EC9CACAABA0A33C28221F25272B27262C25252C59
6A5D3D42474D525958656A6D7574767B7E7D8080818585858C8782858A898D9492979693
999697979896949B9A9E9FA2A0A0A0A2A5A59EA3A5A29D9F9D9B9892958E8E908A837C77
72797D8286868B8783817E7B7C7A7C7B7E8487879398A2A9B1B3CEE0E6E5DFD3C1919897
98979896999B928C8888868480817F7E7E6E6751352927292B2F2C332C2D3A4341445241
4345462E2823222F4559879DA39C889C969081442C292F2B2723242F454E68808E8F9091
8A888C979BA29EA09B9E9C9C9A96969D9B97989597989698949699979B97999895949691
94939295969491969391909092908E91918C8E8C8985828784857F8C97A1ACB5BEC1C6C5
C4C4C3C3C2C3BFC0C4C3C2C2C4C7C8CACCCED1D1D2D1D1D1D0CFCECCCECCCECDCFD0CFCE
CFCFCFD0CFD0D0CE
4F4F504E544E4D4D4C4E46494A474B4344454137333434332A2B2E44506777808491979B
A1A2A3ABA9ADB0B0B0AFB1B1B0B1B1B2AFAEAFA9A5A29D9794877E72655651494B504D50
50535A5B5D5F646B767C7B878A898883887B58473438486E68675D4961685E58695E3A38
4F6C63534946768D545D5F445E7C5C4F7081969A6A3A35766E2524262A302D2E303A3331
2B312E2D2A39323233655E674C4B5B4A475B7AA38B70756E5A423B3D5A4F42442E2A2429
3A32212330212C285C898A7578787992BFCCCECABFC57F2F2222272B2922282727283056
645A4137484553575C6066717577777D8080808784848486868A878C8F86909092969993
97959894969A9D9B9C9C989EA3A2A0A5A4A4A0A4A4A3A4A19E9B9D9494928F8E88857D7C
7A7B7C7B82838C857D7F7B7D7E79757A7E83858792999FA7B1B8D1E0E6E5DED2BC959C9D
9C9A98959798948E8A8A8A88848081827D6D64564630272B29302D353242454249454748
464B363723212032465C8CA4A59B84A091897235372D2D2E28262D2C4C44637C898E8F8C
898A88939EA0A29EA1999E9C9E989B99959B98979897989894979C9CA095A59797939491
949593939494959792909593928E8F908E8D898A8A8D8A87878280868D9EABB3BBC2C3C7
C5C4C4C4C2C0C2BFBFC3C3C1C1C4C4CACBCDCED1D0D1D2D2D1D0CDCDCFD0CDCFCECFCFCF
D0CFCFD0CCCECECD
51515650574E4B464F4B45454B474C49434343353732322F302F303C5368777D8691979B
9FA5A7ACAAADAFAFAAB2B2AFB0AEB1AFB2B1AFA9A49F9D96908A7E726857504A4B46464F
4D5A5C686F71787E76777A7470727D84827E654834353463766E694F4C635457545E4B33
39565959584D5D857864543D5B796159707B9D9A5F3A447B53212A282A2E283230392F2B
2E282C232229362F355A494650585F533C4A6A9E7F706F7256415282A3A1916D35232532
382F2C1F1F221E2244829A7B7176737FA8D0CFD0CCD0B94926232A26282C242425222853
60543C414A4B545D61676A71757779777F8080858181878386878B8C988A929090969892
999899989A9B9E9B9B9F9A9EA09FA3A7A7A4A3A09EA0A1A39F9E9D99959192898887827E
817F7E7C838387837E7C7B7F7F7975768180898A959EA3ADB1C1D4DFE6E3DDD1BB939C9E
9A99989A95989A8A8B898E828681827F7A76645E4B392B282B2D2B3434343D493F3E4A49
4C513327222122314C6E97A7AA9881A58E886D2C26232F30272A282E3B3C5F718B8C8B8F
8C898A939E9DA19E9F9B9D9F9B9A9C9994999C989499999A989998999B95979796969694
9695959597969390908F8F8E8D929194908F8A8A8F8D8689838485838C94A6B0B7BBBEC3
C5C4C3C4C0C3C0C0BFC2C3C2C1C2C4C7C5CBCACDD1D1D1D1D1CECED0D0CFCDCED0CFD0CF
CFCDCFCDCDD0CECE
5050514E4F514A494B4C4C4A46474743443F413E363736312C2933415A657982838C949C
A1A4A9AEACAEACADB0AEABAEAEAFB1B1B3AEAEA9A5A297978F8C8072665950494B524949
51585D6E85908A83756E65696B6B727C7475644737433D6E846C71514169615A4A4B6156
353F4860625B51717F684B3A63856E666C79A1955C445D8949262D292A393941373B2F2D
26292C2A252830382F443B40546B6A4F393B4D71656E757A674F8BBDBDB89E793C232E3D
4E3523201B1E1C1F2F6B8F867370747690BFCDCBCECCCEA338252426292526272224254D
664E3A4247454B5761676C7171797E807A7E80808382878889898A8E8E8F94939091989B
9796999A9EA29E9D9CA09F9F9FA2A6A8A2A6A4A5A2A0A4A5A2A69F9E9A93938C8E858584
84808181847D84827C7F7C7B797B797C7D82868C929DA0ABB4C4D4E0E5E2DBD2AF94A1A0
969A99979592968F8D8A88858883827E79746B6355432E2C2A303734322E3F413F3D4E44
52542D27221F26344C7199A7A79A80A692815E2B222437372C29342E35395872818B8C8D
8B868C8D979BA3A1A09E9FA09A9F9A9893939C97999A989B97949A95979497979B979897
9392949596978D928F9393908B9490918B8B8A8A908C88878A898286858D9BA8B2B8BAC3
C3C6C4C2C3C1C2C2C0C2C2C3C1C1C3C3C3C6CACCCFD1D1D1CFCFCFD0D0D1CECFD2D0CFCF
CDD1CDCCCDCDCECF
4F4F4F4C4C4F4B49495149474A4A474547413D3F3B3A38322C2E354055677D818A92979D
A1A2A9A9A9AAB2ADADADABADA8B0B0AFB2ADACABA4A09E948C897E756259524745474A4C
4C5D6C939C9086868B776E736E7C857F7A74573C3A474F7A95777169434E6B5B5167647C
413236546B5C4B4D79824C3A5787757563769686585B8A904A3838292E3A383537393028
2523292925283D4834383E5D72816F4F3E383A414666767B7876B4BDB9B699682C26324C
734D2620211E1D1D25508395796F797678A5C7C8CECFCECE893125262527212329272949
5C48353C45494D5A62666C72747582837D7B8083867E8487898A8A8689909A929096969B
9997A1A1A1A3A09E9FA0A2A3A2A5A8A5A3A8A9A8A4A5A8A2A6A69FA09B969190898A8883
838382848481817B7C7D7978787A7B7C7D81898C959FA2AEB9C2D3E0E6E3DCCEA899A1A0
999B969A959292938B8B8C88828481837D766C6757443128282B2C39302C3B4344414D48
465A342524222335487B9AA4A79685A78987572B1D252D3B2B292E302A3051647F8D908B
8B89888E9A9AA19F9E9E9D9F9DA09C969393999B9B9C9C999B9B999C98979B9A98979493
94909492959494939292929290938B8E8C8C898B8D8E8E8B858686838486949FAEB7BAC1
C2C4C4C2C2C0C2C0C0C2C2C2C1C2C2C3C3C6C8CCCDD0D0D0CECFD0D0D0D0D0D0D0D0D1CC
CECBCDCECCCACCD0
4B4B534E4B4E4A50505548524E4A4842433F433E423C353736333C465265787E8A969498
A0A2A6ACAAAFB0AEADAAADABADAFB0B2B1B1ABA7A2A09795908A8073655750464C50494B
56657F9B8A6F6C89A19D85766A70838B84705336333F486C8C7C7D7E5D3C637853433C40
433435425B696248668E543B4E89837566758F7846599B793D3C3E32393E38333B373029
22272A25252429362C3A436F827B6656433B33304E57667B838DBCB7B7B5945E29333D5C
857646241E1B1B1C233770A08B6D7E767591BEC3CACACCCFC3642821232526211F272E4B
5544353A444A515668696B706F7B7E7D7D81838185817F898B8B87888D9298919697999A
969BA19DA3A29A9E9EA2A4ABAAABAAA8A7A9A8AAA6A8A6A0A0A5A19E9B9598918C8B8A86
858083868785827D7E807C787A7B7C7B7D80888D96A0A8B3BFC5D3E0E3E1D9CA9F989D9F
9A9B9899959592928F8D8B84868383817E7A6F665A463A2C282B2D31312D37433E444E43
4E582F29211F223349829CA6A6918CA7897F5429201E2A3830282C2C2C324965788D8C8D
898B8888999D9EA09EA09FA09D9C9A999898999A9A999D9A9A9C96999796989398949593
94949391928F95949392909190939292928D8A8C8C8E8C8B858888837F858E9DA7B1BCBE
C2C2C4C5C2C0C2C1BFC0C2C1C2C1C2C1C4C4C7C9CBCDCDCFCECED0D1D2D1D1D1D1D2CDCE
CDCCCACBCBCACCCE
53534C504D4E4E4C4F504F4C4D504C45413E453E3A38332F302C3A4D566578828A8D939B
9EA4A8ABACADAFACACACACABACAFB0B2ADB1ACA7A59D9D928E8B817763584E4A4949484D
5673948E6F5C657891A4A498816F717C878058312A37363D607E808B8353527A79483C3F
383E39313763705D4E926A414C788F7964738D72416E9762383C433F3D4C35333A3C2C28
2527262021211F2C364449606C6656544C49302D535F4B638192ABB6B4AF884F29345166
887758241C1D1B1A1E2659929E716F6F7185A8C5C9CCCBCCCEB546272121232A25232947
563F3A383C45555569666C7076777D7D858182848082828487898D8B909093959D979C9D
98A09DA1A4A2A1A2A0AAA7AAA6A3ABACA8AAABA9A7A9A5A5A1A5A1999B9897928E898688
84838383878381817D827E7B787A7E7B7E828A9198A2ABB7C0CBD3DCE3DDD8C49D9BA0A1
9B9A99959695918F8C92888483808681807E75675E4A493429352C333533374B40444F47
565E2D28282728355588A0A9A280939F878454291D23283A3931322E27253C5D72858E91
878F8C87909D9CA4A09DA09E9C999D9D9B9B9996989B989C9A989696969B9C9895959797
929296939796949391928E908D8F8C8F8A8D8C8B8A85898A8A867F8681858795A0AAB6BC
BEC2C4C3C6C2C1C2C1BFBFC0C2C0C0C4C2C2C6C7CBCBCDCECDCFD1D0D1D1D1D1D1D1CFCD
CFCCC9C8C9CBC9CC
50504A474C4E485250514D4A4947464346444047413A37313033404A5F697880898F959A
A1A3A3AAAEADB2ADABAEAEACB0B8B2B1B2B0A8A8A2A298948E86817365594B4A474F4551
5C808F7B60615D6474879BA4A294857781786541272C3931406F7C8A9A8562607979483E
323C3C2D34517B6444695B323A60988C757E8960447B864B33333C363C493E333B3E2E2C
2626292728252A302C313E515B5C504D554F322D486257506389A4A8A9A075483343627E
937F60261D1F241D1E243B819C7F756E707EA0C6C7CACCCDCECCA53F2623232321212B41
573C37343C45505B64656C7074767C7981818083858687838689918F928E939397959B9C
9F9A9FA4A2A0A4A0A4AAACADA6A3ABADACA8A8ABAAA9AAA7A5A5A69E9D9D979488878584
868587868883828383817C77787D7B7E8383888A99A2ADBBC9CED7DADFDCD6BBA1A4ABA3
9C9D999A949496908A8E878A858186857E797770604C423629272A3139323E463A3D414C
56592D2629282F325E8BA2AC9B7B9E9A8B75502E1F202C3A3734322C2D2840576C808C92
8C8C89858C999DA3A29DA0A0A2A09F9A9C9D999D9B99999D9D9799979796949993969598
939395909396909391948E8E8E8D91918C8C8B8A8E918A8A888E8C888081828E9CA5B1B9
BCC0C1C4C3C4C2C1C2BFC0C0C1C2BEC0C0BFC3C5C9C9C9CDCCCECECFD0D3D1D2D2CFCECF
CBCCC8C8CBCACACB
54544E51484F4C4B4C4C5149484B4A4D454140423B393234313040495D6C77818C8E949D
9EA4A6A6ABB0ACABADACAAABAFB2B3B0B5B2B0A4A3A099978F8D7F766E5E504B4D4D4B4C
5F7D87745D5A5E5D696A778DA4A9A99991886E452A2E373A35516B819C9C7649517C7C5B
3138332F2B3B746E494D563735569689838C855C5A9270323534363A37523E3843372C2B
252E26272A252930282A2A41534D4C43474D3A2E38484E5B5C799CA29889613D3553749B
AD9869261E2024231F20265B8C947C6E6B7490B6CEC6CDCFCDCDC98B31222727242B2644
55382F35394C565A65666F7173767E788385808385858586878B8B90938F9598989898A0
9DA0A49C9DA0A3A8A4ADB1A9AAA7ACA8AEB0ABAAACACA5A7A0A5A69F9E989994918A8586
8686848886828580807F7B7A787B7C828283838C9BA6AEB9CBD6DDDDDDDBD0B5A3A3A5A0
9D9B9D969493938F8A8C8485868481827F7F7A77625042373029282D3737364439353F4B
5758302526242C2C6291A1A69B7D96938A6F4C3529242F38383935312E27304E687C878C
8A898B888B969DA4A49EA3A0A1A09C999E9D9B9E9D98989A999A9A999C99989496959496
93919196919093918F90908F90908F92908D908B8D8D898C8E888584838283858FA1ABB6
BCC1C2C3C6C1C3C3C2C2BFC0BFC1C2C2C0C1C1C4C4C8C7CACACECCCDD0D1D1D0D2CFCFCF
CECBC8CAC8C7C7CB
4F4F4C4B47474B47474A4C4A4F494547424343423E3E353337343D48586B787F8D92939B
9DA2A5A9ACB1B1AFAEAEABAEB0B2B1B2B1B0A9A8A29D9A94928A817669555546484A4D50
5C798A7F685F6160696967727B8A9BA0A59E8F61443A3B363146536E8E947A573F5D7D8E
60392E2C2E35607548485736383A72818A8F7F536C92593D38373837343C3A304043312A
292E2728332B2A3A2826263F47444147463E39322A353C51616686938F725439565F80B6
AD8A5129232328252028243B7A99836D6F6F81A0D1C7C9CBCCCDD1C15C27202623242540
4E3931383F4F545B62656C706F787C7D7E857F87848685848D8F8B8C9093989B99999C9E
9B9E9CA4A1A6A3AAACB2ADACACAFAEABACAEADA8A8ABA6A7A7A1A29F99959795918A8886
8984848787878A7E7B807F80797B7D818589899099A7AFB9C6D5DADCDED8CCAE9CA2A59E
A29D9D9A949194968D8C8A89887E857F7F8278796A57433D34332A31363A323E39373A4C
61502F28252526336798A4A59A7F968B81683D3720232D383F353837312C2C3D5E7A838D
8C898C8889999BA39FA0A2A19C9B9A9C9E9B9A9B9C999A9D9A939A939796949892959392
9492939393938F9092938E8F8C8F9390908D908991918A8B8D888B87828182808B9AA4AE
B8BCC0C3C5C2C3C2C2C3C2C0C1C3C2C1C1C1C1C1C5C3C7C6C9C9CCCECCD0D0D2D1D0D0CC
CDCCC9C9CBC9CACB
4A4A4C50524E4D4B4C4C504D4E5248464A4749433B403C3635323A47586877818D919B9D
9FA3ACACAFB1B0ACB0A9AAADAEAEADB1B3B1A9A6A49C9596918983746C594F50444F5450
5B748582645F64626A6C676B676E7A83889598958C7454482F404A587086806A51415683
88583C3436373C664A3E56493E374C728D8274588480452833413A423C4035334939342D
32372B2C292B2A3327262F4C495532282E333D392D2D2D3D606F768883684F4F897993B2
986E32212E22262B2B2827306090956D64707985C3CAC5C8CBCED1D4A72F222525282F39
4837363C4751535E656E6D77747A807E83837E848286878A8D8D8D909794989697989C9C
9B9D9CA5A9A7ADABABB4AFADAFB1AFB2AFACA8A7ACACA7A9A7A4A1A29E9A9993918A8985
88868587889186837F81817A7D7C7C8489888E9196A3ABBBCBD8DCDFDAD6C8AAA1A1A29E
9E9C9A9A95929692898E8B8986848680817F76776B5A463C363031303735333E3839414F
5D472A21242224316C9EA9A79C8598938D6434432431282E3B343C2C2D282A3C5C77828B
8F8B8A8987909DA39FA2A4A19E9D9D9B9D9A9B9997979899989999959697959496969597
96929090938F92939290918F8E959690928C8E8F8F8E8D8D8D878A878486818685919AA9
B1BABEC2C2C4C2C2C3C0BEC0C0C3BEC1C1C3C2C3C3C5C6C5C7C9C9CBCBCDD1D0D1CFCFCD
CFCCC9CACCCCC9CD
4E4E4C4B494D4D48514C4B4B4C4B4B45444043443D39363530333F49556A79848F93959D
9FA1A5ACA8ACAFB0AEACACAEAFB3B2AEB1AFAFA8A79F99978E8A8274655D524C49494E59
5969737062606563666A696F6B6E6F6F70767582A39C887260414B4650707D696B463B5E
7F7C5E3B3A3739494E3852353132405D897E6B4D8062383238463C3A363937304536332F
2D2F322E292F312F282B2C466B5F3125242F45352A2E28324D70707B72564A75ADA49A94
70492D2621222528242A2B2A4D80977964707B7DADCCBCC4C8CCD0D5C87535292226273F
43312F363D475164686C707779798080807F828084898C8D8B8D9392909891999798999A
9E9FA2A6A9A5ADA8ABB3AEAEAEB1B0B1B0B2AAA8ABADA8A8A8A4A39F9D9B97989592908B
8C8B89898B8B86847E817E7D817C8381848991939AA1ABB8CED7DDDFD8D2C3AAA0A4A1A1
A4A196999396969E908F898C8A838283817E78776E5F513D3F2A2830333A2E35393E3E4C
584731272628253973A2AFA6988C9A968D57373D23212634373F3A2F363231354C667E89
89888A87838E949EA3A1A6A19D9D9D9A9C9B989C979B989A989A96989A9C979496949795
92928F9093949392938F8E928F8F8F8F9091918F92908F8C8C8B878686828181808898A5
B0B5BDBFC2C2C2C4C4C4C1C0C2C1C0BEBFBFC0C3C1C3C4C3C4C8C9CACACCCECCCDCECDCC
CFCDCCCCCACACBCA
49494E4B4C4D474C494C4C504B4B474745434545423E3A37373C4345556776818F93949B
9DA5A7A9ADABB0AFB0B1ADAEB0B0B3B0AFB1AEAAACA09D9790898576665C50494D5A5259
605B62605D626568666B6B6C6E737272716852547F97949399765A4643546D6A71633F46
5D73856C4C3A39394038433237334771907B5E517A4C323C3C413A393133333142392E2C
2B3532302B2E30252E2E2B41586A332A2437432E2A282B2A516D7270614E5A98A4AC976C
442C282B262126222320282833718F8E697074778FC7BCBDC4C7CBCFD1B3442A2324282F
3E2F343C434F5163686C707A7A7B7B7B7E8183888282868C8A8D8F909298959A999B9699
9D9DA0A5A5A5ADA7AEB1B0ACB1B5B1B2AFADABA9ABAAACAAA7A7A5A1A19D9A9293938F8C
888A8A90888F88858380827B7D7982828389909A9DA6B1BACED6DFDFDBD4BFACA6A6A4A2
9F9C9B969995969A8F8D8A88868186817C7E797A6D614E3C3F312C2930372F333135394B
5F4C30272628243577A8B0AC9388999B8E4826302829242D413D3A3630342E3246627889
8D888B8986858DA5ADB3B29E9A9C9C9C9E99979F9E9A98989A9797999A99969394949496
9295949693949495939390918F8F8C8F8E939192918E8F908E8C8C868786808782838F9B
A8B1B8BEBFC3C2C3C5C0C2C2C2C1C1C0C1C1C0C5C1C2C4C3C4C3C7C6CACBCBCECECDCECC
CCCDCDCCCDCCCACA
50504B50494F46484A4A514843484B43444C44433C404038343B4148546674828C90949C
9DA7A8ACAAADAFB1B0B2AFAEB0B1B1B1AFAEAEABA49E9A989385817A695F534F4F565255
575E5D5A5F62696968696A6A716F7172746D553A507A86858E90795A3F435E6371625645
4A6472806C463636343A38393B35588A8E6C5C5E703C3338413D35322B362F333F2F3333
2C3E332D343231313D37352C3A412F30304A442925223A416066717B675A7FB09A907A45
2A222B2F29222122292622242A53859F787374777BB6C5B8BDC4C5C9D0CC973229292935
432C303C3D4B555F656E747F797678797F83828C84848589898F8F918E959698999C929B
9B9AA2A7A3A7A9AAB2AFB3AFB1AFB1B8B1AEAEA9ABB0AEA5A6A5A49E9D9B9F92928C8E8F
898B8C918B8A898984817C76847F8083888D90969FA8BAC3D0DBDFDED9D3BBAAA7A3AAA4
9D9C9E99989891958E8D898A878184838282777A716553443E3A3429273D31322F2F3345
5D4B2E2C29252B4079ADB4AF91889E9E7C3B2B29222423314343402D313833353D597586
8F898F8C868A90AFA3C6A5A1A19B9A9C9D9A9A9E9A9B9A9E9A979A9A9595949795959593
909494908F92939091918E8D90918D908E8A92938A918D8B8D908D87838682847F818893
A0AEB3BFBCC1C4C3C4C3C3C3C1C2C2C1C0C1C1C1C0C3C3C3C4C3C5C7C8CAC8C9CCCDCECE
CBCDCECACBCDCDCD
535354524C4B4753484A4B4A4B48484649404147403F3D393635434C58677D848A92969E
A2A2ABAEACAEB2B0AFB5B0AFB4AEB0B1B1AFAEABA3A59D9990898475695E524B494D5156
5959595F6A6A6865696D6D6C7172737175726440405A7767687C827C5E48475F806A604A
474A5C6C776B4F3B2F2B353B5550679B825D596D6B423E4D3A433B2B2A2C2C343E333336
3337312E333132332D2C48292E2D2731405B3C282222314B596571846D6D95A69377582D
252320232225242322221F212539729A8B737270749BC6B9BBBFC4C3C5CCC26A32302A2D
3A2D37343C4D59656C71757A7876787E83868487828585878C9094928E929194959C9D9B
A2A2A2A8A6ACAFB0B1B0B8AEB2B4B5B7B0AFAFAFABB2ADA9A8A6A7A2A2A09A96958B8F91
8C8D94938E8A8B8586817F7E7D838086828D9398A0AAB5CBD7DBDCDDD8CDBFAEA9A8A8A8
A1A1A29C9A9A9295908E8A8584837F807C7D7E79756C55423946372F2C34363133313A4D
5E49342929262A3B8AA9ADA88D94A19E6E382C24282A26344144373A332F2D2F33556C83
888C8B8B8D86919B9AA2A6A59F9E9E9A9C9A9A999C9B999C98979797989A989A96969594
90959893949293969697949191929296908F8E8E8F8D8F8E8F8B8B8A8485868483817D8D
98A3B1B7BBBFBFC3C4C4C3C2C1C2C2C3C0C4C3C3C4C3C3C3C2C1C3C5C4C7C9C8CBCACACA
CCCFCCCBCDCBCCCA
5050524D4E4F4D504E4E4F4F4849474649494947423E393B3B373D465D6A798488929598
A3A6A8AAADAFAFB4B3B3B2B1B5B0AFB4B4B2B0AEA59F9A979684806F685C584E4B544F57
545B626461606A6A6E6F6C726F7275747D7E6A505158545A504A6677715C425F7F665944
3C3B47586D757A5D3C31383C4F6D7F92745B66744E35406D4A3C3A27292D2B352F373733
36352E3036372E302C334837333533324B573927211D2C394F666F8684708F9B88593E27
2524272C27232226322522221F295B8994766F6F7384C0C7BBBDC6BDBDC3CEAC3A2F2B2D
352E3236404F59656C727175757B7B82837E8289858886848B8F91909390909597989DA2
A7A9A5A8ABACB0B2B4B6B3B0AFB4B7B3ADAFAEA9AFB0AFABADA9A2A39E9B9B9796918F93
908D92948C91888886867E7F7C82848585899097A7AEBAD2D6DADCDBD8CDB7B0A9A5A4A6
A1A29B999896918E8F8E8A858589808380817E7A716860453D3B37312831393834353A48
614B322A29272C488CA6AAA38598A598612C2D232B3B29333C3E33332F2D2C2A2F4A6279
838C8B8A8D878B9799A1A1A2A09B999C9E979C959D9C989A9A99989C989B969692949693
979592989492919494958E8D91959690928D8F919293908D8B8B8B8B8A89858386817A83
939FA8B2BBBBC2C5C6C5C6C4C2C1C1C0C2C1C1C3C4C5C4C2C3C2C2C2C4C2C6C7C9C7C9CA
CACCCCCBCDCECACC
5454514D5052524D4F4D4D474B4D5048484D4A4544424B38383E4547596B7A7F8790979B
A0A6A9A9AFB2B1AFB2B4B3B7B5B3B4B6B5B0B0ABA7A0979291898677675E574D4F4D5A59
5B605D6463626E69666F6E6C6E77747C847D6E4E5D5B484852554B5E66634D405A5D504D
34323C45555F7176583C313C436B8E916E5E626941453F476C323A38312D2A2D2A2E3A36
323132313232382D2C34403131393A305452362923201F29566D6B8E86837F9783433133
2C2827292A29252831252A201D223A769493707478759FCCBEB9C2C0BCBBCACA90352325
2C2B2E37454D596167757379757C7D7E83827A848186848589889296969593979A9E9EA5
A7A8AAADACB2ADB1B0B1B4B4B7BEB9B5AFADAEA8ABABA9ABA8AFA8A19FA09A9B9C989393
969095928C8D8C8A8486857B8081858489868F95A4B2C1CCDADDDEDBD7CBB4B2A8A5A4A5
A4A29F9B999897938C8E898688847F8081827F7D7467604C3B393C372C34403434323A46
5D48332727232F4A86A0AEA27E8EA497572930282B2A28344D3A333636332B2E2B425A74
84868D8A8B868C9197A1A1A29F9F9D999B989796979B989B9799999A989696939297979A
9695999294929395939794919596949092958F8F929290908E8F928D898B898880817C84
8698A4ABB5BBBDC0C4C4C2C4C2C0C2C1C1C0C1C3C3C3C3C3C2C3C4C4C5C3C1C3C7C6C5C7
CCCBC9C9CBC9CCCB
5757564F544A4F4C4E54494A4D504F4C4A4B4A4842403C3A3B353E44586C7B838A919B9D
A2A5A9ADAFB1B1B4B1B3B2B4B5B5B3B3B4B1B1ACA7A2969492897D6F6761584A4B50525B
5C5C5E6169696E66656C6D6F7071707C8083785C5A5D4E485B62595559685F4A513D484F
37343742495561707359363C4755838685836D623939394D69373136352E30302B303030
2D2D292D3937352B352D483651583B38594A352B241F272C5B666E958F886A7B78542F2F
383335242A2C2A29322B27282224335F90A48373777286BFCCB1BEC1BFBAC1D1C1622827
282C30344448555F6874747979787C80807F798083868A8C8E8D92989898979B989CA0A1
A6ADADB0AEAEB3B5B3AEB6B3BABAB6B4ADB3ABABACB0ADACA8B0A6A4A59D9F9F98969394
95919495958C8E8C8A8587817E81838483899798A1B0C6CFDBDFDFDCD4C9B9ADAAA6A1A2
A29E9FA198969593908A85878583847F8280787D716E6252403B3E3A29303E3434353A47
5F4D362D2A272E4C86A2ACA57C92A89253282F23262C2A304B363537312E312E2B38586E
828A938E8C86878D98A1A0A1A2A29F989B9B989799999D9A9C9B96989895979793989298
929696969293929192959494939594908E9490959A939190918F908E8887858789808084
82929EA7B3B4B9BEC2C4C0C2C1C1C2C2C2C2C1C2C1C3C5C2C1C1C2C4C1C1C0BFC3C6C6C5
C8CAC9C8C9CBCBCB
505056504E5454514C504B4C4F5151504B494943463F3C393D393E4B5A6B79828C93959C
A4A8ABB0B0B2AFB1B3B3B2B3B6BBB5B1B8AFB0B0A7A49D9590877E746C5F5A4F494E5357
56576060646C6B776E6D6F70737275808384796769666A5D69605F5655545A5B5D3F3A42
44352F3A3D434C626F703D374A51727D7C918D764E483C58572F30333F342F2D312F2F2B
2F2D2E33303539292A2D3F58603E2B415E402D262722242F5F626C8C8D7D6B5A665F3730
2B23292B2F2C272632333026212A2C3C789794766D7D76A4CDB3B6BFBBBCBDCAD1AF4229
272D393637475761696D75787A787C7A7B7A7A8383868A8F918F91989899989D9C9EA2A6
A8AFAEAEADB1B1B4B3B4B4B2B4B2B0AFACB6ADAFB0B3AEB0AAACAEA7A6A29F9D9A989299
99929195948F8C8C8A848983817C8184828A939CA3B3C5D2DEDFE0DAD3C8B7B0A9A6A1A2
A1A29B9E9C92938D8E8C87868784837C837E7F80757062533C3339392E303A3B37323848
565136342A292D518EA6ADA48193A07E422B3622222A2B2F3D332F34332E29322C304E6A
7B8E8F8D8A93848A9199A19FA0A09B9B9C9A99989C9B9B9C9B98959B9497989699979595
959990969A969496959592909395949190948F9292918C908F8C908A8C8C868787828580
828791A3ABB0B9BDC1C1C3C4C3C0C3C2C1C3C2C3C4C3C1C3C1BFC1C1C1C3C1C3C0C3C2C4
C3C6C6C6C8CBCAC9
54545558535A5751504F524F4F554F4D4A47474443483F3C36393F4D5D6B7A818D94979B
A2A6AAACAEB3B4B1B1B5B3AFB4B6B9B8B4B4ADA9A6A19A9990857F756459574F52505257
5C5C5E62696B798483787475716A767F7F807B758280735C5F574C454B4F4A4E5A4B3A3C
3D4139363F3A4851536E563C4660688368789189767B736840332D2D39342E2E3130312A
2E2F2D312F323731383A5E613B2C2C485D5031281E1F26355663778F8C7C6F5A46503A2E
2E26322A30322A2D2E2F292726282A325C889B7F69797983B2B8ACBBBDC0BEC8D1CD9835
24262F323B415461656E727A777B7C7C7F7D7C868187898B8F938E95969B9B9C9CA5A4A7
A8ACAAACACB1B3B4B4B3B3B0ADB0AEAEAEB3B0ADADB2B3B1ABAAA9A5A2A19E9B9B9B9A90
9291908E928B8B8884848081847F7F80828C929FA5B9C5D2DADCDEDBD0C7B9B2A9A5A3A7
A09FA39D999690908D8884868181817F7F817D7C796B6A563C343638302F35423F363451
4C54342B29282C5D95A6ADA08DA0A1783D2F31272624282E332A2F39382F2A2A2A2E4463
74898B8C888B878A8E969F9F9FA09E9AA09C9D99999BA1979C9A989897989B98969F9694
9595949599959794969490919295948F9094939191948D8F9091908D8E8D8B8786878082
87868996A1ACB3BBBDC1C1C2C2C2C5C0C2C3C2C5C6C3C3C3C3C4C2C1C0C1BFBEC0C0C1C2
C4C4C4C6C6C8CAC8
59595453595F585451504C4E515E4D4C4D4F484749433F393B3B434F5C6B79828F94969C
A3A8ACACAFB0ADB4AFB5B1B3B3B2B7B7B9B4B5ACA7A39F98948B7F72665A564C4F4A5451
56595A5D67677582898C88848079757B7D83827C7E8175605447383632425C5B4F4C3E42
3F413D39493D343F4856645846535D7677636F8C867E8F753A353530363636312A2F3133
2E352C28302D3234465E5741363F3F536A4D2F2424283132456181918C7F746746373829
2E2F322E2D2B2C2D2F2A2F3329292A303A6C94977373787590BCA8B6C1C1C3C3CDD2C97C
2D21282D38475560626C6F777C7B7A7E80807F87818A888E9494919397979D9D9DA5A5A7
A7AAAEADACB0B1B3B0B5AFB0B4B2B7B4AEAEAFB4B3B0B3B2B2ADAAA8A6A1A19A9D999A90
92929490948A8D8A818587858382827B7F8990A0A6BBCBD1D7DDDBD5D0C7B7B1ABA7A3A5
A3A2A297989491888A868786847E83827E80787B7A74695A46394041312D2F423C36344F
42573B342B2B315D96A2ADA594A59A6B323A322B2A2E2C362929323330332A2A2C2B445A
7583888C8C8B87838B94999EA0A09D9C9E9B9E9C9D999C989C9F999898969C9997999796
9996969B9496959493969B9591939291918F95948F8E908E939392908B8C8B85878B8482
8384888C9CA8B1B7BABCC2C1C2C3C4C4C5C4C3C4C4C5C2C3C3C5C1C1C1C0BFC0BFBEC2C0
C0C3C2C7C4CAC9C9
575756585A585755575350554C4D534F4D4E4B484A3F3F3B3536404D61747B7E8992939C
A3A1ACABAEB2B2B0B2B5B6B4B6B6B3B6B4B4B3AEA4A29D948E898075685B504A4E4F4E52
5459595B61686B6875838D969E998987918E807A818A80817E704330352E3C5153543E36
353C3F434044383A414552685E524F5C815B516D8E7E83805C473C34343539352E2D282B
292E2A302E31363C504F3F4B6A757389906E4C2724222829396386938C7D756A563E352F
2D2E2E2E2F2D2E302E2D2E2F31302B2C365389AA807372747DB5B5B3BCC0C3C3C6CFCFBD
5829242E34444D575F696F777577797C7D7E8682838D898D9493979897989A9EA1A2A3A7
A9ABAEADABAEB3B2B4B0ACAAB4B3B0B1B1B2B1B0ADAEB2AFB2AFADAAA9A7A49B9C949394
9498958E928A8D86828886847F8483828589919EA7BACAD3D7DFD9D2CFC4B8AFA8A6A5A2
A1A19E999893918B8887868680828482817F7D777D71685F4B393F3C302B3C3B423E3543
4355382C2B292F5F94A7B4A797A68E63394336282A2A34322C323638392B30292C2F3658
6F818E888E888881879799A09EA2A09C9F9B9E99989C9A9A9A9B9796959794999799969C
959295949B989595949592929291929490939191918F928C938F928E8B8D8A8886878485
828384878EA2A5AEB8BAC0C0C2C4C5C5C4C3C4C5C6C7C3C3C2C3C1C2BFC0C0BFBABEBFC1
C3C3C2C4C2C5C6C5
5A5A5C5D67645658545256515353534C4A4B494546413F3B3939444D626C7B858B92979F
A0A7A9AEAFAEB2B2B4B2B3B2B6B6B7B6B3B8B1ADA39F9D998C8984746B5E544F4E4F5559
5C5B5B5E63626667676B738494A1A39D9DA19992968E99A2909D854D3C4434394960573D
38393C3E3E3F4246463A516D65564C5677724F516275807F7963563F2F2C2A33292C2729
282E2A292F303E545043466E757C7F7F7C766A4D3B35312E325F8688827263615F4A302D
3335342F3A2D2D2C30302D2B3029292926316F9E9470666F76A6C0ABB4BDBCC4C2C9D0CC
A83D2A2836414B545A66717574757A7D7E807E81868A8C8D9290949898959E9EA29FA4A7
AEACADA9ADAFB6B5AEA8AAABB2B2B1AFB6B3B1B0B0ADAEAFB1B0B0A9AAA4A39F9A939195
95949193908C8C85858586877D818382858B939EA8BBC8D7D9DFDDD4CDC2B8ADADA9A7A4
A6A29F9F97958D8A8885838682827D8281817A75756E6957463A383D342D334049363A45
3E563A2B332B2C679DA4B4AB9DA48C512F443F2F2E2A3B392C282D3339332B2E2F2F3453
697A8B8D88878B8285929A9A9EA09F9A9D9A9B9C9796999A9E9A9795989B969896959797
949695959B9D989795958E9191978E958F92919197978F919092908F888B8A888C888984
8E8384868896A4A9B3B8BDBFC0C2C5C6C6C4C3C4C4C3C2C3C2C3C0C0C0C0BEC0BFBDBEBE
BFC0BFC0C0C1C1C3
5E5E5E5D6B645D59585C55565654574F4D4C4E4C4B42433E3B3A414F5B6778858A92989F
A4A6ABABAEB1B0B2B4B3B4B6B5B8B6B4B7B4B1AEA8A09E9990897E70685E50514F4F575A
5A5D5A6261615D64646C6E707583888E92A0A098A2A2A8AB9E9DA58E7A63524B4C4E5853
41363738393D43463E3349656A54485B697971535362797280766345292825292A27212B
3832332E2B354B546A656F757A7D706B5F56688A90876940325F7D817666535659532F27
2E32362D2C31302B3035302B2A2C2927282D5493A27D66677088BBB4AEB9BCC2BFC2CBCE
C8903430333F4C535F5F6F727579787A7B837F8384888A8B90929799959A9DA0A0A2A7A8
A8AEA7A7B1ACB4B0ADA8B1B6B6B1B1B0AFACABA5A9AEB2AEB2ABAEAAA8A3A09A98969690
8E8E90918F8C8B86817E87877C7F8080848D969CACBDC6D7D7DFDCD3CCC0B8ACADADACAD
A99E999597928C8A888B858785857D827E7B7C7677726A5B4739393B302C313841373549
3B5537302B272F74A09EB1AE9E9C794A324134222228433D2D2330393538352F30312A45
6576848E8C89858386899A9DA09F9E9F9B9A9B9B9B9A959A999896989B9A989A96959695
989A979A9696989995939492949B9692939390929194958E91918E8E8B8A88888B8E8886
8687878885889BA4A9B2B8BEBFC2C6C6C8C5C5C6C8C8C5C1C1C1C1C3BEBFBFBDBEBDBEBF
BFC0BFBEC0C2C2C3
58585D5C5C5B575B545456565552544E54494E48423F3B3B3B3D42505869767F8791989E
A4A5ADADB0B2AFB4B2B3B2B5B5B7B3B4B7B2B0ADA9A29D998D887F6F655D5A52504E5056
5D5D5F5F616561666A666B6D6D6F7272757F888782858D959BA4AEA6A59D968B8C76644D
49473D3F3E43464642393F607A5747526E79757B585C705F6879735D4B2B282529292529
322D31343A445B6D7554626C6C62585A4E5C959DA09F987645446B635F5251554D422725
2834333429262F2B2A292F2D2D2E2B29282D42779C986E616A76A4BEA7B1BCBFBBBDC6CC
CDC17A36343D474B56676D727075787C7B83818084878C908F94989C969B9D9FA0A5A4A8
A8ACA7ADADACB0ADAEADB0B2B2ADAFACAAACADA8A4ADB1B1B2AEB2ACA7A29B9B98959390
8A8E8D948F8B8884878182877C807A7F838B9CA3B1BEC8D3DDE0DFD2CABFB7B0B0ADAEAB
A39B9494908D8F8C88888B8884837E7D7F797C76746C6B5D4E47383C363332353B373146
3A594029232635799FA2ACB3A695774634473C29252B42332B2A2C323839312B2D2E2B3B
5B70828D8C8887858686939D9E9F9C9D9E9D9B9A9D9A989A9C9A9C99999B9E9B9A959599
9A9C97959899989A999794979091929395929093939393928F908E8F918D8B8F8A8A8A87
89878682808A8E97A2ADB7B8BEBFC2C7C8C6C4C6C7C5C4C5C3C1BFC2BEBFBFBCBEBDBDBC
BFC2BEBFBDBFC1BF
5B5B5A5C565E575A555354565156504C51494E4C4744413B3C3B454B586E7B86898D9997
A1A6AAACADB4B0B7B1B3B2B2B6B7B6B7B4B5AEB0A7A39E94928882776C5E564F4F4F5155
5B575B606167646B696D706E6D6E6F707473757C73676C768BA7AB918F90929EA299937A
5F5044393D3A3A41403C3A5176644E477280697B705B59544D6786755F41232225282C2A
332B393C51637B7F6455575650454563757B7C7783919DA07E3D40484A4440423E2F2C2D
2D36332E2E2C2D2830312C3431372C2B322C29528BA57E6967708CC0B2ABB5BCBEBDC2C6
C9C9BB593637455152616B70716F797E7A8482828A8B8B8D8D92979D9AA19B9F9FA2A9A9
A4A5A5AAADA9B1ADADACABADABACADABAAACADA8A9A8A9A9B0B0ADA8ACA09C9A9A95948D
888E8E96898B8980838281817A867A7E878E98A5AFC4CBD1DADFDCD1C6BCB8B5B1AFA8A7
A09B9A9895908D898488878382857E7C7A7B7A72706E645C4A412F3834282D383F41313F
3F5243322C2A3A7CA0A8B0B7A58F7539374A4A2A2531413931302A2C3433312E30312F3D
556D7A8B8C8A878484868F9899A39F9B9E9A9D959C9B9699989A959997959A9998979698
9695979897969398969892969496949093929292969190938D918C93918E908D878C8B88
88848786838382909CA5AAB3BBBDC0C2C4C5C5C7C4C7C6C6C1C1C0C0BFC0BFBCBDBDBBBA
BDBFC0BEBEBEC0C1
61615E5F5E5D585B5E58555657544F54555051504542443D3D3D49555A67798689929A9A
9FA8A7A9AEAFB2B2B1B5B6B4B8B8B3B6B7B6B0ADA8A0A2968F8A81756961574F4D525358
5D636164606668666A6E6F696C6E70736D7175797A6F606E73828F796F65718594919285
775C3F3838393230312F374F6D604D506882745F756A5F3F41476C816E522F2624262730
322E394F6272816955503D3B484D4F6D826D543C5C6973A6AB723B323336333432313431
3337362E2B302C282F322F35332D2E313127273A6F969B746C6982ACBEA0B3B8BFC0BEC4
C3C7CCB04C39434B575F647070767C7A797F7F7F8C8B8B8A93939698979E9D9F9FA7AAA9
A1A3A2AAACAEB4ACABA9A3A6A5A8A6A9ACAEAEADACA8A8AAA6A8ACA8AAA3A2A099948E8A
888D8D8D8A858387828183847F85807F898F98A5B5C5CAD3DCDFDACFC6B9B4B4B4B1ABA1
A499989598938E8E89878A837F7F7C7D79797C72716B645445413B3C34292F32343C3B36
3D50492D232A3A779EA6B6B4A6936E4039454D28233236332C352E30373735312B2C2D34
446573858C8C868885868C959C9FA19BA39B9D9A9B9A9B9A9A99949498959A9599989796
959996979699959993969295949B9696989695919292928D8C938D8F908C8C8E898B8D88
8A878688878281888E9DA6AFB4B8BDC0C3C5C6C5C9C5C5C3C3C1BFBFC0BFC1BDBCBBBBBC
BBBCBBBDBEC0BFBE
63635D605E595B58575B59545052505052534E4B46463D3F3D3B424E5C6C7D848C939698
A4A6A9ACAFB3B1B4B6B8B2B9B8B8B6B9B7B5B6AEA8A49C979289817767615C4F4D555655
5C5B5F655E68676B69736E70716F726C6B7284747A8178706D6C7473674F445962787D79
775D4D39333833332A342F3C5D5A51455E77776E678064493435456A775B47282423262F
352D334E5368715242372A32678C948F7C53423B4367537AA6A35A2D2F292D2E33333030
333431262B2B2C282C31353136353234352A2E2C5082A37F67656E8EB9A3B1B6BCBBBDC0
C2C8CCCCA4403F47515C5F6C7074787B7C837D868D898C8E95969898989D9FA09EA8A9A7
A3A5A2AAACACB2ABA9A8A3A6AAA4A7A8AEB1B0AEACA5A9A6A6A6A7A7A6A1A69B9F958D88
898B8E92908A86878584867F8281818488989FA7B8C2CDD6D9DED9CFC2BDB6B5B2ADA9A3
9F9A999698948F8D8A878483807C7A7B787A736F6B67665A433D3B39362B352F3239433C
3C494234232D3B849FAAB6B1A4926C363B514829263133442B2A272C3536362F2C2C2C2F
3E5875838A878584868389959B9D9F9F9C999F9B9F999A9C9A9795969897979497949698
8F989A9A989B9699929491919396959B95979397929391959295958F8E8B8C91928C8D8E
8C8887858583818384909BA8AEB5B9BCBFC2C4C5C6C4C4C4C5C0C0BFBDBFBFBDBCBDBDBD
BEBFBEBFBBBEBEBF
66665E605C5B595D5C6054595554514D50535451494646403D3E414A586B7C858B96989C
A4A6A9AFB2B0B2B6B3B7B2B7B5B7B5B6B6B8B2ACA6A79D9391848074675A5A504B4F525C
5D5D616462676F6970706E6C6C6A726B6C6D6E7575838584706C68726F6C4C3F3D4A4750
5D6F604230303C322B2B313D5652463C4E676B746C7C6E463C3134506D63553426262A27
32412D393D605A463731364787909390837A603C3D734B49749A842C2A282B312D322B2F
32302C302E27302E31323F30303030332B2A2A2C386B92956F626475A2B5AAB2B5BABDBD
C6C9CFCEC78A40404D59616A71717576777D858689858A8D979497969CA198A1A2A4A7A4
A6A0A4A7AAADACA6A6A0A5A7A5A8A3A7A9ABADA9A9B1AEA9A4A6ACB0A4A6AEA59E938C8E
8888908F8E8B8689868181838182807F8B9AA7B1B4C1CFD9DCDDD7CCC2BBB7B7B0A7A39D
9C9D9B9C97948C878487837F817A777272736F6D6E6361553D3E4038382A3337333A403C
3C4A42342A374082A0A3BBB0978D63393E53532C2F353139322F282C323436342B2C2C2A
36506B7C8886878587838692959F9C9A999D9A9D9E9D97999999989B99979A9898939897
9594989A96969599999595929697979695929193919195929290969392968E8C918E8F8D
8D8D88898583838584838EA0A6ACB2B6BCC0C3C4C4C6C4C5C3C2C1BEC1BDC0BFBFBFBCBC
BCBBBEBCBDBCBEC0
6464616561595E5B5D5A5954515551535353524C4D45443C3938444E60707C858C96959D
A0A8A7A9AFB0B1B4B7B2B3B8B9B7B6B5B8B5B6ADA6A39995908B7F75675B574D51505A58
585A5E61656769626C6A6E6E6C6D6D6C6D6C6E7272899A9F9281706D70786A553E3C3940
536A6754393D3F3729252E2F4E573B3841575C586D65754D434A4741676952492F2C2B24
233538363F5653342F324E71827F787D7976714A4A6C6E40405F8848262B31302C2C2C2D
2F2D272C31282B293036372D33323130302627282D47829E8469656B87B4ADB1B4B6BBBB
C3C3CACFCDC1813F4554606671706F72787F878687838E8C9694979C9C9C9B9FA4A1A1A2
A49EA6A1A1A39F9A9F9BA2A29D9E9FA6A4ABAAA3A6B1ACAEA5A2ACACA0A2AAA4A4958C8D
8585888A8F8E888882827E847F7F807D8C98A0A8B4BFD1D9DFE0D6C6C0BBBAB5AFA09D99
9E9C979697908A82878285827F7A747771767572726A5E55493E493934242D363730403B
3F564C342C343F899FA4BAB08D8D6A3D42575D2E2F39313C2D2A262831313B2C2D2E2930
304C667C878D89868484898C939A9C9C9C9E9D9A9D9E9B9F9A979699999A989797969899
9A96989898939694969A94959495959493999593989295929595969491938F908E8C8F8E
8D908F8A89867F85828683929CA5ADB1B6BDC0C1C3C4C5C4C3C0C1C1BFC0C0BFBFC0BEBD
BCBEBCBDBFBFBDBE
6868636363625D615F5D5B5C595A57535154544B4D46413C36363E4C5C7082848A9395A2
A1A6ABABADAEB1BAB6B4B7B4B4B7B7B8B8B8B0AEA7A39E988E8A8279685C5152554F535C
5C5F5D6162666B686D6D706D6F686D6B6F6C6D78919C9EAEA8968D7674776F6148403F3C
434E6A64594E36322828263A3D5B3B303B4743374F6063696A736A6B5F65463B34272A2C
23283D3E4C494635364E758077654B586160686158588F6A3C3F5B5E3C4B333530302D29
2C2E2E2D2C2B2F2934352F2F322A2F32292521252330668F9F7C64687BA4BBACB6B1B3B7
BAC0C6CBCCCEBB703C4E555E656E70767879828787868D8E989699979A97979A9BA0A39E
A39FA09C9A9A97949696989B96999E9B9C9CA5A0A2A4A5A7AAA5A7A5A29FA6A3A79C8E8B
827F84868B8C8789807E8084828283878D9CA1AAB6C3CED9DDDDD6C6BEBBBAB1AB9FA3A3
9A999894938C8584817D7F7F7A766E777076726D696261533D3A413535252D3734313A3F
384B53323034468CA2A6BDAF88896440405E4C2F392A2E3931302A2D31353A38312C2833
2B43647784908B89868A7E8B8D999D9E9E9E9A9A9A999A9C97969C9594979A9696969898
979895999899989C969896979597989797969596969397959493918F909192918C908F8F
8B8A8D8A858485827F837E838F9AA3A7B2B9BCBFC0C0C0C2C2C2C1C2C1BEC0BFBFBDBDBD
BCBDBEBBBDBDBCBE
64646765636464655E5E5F5E59595353565253514E4D46473D3B4B5464707F858D9197A3
A4A5AAADB2B2B4B0B4B4B5B2B7B8B7B6B6B3B3AEA6A59D96918A85746761554D5052545D
625E5F636368676F6A6D6D6C6D6D6B6D696C6F84A7938D9EABAAA59C86777060514D4542
434353605750413B2C2424283350312E2D3F393339538089837D72797677604D3F31382E
282B334F4D4B463640787C6E615D4B404B40616E5F638D8955555E5F485A4F4B2C2B2F2C
2F3231332C272E31383633302F2D2D2C2723242523243F799C8F736B6F96C1B2ABA6AAB1
B5BCBFC8CCCFCCB66047515C5F676E727B7A7C838B88909294999A9A989793969E949B9B
9F9A9D9A9597918E9291938F909093929298969C9DA0A1A8A8A7A3A4A49CA1A3A7A09286
83858484868A8B87847F817C837C81848EA0A5AABCC8D0D5DDDDD6C8BCBBB8ADA8A2A39C
9695948E908885817E7C7C77736F746C686D6E6D68665551403B443B2F292A39362D3D3D
3D4853333635468E9CACBCA682865F393A5E4136392C383A2F38332D31323F3B372E2829
29425573828B8A888288838993979D9B9D9A9B9D9B9A9898999B9D9D979B969795939A96
99989599969796979496939496979999969695989A9599979591909391948F918E8C8A8D
8E8D8E908A8886848685837E849699A1AAAFB4B9BABCBFBCBFC2C1C1C0C0C0BFBFBEBDBF
BCBFBDBCBCBDBFBF
65656764636464605F635D5C5D565A5755525559514D49463F434D54636F79848E93989C
A6ABACADB0B3AFB4B3B6B7B6B6B7B8B8B4B1B6B0A6A49E95908882766961524E49515158
595D60626368676A6D6C6D69696D6B6B636E7799A0878E9BA4A2A5ADA191806F5F454C53
4C394054655551352C2E30252A3D362B243735373F67968F8B9181817F7B7B7346343631
26293158564E443F62766B56466B574E475D7375737A878B7A745B4534402D2D29272B34
2E2D2B2E2F302D2E362C2E2F2B2F2A3027282B262122286085A1826B677EA9C0A8A1ABB2
B6B7B5C1C7C9CACAA95F4A565D636D75757D7F838A888D939494959B999A9A9698969497
999594939095908B94928F908D8E908E8F8E969796979A9B9DA1A3A5A49A9DA1A3A1988B
81818188848A88868781837E827F82838C9AA5AFBFC9D2DADFDDD2C8B8B6B1A6A49E9D96
938C8C878989887D7D837C73636A695E656865675D61594E3D37403A2D28273435363239
3B4D472F2E33488E9AAABCA58E85623F3B5C4B353C2C38313239322C3034434338292F2C
2F325072838B8A87878381838F939E9C9E9B9F9C9B9C95969B9F99999B94959796989598
9C9A979797969797969592989795929496949A96979796999595929393949291938D8F8E
8E8D8F8E8B8C878B8B848388828787939FA4ACAEB4B8B9BCBFBEBFC1C1BFC2BEBDBDBDBD
BCBCBFBCBBBCBCBD
66666A646465626061626260605D585D53535553514C4D494442475268707C888F92979E
A6A7A9AEAFB0B4B0B3B3B6B7B7B8B7B5BAB4B0B1AAA59D9592858171685C534F4C525456
595E61655F6665686C6D6F756B6C6A69657389A78A889498998E8B8E929FA9996F554647
44434545616B53383130282A2C2A332729353644708F9E7F79868B8773677076502A3639
23293A67454345426C715C40316A6A5152737786829486858D793628292B2E3539342A2C
343432312E282E3733332E3437342C3030271E212020233C76999B6E63708CB9AA9FA7B0
B3B3B0BBC2CAC9CBC8A25D4F535C63717679848386878B8C8F9392979A92969297999193
918B8F919495958C8A94908D8988898B8D8D94918C95959B999F9FA49E9A9496999C9C8D
837A7B81848689868285817F7F7D838590A2A5ACBBC6D2DDE3DED2C3B5AEAAA19C9A9593
888987858888827B7D847E6D5666674D5D685F625B615B4D3F363F362D272933322E333A
3E4B4F342B374E9198ABC0A98F7B623C42654242352938302A30272D2B3344483D2C2925
2E384C627B868B88888380828C949CA0A59DA19D9D9A949B999B989A999B979799949695
999A96979998949C979597959698939596989796939893989899959394949394928D9191
8F8B8A8B8D8E878A888B858A8685828A909B9CA6ACAFB3B9BBBABCBDBFBEC1BDC0C0BBBE
BFBCBCBCBCBCBCBF
67676869676B6A645F6268635B5959565456575653524B4A45484654667480858D949B9D
A5A6ABAEAFB4B5B3B1B5B6B5B7B5B5BBBCB4B3AEA6A59D96908780756B65574C4F575455
5C5C6165676B6D696D707172736E6D6F6E708C83616F75788A8981727C8493979282734F
414A5954515A594939383127292C2F2D25273C71988C825F4E6A817F6B4E5054492C363C
29294F71413B4B546A684E2B355C706562717987757A747787916F332425323A332D2A2C
312F3433292E33302E2F2C2F343532362D2627261C1E23265987A180636673A8B8A3A3A8
B3ADB2B5BDC5C8CBC6C49E595151606B6E7B807E8385878E92958D8D909096949792948B
8F8C8F9396979084838C89827C7E847F88888585778C958E90A09999969696919196958F
83777A80818884857E8383807D80868991A1A2AABFCAD7DEE3DCD3BFB4A89F9A97958E85
88817E7C84827D7D7F7F766C526A5F4C52636261595C52463A303A382F262433342C3139
4F4952342B374F8D9BB0BFA391766038516641392E36392D2C34302A282E3C3D39353630
2B2F50637A878A898585818089939E99A09E9A9C9E9C9A999A9C97979B9B999499999897
9B95959A98999A989392979696979A98989697969798949999969596949395938C919392
8E8D8A8C8A8A8B8B8388888B88868586889099A1A1AAABB2B5B6BABABABEBEBDBEBEBFBD
BEBFBEBEB9BCB9BD
66666660636C696865646A615B605D59545456544D4F4646424A4C5565707F8890929D9D
A1A7ACB0B0B3B3B3B5B6B5B7B7BBB8B5BBB5B1ABA7A89F948C877D756762574E5058575B
60636B6267646C676C6E6D6A6E6E6E6B6C799B643941495C818B878395A1917B82898B80
757B7F715E52454148473A2B2A2D32322C30519193715A44374B6B8E793F362F2F2C2D32
312D5175344E4A5C615E38263353676F7867707471846464797995682925272C322E3133
4429292B2F2F2E2D2E2A2C2C303236342D28252623222223326B8D956E626990BBB7A2A1
B0ADB6B8BCC4C4CBC9C5C59A59515F666E767C818289858C8D93858D8B919493928E928D
9190909695948E837781817B716E867F888A8F7B6C868A8186A6929297999799928E8E84
7F75797F838384847F81837E7F82888A919BA6ABB9CCD9DFE0DCCFB9AEA49F95938C8D84
8785806F7973797772796C55415D4F4A505C5756515655433636373A332D28323E33323B
514D54342C364F919AB5BA9F8F6F5A3A59624D3D323B343333353631272F363E41322E2E
3634456570818D8E8A8588848A90969DA19B9E9FA19E99999B999B9A97999B9A969A9B98
9997969A949597989995969799969A9A93969498969798989795959998979292958F8F92
918E8D8E8D89888586868488858B8584888B8F969CA2A3A9ADB1B2B7B8BAB8B8C0BDBDBE
BFBCBCBABBBDBBBE
67676667686E6966616269615C5F585B5A5B55554F51524A4448495964737E8C92919AA0
A5A8ACADAEB1B1B3B2B4B7B8B7B9B5B9B6B7B0AEA9A5A0958D8481766862544D5152535D
5D5E65676669676A7172706F6F6F6E6A6F8BA1552A2F34466A828895A4B59C8B847E7D85
7F85A4B39C62413A404B464033373037394C768879513A3F2F3347677B472724252A2A30
38365B7937384F6B685A2E324D596976806A72718593634B5C5E81824B2A23272D282B2D
262D292D2C2C3034342B2A2F39382F302C2327262323222126467C9980625C7FB3C3AD9F
A9AAB3B3B8C1C2C8CAC5C7C1965953696C747E7E8388858A8D8D8A8E8E908F8F918E8C91
958F8C908D8E85816D77807A6E5C808089868B716E807B667DA698939CA5A2A399978A83
7E7A777A7C8284847D838081807E8A94959CA6B1B7CDDADFE3DCCDB6AAA4A1989790918F
8E88816A706E727261745D433B4D3C4355565350575653413B34323C3329232C332F393A
4B575330343B4D959AB7BF988B6555425B62523836362E2F2E3133322F29343839363636
3036435A6B7B828C8B898784888E909CA3A1A29F9B999D9A989B9A9B9A9B9B989B999896
9797929494969598979999939697969B9597969496999B9B9A989897959394948D8F9193
908F8E8C8E8D8C888989888C8A83858988848988959599A5A4AAADB0B1B5B7B9BBBCBCBC
BBBDBCB8BCBEBBBD
6868686A666A68656C6D66615F5F59595B5857515050525143484C5B687C81898F959E9F
A3A8AAABA9B1B2B4B1B5B4B5B2B6B9B4B8B2B4ADA4A49B938E898071665D56535755595A
5B60656267696A667170706D7571716E6C8D9A402A2A27324C626F7E9FAF9A9C90908C8E
7E8694A4BABC744333323C3A372C2E384771806E6A685B5745353B42656934282225252A
323D607A27355A625A48364446566571947B686581A16D4E7045466C5F36262D2D2C262A
2D2E2B302F2B2D2E312F3030333239332E2B312426222320202A5E899C6F59679CC0C2A2
A4A8AFB0BBBDC2C8CEC6C5C6C2966060696E76787F8583868B848789898F8D9291908F92
92898684888A837A6D68777D6459768182847F696A8073657F9FA3A8A7B3AFAFA89E9088
7D777D787E7C81818283848782818A8F969CA7B4BBCEDAE1E3D9CDB4A9ACA7A49F969493
9791837C7B718275707E583F423E3D3F40433F435859554537383739342F2D3037343536
435351353032549799B4B993825E554554635340393C2D2E322F3730372F333B3C433432
3236424D5D747F87898A8683858A8E989E9D9E9E9A9B9D9D9C9B9A9A979B98999B979793
93939699989997A09C9A9E9696999799999796989A989C9B9C9897969894939294918D94
90908C8B888C8C8A8E8C878B87888586898A8887868D90959AA1A8A8ACB2B4B6B9B7B8BA
BABCBCB8BCBBBEBE
6B6B67676363676262696B63605D5B5C5B57555254504D4A48484F5A657480838E95999E
A6A9ABADB2B1B3B3B4B4B7B5B5B7B5B5B4B4B3ABA3A29D938D897B70695D55525050565C
6061625F66696B6B6A70716D6F70706B6D8DA93E252E242A373F4E6380999C9290969DA0
9A9DA49F9AC4B3894D2F342F292A243148715F505F6B7484856C5349485E552B24272428
29355D792D346159514A4F4E4E5D5E7F957B526582A9706F7340383A60492B2F2E302A23
292A2F2C362D2E2F30302B2A2B322C3A2D39282425242523222239779C875F6181B7CAB9
A6A7AAB1B6BABEC3CACBC9C2C2BF8A5E5F68757781827C828A81878285928E8F8F8D8F8F
8D8678767D7E7F7E6C6D6B7C6F607A858892969193A7A08D9FA2A4AFACACABAEAD9F948C
837E807C7F747B827B7E808383868D92959DABB7C0D0DBDFE1D5C9B3ADAEA59FA08F8588
91968E85818E999B9D9D888175625B4E41322F3854534B463B37353E3934293148373634
3A554C2D2E3453959CB8B6907F5B4D4E586649364442332C323232302F2928323B3D3931
2E363A7B586C7987908A858885898D959D9E9E9D9B9B9C9D9A9D999D9894999B9A949693
9694959B9895989A9CA7B1A096989799939C9C999C9699999D9A9996989893958F949496
94908F8B8A8C918D8F8C888985868B8C858B87888585858D8E97A0A0A6ACACB1B1B4B6B7
B8BBB9B7BDBBBEBF
686867686767646064636360626359595D5A5B545D504C4B49415058697782868E99989D
A4A5A9ACB2B4B4B3B4B6B2B4B7B7B5B5B3B6AFAAA5A09D92898A81716661595653585559
5C5D60656963666D6E6C6F716A6E6E72667A9F542E312C2B2E323B46618790909CA1A095
9FB0C4C0A5CDCDB4935338322D302D335464402E333A4A677B858884685E6D3224212B20
23314D6E2837595B4F4E484E5E50638B867837547FA77574704B4133465224322B282425
2B252C2F343231303138322E3930312F2A382F27262D22211F232C52849F6D566C9BC2CB
AFA3A7ACB6B9BCBEC8C9CAC6C4C5BE94625C6C787B7C7B81867E817D84939391908F8D87
8881706D72696C78726F7485858F979B979EA9A7ACB2B2AAB1B4BBBDB1A09B9794888889
84837E79777973788083818079828D94979DA9B6C1CFDBDFDDD6C8A89A937F7C76797581
8C98939399989CA09D9E978B8680715E4C392C303E4A433E39383B3834302F314A373238
395B55303035589BA0BCB59270554C57586C42354441472F2E2B2F3A2D2B32343B353A3B
312B36424C6276878E918A8C8786909297A19FA09C9B999D9C9E9E999D96979D969A9797
968F989597979A9C99A5A8A896999A9A9599999A9E9B9B9797959A999696969694939594
92938F918E8C8E918D8D928B88888B8A8B8F86858988837D878D91999DA1A4A9ABADB3B5
B5B6B6B7B9BDBDBF
636360656666626360636661635B5B5D5C575A5B564F494A4A4853596B7B7F898C939A9E
A4A7ACADAEB0B1B3B4B2B3B6B6B5B4B2B4B3AEACA2A39A9488857F72675D565254555258
5D5D59636561676A6A6D6F6D696F6D6B6B717C6A40382F2A2A2B36394A7E78788599989C
A8B6BDAB9EB5D8EBDABD82533C2B32396E572A28272D2E2F415B798380736B562F2C2F26
23284264363E5961544C40574D4A688F7678314F74A583695C474B332D2E252E392C2724
272931342C312D303C403A362E2C3032443B2F342B232725222C293B6E91935F607CACCE
BF9EA3A6AEB4BABBC5C8CAC8C6C4BFBC8F606277797B7B7F8181807E889093908D8D8C82
7C746B6369534B717D878A92959D9D9FA8ADB0BBBBC1C4C1B9AFA7AA9B928E877C757682
80867E7D7877797B8082828580848E949AA7ADBBC3D0DDDFE0D5CAA57E7466605C6C777F
8E8E898A8E98A1A7AEB4AEA49E8D7C665C4D352E3442403E3838353A3831303236323333
365B573938385C9DA5BDB08B6F53555D5465463E3E33352D2E292F2C2D2C312F3735382F
2B28302F435975848A8C898A86808D929B9C9DA09B9B989A9C9F99979A959A9A99969999
9395999B9A989A9A99A2A29B969B999B9698999B9A979B9A999896979496969599939392
949091919092948E928E8E888B89868E8C8B8989858888868484888D989B9FA2A2A5ACB0
AFB0B1B6B6BABBBF
626265636568656263636263616060565D5D5B5853534D4A4944525A64747C889195979E
A4A8ACADAFB1B4B3B4B5B3B3B2B6B2B1B5B6AEA9A29D97928D7F7972666056525852595C
595E63636465696767706A6E6A6C6E6E6D6C68696350443D432F34335E65564E60798295
A7B8B09599AEBAE5F5F2E3C1713B334565432728282929272B3249666F6E645A49463232
2A2C375550535B5F585754574741668669743853719B835A49303D403229272F3F322C27
272429303938322E36433F2E2E36302C2E313727242825242120392A4D859B7C636688C2
C59C959FADB1B9B5C0C7C7C6C7C5C1C1BC926669727F7C7B7A7C7E7B878E8B8D86868572
6A5F5B5D5F5E6E77828B8D83858A939EB6BBC1C5C7CBCED1CEC7B69E908991988B73707C
83827D797275797C8481828185848D8D99A4A9B7C8D1DCE0DDD6CAA57D665A596178808A
888079717589909FB3BAB5ADAC9F9078645345312F373D36333036363335302E34383333
305C583731395B9DABBFA38867454B644D60524C4838312D31322D322D2C3035383A3B30
2D322F2B334D677F8B8F888A85878D8C969A9EA29C9D9C9E9F9C9C9A9C98989A99989B97
979598979698979BA2A49A999496999A96969B979C9A989A979A9A989495969695999296
949595919194948C908F908A8E8A87918C8C8F8D8787868882838181878D93999BA0A2A6
A9ACACB1B2B5B7BA
64646967625D626460636463645D5E555A5A5A55534F4E4B4444525B6B767C888F979A9B
A1A6ADAEB2B4B1B5B4B1B3B4B3B6B4B4B3B0AFAEA3A29B908D7F78736A5A564B50545057
5B5B616166696468616B6C686F69686B646D62676A6B656B6C3B38343F373037394B5676
8DB6988DA8BFB7C2DEF4F2E6CF93373A4C3025282F282326262E33536552524854535948
3332405655464654514E615E5B45608469684A566E91864E372A2B37352C2E293F2C2B36
2C2F2B363D3A362D283740312726292C2F303526252E2D2123212A363C588896635866A3
C2AB969CACB5B2B4BDC3C3C7C9C5C7C1C4C19C6C6A73777A72767E7C838C838F887C7663
53434352637377777C84786C65667489A3BAC5C6CACDCFD1CFCAC6B09788908E94716E79
857E747179747C7B7C7F82828386869094A2AAB8C7CFDBDCDDD5CDAE7E64616B7D89968B
7269584F4F56647B9CB7B5B1ACA7997B6851443A36362F2E303033383532272935352D2F
3454583233355B9CA8B9A18C653D515F56515F494734342E3334333731312B2E383A3B35
32322B2E3253637C888C8C8C888D878C939DA29F9E9D9D9C9A9A9C9B9E9A9B9C9A9A9897
979799999998969BA19B9C9599989A9B9D979B9A9A9B9D9B9A9A9C969C9D99979497989A
999295939794938F91908F8C8D8F8C8B8D8A8C898787868384848081808685908F97979D
A2A1A3ABAAAFB5B6
656564635F646262636661605F605A565B5E565C534D4D49454A5559697381878D959A9B
A2A8ABB0B1B4B1B3B0B1B5B6B5B7B3B6B2B1ADAAA1A296918B7D7971675E5751504D5355
5A5D5B6169656465666A696869696767666D6463676C6674816B4E3932383A322D343147
88AB868AB3C3BEB9CBDFEEE2D3BB7940412A2C2A2F2929292629313454615D3F38384544
3C383C55483C393E3D47554E5750588C7668585174917D483626282D3A303032393C3528
2E2A2E34454F3D2A29313A322D2C282D2D36382827272421252A3032353F6E957C53567E
AFB99F98A9B0B3B4BCBEC3C7C9CAC4C5C5C5C4A06D68717576767F8284827C827C756C56
412F2F496371707578715F523F424B587F9EBCCACBCACACECCC6C3BCA3948A84786A747E
7A7070737C7D78767B7A86848B8A8F949BA5ABAFC1CFD7DBDDD8CFB57F636F728190946F
5A4D4B5958564B4C739EB4B6B1A79B826A50413531322E2C30333133282E2E2B2B2B2B2D
34505F3A343A68AAA9B99B875C3E565D59525C4F3B3B3838362E302E373533333F3A3531
2D2C2C2B303C61748390938B8D8F8B8F92999E9FA29F9B9D9B9C9C979C9B9E9D97959B9A
98979A979698979C9999969996979A98969996989B9C989898989898989796969798979B
96958E9693959491929193938F8E9190918A89878B8889868688828383837F85868C8E91
999A9CA2A5AAAEB1
696960646363606062606365685F5C5C5C5C585551504E4A43474E566778808490959AA0
A3A7A9AFB2B0B1B1AFB1B4B6B4B3B6B0B2B1B1ACA29F968F88877B72645C554E49545357
525B5B61625D616566696C6B6460666B6B6C5D676B686C69727A6B554748413A312B2B40
9AAC716E8996ADC1D5CDD3C6B4AD9A6B392A282A292D312324272F303E5E625345383733
303D43523E4A383D445639383E485583887661577F9975402E27332B30342F2F36402E2C
282C283A52744D2A2C3430352C2D2B2B3534302A302C27282B272E28252C407D8A675166
89A6A19097A3A8ABBBB9C1C6C5C8C7C5C4C2C7C3986C6370727A7E817D7475796D64604A
322B33445C69727D71593E39363D3A414D6BA0C6D0CED0CFD1CAC8C0B09E837261667D7D
74666F72777C75717B818286898A8E939BA2A9B1BCCCD5D6DBD9D6BF8668696C80867651
4155676460625245476FA1B3ADA59A876D52453D2E3536282E2C2F2D282F2E282D28272C
355265312D356AB0A7B99B84573F5B574C48564E38363537322E3F3A303531313E3C3533
2C312D2F3135596C828F928D8A8887888F97999E9D9E9F9D9D9B9E9B9D989A9D97999998
9791979E9B9597999A97969696999A9894979D9B98989698979A9B959A9C9C9897969599
969490938D9993938F949794908E9193908C8889898D878B8786857F8381817C80838487
8D92949A9FA3A7AC
64646163676560606463625D65605D5B5C58595D51504E4D44494F5C687781838F949B9E
A4A7AAB0AEB4B1B5B2B6B4B1B7B5B4B3B5B0ABAAA29F998E8B837B7262594F4F51505058
515B5B6464635E646A6A68686B62696A64666A6966666664656C686363584B3C2D313B75
B89C5642556EA8D0D2C2B2AA9EA19C8A68502E363435322B27262A2A3343596F634B2F32
2D2E4B553943353A4A59352A33404A79846B5A567B9D713A2F2B2C2F36322F2C26382826
27262D40657F4F352E3129352B29312D313D2D282D262C2B28232D2724262F5A7873515C
7D97B19E93979399A2AAB4BBC3C6C9CAC8C5C5C3C298676D6573787A756E64615F564E37
2F3345535A6C7F73583B3C4F575A504D374171ADCFD3D2D3D3CDCECAB69E7B5D54637E76
66626B6F6F7572767A80808688899097A2A1A7B5B7C5CFD7DAD6D4C59A6E5D6978785D3A
5561645D5658595746407BAEADA79C8F7056453F2E2D2D2A29282F30292C362C2A2E2B2C
314668352D3272AFACB69A855348615B4B4A54583A3A353E34342F2D333334373C383534
2E2D2E302D3652687F8C908B8C8A85828B9597999D9D9B9A9C9D9F9C9B9E9F9D96989898
9D969C999699999696979796989A9C9D989B9A9E999898999D9D9B999C959796979B9896
9693948E929693968E949295929191918D9091908D878F8E8B898880848086807F7F7F80
828A8B91939BA3A0
63636362626A5D6065655D665F5A5D5C5B56575955544F4F484A525D6C7683858C9799A1
A8A5ACB1B0AEB0B1B1AFB3B2B5B6B2B6B3ADAEA8A49D96908B837B70675C5048484A4E56
575460635D696365666266656761646B686464676B62626266665E60605F574634334A98
B98555536CA2BEC4B5A9969793979996897F5D6D7356412527282C27232F3975785B4C37
2927394E574935374C4E2F2D323B436680634E5165957039312F302E2A2F30312C382E2B
292B31457977463E2C292A2C2A2D2C2A303A2E2A2628292B2B25272325252E4A69847256
6C93BCBFA8A1999599A8ADB3BEC3CACACBC6C1C6C7C793696267746E695C54524E423B2E
2B2D454A5D757963433A546256565B534839427EC5D1CED0D2CDCEC8B6956C4C466C7E6A
5C6070706D7076797A7D81858A888D959CA1A5B1B9C1C8D4D8D7D3CBA87C5A5567613D3D
5E64594B435769554B3A57A2B0A69D8D744E3E3B2D2B2A272B2D2F312F32292D312A272B
2D3C633B2C337BA9AFB49A844F50665D4D415855343A453D302C2D303431333234343536
333530373438486274858D908C8C87888B92979C9FA2A09DA19F9C9E9B9FA09D9C979A9C
9B9495989A9897969594969A969B99979A999B9A989897989B9A9B989998989B97979596
949894929399959A939491919194948F8D8F908C8E8B8E8B888A8485847F83837E818281
828086888D91959A
6666646260635D645F615F655D635D5C5D56555853534F4A464B565E6D7686888E9499A0
A4A8ADB0B2B3B0B1ADB1B4B1B5B2B6B1B1B2B5A8A19E9B8F8B817B7162544E47494A4F55
56575C5B63655C646364636766656461636363636C6666646365615D5C5C5B54443A4E90
B89C95AEBAC2B0A49796938D9A95939595796992998E6631292B2A2427292E4B70695D45
2A252F304E593C37443B2D312B3B4858885F42615B8773423537322F2B2E312928352A30
26272E528854364430302324262F262E37382F2B29273439322B25282D35484A62899D75
6074A9CDBFAAA4ADAAB2BBB6BDBCC8C9CBC6C6CDC9C8C28D5D616B656156534035333031
2D2F42475F736B47345C625A4842425A6C4A3557B1CFCCCCCECBC8BFAB805846587C785E
5A6C7772707173787B818687888B8D91999DA6B0B7C0C7D0D8DAD9D4BE81654E4F4E333C
54503F2A2E485547534C4595B2A8A08B6B524437272F362A2B2F2E2F342A2F29334A402B
323F603B2B3B84ABB1AE967B4855685745445756373B4236363233303231302E33313330
312B2E30373841587280918F918D888D898D969A9DA19D9F9D9E9E9D9C9F9DA0A0999B99
9697969A979C969797999797969897989A9999979997989799959B9896999B989B9A9798
9A96969B92939593939590949493929290928E908F8F8E8C8A8D88888585838687838282
7F7D837A80878B8E
626263625F665C60635F61605B5E5E5B5A5755535153514A484C515E707885878B959AA0
A3A9AEB0ADB5B4B2AFAEAFB2B0B4AFB4B3B5B2AA9F9999908C827B6B5F5A4D494C4E5156
585460616160635D5E64636465605D65615C616166616660615E5E5B5C5A565852495EA0
C0B4BEC6B5A79388899293979693969696816782989A86482D4C512B2C26264348556D5C
3E2E3026374D6647402F2723293252568377575A5282713534352F2B2E2C2C252428352B
2C2C34668D49313D35292729282E2E2F2C3A32322A2B2A343A342A292F494B393B74988E
675C8CC2C9B4A4AFB6B3B9B9B8B7C0CCCFCBC7C9C9C4C9BD7A505B5E565144383835332A
2E3438465C675A32395E5D4C30292B45704D38429DCCCCC6C6C6C1AC906246445D836E54
5B747A75747173888284898B89908C8F999CA7ACB6BFC7D3DADBD9D6CC9E6F5645383241
433F362D283C3C44636A468FB3A8A186604C3C352E2F452E30333C35342E2F352D322727
29355E3F2B3488A7AFA994725957664F3F4446543F3F3B3A3633312C2F393D312E313437
2D2A2B2F323542506D7B8C8D8F888E868A8B999BA39F9CA09BA09B9B9EA09E9E9A979997
98989A999897989C969E9A9998979A9998979C9A979796989B99989B94979D9897989A97
9999989794959493919191939695949395918F938F92918E8E8D8C8D8887838386868682
8485817E7F818382
60606569695D5D5E635D5F625D5D615A5B5859525150514D4849535C6B7882878C98999D
A5A9ADAFAEB5AEADB1B4B1B2AFB2B4B4B1AEADA69E9C92948B8179716253484A4D494E52
58595A5C5B62656266616164665E5F645E646660606364635D5D5C5C5C5A575956577FC3
C2AFC5C59D897E84888D9192999699999A835E6D898C9069423F473424262C3833335075
634E3D2626335F724D3125232B2C485E7C78635D5A7670372F2B2A29472F2E302727382E
272C3E7A7D3F2B352B2C282A2B2933302F312E2F2B2B2D404841383A2526272125528DA1
7E606C9CC6BDA4ADAFB1B7B2B1B7B9C3CECBCAC7C1C8C5CBB76B515258554E443831352C
2A2C3341525A51323C504F30262427385A413248A3CCCCC7C0C0B98B6B483C3E686C544B
647B7C787A7779808782878B8B968D919AA0A3AAB3BCC7D0D2D8D7D6D3C18F5C43323235
3C34302B2D3D394D8F894C96B09F927B5E43382D292D303131333833312E32322F2E2627
353F50492D368BA4B2A88C6565566C403E483A5F423D3F3B38362D2E2F2F302B363D343C
322E30302F313A4A6178899091918A8C858D929A9E9F9CA1A09E9A9D9EA09C9F9C9D9597
9C9C999A9998989C999A9A97989E9B9C9998989A9B99979A99999A9B999B999C9A9B9994
95989899979696959295929995949698979190908F918C8E8E8C89888985898987858889
8489808583838482
5F5F626161625E5D5E5B60605B5B5A595A5C59554F565A4B4B4F515C6973808D8D949A9D
A2AAACB0AFB0B0B2AFB1B2B0AFB3B1B0B1ADABA4A29B96908E847B7064585249494C4C51
55565A5A5D5C5B60606460626261666362606366625D64635E605E5A58575858555787CD
C6B3BDCEB68C7A80898D91959695999D9987655C8187836F504D56372D2522312F2C2A59
80736135272E376D764425241F2A40556972635D647D79493A2F2D272C2A3F3C292C302D
2E304780652A2F2D31312E2B322F2B2D30323B3B2D333F505A55322A2722211F21327298
9C6B5F79B1C8B0A4A8ACB3B5AFB5B8B6CACEC9C7C1C5C5C5C4AF694C5057554C443C322A
292A33353D4D432B2F3E3C2D2724285857415679AECACCBFB0A39A61452B2B3B4C4A3F4F
6D7B827C797679808A868C8B92909194999EA5A6AABAC2CACFD6D7D3D5CCB57A51363231
2C2B312C2C37385B948045A1A497876B50362B2B2A2B343736383A352F33302F322E2526
2C2E50412B378BA2B7A9935F596358453F403E58433C3D453C35312D2C34313435373935
30302F2E2C2B30405D71819090938A89868891989CA1A09F9F9C9F9C9D9C9D9B9F999A98
999C9C9C979B9999939899989A97999A989B9A999E989499989B989A9A9B99999799999C
979C9B9A9C99989898969494959799989696928F91908E918C8E8D8B8A898C8885848489
878484888688867F
6363645C5F636060615E63625C5C5C5F5B5A5C535B52504D4A4E5061697C7F888E93959E
A3A6ACB1AFB2B0AFAFB0B2B3B1B2B2B0B1AEAAA69F9D99908B84796E63554A4A4A42494F
5555575A59645F5B5F63605F665F646360625D63675E5D5D635C5A5961595653555681CE
CCB8B8D2CDAE777C89908E9494969B9D9D927C68868B7B695B3F5851302A2A292A242133
62917C60352E2943796532272D30455A5765574F608E8D623128242330314A452A313038
40334F8D53282E2C2C2F2B282928252B344867604A5A536D5E2F292A282325222026538C
9F85656592C3C6ABACA6AFB2AEB5B5B4C4C9CAC4C7C5C0BEC0C8AE614448504B4B463A29
2F3130313035352F2B363132282E304C3E455E80A2C1C0AF9577623B2A2726272A2C3351
6E8187817E7D807E8788858E8C93959899A1A3A7AFB9BFCBCBD2D4D1D3CFC5A770413132
332D2E2A313B3A51715C4B9D9688735F402E27292B303638363A37372E293034322E2A24
2F2F50402D4293A0B7A8926053664C42403B3E54503D3E3C3A3330322D30333234313330
36333032322C32364C6A7E8B93908F8A888895999AA0A0A49E9C9F9E9D9E9E9B9E9B9C9A
9A9A999798979A9B96989A9A98999A9D989799999C9D9C9C9A9C99979A999A9A9A9B9A9A
9C9B9A98969795999B9697939397979898979390948F938F928D8D8D8C8A85888A878A8B
888C86828C868488
5D5D5C5D62615D585C5E5C615E5A5B5D5E5B5F555953504C4C4E545D6D737F879095979C
A4ABAAAEADB1AFAFADAFB0AFAFB1B0AFB0AEA8A69F9C99938B817B7262554E464C484B4E
5354575A58585B5C605C605F5F626763605D5E6161605F6165615F5F5956585753556EAE
CEC1AFD0D1C588798B8E8E908F96959C9E9E928A88898B74573733464F3C2F2921222126
3478816D5B46322F537E5E4637395A584E5E5A45518493704D2A2426323C513F2A2F3A52
56355C8747252D34322C252B292B2A303E6E7A706D66523B2B27272D292222262121336A
93A6715F7EACC9BDA7A9AAABAFB3B9B9C4C9CDCAC2C4BEBEC3C1C5A659434B493E3B4233
3030342F30302F372F33302E2C2E2F2C3238465A8AA2968E684E382A29292B262A2E4364
75848884817E8082888A8B8A8F929694999FA2ACB5BCBEC5CACECDCCD1D0CABD9F653836
3A332F32373632393F33567F7C6A5B43312C2B2D3332333A38393B322F2E3534342B282C
30344E4C2C4294A2BAAC92605A58473241353C4C4A3F3C3B3935302D2F2C302F30323138
37393232352F2F33415E7A88908C8A8E89828A9198A0A09F9E9C9EA09DA09B9C9F989A99
98999999969C9A9B9B959A94989A9FA09D99989A9A9C9EA09E9A9D9C9C9B999A9C969697
9E9B9B9E9A999D93989695949896969798989795959492929090918C908D8C898C87898D
8C8C878A88868484
5D5D616262635F5E5D655F5F605E5C5F5D5E5A5B5350524E4D5559636D7483878F969B9B
A5A3ABAAAEAFB2AFB0B4B2B0B4B0B2B0B1ADABA59F9D9691928A7A6F64534D4645464F49
51575558535A555A635C5E5F6966646760655F60635D5F646261615F635D5C56595D627C
A1B2A6C6D5CBA478888D9096969197999A9B9699948B8475694F33304B544A3527242322
28405A7674674E433D658163334166554E4E66454F6D90754F23212F2A36583D232A3F55
3D2D5E82382C2C2A2826242429252A4169797972674828242926272D2F25292722212345
80A195646490B9C6AFA7A4ACB1B0B8B8C2C5CDCAC3C2C0BDBFBFBDC5A75E4A4141434339
35322F30353533353733352D2C2A2F2E2F304F4262776F5C46392E2A272E29262E3C5673
818B8787837D8282858D8D90979394999DA1A7A9B4BBBEC5CACBCCCDCDCFCBC7BA9C764B
3D38353B3533343E333447565B4B3E3B322F303438413B393C393B3635302D2D2E2A252C
2C3346442E4595A8B7A28461625E4A403D3F3653463B3B3D3A34312F2F2F33343432372E
31323E35312E292B35536D838E8E8B8884858792999FA0A19DA09E9F9D9B9C9B99979799
999B979A9A9B979C9A9D999C979EA299999B9E9A9D9A9B9F9E9C9D999B9A99979B9B969B
999A9C9A95979799999596949C989B96959999959491929290918E8D928B8A8E8B8D8A8B
89878B8B87898887
6363696765625E6261686464605E605D5E5E625C5D595652515350626E7B83878E959B9F
A5A9A9A8ACB3AEB0B3B0B1B3B2B3B1AFAEB1A9A3A09D97948E89796E635959504A474A55
5455545A595E575765615E65696A646860656166635F6366606064635C5F5C5D5A5A5F65
7796A0A2C8CEBE7D868E939395909699999B999B9D9D957D6B52463B506C66452826241E
24293F6574695B4E50596B895D586450464C6C5049617C7C5527262E27305F3E2937563A
2F3259732E26292724272525203035707971726040262624272B2F33342A20262A1B1F26
5A90AD76677B9AC1C3A6A6ACB0ADB6B4B9C4C8CBC3C1C2BABCBEB9C2C6A25846403F4B3B
36373935323534343A332F32342E302E2F2C33373F544737332E282E2727302837586F83
88898180837B7E83828C8F8B9294949C9D9FA5ABB4BBBFC2C7CCC6CBCACBCAC2BCB29E80
5B4E3B383C31373A3731393E3A31303034323337373A40363537403F33322E34302C2D24
2C3146452F4694A7B59F836F665E47474A31324A3E403C404135342F2C302F3134322D3A
39383238352B2B272C4A678290928B878587878F959CA2A2A1A2A19C9D9E9F9EA09D9899
9E9A9A9B9A96979A979E9596A09A9B9D999898979B9A989C9D989C9B9A9C9A9C99999897
9C97989C989A989B9A989B96979C9998999B95989893949596949193929290928F92908F
8E8A8F8A8A8C8984
636369686765686363656469636464645B5D65625C555C5A4F545666727D82898F98979D
A3A6ABADAEB0B2B2ADB2B0B3B4B1B1B0AFADABA79F9F99908D847A6E61585B4C494B4B52
55585752595E5C5F6366666A656767656264646264666261646165605F63605D5F60625F
6A839B96A2BABC878891949595989D989B99949C9C9E99917860636679825E452B2A2D20
211F2A4256685E4D505C5C828C69553D3D445E6947557379532B29272A316435364A472D
303163672E2B262B242826272B305C7B7C6E4F322D2A2E282B292F2E2C25242C331D1F1F
3978A098806D7DAACBB4A7ADB3AFB1B7BBC4C8CBC5C2BEB9B7BAB4BBC6C89D5041474647
44433F3A3533363433343431322F31302E323B30383936412C2E28262C292A385E838A8D
82827F847D7E83828F8C8E909197999C9EA0A2A9B4B7BAC2C5C3C5C8CBCBC7C5BEB9AD9F
8476573A3E353336333234333331302F2E3436373A35383737373C4647342B2932292927
272E4C4F2F499DACB1A1806D69564D42352D364E483B3B3A45373C2D2F2C322F35302D3D
3A393837342D26262F3E64798E918A89888282868F969BA1A09E9FA19F9E9BA19F9B9D99
9C9B9B9897989D9B969AA09B99A19D9D989B9C9D9D9C9B9A9A9C9A9E9C9E999A9B9B9899
9E9A979999999896959A9B9B98989999999D999B97999896959190948D8E909291908E90
8C89888989878687
626267636565656265636267626162666664605E6055595452535C69767E858C90969999
A0ABA7ABAEAEB0B2AEB2B5B1AFAEB1B3B0ACACA8A3A099918C847C706555505154484A4D
4F5458595B5D5C5C62636468636468696467666463656061645D5F646967635F665F6262
6471898F8F959E9B8E918F9695969A999896959B979A988C7B697B929B897B4E2C312C28
212825283C3A4C4A5057566C887748333B42516B504D6B744D2B2C282A39613850582F2C
2A2F5D652F282622232631303A497D7865412F28252B2B2C392F2F3028262424271F2523
284F91A0886E668DBCC0A6ACAAADB0B3BBC3C6CBC7C9C2BBB9BBB6B6BFC5C99F5A484E56
4D5048473C343B4038363935323831323533353532312D2B2D2B29282C35444B6A8A8C88
80807A85837D7A8989899292979B9E9C9FA1A9ACB2BABFC5C2BFC5C5C5C6C6C6C1C1B7AA
978A736461444639313237353831313330312F3A363C36383F404941473B2E2D312A2426
272D48542E4C9CB0B1A67C736F5450442F323852443D414143383D31302F333139322F2E
312E3739352F29272E3A5F7683898C89858086828B9197A19F9EA09E9F9F9EA29C9E9C9D
9B9E9B9C99999C9DA49D9B9A9A9A9B9B9C9E989B9C9D9C9FA19E9FA09E9D989B949C9A98
999A969B9C969C98979896989B999C999A9E989B9A999B958F93949392919190908E8E92
8D8E8D8A8B878A84
69696A666A65626D64666465646363646A625D5D5E5D545850585E63747F828B8F9799A0
A3A6ABADB1B2B0B4B1AFB2B1B1B0B3B0B2AFA8A6A2A39B969686816E69554D48494A4D4D
535758555C605F67636364636466696963656461646467656461615D5F5F636064646862
69686F777F828899948F9095959D9B9C9D9F9B99969BA59C958A98ACAD997B4F33433830
2F2C2E303B565C394A4C505D727B61312C404959574B6874502A222222355D4068402729
2D36595D2B27262624292E30435C76603A2A292C2F322D282F2D2E332930262423283D21
22276E8F9F77656FA2BFB9A8AAAAB0AEB6BFC4CBCCCBC7BCB9B5ACB1B7BFC6CDA65E4F51
4F5E574D454657544040433E393B3936322C32353C37382F2B2F303038537B6461788881
7C797A7B7C777A84898C8F969A9FA19A9D9FA3ADB0B9C1C3BFBDC4C3C4C2C2C1BEC0BBB4
A2998A8984676E61473B393733323431343439383C3C413D46474240464E33282B302824
2C2D49542B569AB6AB9B707772534434312E3C5C41383D453B3837333430313230323233
2E333134352B272B353B536F848E94888889847E8991999CA2A2A59F9FA5A19F9E9C9D99
9D999A9C9F9E9D9F9A9D9B989B9A98999C9D9E9B9B9A9D9C9C9D9E9C9D9F999C9898999A
9B96999B9F9A9C9B97989A9D9B9A9C9A9D9D9B999D999696929692939491959292909090
8B8D8D878C8D8883
5F5F65626463676D686B666D6265655F6462615E5E5B5557525A5F67737D808D92999A9D
A2A6ACAFAFB0B2AFADAFB0B0B1B0ADB0B0ACACA5A39F9A958E8B786963554F504A4D4E5C
555456585C655E5C61646365696266666363636061696162626869645E61636569646265
6A6768697071798587898F92969D9E9B9996959693A8BCB4B7ACA5AEA79B8E8766565255
5C483A2C3C41292832415055657881482B4A5752563E647861252223223154526E31302D
2D3C545E312F2D262429333E5F606C573425302B2B2C2E2D342A2E2B2B2A2E2727443F1E
1D223E81A28D6A697CB0C6B5A4AAA8ADB1BBC1C5C8C8CAC0B5B3A9AEADB7BDC6CAAD6454
555F6260646764604A4B49435249513B362F3851695E4B302E434540546F798057658077
7A75737474777A80868D93999C9DA2A09D9FA7AEB0BCBEC3C1C2C6C6C5BFBDBFBDBFBEB7
A99E908A88817E88785A515849373637393941473F41433F454C46424449412E2E2A2527
2E36494C2D5C9CB7B19374706757303130363B543C3D4341433C38352F342E342E342E38
3033363B36302B2A343F576C7D88888B89827E7F8392999AA0A09CA19C9F9F9F9F9D999D
9A9E9C9B9D9E9B9E9C9D9A9B9899999B9D999B9C9C9E9D9D9E9A9D9A9B999D989C989A99
9B98969A9998989D9B9A9B9C9D9A999B9C9C9B9D9A9797989293919296959494938F928E
93908A8988888787
63636469676866696B6A646D666865646666615C5E5A555C585A61677481838D92949C9E
9FA6AFADAFAFB0B1AFB1AEB1AEB1AFB1B3ADACA8A5A09C93918979705F5C504B4C4C4E54
5453585B595D66626168646669646268686666616968636561606B66656364676B666B68
6E69696D6E6B6B7473819597999D9E9A9699999590B1C2B3AC8B8CACA0887879837A6975
82836E3C373B3E28323A464C525A7B713D46434D48506573622D232223375B6B572C2C31
2A305B57342E29252324304D676C6234282B2528262B34322E2D262C2A25282D3B55261C
1E212C6194A173686B8CB9C1B0A4ACA7B2BBBDC2C4CBC8C3B9B1A8A8A6B2BABCC4CCB275
556460686C6B655E5F626666696D6B573E2F456F91847C5344657049676E7B7C6B5F7574
6F6D7170666D79818A939B9F9A9EA3A3A2A3A8ABB2B8C0C4C3C4C6C2C1BEBBBDC0C0BDB7
ACA49A8B7C7A7A817A6F6E76705F46574B455A5F555C4D4B4D514A433E414D392A29272D
2D3A424C2D649CBAAE91806E635F2E2D2F31375E3B3E443F413F3A3B32332C2D2F353737
3735383734302E32353D485E78848A8E898680808087949FA0A0A2A09DA09F9C9B9E9D9A
9F9E9B9A9C9D9B9C9CA0999E9C9B9D9E999C9BA19A9B9E9EA09EA0A09C9A9B9B9B9A9B9D
9A989B979B99979B95969A9B9A9C9DA09D9F9C9CA09A989B969496989599999796919191
8C898A888C898680
63636863656865696B6D646B666B63626562636061585A5753545E6A727C808F92949A9B
A4A7ACABB0AFAEB2ACAEB0ADB1AFB3B4B6B5AEA99F9B9C938C857A726258514B48485553
585A5C5B665E5E6267696965676363656764636464666368636466686168636364656967
6C6F6D656E6D6B71707A90969A9C9B99969492908BB0B88979566CA58D68504767847D7C
948D76573B5952372F2B323948536D786547413F444B597B64382325263F717F44302F29
2A3C5351322626282A30315565685B2D272828242A2A302F28282A28312D3852623D2922
262121357B9699716D779EBCC2A7A3ACAEAFB8C0C0C3C7C5BBACA3A1A2A6B7BAC2C8C8B6
8264626C7171727875767D78757C816E58335A8195928B7460777D5B5971737C7169646E
635D6461686D7A85989C9D9C9DA1A6A4A5A7ABAEB9BBB8BDBFC2C2C3C2C0BEBFBEC1BCB2
ADAEAA9583706E6B666B71777D7962656F6673746F6A5F4E505352473C3D4E392D362F2B
2933474A2B5D9CB8A99583705A5035303234384B3539423C3F47403A3331383031323330
3334323935362D33383E4452717D858A8C86837E7D8A8C999DA19FA0A09FA2A09F9C9D9B
9E9C9C9C9A9F9B9E9A999A9B999B999A9E9A999B9D9D9D9E9EA2A09C9E9D9D9A9A9C9E99
9A999B9A9898999B9997999B9C9D9C9D9E9E9B9E9EA09C9799919698979B9695948D8F89
8B87898888868583
6363666369666865666D6B6D6669686866636063655E53565A575F6A737F7E8A9496979C
9EA5A7ACB2B0ADABAFAFB0AFB2B2B0B2B1B3AEAAA19D99938A83797067584E4E4D505454
595C5B5E636060606365756B6767656267646465646664615A5E63616162656E62686565
696A6A686D717172707287919A9D9F9A948C908F8DA89D5D4B3A5F7472432A264784867F
99755F4F3856593F323C333447506963693B343734374E7A6C5330243154867D3828252C
29344C40372B27263028385766664C352A23222C2D2C2A3128272A3335436C6E412B312F
221E20214A7B9E8E7B7281A3BFB9A8A8A9ABB2B8BDC1C6C5BFB5A99AA19CB1B5BEC4C7C7
BD956C6F71787E7D7B7C8A8786848A83734F7B9B9D9B9D89718489765B6C656A645E575D
5A515A5C626F778F9EA5A4A3A3A7AAA2A5A9AEAFBABAB9BCC1C1C1C1C1BEBABCBAC0B7B8
B4B4B7AD987F6F5B565A5F67746C6872797A6D888B7A716263625B4B40363A382A2A2930
293345432964A2B7A39280735C3831332E36414A3239423C3E493F453334392F2E423634
3D343134343C3536373E3D4A677886908C8A8285828791989F9EA0A0A1A1A29E9FA2A39D
A19B9B9C9D9E9D9F9D9C9D9D9A989D9C999A999C9CA19E9E9CA19FA19B9F9B9D979D999B
9C94969C9B9C989B9D9C9F9B989D999A9C9D999A9A9D9A999896979996989394918F898C
8A84838686868182
67676363656A646369676D68666362666661636363635C5B575A60647379828794959A96
A1A8ABAEB0B1AAADB1B1AFABAEB1B3B1B2ADACAAA09C99908D867B685D534E4D4F565350
575656605B656160645F6465686C6A6366686265676662665D636865626568686B676A6C
6C716A6D696F717277727B848F959B96918C91898A9A824231313D3C3F2C232A5183807C
8D6551534D71684F48493A3B4047665E5F3C312D3132355C725F51292A6E8A5E2B242931
2634473B3E372E2A2C33395B5D613C3830242424292829272A30315953608552252B495C
27201D1F32628EA796827182A8C3B7A1A8ACB1B3B8BBC7C6C4BBA7969A99A8ABBABFC1C5
C7C09E6F6E7B828283858992938E928A757A90A5A3A09B8F7F818A7E5B685A5E55544F4B
4E484E4E60768796A6AAA9A6A8A7ABAAADACB0ACB5B5B9C1BEBDC0C1BFBABBC1BDC2BEC0
BAB7BCB4A89A8C7662545853615F576C6672667B8981786E71655F553D3A3736292B2728
2A2E4346316BABB5A5958473573B373338354753393C3D3C3D45433D373B332C2F333032
35303A383938393A393235415B71838B898A82817D838C979AA3A0A2A6A59FA39F9DA29F
9E9D9DA09D9D9C9B9A9F9A999C9C9C9B9A9F9A9B9A9E9D9CA19D9DA09D9C9A9C9E99989D
9E979999999B98999C9C9D9C9A9B9C9C9D9D999A999A97999A95959492938E91908E8E8D
8D89878686848485
6868666966646664686A67696862636269656563605F5E5E595B5F676E7C838A93989599
A3A7AAAFACAFAEADB1AFAEB1B0B1B2B4B0AFA9A9A09D96918D877E695D53514E54555253
5258575E565C6263636561686C6A656866676563616361655D6566636C656366666E6F6D
6C69706F72747572797376757E88928E8F8A878790A692484138302C2426292652808081
87685A585C62493D4B5A52383542605F515A35302A2A2745605D6840307E843F2026242F
3345614C463C373D63463F5B5C4327353B2929282B272529232D334F5F667654262D5B59
2E2A1F1D2439759AA7886E688FB7C3ACA7AAADB4B4BEC2C6C7BFACA39696A1A9B3BCBEC4
C5C7C1AB7C74787A86898E97999A958E7B969D9FA3A09A8B857E7E73616156534848443F
3F414F5B798895A1A7ABA7ABA4A7ABABADAFB4B0B9B8BCC5BCBEBBC1BBBABCC1C3C5C1C2
BEBCC1BFB9B1A79C886E615858564E585055546D6E756F686A6B61543F332E352A2C2627
2D3148412F79B4B6A3918676463E3E34333455423F44413D44433D3D3634312C37323037
342F343835433837372F383C566E8089918A868081838992979EA39FA4A3A2A1A09E9F9E
A29C9E9C9D9E9E9D9D989C999C9D9D9C9C9CA09F9E9D9E9DA399A19D9F9E9D9B9C9F9B99
9899999C9F989B9C9C9C9B9A9B9B9E9B9D9C9E9A9A9C9A989694989692908F8F918B8F8D
8A89888689888581
6B6B656C666B6866696860646364676A6564665C625C5E5E565F6068747E848D8F949DA0
A8A7ACACAEAFABAFB0B2AEAFB2B1B0B1ADADADA99F9D949190827B6D63574D494C4C5450
585D595B59635D5E5F5F66636E67646C6567626265625F66656865626766646465666A6F
6F6D707072756F7676757A777A7D808A88868B9598A5905E4636312D25272D30507B889D
926E5C606D5F403F4960573E3638425B4F6C542E302E362D47625F563B8D7F2E22252827
27334D3F423A2B3D532A334A543429363E2A28232C29202829345066593D696125335D3A
2D3E2228272A5085A2907264739ABFBDA69EAAB0B2B8BBC1C6C4B3A69B949CA5A8B2BBBD
C0C5C3BDB1887679838B919198999998929DA29B96958F817A6D605D52464D43413F3946
4F59678196A0A9AFABAAADABA8ABAAABB0AFAFB6B9BCBABFBFBFBEBFBEBDB9BDC1C3C2BE
BFBEC3C4BFBEBBB3AB9A917F726A584F54424B5555595E5856565647362F2E312C2C2B30
3039423B2E75AEB7A5938975403E3438343B4F3D435045414247413D37352B2D3631332F
312D2D33393A38323136313A4E6B828B8E8887837D82848D959DA4A2A0A2A5A1A0A0A09F
9E9A9D9C9CA09BA19D9F9E9D9B999B9B999B9C9A9E9DA19E9FA1A29EA09D999B9C9C9C99
9B9B9B999A999A979E99999C9C999A9E9C9E9A9A98989C92959091928F8D918F918E8989
8E87828585878582
6464696964686762686667626864616563636066615E5E5B555B5D6D7481849194999E9D
A2A8A7ACAFAEB0B2B3AFADB2B2B4AFB1B2AEAAA8A59C9C968C85766C5E53534B474A4F55
5456535C5E615E5E5F5E656570666267636263636868656764666A6766626669696A6D67
706E737672736F777676727E817A7B80808BA2B49C9A6F4A493B3D2D26272930567E8CAC
A1888386766C56413D5652433D3D36575D5B82482B282E2534575B5C56906F2921212827
262A3C4C424E4C3B35293B4F4835302B3C2D2727282A272A2E4A6D6033284E63284B5C2B
364E28221D2F3A6E8D9E816562799BBFB1A1ABAFB0B7B9BAC3C7BDAF9B979A9CABACBCBD
BAC6C3C3C0B9927B7D84898F969C9696979794918C847D74685C4B433B463D3D444C585E
71848D9BA7A9AFB0ADAFB5B1AEACAEAEB1AFAFB2BEBDBAC0C3C1C2C1BDBCBBC2BEBEBDC0
BFC1C5C9C9C6C5C2C2BEBAAE9A907F7166645F605B4E47453E3D44383328282C282B2A2F
313B45392D79ACBCA9928C61353C2E383639483F48433C3B46403E3B3B3834373D34322C
2D3130393D36373536312D374C5D758A8E8B898882807F8B929DA2A3A5A3A6A19C9F9E9E
9E9C9F9DA19D9CA09A9D9C9D9A9C9B9D9C9A9F9A9D9A9F9BA29C9FA2A09C9C9A989A9A9B
9E979A9C9A9C9B9598979C9C9C9A9D9F999B9C99959B9A948E8E91908E908D90928F8A8B
8A8E898386858685
6363666266656464696465676A646361646464635E5E5F5B575A6065727D838E92979AA0
A0A7A8ACACACADB2B0B4AFB1AEB2B2B1B2B0AAA8A19D9A928E8174695F53504A4E50504F
595956596165615D636766676468656965636965686D6C6A6767666868686560676B6969
6A6E73797374757975797B7B787C78797D86B2D1AE87643336342F2D2628323C557B8B96
B9CBC0BA7F6F594944534F4137343F4161487F782C282D27293D5A657897722721242B34
232A34353C5642323B344746392F2A2C3A372F322B30302C4260684E46323C602E5B5325
2D55311F2725233E75979F6E5B607BAAB9AEA6ADACB4B2B8C0C2C4B5A59A9C989FA8B6BC
BBBDC2C3C2C1BA9979767A8289908C8E8D897F79756E6B645B503F3F4447494B596A6F7A
8D9EA5A8B0B3B0AFB1B3B4B3B4B0ACACACAFB2B4BABAC1C4C2C0C1BFBDB8BCBCBEBEC1C2
C2C5C8CAC8C9C8CDCDCCC6C3BCAEA69B8B817A6F685E54423E39382F2B272926282B292C
313C4F37327DAEBBAB8F835F313A2F333A454C363A44403A3E3F3D3B3833383B31352C3A
383430353C3C3431312C322F46606B7F888D898886817F8493989BA2A9A6A3A09F9E9FA1
9F9D9C9E9D9D9E9D9D9D9F9E9A9E9E9C9E9E9EA09F9D9FA0A2A0A2A0A19E9C9B959E989A
9D979D9A9B979B9B989C9B9B969A9A9A97979699939696989492918C908D8D918C908B8B
8C89868583858485
6363676465646465646868656961636468656561625D5C5C5E5B6367767E838991979B9F
A4A6A9AAB0B0AEB3AFB4B3B1AFB0B1AEACACADA4A09B98928B7F796C5E57514A4D494E59
535952585C5C635E61645F6168656769666767676768606769636A65696967676B6A6E6D
6D6D71757778787574777A7A777B79797881B6DFB76C5D3435352C27272D272B38619098
AED4D6BC7B766A55506B57463231343C5C455883492928312B2C48617E88712222282836
2E2730302F383738343F4A393329302F36392D2B272F48464F5A52323D3D345733694E26
2F5C341D2727202A4C84A6836C5C6488B0BFAEA9AAACAFB5B8BEC2BBA9979A989E9EB6BA
BEBEC2C4C2C1C2C19E7666686E76787977756C666067655B534D57555D656B727D859298
9FA7AEB0B9B5B5B0ADB1B3B2B1AFAFADAAB3B5B8B9BDBFC1C1C1BFC2BCBABCBFBCC0C2C6
C3C6C9CAC8CACBCECECECDCCC9C1B8B5A898918173605F473D393531342B282627282726
31435D38357DBAB9A38D7B5A3A3B2D3C3C4A433D3A3E3A3940404C3E423536352E2F2D34
3430373A31373434312B2B3342556A7985898E8D87887F808E999CA2A4A4A3A0A29F9FA0
9CA19E9D9F9BA09E9C9C9E9E9DA1A09F9C9BA0A0A2A3A29F9EA0A4A2A1A39B9A9999999B
9E9E9D9C9B9A9A9A9C9B999A99989A989D989495989596928F8D8C8F8F8D8E8C8A8D898C
8C8B8F8C88878689
6262676565626761666566636363676565636160605C605B5B5E6366757F888993989AA2
A4A8A6AAAFAFB0B0B1AFB0B0B1B1B1B1ADABACAAA19E96938B807A6B615858484A524E55
5859555A5A595B60606665666A68676A69686B656764666A67626461676A65666C64676A
6C736E726F78797277767777777578767783AFE4CA8D6F73563825212225262A25498C8A
97A5AB997C7B70696573694E393035405966416B5F2822282C283A5F7F816A201F262B41
2C2C2E383433392A34353A302B2F2A2C353A372E323839352E4A462F2B2C3860496C3E30
325F422A25201D232B6D8B9982635D6C8FB5C1ACA5ACAEB3B2BFC0BBAD9A9D999C9DADB8
BDC0C3C4C6C5C0C0BFAA785555575861616066635B6068646456666E737A7C86909CA3A6
ADAFB3B3B6B6B5B1B2B3B0B0AFB5ADAAAFB5B9B6BABBC2C2C0C0C0C2BCBFBFBFC3BFBFC3
C1C5C7C9CACCC8CCCED0CECECECBC6C7B3AEA490856F644C3F3B362D2B26272828272A2A
2F4562393E9BBBB59E8978523335333B474D423135423839423E4644453B392E352F332F
31313237353639362F2A31343B536376848F8E8986847E848D9097A1A4A4A1A29F9E9FA0
9C9E9E9EA2A19F9F9E9C9C9C9C9E9A9E9F9D9FA0A39FA1A3A3A3A5A3A4A19F9B999A9E97
9D9D9A9B9E999B98989899979495939295979494979592908A8F90908A918C918D8C8D8E
898F8A8788888987
6767646167636665666060636464646164626564655D605959595F6A737E828B90939BA1
A4A5A8A9AFAFB0B1B1AFB1B0B1B0B1B1ADACA8A7A09D97918B83776B63575150444B5351
59575B61615A60606367686968696664606660586765646568635F65626768686E6A6B6E
6B757376737675767879757678787676757A96CDCDBDA59C8A462426252626272B3E6E82
8788827D8183796D6972705E54452F3E3F62465A6D3F2523242C34507581722B2323263D
3233393F39342F2F2F3340322831292A2B342C2E353335312C47372A29293065556C3929
325B5B37322E291E233B798CA0785F647297C6BAA9ABA6A7B0B9B9B7ABA39A9B969BA4B3
BDC3C1C0C2C5C0BEBBB9B0894F454755595D656A6E6874797D7E7D84878994989EA6A6AC
B1AFB5B4B4B7B5B5B4AEB3B3AFAFB2AFB4B7B8B7BDBBC3C2C3C3C0C2BFC0BEC4C4C2C3C4
C8C4C9CAC9C9CBCBCFCECDD0D0CCCDC8C2B9AEA498846F52413C3730322B26252622252C
2F415F2E50A0B9B59F875E4038353E4043383733393D3D3A3B49494746483D3532353430
3333323031353432312F332B31485D73828A8B89868480808691979FA19FA4A1A0A19EA0
9EA09EA09B9D9EA59CA19E9F9C9E9DA2A09FA0A0A2A49EA3A9A1A1A5A19F9B9C9A9B9E9C
999B9B9E9B9798989698949492979692959695969B909292908F8B8E8F8E918A92908C8C
8A908B8A8A8B8A8B
696968656E6363686462636661616164655D615F5D5D5D5F555E6468727D8A8F89969D9E
A6A5ACABACAEADAFAFADADB1AEB2AEAEADADA9A8A39F94928C8075695D56534A46535352
57595259585E60606061646764696C6667696467666868656564676569646A6D696B6970
70706F746F76777A747579777578757875747D97A9B699899F8138333E43434E5962767F
867C7D8282818079706D817D715E342E324D5E477757222329272F3C5A816A3A24262230
373235484D463E3C323E432D282C28252A282D3132333A332F57472424262C54656C3C23
234A6D4145503B27212A457D9D97745B657DAAC6B9A4A8A7ABB3B3B7ABA69A9C969DA6B2
B8C0C0C0BEC6BFBEBFBBB6B8A36D4E4A5266756E797986898E93919498989EA4ABAAAEAE
AAB1B4B0B4B6B4B0B4AEAEB1B0B1B2AFB5B7B6B8BDBDC4C4C6C6C1C4C1C2BDBEC3C5C5C7
C7CACAC7C8C9CBCED1D0D0D2D1CFCCCEC8C5BDB39E927962473D373330322A282B282E25
2D48592C5E9EB2B29B865F43434238363E413A444B403E403D45434F533E3F373A2F312C
3734313634383E39302C3131344557727E8A8A8E8A8A8181858B939DA2A3A5A29FA29E9F
A0A2A1A39FA2A09D9E9FA1A19DA0A1A3A3A4A5A4A2A2A5A4A4A3A6A09E9A9D9D9B9F9C9B
9B9D9B9C979498969A9592969391929594919192919092908F8E8C908C8B8E8F908C8D8D
8D8B898E8F8C8E93
5F5F686865666267665D626668626364626267605F5C5E595A5B69686E81888F9197999C
A3A6A6A9ACACACAEAFAEB1B1B2AFB1AFB3ACACA8A09D96938B85766C6055534A484C4E4F
5453585E595F5F636565636467696567696D6663676366646367646B6263626667686A6B
70727371717274767072777D767B7578777C777D84857D7E9EAE815A6F76798A9AA28E7F
7C7C7C7E7E8482807471798A8166412D2E3754496A712C2129222C314987675A2A22292F
33292A32405A615F5043463A3A312B272C292A2C3435382B315A582D2326263C69633D25
243A6A412C3440362E2F2B5883A689605D6187B4C2AFA3A6B0ACB3B2AEA5A69B9C9EA7B3
B7BFBEBEBABFBDB9B4B9B4B6B5A5896C64687C7B8A8A8E939499A0A3A3A5A5A8A9A6AEB1
AFB2AFB0B3B3B4B2B0B2B0B1AFB4B7B5B8B7BABEC1C0C2C6C5C3C3C0C1C4C0C4C4C4C5C8
C7CACBCACCCDCECCD1D0D4D3D4D1D0CECDCDC5B7A9957C66553F3A372C2A282929272A29
2F3D51336DA7B4B3977E50424C4836323E3E413A3A383E3A3840463A453E36383132322F
333B2F2F373339362F2C2A2D3340536876808C8A8D868781848B96989E9FA1A39DA5A2A1
A3A0A1A19FA2A19F9F9DA19EA39F9FA5A5A3A5A3A7A6A6A5A4A2A3A19FA09CA29D9EA09E
9B9B9B9796989397968F9091928F928F8F9490909093929193908D8C898D8F908F8F8E8D
8A8C908F8E8F9093
6464666D6361645E67616561656061605C5D615F5D5F5D58595C6468777F889191999C9F
A6A8ABADADABABB0ADB0AFADB1AFB1B0B3ADADA39F9D988F8B83756D6452544F474E504F
5356585E5F5E5E62666662675F616468616B67676A6864646467686967686567676C6C6C
716E71737173777471787673787678797977797277767786A7AF877F82878A9DBDC19575
757478778085867F7973737E816D5B3B2D2F3A405A784022261F242C4E87606435262125
3725282F384853666E565056433E312C2C2D2D313E38332D2B476F2F2728263864753D29
252C5C662A2B30383226242E648E9A735F596994B4B9ACA0A9A6B0ABAEA9A59FA19EA7B0
BDBFBEBABAB9BFBCB7B2B6B2B0B4ACA28C7C858B9397969E9FA2A1A3A4A7A4A6AFA9A8AE
B0AEB1B1B2B1B3B6B7AFB5B2AFB6B6B7B7B7BABABEBEC4C2C2C4C2C0C5C4C1C8C5C7C6C6
C9CDCBCACACDCFCCD2D1D4D4D4CFCFCFCDCBC6B6A4947E695F52473C31302725272B2D28
3544443B79A6B2B394754F474148363F3D5148444230333A3B41403C44403E3B35303130
343430403337403838312E2A343C4A5E747E888C8B898682828691979EA4A49FA5A6A1A3
A4A2A2A0A4A49E9FA0A0A09FA2A0A0A5A4A1A2A6A9A8A7A4A3A3A4A3A09F9D9C9A9D9C9A
9A97959697909198968E939290928E8F9091918D8C8E918C8D918C92898E8D8B8E948F90
8F92969698959597
65656767676667676862636261635D616161615F615A5A56595C6369747E868C95979FA1
A3A5AAAAAEA8ADAEB1AEB0B0B1ADAFAFAEACABA9A09D93928C81736D65574F4A484B4F4D
52565A5B59625E6364626766676765616767666366686A696A666868656968676C686B71
716E716A7176727375797B797A7479797676787975767785A58E616F77879CA8BAB67D6E
7A747D857C8086837C71707A84756A56392F3442597A4C2B2420252C4C855D514527292A
34372334474B444E687857494F48353127282F28383D31252B4472332A282B3F5E723E36
292B417D3A29242D342E21223E768C906956597290B9B89FA0A7A7A5A8AAA59D9FA1A9AF
BEBEBEBDBAB5C0BAB7ADAFB2B8AFAEB2A89E959598A0A0A1A3A3A7A5A5A7A3A7A9A7A9AB
ABAEAFB4B1B1AFB1B2B2B1B0B0B4B2B8B8BBB8BFC1BEC4C5C4C7C1C2C3C3C5C8C8C8C7C9
C9CBCDCCCBD0D1CFD2D3D5D2D4D0D2D2D2CCC6B1A4917E6861554E3B32272627272E2B34
38544F4877ACB2B0946C5937384B33363B414A3D353A433F3B39433C3D40413F362D3032
3341343336333538332D332A2B3740526B79898F8E8A87807D8393939BA2A3A19EA4A6A3
9FA8A2A2A29C9DA19E9F9FA3A1A2A4A5A8A3A6A7A6A2A5A6A7A3A39CA19D9E9C9D9B9999
92949597939090969195928F918F8F8E91918E8D919093908B8E90928E8E8F91938E9393
9491949498999A98
6767666E676466686264665E66655E6163606069655E575B595C65677681888E939C9DA1
A6A8ABAAA8ABAEB1B0B0ADAFB3AFB2ACACADABA9A09C938D8A7E73686058544F484C5152
575C5459605D5E626464646467686560646C6168696866676268696966696B666A6A6B6C
6E6D6D7072777877797679797774767D7578787A7C777D7E93784C4C61728E928A8E6772
807D7C84807A86887E787673807B6F68553B2F335D6E4D2726222327567F5A3F3F363424
283D2C3A3F3B3B33476D71423946363425272E2C3C37292827376B4D272A2C3F5D5D3A3B
3B282A5D753E282C282520292B49788775635C66799ABBB0A1A0A4A3A5A29C9E9EA3A6AF
BCBEC2BCB7B4BCB7B8B2AAAEB9B5ACA9A6A6A79B989AA1A4A8A2A4A6A4A4A1A6A3A9A7A7
ACABB4B2ADB0B0B0B2B0B2B4AEAEB1B6BCBDBFBFC2C4C4C8C2C5C3C1C1C5C2C9C8C9C8CC
CAC9CCCCCCD0D2D4D0D1D4D4D4D6D2D3CECEC6B4A2887563605B5540342B262A2A2A282E
35514A4F78ACABB191615B36364132393A3D493B3D3F3E3B3C3B3A45444240393C393832
2E3038322F2F3537352F332C2B2C334B687A878C8C8B878281838A9399A0A4A4A1A5A3A3
A1A2A2A49FA3A5A2A39F9FA2A0A1A4A5A4A7A6A7A7A2A7A8A6A2A1A1A09CA09D9B989696
9595939495939496918F8E90928D8C8E8F8E928F8D8E928F8D8E8E8E9192969397969897
979399959798979B
6666656B66636A696664636A64655F5F615E5F675F5E5B5B545F6568797A848D9395989C
A6AAACACACAFAFAFAEB0B0B0B1AFB1AFAEACABA5A39C93908983776B65574F4B4C484F54
575554565E5F5F626863646367666367696869696865676C6964656663676C676B6C6A6B
6C6E7271747977767A787776737473767271716E7177757A898B71595B5561797B776070
87837B80828280817C787B817F786D6657462C2B3D625A2C27262226507D52402F404F2B
2433373D2F322D2E37426B686547363B2A25222B3B372E26293759642A252A4751583940
432F273C78714130231D1E2020325372767E6C636A839EB4AEA29DA1A1A09FA1A1A0A6AD
BCBBBEBEB5B7B9B7B4AC9CA2B6B9B6ACA3A7A6A49B9A9A9CA1A6A9A4A1A3A29EA4A9A7A6
A8ADB0ADAEADAEAFB1B2B4B4B1B2B4B8BEC0BDC2C3C5C6C5C2C3C1C6C3C6C4C9C8C7C9CC
CCCCC8CED1CFD2D2D2D3D3D4D4D4D0CCCBCBC6B39E88776660624D44332B27272A28282E
365E47578FABB0AA8965582E2F3930333B373B353A39343A3E3B3D4346403C3B3F383332
2E3234323032353533392E2C29343143597682878E8C898785858890989EA4A7A2A3A5A3
A2A29FA1A3A0A1A39FA19FA2A2A1A7A5A2A7A3A3A6A2A5A5A2A0A09D999B9D9D9C969799
949492969591989293909092948E93908E8D8F8C8C909191928E8D918F9298989B999595
9397969798989699
6464686A6366666B6A6563636466616164666961625C5A595B61616B7681848B9196999F
A4A8AFACAFAFACAFAFB0ACB0AFB3B3AFAEAFABA89D9C9A928B8473666056514B514E5153
5453595F5E60605F66666065686862656A666866696F6A696A6B6664666668696B6D6E6D
6A736C7276767874726F6C726C6F6B6D6E656C696465677281949278575D577D79686973
8683807E869289877B7A7E827A73625B4E472F292D565B2F292426244F7B45302C3A6234
292839282524272C363E4D6369623F3637282930393C2E2B2C2D52642D262D4A3C3E3929
31322D2E638C61291F1F1D1F21283E6C8E97847C716E86A7BCAD9D9EA3A09FA2A1A6ACAF
BBBCBABBBCBBBBBBB2AE908FABB5BCB8A7A9A7A6A19E9A9B9CA0A5A6A39E9DA3A1A6A1A8
A8B0ABB0ADADB0B0AEB4B5B6B2B6B8B9BEBDBFC1C4C3C6C7C4C7C2C4C7C3C4C5CBC8CAC9
CACECBCCCFD0CFD1D2D2D3D6D6D3D1CECAC7C0AC9B8A73645C595140342A25252A292C31
385D495896AAAEAA8359562D393C2F2E2A2F393933343D38383C443E404042403B393330
2A2B332F323438323932332D292C333A53727B848B8F8E858887868F959AA1A4A3A7A6A3
A1A1A2A19FA09F9E9D9E9FA0A2A2A5A2A3A4A1A4A7A3A4A3A09F9F9B9D9D9A9D989A9296
9092919393929395948F9090908E8F908F918F8F8C918D8E9292939395949B989C9A9598
9796969895969498
6464666A62696364636767646165635C62655D645F5E5B5A5960646C737E8A8A9093949C
A8A4A9ADADACABAFAEADAEAEB2AFB0AEAEADABA2A19C9A948D81766A5D5455514B4C4F52
5A57595E60605F5D6063686565676864696466646A686D6565696663666567656A6D6D6B
6C70707374777471707170736B716A736F6E6F706A6566797D858C84716E828C716D7570
7A7E80848B8E8C8D867C807F7A7D6C60594E39302E4559382C212627457640382A274A54
32313C2A2525283452483E395A62533D322628293239372C292940663B273B5A31343225
263245344F7A532120231E1E203162678E8EA1887D6A7488A3B2A5A0A4A19CA2A2A5AFB3
C0BCBAB9BBB8BBB9AFA48A84ABB0B9C3B8AEA8A69F9C9E9C9B989EA09E9E9EA3A0A2A6A5
ACAAAEAFABACACB0AFAFB4B4B3B7B6BCBDBFC2C3C5C4C6C6C6CACAC6C7C6C7CAC9CACBCC
CCCFCDCFD1D1D0D2D3D4D3D6D7D4D2D4CEC4B8AA948675656358503D322B2D2928292831
48655069A4ACAEAB6E58483143382C292E383D3F393A3C3F3A384040423F3F4840383530
3234303139383336383A362C2B2A33464D6C788488918D878A87888F9099A2A7A4A5A4A2
A0A0A1A29FA2A1A1A09FA1A2A6A3A2A5A3A2A2A0A4A1A3A0A0A09B9C9B9B9B9C98929894
93948E908D91979490909494938E929190918E8F909394949290989B9895969A999B9A9C
989A979494989996
6767656769676267636666656363645F6363635E5A5E5E56585B696E7880888A939997A1
9FA9ABACADADAEB2AFAFACB1B0ADADADAEA8AAA5A09D98938F82756A64544B494B4C4B58
575C5E596162625C68686267636765626A676A666A6D6963656668686669686668686C6E
696E7475776E75717277757A7B7B7578777A7A797E7B797975797F7E81899A8B71737A77
6E7C87868A898187928780807B7C7E75615448322D374B443327282D3F6E46322A293145
3327302C26293449613B2E293B55584A392E2B2F3831392A2C2A3C5F412B455D332D3727
2B2E3D364F653F241F2120202C4F7D675F729BA187746F7A84ABAFA3A4A29DA6A6AAB4B5
BDBBBAB6BFBBB8B1A098747DA9B0BCC3C0B6AFA6A2A199979B969B9A9B999BA0A4A1A3A5
A9AAADAAA9ACAFB1B1B4B0B7B5B7B5BDC1C1C3C2C5C3C3C7C7CBC4C6C7C8C9CBCACBCBC9
CECDCFD2D4D2D4D2D6D5D4D4D4D6D3D3CDC4B2A392826D5C60574D3E332F292C2B272731
4763436AA1A9AEA469594233443C322C3B36333B39393A3A413B413D3B3D3D3E3B3B372D
30323634332F33393736332C2B282E35455B737D88938F8B8B867F8A8F97A2A1A2A8A4A1
A3A4A2A3A5A4A4A49FA29F9EA3A6A6A59EA0A3A0A29FA09C9E9E9C989A9C989C99998C93
8F8C929095939596938E8D938E8D8E92958F8D8F94949798999799999795969A9A9A9B9E
9A99989997979597
64646D6768676A60646B646867616B615E615C5D585F58585859616D7C7D858B90989CA0
A4A5AAA9ACAEAEAFADB0ACB1AFAFAEAEAEA8AAA5A19E94948C88756860584B4B4C4E4F52
575F5B5D5D5F5D615E636363656C666664686567666969646A686D64676B626969696F6D
696D757C6E6F767C75757A777A7476797977767A777977746F7679777D9EB997787E7972
696F838B83818485867E7F84848A8A846E5E5D43332D314139292643506467332C292636
3728292B2C3348684B3625322E3E574E35342D3C362F3B2A302A36594B323D4E2F313731
2E422D344E533F23231F20243373865A3156819F947D6F777A90B7A99DA2A5A5ABAEB3B3
BABEBAB9BBBBBAAE929A7681ACABB8C0C2BEB8AAABA19D999CA2A59A989B98A1A1A0A3A2
A8AAAEADACAEADB3AEB3B0B0B2B5B7BBBDC3C2C3C2C2C4C5C7CAC4C3CDCCCCC9CBCDCCCA
CECED0D3D2D4D2D2D7D4D6D6D6D6D3D1CAC1B09D8F7E6560584D44372C2D2F2829242D31
545D3E7EA8A8AFA35E6E3C332E3730262F3638363C35403E43413A3B383C3D3F3D333A37
37362E33312F2D35353433322D272A2832466175878C948F8F8787848F969FA4A6A7A4A4
A1A1A5A1A4A3A0A19F9F9BA1A1A4A3A3A19E9D9A9C9C9C989A9A9E9A9B9B989795929291
929195919891919394918E9594919293909196949898949B999F97979B9695979B99999A
97999A9797979696
6868696A67686B6765626466675F65615F5E5F615E5E5E5A5656636B747D838C91999B9F
A6A9AEACAEB2AEABB0ACB0B2B0AFAFB1AEACA7A69D9C92908B83776D6459504B4E514B53
5A5D575D5E62625F676166636464646366666564676C6B6A6467686365676766656A6867
6A7085867573757372737A767878767C7C767B7B767571727776777687BDD2AB7F7C7B71
6967718686848C8A7F808485858D827A7F6F6951462F2C313F332B54715D683927232829
2E292A2A34476B5F3B312B2F30334D5C46362D2C35383A2D2C2E334A542F343B282F2E34
51562A324D51412B2823202B45947B4B202C6687A0907A777F8095B1AA9DA7A7AEB1AEB0
BCC3BBB8BBB9B9AC8C9B7D88B0ADB1BAC0C5C1B6AFA9A4A09C9BA9A2939C9D9F9DA99DA1
A8A9A9ABAEAEADAEAEB3B0B0B9B8B8BAC3C3BEC1BEC5C7C7C5C7C8C7CECDCDCACACECDCD
D0CFD1D0D3D2CFD2D6D6D6D7D6D6D1CEC9BBA9998B77655D594E3E312F2F2828292A3338
56434898AAA9B19E5B713E2E2831343735363B35353A3A40383A37343C37383E423A3A33
3138332F2C2E2C323A38363630292F2C2F3A53748592918F8E8A86848B949DA0A5A7A9A7
A6A1A3A4A2A2A2A0A1A09EA09D9F9C9F9F9B9F9A9A9A9A9B999A97999898939596919293
93918F8F918E9195929192909596959997979B979B9C9A9C9799999799999799999B9A9B
9897959898969593
6868686B68686965666662636664656061605C5D5D5C5E56585D666D747F818C8F949C9D
A3A8A8ABAEAAADAFB1B0B0B1B0AEADAAAEAEA8AB9E9A98918D7E756C6357514A4E4E5153
595F625D60635F5B60626264666467656169666A66686A6266636964696567696A66666E
6C76867D6D6F71706E787C7C7577787679777678787572727270717C9CD6D8AA80767F79
726E6376838887797A8185868A82777883775D595D56412F3631343A535D5C4D2B2B282B
2B292A2B335A6C4D3F3E3D342F3F41484B312F2A32394732312C303D523F38382F282C38
68612E4A514C482F2722242E6E91692E1D2336698AA28A787A727B96BAABA6A6ACADACB3
BFC2BCBABAB4B9AF8998878BAAA6ADB4BCC5C9C0B2ACA7A2A19FA1AAA29C96999BA1A09C
A3A6A9AAABAEAAAEACB0ABB2BDBBB8BFC1C4C0C3C0C7C8C3C7C8C6C7CCCACBC9CBCCCCCF
CDCECED0D3D2D2D5D4D3D4D4D5D3D1CCC3BCAA9885786A5A4E49382E2A2B292B2F2F2B3B
573A50A4A9A9AB8D5D74512F2D34313034353537383C38373A363A3E3B393D3B3C4B3C3C
433432322E31303435373936312F2D2F3433526D7E8D93918B898280878C9A9AA3A8A6A5
A5A0A4A4A3A3A3A3A2A39D9B9C9B9C9D9B989C9C989B98999D999C959993909694929291
9293928E908F92919793939698989A9B9F9B9F9E989C9A9A9796999899989D979A9A9B9F
9C999A97989C9497
6B6B6A6C686B6C6B66666261655F696A5E62655A5F5E5E5D605F636B737D80889194979F
A4A8A7A9ACAFAFAFAFAEAFAEAFADB0AEB0ABADA6A19C95908B847A6D6159554E524F545B
59595A5D5D5C615C63666165666667656960656466676A6168656A64626C63656C6B656D
707077757275726D717676787577787574787376777474736E6E6E8AC6E2D29E7F777874
6F746D6A7B8981777B7D80858B7C7F85827868615E66614D393C3B303141535C2F252729
232D282F45685733474B4E352B2C2F3A423131313039383536333239484B3A3926272C38
6A5B3C67434251473733344F9A88512A1F212041788BAA8579707781A2B6B3AAAAAAADBB
B8BBBEB4B4ADB6B2939A8F95A7A1A4B2B9C6C6C5BCAEAAA2A5A6A1A4A6A797939A9A9E9B
A5A2A9A5A8ABADAFABADB4B5B8B7BCBEC3C3C3C7C5C4C7C3C7C7C7C9CBCDCDCACECBCCD0
CFD2CFD3D1D1D5D5D6D4D5D5D7D1D0CAC3B8A2917F68615D503E352E282226282A283247
603766AEA4AAAA83636E4E2C2F322E2D3334383E363B343B393D3D3E38363D45453B3F36
36362E2B2D333533303737383B382E2A2D344B657A8891928D8E8A87868A949BA4A4A4A5
A2A5A3A5A2A4A49F9F9E9E9C9A9C9997989598999996949A959897959595939391939394
94939493928F93969A9B9D9A9D999B9C9E9B9C9C99999D999898989B9C999A9A99989B9B
9499989797969594
66666A686A66696766656460646463636464625E5A5A5B5C6A656767757C838A9095999B
A4A7A9ABAAACAFAFADB0AFB0ADAFB0ADB1AEADA5A09C948D8E827072605B514E4F525755
5354565B636562636567636563636864646464656667686463646A616565666A6867696A
6D747771747272767373757872757A797576747474746E71696A74A4DBE3CF99767B7675
72726A697283807D7B7983897A798787837E746B6662645F492E32313033404F3F2B2725
2C2929314D6E492C3336383E332E2D353D47302D3337333A423131373B483D3526242E47
69594E643C4B59615D565677A68A5E271D1E202A46769A9B83787B7881AABEB6A5AAACB9
B3B8BBB6B5ACB5B399919298A7A0A3AEB6C3C9C7C3B6ADA5A7A8A9A49FA0A69493989B9C
A09FA3A2A6ADAAA9A8AEB3B7B4BABBBDBFC3C1C5C2C3C5C1C4C7CAC8CBCCCECCCDCAC8CE
CFCFD0D2D0D2D3D4D3D5D5D5D5D0CFC5C0B3A1907A665D574D3E342C2622292928313B54
503984B0A7A9AA7C625A413A363A2A2B2C35393B313C3535424035403E3C3B423F44443A
39312D2B2D31322D3032313538312B2A272E385272828F918F8E8883838A91989EA5A2A4
A2A5A3A2A69EA19E9D9A9D9A959898959796989493929594919995969A9495938E929192
9793969195949C9BA19B9FA09D9B9F9F9C9B9D9C9B9DA19D9B9A9B9D9C9A979A9B9A9B97
979A959798999398
6B6B676C6B6B67646767675F6563686161616263615B5D5A5961696F767F878D8F9799A3
A3A7AAACA8AFB0AEAFAFAAAFACAEB2ABB1AFA9A59D9D98908B84816C6559554C484C5453
5758585C5B5D635F6768666865696864676C64646566656266646362636163676A656B6D
6C7F776D726E727672767877747474767072767576726E6A66707DC1E2E1C98D71777672
716E676D72777D82827D7576727E86887D84817D6A686764543E403935383634432D2926
272E282B576E3E272B2E2A38403F2F353744342C2F34383D373132312E443C312E313C4B
5548595B4568655F52533E68A48C6F36231D1D20295285979B8079727B8EAFC0B7A6ACB8
B5BAB0B2B0B3B3B1A18D90A4A6A6AAB1B7C0C7C5CABEB0A8A6ADADABA4A2A3A49D95929B
9CA1A0A2A6AAABABAAA8ACB4B8BBBDC0C1C1C1C3C1C3C6C5C7C8CAC4CACCCCCCCBCBCCC9
D1CDD1D1D2D4D2D3D2D3D4D1D1CFCBC6BDAF9F8D74645557473B2D28242322282632415A
464093ABA2A4AC81635A39383332344338363C3B323437383C39393F3D3E433E43424238
3E34322D342B312F2F34343636302F2B2E3338516076868C91908A88858591979CA5A8A8
A8A59EA39C9D9A9A989A9696979699979597989491959093979697959497969696939092
96979998989B9C9E9EA1A0A1A1A29E9E9F9E9D9B9D9E9A9D9D9B9C999A9B9B999D9B9A99
9595949798969495
67676C716A68686B6A6766666566686563636864615E5C5B585F65717580868D93959DA0
A3ACABADABAEACADACAFAFACAEAEAEACADADA8A6A399968C8683706B645A534945475354
5555565F605C5E696565636767666768686A6A6B64696868646762646365616268696469
6E8B8672727072757172717271757473757473756E6D6D6D6C7499D9E2DCBE7F6F717575
6F7170737474727C817C7C7277848582868885827669686A6C615B5539353535363A2729
252E39345B693F2527272F3047513E303840422B292D383438362A2B2E3A483B2D393833
4649666C6F79594C3B3B2D5E986A41251F1C201D252E5983A196857C737B93B4BDA9AAB0
B8B9AEAEA9A8ABAE998A90A7A8A7A6B6BABDBFBFC4BFB3ABA5A9ACA7A7A9A7A2A5999196
9B9D9C9FA6A6A8A7A9ADAFB7B8BAC1C2BEC0C0C1C5C3C4CAC8C9C9C4CACBCACBC9C9CDCB
D0D1D2D1D3D1D2D2D6D4D3D1CFCECAC8BDAB99867367565146372E26211F232A2E314B59
3C4E9DA5A3A9A4846848363C3236493A2E33383433373B363C3A3D3D39373E3C41443E3D
3B302E342D2B2F2D31303432363535292A30353D5A6A8189938F8F88818090949DA0A6A5
A29EA09F9C9C9B9D999A9799989E96979A9695979499969199A096959898969698989798
999E9EA19F9CA1A0A0A2A0A0A19FA29FA09E9D9F9F9F9E9D9B9C9E9C999E9B9B9A9A9D98
9999979499969492
6A6A696B686B6A6C63696767696367636463655F60605D5B5C6263727780888E92949B9F
A2A5A8ABACAEADADAFB1AFAFACADAFAFABACADAA9F9C978F8B83776E665A53474C4E4652
4F565959605D625D636763656764676A6A666A6967686962686562626564656562646466
6C83A78E7871726E787973707374707176757475706E70657084BCE4DFD6AB796E757272
75797579797464697E797E7983807D7D858E8B837A746F6F6963575A44332E2D2F322B32
262F3538696D41272A292F2E414C47382C363D302D333732423537292E36413C38373432
3F607269787E50402A35366889582920262024221E24365D91A994847B777D95B6B9A9A8
B6B3AEAAA6A3B0A3948B8FA9B5ADACAFAEB9BEC3BFBAB6ACA7ACABA7ABADA8A7ABA5A095
9394979DA5A6A9ABA8ADADB3B7B9BEBFBEBFBAC3C3C5C7CAC6C6C5C6CACDCBCBCAC9CACB
D1D1D0D2D5D3D3D3D4D4D6D2CFCAC4C4BAA799847363524E3C3430292223272A33364B52
31689C9C9EACA689734A373031393C2F303136333535373838373A3C3A3C3C3F4246423D
353733332D2A2A31332D38373C3538282C2A2A354B627A8A8C8F8B8A82828C909B9CA2A6
A59EA09C9B9C9B9A9999979897989A9499999693939797999B9799969B969B9A99989A9A
9F9D9D9F9C9FA1A0A3A19FA2A0A0A1A49FA19E9E9F9CA09E9B9D9C9C9D9C9B9B9B999E97
9C989699989A9494
68686B67666865686867656467636663696361645F5E5F5C58606968757F878B91969FA2
A2A6AAADAAADADACAFAAAEB2B0AEAEADADAEAAA99E9C99918A7F766F60584F494751484D
4F56515A5D5A5D5C5F6362666867626A67666769636A6C63686362656861636465626267
66708FB0A3786D6F736E78747471707470736F706E676C696F9BDCE5DDD6A4736D757172
7678787D736D636172758186857A7E79858C86736A7A6B67604B475153432F2E333F372E
2A2C2C3C686D4D2E312C2B2B303E473F32333B353235313736442E2B2E3B3E4039323237
4E636E675C7A3F372D333B8089472524281F24232823292B6291A5958174727BA0B5B9A5
AEADA8A9A1A8A8AA96878EA9B6B1A9A8AFB9BCC0C6B9B8AFA7AAABA9AAACA9ABAEAAAFA1
9693959CA3A6A5A9A7AEACB2B0BABDBFB9BABEC3C2C2C4C6C3C5C4C9C8C9CAC9C9C8CDCC
D1D0D1D1D1D1D1D3D1D4D6D4D1CCC3C1B5A4947E6F61514D3A3B322C2627282B30374C46
2E789997A1AEA9866C41333333392E292F2C31353333373B393C3D393B44393D43433D3C
3834332E2D2F2F2C322E3039343435312A2A2C2F455F747F8A908D8786828989939DA4A2
A39E9C9C9C9496999A959595969796949596989494929694969A98969B999C9EA29B9D9E
A29FA19E9C9FA0A2A2A0A1A1A1A2A09EA19F9C9FA1A19E9D989D9D9E9C9B989C9F98999E
989E999C999A9895
6464666E6D6966636F676A6D6567676365626362645E625B5E60646D767F889293989DA2
A2A5A9ABAAB0AFADAEACADAEAEB2AEADACAFAEA6A19D978E8A84776C65585548464B4D4F
4E5455575B56585E62625F686A63656966656B6A656A6B65636469606365646166626366
696A6D8CB999726E6D737673766D71716C6F6B6B6D6562677EB4E4E1DED6A67475726A74
757F78747472676564677F8B8584827F83877C5F4C5B5A50523C495B594F3937384F5247
332B2C35666D49342D2A2A2C2E3646463A3B3C392A2B2E2F2F3B353134433E4239363444
5A60633B436A372C2F3450908137292D2A27242123202124346B9BA08F786B6A7D9BB5B5
ACABA5A5A6A6A7A394848DA7B1ADA39FB1BAC1BEBDB8B7B1A7A7A7A8AAABABAAABADAEAC
A79C9395A2A0A2A9AAADAFB0AEB6BABCBBB7C3C4C1C3C4C9C6C4C7CAC8C8C8C9C8CACBCC
CECED2D0CFD0D2D5D0D0D3D4CECAC4BFB1A58A7A6B62584B37312E2D2A272B2A3746523F
428A999BA5AAA686653A33403F36322B333A3630303B373738393837393B3B3F443C4444
3E3738342E2A2C2A30343237363F362F292E2C2D3A5171808F918E8A85848387909A9FA1
A39E9D9D979C979B9696979395989795949698959896979A9A9A979FA2A1A0A1A09DA1A3
A19FA39FA0A09D9FA0A0A3A3A39F9F9EA19D9C9EA19F9B9E9F9C9D9C9B9C9E9D9D9A999C
9E9B999A9A979598
6363636D68656C676B646A6869676562625F6261605E5B5B5A58636D7685868E94969AA0
A4A3A8A7ACA9ADB0ABABADB2B1AEABADAFAFADA8A09A938E8A877A736159514D4950514B
505154555F605D606261666868636B6562686C6862686463666668656664696566696666
6163676F8CA77B6C717572776E7076726E706D676462606893D1E0DEDCD6B67972746B71
757B787574716D6F6561697A868A827D807A776C63685041403B48574F52494B4D5C5C5A
43392E3754685A322D292A2D262D4043372E413A322C2E342B303A3C414C3A3B41353448
545C4F3137613A2C2E406F8F712C2E292327262322211F2025367097A88E74677283A0B3
BFB1A9A4A5A4A5A08E8489A4A9A59E9FA9B6C1BBB5ADB6B4ABACACA9A9ACA6A8A4AAA8B2
B3AF9D8A939D9FA6A7A9ACAFAFB4B9BBB7BDC1C0C1C0C7C8C3C2CAC9C9CACAC7C9C9C7C9
CECAD0D0CFD2D2D2D1D0D3D2D0CAC4B9AA9D8778656059473830262726262C39464C5038
56929FA0A8AD9E885230383B373A2F3A2A3433313441363536343B333B3A373C41433E40
3C3433302D2F303031303536373736382C2A2D31365169798992918C86847E818E9598A1
A49F9E97999D97939A989795999494969B98989B989B9D9DA0A19EA29E9FA2A2A0A29FA0
A3A1A3A0A0A3A09FA4A3A3A09F9FA0A0A0A0A4A19E9F9EA19E9C9B9E9B9E9D9BA09A9D98
9A9D97979A989693
6868696769686B676D67696A68666867636365666065605B5C636A6F7780858E91979D9F
A5A5A7AAACAEAAABADB0A9AEAFB1ACAFAFACA9A6A1989B938E84776C6151514343474E50
5150575B5B5F5E5B5B61635F6861635F5F646163666A6465646964646664666366696867
6864696A707E7C6A6F74757370726F747171706A65615E6BA7DDDED8DBD8BB81716E6E6F
737171746E6E76736A6C626E7E8D8C7C78777B8181806E5857635B604E4C413941434244
35342E2E5561623E2D2A272D292D343B2E2E383E33312F36313340514C4A413D4439414D
465950292B4B3B352D59888A5E272926242E282323211D1E1F264173A4AC88716774879F
B6BFADA6A4A6A5A38D86809BA7A4ACACA2B0C0BFB6ADACBDAEA7ADAAA9AAA1A7A0A8A3AE
B0B7B59E8F999FA6A5AAB2ADAFB4BBB4B9BDC1C4C2C4CCC8C6C6C7C9CAC9CBCAC7C9C9CC
CBCBCFCFD2D1D2D1D3D5D5D1CDC9C2B8A7967F6C615C5146312623262E2F303F454D463D
76969C9CB2AE9C7F4D2F2F3231362E2E30434537383F38353839343536373B3D42433A3F
413A3530332B302F2C313232323A372F282C2B34364D6075818F948F87887D7E8B929A9C
A29C9D99959B99979997969193999B9799989A9AA09C9DA1A39F9FA19E9FA3A1A2A2A1A1
A0A0A39FA8A0A4A5A5A59F9EA1A19FA0A2A1A0A19D9C9CA19BA09C9E9D9E9D9C999C9D99
9D9A989696999996
66666664646A6368696A6963656569616467646764605C595A61656E7683868D92979AA0
A3A7A7AAAFACACAEAAACACB0AEAFAEADADA9A8A79E9EA09489817A6E6A55514A46434F4D
4F5652565B615A615C6665646160665F616466616761656763636666646664656A666A67
67676B6D6A6A706F7278777871706F6F706D6B69635F5E77BADCDED6DADBCA8A6B68706F
716E7369697175706D6D756F74868782797E80818182745765737270716F66565750563F
2F2E3233515E604D322B2A29272D3237332F313B3332352E33385354484845424541433A
4061562B2E3E40373C57928E5B28272C2D2B2A25242A211E1E21254A85A49C89706A7284
A0BABDA7A4A5A4A386808399AFB5B6AEA4B2C1C0B8B9B3BBB3A9A7A6A0A8A0A4A1A5A4AE
AFB4BBB5A59B9C9BA4A7AEACADB5B6B3BDB9C0C3C2C5C4C7C7C2C4C9CECBC9CDC6C7C8CB
CBCECFCFD3D5D5D4D0D3D3D0C8C1BBB4A3947A6B5F5F523E2D29272B2E2F36424C493F57
879B9C9FACA697764D312B322F2F2B293137302C2E343434383A40353B363836383B4243
3F362F332F2C2E282C28292D2E37322E2C2E2E3739444F707E8B8E908B89857F8390949C
9E999B9A98959596939C9294959C9F9A9C9CA29CA2A19E9EA09FA1A1A2A2A09FA2A1A2A0
9FA0A4A1A4A3A0A6A3A1A49D9CA09DA0A19E9E9E9E9F9EA09D9B9D9F9D9E9D9E9C9B9C9B
9D9A9A9A98989596
64646C6A6B6E67696967606767636365666665645C635B5C5B6369727B7E8689919A9E9D
A5A8A5AFB1AEAFAAABA9B0B1ACACAEAFAEABA8A49E9C99928B817866634F484849465353
5353565B5D5B5B5C615F615D6762666764646562696B65625F6662636263646768676868
6A686C6E6C6E736D747677766E706C706E6C6A5E6762638DCEDFDBD5DAD8CB996C6A6A68
6A6B68696A707775717778746E757C7F7F8384847E846B57787C72707272796F6E756947
2D272B2D3E575F562C2D292F262B2F36342D2B32302D3134384A564F453A3F494B454031
4562582B2D3C3C2C32518E8558313E404B433E2E29262423231F212956829AA088716C68
789FB8B5A0A7A298807B8EA0BBBAB1B4A6B7BCC3BCBCBEB8B5ADAAACA2A4A39FA19E9FA7
B1B4B6BCB1B09F989CA4A8A8A7AFB0B4BAB9BBBDBEC0C4C4C1C1C6C9CBC8C9CAC9CAC9CB
CBCCCBCBD3D1D2D2CFD1D1CECBC1B9AFA489736857594B3D2E262A2E2F2E4249554B3E65
929A949BADA39A7D4D2D2D2F33312A2B2F312D312B333337313536353A31403A3D38403F
45473A342F2B2C2C312F332D2F313D312A2D2D31363F4E5F76838F8B8986857F7F879397
9B9A9B96969896979B9698999B9F9E9CA19FA2A6A7A5A2A4A0A7A2A6A3A4A6A1A09FA0A0
A1A3A2A2A39FA2A6A1A2A1A0A3A19FA1A09F9FA19D9C9C9CA19F9F9D9EA09FA2A09A9C9C
999B96989B989497
6B6B6B696B6E686E666A6366666366656565646261615E5B5C636A6C7980888A90989A9D
A2A9A9ABAAADACAAAFAFAEB0AEACAAAEAFADA7A4A09D978E8E7E75676256524A434C4B4D
515350585F655D5B63645F6361656360646665686867666062645F6261636A686D66666C
666A6C6F6E6C6E6E7071747171706D6D6E6E67645E5F64A8DDDDD6DBDBD2CEAE796D6767
6B696769707370757572776E6767717A8084857B7B7C6E657F847D756E737B7F82786857
302C262B363F5B5D362D2F2C2B352A2A2A2B2E30312B37434C54504E3B3F485655453828
38675324232D392B3B629187635651646F63593325212A22241F22282E50869FA281665D
637C9EB5ABA1A48E7A7B86B0BEBAAEAFB4B5C0C1BFBFC1BFB5AEAAA6A2A5A29F9CA19FA6
AAADB5B9B6B2B0A29EA0A4A7ADADADB0BBBBBBBCC0C1C7C3C0C3C3C5C9CCC8C9C7C9C8CC
CBCBCCCDCCCFCFCECECDCDC9C8BEB4AB99886D655C5B4933272430312C3150544C414572
9A99939EA3A89D784A33302E2E2F342C292B2C332D343130323331373932363A423E393F
3F3B34372E2F372D302E282F293231362E35313A37384858717F86908F89888182859092
96999B969A959497989D999D9E9EA4A1A5A8A9A5A5A6A5A7A4A7A5A1A4A3A29FA1A0A3A1
A1A0A4A2A4A3A2A8A1A1A0A0A2A09B9FA09EA09EA09CA19EA09F9D9D9C9F9F9F9E9A9A9D
979C96999A9C9496
67676A6B6668696D66706B666E63656161616064605B5D5A575A6274787E858E929A9BA1
A2A5A8AEAAACACB1ACADADADADADAAACACA9A7A5A39C978D8B83776F60554D4D444C4F4C
525556595A635F605E5D6462656768645F68696465616362616662606866625E64656B6F
6A6C676E6D6F6F74716F6F727270716C6C6B63625E5D6FB7DFDBD5DBD6D1D9C68C706568
6769707673736E7371747A757372707076807F7F7C817F78838C8377727F7E7778725D34
2D26292F3C33435847413330302B2D312D3132382F3134465C50533B3F4B4E594B3D2C2E
3A625325232A3731537288876B685E5F5D48352523262A242125242521325B839A94755A
53667696B4B6A589788D95ACBBBCB6B0B5BBBABCC0C2C1C1BDB6B3A7A9A5A5A1A1A1A6A5
AAAFACB4B7B6B2ADA7A4A1A6ABADACB1B8B7B8BBBDC0C5C3C1BEC3C7CBCBC7C9C7C8C8C6
CBC8CCCBCCCFCCC9CDCACDC8C3BAB0A393806C5E545347322C292F28253659514C3C4980
969488A1A0A39E8257352F322C2A29302C302E2F313032323237363D354139363A403F3F
3F3C3E3C2B342E2A2D2D2C2C2E2E3732302E302F2F353F516776858E8C8C87837F818B8F
9398989A959397969B9A9DA3A7A3A4A7A5A5A4A8A6A6A5A5A4A4A4A1A0A4A4A1A1A1A2A1
A1A0A5A4A4A4A4A1A4A2A2A29DA1A0A1A29C9D9D9E9F9E9F9FA0A09D9C9D9E9B9F989A9D
9A9E999A969C9695
69696F6C68686A6A676A686969676C60606563606157595B585C63687482859191949C9E
A3A6ABACAAABACAEAEABADADABB0AEAEAAADA9A29C99948F897D706D5D524D484A4C464D
50564F605B615E5C645D6263616262605D686160616561685F646560606463666762686B
6D66686C7072747473737571726C726C6A6C62605B5B7AC0DED8D8D8D0D2DBD1AA786364
616B7178786F717277787D7B7D766E6A70777E85828B868185848484777B7A788076522E
272B313B342B3C54503D39312C2B2D2F2F352F2E2B2F3E585F58423A415557604D2B272F
405750252A2C3A5C687D8D865C463F362F2E2A31292A26292322222428262F5F7E937A66
69605C7795B5AE8677A69EA7BCB6B4B4B5B6B5BABCC1BEBFBEB9B4B1A9A2A49B9CA2A4A5
A8ABACB0B5B6B3B1A6A29BA0A5ACAEB6B6B5BBB9BAC1C5C3C4C0C2C7C9C8C6C8C7C5C9C6
C7C5C9C7C8CECECCCDC8C9C7C1B8AEA088766B5A56554134292E2C292A44585451415187
9A888BA6979D9C89593931373B34362D2C2A302C2B33312F3A393A343A38363C3A3D4246
3C3A433936332D34302D2C282F362E342F2F2C2B31363A435B6B7F8A8B8E8889797F8188
9197999B9996959C9FA0A5A3A4A5A7A3A2A4A7A8A6A5A3A1A3A5A29DA19F9F9FA29DA2A4
9EA3A5A3A1A1A3A3A2A0A1A2A29EA0A0A3A1A09CA09E9F9F9F9F9C9D9EA1A09E9C9C999C
9B99999A9A979594
6B6B6C6768646D6C6E6A6C7064686665675F6564605B5F5B585D656D7D7F818D91989BA3
A3A8A7A7AAABACAFADADB0B0AFADADAFAEADABA1A29B98928A7D756B5B524F48494B494A
5957545F605C5E5D64636465606367646669636362636268616662646A63646366666968
69676C6A6F6E747476767271716E6F68686F625E585B81CBD9D7DBD5CFD8DBCAAF8A7465
626F767A7C76747878797A7D7A7D6E69647173808A87848A8C8284887675767B81765D43
35353D392E2B384E5F4A36342B2D333129312F3233394A62594A3E45475254613B2B2F36
48564127282E4776757E8162392A2A2D2F2E3031342B2F2C2E232222242629375F767C6C
755C4E5B7793A38B7AB19893B9B5B3B6B4B8B6B8BABCBBBDBBB6B5B3AAA5A5A1A0A1A0A6
A4A6ABACB3B9B4AFACA7999CA39EA5AEB5B9BABDBDC2C4C4C7C4C7C8CCCAC6CAC7C8C5BF
C3C8C7C6CCC9CBC8CCC5C4C6BEB7A89E8674685C5353432F3032302C364D534F48495D90
9186899D96999E8360472D3A352D2E3630322E34302C2F31343433363C3E3E393C3C4842
413E3F3E3634302B2F27333228302D37333131282D34383A596A7885908F88827F7C7D85
8C959B9C999FA19CA2A6A3A6A8A5A7A4A5A7A4A7A3A7A4A6A1A0A3A1A2A1A0A4A6A4A0A2
A4A4A3A0A5A3A6A0A0A29FA0A09FA0A0A19FA19E9B9F9D9D9D9E9F9E9B9D9EA1A09C9C9B
9B9C9C9B9A9B9994
6A6A646A6667686C6B696E696C6661626462635F5D5C58595C5C6972757F849092969C9F
A1A6ACABABADAEADAEAEB2AEB1ABADAEACB0AB9E9E9D97918C81776D5E514E4847414F4F
5258575D5E5C5B5D63636264646362626664626963676264616365646260635E61646468
666A6A70746D7170716F76706D6B686B6767635D58597CCFDAD9DAD1D7D8D7CCBCA57669
656A767C807D74747973767C7B7F75716767667888868A8C888181887F81847D796D5E56
434A534433313249665949412E33342A2A302B2F343346614B3B454458555B5945292D37
485036222F3B5A76857C6F4B2A2B2C302E333A312B2929292C2D282A23242427365C696E
7A6B4F4F5F6F89827DB19785B3B7B4B7B1B6B2B6BBB6BBBDBBB8B4B4AFA9A7A1A2A3A5A7
A6A6A5ABB1B6B6B0ACABA39A9DA5A7A9A7AFB9BDBDC1C4C3C6C0C5CACDCBC7C7C3C4C3C3
C4C6C5C9CECBC5C5C8C3C1C0BAAEA89E8479655F51493C372E302B324E5F554B5447708A
857F829399949887715135342C2E2D2B2F2C2E30302F312F3333353C3735453236383A3C
3C3A343B3D312D322E2B302B2A2D30353833362B2B312E3853617485898C898285827E7D
898E969D9DA0A4A2A0A4A4A5A5A7A5A3A4A1A4A4A4A5A6A4A1A1A0A0A1A0A0A4A5A5A39F
A3A7A5A3A1A2A29FA2A3A29EA1A19FA1A09FA3A09F9E9F9C9FA0A09E9C9D9DA09D9D9E99
9B9B999697969796
6E6E6E686C6A676B65656B696769625F64626064605A595C5C64686E7C7E868B8F979D9D
A0AAACABB1AFABACAFADAFAFAFAFAFB1AFAEACA4A09A988E8C84776A5E4E4A47454E4B50
505855595D6059586060615C6064625E65606266635F62636063655D5E5F5E6364676665
696D676A6C7170736E71716E726D6969656661605A597CD2D9DCD7D3DCD4D3CDC3BB8672
6E6A7479817A7C7271797C807C7E7A7568666C757A7D898A898A8786898A837E776A6658
4F67625D4E463B44575A4F4233342E2F2D2E2B31353D4A55514655444855604C3D382538
4B4F3F282C5E597B806C5E35292D2F322D31323234302C2A31332B2F21272C26353C536F
8A765649545D6C657CB19A86A7BDB7B7AFB3B7B6B6B7B9BDBFBCB9B6B6ADACA4A2A0A9A8
A9AEAEB0B3B1B8B0AEB1AB9D9DAAADA8A6A6ABB4BBC1C5C5C4C1C4C8CAC8C3C4C5C5C2C3
C7C6C6C3C8C8C6C6C5C7C7BEB8ADA79A87726259504C4638302D27356C625548574C8682
8A868D91989792877C5D3D332C33262C2A292A2E2C332E322E303E3936373B3B3A393B33
3A42383937323234452E2F282D282A30323933312D302F3A4B576D7C868C8E87827C7781
7E8C979DA29FA1A2A0A5A5A4A4A3A5A5A2A3A4A6A1A1A2A4A2A0A4A1A3A6A2A59FA3A1A3
A2A7A5A2A0A4A1A3A0A2A1A3A3A2A09F9E9EA0A1A19FA0A0A69E9F9F9D9D9E9D9A9F9C9D
9C99979696959697
6C6C6A676E69676A6A67686B6665666260666460625C5B585764646E7D7D8A8C91979C9F
A3A7AAAAAEACAAAAAEA9AAAFB1ADACB1AFAEABA79E9D9791878476695A4E4D4543494D50
4D4F5455595D5A585A5C636462626064655B62626465606766616563625F636265696268
6A6A63676E73707371726F6D6D6B6D6D6C62605B5B5680D3DCDBD2D6DACECFC6C2BBA385
777176767D777C77757278757D807A7A74717471747881848E9086888684807E7C766F5C
5B7C716A595553494A514D4C3D3E3B3230292A383A484D484E434145455551473E3B2736
4C51382636715B79785F5832282C2B2F3A2F2C2D30303631303A2F292A2C2927292C415F
6C846B585559614F72A7A1839DB6B0AEA9B1B7B1B0B3B5B7BBBCBCB7B2ABADADA5A3A6AB
ACAFACB3B3AFB2B4B3B0A9A7A0AFB3ACADAAA2A8B1BCBDC1C3C3C2C5C9C7C0C4C6C7C4C4
C8C6C4C2C6C6C7C8C4C9C8BDB5B09F90846A5C624E513F38302830576A624A4F4D67897F
8B8599949C97978276603B2E2D2E262C2826282B2C2D2F2D313A383937383635383C3739
493B413A34312D2F332D2D2A2B2A262E2E3831322E35373548496274788688887F7E7F7A
7D8B939AA09DA2A5A1A5A9A4A6A4A6A5A3A8A7A9A4A2A59FA3A2A5A1A4A4A3A1A5A1A6A0
A0A39FA2A2A1A2A49C9FA1A3A2A19EA3A19E9EA1A4A09F9EA09DA09FA29C9F9DA09D9D9F
9A979D9997999897
6A6A6A6C68696A696C68656B6A64646664666465615D5B5A5562686E747D858D9495979E
A3ABA8A9AAACACABACAAACACAFB0ADACACAEA7A6A19B988B8582766D5D504C44464B4F54
4A5054545D605E5F5C62616664666263676666636660606060616164625E636469656667
6A6A67686D6E74746F6C6F6C706B6F6868646056565A7FD3DCD6D4D9D6C7CBC4C9BFB59B
86767B817D7A7F81796B6B6E7A7B797E797779716A75847C818B8B8F81827E7F84807663
5B7876746C636355434F47403E3B36383E2E2E363D576445534544484D5241373E35333A
47553B2734666B6F66584A2827282D2F342F322F33302F2D353C332B2D2F2C2D2A2A3F5E
5967786656565E405C868D818DA19FA5A6ADB1AEB4B1B0B5B7B8BAB4B7B1A8A9ACAEA4A6
A9ADB0ACAEB1B4B0B3B5B0B0A9ABB1B0B1AEABA5A1AEBBBFBEBCC1C6C8C9C1C7C3C5C5C3
C7C7C7C8C7C5C3CACAC8C3C0BAAF9B8C79645E66563F3C3D2C253D69565C4E4341728683
848897969F99928275684A3433312A27292827282F302E33383D3E39383635363B3C423C
393F394440363430362A3323282E2C2E2F373232302D38363E475A6E7F848A847F837B76
7F858D9599A0A2A6A6A8A5A9A6A8A5A4A6A7A6A3A6A2A0A7A5A4A3A5A1A4A2A7A2A6A5A6
A3A4A1A1A3A0A2A29DA09FA0A19EA3A4A3A09E9FA0A09A9B9F9B9E9D9D9DA09C9D9A9799
9D99969A9E9A9895
696971706F6A6B67686A6C696667606668666066615C5B605A5D66717882838C95989A9E
A6A8ABA9ABB1AEB2ADACABACAEB1B0ABADABAAA8A09D948D8B81776C6152494341494952
4F5958535C5A56575D5F65606165626060615E61655F5F5C5E625F616260636265656465
69676A6B696C726B7373796A776B6F6A67635F56585D83D0D4D3D9D9CDC9C4C9CBBDABB6
9280787B7E7C7C7F72605E6774737B837C807B7576747D73707E878D89838489807D715D
4E7984857D787258403F423E48463C3839373A384058614F545044433D45322F3635343F
444F42343F5F665D585F4B3232352E2E2D3030302E31353137332E31293132262A29334F
4651696C535359384C676B75798A8D959DA4ABB5B7B2AEABB3B3B6B2B7B3AFAAA9B1AAA8
A4AAB4B1ACACAFACADB5B1B4B1ACB2AAB0B0B0ACA3A8AABABFC4C5C7C8C5C0C3C2C4C2C0
C4C5C5C5C3C7C6C6C8C8C5C0B8AB9A877466625D4A4A4838293E6E5A5D5451365F848482
8690919B9A938B7E72695438322924282C2C29282C2B302D35373B37383438353A3D3D3F
3838363B3533302E352F2E2A25293031343932333230303E42434F6278848B8983857A77
76828C929AA1A6A5A7A6A4A5A8A8A5A6A6A4A4A6A7ACA2A2A4A4A4A3A3A4A5A8A5A0A3A2
A0A4A0A3A1A3A0A1A1A0A0A4A0A3A2A0A09F9D9F9EA19F9E9F9A9D9E9E9D9B9C9B9A9D98
9C9E959999989B97
6C6C6B6A6C6C666A686B6C676565646863606062625C5C5E5C636A6D77828A8C959A9C9F
A0A7A5ABACADACAFACADABAEAFAFAFAFAEABA7A99E9C94918681776D5B554E464548494D
50514C53585C5A5860625D60635F635D615F5F645F5F5D615E6262676562626464656866
68686E6C686F6D6D746D706A6B636A6263645F5F565A86CFD9DCDFD0C8CEC6C8C5C0A4B0
8D7C7C757E7F80787767656970737B807D84847F7E72726C6B737C83888981877E79795D
5C7C8D8586746B584F484154473C3A353B47484042595B625A494A4538362F302D312D3A
41454146405F6042584E43312B2A2F362E312E2E2E2E2F313135312F302C2825242B3A56
3C414C5B4C5D5A37527A747875858C939099A7B5B5B2B2AAAEB6B8B2B6B5B2AEACA7AEA7
A8A2AEB5B3A9ABAFB1B0ADB3B2ABB0ADABAEB1B1ABABAEAFB3BEBEC4C8C3BFC2C1C2C1C1
C4C5C5C4C3C6C6C5C6C1C5C1B6AC968570625B4B41503E2B3C797A56625745407B8A8682
8B91869798948A7D766B5B3A27242A2A2D2D2D252C2C2F2B33362F3736373B393A3C3A35
373437383D3638332F2A2F26282C30323A3A363831302F3942414C616E83848985807B78
7782828E999CA7A7A6A8A3A7A8A6A4A6A7A4A5A3A5A3A1A1A5A4A6A0A4A5A4A2A5A4A1A3
9EA5A3A6A3A0A2A2A0A2A1A5A0A3A5A4A2A1A0A09BA09D9BA19BA09D9B9D9D9E9C9C9B98
9C99989697989A96
6D6D6D6E706B6D6C67686868666966696665616362615D5D5E5E6A737C828792939A9FA2
A1AAABAEAEAEAEACADA9ACB3AFADAFABADAAAAA49C9A9990897F746961524D41464B4751
565554555A5D585B5A5C635E5F5C64625F615C60605D5F6264626365625E646265626769
68666E6A6C6C6B7072706E6F6B6B6C6866605D59555B8FD5DFE0D6C9C3C6C4C2C9C19A97
8D8E7D797A7A787476726F636B75787C7F85827F7A776E6C6C726B71818A8A887C808073
78848D857C716856444040464D3F3E3C47525044495D64555D4746493D39373430332E2D
3D434955526350333F474746482D2B2F2E30303231333239302C31383A3D2A2D2B2E435F
374C4B40446C64455F7B8C8A777CA6AB9D9BAAB4B7B0B3AFAFB4B9B5BABAB5B4AFADAAAB
ABA9AAACB4B1A9ABA9AFACAFB4B0AEB0B2AFAEB2AEB1B0ADB1B2BABEC4C4C0C3C1BFC1BE
C6C3C5C2C7C8CBCAC6C3C2C1B2A0907A685E535252442F367E7F5553535A415B84908684
8B8490979DA38D7B7271593929292529292E342C292F2C2B2F313531343438373B3E3C35
373D3D3638363839342F2D272A34313035323B31303632373D3D49516479878588857C7C
7E7F828C99A2A7A9ABA7A3A6A7A8A6A6A6A4A2A5A6A6A2A3A1A2A4A1A5A4A4A3A1A2A2A0
A3A2A4A4A0A0A29FA1A19CA1A3A3A4A2A1A19E9EA09BA09E9C9D9E9F9C9C9B9D9D9E9999
999A9B9694969D98
6B6B6B6C6B706D68686966646B686A666567645D605E5E5F5D61666F7C818590949BA1A2
A3A5A9AEACACABADB3ABADADACAEB0AFAFACACA39E9B968D8C84736459504C4542454B4F
4D55545D58575A5D5E5F5E615E615F5E62615E6162646165636260606364626161636B69
6C686C696B756E6C726C6A6C6D676C60655F5A5956629EDCDDD8CBC9C0C2BFC0CDC3997E
86A2817E7C78737475767063656D717C807D82818681757078736B66707B7C8186898985
89888A7E6F6D6D5A423F3B4250544C444A585D484D606A6165484245373F344236312A2A
374251554966472A2E3739426B462A2D333537352E333042383B3F49423B3545393C5569
3A4A4D403E6F6B5456638B8E7A6C98B8AD9FA8BCBAB9B9B4B5B1B7B8BBBBB5B9B5B4AFA8
ACAFB0B0AEB3B0ADAFB0B4ADB3AEAFB4ADAFABAFB0B4B2B5B4B1B1B6BBBFC0C0C1C1C4C2
C1C4C5C2C5CBCCCBC7C5C1BAA8998C71635857584F3B3F66815A5355534740838C868684
8A818C999EA59D8F826D5236292B2C2C262A2E2B293033323332302F313939343A323837
373A373D393A3C39302C2A2A2B2F312E3232353234362B2B323E404D5A6D7F7E8684827C
7D807E8894A0A6A7A8A9AAA2A6A9A4A9A3A7A5A1A7A2A6A1A3A4A9A7A4A3A5A2A0A2A0A1
9EA0A3A3A2A3A3A3A2A1A1A39FA09FA0A0A1A09E9F9EA19E9EA09E9D9F9C9D9A9F9D9A98
9B9B999696989797
6C6C6A6C6C6D6B6D64696967656664646262686360625F5F5C67696E79868A8B9095A0A3
A8ABAAADAAACABAFACADAAABAEB0AFAFAFABAAA29D97988E8780786559594C4B4747464F
4F5452555D565E625D5C67606261616560635F6364616160605E6261646662616466666A
6A68656A6B6E6B71706F6E6A6C6966645D5B58595274B5DFD0C8C7C7C2C3BDC2C6C1996D
76A588867A717670767A726F6C6E7887817F8282868481767B7A756F6D6F767880838179
7A78756E706B65645A5C51483E474F4B47535B584E5A6463645A404339363A39362A2731
313C596E606E40272E304236565B2A2F32313134363F3D3F4F5C58625E5E625A524E607A
5A504E4C457C745560697B847C6B769DB8ADA4BDBABBBEB8BBB7B9BCBCBCBAB8B5B9B5B0
B1B2B1B4B3AFB1B1AFB3AFACB1AEAFAFB3ACA9B2B6B8B4BAB5B7B5B4B8B7BAC0C2BDBFB9
C2C1C1C6C9CACCC7C5BABCB3A0897C675B595A52424B78866B4D5C45533F698B86828484
7E858E97A6AEB7AC9E83594134312C2829292B2F2E2E342F2B292D343439383842393937
36403A39363A3935353A2E29272A2B342D2E37333D342F3136434943526C78838484817C
7E778189939CA3AAA6A7A6AAA8ABA4A7A2A1A3A2A4A4A5A4A6A5A2A5A2A4A4A5A29EA4A2
A19FA2A4A39EA1A29FA09BA09FA09DA2A29FA09D9EA09E9E9D9B9D9B9CA09E999E9B989A
9C999A9997979697
6C6C6B6B6E6B696C6A66696A6967666361626465625E5F625F696E7279818B8C9098A1A3
A7A9AEAAACADAFB0ABAEABADAFAFB2B1ABABAAA4A299938F857C716A5B534C47474A4C53
53535C5457585B5B5B606362645D5D5C5E5F605A61606466616065646469676664646467
68656A6A6C6C6B6B706E6B6F6D6367665D5657555C9BD4D7CDC6C2C0C4BDC0BFC7BD9B70
688D988E7D7470757E7E7A7C786A767F81827D8285847E7A7985827A7378827C7D7E8472
71665E7380878377706657453E445D5949415158535F5A61606851453633312E322C2A24
2E3852786C72362224282B325C622B3B353B3A3637393F3C4E575B525451584E38305C78
55474632607C785C7A987E8F816B54789BAD9BB8BBBFBEBDBEBABABDC2BFBBBABBB7B9B5
B7B1B2B3B9B2B0B2B7B5B3ADAEAAAEB0B1ADACB1B3BBB6BBB5B8B4B5BAB6B1B4BBBCBCBC
C1BBC1C6C7C6C5C0BFB8B2A894836F6059595D4B497E8A736B6B625D5C5C889586848A81
7B88939BA3B3BBC1C1B193683B323429312E2C2E2F2D2B2B29292E37343D333A3B393438
2F32383434333A3731312B302A2B2F322F2F323336373632363B3E4249617582878A8680
80777B858C9BA1A9A7A9ACA6A6A9A9A2A4A3A3A3A4A3A3A3A4A2A2A7A5A6A3A6A6A0A1A2
A3A2A4A2A29F9F9EA0A0A1A1A0A09FA0A0A0A19EA19F9C9DA39E9E9A9A9C9D9A9E99999A
999C96959B979699
6E6E6E6D6D6C6C6D69676668676867656865636760635F6360656B7179818A8E969A9EA1
A8A6A8A8AFACADADABADAFB0AEB2ADADACA9A8A79E9C938D8880756958514A4B444A4C50
4D505757585C5C5F5A5E6362625E636262625E6160636562646467656263645C6965666A
69686A6B6E6C696A686F6B6B69656161605A505973C1E2D0D2CDC1C0BFC7C4B7C1BAA677
58689194867474787980837B796F75767C7A7B8183867C7A85918C897E878C86837C7F79
796F7B8786847F807B6951474A4D56584E464C494A5353675D6966423A33322E2B2B2826
2931476A7B7C40272426253639414248403D404C3B332F464C3D3B3232373D2E2E2E4D70
584A312B4D827F697991A18D8D6C47687E8F92B8C0BAC0C2BFC1BEC1C2BEBEBBBBB8B9B6
B7B6AFB2B3B6B1B3B6B4BAB4B2ACA9ACB1ADADB3B5B6B8BBB4B5B2B5BABEB6B8B2B4B4BA
BAB9BFC3C2C1C2C4C2B9B2A28C7A665C5F5947456F877670696D666F6B7D958C7F7A837B
798F939B9FAAB8BDC5C8C7AC7C59362D2D2C312E2A2B2B2F2E2B2C313335393935373332
332F3439333B38333739302D2C2F30302B2D32383639392F2D383C3B4A5C6D7884898784
807C7B8188989DA6A4A9A7A9A5ABA6A7A6A2A2A3A1A3A2A4A5A4A4A2A1A3A3A1A5A3A3A5
A2A0A1A6A1A0A29EA09F9EA19C9D9C9FA19DA2A1A1A19E9E9E999E9C9C9A9AA09B989B9D
9B9A9A989C9B9D98
6E6E6D6A6C6A666E68646A6769666666636564645C635F6363666E737B87898D94999EA1
A7A6A7A7AFAEAEABADB2AEADACACADAAADA7ACA39E9B9390887F77695951494649484D4F
545557555B5B5C5D5A586563625F63616160635F616064646463605F5E60626567606769
646968676A6C69686968686566605D5F5B54546393D2E0D1CFC9BDC1C6C8B9B6BBB9AF91
695D87A08975757C8385848180807476747B7C7F8185817F868C837D7F7A747A746D707F
8B8588837E817F7D837A7579755E5F64635A4E4B3F4A4658625E5E553E3B2C2D27262928
2C45436772834E2A262F2A30302930574C5B3C5838272B2D3C3B322B303A352A28263E6F
70432A2535708A7D656E908E8C7C42586F7283B2C4B9BFC3C3C1BFC1C0C2C0BFB7B6B7B7
B5B3B3B1B2B2B4B4B2B5BBB3B8B1ADAAABABACAFB5B7B8B9B4BAB4B7B8BBBABAB7BAB2B5
B1B9BDBDC3BFC3BFBDB7AD9F846F5D5C503C446C7C6A5B68675A60786688917D787D7A73
798994999AA6B2B8BBC7CDCABD9C71442F2D2E27252D2B2D30292B32352F3738373C3B35
3432333D333737363B3332322F2F2C362E2C2C3431393A313A343B4549516474808D8B82
7E7C787A84949AA5A7A6A7A6A6A8A7A5A2A5A1A5A3A29FA7A6A1A3A0A3A5A5A8A4A5A3A3
A2A2A1A3A1A09D9FA0A0A29E9CA09A9EA09CA0A1A39FA0A19F9B9F9E9C9E9D9E9C969A9E
9A9B9897999A9A97
6B6B6A69686C6D706A6A69656B63686564616262615E5C6361696E7780808A90969B9DA0
A8A7ABADAEADADACACACAEA9AFB1ABABADAAA6A5A19C9694897C756656514A4A494B4F55
55594F55575B5B5D5D5E605F5E6362626363665E5F61616366626262605F5E6365626567
676C6A68686B69666C6E69666664635B59535781C2CDDEDAD1C8BBBDC4BAB1ACB7BBBAA9
956B789A7E7C7C83878485827E75726E707A7B7E8184808581827F7D7E79767E7A70738A
8E87887A77777C777C7977727264666965595C55423A4046515B5A4F3C352F2B29262723
2F4441586E84692D2A2A242A302E3357645E32672F292E383C3930323B3B363530323D6D
77422D222C4B80885A43707F7C8A526371626FA3BEC4BDC5C6C4C0C1BFC0C2BEBAB9BAB8
B8B6B6B7B1AFB1B2B6B6B8B1B9B5AFABA6A5A9ACB0B6B7B3B0B4BBB3B8BDB9BCBABABCB6
B0B3B6B2C1C2C5C2BEB2AC94785F544C454A7075634A536461596559708F827B757D6C66
7E89959799A1A9B5B4BBC3C5CAC3B783402B2C282A2B2E2B2A2F252B31313435383B3637
32323A36373A3F353831322D2D282930312F2C2F393B373E323339484744597479888883
8284828084919BA1A7A7A8A8A5A5A8A3A3A7A2A3A3A3A5A2A3A5A2A2A2A1A2A3A2A4A3A4
A3A4A1A3A1A19DA0A5A0A39C9EA3A29FA19C9D9D9F9E9CA19D9B9B9E9C9C9D9B9A99989C
9A9A969B96929696
67676D6D6E6D7068746A6F6D696A67636062636365646662646A747680808B8E949B9FA3
A5A8A7ADAAADAFAAAAAEAEAFACAEAFACADA8A4A19C979490887D756357574D4B4B464D50
535254595C5A5D605C5D5E62656564675F6163636261615E615E695C615D646363646067
6666666B696C6E696666656262625E5554566CADDDCECCD9D8CABFBFB6A8ADABB4B8BFB0
93746780828685827F7F83857C7D786B6B7576827F868789837E847D797D807B79777D7C
89888A8179666868696A76756B696F5A585453544D433C3E4256635A493B412F2F342D2C
292D405F71856B2A2222252B2A2A39516266305E2F2D2B3E3B3A38353B33352D2F273D64
744E2723234184936D25415B65877D7574616786A3B8C0C7C6C3C2C5C2C0C2C2BFB9BBBA
BAB6B2B6B5B3B1ADB6B9BAB8B8B6B6AFACA5A7A9B0B4BBB6B5B1B5B0BABABCBEBBBABFBF
B8BDB7B1BAC0C2BFBCAEA88666514B4A586E6C524C595F5C5F61585B8B8E7C7275776864
7B8C9C9898A1A4ACAEB3B6BBC3C8CEBF8E4A342A2B2B362931262C272D2D2E2F33363331
342E3A39363540363930342A2C2F372E2A2C2F2B35323632393135434543526777868988
838685837F8F979FA7A8A7A7A6A5A9A7A2A5A7A4A0A4A69FA3A4A2A0A4A2A3A3A5A2A3A2
A5A2A2A1A09EA0A3A2A1A29FA1A0A0A3A1A1A0A19F9FA0A09D9F9E9E9BA09B9A9C9B9A9B
9B99989795969997
75756B6E696F6E656D6A6B6B6E6863646162626364636665626E7376827E8A8E9499A0A7
A5AAABACAAAAA9ABACADAFB1AEABACACAFA9A5A1A09A948E898177675C4E4E4B44494C4F
5755545D5F5F6460605E5C68616160635E626160605F5A5E62636A645F62616469626267
656B646866676D6868646567625C5855575F98CDE1D6CBCCD5D0C2B6A69FA7B0A8B9BEA6
8F6B646D7B8C8984818188817F7D78756E6B717A787E84808281807B797A7976797E7F73
7C878F8A8079766D6A5C6664695B554E473F3F4356484A464141615A4E48443D3D3E352E
2A2C323C607F73362A25252D262B335460613065382B2F2F343E504B3E3F42322E2D3757
695C2A2825367C9E8A39232A466A96917A5F6E78869AB6C6C5BEC3C7C4C2C0BFBDBEBCBF
BEB9B8B2B7B9B5B2B4B7B7B9B8B9B1ACB0AEAAA8ABB5B5B4B5B1B4AEB9BBBBC1BDC0BCBF
BDBBBDBBB6BBB9B3B3A591775D4C495C685F513E4769656765634B7F92846F6F81776C67
8394989993A2A7A7A7AFB0AFB5BDCAD0C6985E3328292A292F3629282C2D2E323431312F
2F32343B373E3938453532302E2B352A2D292C293033343732322F3241424C5870818A89
858586898689939B9DA5A5A3A6ACAAA8A9A7A5A3A3A7A7A6A7A3A3A0A1A4A5A5A4A2A0A2
A3A1A3A2A1A1A19F9F9DA39D9E9B9D9D9DA09C9E9DA19D9B9C9B9E9C9E9B9A9C9B9A9997
9A9A979797959A97
6B6B6E6A696C716C6D666968686365646A6163646865665F6270737881818B90979BA0A6
A5ABADADACADABADABA9ABAAACACACAEADA9A3A2A09A938B888177665C534A41444B4958
555757595959585D5F5D5B5A6062625B5F62615E5D62615F606468605F5F606461626265
676B6967676D6B6C656B66645E5B5754597FC6D8D8DDD3C6C7D0BDA9A091AFAFABBCB0A7
A1745F6269888F7F828B847B7C7F827C746C6F7580807B7E857B7E7B7C7A78787C7B7C7E
78838D89888A898B8D887872634E3832343D433C4E53545340464D5757625748423E423E
2B24282D54726B41292928282C2A2F52586D355E452A29262F2D373B3C575C5045323E49
64683B31272E64A4916C22202A4892AE92717B79778399B2BEC1C4C6C7C3C2C0BFC1BDBC
BDBBBAB6B7B5BAB6B6B4B4B5B5B6B4AEB0B3AFABACB0B6B2BAAEB1B0B6BCBEC0C1BEC1C0
C1C1BFBEBABDB7B1A698715A5248505C563E4553676F74665F50748E8E7B6D7D817D6374
8E9B98989AA4A7A3A8ABAEAAADB6BDC5CECCAC6634262A2D272520242A302D2C2E333234
343538403C3634454336354135312F35312C3030333731373A343231324145576C7C888E
8A8B898C8484919AA0A5A7A5A5A7A3A5A3A3A9A6A6A8A4A6A2A5A2A2A4A2A2A3A5A7A3A2
A1A2A1A5A09EA49EA09F9D9EA09C9E9EA09F9A9B9D9FA19E9D9A9C9B9B9D9E9B99999998
969A949A989A999B
6A6A6B6A6A6869686D686866646364626A646463636C666A696C717A80828A94969AA2A4
A8AAABAAADACACAAAEAFA9ABACAEADACAEACA9A49D9B91918C80756B59554E474347474F
5153585D5A5A5D5B5E61635F5E5C636162665F6160646262655E616163626562635F6263
646466666D67656B666660635B5559545FA6DCDDCDD5DBCEBCC4BEAB9B9DAEB4B6B49BAE
9A6C5958677F8C80848684797A82897D7469636B7E847A83827A7B817A787A7873797A7F
737883898185898D93898B886F563D374A5D5D474544505B575445444D626851473E453F
3E2D2A33395D78622D2B2624262728484E6E3C62592D2E2B2D2C2B2B344060534A435455
605E523E27264D82907D2A1E1F2E70A59F9F907F74747F91ACBFC1C4C7C6C4BFBCBFBFBC
BBB8B8B5B7AFB5B5B4B7B1B4B7B5B5B5B0AEAEADAEB1AFB4B7B1ABAFB6BBBCBDBDC0C2C1
C1BFBEBEBEC4C2B6B69F71564D4746393237486A6C726C5246638B92826A748A7A6F6A7C
919A909998A9A9A9ABA9AFADB1B7B5B9C1C9C9B87E3B322A2A352325272A2A2C2E303436
3836343434363B3B3B3D343833303435312D2C2E32333330372F313339393C556478858F
8E8E8F948E8691969CA1A3A9A5A7A8A6A39FA7A8A2A3A4A3A4A3A8A3A1A6A1A5A3A1A4A5
A5A2A2A19AA2A09E99A2A09E9D9D9C9F9D9E9D9F9E9E9E9E9C9C9F9D9C9E9D9C9A9A9B97
9B9A999495999997
67676968676B696B68696868686464656763656564636C62656D70747F808D90949BA0A0
A7AAA9ABAEAEA9AAABAAABA8AAABABAEADAAABA39F9D908E8C8174645D5148414B424F51
53545D565B585E5B5E5E605F615F5D5D5C5F5D5F65696963605E62605F5C645E61615E67
6A696A6B6C6B67636764615E5F57595777BAE0DACCC3CFD9CCB9B6AAA4A7ABBBBCA19EAC
8069625961747D86827D78777D8B8785797666607B7C827E7F7A888274787A71707B7D7A
767D7B848B88908B8B8987836F69685F726F5B4F4E48524E4A494743404A555E53504D3F
3E3F3730323D5C634A2C272426272B3C3D654861733D2E363B36393C364D81624A42536F
775E53452C26324C7D85511F212947909FB1AE897A6E777A8FABBCC6C7C5C3C3BEC2C0BF
BEB6B4B5B3B0B5B5B4B9B5AFB3B9B3B5B3B1ADB1ADB4B1AFAEB0B0B6B5BEC2BBBAC0C3C3
C0BBC2BCBFC3C6C1C1BAA9805837302E2E395F6C72674C3C6085938870697B85746F808A
949A939899A9A6ADAAAAAEACAEB3B5B2BBC2C8CDBF9961392D2526282A292A2F2E313034
3533333235353834333A343E362C2F2C2E2D2B342A3635343233322E2E37334861708389
9291918F8C8990929BA0A1A8A3A8A7A7A6A5AAA6A6A4A4A4A4A8A6A7A4A7A5A3A2A3A0A3
A2A1A0A1A09EA09D9C9F9CA1A09F9D9D9B9F9EA19E9E9A9E9A9D9D9B9A9B9A9E9A9C979B
999F96999B9B9699
6C6C6A6D6A696B6866666868656464686169616A676365676B6D737A80878C929497A0A3
A4A6ABACABABA9B1ACAFACADABADA8ABABA9A89F9F9A9790888577695A574D474A4A4A51
59595A5F5F5C5F605E625E66625C6163606161616465685F5F5E5F5D5F64606266656163
6669646A6C6B676661655D5B58515568A6D5D3DAD3C8BEC8D5C6B3ACA1A2AFBAAC9EA8A2
83837F6762666F857E7A797D858A8C8880817C6B6D7B82807D7C857D7E83797677797B81
7D7873788A8D8C888A8C89817F827B6B6B575550646F6C503B3A424042454B5649444F3E
39393C3B33393D5150372E282A272734365F654F6D462B303B374539343E6578644A3F5E
787E7465432A2B2C56837622201C317A9E90B1B28B7B7775798EA4BDC8C4BFC2C1C6C4C0
BBB8B6B2B5B4B2B5B4B7BBB3B3B7B4B9B7B6AFB2B2B4B6B2A8ABB1B7B7BDBDBFBFBABBC0
BDBBBBC0C3C0C4C3C3BEC0BB97452D232A475F726F5B3D4778958F79696A777E656A808B
9A9D9EA19CA8ABA9ACADA9A9AFB1AFB1BCBBC2C3C7CDBC823B26252B39282C2F332F3134
30363535343B3536353031373333352D2B2B2E382C3433373A30323A343C363E586A8687
929294928D8E9091989DA0A8A5A6A6A4A5A7A6A6A3A5A4A8AAA7A5A5A4A3A1A2A1A1A5A1
A2A0A4A1A2A09EA0A09E9C9F9C9C9B9A9C9C9B9DA19BA19D9D9D9D9D9A9D9A9C999A9A95
999D999799999995
6A6A696B6E676A67686C6B6569646268646966696265676A6970797F83888C93979A9CA3
A2A8A7ADAEACADABACADABACACABAEAAACACA3A19E99938D857C72695A5B4B4648514B53
5954595E5C5C5E6059625E5D655E65615F665E605F66615F655E5F635C61656663606564
676466656563636A635D595C524E558AC9E0C9CAD3D3C5B6C8D1C3B09CA5B3B39FB0AE90
889B9C6E5F6675817F7D82888C86898885878378667178767A7B7E808180817878757E83
7E7C77737B8B8E8F888E8F84786E64514B5878798680765A55403A3D404F5756534D4141
3D4137373A2E303E4F4E2F262324282E3748666C745D3B3B3D372C32343138637B714E4D
5C7A77705C332226296077491A1B215D98728DADAB96897A797C8EAABCC1B4C0C5C6C7BF
BCB2B6B1ABB0B4B7BCB4B9B2BBBBB1B5B7B2B4B3B1B4B5B2B0ABB5B1BBBDBBBCBFC0BABF
BCBBBBC0C3C3C3C3C2C2C1C0BEA25A30323E58675C3F4157868E80746674797764778B8D
96A5A2A69FA4A8AAA9A8AAAAAAA9AFADB6B6BAC0C4CFD0C27D2D272828252A2A2D302C30
3032303739303239373234353633312D2C2E2E30323131383330342C342F35354A657788
9195928F8F8F908F9299A1A4A8A1A4A7A6A9A5A5A4A1A2AAA8A5A4A2A2A4A4A1A2A7A4A0
A5A4A09EA09F9D9FA29F9FA2A29E9B9D9A9C9D9C9F9E9D9B999A9A9C9C9A9C979D99999A
9C9D969B9A999698
6B6B6B6F6A6968686A686C65696C5F666561616765656A6D6B74727F82868E93949B9FA3
A7A7ABB0ABAFADA8A7ACABABABAFADAAAAACAAA59D98938E887E726D5B5A5445464D4C52
5958585B5F575B605D61645C5B5F5E64656462656568646266626562636763686461635F
68666561646564645E5C5E54535259ACDDDED0BCC6D0D3BEB3CDCFC5AAA6AAA0A4B59D86
97AB94685D676C7A7E8583888E888885858A8B816A606372787D797D7A858778797A7A81
807C787775808C8D857D7570625A4E5375808B8C8B816F5A56583F344753424052625544
39364141312D2E2E3D4546312B232C343A2F47767D7A4D334C493232302E384A6E8F7468
5B5E68667F58272224306252201B1F478E4D5F8C9EB49E918076808FAABBB3BAC4C7C8C1
BDB4B7B7B2AEB2B7B7B2BCBABAB8B6B5B5B1B6B2B7B2B0B3B4B8B4B5BAB5B8BCBABDC2C2
C0C3C2BEBEC3C3C2C3C7C4C1C1C1B37A413750613E3341628D7E76646571796962829590
95A5A7A8A3A5A6A6A8A4AAA6A5AAA6A7ABAFB7BAC0C7CDD1BB712E2925272827252C2F32
34362F35353238393D37383C373930292D2A2E2D292E343B38393E36322D393438587084
94999392938E938E91959E9DA5A5A3A9A4A6A5A4A3A2A4A8A7A5A7A39FA5A3A3A1A0A4A4
A39F9E9E9D9D9E9D9E9E9DA0A19F9F9C9D9B9E9C9C9B9C9C9C9C9D9D9B9A9C9A9C9A9997
9A9797999A999796
6F6F6A6C6969686669656B6B6A6662636569656D68646A6A6C6D737B7D868D9297989EA6
A4A4ACABABACACABA8AFAAABA9ADABACADA8A6A39D97918A887D6F6659524E44464E4C57
5858565B5E5E6163615B615F606262656164636362676563676461655D6260626064655E
616364686368636861595652515061BBDBD1D1CBBABCCDD1BEB8C6C9BFA49D9DAFA68793
A7A78474645F69717A7B7D82888A86868A91877B7667636376757E807E827D7F7E838482
7E7E79726F74817A7E7461585A6B79808A898F988D8A735956725F443F413A3E39536866
4F343337332A292D363A44362C252634393034637490643F5056432E2C2C323A466C8683
675B4A4D5A6940252624304A2C202D3589483063819DB2AD937974858A9FB8BEC2C6C7C5
BEB5B7B5B9B4B0B1B5B9B6B9B8B8B7B8B5B3B3AFB4B5B4B5B1B4BAB7B8B7B7BDBCBDBFC0
C2C0BEBCBFC3C3C5C1C5C5C6C7C7C6C0A05C5C442E2F3A697A75706060786B60688A8A8B
99A4A5A8A0A6A7A5A7A8A7A8A5A6AAA5ABAEB1ABBCC2C8CFD2BC76382E282B2C252A292C
2D3431333731383D372E32373C37312D302E2C313531323336343132282F3E313250687F
8D9797949191948D8F959D9FA4A6A5A3A5A6A2A5A5A3A4A6A6A6A5A2A2A3A0A4A4A39EA5
A1A1A39AA19C9C9E9B9EA29E9F9C9CA09F9C9C9CA09A9B9B9A9D9C9E9A9C989C9B979898
9B9A9B9698999994
6D6D6C67647068656B6661686766675F636560666465686A70706F7A80849193989C99A4
A6AAA8ADADACADACA7AEACAEABAAAAABADABA6A39F99948C878172695A574F48494C4A54
5256585C5E605B605F5F6062615D64646A5E63676264666468645E6564625E645D5E6061
6066656663686263615951504F556CCBDFC8C9D2C8B7B8CECDBBBBBEBFA396A6A7887991
A897777E786B66717570717C888A85888A8B7F82817367617375847C827E7A8484828382
7F7A757A7877686D8488808282878387878D90939186795F6B8B7956433B3B3D383D4B68
6F5239393031312E332C373F2E2A2C3030302F3C647F7F5460645D343433373636416995
7959483D4E615F472F25212A312C243281542C495A7D9CB6B28C807D7A80A2B7C0C5C5C5
C4BCB7B7BCB9B3B1B3B4B6B9B9BEB8B6B8BAB8B3B2B4BBB9B9B2B7B8BCBEB8BBBCBDBFBC
BDBFC0BDC1C2C0C3C1C2C5C7C9C6C9C9C8BA9A603733425B68645958636D655D71878393
989FA5A6A2A4A2A3A6A7A6A6A4A6A6A5A6AEAAA6B1B6BBC5CFD3C07334242629252D2F2F
312D3638353D36383234332C3136302C30372A323531352F353A362E292B2E3231456477
889396939191948F8B92979FA3A6A9A5A1A3A4A6A6A3A8A9A8A4A2A3A2A2A0A2A3A4A0A2
A2A2A19E9E9DA39C9FA0A09D9D9B9E9CA29B9B989D9C9E9E999B9C9D9C989D9A9A9C9D9A
9C9A979898989A96
6E6E6A65636966656C6A69686965655E64666562666B66696F72777F7F8D8C8F969B9BA2
A7A4A9A9ABA9A8AEAAABADACA9AAABACACA8A6A89D9C9493847B6D655C544E464A494B4F
54555255585E5D6163646162606169606067656163626161616165636461606160616164
62646464656764625D5B54544E5082D1DDCFBDC6CECCB6B9CECBB49EB1A5999F877B8591
A3847986907A696F6B72747B868B898B8686898585817F71646B7B7C8277818883828784
76757E867D717882918F8B8D86828688878A8F9396837453758C85705A54473D38353947
666E70513833302F2E2B323A3C362A3133362B2E5D787F6B7A6B564D2E3031382E2A416F
886A513D4B56585D50312321303026276D6B416B3348799FB1B299887875819CB4C0C8C7
C3C0C0BABABAB5B8B4B2B5B7B6B9B9B8B5B7B6BBB8B4BBBBBCB8B5B6B9B8BDBEBABAC0BF
C0BDC1BDC1BDBEC3C3C1C4C5C5C7C7C8CAC6C1B08E5443695F514E5C706C6C6B7A8A8D8F
929AA19EA0A19FA6A7A8A3A7A7A9A4A5AEAEA7A7AAADB5B7C3CED4B5612F2627292D262D
2F3332333B37384236363C343132302B32343032372E3333373C312E2E282C3436355A6D
7C8C9794969396928B8D8F99A5A3A4A5A5A3A5A6A7A7A4A3A8A5A8A4A39FA0A2A0A2A29E
A29F9EA19DA19EA49C9DA29C9F9D9D9E9B989C989E9C9A98989B999D9C9D9D9D9C9C9797
999C969698999694
6E6E69656A6C6A696468676A6B6A695E656268606269676A7072787D81899593979B9DA2
A6A6A9ACAAA9A9AFABABADA8AFACACABA9A9A7A39D9A948F887E746859564E474C4A4D50
5356545A5A615B5E5C5F5D615D64675D5F635A6762666161616566616464606667666663
696766626762635D5C5A564F4B63A8D8D3D4C9BCC1CACABABBCBC1A094AAA3847181999A
997A858F99746B6A636A76748088908C82868D87868B837F766F707E7F797E857F7F817D
7B8184877C777B7B7F8C8B878483888D888A888F8D846F4B7B8E867D64625D5044373935
3A4A7073624D3331313037343538302E373C322E4D75767C7379655E512E30392A262D40
718E5C3F46595F665F4D2C2B2327242B607B5E682C27437292AEB29A867A808AA0AFC0CB
C4C0C0C1BCB6B3B8B6B4B6B6BCBBBBBCB9BBB7BEBABCB8BBBBBBB8B6B2BABABBBBBCBFC0
C0C1BCBEC0C1BFBFC2C2C1C3C2C3C3C7C9C7C6C2C0B68D6952484E666E6D6875838D908B
878E8F838B9292999FA2A3A9A5A7A8A6ACAFA8A4A4A8ADB5B5C0CACDAF562B2B282D3128
29342E3233354239353837313637322E2D362F31292A2A2B34403A353532303733314266
7C859293959192958C8B8E999FA2A4A6A69FA4A5A59FA5A3A8A5A5A7A2A59FA5A3A4A3A0
A1A2A39E9E9D9E9A9D9DA69B9E9F999E9C999C9A9A9F9B979C9A9C9A9B9C9D9C9D9E999D
9A9A95969A989798
6A6A6B686B6C6A67696768656A6469626962666466676B696F72777D81908F9296999D9E
A5A6A7ABAAABA9ABA9A7ACA7A9A9AAAAADA6A4A29B9A978D877E706B5A564E4D4C4B4F56
5353565C555E5A60615D5C6161646065685F58645E6465606A615E5F686362626C656363
636464616462615E5A59514D4D70C8DFCBCDD1CDBAB9CCD0B0B7C3B1978C8C717688989C
888499A68E746D615A6E7678777D8A87848B88858786868875616F777A80808378827E80
7F848380867D787375848A8B878D8A89898B848888836C57868588897D6F635952523C35
34384A606F715C424142353735392C2E393B332939647D8D74728375654C2A2B2A2C322D
42788355393E51697A5E3B2A262C2323497D40552F1D233A688EB0BDA0887C7B8695ACC5
C5BDBEC2BFBDB7B4B3B4B5B5BCBCBCBCB9BFBDB9BBBEBCBFB9BEB8BBBCBCB8B9BBBFBEBE
C0C1BBBDBDBFC0C2C3C2C3C5C1C3C8C9C8C8C6C6C6C9BDAA84594B626C6E6278818C8F84
81806F6E717B797D8A939BA2A0A6A9A7A5A2A5A2A3A8ABB1B4B6C2CECFA8522D2D282B2D
2D2C302E2D2E372F3835323137383B303134302B27292D3034393C434B38373136333958
70838E96969493958A8F8C989FA2A7A5A7A2A4A7A4A2A4A6A5A4A4A4A5A3A3A2A0A3A4A3
9FA2A09E9EA39FA09B9B9CA09FA09A9B9E9A9A9D9D9FA09B9A9C9E999B9C9C9E9A9C9B9E
999D979D99959895
6767696A676F6769686C645F646465666765626765656C696C6E797F84898C9499989FA2
A7A6ACAAAFAEABACACAAACA9ABAAADAAA9A9A8A4A29C968F847C71645E565447454E494F
5A525B5C5C605F5E635A5F64605F626360656063646665616761666361605D6662656364
6262606363645F5958564D4D5384D5DFD1C3C6D2CBB6B7D1C4A7AEA5A4917C7982838D9B
829DA4A1827B7F715E6D7671736C7C868889848A7F808A8B7D7D796F757F7F827C7D837B
82888488837D79757479889292908986888C82838682674E7B888C8987867668575E544D
3B31414A55626A685C453E373B3331333536342C3A4A6080855E6A8166604B312D29322F
2F5A717642384E5A6C64593D363B23292E7E472B281F1E23335B8CB2B99C8B7D78798CAE
C0BDB9C1C0C2B7B4B1B0B7B2B2BBBEBBBEC0BCBDBCBDBEC0BDBFB5B9BEBDBEBABCBCBDBE
BEBEBEC4C2C0C0C5C1C1C2C3C3C4C6C6C5C5C5C5C9CCC8C3BC9F6E6967625E73858D847F
7D6E635E606761656D76868E8F939FA6A3A3A2A5AAAAACB1B2B1BBC5CACDAE5432302827
2A322E322C382E343A3E3B35333A3D2E2A2F292E2F2C2C2D353D43483C343C3A323C3C52
68828A9595979394968D929499A0A3A6A7A7A3A1A4A1A4A3A5A0A3A2A4A29F9FA3A3A2A1
A19FA09F9F9F9F9F9D9EA09F9F9D9B9D9C9A9C9A9C9F9B9B979A999D9C9B999A9C9A9B9D
9A9A949A969B9697
6B6B696B6B7066656768635F6662655F64646567636B696C6C6E7C7F8085919096989CA4
A7A8ACA9B1ACABAFABAAAAACADB0ACA9ACAAA4A39D99948C847A6E6458594A4548474C55
515666595C5D6161625E5F64625E63625D606460666A66656463625E6066646A65615E5F
616565626662605F5D534B4F5EB1D4D5D6CBC0BECFCDBAC1CCBA96929D92898488829391
89A1928B858F8477625E6671756F77839185828782888E8388838674717B7F7F807E7E7D
8082858E837E787D7C75868F928F8A838A8683867F7E6A48828F858789847E8078636150
4C563F3A3C4947646152535A4534362F2E33392F333F4A6A8B745B737A5D654C352E333C
344859676C504B4F505E6B4F4136222F2F746A2423231F1F21295D89A8BFAD9B88717387
A2B7B7BFC0C3BDBAB7B3B3B2B4B3BABBBFBFBEBFBEBDBFBFBEBEB9BBB9BABDC0BFBBBDC1
BFBFBEBCC0C2BFBFBFC1C1C0C1C4C3C3C3C6C6C8C8C7C9C8C8C0BAA0795B55778987827F
766863626360565D595F6872757C8895999F9DA3A8ABA7ACB2B6B6BAC3C8CEAB60332829
2B2F2D342D2F2D2F36323436343B3032312A2B312A2B2B2B2E333133332E3B484F2F3344
547484949896979890918F8E9A9CA3A2A5A4A3A5A7A19FA0A0A5A2A29FA0A0A29FA09F9E
A0A09FA0A09EA09E9FA39F9FA0A09E9E9B9B999E9B9F9C999D9B9A9A9A9B9A9C9D9B989B
9C97989897959499
6C6C6A666668666666676264615E6063635F6269676E6F6C6870777E8487939297989E9F
A4A9AAACABABACADABABAFACADABACAEACA6A8A2A09B918D867F715E5E5353524A49534F
56565E5A5E5E5A6061665C605F6061625D6263606264616666645C606260626A64696065
635F645E63615C5F6550525170CCDAC4C6D2CDBFC4CFCEC2C2BAA5908A838587948B8D87
999A7A869391817A685D5F7170736E7B848785828C8C878686828B7E70717E817F83777D
81888888828783837F7B79828D918E8588878F8B857F6D577B83827F7E858B8986857364
65605E483D3E3C4B5D4F4D4E4F423D3B373B3D3A343A45576A81635E8073525A583E3835
3F5B60515C815E5B4B4B5E63614F31262D797B282522211D2025405982AAC1B19A7D7473
7D9AB6BCC1C6C4BDBBB4B0B4B5B6B4BDC1C0C1C0BFBFBDBEBFC0C1BCB5B6BCBCBFBFBCBF
C0BEC0BABAC2C5C2C1BEC4C4C4C4C5C5C5C5C7C4C9C6C7C4C6C8C8C4B98B687E8582817E
6461615E6660565858575B5E61666E7C88909499A0A6A3A8AEB2B6BCBEC1C8D0BA632E2A
30323130312E353131333534343033332F2E2D29292A2E323A3D3F3E41404D342D2F3134
4A697A8A9095979592948A8B969DA59EA5A6A4A6A1A7A5A2A2A2A3A29DA6A4A39DA29F9F
A29E9CA09D9FA29D9C9B9C9E9E9E9E9C9C9A9BA09C9D9D9E9F9C9D9D999A999A9E9C989B
999D99979D9B9697
69696A6B6A676B6769676564626364626263626D696A6D6D6F74768086858E9395989DA5
A7A9AAAAAEAAACA9ABADAFB0A9ADABACAEAAA3A59D9C958D877F6E615B55504A4C504B4D
5453565D5E605C5F5C5A636365646263626064626363626D6360615E626664646364625D
5E5E605B6263605D5452535278D4DFC9BACAD4CFBEC3D5D3B9ACA69D8379847B98958E91
9D89788A977F7D7E726A6566686D7873808583858F82848F8B8E8A82766D727C7F817B7D
818B838283868482847C7A79848F8F888A8C8C8984837762637C7D84838B8F807E7F7D66
606E74635F504D4E4C46474F4E46403236394040423A4044576D6C5B7A936D5364614F37
4C6C665B43768976663346494F553A2D337078392521242122242C475776A8C2B99E8271
6E779BB4BFC3C6C3C1BBBEBAB9BCB6BABDC2C2C1C0C1BDBEBBBFC2C2BCB6B9BBBEC4C1C3
BBBDC2BFBABFC2C2C2C2C2C1C3C7C2C2C4C2C8C4C5C6C9C4C4C6C9CBCAC5BAA48D7D796F
5A5E5D5C5E5D5C5A5A5C58585C5B5B677578838A989D9D9DA4B0B4BEC1C3C3CFD3B4552C
242929322F2A2C2C2C2E36362F3537382E2B3031302B2F313233313B42393A3B3735343C
435E73849196909895928E8F919C9CA4A4A8A5A7A5A4A3A0A2A6A6A29DA2A39EA19EA0A1
A59E9DA29E9B9B9D9D9DA09C9F9D9F9C9B9B9D9E9E9F9A9F9C9D9A9A9B9D9B9C9D9A9C9B
9998979A999A9597
6767656961676A68676762676260605D6066656C686A6B6D7472748386888E91959D9DA5
A8AAA9ACAEAFABACABAFB1AFACADAAADA5A8A8A2A09C918A857D6B615E4F4A4B4B4D5351
4C54595F5C645C615D616366676760626562605E6863666861645F605F6663646262635F
64605E5D5C5C5E57534F4F569AD4DBD4C8C1CED5CBB8C8DBC4A3A5999580796B768EA1A3
988686A089717C7F7B71716B5D6F7B707D7F878A8B7F888D8987878B8877717B7E807B81
7F858087858386817C7F7C7A7B868E8C8D908A8A8E8575736E616F838387868485847A6C
63748177756E61686252443A3A4138323D39383C3739393A4A5D6D665C7C91684F696D58
4C667A67455B76817C3E37384F443C404A677E36261F221F242A242B303D779FBAB6A38A
746B7F9CB9C5C6C4C4BDBBB8B6B9BAC0BFC3C3C3C4BFC1C1BFC3BFBEBEBEBFBABEBEC0C6
C0BEC0BBC0BEBFBFC0C2C2C2BFC3C2C4C5C3C7C7C5C3CACAC6C7C9CBCFCBCCCBC1A07F61
5D5D5C5F5E625D5C5A5C5A56525D5A5C636B737B83899096A0ABB1B7C2C7C8C7CDD19F35
262A2B2A2A2E332B2D2E303431362F342C2D2F303131272C2E2D3332383C3737302E2D33
38516B808E97969494968F8D90999BA0A3A4A6A3A3A5A3A29FA4A4A19C9EA19E9FA2A19E
A19C9CA19CA0A29E9E9D9E9F9C9C9F9D9A9B9C9A9B9B9E989D979A9A9A99989B9B99989B
99979A9B9998979C
626264646D66656768676866655C645D6064646F656D6A6E6D73798086898B97989D9FA2
A7ABAEAEAEAAABACADA7A9AEAEABAEABAAA9A6A69F9A9489837B70665B504E49464F5152
53555C645B5F5E605E5E615E62605E6660675F60646661676A6062646A685E6765685E66
625F5F6360595D5951534F60B8D7CCD5D7CCC1C8D2CDBAC7C3AE979A998678696980A39B
878796987C6F7C82816F6D665C646F76747681868489928B8C898B8882897C71747C7E80
808082858487888584887F827C7A81858A868D898E8A84867A636D7E8683878588857C72
69697E89877C76787865524F3B473A3C393E39373A393C42454A5F69635C7D8D62597570
68677F916C475B6F876F382F373E2E2B3864773A302A2D25372C1E2020253B6891AFC0B1
9373738299BAC4C4BBB8C0BEBFC0BFC2C2C2C6C5C4C1BDBFC1C1BFBEBBBAC2C1BFBEBCC3
C3C4C4C2C1C1C3BFBFC0C1C3C2C3C6C4C4C6C6CBC9C9CCCBCBCAC8CAD0CED2CECDC9AD74
675D575A5B635A595E5B5A5757565965606563726A6C78828F99A8AFB5BFC6CCC6CBC681
37292C2A27282B2A2F322F3436343032322D2C2B30362A2A38383337393D3739312D2B30
33435B72848D959995928E8B8C93979B9BA1A3A4A3A1A39FA2A3A2A19E9C9FA2A49C9FA3
A19EA39F9DA09DA09D9CA09F9A9D9F9B9D9E9B9C9B999A9A9B9B9C9B979A99979A9B989B
9A979A9F9B99999C
6565666767656363686167646760625D61646B6A6F6D6F6C7474798086888C95989DA1A2
A9ABABADABABA9ABACADADADAFACADACADA8A8A6A198948B857B6D605A514F49454B534D
55575D5D5F606165605F5F62656468616268605F636666656B6161616665626667626061
5F6561615C5B5B56514F526ACADFC9CAD0D5CBBBC4D0CAB7BDBAAE9789807B716A759D91
858C947E727878887A7476746A60697476727E84878D8E8A848C8A88808B86726D7C787D
7D7C8689848A87848889888276747D85868E8E90888C878B8B866B6780838988867F8171
6B5F727E837A767D807A6F66655349414E433D36393641414546526270675A787F596260
5E5E64697F6F3F41545C66523938342F4F5D64302F30362F26281B201F1F26305F84B3C4
B49584868199B1BEBBB5C5C2C3C9C4C3C2C3C6C5C5C1C3C3BFBFC4C2C1BFBEC3C3C4C3C0
C0C3C3C4C0BEBFBFC0BFBFBFC5C3C4C6C2C4C2C7C6CACCCCCDCCC9CCD0CDD2D3CFD1CDBB
8E655C585C5E52595A5855575355575B5C605B5C60696970728597A2A7B1B9C2C8C5CBC2
803C31302D29282630262D332F31333231332E2B302A2E2D382F33343D353A32342C2B29
29325572868A93989592908F8F8E989B9D9EA2A3A8A4A1A3A3A2A29F9DA4A3A39F9EA49E
9C9FA19D9F9A9D9E9C9A9B9E9D9D9F9B9E9C9E9D9F9E9B9798979A9C9B9D999D9C979A98
9B979C9A999A979A
636363646666696E6D6765636262615E62676D6A6969686F6B737A7B81888D94969AA2A5
A8AEACADABABADADB0ACABAFAEAAADADADADA5A09C9C928A897D715D5D4F534C494D5553
54525E5B5C61655E61616063636261655F645F6568646164635F6164646564646A636161
64625F5B635E5B5451524E6BC4DDD3C8C7CED5CABCC5D0CBB4AEB1A781767D706C677B86
878C81737478707C716D7B787770676B71787678898F8A88878A8885848B888A876E6B79
7A7E817F8687878C8987807F7C7E7D80898D8F8B878A898A8F8B72646E8083828388827C
7D6B66727F887C676B6C6C6E8087765B645643454D5B4E505044536F727060626B654950
463B4D56556C78553D404A5F5E504C44494A603237482C2926252424202121242E5596B1
C1B49F8D918A98A2B8C0C6C9C2CBCBC8C5C4C3C6C5C1C2C2C1C2C1BFC2C1BFC0C2C6C8C5
C2C0BFC3C3C2C2BFC4C5C1C0C0C5C7C7C3C4C3C4C7C6C8C8CDCBC9C8CAD1D3CECFD3CFD1
CBAC7F6A615A55595754595856585761615D575C5D5F61616374818E99A1AFB4C7C5C8CF
C497633F31252827292629313033382E3432303432382B3335343339323C3B352E292926
2A2F4063778A989898929392919098939EA0A2A4A5A1A0A4A6A1A39F9FA1A0A4A39EA19F
A2A1A19F9C9E9D9EA09C9D9B9A9D9A9E9C9F9C9D9B9C9B9B9B9B9C9C9B9A9D9C98999D99
9B99999597999B9A
5F5F6664646569686C6663636063606265696465686C6F6E6E74767C81898B93989DA1A3
ACABA7ABB0AEACABADA9ADB1AAADAEAFABA9A6A39F9C948E867E7664555047484A4C5151
5458575E5D5C5C635B5F6163635F5F615C6262616367656A606366636162655F69686865
636461605B625A57514E5987CDD3D5D1C2BDCBD7CBB9C8CEBE9EA7A189757671787B747B
8A7F7276787372776C717278827F6A60717973727B888A8B8A878389888588868A766E71
7A8282848485858B84837F8283877D7E838E908B928E8C8E8C8A82746174787C868D8C85
7E77656877858A7F6961696B7F8E8E777874554053534A65604F4B5F747D705C50534855
5530304642486D866D42303C4A4F4E513C4656403930292A3026202326282523254A8388
9EB5BBA8A08A8B9BA0B9CBCBCACFCECDC9C7C6C5C5C4C2BEC1C2C2BFC1BEC2C1C2C4C0C5
C4C4C4BFC3C2C1C1BFC5C6C4C3C3C6C7C5C5C5C8C6C6C6C4C8CAC1C5C2CFD1D0CDCDCFD1
D1D1C6B397765F5A59565A55535958595B65575B5D5F5E5D6468707C858E9FACBEBCC3CB
CACAC79F582D252A2B28262B3332373338332D2F2F33363C362F2B34333D3839312F2B25
262D39546A868E96949391908E918F93999FA3A3A5A2A1A09FA1A29E9DA1A2A2A49FA19E
A3A09C9D98A19D9D9F9D9C9D9A9B9C9C9D9A9B9B9B9E989A9E9C9A9C979A9C9C9C989A9C
949691959799989B
63636367636966686267636463676A5C606A64636B6E6C716E72777D83929092989CA2A6
A5ABABAAACB0AEADAEABAEADACAAACB2ACA9A7A09C98978A837A736559514B47434A5052
5453585B5B61665B5D6267656665615F615E666660646361626066616766666065646367
6C63605F615E575955515DA1DFCDC9D3CEC1B9CDD5CCB6BBC5AD9A959986826D848F8C81
87797775746F71706E6E70788480705C676E6E73767F878D87878F8688848A818888876B
758185868186848B7E8184878C868282797F8C8C908F8F898D8F9089705A6C7D8C918F8F
817C72696A74808884757067758490807B7B6C4F4A4756646A5D585E748A8C755B524B52
674838443836416C788460443B3E3F3A445A56482C2C302824252325294748282533635E
6D91B7BEB298868D95A4BAC7C7CBCACBCBC9C7C4C5C4C1BEC1C4BFBCC1C1C0C0C2C2C0C3
C2C6C5BFBFBCC2C2C1C1C3C4C1C4C6C5C7C8C6C6C9C9C7C5C8CAC3BEC4CBD3CDCCCCCDCE
D1D1D0CDC9B994836E61595B5657565B5E5D59585E54585B5663666F71778D9FB4B5BAC2
C6CDD5D5B4592D26312E30252A2B322F36362D3934352E2D302B292E313B36352E2B2B37
262D384C5E7C8B929395929392909094959DA29FA8A39FA0A0A0A2A59DA29D9F9E9FA39F
A19EA09E9C9E9D9EA09F9DA0A09C9B9999979A98999A999C9B9C9A999B9B9C9B9D9A9C97
99989C9B9A9B9A9B
63635F62626C68676565626163636062676365686B6D6D726D74747D848F92949A9B9FA1
A6ABACAEACACADABADADAAADAEAFACADA9ABA5A69D96978E867A73665453514F424B4C52
5450555F615E5D605F5F645F6562606C6760635D6168666A626061636464616265656266
645F6462605F5856524E63B0DFD7C4C2D1CCBEB7CCD9C5B0BAAEA39097908D7C6C829993
8A7C766A656E716D7174747B7F7D816C5C616A77787882938D8F8B83888585878A8A8E78
778080877F8284817E88888B8889857F777489938C91938D908E8E87796A667B868B8A8A
89897E7158607276777864595D7175777A6E6760685E67857F6870757B808B8C7D675957
4E4C483C33363C48526B807D673F3C3B3A5F4E41362D2F2C292E2826292E332B29282D30
385E89A8C2B1989C9695A7B6C3C5C8C8CAC9C8C5C5C3C3C3C6C3C3BFC1C3C1C4C3C5C5C3
C2C1C4C2C0BBC2C2C1C5C1C4C3C7C7C8C4C9C8C7C6C9C9CBC6C8C9BFC3C9D1D0CCCBCDCB
CFCFD0CFD0CFC8BFAF967C72635C535B545C5F5B5D535A58535B6163666272879CA7B5BD
C2CAD1D7D4A6452666262E262E2C31372E37343833333330382B2B2F2E39393832302E2F
24272E3F5C7886919A95959290908E8E94979B9E9FA3A6A1A2A29DA6A0A19FA09F9EA09F
A0A1A1A09E9F9EA09B9D9A9D9E9C999997979C979A9A9B9B9B9A999D9C99999899989A9A
989A9E9A9C9E9999
6666676363646664676266626067616564626A696D686A6A6979777D858E8D949B9B9FA1
A6ACADACADAFAEAFADB4AEAEAEADADB1A9AAA8A39E96938A857D6F665B534A4B464B4F50
5651525E625E5B5F65625E5F6262616563636760606767646060635C645F626362686263
635F5D625F5D5B56534C6FC3DBDAD1BFBECDCEB9B1CBCABFAAAAACA1827C8F857B7193A8
998576696D6A6A6F74717D80777E83776F5D60747A7877868F908986898581898989918C
77727E7F827D867E82868889848E867B7F7A7D898D8E95948D8687898C87766478808693
978B7F71685C6264686E656258575F696D625449585A607D817C95998E84878B87857E6F
4D453F4A4348453E394D627A8064383A425A40413833353136372C292D2E292A2E272624
232B5277AEC4C0AE97919A9FABBDC2C2C3C7C7C7C9C4C3C2C8C4C3C0C1C2C1C3C4C5C5C6
C4C1C1C1C2BDC1BCC1C4C3C3C2C4C7C7C7C7C8C9C9C6CBC8C6C7C9C8C6C7CECDD2CECFCB
CFD2CED1CFCCD0CBCCC7AD95887E6C655C595B5A58555758585A5E595E5A6375899BABBC
BEC4CFD8DAD0832C2C282C26282E312A2F323132312D2D33272C363B37343535392D2C2C
2A2831374C6E7E8D93959293908F8F8B92969DA3A19FA0A0A2A2A1A29FA09FA09FA09CA1
A09E9C9FA29D9B9F9D9B9C9C9D9D97989A989B9C9A9E9D9C9D9D9B9A9B989A999A99979B
9C9C979A9B989B98
6262676464636761615F66686261606366616967686A6D7170767C7E838B8E98999CA0A3
A7A8ADAAAFAEACABABB0ADAEAFAEB1B0ACACA5A1A097908D867C6F6761544B4F46454C4F
5654545B5F5B665E605E5B645F6167646663645E606460655F6262636366616563636764
60615D5D5B60564F504F7ED8D5CFD8CDBAC2CDCEBAB8BCC5B6A5B1A8917B8388878B7E9A
A6A7817574666D726E77827D78787F847F6E596B70777179868C8C8C8D85878C878A8D8B
85787074787D8186827F88868789837F80837B808C949D9589868D919493846D5C788D96
988E897F7A6B5C5A676C636D58504F54504B463A3F484879918C999C9B97928A8B868B7D
71655753616554403C51515F756F5341424C413E3F3D46373A45352C29322D2D2F2B2726
272B2A498EB9C9C8B09694939EA6B0B9BBC2C8CACDC7C4C2C6C6C3C1C3BEC0BFC2C3C5C5
C4C7C0BFC0C1C3BFBEC0C1C5C4C5C4C6C8C9C7C9C9CAC8C5C8CAC9C7C8C8CCCECECCCBCA
CCCFCECDD0CECECCCED2CDC6B29F9390806B5C5C585450575558565A5F58626E728193AF
BFC3CBD3D6D7B95028282A242C28302D32362E33302C31372A2C303230303A343F32312A
292C33324C637686969599969494928E8C929A9F9FA1A1A29FA0A29E9F9F9F9F9F9EA09E
A4A09C9C9C9D9A989D9C9D9D9E9D9B9B999A9B9B9A9C9E9A9C9B999C9B96999A9C9B999C
9D999A999C989A99
63636462676162616260666C5D63646B6C6666696768686A71737C7F888B8B93999A9B9F
A6A6ADABB2AEAAAFACB0B0A9AEAAABABACA7A3A6A197918B84746E6257544B484A4A504E
5456575D625C5B5C5F5E6063635F6B656669645E5F66696C636366626363616266626463
6763625E5859565252557DDCD5C2D1D7CAB6C0CACBBCAFB7B6B3949EA49382789AA39089
A1B295816F6D7167697F7C75747279848682725F66747E7C8088908B8A9088858A868986
8B87866C727A8483838080858A8586868187817B808C93928A8B91949A958A8677738C90
94958F8B897F72676465666B62524A453E3B3F4944324079948F94A3A6A8A29783788A86
7C85857B7B756E61605B545158766051454852525159434843503C2F2B353635292E4033
26242B487BA3B5C7C5B3A3999CA09FA1B8C3C2CACAC5C6C4C4C4C6C6C1BFBEBFC4C0C8C6
C2C7C1C0C2C3C2C2C2BEC0C2C5C5C4C3C7C8C9C7C5C6C9C9C8C8CBC7C6CBC9CECECDCECC
CBCDCECBCCCDCDCBCECED0D2D2C7B4AA9D8F807162535157525557585C586065666E839C
B2BBC9D4D5D8CF98322625212525253133302E3435292D372B29292A2A2E2E3637373630
2F2C2F354E57697E8E93969A929091908F91969A9DA1A3A2A2A29FA2A5A69E9EA1A09F9E
9DA19F9C9B9B9B9B9B9D9D9C9D9C9D9E9B9E9B9B9C9C9C999A9C9B9A9B999A9A9C9A9B99
9D999A999B9B9899
6363646160616363636765625F636262686461636369656A746F777B84898D91959C9DA4
A4A9A9ACADADAAADB1B0AFADADACAEAEABACA7A19F9B978B847871635B504D45454F4B52
5153545D5A61625F5F685F5D5F6363656366645F636666665F6068636560616766646362
655D60595A56564E515180D6DCCCC4CCD2C6BBB2C9C6B5A2B2B9A48A989E9A8186A59E94
8E9C9188797870737D79747370747B7B818883696B6D7B7875808A908F8F888C89888783
8D8B8F7770757D77867E83838586888A8B8A8680807E8E948B8D9494959491948C7A727E
8E948A8C8E847971706F6A6C685D5E5957595B624B3A467E909DA6ACA4A0A3A18F718081
8C85868C858084746954464245535D6F686272675661615F575833313741463134545E46
2B222D5992969CB1BCC7BEA99A9DA19BA0B5B6BEC6BFC0C0C5C3C5C7C5C1BEC2C2C2C6C5
C3C5C3C3C1C3C4BFC0C0C0C2C1C4C5C5C6C9C9C8C9C5CAC7C8CBCAC8C6C9CACACECFCFCC
C8CBCDCBCECDCBCDCDCDCFD1D5D5CFC1ACA39F9383695859504D545B63575C5F5F667A87
9FB3C1CBD5D9DACB69292D2B23242A2E302F30342E2D2F372E2A2A2B2A2C353336332F34
2D30303236466477869697999B95958E8F929598A29EA39FA1A59FA1A1A09E9F9EA19F9D
A0A0A09F9E9B999B9E9A9C9B9D9E9B9A9C9B9C9C9E9D9E999B989C979B9B9C9A9B969A9B
9A9A98999C9E9B98
6363626261616267636562615E61656368615E626464646A6C70757C84898D9596999FA2
A5AAAEADABACAFAEAFB1ADABADABA9AFA9A8A7A49C9A8E8C837B6F655B504B444C4F4F56
53545658595D5E6261626861615D6165655D645D64606662646367666266636364636461
6562645C5858544D4F508BD9DBD9C8B7CAD2CBB4B7C2BCAF9FABAC9C8191AD978887A5A3
8C878588777671778076767A6F79807D7D898786726579767676818F938D8D8E89888581
888B88847C81746E7F7E8682868787878C8A90928379838C9698969391949999907F6B67
77868A898D938B7C847E7C7978696D696F675D534D39548098ACABA6A8A7A9A49A847982
83776F727C767E736964586979818D949892AC9A8B7F6E67685C4351625A3F40707E7160
33232F7BA59B9495A2B2C5C5B49D99A4A2A3ABB6BEBDB9BCC4C7C4C7C9C6C0C2C1C1C4C3
C3C2C1C2C5C2C6C1BDBFC3C3C3C5C3C6C6C9C6C7C9CAC8C7C9C9CBC8C8CECBC9CDCECECB
CBCBCACBCBCACBCACDCCCED0D1D6D4D3CCBDAA9E9693906D564C5459575B5A6A61616E77
889BB5C7D4D9DADDAF42282127262F3D2A2D2E312F2D2F33322D2B2B282F3737363D3739
342F2D35394A56687B8C9497979393938F949591979B9DA0A4A1A69FA19E9F9DA1A0A29C
A1A09C9E9A9B9A9A9F9F9C9E9B9E999C9B9B9B9C9B9E9C9899999A99999C9A989A9A999C
999A9795999B9894
64646561636262635F5F60656363606368636167656A6A686B717579878B8A95939B9F9E
A5AAABADABACAFAEABADADABB0ACABADADA9A6A39DA08F8C847971635A4F4F4544484F50
5A5A595B5A61625D6561616460656067626860645F636666666461645E62646863666562
605F615F5F5C544E4D5495DED2D7D4C2B4C1D3C9ADA9B0B1A096ABAC9F889A9C9D8F97A8
958E80846E727B7D76707D7A7882807F7A82898E7F626C6C777E7F82888F918A8A878D89
8F8586858F92706D717E89838480878A898EA192857D7A879496919496999A9A9388785C
586E808396968E8A85897F7878797772726D534B4C504E8099A3AAA8A6A5A5A59B8E7F80
7E737175726C605B617086A6A9A19EA4A6A7A486826868838C777298A498657090856C48
2E3359939C9D9B8A87A0B8C4C7B6B0AA9EA4A7A7B3C2C1BDCAD0CCC9C6C6C4BFBFC0C2C3
C2C3C1C3C1C3C3BFBEBEC1C2C4C3C0C4C4C8C9C7C7C9C9C9C8C9C9CBC6CDCDCBCCCDCECB
CACDCDCBCBCCCACECCCCCDD1D2D2D5D4D6D3BAA5A5A5A0957A5F4E4B505757625B606872
7A8CA7BED1D6DDDBD48F2F22202622292727302C372D2F37322D2C342C30313433363E3E
3D31373839404D5E738A909B9395919892919094999AA0A0A4A29C9EA19B9C9B9F9B9EA2
9A9F9C9E9A9E9A9B9C9E9E9C9D9A9E9B9D9A9B9B99999B9B989D9E99999E999B999C9A9D
999A9796999B9997
61616566606265665F636464635E63636262656366686A6B6A7075737E868B94959A9FA0
A6A9A8AAA7ACADACACACAAAEADAEADADA9A8ABA49C9C958C857C6E645A5752484549494E
585A595E5A62636761645F616165616060655F64615E67625E5F6262616063636561655E
615C625D5F5E5851505192DBD0CCD1D2C3B7C6D0BEA499B2AA9F98A0A29A8594AA9E8B90
A39C857B78778179777E80787C827B7F7A85878A86807B5E6A807C747F8D938A8B8C8F92
8B8087848E8B867E7679818A7B84878A8B92998F887F7A83888B979B9D9E9799948C8976
5C5B5E77968F878A8C80767576776E6167594E63706456808B99A7A4A8A4A39C8E7E7166
63616068707C888A8A95A2ADA19C9D99959D93766C6A99A092819AA2A29576807E775635
384E829F97A095848A98A1AEBBC3C6B1A6A4B0A5A4BBC4C2C9CFCBC9CCCAC5C1C0C2C6C4
C1C0C2C1BDC1BFC2C3C0BEC3C4C2C3C4C6C4CBC9C5C6C6C8C8C9C9C8C8CBCACBC9CFCCCB
CBCACACDCDCBCCCBCBCCD0CFD0D2D3D4D5D6D2B4A3ABA094998B76574F4A56535C58626C
717D9BB2C3D1D9DBDDC35B262724272525292E2D35342B2F31332B2D2D2D343A31373734
30333232373D4050687F8D929A99999792949193979B9FA09EA0A19D9E9FA1A39D9DA09F
9E9C9D9C9E9EA09E9D9D999E9C9C9F9C9F989C9D9E989F9D9A9D9C9F9B9E9A999B9A9A9C
9B98979B9E9D9B97
63635D62656462635C5F636465646562606563646B6A68686B6D747A7E888C92939A9FA1
A1AAAEAEABACABADAFB0ADADACADA9AEABAAABA39A95908F80786B5D5C534B45494B5152
55545B595A5A636065645F5D615F5F5E5F5F6064665F60625F65666462625F6263626363
635F5E615D5A544D4C5092DAD9C7C2D2D3C5AFBCC3BB9EA2A5B5A08DA4AAA08AA29F9C89
A3998870637570717982817C7F7D78877D8483838D919163687A7E797B828D928F918E90
8E878B8D898A8F9585737B7C7A88858890968C8F89868A8C8080979C999795949293968A
7C6C546478797E847D756D6C6E61555E5E656C81877F60738795919EA2A3998C7E675C6E
868083909DA3A19A9EA9A9A492898E8D8E8B89898994A8A29E9AA8A59591786B6453383F
7B919B9B9A9E8E8A9B938F91AAB7C1C9C0ADAAA9AAAABCC0C4C4C6C6C9CAC8C6C4C6C7C3
C1BEBEBDBEBEC2C1C3C0C4C1C3BDC2C4C3C4C6C7C5C6C8C5CCC9C7C6C9CBC9CCCACDCDCD
CDCDC9CCCCCDCCCBCBCED0CDCFD0D3D4D3D6D2CCAFA2A7A499939A8A6557515251556564
646F889FB1C8D5DDDED898292222222325242E2C2F323236342C29283030323732393A35
322E3139313C37495F7782919A989D958F929291969A979EA1A29FA2A0A0A29F9E9FA0A1
A09C9A9C9C999D9C9B9E9A9B9E9C9D9F9F9A9F9C9C9A9D9B98999A9D969B9B9E9A9F9E9C
9A999B9A9A999D99
66665F6362625E60605F645F64645F6164616264666C6B696D6E727981898B919599A0A1
A4A8A9AAA9ADAEAEAAACACABAAA9ADACA9ABA6A39D99908881786E625B554F494948534D
5357595B6359666462625F60616362605E5A5C5C63626360645F61635E62626268696565
6A6260605C5654544F559DDED9D4C2BDCACABEA9ABC0B39795BDAC9498A9AA9B8D93A492
8F8E837D676165677781847F7F80818482867C7E878D8E7A686977817F74828F97949092
88898F8B898C8B8B90836E6F7E8B8A888D88858A8E929D907D7A8E9696909294999C9895
948971625C646C6A6F69685B5A5D5B69717684999987727791A38C8E94968E7B694E6FA0
A2A1A3A3A2A1A3A8A6A39E9E90878589909E9D9E9D9FA5A3A6A3A39D969392959587627A
ABA8A09FA6948B989D948F8399A4B2C2C5C0B8B2ACA2B0AFB9C2C3BDC1C8CBC7C4C3C7C6
C2BFBCB9BCBFBFC1C1BFBDBFC1C1C0C3C4C4C7C5C7C6C7C5C9C6C6C8C7C9CDC9C6CCCDCC
CDCACDCCCCCCCBCACACBCECDCECFD1D4D3D4D3D0C9A39BA4A89B969D997C66525152575D
5D667F919EAFCBDADDDEBB442621212023252C2C2D2D2C30372A2E352D302D2D34373C38
3333373435343D4C546D828999999D969292948D9398969D9AA0A29E9F9CA0A29F9E9CA0
A09D9A9F9C9B9A9D9D9B9E9B999B9B9E9B9A999A9F9C9C9E9C9B9D9D9A9D9F9F9C9D9C9C
9C95979A99999897
626260636260646565606360605E5F606264676364676B686872737A838589909498A0A3
A3A6AAABACAEABABACB0ADAAAAAAACABAAA7A5A29C93938C88776D5D5C52514B48484C58
565A5B5B5C6064655F61606666635F5F5F5B5E5E65616461615C5E616065616563656464
61625F615C5755504E58A2DFD1D3CEB8B7C5CCC3A1B0B1AB95A9A6A1908CA5998B8BA996
9280848671625A5D7382837B858A88878B80797C83908A8E83666F837F7F778496938E8B
85898C8C898F87888C8B7B767981858B8B817F8B919FA09088898184908991979C99A19C
A39E948C8C746D666B696E727577808183909C9E99918079949D938C9A8A7B6B583B7DA2
A2A4A2A19DA2A4A4A09D9E98939CA0A1A7A0A4A99EA2A3A3A3A79F98979C98A3A5968EA3
A9A09AA7A19594A69D968C919C959AB2BCC1CAC5AD9EAAABADAFC0C3BCC6CAC3C4C3C8C8
C5C1BBC0BFBFBDBFBFC0BEBCC0C1C2C2C3C1C6C5C5C3C5C2C8C5C5C6CACBCBC8CAC9C9CD
CECBCDCACCCDCECBCACDCECECCD0CFD5D2D2D1D2D2C0949AA5AC9D929B9F90785F5E6864
5F5E6F808DA5BBD6DCDED279292A202125272E2E362F342C3130342F30302D2E303C3E3C
3532354147383B4044617C8698989C98948F95909594999C9B9FA0A0A0A0A3A0A1A09E9C
A39D9E9D9B9D999B9C9A9D9B9B9F9C9F9A9BA09C9E9C9C9A9D9C9C9B9D9C9C9E9B9B999D
989B9A9D9A9D9B99
5F5F6061625E63626360655F615E5F5E6262626268686C6C6D6D7A787F858C90979BA1A0
A4A9ABABADB1AFACA9ACAFACACADAAAAA8A7A3A49D96958987806B5D5B524B494C494E4D
53555D5E635C625C615B6064626161635F625B5E66616563636461616862636260626260
65625F5D5F5F54504F5390D8CECACFCDBDB1C2CEBA9CA9B6AE9D99AE9F858F968F909892
928078826D635B5564798A818C8D8A85897B7A808389838F8F71687581817A788793958D
8C8A88898E91888A8A8B8E93797880857F87888E92A29992978C7A75828D969699A2A8A5
9DA09D93999E91888F99978F888D9394929D979094927F7B848B8F8D8F746B614A468EA8
A6A39C9C9FA6A19E9D9E9EA09FA4A1A6A4A0A4A19FA0A6A3A6A2A1969CA39FA09A99A4A8
9F9EA1A29D98A4A79D918C9D9E9A9397AABBC3CCBFB4B1AEADACADB6C4C6C5BBC1C9CCCA
CAC4BBBEBCBCBCBCBEBCBEBABDBDBEC4C5C1C3C2C2C2C4C1C6C7C8C6C7C6C7CCCBC9CBC9
CBC9CBCACBCCCDCBC8CBCDCDCCCDD0D2CFD0D2D0D4D0AB939AA5AC9F8E8F9E9D8D786F65
55606C767F97B0C6D6DFDBAA3622272923252D2E3136363C3E312E32392F322F2E394942
353932322E31363F3F586A7F91979D9A969394929491949B9DA19FA1A1A29F9D9F9BA09E
9D9D9D9E9B9C9BA0999E9A999B9E9E9C9D9C9B9A9D9B9E9E9B9D9B9A9E9B9C9C9A9C9F9C
9E97979C999C9B99
5E5E5D5E625D63626765615D5E5D625E6262615F65636763666C75787E878C94979BA0A1
A3A9A7A7ACAAAEABADADADB1ACAEAFABABA5A1A39B99978D807C726363554B4A4C514B53
55555A5D615E5F5C5D5E6661605F61625C5F5D5D60606067656664646262625C5E626367
5D63605D5B5D575350569AD9D2C9C4CFCBB8AFBEC8AE9CB1B3A793A9A0928282919B958C
9581766C6B6B635A586A8D88918D8A867A7A83878A7E81888F8A7D6F76807F787B8C9393
908786899091968D8587939688797D7879888987969A979994888C8D7D8A94979EA5A19F
9D9A99989EA095949F9990919C9B9EA1A2A2968B8F8E8B877D7B757D716959595D6E95AA
AA9F9BA5A8A5A4A5A0A0A2A4A49EA5A59DA29C9AA1A4A5ABA5A19B9AA3AAA09BA0A3A3A4
A0A5A29B9CA5ABA29B8C99A29C9B979292A5B9C2BEC5C0B4A4A2B3B0BAC0C2BDBBCBCCCE
CBC6C4C0BDBCBDBBB5BAB9BBBABDC0BEC0C2C1C3BFC3C5BEC3C5C7C5C7C7C7C9CBCBCBCC
CBCBCECDC9CECCC9CACBCBCFCCCDCED2D0D1D3D3D4D5C7999399A6B0A68C8C9BA4A79B87
6D676C717896A8C0D1DCDFC351252425292A2C322C3139373833343E363C2F3637334344
393B3130323536303E4861728796989997959492918F94989D9F9D9BA09EA09FA19FA09C
A09D9F9D9D9C9A9B9D9E9A9B9B9D9BA09F9C9E9E9F9C9C9D9C9E9A9D9A9D9F9F9C9E9C9C
9E9F9D9B9D9A9C9B
5F5F6160676163656062615F685F6060635E655F646563646870747983868E9294979E9E
A6A7ADAAAFACADACAEAFACACABACADACAAA6A4A39D91948D857C746D64534E4C47554D54
595C5B5B5E5C61605F60666160615F6062685E5E6462636263626263665F636563646465
6A66655D5E5A5B555259A0E0D3C9BDC0CBC3B1A4BEB0AD9A9EA8A49195A1967F909A947D
837C786A696E6A625C5C79808B8A8D83767E8A8C86837D898C92917A6A737A7876798D91
888C8B9191919A978B878C8C8D90836C737A84889493979F8F91A197838293989E9D9EA1
99989B9CA0989C999790929CA9ABA79EA1A1A79D93968C8783837F7B8B95848D92868E9C
9A9EA0A4A0A6ABA1A6A3A5A49F9FA4A9A39BA09EAAA4A9ADA89E9BA5AAA49CA9ADA8A4AA
ACA09A9AA5ACA6A29B93A1A39B969695979A9EAFB7BBC9C7B7A9A9AFBCBCAEBABEC2CACC
CECAC8C7BFC2C0BBB9BAB6B4B7B8B9B9BBC1C2C3C1C3C5BFC1C6C6C3C8C6C7C9C8CBCACB
CDCECACECACBCACAC8CACDCACCCCCDD1D3D1D2CFD8D1CFAB94999CA9B2A8918B94A1A9A5
A28879747E8D9FB2C5D7DED57C272428292D2B302E3537353433332F3A3A2F353446453E
36353D2D38382E323B48556D8091979C979E9396949091949A9BA19B9EA19C9F9B9EA09D
9B9E9C9BA09C9E9C9B9C9D9C9D9B9B9FA19E9E9E9F9D9C9B9C9D9C9B9E9E9C9BA19D9C9F
9E9C9B9C9E9C9A99
6363626065636063595B5F5E5F5C61605D5B5F605C6169636A6E757E838B8C91969AA0A0
A2A6A9A8ABAEAAADAFAAA8ABADAFACA9A9A9A2A49B91928A81786F675E4F5148464F5057
5A5A595C5B5E636061675F64625E6060636163625F62605E5F5E5C626261636261665F61
6364675D61595D55515594DDCBC9C8B6B9BDC0AEABA9A9A6909D9E9A8CA498888093917A
787B876F6D6D6A6B6159636E878A877B80898B8A87838589888E948E726D727C7A767C88
89938E8F8E9393918E918E89879295867E707E81898D9695939A9F998889838F97A19D9C
96A1A29A9DA29C92909498ABAEA89E939298A19C929692888E97A09AA4A39DA9A89D9A8F
939D9D99A9A9A3A4A49DA2A0A8A4A0A59EA2A1A8A8A3A6A9A59B9EADA898A1A9A6A1A8AC
A69898A3A5A6A69E9F9FA8A4A19B9C9EA09C9A949DB2BAC3C7BEB3A9B1B5B1ABAFBDC6C8
C9CACAC6C7C1C0C0BFBDB7B7B4B5B6BABEBFC0BDC1C2C6C5C1C7C6C4C4C6C5C5CAC9CBCB
CCCDCACBCBCCCBC9CAC9CBC9CACECCD0D0D1D3D0D4D1CEC49E93989DA5B2AE918E919DA8
ACA79B8B858693A4BACFDBDFAE372B28252B282B302E323336302E3340362A2A32473537
3A3437342F333443434550647A8E969999979396938C8F8F99989D9FA09F9FA1A0A0A1A0
9F9C9D9D9A9E99989E9E9D9E9E9EA4A09F9C9E9D9C9C9F9D9F9A9D9C9E9D9C9D9D989C9C
9F9B999A9E9B9D9C
60605E68695C5B5E5C5E5E636360635E615C615F5B616562696E727B80828A90969AA1A0
A4A8A9ADA7A9ABABACA5ABADACADABA8AAACA2A49A98948F84786D675A5452484C555153
5B5D5C615B6364616364636466606263655D6064676360685F5F62636260646263616165
646666665F5B5B5552577AD3CEC1CCC4AEB6C2C1AA9FAC9E958AA4A991858B94898D9D81
7A75837A736C696F6B635F647784837D8C928E87898488828682908C87786A6E76777A79
899A9790918C8C9496978E85868C8F959275847E848B9397999899919290897C8B94969B
9DA49C9CA4A0989296959CAAA99E979498A0A18D8D9392899BA4A3A3A6A6AAA8A6A8AAAA
9D9188969B9FA1A3A19FA4B2AEA29A9FA5A7AAA9AAA7A3A0A2A0A3B09FA1ACA3A1AAABA2
97A2AAA49DA0A39CA1A9AAA5A09DA2A4A49C979092A0AEB5BFC3C8BFAEA6ABB7B5B4B9BF
C5C9C1C5CAC5C7C3C5C2C3C0BBB9B4BABEC3BFBEBFBFC3C0C3C5C6C2C3C3C2C6C6C9C9C7
CBCACACDCCCDCBCBCACACCCACCCBCCCECFCFCFCFD1D1D0CFB59798979DA7B2B193889398
A5AAACA69C958F97ACC9D8DFC9602B2B28262A31382933323130352B312B2D3035393134
343B39312C323035473B46536D818F999B999B95928D9090969AA0A29E9CA29FA29F9F9F
A19A9F9E9B9B9B9B9C9D9BA19C9E9C9E9F9B9C9D9D9EA0A19B9F999D9D9E9E9C9D9D9B9D
9B9D9E9C9EA09F9B
5E5E5E62635E5D605F5E5E5F5A665E5E5C5A5B605C5E616464676E7583878D8F999CA1A2
A6A5A9ACABAAAAAEADA7AAACACACA9ABAAABA99E9A93908A81796C636158534D4D555355
5C5D595D5D5E606862635D635F635E635F655E6164616466646161646567686063676563
666564605F5D5D5A54537DCFD5C1BFC1BDB3B1BAB9A19B949D9992A4948179948F8D8783
7C7376746F6F63686767645F617E8B8A94918E8B8B8C88858285858B878C836C6A7B8278
7F8F9593958A869599998F85868A918C94918B7680879291949E96928E98917F838695A0
9FA2A2A69B989A9A9E9A9DA3A2969699A99E9F9C9D9F9C959AA3A2A0A7A6A59FA7A6AAAA
A99B8F948B919696A1A8ACB4A79FA2A6AAADADA9A9A49F9DA5AAB1A6A4B2AD9FA8ADA49D
A2A9A7A19D9CA3A1ADAEA9A7A29C9CAEA6A498909E9B9F9DACB1C0C9C3B5ADABAFBBBCAB
B6C3C3C3C8CDCECACAC8C7C5C4C5C2BFC0BFC4BCBCBFC1C2C1C3C5C4C3C5C6C5C7C5C8C6
C8CACACACDCBCCC7CAC9CBCCCBCCCACECAD0D0D2D2D1D2CFCDA49C97979EA8B5B09C8B90
96A4A9A9AAA89798A9C0D1DAD7932F27292E312C342C31302F2F38342F2B3D412A2A2B2F
3237322F353530323C42464B60798495989D9A998F9190949497979C9D9E9E9D9FA2A09F
9D9E9F9C9F9D9CA09A9D9A9E9C9C9E9E9F9CA19F999EA09E9D9C9C9E9F9F9D9E9B9F9B9A
9C9E999D9E9D9A9F
61616065645C5C5D5C616262615C5E5C605D6062665E6161606E74757F888C90979A9EA0
A4A7A9ABAFADACAEACAAAAABAAAAADAAACAAA29F9993918987766C665C58504C4E515453
55565F5E5D63655C62636463636462655F62606066655F6062616367676B6A6366686564
6A5F65615F5E5C595C5674D2DBC5B5B0BDB6A0AAB4AC9288A9A08C8C92887B7B8E907C74
7771786D6B6E666967726E645D7481858F91918E8E8B878B88867E847E939C7F61758382
7B838E8D8E918D8F939A8C85888A8D898B9A8E87917D838D949594919A9A958F8E878C9B
9FA3A9A09B999AA4A1A09E999897A1A6A79E9EAEA7A8A0979CA09E9CA0A0A5A1A4A8AAAA
AB9E9CA2A48A848E99AAAEA7A1A8ACA6A6A2A9AAA39F9CA3AEB0ABA2AEAFA9A6A3A6A0AA
AEA8A0A0A2A1A6ABAEACABA9A4A1A7ACABA19A98A498958C98A4B0C0C7C5BFB5A5ABB8B8
B8B8C0C4C6CACDCDCACDC8C9C7C4C5C5C2C2C0C3BEBFC0C1C2C2C3C2C1C6C3C2C3C7C7C8
CAC9CDC6C9C9CAC7CACACACDC9C8CBCDCCCFCDD0D3D0D2CFD3C09D99999EA6B1B7B49A87
859499A3A7A9A7A6ADB9C5D6DCB63E26252E262B2A30293230352E313436462A272B2E2B
2E3336352F2D2C36354447466170808B969F9996959490929291969C9B9FA19EA2A29FA2
A79FA09E999E9D9B9C9B9A9C9C9EA09A9EA19D9CA09EA19C9B9D9C99A09F9D9DA09C9C9D
9B9E979D9A9B9C9C
60606D6A615F675F5D5F626560625D5B5F5D625F5E5B6165636B72767F848A8F979DA1A0
A3A6A7A8AFADAAAEACACADACAFA9ADABA9A9A4A09A97938C82766D665A554E4E4A515454
595C60625D606360656361645E615F6364605D5E605F646261626062666464636A69655D
625F6660645C5A58555169C7DCCCC1AABAB9B3A2A4A99E8F979794948D92877986998373
6A747464616C696D6C6D6F6D676D6774868A908D8F888A878C84797A838C908E7D6D7781
7D767C8A8C8F948F948C8C8C8991928A87908F939789768D89818D98A39B9B9999958A8E
9C9F919A989BA3A6A59E9A90929EA8A09D9EB3B5B2A09E999E9C9E9CA0A4A4A5ABA5A9A5
9F9DA1AFAFA587879299A1A4B3AEA6A49FA1A8A7A19AAAA9ADABA0AAB2ACA3ABA1A1A7B0
ABA5A0A9AAAAA8A7B1ADA7A3A6A8ADACA6A299A8A39A9F989DA1A2AFBAC1CAC6B7ADAAA8
B1BBB8BBBBC5C7C8C9CCCECFCEC9CAC8C5C4C2C0C1BDBEC4C2C2C1C2C0C2C0C0C1C7C4C6
C8C9C9C7C7CBC9C9C7C8CBC9CACCCCCCCBCCCDCFD0D0D3D3D0CFA99A9B9DA2A9B3BAB894
85898E9A99A9ACABAEAEBACDDBCE6D2627262B282F292A3030322F33353130262D262A2E
2F353934302E2D31343844504F627B83919A9F989492918E909598999B9F9E9F9F9EA3A2
A29E9F9FA09F9B9B9C9F9C9F9E9E9BA19FA09EA1A0A19D9C9C9D9B9D9E9D9B9D9F9F9B9B
9E9D989F9F9D9DA2
5D5D646860595F5F61605F626260606160615F6060685F60656A737981848F91949B9FA1
A3A8A8A8AAAEACABABADA9AEACADAEAAAAA8A4A19D96948B81756D625E51494E504E4D53
565E5E5D605E64605F6164686468646566625E5D606263635F6664665F62656368686466
6B625F61635F5F5A595662B5E1CBC8BEA4B6B9AA95A8A2A18E87999E8D8391908197867A
696B6B6762646C6B6E6C67726C675E616E8B93908E8F8B8D8A887C838D838C9496766A76
737476828D91978F8D8A9193929597838691978E898C87A08C77929C999D9A9F9F9C9086
8A8D9197ABA7A8A6A095959898A29A9DA6ADB1B5AAA2A2A1A8A2A09E9DA1A5A79FA4A29B
9EA1AAB0ABA69F96999691A7ACA1A2A0A49FA6A9A5A7A8ABACA6A5B3B1A9A8A7A1A8AFAA
ACA4AEB6B0AEAFA7AEAAA8A8A6B6B0ADA49FA3B2A49FABA7A6A29D96ABAFBEC7CDBFB0AB
A2A7B8BCB6BBC3C8C5C9D0D1CFCDCDCBCBC9C7C2C1C0C1C0C0C2C3C3C2C0C0C1BFC4C4C4
C8C5C7C9CACBC9C9C8C7C6CBC9CBC8C8C9CCCCCFCFD0D0CECDD0C19F9998A2A4AAAFB5BB
967E85898E9AA8AEB3B3B6C7D5D69B2E2424272927262A2E323235332F3730352E292C31
303B312F32332C2E303C4346495A6D7C8C959C9D9794948F919493989EA1A09F9DA2A3A1
9EA0A2A1A3A19E9FA09B9B9EA19D9F9E9E9F9DA0A19FA1A09E9E9E9D9D9C9B999C9E9F9C
9A9A9AA09D9F9B9D
6262625E5B5B605D5F5F58615C5E615A585F625E5C5F626263656F7981888A9295969EA2
A2ACA9A8AAACAAADABAEADA8AAAAABA8A9A6A4A09A9491857E776A675B594D4B4D524E51
53585E5B5E5F645F636064616166626462615F6A605D6265636362606260606666676966
666866606461605D555865ABDBCAC3C2B9A9ADB0AD9692ADAC8F92928F7A8E9B8F877D76
6D636C67645B5D5F7167686A6A6C6B5C5A758C93928E8D8A8E88828B898188908E8C8C7A
63777E7B84938F8C8B8A90929B99928687938F8A88909C9E997A98949497A2A29D9C9591
848691A2A9AEA79D9A9A9FA6A19C9AA5AEAAADB2A2A29FAAACA5A5A6A6A4A1A1A19F949A
ADAEB2AAA1A3A3A5A9A69D9B9D8FA0A8AAAAACA8A9AFAEA9A7A6A8B3ACB3AFA39FB0ACA6
A9AEB9B8B5B3AFADAAA9A8A9ACB0ADACA0A3AEABA7AAB5ADA9A69F98A194A8B7C3C7CAC7
B3A4B1B4BFC0BAB5C0C3C4CDD2D2CECCCBC8C8C8C6C6C3B9B7BDC1C2C3C3BFC3BCC2C4C4
C5C5C6CAC9C9C8CBC7C8C8C9C9C9CCC8C7CACCCFCECFCDD0CCD0D0B198939AA2A5A4B0B9
BA967D808490A1A9AFB2B8C5D1DBB83D262A2629262C292B343138473836302E2E262B2B
2E2F373531352D2C2C353F3F46546171839695999C949795939193969D9D9F9EA09FA3A1
A1A29FA5A29F999FA19E9E9D9E9D9DA1A09D9FA1A2A1999E9D9A9C9C9A9B9C9BA49FA0A0
9BA09C999BA19AA0
61615D64625D615C5C5F615C5B5D616061645F5D62656166616870767F858E95999B9FA0
A4A8AAABADA9A9ACA9A9AAA9ACA7AAACA9A4A49D999790877F756C6458574B4C4E4E4C55
595B5E605C5B64605F626D60656463635F6263636263616561635E626164636465696264
646A69616460645F585660A6DECFB9BABEB89DB4AEA48DB2B5A7898D9888848F8E8D7E78
706B686469615D545E6973706A6F716A5F64778C90918E8686868C8B8386898685929B8D
6E767671798688888A8E93999B979294928F8683939798969B919C8D8A92A19CA09B9997
8E86889EACA39597A2A7ABA6A1A6A4A7ABAFA7A8A6A1A8A9A9A8A5ACADA5A3A09A9B9AA1
B8B0A79EA0A5A6A9ACACADA19E8C999FA0A7A59FA5ACA5A4ACA8B3B0A9B3AF9FA6B3A6A3
B1B9B9BAB4ADB0AFA5A6AAAFABAFB0AEA4AAAEA8A0AFB6B1ADACA1A19C90999DAABAC2CF
C9B9B6ADB0B4BDB5B5BFC5C7C7CECCCCCECBCBC8C9CBC7C5BDBABEC3C1C5BFBEBEC1C1C6
C7C6C6C7C9C9C9C9C8CCC8CAC8C9CEC9C7CACCD0CFCECCD0CECDD1C7A49A9E989BA5ABB4
BABE987C7C8B96A1AEB7BAC7CCD8C858252528252629292A34303049403B362D2C2A2729
332D3236332F2C2F333238424A505B6C7C888F9799979296938F958E949A9FA29FA39FA4
A1A0A19F9FA1A19CA2A09D9E9C9F9D9FA19C9FA09F9F9C9C9A9C9BA09E9B9D9FA19D9BA0
9DA09C979B9D9C9C
6565636560615E6A5B5E635F6460615E5E6064606065686062646B767E858D939C9E9DA3
A5A7AAAEABABAAAEABADAAACADA6ADA7A7A3A5A29993908382756D6159594E514F4F4C50
5A555D5F6161656168696964665F5E656464646163656363646162656164646666676863
696C635F6564635E5A545C97DFD5C6B2C0C4B099A5A79F98A2A192889A8C8982868E867B
78686664656D605750617073706E717071686B74898F8986878A8F8A8A8B8A85878C9099
91816E72777D878B908B909794979A9A938E8C8B9591909197A0A1968289959895999D8F
94919092999B93A6AAACAAAAA9ADA9A7ADA5A3A29DA4ACACAAA8B2ABAAABA09A9CA2A7AE
B4A2A09FA3A7A8A7A7A8ADAAA1A1A599949C9AA2A6A6A5AAA9B2B1B0B0ACB0A4AEABA6AD
BABBBBB4B3B2AFAAA9B2B2B0ADAFAFA7ACA6A7A2ACB8B9B7B1ACA5AB9496A69790A8B5C0
C8C8C5BCB2A9B0C0BFC3C0BFC3C3C4CDCFCFCCCACAC6C6C5C3C5C3C1C2BEBFC2BDBEC2C0
C6C4C6C7C8C9C8C7C9CBCCC9C6C7CBC9C9C9C9CFCECACFCFD0CACDD1B3A3A09B999EA9AD
B2BCBE937E838D9BA8B8BAC1C6D1D2912F26262F2727292F3D34324A3C3531332C2E2B2B
2A2D322F32372B2C302E3A3D4C555660717D919599959894918F8F92979B9FA09FA0A0A1
A0A2A19EA09B9F9F9FA0A0A19FA2A09E9D9DA19BA39E9CA29F98A19E9FA09C9E9B9D9E9F
9B9E9B999D9E9E9F
5E5E625E5C606567615D60635F615E6560635C5E5C626663676569777E848891989C9EA2
A8AAAAACA9ACABA9ACB1ACA9AAABADAEA7A7A39D9B93918784766B665A51554B4F4D5452
5959625F5E605F5D62646365615F606163635F63646065626661636162636A6664626667
666A64686862665E605C5E9ADDD9C9C2ACC3B59F91A99F97898E8F918D868B8581887E7D
7970695B586169615F6764737C77746F7573656078868D8C938F8D8B8F8D8080888B8598
9F93756F6F71818B908F979692969C97968D8D8E94838D969E989DA096958D8B8E8F8C8E
979EA4948A8B9EA6A9A5ABB2B2AEABABA3A4A5A5A4A6ABAAA8A9ADA6AAA4A19FA5ACAEAC
A39FA2A5A7AEA8A0A5ABA99DA2ABABA8A98E939AA1A3ACACADB0ABAEACADB0B0B2A9B0B5
BABCB9B9B8AEB0AEB2B2B3B4AFAEB0AEACA3A4AFB1B5BAB5AEADACA795A5A3949DA0A1AA
B8C1C6CFC1B9B4B6B6BABEBBC1C3C4C6C9CDD2CECCC6C9C5C5CBC7C5C1BEBAC0C2BEC3C2
C3C5C1C2C8C8C7C6C5C9C8C4C6C8C9CAC9C6C8CDCCC9CFCECFCDC9D1C6A9A59B96999DA2
A9B1BDB8907F8A95A6B6BBC5C3CED5B93F2E332D23273C38452D332F332F3832302E3128
3329293031372D2C322F323A40464F4F6774868D959795989494909094989F9A9FA09DA1
A1A19FA3A29F99999FA2A1A09FA09EA2A09D9F9E9E98A09E9E9F9C9C9E9C9F9FA49CA0A0
9C9A9E9B9CA09D9B
60606360635D60655D625C5C5F5F62625D6362625E625F6166686F757C858C94989A9CA2
A5AAADABADAEB2AAACADADAEA8A8ABACACA8A69D9A968E8680766E5F5751504E4D4D5255
5958615C6061635B61626462646B6465635D5F6664636364616163656063676562666669
6767686663676664585A5D98DED8C6C4B8ACACB1A0969DA999828E948C84918A817E717A
76746F6257535D726C6C61697879777875786E675F73808F918F8F91908C7C858987888E
93A19972686D78788D98949496989896949495979886959D95919899A19F9B98918B858E
9FA6A397878895A3A0ABB3B0B2AFA8A4A6A3A4A7ABAEA9A7ABA9A9ACA49E9EAAABB2ACA7
9E9D9EA5A9AAA7A2A7A39B9CA9ADAFB1AEA59B9EA2A1AAAEAEB3ABACABA8B0B3ADADB6BA
B8BBBCB7B6ACAEB4B1B4B0B0AFB0B0ACA4A7ADB9B5B4B2B3B3AFB39E9AAEA497A9A2A89E
A5ADB4C9D0CBC4BDB2A8B5C1C3C1BEC0C2C1CDCFCECCCAC6CAC9C8C7C4C2BBBFC1C0BFC3
C3C7C6C4C2C5C8C6C6C8C8C9C4C6CACBC9CCC8CACDCBCBCFCECFC8CBD0BBAFA0A19B9E9C
9EA6B0BEBA938C94A9B3BFC4C7CFD4CF732D2C272B2C3140392F2F372F3337403230322B
3129292F2F34302928292D33434C514F54697989919697989293938E9096989D9C9E9F9E
A19FA1A2A1A1A19DA0A09FA19E9BA2A2A09D9C9EA1A09F9B9F9F9E9E9D9F9E9FA19F9E9F
9C9B9B9D9FA09A9C
6363606161616164655F646A60616062615E665F5E6362626A686D747F83898F94969EA2
A5A1ACACACACACADB0AFADAFADACADADAEA6A39E9C958C8882746C6255584E514C4E5158
5A5A615F6162625F6264626368656660676560606360666363636063646165636466626B
6361676768646362595A5985D9D8CBB4C4B6A5B2AEA993B0AB89859A9D87858A7A756F72
746E716E615355696D7168676D777E787672696A666772868E97928F8A86888F8E918F87
8D9E9D86707376757F9490909697979294919AA1999195958C8C8F9A9A9CA8A3908B898F
A6A5989596999091A2ADB2AFAFADABA8A6A6A7A4ACA9A9A8A6A7A39F9EA4A8B5B2ADA9A7
A2A9A8A2A6A3A3A4A19CA5AEACA8AFABA9ACA2ADA69BA0A0AAB2A8AAAEB3B3B2B1B3BBBD
BBBCB5B7AEB3B5B8B8B4B1B1B0B4B0AEA9AFB7BAB6B9BBB6B6B4B29EB0B1A09EB2ABA6A2
9D9CA2B5C4CDD1D1BFB6B7B0B9C3C2BBC5C3C3C8C9C8CEC9CCCCC9CBC7C8C3C6C2C6C3C3
C5C6C6C6C6C7CAC9C8C8C6C7C6C7CBCACACAC6CACBCDCCD0CED0CBCACFC7B4A7A79FA09C
9BA0A5B4BFBB9D9FABB4C0C9CCCDD2D3A23E282D2A283C323736372E2E36313835353A2F
2D2C2A262B322D2E2D2B2F333A3B49424558728192979899999295939195969C9F99A4A1
A3A0A2A1A29D9F9CA19EA1A0A19DA6A0A09B9B9EA39F9C9EA1A19C999D9E9C9EA0A0A19E
9D9A9A9A9B9D9E9B
5F5F666563685E626061646263626265655F696262625F61646772747B7E898F9198A3A0
A6A7A7AAAFAEAFAEACB0ACABAFACB2ACA9ABA29D97948E897D7672645B5653524F515455
605D5C5E5E5E5F5B645D66666765666461665F6065626567616167656365626269686967
656A6969636563625E5A5E94DADBD2C1B7BDB49DAAB7A597938E8C968E80817E80766970
6E696E6F68646363647574726C6F777F7E736C6662656471889799938488939189938E85
8F95928D918E736E7C8487919497908F8D969B979C9999988A8A889097989C9D968991A7
A39C8F96A9AC9D8E959EA8AAA6B0AAABADADB1A7A6ACACA5A7A79FA1A7B4B6B1ADADACAA
B0B2B1AAA0A095999BA6B2B3B0A7A6A6A6A6B1B3B0A4AAABA3A3A8AEB6B7B1B1B1BBBCBD
BABBB1AFB0B8BBBCBAB9B9B3B4B6B0B0B3B3B3B7B3B2B6BFB6BAAAA4B9AB9DABB2B2AEA9
A69D98A0A6BBCAD0CEC9BFB4B2AFBCC3C3C0C2C3C2C5C8CCCCCFCCCCCBCAC9C8C8CAC5C7
C6C6C6C6C7C7C9C9CBC8C7C8C5C9C8C8C9C6C9C9CACDCDCDCCCDCFCBCCCDBDADA9A09EA2
9F9FA6AFBCC9C2ADB5BBBCCAD1D2CED4C55D2826292A342A312D2C342E3137312D30322F
312B2B2D312F2F2E302B313033383A323E4964768291989A9B9692949393969C9CA0A0A1
9FA3A4A2A4A1A29FA2A19F9E9EA1A29FA29F9C9B9E9EA1999F9F9E9B9B9F9A9A9C9E9F9C
9D9B9F9A9C9AA09B
5F5F6363676561635C635D6061615C66655F67635D5F5E66636671737A838C918F999B9F
A3A6A9ABACABABADAFACAEABABAAADADAAA6A4A39A9390877E7973615C564C4C4D505356
595C595D5E5E5B5E60616563646265686460606066656363616063635D636361676A6967
69686B6B676A64605F575F99E0DBD2CAB2C0B9A09BA8A2858394918B7C828681827A696A
7364656C69686C6C656B75746C667180838073656065666E798A948E888F8E8E93988A88
908C86939C9E7A6B717682919592948F929B9A9B979C9C94918A8787908F90979399A0AB
9C98A0ACB1AF9E9E9593949CA6B3AFB1B7B5B1AFABA5A6A8A49EA3B3B3B0AFA7ACB2ADB6
B5B3ACA6A4A59BA3ACADB1B2A8A09EA2ACADADB1AEB3B7B6A7A2AAB0B0B1B2B0B7BCBBB8
B9B6ABB2BBBCBFBCBCBDBCB8B3B0AEB0ADB0B4B4B3B5B6BCB6ABA5B1B8A7A2B7B4B2B3AE
A99BA3A1999CB2C2CACFD0C4BEB5ABAFBCBEBABAC3C4C5C6CBD0CECFCFCACCCCCBCACCC7
C7C6C5C5C3C7C6C8C6C8C8C8C8C2C6C9C6C9CCC8CACECCCACBCACECECACFCAB8AEA39F9D
A5A1A8B3BAC5CDC6C0C0C5CDD4D5D3D5D3952A2E2D25292F2C2C2D2F313932312C2F3631
2E35332B2E2E322D30303230353431302D3E526D8090959C99989591918C94969D9FA0A2
A0A09FA4A1A2A3A49F9F9BA19FA2A2A19BA39D9D9DA09F9C9D9CA09D9C9F9E9E9B9EA2A1
9E9B9F9D9CA29D99
63635F6063635F67606D6A6361616062636065605B616161616469727E808E8D91979DA0
A4A5A6A6AEAEADAAB1ADAAADADADAFABADA7A2A497938D888278746359504C4E4A4C4F4E
55585C5B636062615F6063646461656560636263676361635F6460666163646264676A66
6368666B656568635F5B6091DED9D0C7C2B1B3B18D8C9E8C858B8F88757995857B756D6A
676468686768787168696E71716A72777D7377716C6A716F687A84899491888E98959194
9082888D9498938B756C75888C909499989494939F9A9A99958A83818B928C9094A2ADA6
9A9FB4B3B5A8A2A7A3998B8D9EACB2B5B3B1B2B3ACA9ABA099A3ACB5B4AEAAAEB0B2B3B8
B4ADA7AFAAAFB2ADB0ABA9ACA39DA7AFAFADA6AEB4B9B5B5B2AEB4A7A3B0B6B6B8BBB9B6
B3ADACB6BABCBEC0BDC0BFBCB5B5ACB0B2B7B7B4B9BAB8B3AEA8AEB8ADA3B2B8B6B4B8B5
ACA4AFA7979BA2A2B4BFCDCECDC2B9B5ABAAB9B9C3C4C6C6C4C9CCD1D0CDCECFCCCCCBCD
C9C6C5C3C3C7C9C8C8C8C9C8C8C8C7C8C7C7C7C9CBCCCBC9CDCDC9CCCBCFD2C6B6A7A4A5
A7A5AAB3BBC1CDD1CBC8CAD1D2DBD8D3D8BA3E2D2A2A262A2A2E2F2D312D343432313A41
3A32262B2F372C323335383D3834312A293648617986949F9E989594908F9397999C9EA1
A0A09CA0A19E9FA1A19FA09FA0A5A1A09FA2A0A09D9FA09D9EA1A29D9C9D9D9F9F9E9E9D
999D9F9DA0A09C9A
5F5F625D5E6262666065646061606361606461666266615B636972707782888E93989BA0
A3A8A7ACADB1ACADADADACABAEB0AFABAAA7A6A296908F83817672635C564F4E4C515354
56585F5C5F5B605F60616264646364616161636562675F675F6464686262646369696A66
67666A6A6A6464605B5A5C85D5DBCEC3C1BC9EB49C8D95968A8587887475857E78707674
68676D6F67656F6F6D666360676F73758571737B7E7774746E6A7384958A858A91909994
8D888F8D858D9BA48778707287909599969996979997A0A19E8F868C90888B90A0A09C9D
A1AFB6B4ACA7AAA9AB9C908995A1B1B6B3B3B4B1B1AA9E9F9EAEB0B0ACACB0ABAEB7B3B8
ADA5A8AAB3B4B0ABAFA9AAADA7A8ADA6A8A6ACB4B3B3B3B7B6BABBB5B0B2B3B4B7BABCB2
B0ADBAB8B8BBBEBFC0C0BCBDB8B4B2B6B6B3B7B7BAB8B0A9A3B0B2ABA7B0BBB5B5B7B6B2
A3A7B3A99DA6A79E9CABBBC4CACFC8C0BAA7A1B1BEC3BCC3C7C7C9C8CCCDD1CECFCFCDCF
CECCC6C3C1C7C7C7C8C8CAC9C6C7C9C6C5C6C5C8C8CCCBCCCCCCCDCCCECDCFCEC0AFA8AA
A6A9B3BBC1BFCCD0CECDCCD2D4DADBD6D9CC6D332F23262C29282A282A3030333134333F
48382C2A2C312E33363B303D32382B2B2530405771818D949B9D9A92928F9193979D9B9F
A3A1A0A09FA2A1A39F9DA2A3A19FA19FA29F9EA09A9EA09F9D9F9BA19EA09F9C9B9E9D9E
9B9B9D9F9EA2A19A
66666260625F6269666661665E60626160615E6061666063656B72747C80879792989A9D
A3ABAAAAABAEAFB1ADAFB0ACAEAEB2ACAAA8A4A196948D847B736F675A514E494A4C5256
54565E59625B5F616064665F656364605D6163616562675F6265645F5C6466666766666A
676E6767636769655C5B5F7ED1D8D2C8B2C1B69D939E8B8D928887847B7E7A7274717379
67686B6E7061676F6B6D6D61546775767A71707D7C80797273736B7783898D8C8C959C93
909292857D8C8E99A298777B818A92989C9598999399989DA29F92848789999E989498A9
B1B3B5B0ADA8AAB1A79D979398979DA7B7B1B6B3A9A1A4A2A8B4AFA6AAAFACAEB1B8B3AD
A6A5A9B4B3ADAEACAEAEAAA9B2AFACA4ABADB1B3ADB2B7BCBFBDBABAB8B1ADB6B8B4B2AB
B0B4B9BBB8BABFC3C0BFB9B9B8BBBCBAB5B2B9B9B7B0A9A4AAB5ABAEB2B8B9B8B7BAB9B4
A6B1B4A6A9B1A8A198A4A6B0BAC7CFD0CCBFB3ACB2B3BCBEC7C6C6C4C4C8CED0D0D1D0D0
CECECDC9C1BEC4C8C8CAC8C6C8C9C9C7C2C2C6C8C7CACBCCCACACBCCCDCCCFD0CDBEB1B5
ABACB9C0C8C1CDCECFCFCED3D7D8DAD8D8D693362F23252B2D2D29362E2E3C352F37383B
3632342C312F2C2F2B39343D38352E2A27343B4B61778691979896989294938F9395999B
9EA0A2A1A4A39FA19CA2A3A19B9EA0A2A59D9C9C9E9D9DA29F9FA19F9A9D9E9D9D9E9D9D
9B9C9D9D9EA09B9C
6A6A67605F626065616463656161626161616161636063656A6571717C7E888D939B9BA1
A1A9ACADACACAFAEB0B0ADACACABB0ADACA8A79F99968B867F756F6359514A474D4B4E4C
575B5C575A5F62635D6666645F5E64645F65645E6263646562635F5F686066656165656D
706B676A65666B615D585E7BD5DAD4CDBBB3C3B890A19493828A837878868378736C706F
6B6D67686E6B6B686F727B6E68636A727A7974747A7A7F807A7A746970818D9294949493
99968D8186888F8E9DA8887A858188939C9690909493909898A89A808597A09A939299AB
A7ACADABB0ADB3A7A59EA0A8ABA09698A6B3B2ACA3A5B1B3AFAAA9A9ABACB0B1B2B3A7A7
A7A3B4B9AEB0ACAEB0B1A9A6ABAEAAAABAB4ADACAEB1B9C0BCB9B4B4AFB1B1B9BAAFA9B2
B7B5B8BAB7BCC1C2BEBBBCB6BABFC1BBB9B8B5B4B1ACB2B4B1AAA9ADB2B8B8B9BAB8BCAE
ABB5B3ACB2B3ADA5A2A7A3A3ABBBC0C7D1CCC3BEB5AEA5A9B9C3C6C8C1C5C6CCD1D2D4D4
D1D1D0CEC8BDBFC6C7C8C8C7C8C8CAC8C6C4C6C5C4C9CCC9C8C9CECDCBCBCDCCD1CBBAB7
B0B4B9C3C7CACECFD2D1D3D4D7DADAD8D8DAB642292520262C2F30292B312E322D313337
31362D27292E2D2C2C343A3735362B34282F3C515C6E7C90939B9898969191908E929599
9EA09EA0A19F9EA19DA0A19DA0A0A19FA19E9E9E9DA19FA29D9E9E9D9F9E9B9EA09F9D99
9B9B9C9F9D9F9B9D
6A6A646065636264635F585F625F685F6561646666676365696B6E757A808A8E919B99A3
A3A5A8ABAFABADAEAFB2AFADADACADAAABA8A6A09A948D857B7273605B53524A474B534F
54575B5A60625B5D5E635F5E626562645E6464616160656364636162606A5F686367646B
6D6B6869656567615B5A6076CEE1D3CAC7ACB5BC9A8D939B7E7D857C6F7B85746B6E6962
687263636B6E6A756C70727571716C737C7A8577797A7E7F807B7A6E66738194908F9197
9B8F888D88848B8C909E988A7B787B89928D8E94959093989C9E9292A3A39A9694969CA3
9EA6A4A8B0B3AA9EA5ABAEB3ADAAA19096A5A5A7A4B2BCB5B6AAA9A5A8B2B0B3B4AAA8A4
ADB3B1AEAFB2AFAEA5ACA8A6A5A9B4B8BBB3AEADB0B7B8B6B5B5B5B6B2B5B7BCBDB2B0B2
B2B3B9BDBDBFC5C2BCB7B8BDBFBFBEBDBFBAB6B1B1B7BCB7ACA7AFB2B0BABBBCB9B9B4AE
B8B7B6B0B8BAB1A9A9A4A5A8B1B3B3BAC4C2CDCDC8C3B3A9ABBBC7C9C3C2C3C3CACFD2D3
D3D2D1CCCBC5C2C5C9C9C9C8C8C8C8C8C5C6C7C7C3C7CACACBC9CFCCC9CDCACDCECEC5BD
B7BCBEC5CBCCCFD3D1D1D4D4DEDCDBDDD9D9CB6929282624322B2E2E35302E2C3435342F
2E2C2E2A30273E31303037383E37333A2E363A504E69758890949C999890948D8D92969C
9D9FA09EA3A1A09F9EA0A09FA0A09D9F9E9B9F9C9C9F9D9F9CA19C9A9E9C9E9B9F9A999C
9B9B9C989B9D999A
6363645F606366626A695E64675E65606765616463676764666C76727F80878F93999FA1
A8A6AAAAABA9B0ACAFB0AFADAEAFB0ACABA8A59E9C9690867871746456574E494F4C4F50
53595C5D5C605F5F5F605E636062696B6668626462615E66626062646266645F6363626A
6B6A676466676562615C5D74C5DFD4CECAB6A7AE9C938E998A727B7B6F6A766F6C6D6669
636669666E6D6C706C6C6F747B7D7877757C83817E767D81877E786E6A606F8D94939B98
958E90998E908D908C939C958B7B7776848C9796929295A2979398A6AFA5938E969C9A9B
A0A5A4A8ADA8A6AAB3B6B9B5B7AAA2999A8F9EA4ABB5BFADB2B2A7A5ADB2AEABAAA2ADAE
B9B1A9AEB0B1ADA6ADABACA4ABB4B8B8B4B6BFBFB6B0B1B0B4B9B8B9BAB9B3B9BDB8B4B3
B0B9BDBEBABEC0BFBAB9BCC2BFBDBCC0C1BBB9BDBFB6B5B1ABB2B0B2B8BBB9B8BCBAAEB6
BDB6B3BAB8B7B5B4AAA8A8B0B8B6AFB9B8BABFCAC7C9C7C4C2BAC2C1C4C4C2C1C6CBCCCF
D4D4D1D1CBCCC9C8C9C6CACAC9C9C8CAC9C6C6C6C7C7C9CBCCCACDCACBCCCCCDCDCECDC6
BDBFC0C5CACCCED1D2D2D3D7DBDBDCDEDEDDD58C272424272A2A2A3235302D2D2D373135
2F2E302B292B2B2B2F3430323C3136363132383E485C687689919998979A969193909396
999E9E9FA1A2A1A6A2A2A09EA09E9D9E9C9FA09C9C9C9E9D9C9F9E9B9C9E9C9B9D9B9B9C
999B979D9C9D9C9D
6464616564656367686165616161655F6C656363625F6567686E74758183888F959F9B9E
A1AAA6ACADACACACB0AFB3AEADAFAFABA8ABA39F999391877E75716258524C4D504C534F
58595D5A5D5F6161595E656367646767606064616462645F5F6465675F5E66626161646A
666C73676B6765615E5E5A6CBDDBD7D1C0B5B79E9F948C898177706D6E64666A73726D68
6E626468686C706970717274757B7974727773707B777A7D857C7A756B6A66768C959A94
8D9097999697908D8D8F8E939E857977768B938F93979A9A958F9BAAB4AA999993A1A0A2
A19EA1A8A1A2AFB8B9B8B4BCB7A1A0A3A7A09599ACB7B1B6B1A9ACB1B3B0ADA7A6A5B4B9
B1ADAFACB3B2ACA9A9A8A6B0B8B7B0AFB2C2C6C5BAB9B1ACB1B6B7B8B7B3B5B6B6B3B1B9
C1BCC0BCC0BBBBB9BABBBBC3C1BEC1BBBBBAC1C0C0BAB0B2B5B8B5B6B8B9B7B9BABAB6BC
BBB4B5BBBBB1B2B5ADAEB1B7B7B4AFBBB9B9BAC1C6C4C9CECDC7C2B8BCC7C3C0C1C8C7C8
CBD1D4CFCDCBC8CCCCCACBCACAC7C6C9C8C6C7C2C5C9CAC9CAC9C9CECBCCCFCBCBCECDCA
C3C2C0C7C8CFD1D1D1D1D2D4DBDCDDDEE0DFDBA934282C252B302A2C3437312C2C323932
31362F352E272E292C37333B332F3B3B3D423C414A545C707E8D949C9898939491909396
9B9AA1A09FA09F9FA2A29D9E9FA0A2A19FA09E9B9D9D9D9F9C9C9EA09B9B9C999E999A9D
9A9B979D9CA09E9B
626263616762656A6A6963615E5D63656162606166626168666C6F7A81828B8D939A9A9F
A1A3A6A9ABAFACADAEADAEAAAFABADAEACAAA4A09D9390857D756E685B54504A474B4E4F
5455545D5A5D5C625E63626162606666676164656062626462636167666263646B676966
69676A69686A656662575964A6DBDBD0C6B4B5A7968F8D83807A746A7165646A6E696F6B
6C6560636C6E6B706C717572747370737B78756F6C787D7B857F7F7E79736D6A77899991
8D949597959D96919088868C8E929B9A7B7B7E93969E9691909EA3A3A7A1A8A7A09AA5A7
A19BA0989EABB0B1B7B2B2B6AA9FA0B0B0AF9C929FA2ACB3AEB1B2B6AFA5A6A6ADB9B5B3
B2B4ACADB0ADB0AFAEA4A9B9B7B3ABADBDC2C1C1BFC5C0B9B1ACB0AFB3B3AEB0B3B4B6BE
C0BEC0BDC0B9B5BABDBCC0BFC0C2C4BBB7C4C1C0BDBBB6B9BBBCB9B2B5B7B9BABCBEBABD
BAB1BABEBDB6B9B8B0B3BFBDB7B8BBBEBABDC2C6BDBFC6CCCFD1C9C6B9BCBEC4C2B9BEC3
C7CAD0D1D2CDCCCDCDCECDCBC9C9CACBCAC8CBC2C5C5C8C8C7C9CCCECDCECECCCACDCCD1
C7C3C2C3C4CED4D2D4D3D3D5DDDEDEDBE0E1DEC34B25242C2C2928322D272D3132374737
3F382F323329282934302D2B2D31373238423F454E49586C7884919699999593918F8F93
989B9D9CA0A0A1A3A2A1A2A39FA29D9CA09F9E9C9C9F9F9E9B9E9E9E9D9B999D9D9C9D9B
979D969A9A9D9D99
646467666566646363656964686667636665626361676162656D71757A858A8F96969DA2
A2A7A4A6A8ACA9AAAEA8AEABABADABAEACAAA6A49D8F93897C7370665B524A4D524A4E54
5657625B5B595B5D606465676665646763616262646363625C645F63636662646A666668
6A6A6B6767686563615B595C93D3D5D3C9B79EB6A5898C8A7A80777667656C6463696F68
6B6B6866676E767664646D79726C696B7C817A716F6D7B7D807A83837E7E736B6A758E8D
9190959099989899938885848B98A2A4887479889595939699A5A19E9D9D9EADAF9FA096
9D99989DA9ABA8AFAEB4B3ADA8A3ADB5B6AF99949A95A1A8B3B8B8B0ADA7A6AFB6B1AEB0
B2B4AFA8A7B0B6B1A8A9B5B7B1ABACB8BEBAB7BBBFC1BDBEC2B6A9AAAEB0B2BCBCBDBCBC
C1BEB8BBB7B0B0B7BDC0C0BFC2C6C1BBC2C7C5BDC2BFBFC0C0BBB9B2B3BABABBBCBBBBBF
B5B7BEBEBCB8BBB5B2BCC1BBB9BAB8BBB8C0C6C7BBA5B1C1C8D4D4D3CBC0B3AEBEC0B9B1
C1C9CAD0CED0CFCECDCECCCDCBCCCBC9C7C8CAC7C6C8C9CAC9CBCACDCDCCCFCFCECDCBCD
CAC9C6C6C6CBD1D3D2D4D3D7DADFE1DBDFE0DFD06421252A2D313031312E373435303430
3536302C2A2E2B2A342B34302F3335363941393E40454B5D6B808F979698969591929191
94989A9E9CA1A1A1A09F9EA0A09F9FA19F9B9C9C9F9D9B9BA09E9D9A9D979C9D9A9B9B99
9A9797979A9E9998
64646761636362676A616661616362616765646564605F65656872797D858B8E949C9E9F
A6A2A6A9AAAAA9AAAFACADAEACACB4ACACA7A99F9A948B88827267635D5252484F505157
5C6E675E585C5F626163656162656166626266636463676260636761666A646469676C68
676B66696F6A6A6661595E6183D2D8D5C8C39FA6A68B848184736B6E64656B6560676A68
686F6E6E67676C73696168717072726E707A7B79716B6C737F7A7D81827E7A706A697D88
9499939797939C9D948D8A87899495959B967F78898E9CA1A4A39B99989DA5ABABB29E97
9396A5ADA9A4A6A9AFAFA9A6A7B2B8B8AD9F99A7AD9A949AABB2B0ADACAEB5B5B0B0B4B3
B2B5B0AAAFB6B0A8ABB4B7B1ADB1BBBBB5AAAEB9C1BBB7B9BEC2B6A49EA8B4B9BAB8B8B5
BCBCB6B7ABA3ABB6C0C0BFBFC5C0BDBCC4C8C3C1C0BEC2C5C2BEBCB8B6B8B8BFBFC1BFBE
B9C0BCBDBABDB9B5B5BFBFBDBAB7BEBCBEC6CAC3A88F96ACB8C9D5D3D1C9BFB5AEC5C7C1
BBBAC4CCCDCECFD2D1D2D0CDCDCDCDC9C9C8C7CCC9C9CBC9C8C8C9CBCECECDCECECDC9CA
CCCAC8C8C7CACED2D2D4D4D8DADEDDDDDEE1DFD17F2C272C3138333736394036342C373C
3936332E33332D2A2F2F33312E2C2D34302F313F4041454A596F808C9598999698918E92
9296969B9EA0A0A0A2A29E9F9D9F9E9EA09E9D9C9F9E9B9D9C9E9E9C9D9899989B999C9B
9AA09A9A9B999A9C
67676663656061646164636163646466666B6264615F6167666D72757F818B8F939B9EA4
A3A4A6A6A9ACACB2ACADACA8ADB2ADAEAEABA5A09A9389877E756D5F604D4F4E50515755
5B5D615A5B61615E67656165616464665F62666664646564606066616466686965686A6E
676D6B6D68696B6562615E5A75CFDDD2CAB9AD9C978C877A807B6D6167676C6863686F6F
716C6D706D63626B6A726F7069767771707377857A706C72717A83807E827D7B76716E7B
92969A988F969D9C948F8C89968C8C91A6A789747985979B9F9B9A9D99A2A49FABAFA99E
96A9B2AEAAA7A7ABA9A0A9A3A7B6B7B7A59DACBCB0A39F99989EA7AEB0B9B3AFAFAEB0AD
AFADAEB4B3B2AAABB7B8ACA9B3C0B7B6AEA8AEB9C0BCB3BCBCBFADA6A99A9CACB5B2B4B3
B9BEBEBEB9A2B2B0B6B4B7BEBDBCBBBFC3C7C3BEBFC1C7C8C2C2C0BFB7B9BCBEBFBEC2BB
BEC2BFBFBDBFB9B4B9BEBCB9BCC0BEC0C2C9C6B7929090949FACC5C9CBCCD0CBBCBFBBC6
CAC5BEB7BEC7C8CDD3D5D3D0CFCBCECDC9C6C8CACAC8CACACAC9CACBC9CBCCCDCECDCDCC
CBCCCDC9C8C9CAD2D2D3D3D7DADBDBDDDEDEE0D68F342D302E2C313037313B3535353334
383232322E2E2728322E34342E333A343339393A3F3A4647566573859397959692939090
929798999F9EA1A29D9CA0A0A39C9E9FA2A09D9A9F9C9E9B9D9F9E9C9D999B9A9D9A999D
9B979B96979C9B99
636365616862646661646363675F62626667615E655F5D67676D6D778385898E959A9B9E
A2A6A4A7A8A9AAADABADABACAAACADACACA6A39D9A958E85817368605950514F4F4C4F54
575B596359605D6065675F6461616466686666636664675F5E6166616563646866696C70
6A6E6B6E6A6A686A6A605F5968B5DCD2CAB7B0A28B8F877B7E7B6B616B706B696C6B696F
7070636669696966686E75706C6371757A7A767F7E7D796B6F737481787E7D7A7A796F6D
7D93A0968F919696948D94948F8A9194999F9394847A8293989BA1A1A1A3A3A8A1A6ACA4
B1B6ABA9ADA9AAA8A8A7A6A8AEB4B5A5A3A9BEB8ADAEB2AC96929EAEB2B5B1B1B0AAAFB0
A9ADB2B5ACB0B5BBB7AFA8B1B8BEB4AAA9A8B6BCBBB5B4BABEBEB7B4B6AD9CA0A8ADADB2
B4B9BEBEC1B8BBB0B2ACB6B7B4B7BDBBC0C0BEBCC0C8C6C6C5C6BFB7B9C0C3BFBEBDBAC0
BDC4C2C0C0BEB6BBBABEBBB8B7C1C3C4C9CABDA08F909A949A99AABBC5C6CED6CDC3BFC0
C2C3CAC1B5BAC6C5CCD3D4D5D1CECDCDCCC9C5C7C7C7CBC9CAC9C7CAC8CBCBCDCECECBCD
C9CDD0CACECCCDD3D1D3D5D9DDDBDEDFDCDEDFDB9E30353030323433343437363A322D37
362C30302A2B2927282D34332C313335303037383B43434449596A809193979594949292
918F939B9F99A1A2A29F9E9EA29CA3A0A39EA09EA09CA09B9C9FA0A09F9D9D9A9B9A9698
9B9B9997999C999A
676765666363615E646064626662645F6669615F636160686370727580858C909798989B
A0A4A5A5A7A7A9ACACABAEADA9AAACA8A9A7A3A19A928D867D746E605D4B504C4B494D5A
5D585A6356606266626863626363616668636067656968666967606B665F6568636A6B6E
6A6B6D6D68696D676B5F5965669ED9D6CDC3A69E98867A817F756866696D6F666E6C6264
696D615A5A6F716E656071716965606C767B797774787C747172686D7C7A7B7C78757670
6D80949895919A948F969B95938E9390918F98A2A287797E97A0A0A6A2A3A7A49B9BA0B2
BCB3B2A6ACAEA4A9A8A5A3A7ACADA4A7ADC0BEB0B2BDB8B19F9694A3A9B3BBB8B3ABA9AB
B0B1AFABAFBABFB7AFABB2B3B4B4B2A6A7B7BDB6B2B0AEB3C2C2BFC3BDBAACB3B4B1B1AB
A8B0B6BBBEBBBEBFBAB9BCB7B3B6B8B7BFC2BEBDC0C5C5C4C5C5BCB9C1C2C1BFBCBBC4C3
C1C8C5C2C2C0B5BFC1C0BDBBBAC2C7C8CDC9B1958E97929896959799ACBFC4CAD1D7D5CB
BEB4B6C8C7B8B2B8C5CAD4D5D3D2D0CECDCCC9C9C6C8CAC8C9C8C8C8C7CACBCBCBCDCFCE
C9CACECDCDD0D2D4D3D4D5D7DBDBDFDEDEDEDEDEB7422829302F3330343A333834313337
322F312E2F2B2C29252A2D35323334373633393D35383F40464E6077879094979A969593
92919297999F9FA19DA1A1A2A49FA09C9C9F9E9C9D9CA1A29CA2A09E9F9A9A989C99979F
9B9A98999A999797
616167635F676166646766606661676367625F5D60665C646B6C6F778087898F9598999C
9DA3A6A7A6A6ACA9AAA9ADABACACACABAAA6A29B9A958D8580766C635F504A4E4D4D4D53
565A5B635A5C5D5F645F68626362676B63636363676366656265636263666568636B6A68
6C6D6C6A696B6B6F6E6261616391D8D9D1C49B9595907F807F766A6B6B696D68666E6763
5E666769605C6972675E67737570685B65727B79777778807D7B736E6C76807B73727471
74727C8F95978F8C949F9D959D9A8E8F8E95939CABA68B807F8F9C9DA5ABA59F979AA8B0
AEB5B6B2B8A6A6A4AAA5A5AFA0A09FAABABAB5B5C0C0BCB0A8A39A999EB2B9B9B3B0B3B2
B1B2A8AFBEC1B9B4B2B7B3B4B0B2AFACB4BFBCB3ACACB3BCC1C4C7C6C4C1BBC3C7C3C0B7
A6A4AFBEC0BDC4C5BDC1BFC0B7BFBEBBBFC5C2BDC2C2C5C4C1BFC2C8C4C2BEC1BEC5C5C4
C5C6C5C4C2BABEBFC4C0BEBFC2C6C9CDD1C4A08F969896989697938F8D9BADBFC7CFD8D1
CBC6BABBB7C1C1AFB3C0C7CFD4D2D3D0D0CDCFCCCBCCCAC6C8C8C9C8CBC9CBCCCDCDCCCE
CACBCDCDCDD0D2D3D6D4D4D7D8DADADADDDEDEDDC8532D29303333443637353635303531
393130382C2B352A282928272D2F323535343437313635373747546A7E8D93999D959693
94959092969C9B9EA2A1A1A1A19FA2A09F9B9E9E9F9DA09F999D9D9E9D9C9B9C9D9C9C9B
9B9D989A9A9C969C
6464606169686767676465696364636368665F6462636168696E71797F848D8F9298959B
9E9DA5A6A4A6AAA9AAB1AAABAAA9AAACAEA99E9A96958B817C766D61594E4D504B515155
55565B635B62605C63635D6063656C6564686864665F67686364626560646366656C6D6A
696B6D6C6E6D6F6E6B6A635E6184D8DACDC69CA08D878A7878786E646D64636C69656A68
665B6574685A596B6E736E6F737A766F63666D79807D808180867E756A6B747A77767375
73776A778C918C8C9799979CA2A18D8D909392979BA6A386767A8EA2A5A4A79E9CA6ABAB
AEAFB2B7B3B1A6ABB0A7ADA49EA1ADADB0AEB1C3C4BDB5ADACB2A99A9DA2AFB3B1B6B7B2
ADACB0BCBEBBB3B6B4B5B5B1A9ACB6BCBDB6B5ADACB3BDC1C1C2C1C2C3BFC5CACBCAC9C5
B9A39FB0BDBDBCBFC0C0BFBBBDC2C5C2C3C6C7C2C4C3C5C4C2BCC8C7C5C4C6C5C6C8C7C5
C7C3C3C6C0BBC2C5C5C3C2C6CBCECCD1D0C49A97999899979495928D8A8E909FBBC2CCD5
D7D2CDC2B4AFC1C8BBB4BCC7CDD0D4D3D3D2CFCECECECDC9C9CACAC8CAC8C5C9CDCDCDCD
CBCBCCCCCED1D3D4D4D7D4D6D8DADBDDDDDFDCDECF69282A2C262A3136342F393B2E2F32
322E32382E3232282D2A2F2B2C2C31352E362E36303232302F3A4A6173858F9A9A9A9796
9294949094969F9CA2A0A0A1A0A2A09CA39FA09E9F9F9F9E9B999E9C9E9C999B9EA09C9B
9A9B99959B9B9A99
63636862676466646662616361646261686162636363616363676E767D828C8B95949698
98A0A8A4A6A8A6AAABA8ACA8AAAAA8AAA9ABA1999A908C837C7370635A4D504D4F524E56
565A595D5B5E5D6160646566666167656566676361626765696460676268686A6267676D
6F6B6A6D756D6C696866635E5F70C0DED2C0B2988B7E848476747062696961636C67696F
6966626569675F5A657576727875787A76706D77807F7C7E84807C7A766F6D727C7E7579
7171696A748287929D979AAAA49B919490949692949D9D9A8F8C8691989B9DA3ACB2ADAB
A8ABB1AEB5B2B3BAA7ABA9A2AEAEADA8A4AEC0C0BBB2ACAEB8B6A9B2B4A2A0A6B3B7B5B1
AFB8BCBBB5BDB7B2B7B7B4AFB1B8C3C1BCB8B3B0B6C0C1BEBDBEBEC3BDBFC9CACACCCCCA
C5BDB3A9A4ACB1B4BDBDBEBBC3C8C7C5C7C8C6C5C5C6C6C5C2C4C9C8C4C7C8C7C7C5C9C5
C8C5C6C2C1C2C1C9C4C3C4C8CDD0CBD4CEB9929497979A9A959596939390908F96ADC1C9
D4DDD7D2CBBEB8B9C5C2ABB3C1C8CCD2D5D2D2D0CFCFCECFCCCBC8CBCACBC9C7CACCCACA
CBCBCCCBCFD2D1D2D5D8D8D8D9DADADEDDDEDCDFD6802F2A2E2A2B2D3634303131302D2E
303730363A3331322D312D2F252D32333736333130342D2A2E34384C627A8B95969A9C99
97938E8F9496999E9CA5A3A19D9FA09D9E9C9E9A9C9E9D9F9B9B9E9B9C9D9F9C999B9C9A
9F979D979A9D9A9C
6666696062615F696B696263636566636360636164615B6363686E747A848E8B9596999E
9DA0A3A2A7A5A8A9A9ACA8A9A8A5A9A8A7A2A09C9A938A8879767167594F504A494F5253
5759555E5E5B636664696C66686664676465666A615F6A6B65685F6560666564686C686D
6F68716F706D706E6C6968625E69AFDFD7C9BA9E828A797B776E6A655C6366666A6C686C
706B6960606E6E665E646D727775757479787778757B7B7B7D7F81827E7D7970727C827D
75746D6C6B7286949997A3A9A2999E9B9B97918E938B8A92AFAE908987919DA8AAADB1AD
ACACADB1B3B1B8B9ACA6A8ADB4AFAAA8ADB7BCB2ADAFB0B6B8ACB2C1BEAEA199A3ABADB1
BABFBEB7B7BAB4B3B9B8B7BEBFC0BBBCBBB9BAC1BFBDBFBABFC1C1B9C0C6C9C6CBCCC8CA
C6C8C7B69D9AA4B3BAC1C4BFBFC1C1C3C6C7C4C8C6C9C7C7C5C9CCC7C8C9C8C6CAC7C7C6
C5C6C4C1C5C6C5C9C5C8CBCDCFCFCDD6CBA8929798999C939B9694909992908E8B8D9AB8
C5CED1D9D8D0C7B9B5BDC3B7AEBAC7C7CFD2D3D3D2D2D1D0D1CDC9C9CACCCBCBC9C7C9C9
CBCCCCCBCCCFCFD2D5D4D7D7D7D8DADCDCE2DEDFD9942B272A292F362F3B3D3330312F34
3130333035362F272A292C2A2C2D33322F38342F34282B2D27272E40516F7F8C979B9C9B
979390909597989B9DA1A3A19F9FA0A3A19F9E9E9F9D9E9FA09E989EA09F9E9D9C999B9C
9898989A9B9B999C
65656263636363666464636563666363646A616063635F5F65626F747D848C8A9194989D
A2A4A5A7A5A9A6A8ABACA9A7A9A7A7A4A4A89F9C98918E857B776F655952494A4E514D50
585A57575E5E5D616866656261686568656463686764636A676361635B68656C6D6C696A
6D6D6C6E706F74706C6F66605D69B6E3D7CFBCB2907F766C777467635E5C67675E686C6C
686D7971646370766F636269767A767672767B7B7977797C7F83847F818B867C7371787A
7977746C666B7388909AA39D9E9B9DA1A49D948F8C8D8E96A5AA9E8F818899A5A9AFAFB1
B1ABADABB1B3AFB2B1B2BBB6B2A7AAB5B8B3AFA9A9ACB7B8B1B1BFBCB6AEABA5959E9FB5
C0BFBEB8B8B4B0B3B2BDC1C1BDBDB7BABABAC1C4BFBCBBBDC3C2BDBABFC5CAC9C8C8C7C7
C9C9CAC3B59695A7B7BEC3BEBDBFBEC4C6C4CACBC8C6CBC9C8CBCCC7CBC9CAC7C7C9C6C7
C4C4C0C3C6C8C9C9CBCECFD0CFD0D2D2BE968F959A9A9A9594989295989397948E89858B
9CB5C2CFD8DBD3D0C6B8BBC1C0B1BBC3C8CFD5D6D3D3D2D1D0D0D0CBC8C9CDCFCBCACAC6
C8CBCCCCC8CCCED2D4D3D6D8D6D8D7DCDDE0E0DEDEAE352A2F2B312E3536332C2F322E36
3533383633302E302E292E2D2A2F353331353637393733281F23262C3C5F748697979C99
979697918D93969AA1A4A0A49F9DA1A1A09D9C9EA09B9C9F9C9B9C9C9D9C9C9C989B9D9C
9C9A9A9A9C9A979B
626261636364626A606667646463646A63646A5F5D5D60635C646A717E80888C939A9A9D
9FA1A5A4A7A9A7A7A6A8A7A4A5ABA6ABA5A49E9D96958F7F7D746A625B564C4A524F5450
57545557605E5F5C656264626462626561666562696B6B626A656564636465686F736B6E
6D6F6F70716D737171726D646668A9DFD3D5C8B6A17B75747374666063585C6360646972
6E7175736B666A71796A5F5B677C7674756869777C7F817D7F828180837C7F8577716D70
78797B776962666F82989B949B99A3A49FA0928D8F91999C9696A3A796939099A8AAB4B3
AEAAADA9AFADAFABA9BFBFBAAFAABABFB7AEB3ADA7B0B5B4B0B8BCB1B6B3B5B2A8939CB1
B6B7BCB9B6B4B3B1B9C0C0BEBDBAB9B5BBBCBDC4BEBCC1C3C5C3C1BDC3C7CCC9C5C5C2C6
CDC4C6CAC5B0A99AA8B2BABBBBBEC3C4C6C6C9CAC9C9CBCDC9C8C9CCCBCACAC8C8C5C5C5
C4C4C2C8C8CCC9CDCFD1D1D4D3D5D3CBAA8F92989B9C9B99999897919697958F908B8483
7F8493ACC4D1D9DBDACCC4B7BFBCBDB6C0C8CED4D6D6D1D2D3D1D0D0CDC9CACCCECDCAC7
C9C7CBCCCCCBCED2D0D0D3D6D8DADADBDEE0E1DCDFBA3F28312D2A2B2C33342D32313336
343737343838322F2C2A2A2D2D30353C3136373535343328251F252834536B7E8C959B9B
989B97918C9096979D9FA0A49F9FA49E9E9E9D9CA0A19B9C9A999A9B9E9C9A9D9E9B9D9D
99969A999B98999A
63636163646465636464646367666264616061605F62615E61646A707983898B97949A9D
A2A2A4A7A9A7A7A9AAA9A7A3A8A9AAA8A5A39F9B94928E837B726A60584F4E4B4F505251
5B55575B605E615F645F6462666665686266696A666B696B64666363646468686A74696D
6C716C746F6C776F73716A6A67678FD4D2D0CEB1938D77776F66655D5D635E6468686165
6E6E6E70726F716E6F767269606B78847571656A7B7E807F76777E81837C768186817B73
717A80857C6D665F707D8D98989FA69FA7A69690929F9D9C8F9197A2B4B2989297A2B3AD
B6ADAAA9AAABAAB0B6BAB5B5B6BCBFBFB2AAAEACAFB6B1B1BFBAB5ADB4B7B5B6AEADA398
A8B0B7B4B5B2B0B6BFC1BEB8BCBDB5B2BEC2BEC0C1C4C5C3C6C4BFBBC6C8C8C8C5C3C5C7
CBC3C7CBC9C6C4AE989FA9B7C4C3C3C8C7CAC8C7C9CACDCCC8C4C8C9CCCACBCAC8C7C7C4
C2C7C6CCCBCACDD1D1D4D3D9D7D9CEBB978F9195999A9B9996989998969498948C8C8686
8077707992B6C7D3DDD7CFC8BEB6BDBFB1BCC6CED1D6D5D4D5D2D2D1D0CBCACDD0CCCACA
C9C8C8C9CDCDCACECFD0D2D5D8DBDADBDDE0E1DEDDCA5A2D2F2A27262F2F32302F2E2E34
3E3638423736353031332F2E35313331322D37343138342C282321222C3A5D7684919D9C
9C9996948F8F929A9A9D9EA1A1A1A29FA1A19F9B9F9FA49C999F9D9B9F9C9D9C9D9A999C
9E9E9E979D989E9B
6363656063625D6565656363646360656161605E655D585C606569707E84878C91959C99
A4A4A2A8A4A8A4A9A5A5A9AAAAACA9A7A9A49E9B96908A7F79736B6058554F4A4F515150
57585B62615E5D65646866626466686C696B636768656D686A676166656A666D6F6E7371
6B6D6F6F74767174746F6D6A646382CFD8CAD0C396928478726C655D5C62646162676461
5E6C706E717279756C717F7D736E6E7E8580766F6671807D7B79787D82847B818C82847D
7A757D7B8375675C5F647B949CA8A2A29E9D9AA0ADA79E959592909CB0B6AEA38F939FAD
ACABADADABABB0BBB8AEB0ADBABDBFBAB1A9ABB0B2B5B3BEBDB1AEB0B6B8B4B1B9BDAB99
A0A9ADB5B0B7BBC1C3BFBEB6B9B5B6BBC1C0BEBCC3C6C7C5C2C5C0C5C3C6C3C3C6C4CAC7
C3C2CACBCBCDC9BAA09A9CB5C5C5C9CCC6CAC9C6C9C8CBCCC8C5C7C9CBCAC8C7C9CACAC9
C7C9C8CDCBCCD3D5D6D2D5DADAD5C19D888D9197979998969899989A94989A94948D8989
7F74716064729DBACDD7DBD5CBBFB2C0B9B1B2C4CAD0D7D9D6D3D3D3D0CFCFCECDCECCCB
CBC9C5C8C8CBCBCBCFD0D4D6D9D7DADBDEE1E3DFDDCD6D272C292A313132333534333534
463131303333302E2D342E362D31373937383936393B34302E23201E25314C637F8D9697
9B9896948C8F8D90959A9FA29FA0A09FA19DA09D9C9B9F9C9A9F9E9B9E9A999B9E9D9D9C
9D9B9A9D9A9A999C
5E5E65606363615E6463676D636262626361625C6160605E5F676C717E84829191979B9D
9EA2A9A7A7A5A6A6AAAAAAA5A5A7A8A8A5A49C969B938C877A6F6C6357544E4A4C504D53
515A5B60615C5C626264666261616A67626662666A677167686764656566676D6F6B6C6B
706D6C7071716F7572706967646377CEDBCBC6C99E947D7F676E5B62615F646467656A68
635E696C71757D7771717679727174737A7E7C776967707A7A7C7F79777B838688838485
7E7F817B837F7A6D5C5B707D9A9FA3A094989FB1B5AD9E8F90949B9C9FA8B4BBAD9D919D
A4ABAEB1ACB3BEBAB0B3AEAEB7BABCB7BAA9B5B3B3B8C0BFB7B5B5BCB9B2AEB8BEB7AEB1
B49DA3A9B1BEC3BDBDC0BEB9B5B6B8C1C3C2C3C4C4C2C7C6C8C6C4C4C1C2C4C0C5C8C7C3
BDC3CBC9CDCBC7BFB8A999A8ADC0C6CACAC8C9C5C5C7CDCCC9C8C8CBC9C9C8CACACCCDCC
CBCBC8CCCDD0D6D4D5D5D8D9D6C2A189858F93969397969999979B9A9C98969695948C8C
847A716559565B77A5C1D3DDD5CFCABFAFB4ACACC0CCD1D6D7D5D6D6D2CFCFD2D4D1CFCD
CCC9C9C8CACACBCCCCD0D4D5D6D7DADBDFE3E2E1DFD17C2730282D32322D33333334363C
3837302F353332312E30302E2A292C3730373E3236383E3029202421242941556B869095
9C9A969692918E8F929B9DA19FA2A3A2A2A09DA0A09D9C9F9E9C9F9D9C9E9D9A9B9E9F9E
9E97999A9C9B9BA1
5F5F5F655E63606263635F65656362656065635F615E5E5D5C6370707C838D8F9293989F
A0A4A8A8A9AAA9A6A8A7A4A5A6A4A4A8A3A29F9D9A948A857A706B65585456494E505454
53585A5C615D605C626366656467686467605F636E6568616766656767666B6B68686A6E
6F706E6D6F71717271706C6B656670B6D9D4C8C7AB9D8677756863646769655F6C6B6967
6A665A606B75787A7874756E777E847D767A7E7F7A7674717C837E7C786D7B8485828584
8D968C828186827E6E61626981939A96959CABB2AFA8A59790A1A29F9BA3A4B5BAAC908F
9CA1ACABB4BEB7B6B1B3B6AFB7B5AEB2B6BCBAB4B6C1C0B3B8BAB7B9B0AFBAC0B5B2B7C1
B5AAA89DABBDBBB4BEC3BDB4B6C0C3C0C2C7CBC6C3C4C7C3C3C3C0BFC5C5C3C3C5C8C4C0
C1C8C9CCCBC8C7C0BFB7BAB6A5AFC1C9CAC5C6C3C4CCCCCCC9CBCCCCCBC6CDCECBCDCDCB
D0CDCCCDD3D5D7D7D4D8D6CDC09E86848694959A96979C969A9D999B9B9A989995919390
857C78665A50444B6194B8C9D2DCD8CFC1B6B0AAAABDCBCFD4D7DCD8D6D4D0D3D2D1D2CD
CFCAC8CACACDCCCDCBCDD0D3D4D6DADCDDE1E2E2E0D38628282529292F37373633383737
3A38293232322A2E2B2D2C2B292A2C2D31353238323633313028242221252D475A778E97
999C9895959091908D969B9FA0A1A2A4A29F9F9E9EA39F9E9E9C9D9DA0A19DA29B9B9B9C
9B9694989A9C9F9B
5F5F605D5E5E6161645E63616764626160665F62625F625F5F666D7077808B8F8F969A9C
A0A5A4A5ACAAAAA6ABA9AAA7A8A1A6A5A2A09D9C91908A7F7B72696354544E4F4A4B4E4E
5658585D595F625F686068605F6364645E6A656563626A6667646160646B6D6A6C6E686E
6D6B6B736D7273706F6E6B6E68636EA0D9D2D4B9B89F8C786F6B5F656A6A68616371696A
64656152566D7373717A786E72808181797975797E8378777A787C7E7977727F888A8482
8687958A85858179766F66626A7889919DA6ACACA3A5ADA6A6A39DA2A09FA8A9A8ADA8B0
A299A1A9BCB8B2B7B4BAB6B3B3ABABACB3BDBDB5C2BEB4B4B8BCB8B7B2B9BFB1B1BCBEBA
B1BAB9A79DA6A9B4C3C3BEBABDC0BCC2C4C8C8C6CAC9C7C2BCBDBFC0C7C3C6C5C7C1BDC2
CACACACDC8C5C5C2BEC3CFCDC2B8B4BEC4C3C6BDC6CECCCBCCCDCDCCCCC4D0CECDCBCFD0
CECFD1CDD0D7D6D7D7D6C7AA908381858D9394979B9797979B9F9B9A9B9B98979594948F
8783786C5F5247393D4973A0BAD0DADAD2CBC4B3ABA9B9C9CCD2D9D9D7D5D5D3D7D1D4D1
D0CDCBC6C5CACCCAC9CBD0D1D4D7DADDDDE2E2E4E2D38E262525282B2C2E2E32373B3A42
3E3334322E322D302D2A2B2C2F292A36322C383531333033382A2B26222639374A678191
9999999B9390918E8F919A9AA1A0A0A2A39F9F9EA09D9F9F9E9F9F9C9D9CA09D9F9D9E9A
9C9C9A9B9CA29C9B
5C5C5F5F645A60625D5F6A606762606161655F6260635D5960636B777C82818D929499A0
A1A7A5A7A6A7A9A6ABAAA8A8A6A8A6A6A4A29D9A91908D7F7B706D635C55484C4E4C5151
5453565B585B5D5F6062616263626767656865646465636562656865676B686C6C676D6E
6C6C6A6D6F71726E72786C69665F6295D9D6CFBCABAA968971665E61636A6E686B676F69
6C6A6D6254606A756F717473767D7A7D817E7E7B727B827B787467767D7E7F7E7E828882
837D7B87838285877B80726C6D64718AA3AAA8A3A1A8ABB2B2A8A6A1A2AAA39E9E9DA9B8
B5A797A5B2B2B6B5B6B4BAB6B1B0AAA7ACB7B2BEC3BBB5BCBFB4ADB3BEBEB2B4BCC0BBB4
BEC0B9AFAAA5A0B3BFC0C2C3C1BEBCC4C9C8C7C6CBC9C7BCBAC0C8C8C6C7C8C3C0BDBFC9
CACACACCC6C5C5C7C4CDD3CECDCAC0BEC1C5C1BFC7C8CCCCCFCDCCCBCAC9CCD0CFCDCFCF
CDD0D2CFD6DAD9DBD2C4A27E787781889094949696999C9A9C9F9C9B9B9A9C9C94968F8D
8988746C636057482F2D3A5784ADC6D5DAD7D0C8BAAEA4AFC1CBD1D5D8D5D6D5D7D5D3D3
D4D0D0C9BEC3C9CCCBCCCDD0D4D6DADADDE2E3EAE5D4922A27262A293338333236393932
3C2B302B2E292F28292B3633312D3331362D2F323B323633382E2C27272B313442577086
959A9F9B989592918C9095999D9D9FA29F9F9F9DA29F9C9D9FA09E9C9F9D9D9C9F9E9B9D
9C9D9C9B9E9F9F9D
5D5D5F59625E62615F5F6361645C615E60635D606B5E636362616D747C85858D91959C9D
9F9FA6A5A9ADA8A8A9A9A8A5A7A9A5A2A39C9D9992958C7E776F685E544F4D4A4D4E5145
51565A5B5E605C6060625F5F636262636065656A65656363666069636C6B676D6F686A6A
6C706F6C706F7176706E6A6369616887D5D7C9C3ADACAB8F6E655C60686764616D6A6F71
6F636C6B6F5C576771717976797A7579797E847F77717A7F817A6F726F797F807E80868A
897F7B7579858689817B73776E676A7A91A0A19FA0A0AFB5AEB1ABABAAA3A49A999AA3AE
B7B5AC9E9FA8B0BAB8B7BAB6B5AEAFB3B1ADB2C0C1BBBAC4BDAFB5C1BEB5B0C2C3BBB8BF
C2B7B3B6B9B9B6ADAEB5C1C1BEBEC6C8C8C5C8C5C7C8C1BEC2C7C8C8C7C5C4BCB9C2C8C9
CAC8C8C6C5C7C9CACACFD2D0D1C8CFCECBC9C7BEC1C3C8C9C7CACBCECDCECECFCDCECECF
CFD0D2D4D6D8D8D7C499716B767E838690949897989B9C979D9D9D99999E9C989A93978F
8A867B716A5B513F342B282C3F6597C2D0DAD9D3CFC0A799A4B6C7CCD8D8D7D5D8D8D7D6
D6D2D0CECAC3C9D2CCCBCCD0D3D4D6D8DCE0E2E7E3D694282A262A292C2E2D3437363F34
3936302E34292B2B2D2F342F2E2C2C27302B2D313130333D373833332E2A2A33354D657C
8E97979C9A939591908C92949A9F9EA19FA19FA0A2A2A09D9E9F9F9D9FA19C9BA19F9D99
9B9B9C9C9DA0A09E
5F5F5C5D59605A5C5D5D606060625D5F6061605E635F595B5D636C737E84848A9194989B
A1A4A4AAA7A5A8A6A7A9A7A7A7A9A9A39F99979A918F878075716C60584D464549474E4F
545059585D5C5D6162646461636561636662646864656468696464636666666A676A686B
6F6C6D706D6B6F736C6E6F6C6C66687CC6D7CFC0BCA2A2826B5D5A615F63636466646D6C
706B6C71726F6059616B74766F74767F7B7B84847E787D7D807F7F746D68727D7F808B8E
918D817571758288827F7371756B676B74889AA39FA3B2AEAFB3B4B6A9A8A09FA3A0A6A9
A9B4B2B1A798A2B1B6BBB5B9B1ACAFB5B2AFB6B8B7B6BCC1B5B2C8C5B9B5BFC3C1B7B6B8
B5B3B9B7B9C4C2B0A3AFB6B9BBC7CACBC8C8C8C8C8C1BFC5C8C5C6C8C4BDBBB8BDC8C9CC
CCC8C8C5C9CBCBCCCDCDCCCBCBCCD0CDD0D1CECAC8CAC5C8C8C7C7C7CDCFCECFCBD1D0CF
D1D2D3D5D7D9D8D1A96C5F6E777C83888F96979A9B9C999A9C9B9D999A9B9C9DA095938D
94898072715C5546322D2925272F4D86B7CBD8DDD9CDC0AC9996ADC6CED5D8D7DAD9DAD8
D4D2D2D1D1D1CED3D0CCCCC8CECFD6D8DCDDE4E8E5D6922C282728272B323032332E3233
31313638352F302D2E333030352A2F2B2E26302E342C312E33383836352D2F2C2F3F5670
83909AA09B99999292908F9293989C9DA3A1A09E9E9E9E9F9C99A09C9F9F9D9C9F9B9E9C
9C9F9E9C9DA0A0A1
5A5A5D5B605B5C6063595D5D5D616060635C63605F5656595F686B6C797E8A8C9594999E
A2A3ABABACA6A7A7AAA8A6A4A5A4A7A4A39C9B96948C84837C736C5D534F494C4D4B494F
524F58555C5B5F5D625E646661636263606867656962666464626568696665666766686E
6B71727173736D747372717A6F6A6970B1D9D2BFB8B28D84725F5E5C64606E6A6567696A
667073776F75726559636F7F706B6D7A80817E7E7E82878579747C777C767273767D8687
8C8B85817975727888897F76716F766F696A8994A0A9ABACB0AFBBB2AFA9A8A49FA8A2A1
A5A3AFB8BAACA1A3B0AFBAB0AFB3B5B3B9B8B7ADAFAEB6B9B4BEC7C1BAC2C5C2BDB1B4BB
B6BBB9BCC4C3BAB0B8BCAFABB4C3C7CBC9C9CBC9C3C2C3C7C7C2C5C6C0BCB9BDC4C9CCCB
C8C9C7C7C7CBCACACDC8C8CDCACDCBCCD0D4D0CED0CED1D0D0CECBCBC9CBCCCACDD0D0CE
D1D5D7D5DBE0D6C689525868787E868E939297979B9997999CA09E9B9D9A9B9B9A949691
908A82766D6A60623B2B26211F272B4371A7C9D3DCDAD2CAB49C94B2C5CCD5DBDDDBDBD8
D7D5D3D1D3D3D2D8D4CFD0CACACED4D6DEDFE6E9E3D3932F2D2D2A292C2F2B2E30303138
3832323C3C3B312F2E2F2B3030322C2F26283132343235303D36373337352F2F33384661
708991999C99958D928F8F8E92959D9CA0A0A19D9D9E9FA19E9F9E9FA19D9DA0A09E9C9A
9F9B9C9E9B9E9F9E
61615C59575F575B5F595F5E605D6365605D5B5D5A554F5C5C63696D7A808A8E96969A9B
A1A6A8A7AAA6A9A6AAA7A8A5A7A8A5A1A29D9A99968A83847871665C514A514D4A50514E
4E4C57575D5B616060666864616D636464646463695F6464636666646163686769686A6B
6B6B6B6F6C707372747974736A6B676DADDDD3C9BCAC92807562615E5D69696A6C656969
6B6A6F767169737A6C5E66767D75696B7884817F7A84838B8179767A8187797068757A80
8184838B887F7D787A83827E726A7074716666829BA8AAAFA7B5B2AEB2B8B4A5ABA2A7A1
A9A4A9A5AFB7B7A697A6A8AEB5BAB7BBBFB7B1AFACACABB0BAC7C4BBBEC3C1BCB1B3B9BB
BDB8BCC2BFBAB7C0C9BFBCB7ADB4BBC3C7CACAC4C0C5C9C4C6C6C8C4BEC2C3C4C7CDCBC9
C6C4C7C8C9CAC9C8C8C7C6CFCCC9CBCCCFD0D2CFCCD0D1D2D0D1D3CECDD0CFCCCDCFD2D4
D1D9DCDAE0DBCFAC694E5A717880888C8D929C9C9E999A999E9E9E9BA09A9A9D9E979694
8B8A837E706A62593F2F2D232422232A395EA3C3D0D6DAD2CBBB9E9BB0C0C7D5DBDBDBDB
D8D7D6D4D3D2D2D5D6D7D4CFC9CAD4D5DFE1E8EAE0CE8E2C292A2D2B2E2B303032313337
382F38313232322F2D2D32333032322E262B2F2F393630393D3B383C323137302E2E3F4D
6A7F8A969D9E9696948C918C8D9498999EA19F9EA19C9F9F9A9B9E9E9DA19FA19DA09E9D
9E9B9D9F9B9F9F9E
5A5A61565E60605D5C5A5E605C5C5F60605E5B5C595B575B5A65706F787F868B9193989C
9FA2A5A6A7AAA7A9A5A4A4A6A2A6A5A4A09D9897928C877C786D6961554F5348484B4A4C
45505754535C615B5E6163616466636060616368635F6664626568646463666666696766
6B6F67686E707172737175786963666998DBD5CDC3A2998A756760636264656769686766
6B6D6D6B74767B71716969707F79737368727D7D808A808787817E77727A7C7F7A6E6F7A
7F7F878A888886807A777C8579746B6D6F6B5A66849EA8A4AFAEA4AFB4BAB8AFA7ABA9A6
ADA4A3A198A8BDB2A5AB9CA4B2B1BBC3BBB3B5B8B3A9A5B1C2BEBBBFC3C6BEB4B9C4C2B9
B7BAC6BFB8B7C5C8C4C2C2C7C1B1AABBC1C6C5BDC3CAC7C7CAC8C5C2C3C7C5C8CBCDCAC8
C8C4C9CBCACAC8C3C4C9C8C9C8C4CACECDCFD3CCC8D0D0CFD2D1D2CFD2D1D0D0D1CFD7D7
DBE0DFDCDFD3BB7C4C525C6F7A81888A8E989A9E9D9C9F989F9E9F9E9E9E9A9BA099979B
938B89817668605046302B242224222326305295BCC9D4DAD8CEC1AB989AB8CAD3DADDDB
D9D8D7D6D4D4D3D8D9D8D9D5D6D1D6DBDEE3E9E9DFCB732C2C2A2C28302C2E372F2E3231
34303B343B35343831342F322E332B2D2C2A242B372D30323939393B3A383833382E3845
5870868A9B9599979590918E8B8F9699A09DA09EA2A2A39F9FA0A0A49FA1A29E9FA0A0A2
9D9D9E9F9E9E9A9C
5A5A5F585D5B5864615B5E615D5B66615F625C575B5C59535A616D747984898D95929A9B
A1A1A2A5A7A9A8A8A6A4A7A6A2A2A0A4A19E9B99918C8382766D665B575245474A454C4A
494D5057585E645F5A5C625F636362606364666166656463626464636561646A6A6A6C69
656B6C6A7072726D72726C786968636782CBD8D1C2B79787756A65676562616A6B686A71
69696F6C6F797F776C6E6C737074737E746B6E7781857C8089848785766F747D837F7463
6F76838986828A8780827F7B827E7A716A707266698899A5ABA0A4A9B4B8BDACB1AFACAB
A4A6A59CA0A7A6B0BDC3ACA5A6AFBBBAB6B1B7B6ADA7ABB7BAB6BBC0C2C2BBB4BFC2C1B9
BFC1C1BAB6C4CAC2C2C5C3C3C1B8B2BCB6B9BCBDC8C8C7CBCAC7C9C8C9C3C6CACDCCCDCA
C6C4C7CAC9C7C6C2C2CBC9C6C6C4CDCACCD0CDCBCACCCECFCFCECED1D1D3D2CDCED1D8D8
DFDFDFDEDBC9985A495661717B7F848A8F8D9DA4A1989B9B9B9E9E9A9D9E9A9A9A949691
958B897D796F5A5844332B2B26242028242A304881B6CCD4D9D6D0C9B4969ABBCDD4D7DD
DCDCD9D9D9D8D7D8D8D6D4D9DADADDDCDDE6EAE9DFC55F2C2A2D25272C2B2F34353C343B
40333437372E323A33312C32323C36353029282C31313432323A3536393832322F2E393D
4768798A9196989695928E908A8A90969F9DA09D9EA1A49E9E9F9FA1A0A0A19E9C9CA09B
A19A9D9F9F9EA09B
5A5A55585B58555B5B5B5B5A5A5F5E5A60605F555A5A5A585D6268757E7F858A9496999C
A2A5A2A5A9A4AAA9A8A8A7A5A3A6A3A0A19D9D98938C85837C756559564D4A424449474B
5150505A5A5D5F5F5B5E5E66626268636263686261636063636468635F6665666A656D69
6769696A697173726F6F7068686865677BACD5D2C0B2A786776A636A6265656069616970
6C65676A6F777E736D6B6C77766E6B797C786B706E807F7E8583838E817C756E7C838071
6B5D7581858E888B8D8489837C8082807A726F6E6E6B7895A1A39FA7ACBAB8B4B4B6B3AD
A9A09FA2A7A3A6B3B8C1BFB4A6A2ADAEB4B9BAB5ABB2BAB4B4BABEBDBFBDB8BFBEBFBAC4
C4C2B9B5BFC9C5C2C2C5C6C0BEBEC5C1BAB7B6B6C1C5CBCBC7C9C9CECCC7C9C9CDCACBCE
CAC8C8C9C7C5C2C7CACCC6C5C6C7CFCCD0CFCBCACECACCD0CCCBCACBD3D3D0CECED5D8DD
E2E1DEDDD3B26B4D4B5668707C828B908B929AA19B96989D9C9A9E9C989B999899999699
908E86827B6F695A48382B27272821242224242C446CB2C7D1D6D7D6CDBBA19DB8CFD5D4
D9DADCDBD8DADADADBD9D8DCDEDCDDDEE2EAE9E7DFB642272B2A2D2C2C292D352E2F3136
3233393C462E2D303037322B2D33353A3D3A30302D392E3034353435343631372D303532
45586881888E98969A978E918A898B94959C9EA1A1A3A1A4A2A0A1A1A2A09F9F9DA0A19E
9D9F9A9D9E9F9C9D
57575559575D5B595E5D5F5E5E5F5D625F5F5A58585B54595A626D737A84868D9096999D
A1A2A3A8A4A9AAA5A5A2A7A3A3A6A2A4A19C9D9B908F84817E746A5D584E4442494A4C4E
54525457575E5A5D5B63606261616260616162616561626563616161686064676D676C66
6A696A6B6E6D7471736E6E6C706A62636CA0D7D0C3ADABA08172666769626C65646B6D72
6F726B636C767674716C7175757772757778797D71717B8A837D7E838A86807A78778586
7E73657285868D8A8C838A87817C787C857B716A6F6D66768E9AA6A6AEB0AFB6B5BABBBB
ACA2A2A3A3ACB4B0B2B2B7B5B9ACA1A0AAB1B1B3B5B8BCB1B7BFBABBBCBBBEC2BBBABDC6
BDC2BDBFC9C3BFC2C4C5C3B9BDC9C4BEBDC2BBB6B8BCC1C6C8CACDD0C9C9C9CACBC9CBD1
D0CAC9C9C4C3C7CFCFCCC7C1C7CBCCCDCECFCACDCDCBCDCCC9C8C8CBCECFD0D0D5D9DBE0
E1E0DDD9BE804D494B546A7280838891999B979A99999D999E99999F9C9B9B99999B9A96
938F867F776B685E554430332C2B2429202424252832619CBCCED4DBD9D3C6ABA0B0CAD2
D3D9DED9DDDCDEE0DFDEDCDDDDDFE1E2E5EAEAE5DBA034282B2B28292D2F2C3231303132
353B3636363A32332E2D2A2F322F392E36332F322F2C2F2E3B343C3F353A2D352D302F33
32455771848B95999999939291858C9292989B9EA29F9EA29FA1A0A2A09FA5A1A0A0A0A0
9E9FA09C9AA09D9D
5757595E59555B5A5A5F5E5F575C5A5E5C5D5E5D575950545B646E727C86868E91959AA0
9FA0A3A5A6A7A2A7A4A5A3A3A3A2A4A39F9F9A958E8E857879726B5D4F4E4C464549494E
4C4F53595A5C5B5B5F5E6363606263635F626364655D60626766626665606C676867656E
6B6A6D6A6F6F6E6F6F736C6B6F6866636B92D8D8C4B3AA9C847269616068696B6B66696D
716F6F686773747671717A6F6D747D7B7072777E7A767385847C7B7F868681888183798C
8B86776E6A7685898986859087817B78868B7E766B6D6B6A708AA2ACAFA6ADAAB0B3C0BD
AFA9A5A8B1BAB5AFACA8ADAFB8BFB79E9BA2A9ABBEBEBCBEBDBDB3B4B6C0BFBBB5BCC2C4
C4C4BFC1C4C4C3C5C5BFBDC0C5C7BEBDC3C3C0C1C1BAB4BFC5C6CBCCCAC9CAC8CACCCAD0
CFC9C8C8C8CBCFCFCCCBC7C6CACDCDCFCECECFD1CECFCECBCAC9CBCCCCCED1D3D9D7DDE4
E1DFDBCDA05E3F42585A6D747B838792929695959B9796969C999D9C989A97999A999997
93938983796F645D5343342D2E262A27283325222428314D8AB9CCD4DDDDD5CDB9A3A7C4
D1D3D7DADDDEDFE2E0DFE0DFE1E2E4E5EAEAE8E4D47E2A292F292C322E2B2C31302F3439
393437373A363438333631302E2E2E3532303832302C333431383B3334313E36322D2B2A
3D434B677582909898949794928F8C8A8E92989D9FA2A3A3A3A3A4A0A09D9FA09FA0A09E
A09B9F9F9C9C9D9F
5F5F57595C5A58565A575A5B5A5C5A59585A595655565558565F68727D85858B91979C9E
A1A3A4A5A3A3A3A5A3A2A3A4A3A3A7A6A59F99948D8D86857A74685F5451454A454E4951
4E5A53555A545E5B5F5E6060666161625F5D605D625F5E5A625E65646564686C696A6E6B
6C6A6A686A6A6C746A6E6F736B6866676D79C3DACCB6A78E7D6F68645E616B666A6B6972
71686F746B6B6D78747172757475757973777379807B737C827B808384827B858687867F
82848A8178737986868888888A8F867D797C8483786E656B697087A09FABA9A4A6AEBBBB
BDB7A6B6BFB7B0AAACB1B2B3B4B4B3B0B09FA1ACB8B9BAC3C1BDB7B6BFBCB3B2B9C2C3C1
C6C3C0C0C2C4C6C7C0BBC1C6C7C0C1C4C1C5C8C5C6C2BCBEBBC2C4C9C7C8C9C8CCCCCFCE
D0C9C9CBCFCFCDCECACACACECDCFD0CFCCCCCFD0D2D0CFCBCACFD2D2CFD3D3D6D8D9E0E2
E3DFD8BF7342434E56626A718086848E96939597999796989D9B999798979E9C98969696
958C8A81776D625C4E433A312E2B2B29282722222826292B4078B1C7D2DADFDAD1C4ABB1
C0CFD3D0D7DDE0E2E2E3E0E4E4E5E7E8E7E6E3DFBE4F222A2D292E272C362F2C2F3B373C
3D39313431353D3733393131322E333438333832302E2D3A353D2E38373636363C2C3127
2B2B3D4C6A798E939B989896908E8C8D8C8E96999EA0A9A0A3A3A3A29FA19FA2A19D9F9F
9C9E9D9E9EA19B9C
61615B595A575D5D5B59545855585A595B5A585655525A50546468707E84868D94999A9E
A0A2A3A6A1A7A3A4A7A3A1A39FA4A4A1A0A09997918F888277706C61534F46444B4B5054
575256585C56585D615C605A62625E615E62635E615E605F6562666165626966656A6769
69696C686C6A6F706F6B6D6C6D656464696CA3DDD3BD9B93796D6A60666A63646B696967
736E6B6A727376706D75707073797570707E80766D7A7A7D7E7C8188858580808599898C
88798A8A88817E727F8C8B8A8A8B888B7F716B70797C6F6161686C7D90A7A8A1A3ACB6B8
B9B7ADBBC8B8AFADB2B2B5B0ADA8AFB7C0B8B4A8ABAFBBC0C1BCBBC1BBB5B5BDC0BEBFC6
C5C4BEC3C1C3C4BFBBC4CDC7C4BFC1C2C7C6C7C4C6C7CBC8BEBBBCC1C2C6C9CBD0CFCDCE
CFC7C9CFD1CFD0CBC7CACACDCECFD2CDCED3D1D2CFD0D2CCCFD3D1D1D3D4D5D3DAE0E3E1
E1DCCE9E4E39424B535D6F7A7C828B8E929195959699999B9A9C9B98999B9B9B999C9B98
918E8983776F65634F4039332E2B292B2B252B24242627232D356BA3C5CFDAE0DAD1CBBF
B3BACACFCED6D8DDE1E2E4E4E5E9E8E6E3DCDCD79F302A28282D2C322C2F2E3033363C3E
3436353136323D373E39363A3B323333333037343B353030332F3A373439333735302D27
292A2E44576D808A949994949190918A8B8C9094999FA79FA7A3A8A2A0A1A09F9E9CA19E
9C9F9B9A9EA09FA0
5656585958565D5D5A5B5B5A595D5C5E5C625D54544F565156606B7579828C8B92999A9B
A1A2A5A6A5A6A4A0A6A4A6A4A3A4A1A29FA19798908C8881787367615C504642434A504F
5354585B5A5558585B605E5D5F5F5E615B5F615F5F615E5F6462655F66696D686768656B
676A6A6F696B6D6C6F6C70706A67656164638BD7D8C9A5927B6D6660676E696664676D6D
6E6E726C70787C71676F6C757177746F69757B7A746E697A847C827E7F89818488948E8C
857E7E8291918780767C838B878A87918A7D786E6F797B71726E7371768A999EABAEB3B1
B1ACAFC0C9C1BABAB1B9ACAAAAABB0B2B9C1C7BCADAFB0B9B9BBC5C3B6B5C1BEBBBCC5C6
C3C4C4C4C7C8C4B9BBC8CBC5C5C1C2C4C8C6C6C2C6CECCC9C6C3C0BFC0C2C4CDD0CED1CD
C9CACFD0D0CEC8C3C8CCCCD0CFCECFCED1D2D0D1CED2D2D1D3D1D2CFD3D5D6D6DEE4DEE0
E0D8C378403D494C59616E767F89889295989A969697979A9D9A9B9A9A9C9C97979C9596
978E887F796E6B6156493B322A2F292E282927252524272125282E4F97C0CED9DBDCD5D1
C9B7B6BFC7CED0D2D5DBDFDFE1E1E1E1DAD3D4C87026262A302C2D28312F2F3031323437
37373437303341414D37332C3334313536343636383335323030353744393C4139362A31
2A2C2D34455D76849094979898938F8C8D8A8B8F9A9D9DA1A3A7A9A5A09FA19FA0A09EA0
9B9D9D9D9F9D9F9B
5858585C5B5E58585F555F585659565B555F5A57535858545964696F79818C9090999E9B
A2A3A4A5A6A8A4A6A1A8A4A1A2A3A3A5A3A09698928C877F7A746D6260544846474D4F50
4F55585C555B585D5A5F6258645D5D5D6162605F5E635F61666668605E65676365686A6E
6A6C706D6E7277716E716E726E6D68656C6279BED9CAB79C756B5D64676D656A616C6A69
6E686C71767378756F716979766C6B7078766E797B7975727F8485848181878B868F8586
888988868C8D8D857E7E7B8286888C8C8E8B877D6E71787C7E787171706F7E93AEABB2AE
A5AAB0C6C7C1C1BDBBB2ADA8AFB0ACB5BDBDC6C2C2BEAAA6ABB5BBB8B7C5C0B8B9C2BFC0
C1C4C5C6C9CAC4BEC5CAC5C3C7C7C6C9C3C3C1C5CCCCCDCBC9C3C7CCC5BEBCC5CBCDD0CA
C8D0D5D2CFC8C5C8CBCDD0CFD0CFCFD2D3D1CDC8D0D0D4D2D0CDD2D5D5D7D7DBE0E2DEE0
E0DAAE54353F47515B68717B81878A909196989897999E989B9B979B9B9A9C9E98989B9B
938C8C7E7F6F6C6752473A2F322E2D2F2F2D2E27282A28263326272D4685BCD3D5DCDEDB
D5CFC4BBB8C1CDD0D0D1D5D8D8D6D9D8DADAD2B850222325282F2B312E3132342A313935
3E413D343A38393E2E31373036342F3D35393737393C3434303035333C36453E352E2B27
252A2D2D3E5869788A9194999695918F8F8B878D92999C9CA1A2A7A19FA19FA1A1A0A2A0
9E9E9D9D9F9D9DA0
5C5C6056585E58585C5A575854565B5D54565354555554555A626A737F808A8F95989E9C
A49EA1A4A9A6A1A3A6A5A1A0A1A2A19FA4A19A95938D8A807C7970665A5250494A515250
5053575C5C5E5D5D5B5F606060636361605E5F5C626063615F6061656866636867676B71
6B6D6F6F6B7070776A7070706F6D6D6C6B646C9FD3CFBFA17C6A5F616969656B6867656B
636C697276717175726F6B6C706F696670797A716E7C80797C7D7D8786818187888A8980
8283908D91908E8F8A88857F81888A8F8D868E8D836E646C7D7F787270716C7794A4B0A9
9D9FB5C2C0C2BEC1BCAFAFB9B4AFAFBFC5BCC2C1C6C5B5A49DA6ADACBCC2BBBDC1C1C1C0
C5C5C6C7CAC4C0C6CBCAC4C1C1CAC8CAC4C4CBCCCBCBCCCBC7C5CECCC6C6C6C6C2C5C6C7
CBD3D2CFCCC6C6CDCDD0D0D0CCD1D4D1D4CFC7C8CCD2D3D1D0D1D2D5D7D7DCDFE2E2E2E0
DED394433A414E53596B777C82898B929494979797979B969A98979B9898999E95979999
978B87807B73695E52493436302F312B2D31292C2B2728242523222732417CB8D0D2D8E1
E1D5D6D0C4B9BDC3CDD1D4D7D8D5D8DCDDDDCA943F2A2A282B2C2E2A2B2A2D2E2A2F2C34
3A3B3331363636333532313533383830313636343836312C352E373136353C382F2E2B28
25273237384E586C7E8B909996949290918B89878E97999F9FA2A3A4A1A4A39FA09C9FA0
A19B9F9FA099A0A1
5A5A61635B585B5B5E5A5A5C5657595557545656535553575B666B7682838B909496979C
9FA1A5A4A6A6A5A2A4A0A5A1A6A0A4A8A2A49A94938A8D807E7C6D685E585346504B5252
535B5D5E5960605E5E5C5B6162665F686C626364696265625E62656A69697871706A6E6C
6B69686F6B716E6F6F74726F6F71726C6B6A6A84C5D3C2A69773656264706F6A64686A6A
6D6E6D736D6770746F73766D696C6C6C64707D7B7573757F807E777C86847A8281878980
81818384908E8A8883898C8D827F768E8B898A908E7E7D746E86807E79746D6B72869B9F
A4ABB9B2B9BDBDC2B6B0BAC3B4B3B4BEBEBDBDBEBFBFB7B2B4A8A2A9B6B5BAC5BEBEC2C3
C3C6C9C5C4C1C3CBC9C7C5BEC3CCCACBC5CCCECDCCC8CBC6C9CACDC8C6CDCFCBC8C4C5C4
C7CBCBC9C8CCCBCBCDD0D0CDCCD2D5D3D1CCCACAD1D5D5CFD0D3D5D6D6D9E1E2E1E3E2DF
DFC4683335434A5B5E6B6D7D838A8D8E93979896949797939B9A999C9B9899999898999B
948C8E808177635F554839353328292D2E2D2C2B2E2D26222623242326324971AFC7CDD3
DAE1DBD8D3CFCDC3C2C6CDD3D9D7D9D9D8CFB071462F2A2B2C2C332A2A3843372A33333D
3B3A36353735333438353A3E4342383432323B38353A332E312E2D333632363C37373130
2C2B2B2E373B4C5B7381889797969593918E8B888990929B989FA1A2A3A1A3A09DA2A19E
9E9FA09C9D9E9F9F
61615A615A5D585E5E595B5A5B5E5B5C5956595C554F51575A636974818B919197969A9D
A0A3A2A2A4A6A3A4A8A0A6A3A5A3A5A0A4A49A9790928A7F7A746E655A514F4E4A4C5054
5758565E605D5D635A5C615D5E616165656064666D6762656964676D67676E6F6E6B6E66
706B6D726D716F76747475726F6C6C6B70666C79B4D5C8AD8C78616368726A6B6863676A
6A69736E6C6A6F726F727370706D6C78776E767F7F757675807D7D8080837F8889848689
8D89858382878E868A7C8291888781898F8889928B8F91877C7C7A807D7D6E68676C7B90
AAB8B6B2B6B9C0BBB6BAC1BCB7C0BEBEB1BBBDBFBBB7B9C2C4B8B0B1ACADB8BBBEBFC7C7
C8CAC6C3C3C4CAC8C3C2BEBDC7CACCC8CACDD0CED0CDC8C9C8CDCBCCCCCCCBCAC9CDCEC8
C5C7C0C0C6CDCDCCCDD0D0D2D2D5D3CFCCCED1CCD1D3D3D2D2D5D6D3D4DDE0DFE1E3E0E1
DDB258363F434B535F69707E82858991919A9996959894979C9B979B9A96979C989B9C97
948C87817E76675D523F3F322B2F2F2D302D27302B292C26282923282E2E3E4E699BC0CB
C9D3D9DEDAD6D5D5CFC9BFB9C6CBD2CCC1A9938159402F2E2D2E2A2A2C3130322E293131
363832383438393637383A40423B3A37313C393534302E36302C322F303339383C393230
2D2E2F2C2C2B374C6172858F939C9797908C87898A8A8D969B9DA4A1A1A1A1A1A3A19F9E
A1A09E9DA09D9EA1
5858645D575E5D575D5D60625E5B605D5C5D575D525458565C6369757E868D8C92979A9E
9FA2A6A5A8A6A4A6A4A5A5A2A4A3A8A3A4A19A9D8F8C877D77736E5F5B50514947515551
575858595965605F605E615E5B6164636262636B6A676365666163626969686E706B686C
6D70726F6C6D74757473786F706D716F6F6B6F718FCCCEB690726465676A6A676B6B696C
6E67706B687173716A6E746F717970707A7675767A7A786F747884857D7B7D7E86878684
94938989837C7F8890847C83878C8D8D848787959289808C87867A7580847B6B6B75677B
90A6AEBCB4B6B1B1B8C4C1B6C4CAC5B6B2B9B9B8B6B1BFC3BEB7C1C2B5AEA5AEBBC2C5C7
CCC4C1C0CAC9C8C3C0C1C0CAC7C7C6C9CDCCCDCECDCFCFCBC5C6CBD3CDCECCC9D0D2CFCB
CCCBBFBDC2C7C9CACBCDCFD6D4D3D1CECFCCCFCED3D4D3D6D5D4D4D3D7DEDFDFE1E4E4DE
C7893E363E434B59616E768080888790949899959496989699989A969D979B9F9C9BA097
908D85817D716C6352443E38332D2C29282F302A2C26312A252825282D35434F566586A7
C3C3C9D2DADADBD9D0C3AA9CABB3C6C5AB959289725C362C2B27272B2F2D2B3B3435332F
373630383A363732312E373438393D38342F3930313B3834362D2F2F3737353D34313732
3235312E26282D3C50667B878F969796918D8A8B8688868E939A9DA19F9DA3A1A39FA0A2
9F999BA09EA1A2A0
5E5E5D5B5B595C5D615A585D5D5B5A5E5E5D5859575B5D565B656B717D848C8C9295979E
9EA0A1A5A5A5A6A6A5A3A5A0A5A0A2A9A5A29B9A928A88807B736A635C514E484A50514F
595B525556615F5E6162646260616362676363646869656B65666566656A666D6D6F6E73
6D6E6C6C716F6F71726C7372746F6C6C6B686A6F77ABCFBFA475626B6162656867686D6D
6C6F6B6E706D6D7267676E747273757178827E7A7B7774817B78767C7F8077787F878587
8B8B918C92877D7A8A888083828286938C858488908F83868789837A778585786F6C6F72
6E7F9DAEB7AEA3ADBCC2B7C0CBC8C0BABDC2B4B3B5B7C2BCBCC3C6C2BDB8B3B2ABB4BFC6
C7C3C0C6CBC5C3BBC0C5C8C9C6C3C3CED0CCCECBCBCCCFC5C2C9D1D1CBC9C6C9CECCCBCC
CFCBC6CBC7C8C4C7C5CCD2D3D1CECED2CDCCCAD2D4D2D4D5D6D6D3D8DEDFDFE1E4E1DDCD
A261393845475059626F7C8082878B8D93979C969A9A97989A9B99999B9A989B9A999994
918C88847B706C5F534C413135302D302A2A332D2C2A29262927282E3C43505B5F676E7C
93ACB2B9C1C4C8C8BDA28A8D8F8EA5ACA292969388714A302B2A2F312C2A36332C2C2E30
32383B393C40363231303B35353A38353631383431303A32353A322D2F353837333B3939
34322F292A2323303B5C687D8E92999595948D918882868D8D969C9EA0A1A4A0A2A3A3A1
A0A3A3A1A0A19DA1
5C5C595F5B5A5C5D61585A5A595B605F595B5756525A58545F656F7681858F9596989FA0
A2A0A2A3A5A4A6A6A4A9A1A2A2A2A3A6A2A09A9692928E7E7E756B6555574C4E4C4D5058
575356585B615F5B5F60626066616266656564626663666663636564686067656D6E6B71
70706E70737271727570747673777573716B6A707093C6C7A97F68626967647275626669
6B6B6C6B6B71756B6B776C74737470707877777A79737B7577807B7684818484797A8483
8A8C889094968C7C7C8389878E85748597928E888B8F948C7D7E8488827C83837B716772
706D7896AEA7ADB0B9B5B6C4C9C6BFBCC0BFB3BABCBDB6BAC5C3C2BEC0C4C6BFB0ABB8BE
C0BFC5C6C7C5C5C0C7CACAC9C5C8CBCDCBCBCECBCDD0CEC0CAD2D1CEC7C7CCCFCDC9CBCE
CBCACECDCCCBCCCCCACCCDCAC9CBCECFCCCED2D6D4D5D5DAD9D7D6DCDFE0E2E4E1DFCDA5
6E49383F484B5355626D797984888C8F92929598969A97979D9C9A9C9F999C999B999694
8F8F83827D6F695B54473A37302E2C30322F282C28252829282A3437444E5C626B72777E
7F848D989E9C9B9E948C858A8C8C90959A919796927F6842312B2C28292C30282A2E3230
32342F333F3C383133343836383A362F35322B3436363A38393A2F2A332F2E3637383C3B
3131302D2621282E32455C73818D94979695908F918C87898A969B9E9F9E9DA0A6A3A2A2
9F9FA0A0A2A2A2A1
59595859585A60655A5C60605B5B5D5A595B5958565856545F6570797A858D9094999F9D
A0A0A5A4A8A6A4A7A5A3A4A2A6A3A3A7A39E9C96938E857F787069615E584E4546505654
53575A59595E5B5E6464606766616462616561646A64656165616864676266656C6B696C
6A6C6E717573766E76747373757276736F6F6F736D80BAC7A88D6F635A686A6D6A736D64
6C746E72686C777169726E736F74706D6E727276727D7B7A727B807F7E7A7984827C7B7B
8889868C8A8D968C7F7D7A838A91867D838D938B8687909085827B898C7E7B7479837478
747D6F7887A3ADB6B1ADBFC7C0BABDBCC3B9B3C7C2B8B5C1C1BCC0C0C1C7C3BAB4C3C2B3
B6B6C1C0C2C2C5C9C7C9CBC3C6CDD1CACACCCECED1D3CAC4D3D2CEC7C0CCD2D0CCCFCFCD
CDCED0CDCDCED0CFD0CECDC7C7CACBC5CBCBD1D0D3D5D6DAD5D7D9DDDEE0E2DFDED1A57B
615138464B4C53585E6E767C81878D8F91979A989A9D99979BA29B999C979D9999989895
908A87817B71695D57413A322F2E2D2E2C2E2F292C26292C2E2E35474E59616974787C83
86898E8E8E8B8A8B8A8A868E908B8D909593959894897960382D292A2B2F2B2D312B312D
35313235393731302D3135353233363A312F302D2F363335393A3532362C2D352F37363B
383238312E28292F39394C667A869395989996938F928A86818F939A9C9BA1A1A4A49FA5
9E9FA2A2A2A6A3A2
5E5E5A575D5D5C59615B5E5E585A5458595F5B5A59595A576465727881828C8E95979D9C
A0A0A1A4A7A6A4A3A4A4A4A3A3A6A3A0A3A19B968E8C86847A706F6460594C504C4F5350
58585C5C5F5C595F616067616560606665656265666366626363646067656A656A65696B
6B6E6D6E76737376787371746D6F73747771716E727399C6AA95766463636367686D7165
68707374706D7270706C71736D7179756B6F76757272717F787A7A80837D6C7581848481
8589838A908B9498908A8576748B948E857F909690898985918E817D868A8A7A76808384
827B797C788BA1AEADB6C5BFB8B5B4BFBFB8BEC8C3BDC3C6BCBBC1C1C5BEB8B4C0C8C1BD
BBAFB9B4B9BBC3C6C7C9C7C5CACDCACECECECDCDCEC7C7CED4D4D2C6BAD2CECCD2D2CDCB
CDD1D2D1CCCECDCDD0CDCDCDCCCECFCBC8CACECFD1D6D8D8D7D5DFDCDADFDEDFE0C37155
5A574742474F5762696D747C8086908E9394989A999B9A9A9A999B9C9A979D9C98959595
938988867A726B5D54433C362B2B2E2C2A2D29242724252A3037424F59636F767C7D8087
888B8E9191908B878B89888A8D8E8F94949496979B9B86734C32292F282C2B2B2A292B2C
3B342F32323B333837353A383B3136323F322F293033343D393A3D35323032353436343F
3D3B36303628272C2E364E5769768892949A9593928F8E8980838D93979C9FA0A3A2A0A2
A4A1A39DA3A7A4A5
58585C5459615C635B5F555D5A5C605F5C5E595B5A5C5959616772768184898F9295A29A
9B9FA2A4A3A5A0A2A3A2A7A29EA1A2A3A09B9C96908D888277716A6159544D4C4D4B4B54
5958605E5B5B605F5F61605E635D626A6568636566666560626164686566656765686B69
6D6D6B70756D72717673727870707371726F716B6F7387BDB8907867656869696B6D6B65
706A6F73726A72746C736C717472727276736E6E71706D707B7B7C7884807C7079828C91
8A847E848F91909092919082757587968F8687939A8E8889909092877B83887F79758089
887E767E7E817D8EA3BDC3BDBAADB6B4BABDC7C8BCCACAC3BCBDC4C5C2BAB6C4C5C1BCBF
C2C1C1B1ACB6BCC3C5C5C7CCCFD0CCCFCFC9CDCEC9C5C9CFCFD2CFC5C5D0CBCAD1CECACE
D0D1D1D4CFCECCCFCECECFCFCDCFD1CDCACDD4D4D3D5D5D6D9D6DDDAD5DAD9D9D7B1573F
3C4142434C525A5D636D767F81878C8E9696979A9A999A999C999B9C9B9A9999999B9596
938D89817E746B5E52413B322F2D312D2D2F27302A282E2C2F4248545A6D76767E82838C
8A8F8F96938C8C898C8A8B8E8E8B8D95919495989C999481684336292B302D2C2D2E2A31
2B28312E3536313B3834323B393336313732362E342E34313536373332302A3130363634
3B37332F2E342D2B2E3A3C4955697C868D999D978F948C8A8585838C9699A0A1A1A2A2A3
A3A3A3A4A3A6A3A5
54545453575B5A5E5E5D5F605C615F5F5E5E5A5D565C5A61666970748288888E92979C9C
A0A4A4A4A3A3A3A4A8A2ACA4A0A0A4A49F9F9B95938D8A8577726B5F5757514B4F4A5053
5754595D625E61605F5C5E66666061646566686062635F6364605D6565646668676C6A69
6C6D70706F756F6E72707778777371777B6D757571727DB2C48D7D6D65646A66686C6864
6A696C6F7170717271746D6F706B70726A73716E6B7474726B7A7D7D767884767A7C7D85
8889837B858F8D8E90868C93848281848C928F8E8E938E8F8C8B908885847E8C8181737C
89857F797B817B778BABB6BDBBB1AEB0B0C3C5C2C4CEC8C1C0C1C3C0B9BEC6C7BDB5B7BA
C2C8C7C0B3BDBBBBBCBEC4CCCACACDD0CDCCCDCAC2C8CFD3D0CEC9C6CCD0CAC9D0CBC8CC
CFCFD0D5CECFCDD6D4D3D1D2D1D0CFCDCBCFD9DAD7D8D8D7DAD8DDDDD3DCDEDAC589453C
424044484F5258616B707A8384878E9193939A9A9A9B999A9A9B9E999A979A9B989A9397
908F87827E736A5E554338302A2D293033262C262A282C314049555E5F73777E8388888E
8E919593938E8D8F8C888A8D8C8B8E919297949B98989985765737272E2C2C29292C2C28
2937292E34363639323534373F40343F3737332E2C2C2E2B343F3A3833382B2E30332D3D
343530303136302D34373A3B455C6F7A8995959698908C8A87868888909599A2A1A1A4A6
A2A4A5A6A3A6A2A3
55555655505E5B5E5F5C605E595C5D595E5B565A57575E5E5F63757D8184889093939B9F
9CA4A2A6A7A7A7A1A6A3A6A2A2A1A39F9E9D9897918D8580796E685C5E5A4D4C4F484B52
525D5D5E615B615F6361655D635F68646B69686464606362656262646C6462676768726B
6C6F6D6C736F6F73757477747979767A77756F6F7373728FBC9A7C7266655E6E6A66626B
6C636B706F73737573766C6A746F6B7370727478746C6D777378777D7776787E8A847E7C
85908F8A85878E96908E868C928E8985868E958F90898694928E818289898584878A8779
838B888C82818284818390AEB0B3B2B4B7C4C0C3C9CAC7C6C6C8C1B7B9C5C7C2BCBABABD
C5C3C3BFBEC7C4C0BBBBC2C7C7CED1CECDCECDC3C8D1D2D0CDC6C6CFD3CDCDD2D2CECDCB
D0CBD0D0CBCBCAD3D0D3D0D6D1D2D1CFD1D3DAD7D6D7D6D8D3D2D9DAD7DCE2D6A75B3B39
3C42464C50565F606D72797F85858A9193999696979D999799979B9C99999A999A9C9B94
928C89847D766C5F5B433B2D2D2E292C2B2B252B272D3137414B5B65727B7B80858F8E8F
919393908F908F8C90868B8B8B8E919491939495979B9C928673542F2A2C2B2D282B322B
2E342E3135313B35343433373934343B37363134322E2C2D343D3C3D2F312C2D2B293134
323330324536322E32342E3B3D4C6777818D92979692918D918E8A88899195999EA1A9A7
A9A0A6A6A4A3A1A4
55555C585F5E5B5D5E5D5A5E605A615E595A5F5D5956576261646D777F878C9491969E9F
9FA19FA3A6A7A7A9A5A8A6A3A5A5A4A19F9D9C95928C86837A726C5E64544D4A4D4E5152
5959595F5F615C605F60605C5E616A6567656165676066656264676762606B6567686869
6B716D686C717175757277747576797A787476757572747C939A7A7372706A5F67646466
6A676C757C7476776F726F6F717872757976796F756F73727B78726E7A787F7F7F868B7C
777E888E8B85889396948D8E88878B898E878D93918E83868E8E8C83868C8A8C848A8E86
858B8A8C91877D7E8A807F899CA9B4B6C4C2C0C4C8C4C9C6C9C5BCBCC4C4C0BEBCBDC2C3
C2BEBDBBC3C8C5C7C3C3C1BCC3CACCCCCED0C8C7D0D0D1CBC6C3CDD7CECDCED3CDCECECF
D2CCD3D0CDC9C8CDCED0D0D3CFCECCCED6D4D6D5D4D0D2D6D3D3D7E0DFDED6B5723E3536
3F46474C545A59656D737C7F84858B919797979A989A999B9999999B989899989C9A9893
928C89807671655A4F46332F2C282B2B2526262D292F353A4C585E697B798183858C8E92
93929195908B8C888E898C8C8B8B91948F949494979B979D938263402E2E2C28292D2E30
2A292D2D352E323239343B37352F33343648343430302C333235343C32332D2C2A2A2F30
3134323F4037342F333333333B4655677A848D919693938F8D8F8C88868A8C949B9FA1A5
A6A4A3A4A3A7A1A3
5A5A5759575F5D5F5B5E5D595D5B625B56585D58555A5B5C62676C73808689919495999E
9DA4A6A4AAA6A6A6A6AAA5A4A8A3A4A29F9E9B948E8A847E7C6E6C6263574E49464C5251
56525B5D5B605B5E63645E646563696665666466686266636467636860646764686B6A6B
6E726E6E70737572757575737778747A79747373747778797F928978776C6B726F6A6864
696D6E767676726E7178706E70737577726971716F7676726D797C7176767F8282818585
857F797A8E8C898E899394908C8A888B9396888289938B7E848D8E8D82818A8E8A7C7C88
8D8F898F918F8F75808F877B84929FBBC3BFC1C4C5C7C3C7C7C1B9CDCAC4BCBCBAC2C3C2
BFBFBFBFC4C4C6C5CBC8C9C6C8C1BEC5C9C9C9CFD3D1CBC1C4CCD3D3CDCFD1CDCDCDCED2
CED1D3CED0CBCECFD1D0CFD3D2D0CBC9D3D4D5D4D4D1D0D4D6D3DCE4E3D9C37D4C3D423C
44474B4D56595E666B767B8381888B90949798A19A969A979A9E9A999A9899999E9B9991
908E8A817970665D4F42342C35322A2B26272E302B353F4D5A5C5F6F808284898C8F9295
96909293908E8E8C8B8E8C8C8D8C94929292919497999D9D958D7556342B292A242E2A2A
2A2B332C322C31353B37383231373336353A3733302C2B2B3730353936333531282E2D32
393734353233383136363139353F5054697D838B91938E908F8F9192908B8B919AA2A4A4
A6A4A3A3A6A59FA1
59595B51535C595C605C59625A5E5D5A5E5F5C575658585A5C666F727D848C9192979E9E
A2A6A5A6A6A6A6A9A8ACA7A9A8A3A2A09F9C99969289847D7E726F635F574E4A484D4F53
56575C5D5F605F6166635F63635F5E635F6266666162646465676867616368686567706D
6D6C71706F71767677757679757774787579767B7A7779787A808D827B756C6F7470666A
6F706E7274726F746D70716C7571697073716D7173757477747176797E77717C84878B83
888687787987898C85858F959490858091938F89828A998B85898B8A878385818A857E80
8B8992848492938C82839495858287A7B4C0C8C6C6C7C4C4C3B7C2CBC5C1BDC3C7C6C2C2
C2C7C7C5C7C3C5C5C6C7C8CECBC4BBC7C5C2C6CDCECAC3C5CED0D2D1CDCFCDCCCDD0CFCD
D2D1D0D0D0CED2D1D1D1D0D5D3D6CECFD4D6D6D4D8D4D4D9DBDBE0E6DCC5976141404443
47494F4E57595F636B738084898A8D9196999B9C9A9B999A9A9B98959D979A98A2989A94
8F8C887E786D665C5041342D2B312A2824282A2E303846575A6A68768081848A8F959597
9296939290918D8B8D8B8C8E91918E909498959596989B9B97938971482D33282329252B
2B272B29372F352F354237373933353037383A36302F332E322E373C3A40473B362E2C2E
393D3134353334333734323638383E4D5B717A85938D928F8E8D919393908C90929A9EA2
A3A6A4A8A4A4A3A2
5A5A5555555A59595D5B5B5B5A5A5B5C5F5959565458575A606471747F838D9390979A9F
A0A4A4A6A0A5A4A4A8A5A3A6A6A0A4A4A09E9A95908D867C79726C625D53504B4D494D56
5A5A555B625C605E5A6567656162646060646464616365685F66686C70656664676A696C
6D6F6E6E6F7171737872767472767476747575797E7475767C78898B8274706A696A6E69
6E6E747979706E7773706E6D6F6D6D6F73747A7172707674707A7B6F757C73717A8A8288
7E7F8E817C7880838C8481848B8F8E8F838490888B8893978B8D8A8E88898E7F848D8287
85898F8F868E96959691999E958C7D809BAFBEC7C8C7C4BEBCBEC8C4BEC1CBCFC9C5C0C4
CACAC7C8C8C6C5C6C3C2CACECBC6C6D2C7B9C1C5C5C2C1CBCFCFCFCCCECDCCCCCDD0CECF
D0CDCFCFCCD2D3D0D0CFD3D3D3D3D3D4D6D7D8D7DADADBDFE0E1E0DCC59C785543464849
484F524E55565F686E747A7C888A90949598999B9C9C9A9A9E99999799979D979E979B9A
918B8A8378726A594F41353D32322B2922292B35343D4F576268747D8085878A8F949295
959091938F8D8F8A8B8B90918C8E8C9191949694959699969B98927E613F2E2523262729
2B25282D2C2E2D2F2F353C3B393837383835373733352D2D2C2E2E3237383636332D2E32
33312E2F383434353F3B303B333A393E505D6B7B868C92918E908E939597938C8C959EA4
A4A4A4A3A4A4A4A3
57574E59515E5E5D57595C5E58595A565B625E575659545A5D6269767A818B8F9294A1A0
9EA1A3A6A7A7AAA3A6A5A6A4AAA8A5A1A49E9894908D858278736B5F58514B4C4C4F4E51
57565C605D5F636360666B646469636662656666626367636366666A66666766666C6970
6D6E6F6C6E6F72747772737271767B78797575788273757B787A828C90796F6A6C726C6D
6E6E7574756B6E6B6B6A6E6D7272707C7474737C6E6D7D79777A7C7B7571807A717A7A83
857E7B7E83848170898F8488858E8B8A8982848C92928F85908D8E89898990897E82858D
8A86818D8E8986919A99A3AA9BA294808292ABC1C4C5C1BDBFC5C1C0BFC4CCCFC9C5C4CC
D0CDCFCDCBCAC6BCC6C8C8C9C4BFCDD3C6BAC8C5C5C5C8C7C7CACCCACBC9CACDD1CECBD1
CCCCD0CDCFD5D3D2D0D3D3D3D0D2D4D4D6D7D8DADBD9DDE4E1E3DCC1926E6C533E45484D
51525156585E61686B727C7E868B8E939A97989E999A9B979E99989A98969B9C9C9DAA99
928B8784796D6659543E30282A26272C2B2832303E46505D6572777D8086888A93979395
929293918E908E8D8B8E919090948A9290919395969598999C9B96877659342B252B2825
2826292F2B2B2B313D3732343B37443A383832323439372B2C27303238423A3A36302D2B
313A2F2C3A37363B3236373C3B3F414348505A6D7E8A889293908D929799998E8B90949F
A1A3A3A6A5A3A2A7
5A5A5453545A54595B59575F5D615B5A59605B5A555653575C6B6A787A82878E9994999E
A1A0A2A7A6A7A6A3A7A3A7A1A3A4A29F9F9F99968F89867D79716A6160534A484B4A4E4C
555F575C605F655D625F626264606368615F64615E6363636164656168626C686C68656C
6C6C716D6C727176757371727A70727079747476777E7B79797E7E88907878706A736C6D
6D7277757571706D706D737075747275777A7576727279787D7A7C7A7C7675777978727A
898A85787D8489797C83868F8C9290888E9484848D93948B868F8D8E8A828D908B827A87
8D87868C9B9190878B9A9BA9AAA09C9C8B7B84A2BBBFBFBCC8C5BEC2CACBC9CAC4C1CCD0
D1D1D1CFCAC6C1C3CACFCBC8BFBEC9CDC3BFCEC7CDD2D0C8C6C1C6C9C3C5C8CFD1CBCBCE
C8CCCFD1D3D3D2D0D4D4D3D4D1D4D4D5D7D6D8DCDBDDE2E1DED9C2905F4E524E44474C53
4D544E52586361696E767C7F898D8D9493949B9A989D99969C9B9C9C99979999999C9E97
918F8A837C716458533B332E2D2C2E2A222B30333F5659626C767B7F83888E9095989795
9391958D8E928F8C8C8E8C8D908C9091939092929497979B999C9C93876C4C382C2E2D25
2A252729272C312D3A32393B3E373A3A3937373735302F2A2B262E2E31323B3E3C35302B
302C313031343A33372F37373A403C443F44526371818A9293929392959698939088909B
A2A3A5A2A3A6A6A6
6161575155575855585A5C625C605B5C5A5E5B585659555967676B768084889093989AA0
A1A2A4A4A5AAA6A7A7A9A7A4A3A1A49F9F9E98948A86837D7B6F69615A534E4C4B4E4D4E
5859615F605F61616468606A626664676161636360646363686769636E6869676A69716B
676D6F6C7474727B767D7477737473717B757C797D7A777C77797A7F8988797071727072
7479766F6E6E6F716C6F706F6F6F74766F727B746B707D7179727B786B7F7D726D817D7A
77808A857B7E8989847A788A8993857E88918B837E85978E84818F96948C858D918C8D8A
8F8F918D8E9796998B9098A7ABAFA49D958A7C7A9BAFB7C4C7C1C6CBCEC9C9C6C0C5C9CD
CFD0D1CECAC4C3CBCBC9C5C3BFC2C6C2C1C6CCC6CED4D0C9CDC4C4CBC6C5C2C4C6C7CAC8
CAC9CDD2D0D3D1D2D4D3D3D1D5D4D3D6D8D7DBDCDFE3E2DDCDB49261474443484A4C4957
57535755585F63656F777D83848A8D8F95969B9E999B9B9A9CA39B989A9A99979A989396
95918A837C7264595337332A2D282D3D3B33303B4F5D60687A797C83898D909193969493
9392938E90908E8F8B908E8A908D918E91929690919394999A999B948F81683D27292529
29252828273032322E3D443737373635363933373239312D2E2F2B322D31373F3939342F
302A2A33383932343934333838373A3D3D4646586878838A8F8F9193959A9796908B8993
9A9EA2A99FA3A5A3
63635B555457575357585B5F5D5B5F5B5D5D575653525B5C5B656A7A7E858A8C92979A9F
A2A2A9A4A6A9A8A6A8A7A8A3A5A3A8A39F9F96998E8B88837C6E6B6159504F4B4F504C53
5F5D585F62616165636461675A6864646361635D6768606362646469666A69676A6A696C
6D6A726F717074727D7A7373777373797577777779777C787B77757E82877C73737A746F
766F6E7A6B696F716E736F6A6F7973747A7470786F696E72716E7D7A717B807A74748279
7C7C7981857B798283887F7D8E8E8A817687918B8B7D8E998D8B91949492877F8B9B8F90
898B91938F898B9D999491A5ACA9B2A99B9A96817F95A6BFBEBBCACECBC9CAC7C9C9CACC
CDCBCDCCCCC9CFCFC7C2C5CAC9C6C1BCC4C5C4C5CED3CDCAD3C6CCD3CDC8C7C3C7C6C4C4
C4C9D0CDCCCFCFD3D0D3D3D4D7D6D3D4D6DADDDFDED9CEB8997E6A554C474B4A4B4C4D54
535B59565C615F6B6D7C7D82868B8E9394989C999A9B999B989C969B9999999B98979396
95918981827464564C3B312D2A232939413E3B545B5D646E748088838890919393969795
92928F918C908E8E8F8D8D928D908C93909495919490949A999A9A9A998B765A34292C2C
242529272627282C2E38333A3B383C3C352D343436312F2C2D3330292A323B3E3B373931
2C2C2D2E353535373B3A3B3C3F4042403A3E4652646E7F81888E9294959895969387878D
909A999EA2A4A2A5
6B6B66555053535B58575B5B5A585D5B5A5B565A575058545E646F7782868C9192969D9F
9EA2A3A6A4A4A7A9A8A7A7A5A4A4A5A29E9D9A9D908A8D7E77726C77595248475057565E
59595F606065595E626865685C6361646362665F6461666B6863666861656A676466656A
6C6E706F746D7175767A79796F72727475757779777A79777A797C7C7E82857775787373
6E6B727A6F6B75767170766B70737475787A74797C78717273756F6F71727273797C7776
7B847C738B8B7C7A78888B8281898A8B867A849196938590949293949397948884808A8B
9085808F9594879C9D9E99949BA8ADB1B7A59B9091898B9EACBDCBC9C8CECECBCAC9CAC9
CACBC9C8C8CFD3D0C9C7CFD1CDC8C7CAC9C2C3C8CDCCC4C9CEC6D1D3D1C9CCCCD4D1CFCC
C9CFC7CACBCCCDCFCDCDD1D5D3D3D6D8D9D9DCDFD6B89E7A5F5650504C4A514D4D555854
5D595353565F616B70757C8288898C9295979B9D9A98999B9B9E98969B969D9B95979794
908E8B807E7463584B3B2F272F40352C2A3A4F5C606A6A747F8185848D8F939795949491
90938C8D8E8D8D8D8E8C8B8D8E909490928F939195929399949D9A9B9C95876C4B39362D
262325252B302B2C312F313B3638363F3F3633313934322C2D2D2B2625313135393C3C33
2D2B2B32383534353035373840483B3D3740464F5563757A808C909592959796918C908C
8C93989D9FA1A4A5
7474695E54565159585A5C5F5D5C595B58585D575157565961626B7983898A9495979B9D
A1A5A7A4A9AAA7ABA5AAA7A7A4A5A5A09E9E9B96908C847E737164605A534C474D4D4E57
5559635F64615F617163636164606266646266656363676A656667646267686C67656B69
6A6B6B726E6C747472787977757174747676747277757278797C7E817C7E827772727272
6E6C6A6D6C75766F6F726B6D776F717677767376757979706B6D746C63676D70717F7478
7277857C78838686797D88848381808C8C877E858F98918C8A948C95919498948E7C7E90
958D808693979391989CA2A7A498A5B4BCB7AB93999C918794AFBEBDC4D2D0CDCACDCFCC
CDCAC5C2CACED1CDCAD7D5CDCBCAD0CBC9C4C9C8C6C2BDC0C2C4D0D3CFC8D2CCD7D4D8D6
D3D3CBD0CFD0CDCFCED2D0D7D3D7DCDEDFDCE0DDC58569594E4C4B465251524E54545356
545858596062676972787E7F898B8D9195979A9C989C99999E9B97979A969C9C9A979B91
90928881796E64564D3E3026242C2D3135444F64616675797F8889889190949296969891
918F90918D8D8F908A8C8F8E9391908D928F9195929190969296989A9D9C8D7F643F2B29
2A262329302A2C2C30303131373B32353A3738333936353532262E2925282D30383C373B
3231292C29342F2F333330313A353D373B404A4A515B69727A838F9096959A9492919491
8888929AA0A3A3A3
7A7A6E625653515556535969635B5D5B5C5B575853565456636270747F868B9292999A9C
9DA1A3A5A9ABA7A7A7A4AAA5A8A7A0A1A09C9B979089857F7A6C6A6157534F4C554E5154
5C5E5E656163646466626662665F5F686161606768675E606B66636260676A6C6D69686B
6E6B6E6D79776D757073747372727974787678777A797B7B7C7D7B7A7D7C837F79757771
6A6C6A6A6F727C72726D6D6E7B72727474797672747474797263707673696F70716E787D
79768489847D768587807B888F8E898491908F85838F92958E9093919A948E919A877985
958B90868A9395958C91A1A4ADA799A3B2B7B0ABACA0A0998C82A0AAC1CDCFCFCDCFD0D0
CDC9C4C8C9CCCBCBCCD9D8D0CFD1D2CDCACCC9C8C6C2C4C0C3C9C8CBC8C6D0CFDBD6DAD8
D6D4D0D7D6D5CFD3D5D5DADBDBE0E4E4DEDFE3D6A86055524A4A48485151564F5858575F
5A5A5957605F676971768280868F90929797989C9A9E9A999C9998989E9C9B9D979B9492
8F8E8780807160584E3C2F2525242C373D4A50646772787A7F888E8C9290959995949792
9290948D8D8C91908F8E968F8F8D918B90928E9191929392949495989B9D989071513828
282527252C2E2B292C2A34303134383837323135403C353632322F2C23292C2C35363C3D
41392F2B3130323137323134373238394242514D4D515F697179878D9195959192959595
8F83879199A0A4A2
7B7B786A6358565555535E5C5D615B565A5C5B585B58545759646F7B80838D94939CA1A0
A5A2A5A3AAA9A7AAA4A2A3A1A3A3A4A4A09E999790898577796F655F5D544E484D515658
5A5C5D60625F616467635E5B665E62656160606566645A63656364636A66686D6968656C
696E757171746E7974747674757475767A77737A74777B7A7A767A78797D7B837F746D6F
6B6A6D6D6F6E736D746F6F776F706C7676767A74737A767B7776737573766F696D757570
7E7E7A8483877F7683868580838D9391878D8F928D8C8A9193938E8A9596938D9394898A
89878E8E8A8B9097988A91A1A0ACACA6A3A7B6AEBAB1A49C98979196B1C4C9CDCDCFCFCD
C9C7CACECBC5C6C7CDD3D3D4D7D5CED1D0CAC8CAC7C6CAC6CBC9C8C6C6C9C9CBD1D1D6D8
DAD0D4D8D9D3D5D8D8D8DEDFDFE4E0E0DDDFDABE824D474B4C4E4F4B555455545A55585F
5C5B595B6162676972767F7F8B8C909096989A9B9E9A9A969D9B9897979C9899999B9290
8F8D87877E786A5D4A363129252C31383952605F686B777C7F8C8B8F929496949594928F
93918E918E8E9092938C8E8F92918D8E8F928F9391909191949796969DA0A0988964412A
2830262A2E27332D262A29302A363433363437342E33383433302E2F2D2F2D3132353A3D
44422E2E3032353A32352F31332F34423D43484A5051545864707A858E8E929492959899
9689858C969D9FA3
82827C74665E4F54585C575B5D5C5A565E5A52535A56585A5D68717D7D848F9199979A9E
A2A5A6A5A4A8A8ABA4A7A5A5A8A6A2A19EA099958F89857D7B7063625C504C4E474B5458
54575A60615F6160605E5D63625D62686162626364676367635F64616863656B6A6B696C
6B6A6E6E6B746C747574737572747576787678797D767D7C7A7678797C797D7A807E746A
6B6F7067686F6E7171796E717274716C7678767A7874757475767A766C7A786B64677472
737E82817A7D887D768286837F818D8E8E858391959389868B948C84869692978C929592
9589898B909088939695959EA0A6B1B7B4AEA9B7B6B7B3ACA3A7A1978FA9BDC6C9CCCCC7
C9CDCFCECCC7CCCECACACFD1D7D3CED0CBC9CDCDC6CCCDCFCCCCCCCDCACAC9C9C7CBD1D0
D4CFD7D8D9D5DAD9D9DBE1E2E4E6E1DDDCDBC18E594B4C4E4956525255585A585A555859
5A5B5D605E64696774777C81858B9094969A9A9CA0979B9A99989C9B9C989D989A989298
92948D867C78675D4E40302D292D2D3A465462636A737683848E9191929597989691938C
9890928F918C928F908D8D8F91918B969290949391918F9293959597999D9D9F8E765A3E
2B33332B2A312D2D2E2D2D292E312F34373233383034353439393830302B2D2C2F333D38
3B33302F2F2F2D342F3437323135353C3D493F45504B555158636D79838C8E9199949696
989486848E979DA0
888882776F625B525653535D585E57595B5A575658585256616570737D858C8F93999BA0
A4A2A5A5A5ABA9A7A5A6A2A4A4A1A1A5A09D9A978F8D848079736E615C4F49484D4E5056
585D5A605D626562626061656A5F6569645E65656668675E656461676763676D696B696C
6A6F706A71736D7172797477737173787A7779797B78797B7573807C797E797F7D847B6E
6B6D736B6A6B6F6E6F736D6D7171757169747A7C837674727C74757B7279787972666A78
75797E8278797F857E7A73798086838B928C867F8D8E918984898D8A888E9093978D8D90
9195928F9999968C97979DAA9F97A7A8B2BBB5AEA8B6B6B0B1BDADA096919BAFBBC2C6CA
CED2D1CECBD3D4CCC8C8CCCECDCBCED1CDD0CCC7CBCFD0D3D0CECED0CCCCC9C9CACFCECB
CECED4D7D8D5DAD4D9DEE1E4E6E4DCDCDACC9E66504A514F515351565459575B5D5D585E
5D5E5B575C66686970777C8285868F8F95989C9C9E9A9D9E9C9C9D989899989A9A9C9994
959389867D72665B4F392C2828312D3D4B55626B71757A85858E939291979596978F928F
91948F8E928E8E8D91908E908E908A8D959190948E91939393969898959AA39B95856B49
3329303152563B3E39392E2B2C3235353337353334313636383B37312F2C2F2D29313436
383A3836322B312D303834302E383F383F42434B4E4A4B45525C647079868F929493959B
9A988F818589969B
8888867D72635B5953535657555A59575A5A5B575659555A616A70797D898D9398959D9B
A4A5A5A9A7ABA9A5A5A7A6A8A5A5A7A39D9B96938F898280746F6B605A504F49494D5458
5E5A5F5D5E605F61615E5D646962676865606A6A6867686266666067656266696D6D6F70
6A6A6B706E727179727374756E7476727A767E7E7D7A7B7879737C797976757C7C81827B
74686F6B676A6F6969706A6B746F7174716B76797D7A78717577726E767D776F7173726D
787A7C76777B7D81887F7B727D8B888589928A7F828691918B898D92918E8B8E8C928F8B
98969A928C939193969B9AA5A89795A5ACB3BDBDACADB4B2B2C0BFB19F9E9B98A0ADB5C4
CFD0CFCFD0D8D7D0CFCFCBC9C8CBCED0D1D0C6C7D0D0D0CECECFCDCFCECBC9CED0D1CECA
CCCFD2D1D1D5D8D4D7DBDEE2E1DEDADDD8B070544E4F505454595B5A59595A666462645F
61615E5F625F666870737D8186898A919598999C9E9A9A9C9A9D99979999989798959795
908989807C73655D513933292A2D34434C5B666C717A7F868992959490979793918F8E91
91918F918F8F8E8A908F8C9091948E918D939291918F949393989197979C9A9C9B907E66
46302A273C3D49463B292C2A2B2D343B363F3735363638393B313734362F2D332E2E2C38
37393D33352F332A2C2D302D29373F393B3A3C454D4E4B4F51505A647382859195959897
9A958B8780879499
8F8F8B827B726559554F565857585B555B5858535658555C5F6A6E7B818D8E959596A19F
A2A6A5A8A5A9AAA6A3A6A7A7A6A6A5A09F9B97939589828374716A5F56544E4B4A4D5258
55585C5C5961616361605E666061656D656067636D66676A64656761676267646C6B6F71
6A6F6E696F7670777970737576767474777A78767A78787C7B7E7D7B77797B7B7B858080
776D6C7370666F6667716C6F70737573766C706D7A747779757771736D71807B6C737F74
70717677737A817D7C85887F7486878E85869088897C808E8D927F878B919786858B8F8D
8B9696998E84919999978B9EA3A9A498A4ADB0B8B9B2AAAEAFB8BEC0ADA59F9FA09AA5B8
C3C7CBCBD4D7D4D4D4CFCECFCED0CECDCFCAC7CFD0D2CFCDCDCFCED1C9CACECFCECED0CC
D2D5D0CDCCD4D6D1D4D8E1E4DFDCDED9C5945C4A524D4F555856575C625F5E5E5D5E5D5F
5E615F626760686E7174797F86898E939698999B989B9A9C9B9C9A989596959A97959494
9185847D7B6D6B534940342E30353B4757606C72778085898E9094949798959290928F95
918F94928F8F918E8F8F928F91908F9390949591908B90959191919396969A9C9C998D80
5A3D32352C27312927262C2E2B312E353B3D3A333539303D34363832322F2D302E2B2B35
3C3E3B3A3433322C2D333033303E363A3C3C3E4147434B50494A4D5868737F8990969997
9C948E8D89888D8F
92928F837C726A5F5A5750515759575B5B595C53534F555B64696D7E81888D95959E9FA3
A2A8A6A7ACA6A7A6A9A2A9A5A9A9A4A29D9B9A938C8986827C726A6059584E4E484D4E51
54575E5F5A5F5E615C605E6161666467676867696867626668676267676669646B716C6B
6C6F73686B716F747273747575736E7775777A7A7975787A7A767B787981777D7B7E8185
7C75746E6E6D716C696F6868726F71746E6E78706D7781797C7B737873747A837D757272
78736F7575767E857A7B85847D7E81828B8989898E8B807E898A88837D90968E848D8D8E
8F878C9A9A9A8E9AA2A0969AA3A7AFB0A6A3ABB6B3BCB9B2A7B1B8BDC1BAB1AAB0A89C99
ADBFC2CAD2D1D1D7D5D3D4D7D4CFCDCDC8C8CBCED1D0CDCCCED0D0CCCBCDCECFCDD0D0D5
D4D3CEC9CFD4D4D2D6DBE1E1DFDDD9C69A68514C4D5456515B5C5B616162615F62645D65
62605E5C6066696C74757C7F888B8E95959A9C9D999A9A979B9C98999A9C949698949196
928A86827C716658463C332E38384152576575747B828C898E929892989793938F919092
8F928F94928F8E8D90908E918E908D908E9090928C8E928E9191919499949C9A9C9C978D
705034282C27262B2F33272D292B312E30353C3B3C34353A353A3838363234312A31272E
323B393E35312F2A2C25282C2E2D3544413F3D4647444B554B4B43515A6B7C7F8D949699
98948F8D8F8E8D8D
9696938D847C726958545352575A575B595B5E5956535A5E626B747B808588909798A2A4
A4A5A4A9AAA6A4A9A6A4A2A6A7A5A4A19F9F9696908A85807C746D625B534E4C53515253
5D5A5A5C5F5C615E6262646065666465655F636B656B67656364616366646567666D6E6D
6B6F6C6E746F747470717374776E7279757676797B787578737B7A767F7F7B7C797D7D7B
7E7E7D72706B6A69656C676B7273707675717A766B6D7C7B7F7C767A737D7A77797A736B
757D746D767779767F817D848A8B80778C919288848F898C8988888E88808F9298908A90
919183879A969C959A9E9CA4A5A4ADB0B4AEB2B3AFB5B7BEB3ADB1B6BAC0C0BFBBAA9F9C
A0A6AFBDC7C9D4D4D4D4D8D8D1D1D1CCC5CBCBCCD0CED0D1D0D2CDCCCCD0CCCCCFD4D4D6
D3CBCED3D7D8D6D8DEDFDFDDDED9C7A16D4D4B515054585B5A5D606661616263655F5C63
615E5E5B6265666D72747B8084898F9096959A99999C999497999899999A9A9B98959290
8D8E8A807B6C6151433C382F333A4E59626F75798A838A8E90979695969392938F918F92
909393908C8F8B909391918E91908D8E8F938F8D8C8C8F8F8F90919294939B989A9E9E92
876D48352C312626272B29282929292C322F373A3C3438312F373832333A34322E2E2828
313833363B34372D302D2E2B2C302E383C47455043414456484245434C5A6976828D919B
9794929092929691
959594908A80746E65584F51555556575960575754515C5C59657076808B8F92989AA1A0
A4A9A9A9A7AAABAAA9A7A7A6A5A6A2A79D9A9B96908C868178736A615A55504C554B5157
5C585D5D585C5C5B6161656261666361656263666D6867656567646265666766696C696C
6A6A6E716F70717174727275747273757375767779787A797D77797B7B7C797D857A7B7D
7F8182757469696A666D6C69726B72707B717975717073727F7F797E79737A7B757C7978
75787D75716F7A817C8387848183887F7E888D958381898E8F8387888F81828A8D938687
8C929182929B9DA794959DA5AB9E9DADACBDC4B5A7A5B1BCBCBFB6BBB3BBC2C1C3B8A59F
ABA9A5A9B5BEC9CDCFD0DBD8D2D7D2D3CFCECCD1D0CFD0D4D3D0CFCFCFCCCDD0D2D4D4D3
CBCBCED5D7DBD7E0E2E1DFE1E0D2A86D574A504F5656615A5D6360625F5E5F626A665E62
615D62596064697070727D81858B8D92979A98A09A9A9A98989C9B9A9A9B979A99979192
8E8B84817766614F413539393B42565D72707A7D85888B8F9394949494918F918F919092
929496908D8E8E8D9196928B8F8F8F8F919595908E92918E8F958D91919394989A9D9E9B
90805E382A2A2424262829262927252E292F2D3432353F3342363835393735332C292626
2E3234363538382E302E2935382C333B424D493C3F4245535B3D473C3C49506778848D91
989791939293959D
9A9A96948E897E76695E56515053575956555B535856565C5F6770767D898E8F979B9EA2
A4A7A9A7A9ACA7AAA7A7A7A4A7A4A4A19D9B99948F8C897C757169655D57534B4F515356
5457595E5D5F635F5D6364636661675E62655D656A6F68686965686666616A6E67696D6E
6E706F727073767573736F75767375797375767E73777A7A7D77797A787E7B7C7D7E807B
7882847D776E656C6D6D677171696D6E6D6C747D737879766D7C7E827C7D74787F7C7B7D
787C727880736B827E817F82857B8486818782948E8585888B947D7B8C8E857E85978F87
848A92958D8E97A5A99699A6A7AEA9A4AAB4C0C0BAB1AAB9BCBFBFC4C4BBBDBCBFBEBBB5
AEA9AEADAAA9B3BDC4C7D0D3D4D5D3D7D0D2D1D0D1CED0D2D1CDD2D1CFD0D0D1D3D6CECD
CED0D3D8D9D6DCE1E2DEE2E2D9BB77554F515756575C605B5C5D66626164626566656361
5F6363636261696B72717F81828A8A90989599A09C9E9998979898979E9C99989796928F
8E8D7F7F79695F53473A403E3E4E5A656D777F85838C8F909393939391978F8C90959592
9791938F908F9290938E8D8D8E8F8F8D9393908E8C948F8E92959294969C97989A9A9C9E
978B7455362B2A24292A2C282929282C2B2E2E3C38343C363739383236373734342E2E25
2A2D333335373B383332292C2E2B2F2E343434333F3D464F52504340383D4B5B6A77868C
95969295969895A1
99999996908F837C756660594F4C5652585455565559585B626E737D7E828D95979A9C9E
A5A6A7A9A9A8A9AAA7A6A7A8A7A3A2A09C9B9A948E8D857D766D7168535349484A494E55
585C5C5C645F5F5F64646262675D6663686360646A6A6A65635F63686363686664636770
6F706F6E717775707073717C747073767B717978797C7B777C73797A7D7F7A797F7C7979
7B83818A7D71706D6E6A646E6E706F6D7077767C7A7572777472767B7B78797471787A74
7B7A746E7A7D76747C7A767D84857A86898A8980958D8A848C918D7B7B8D8D8B818C8C8D
84818D95998D8799A29E9798A6ADACB5A7AAB1BDBDC1BABDB7B0BDBEC6C8C2B5B3BDC2BF
BFB9B7B1ABADAAAAAFB4C3C8D1D1D4D4CFD5D4D5D4D2D1CCCFD2D3D3D0CFD0D2D3D0CACF
CFD3D7D8D8DAE0E1E2DFE4E0CA925953575157565C5D61635D6465626162655E64626162
6562615C61656E6F6F777E80858C9090949699A09D979A96999A99979799999B97959191
8D8A857E746A5A555340444347535B6B767B8185878C93909694919894938E9193939593
949192918D8D938E948F8D908D8C93919292908E8B918F95919093959398949795959D9C
9A957F6B5232312A2E24232323282A30372C2D31343731343836372E313930303032312D
2B2E352C313135313832312E2D2F322E31353334373E464A484C4241423D3F465267788A
8D9A95969A969D9E
A2A2989B958F8A8077716260544F5350545C56524C5456555F69727985878E93979A9DA2
A1A5A9A8A8A6AAA7AAA8A5A3A8A5A0A0A19C96948F8A887B776E6A5D5251484B4F495255
585B595F616060606060636A6660676563605E6767635F665F6564686867676A676A6D6F
726E786A75727371707172736F71727876757A777D7877787C7A7B7A7D78797A7D7B7C78
817F7E857E79746F6A686A6C71736D6F706F747878747D757E76756C7E7D797C7F6F7482
79777C73737C7F796C6E7C807B8482847F8B92857E858E877B848D89827F898E8A878A8E
8E828486979A8788A1A1A59E9CA6A3ACB5B6BAB1B7BBBCC1C2B3B3B8BBC1C6C2B7AEB3BA
C3C3C4BDB3AEB3B2AAA5AEBCC5CACBD0D4D5D5D7D5D4D1CDD1D2D2D3CFD0D5D5D2CFD1D2
D6D8D6D7DADEE2E2E2E1DCCDA4674E505356595B63656064656266656565616364616365
60635D595C656B72717380808A8A8D969596949A999C9997989A999B9699969E9A959293
8E88877F766C5E554E50534F525766717480838A8A918E919C919393938F8D9392959495
908F938D908D908D928E8E8F8F8A908B9093939B91918F919092909292969296949B9B9B
9C9C92806841342E31262827272326282B29292B30323037393635383F343234312E2F2A
2A2C2C282F3239353C32312C272E322B312D3130353B4243454B414C463B303044526D7D
869195989C9E9EA0
A3A39E9D98918A847C7369604F51535351525554585257575E6A6E7D84868F91979B9EA1
A4A9ABA7A6A7A6ACAAA7A4A8A6A3A2A29E9D9B97908A897F7B73685B57524D4D4B4D5056
59585B5F5E5F615D5D63666A715E626268665D66606363646463676368676B686A6E686B
6F6C6E6F6F6F6F71747571767572766F7576797877777775797A7B7C7E737973797D7C7A
7D7A7F7B86807B766F6C726E6A6F68746E7370747773787D767679736F797D7D7D75757E
7A7D7A78787676837F727D827D767C887F798B8D84777F89847C84878F86798A8F928E83
8A8D8B7E92959D988FA1ADABAD9BA6ADB5BFC6BAAAA8B4BBC0C1BCB5AAB9C0C2C2BCB4AD
B6BEC2C2C4C0B8B1B2B8B3B2B0B9BBC8CFCFD2D5D5D7D2D1D4D1D3D1D0D5D7D4D2D2D4D6
D7D7D7D7DCE1E0E2E4DECFAB75514B5559585E64636763646965636A6564626368676367
65636161606A696C707180858D89909292939A989A9B96979E9C9A9A989A999B9A959191
938B847B776A5A595256525759606C717884868B8E9093979594919092908C9092929095
92928F8E8D8D918D92908D93908D9291928F919090909292959295939994959A94929D9E
9D9E958D7358372A2A2830282728292F2A2C2F2A332E2F353136333A3330363237343232
2B2E312B2C30343B38393B332E2F372D352F2E2F37373D423C4E474D4C403930313C546C
7F8A95999BA1A0A7
9E9EA49A979792858479716B595350525353545054565459636A717E82869097969B9CA4
A2A5A5A8A9A7A6A7A7ABA7A4A7A3A5A39F9C9B98948A8A7E7873685A57504B4B444B5055
5A575C5D5E595E6461626167665E5C5E6169636961666867616A6663626868686A6B6E6E
71706C6E706E737372726F6F727179787A727C827D7A7B7B7F7779777C7A787A77767B77
7C7E7F7E848C7E75746A6D70686D6D726D6E706E78727577817C7273706F7781817A787B
7C787C72767E7C748682807F8281777A84837F8887877B86878D837D8A8A867C8A97A18D
7D8A919295969DA6A48E8FA3A9AEA9AAACB5BBC2BEB1ACB7B8BAC1C6B6ABB4B9BAC4C5BE
B9B4B8C2C4C6C6BEB8B7BBBDBDB6B1B8C2C3C9D3D2D7D3D8D4D3D2D2D7D6D6D3D3D5D6D7
DAD7D8DCE0E3E2E4E1DEBD835A4A535A5B5C6361646668656B6663636868666664646165
675F5E5B61676F6F7174808487898F959496999B9C9A99979C9C99989B9B9A9C9996938F
8E86817A7165615E5C5C5559626F6D7783868B8C939196939692948E8F8D918E91919394
929190908D90918D938F8C91938B9394908D949290958F93939293949592949896919997
9E9D9B93816F4F362B2A3233282C39262C2C253A2B312E33313B3937323236343837362F
2E2F2E2729303541363C3C37312D283132302B2B3331383D444E51514F463D2F27313C58
6E84919499A0A5AA
A2A2A39F9897938E887E756E605F514D54535556565851575E6A737E85899091989A9FA4
A4A4A9A6A5ABA7A7A7A8A8A4A4A5A3A1A39E9A95928C8B7D7B726B5D58564D4B434C4D54
52535A5C5F5E5F605C62605B63616367676262645E616366666A656662666669696C6C6C
68716F6E716C707376776F77786F75747C7A77797B7877777E7F797D77827B7D76777777
7A827E7C808C867C7A736D6A6F6A6E6E696A706F6D6F7375747F72717377726F7C7F7F81
7B7E7D7D787F86797785837C7A7E7E787F89877C81888E848494957F7885878682879A99
8A8A9491A092959FA9A4948DADAFB7B4B0ACB2BEBFC4C1B8B1ADBCBCBFBDB6B0B4BFBDC1
C2BFBFC0BBBFC2C4C3C1B8B6C0BFBBB7B6B0B7C0C9D0D3D3D2D3D2D6DAD6D4D3D2D6D7D6
D7D9DBDFE3E2E6E6E4D5A363534D51565D61646369686762656867666466676863656865
665F66646A686D72737383818889909394979C99999D9D979D9B9A9D999799989D969090
8A888078706C675D615A6365687279818283888D91979A96939495908F8E9090918C9194
9390908E90908E8D9090918F9090968F9194938F8C918B95918F8F919295929896909796
999D9E988E846D482E292D302C2C2D31292A2A2F35352E312D313A3E2E31323C30343235
33382E2D282A2E333439373A30302D322F2F2E2C323133363E454B5A52493D342B2C3143
58708591979FA6A9
A7A7A29E9B98978E89877972685A51505855575A54524A5861676D7C7F848D95949D9DA1
A5AAA5A8A8A8AAACABA9A6A6A3A4A19FA29D9A9891908D827A74686057504A4C4A515453
595A58585E6566626A625F676063636668625C656664626367676464666766666B6C6869
726E736F7972757B7E716F727471736E797173707C7C77777C78757D7E79797B7C77797C
7B7F7D7B7F828F8976767271706E6B6D64676A757069717C777C7976757378716B7B827B
7D7B847A76798383887A82858178778382848C8B877C8C8C847E868D85838E898B8A8D96
94938D8A969D92899EA3AAA29CA6AEAEB7B6AEB4B4BCC1C1C1BAB5B6B5BEC0C0BBB3B2BA
C0C3C7C6C2B5B8C4CDC6C4BEB9BDC2C5BDBDB2ACB5BDC8C8CFD0D5D6D7D4D4D6D9D9D8D8
D8DCDEE2E3E4E6E4DCBD7B565253535A6161656969696565616763646365636967686568
64615E6367696C6D6C777D85898A92949795969E9A9B9B979D9E98999997969899979192
89897C77736E6661666967686F787B80878C8C8E95959696949492908F92929392939292
9590938E8E8F928E8F9092918D90918A8E8F8F90908E908F92938F929596979594939797
989D9D9F9C917C5B3F392E2D2D2B2B2B2D2D25262F322D2E313534333534343333343133
2C2A292E292A2B3630383F3A312D32382F31312E313030363A41484F564D3B3329252531
3E566C8397A0A3AB
A5A5A2A49E9E9C948F8D817B6D5E524E50505555555051595C67767882878D929A999EA3
A3A8A9A9ACA9A9A7ABA6A6A6A4A1A4A19F9E9C9A918F8A837A7470605A50464A4F504C56
605A555A5B5F616872646366626369616A5F6166626964626269656565656C676B656B70
6F6E70726E767672747272736F6F717572797277787A78757973787A7B7B7C7A7A787B75
7A7D797B7C7D99A47E6F6F796F6D6B6C6E6B686F6C6D6F757676787572737377746A7E84
7A73887E76797C758789807983887F7E848385888C82818C9089778592968C8A888F9091
928E9F8F8E989C9896A0A3A9ADA99CA9B6BABFBFB0B0BBBABDC4C3B2A9B6BEC0C2BBB5B3
BDC0BCC2C9C6B6B5C1C5C6C8C7BDBABFC2C2C4BDB7B4B9B9C0C6D1D2D2D4D4D6D8D9DBDB
DBE0E3E3E5E3E5DDCB935D5A5959595D656A67666A6C6D686566636666686868696A6568
656A61606B6A69706D7782818B9090959595949EA09A9B9A9D9C9B9B9A969D999C95948B
8A83817B76786A6B6C70736F757C7E848A908D9092999695909290919190938E93919694
92918F8E8F8C9292918D8D928C8D8F8F92929090938C8E9193939291939497949697989A
989D989E9F978C77583B3332292B2F30342D272A2C3927272B2E3432313634353435332E
322C2C302B2E2B32303B3935383837362F2F2D30383232343C3939474F4A3E372725292C
313B5A76899AA3A8
A7A7A5A5A1A09C96938C847E77655D50526F504F4E49505A6266717A82868A93999BA1A5
A3A6A6A6A6A9AAA9A5A6A4A6A1A2A0A4A1A09A99969086807D72685F564F4A4D4A4C5350
565858585E5F5E5C6C646262655F625F625F64646266656466636366626B64666A666D70
696D70706C737470737876776F75716F72727A7974767A757B7A7C767B7D7B7A76767A7B
80837B7A7D7B8EAA8D746F737172726A6D6E706B686C7173717A7D757578717A777B727B
888183817B767E7880828B867D808A8179818D8A8A8D8783858D867B8692948175858A9B
92889295938F989DA2A08B9BA6B6B5A8A9ADB5BAB7B7B2B2B4BCC2C3BAB5B2B5BBBEC0C0
BCB6B5BFC4C6C0BDC1C3BFC8C7C6C5C3BEBEBEC4C3C2C0B5B5B0BCC6C9D0D2D2D7D8DDDB
DFE2E4E4E3E2DECBA26B56595B5B65666C6E6D6A6D6B6F66676965616B686C6C67676566
6667656062686B6D74778683888E90929799979D9C9A9C9D9E9B9A989A95999995948E8D
8A8080797775726F737672767D8084898C909093999394928F8F93919393919297989692
91918D8D8F8E8F918E8F91908C8F91909293918E908E918E9493918F9190969491989799
9999999E9E9E96887055362C2F282A30302828282C292B282C33333A2F33363838383631
3032312A292C2D3030353C333A3B3331332F353032353131343638414D4D40382A262622
232B47637D95A0A8
ACACA6A5A0A49D9A988F8E7F776D6156514D52584E5052555D6B727B808689959698A0A4
A6A6A8AAA6A6A9A6A7A9A3A2A1A8A0A0A09C9A95928D88807E73665D54484D48494E5351
5457575561655D6665665F5E6160666164606562656365636564676763656A657068646B
69716B6B6B71726D737675786E75767576787E787A76786F787577727E77797B767B7B78
7B7F7C7C7A76819CAB836E727475776E696A6E67696E6D726E757976787872767A817877
747E847E7A7E7D7C848380888C7B7A848586848D918E8C928D898F84857C8A8F83858A91
A0979391979C908D9EA89F9997AAB1B4ACA8AEB5B8B7BBBAB6B5B5BCBFC1BEB3B3BEBEC1
C4C4BEB8BCBCC2C9C6C6BFC3C1C3C5C7C7C3BBBBBFC2C5C6BEB7B1B5BAB9C1C4CDD1D4D7
DBD9D6D6D0CDC09E725E54585F6063676C6B6A6C6F64716C6B666966666A67686D6C6E68
6865676265726F7174747E858B929296979A999D9A9C999BA09B9D999898989B97948D8C
8783807F787A77727776777A828386888F8F939695979393938E938E9191939097949891
9493918B908D8F8D8F8F8E8D908F908E918F9091909292929393918E9190919293969395
9695999C99A09F957F69472D2D2D2D2B2C2D283530292C2729303237363337323532393D
353734302D2D2C2B302C36373538443633322D2D2C3332303137353D434742382F282724
23272F4B6F8697A7
AAAAAAA7A2A49D9C9B9291867C746C5C554E4E504B4D56555B687777808989919E9BA4A1
A8A8A6ABA6A7A8A7ABA4A2A6A5A7A5A1A19E979890908B807B716762544D4A474B4C5253
545A655860606063656566646169686663636866676265686460656265666464686B6B6C
6F6C6F68736E7172747273706D7270737974767B79787675797578747B7B7E7A777C7E7E
7C7B7C7A7B7E7F97C6A97470727072747272746F716A68717472777A777775767B788380
7B6E7D877F7C7D787A808078848F817E86928C818C907F8C948B88878E8E838692958682
8E9F9A8E8E9AA198959DA6AEA0969BABAFBCB9B3B2A8B7BABCBEB2ADBCBEC0C1C0BFBCB9
C0C3C4C5BABDBEC1C8C9CBC8BEBAC4C5C8C7C3BDC2BFBFC6C9C5C6C0B9B6B5BBC1C9CCD1
D2BBADAAA39A8A69595B5E5D6069676F6E706D6D726C6A67686E6D69686A666A696B6865
6461646360696C7074767C878B939896949A999A999B9A9D9EA19C9B9894969595938F8D
8A8586827E788077767B7C7E82818D8D908E939698909392928E8D909091949396939A94
94938D8D8D8F8D8E938B908D918D8E8E9192948E8F938F92929298959691939594969495
989699969A9A9F9A907B56412F2E2D2A29272F2A2C342926292B2C303133373534373535
362F342E2C2C2E2E282A2F303335333936362F302F2D3231323634403E4343473C333025
221D222F53708BA0
AFAFABACA7A2A19F9E92908C8079716459504D4D4E4E4F59636874797F8A8A8F999BA0A2
A4A7ABA8A7A6A8A6A3A5A2A4A3A6A4A19E9E9893938D87817E796E5B5648504A484E5352
5758575A5D615B5C5D63615C6365666663636A65655D66656761636362656B686C6D6A6A
6F6D706D74717370747077747073707372747876777E78787877797D7C79797D7D7B797B
7E7D7C7979797A88B5B47C6C6F6F71747670726C6D716A6F6D7271727675797683808089
817A707E8D86827974798B8783898B8B7F8D90867A79878984938D7F7E9191828190958B
80959E9A8E8D9BA5A5929CA1A9AC9EA0A5A8B7B9B7ACAFB6B4BABCBCB9B3B4C0C0C3C4BF
BEB3BDC3C4C5C3BCBEC3C9C7C7C6C6C0C0C2C1C4C5C8C6C6C3C4C7C9C5C9C4C2C8C6C9CB
C998726E6D6B635A5A625F6561676865716C6C6C70706F6F6D6B6A6A6C6C6A656A726768
6767676167656A706D727F8287939494979A989A979A9E9E999D989A9693949695978F8A
878785837E7E807D7A807D8287868D8E9096989595929290928F8E8E8F93969194949496
93958D8A8C8E90908E8A8C8D918D8E8E908F948F8E9290929193929A9291969491989594
939596999E9C9D9B958871503B302E2F312E2C272630292E28292A3133353C3D443A3631
33332F31312C2C2A27292930373536393839393C312F373531343637343D444344383026
221E202633567A94
ABABADAAA8A7A29D9C96948B847D786D6053544B4B48515862646D7881868C92979A9FA3
A8A9AAAAA9A9AAA6A9A6A4A3A2A3A29EA29D9C96938A8D837B796C5E554D4C4846484F51
575E565A5D646064665F6764675D5F6661616664625E61676063656660656867686D6B6C
6A6D6C6C756D716E717774767074757573757976777D767977797A7979797C787A7D7D7A
7B7E79797C7F757B8AA388766A6F767072797676716F746C7070767272777376797D7C7C
7C827C757D888979737E84818B8A8584848A818F8D7B7E88828492878489969583849696
93898C97A39C919CA8ACA498A1ABB5B4A69CA1B5BDBDB8B8AFB2B9BCC0C0BCC0BDBCC1C5
C5BEB8B9C0C5C7C5C1BAC1C5C5C6C9C6C4BDBCC3C5C8C7CAC8C2C2C8CCCACBCCCBCBC3B5
A1705D5F5C5F5E5C5E66626466696C6B746F6C696E6F706E6A6868646C6F6C6C706E696D
6668666467686B6E76787C85878F90939395999C9899989A9D9E98989A95949492908E8A
888886858787847E8082828288888C90959399959496918E8E9092908F91919292919694
92918F8E8E8F8F91918D8C928E8E8C91909091928F8F8E948F8F9293918B949696959494
959595909A9D9B9EA498876E5034332C2F3032272B2D2F282F3431332A31343536343437
323536312B30322E2C2B282C2F363B3A3732322D3E332E2E303036363739404541463C2A
26251C2024345E81
ACACACABAAA8A39EA19B95918B857E73665B514B4C484F5860656E7781858D919999A2A0
A6A5A6AAACA7A7A5A5A6A7A2A2A4A1A1A49C9A95918B8A837973695F524C5048474E5053
57545F5C585D5F5E6665636360636E72676264635E616065676264665E62616966696A6F
706F6D6F70727270727B757373767570727B71747A78757A71767978797C777A7D7B7B7D
7E7D777C7B74787B7E8D967C6E73726F71757874797374726E6B6C7A787777757A7E7B7B
8181857D79778A857D7F857E798A8D7D7F8D8D8A8F90877A7783848E91888C9393948D92
96998C859AA3A39A9FA4B3B0A19FABABB3B3AFA9B1B4BCBCBEB9AFAFB3C0C3C3BEB8B8BE
BFC5C8C0BABDBFC4C8C3C2C3C1C3C6C5C7C6C7C1BCBCC4C5C8C8CCCCC8C7C6CCCCCAB592
7362585D5E62635C656667656C6D697173706E7172726A6E6C6C696A6A6C6D7072706A6C
68676564656B6A6E70768083878C91919295989C99979A98989995949894948F928F8F8B
8C8589858681898483858387888A8D8F9297959292939192918C8C8F8E928E8F94979491
92918D938E918F8F8F8A8D8E8D90918C8E92909091928E94919091979490919294949798
93969399999C999BA09F9F97754A323229292D32342D29292C2D2E323335313033363132
303A3737313D3933322A28292F333D3E3833362E332B2C312C2B3A362F393F454A484436
322C20201E223462
AFAFAAA9ACA7A6A4A19B95958F8885766A5F52484B4B51585D67707581868D8F94999DA3
A7A7A8AAA6A8A4A4A4A5A7A3A4A4A3A2A09B9996908A8A847E746E5E515147494A4C5158
575858555C5C5E5F65686A626164616C5E6166686164646369646565616A61676C6B6C6D
6F6C6D6F707777776B6D6D6F71757570777579777876777878767A797E7978787C7D787B
817A7C7A797D7C7C7B7F9E87716C6E7472736E727B76787777726F7D7B7B79727B7F7D7E
7E7D79787D81848E8F8787827B828988848A88948B868982797B818A908D86818093978A
879CA19196A0A4AFA89BA9ADB5B2AAA2ABB1BDBBAEA6AEB1B8C1B9B0A7AFB5BBC0C5C4B9
B4C0C5C5C4BCBAB9C3C4C5C9C4C3C1BFC3C4C9C9C8C1C1BFC0C6CDCDC9C9C8CBC6B4916C
615F626464656867666D6C6B6F72717176766F717170726E726970686D69696C686E6D6B
6B6D6961646C6770717A7B7F868B8C8F9596979A979A9A999997979C9695959891919088
8C868A8A8989868985868A8B8B8C9195939494939292938D90908D8C91918D8E90919390
92928B8E8F8E8D92918F8B8C8C908C8D94918F90909091908F8E91929594939693919694
9191949A969B9A969DB3BDB6A37F53362E2C2B2D332C2A2B2A2F2B2D332C2C3230283432
3130323D3C32313433302E2D313340353836342E35303233292B3334312E323445434D40
3C2E241A191E2337
ABABABACACAAA5A3A0A0989A91898475766556514C494A525767727883848C929299A0A5
A4A8A6A8A9AAA4A5A3A6AAA5A7A6A7A3A29B9C948C8A8A847E746C6351555145444B4E51
545F565B61585D6462696B66696C6C67626865676269626064666466696D6A676C6C6B6D
676B7171767374786E6F727274747575757576747B757A76777678777D7A7C7F807D8081
80777F787C847C7F7C7B8682736D6D6C72756D6C7476777B7C797379737A7F7878817C75
7578787E8082848487838A817B8A867C7F85818890898189877F81838B87878275859297
938D9C9EA1A29C9DACAEAAAAA9B0BBB8A8A4A9BABDB7AEA6A1B8BFBFBAB3ADAEBAC0BFC2
BEBCB9BFC6C5C3BDBABCC4C6C8CACBC5C5C1C1C6C4C4C7C8C6C4C9C9CCCCC8C3AC8D6F61
65646162686C68686D6B6E6B6A70717170726E73746E6F6D716C706D726A6A6C6B6B6E6A
66676260696B6E71707B7E7F898F8D949496969896969694979795999497909591908C8D
8B8C8C918C898E8A858A8C8C8E9192969596929492918E8D8C9090919091909294909394
92948F918D8E8E8E8D8E8F918F8F8F888F8F9091938D91938E8E90939392909190929292
9392929A979A9798A0B8C7CCC1AE8953312D272F2F2B2D30302B2E2F2C2D2F3632373031
343530303635363335322C2C312D3A313836394039353735332C2F2E313131353D3F3F46
3B3126201A1C2324
ACACAFAEADACA8A1A0A09E9A968F857F7B6C5E534F4C4A515963717780818A8F959AA2A5
A3A7A5AAAAA7A3A4A5A5A5A2A2A5A5A2A09D9C988D8988837D736B5F5357474946514E55
59595C565C5B5A625E5F6365616561645F63616262636563696765636865656E6B6C6B70
706D716D7075726F6E73757170747573787878757577787978787678807D807E7A7A7F82
7C7E7D7C7D7F7C7D807F787B8080736D717370737878767B7F7D76767577807B7F80797C
707B7A7F7E857D7E858288847F828A80817F86868990938786858A838688898F8E8B8A90
979896979BA9A4959CABB2BAACA4B3B7B6B2A8ABB8B4B8BAB3B2B6B6B8BFBEB3B3B3B7BB
C5C5BDBABABCBFC1BFBEC3BDC1C4C5CACACAC3C2BCC1C7CBC9C5C9C9C6C8BDA986716667
6E6C6A696B69696B6A6B707272727074736F73727171736C706C6F6F706C696C6F686A6A
68696167686E6F7173767F858B8D8E909396989B9A9598909698959590929090948D8E8F
8D8D8E9290898F8A8A8C8E8B8E909597979A938F8F95908C8E8E908E9193909092949194
9490918F8F8F8D8F8F8F918F8D8E8B89918F8F918F8E90918F938F958B8F8E9292918F94
9394949698949599A5BFCAD5D2CCB8945A36272B2B2A2A2D2D2C2E2A2A292F2C322D3C33
2E3237323433363738393030322D313433323837343B372F2B2C32312C312F2F353B3C40
33382B1E1F1C1E21
A8A8A8AEABAEA6ABA49E9B9996918C8781766D5A504A4B4F54646F7784898D91979AA6A3
A2A6ABA5A9A6B5A3A6A4A59FA5A4A5A1A29E9999918E85867E756D6356555048454C5652
53555A5F5E5C5D645F61645F6761626062636466685F62656668676264656468656B6D6C
6D6F6F70716F74737271736C7178737376777474797D7B7778747D77787C7A7A7C777D79
7C7C7D7C7C7E7A7C787E7D7A97B1866960666F73757474777C7D76797B767B7C84827979
747973757A7D817E848587827F7F797B897E7F878782888F8D7B818A8C8D90939590918B
8898A09C909FABAAA5A4A6B2B7B2ACA5A9B8B7B8B1ABAEBAB9BCBBB2B6B9B7BCC3BFB6B4
B9C2C2C2BDB6BABFC3C4C6C5C5C3C0C3C8C7C7C5C2BCC1BEC3C7C8C8C3BBA1836D646667
6A70696A676A6E6D756F73756E7375737472727271767470706A6F6E716F6A686D6A6B6E
6C6569676A686B7472768085868B8F9695929797969A98969496959392929393908E948D
8D90948F8C8D8D8D898E8D909390969993969091948F90908B8C8E8C8E8F91908F959494
8F938D8D8E91938D8B8F908D8E8E8D8B8A928D8E8F8C90918D90948F8F8F9293928F9493
908F959496909197AEC4D1D8DBD7CFBF9C62312C26262A2D2E2F292C2D2B2F2C2C313532
3135322F363A37373634382E2C2D2F2E2D2E31323732352D2E2C2D292A302B2D333A353C
3E3A3B2824201B1D
AAAAB3ACB0B1ACABAAA09E9C9591928A827E70665D59484F5A657279858C8F95989C9EA6
A4A4A8A7A7A5A9AAA5A79FA5A6A2A0A5A39D9B93908E878981776E655A52534A474E4B4F
5256575D5C615B5D5D5F635F5F606262606567616361636360676963646862656F676A6A
666A6B747272717376707271727174727176767781827C7E7B787B7F7C7C81797D7C797B
7D7B7D7A7E797B7B73737A7CA1CFA967625B6E737E79787B847978797E7A7673807A7878
7C7776747F7D7F8082828387777A8A7C8085858585868787918B809096938586988A8F9D
92929B9DA59A99A4B1B8AD9DABB3B6B5AFABB5BAB9BAB7AFA9B7BCBFC1B8A8B6C0C4C1BD
B3B7BABFC2C1BFC1BDBDC3C8C9C8C3BFC2C3C2C3C4C6C4BDBEC4C3C0A98F766565616A69
6A6F6D716F72726D737072736F747673747573757473706F6E706A6D6C6F6C6D6C6C6A6B
68696466686C7471797A7B878C8C8B9291949596979394939895929193948E92938C9092
8F9090908F8C8E8B95908F92949598969C92928B8D8E8B8D8F8C8E8C8C90928D91919191
9190918D8C8F928F908D8C8F8F8C8C8C89938E8D908E8E918F8F8F91928C9190968F9090
948D8F908F9294A0B9CCD3DCDFDBD7D3BF9557332A292B252C2B2B2F2F2E282D2B343230
3938373B303633393B373435343228272B2D333333363239342F2A2A2E302A3030383736
3A38362B27241E1E
A7A7AAADB0AEAAAAA7A0A1A19A979292878175695F56515058686D7883848E95969EA2A9
A6AAA6A6A8A5A4A6A7A6A1A3A2A3A5A5A0A09B97948F8B847C74725F564F4E4A474D5151
56575A5A5B5F5D5D5E5C635C626160615F5F626262666C61656862686E6A6867656E676A
69656D706E727571767373787A787272717678757A81797B7A797F7C7C7D797E7980797C
807C7E7D81797A7A79777D798CBEA86D5B576A6D78787D767A7C717B7D7973797D7A797A
757B7A717E7D868C8381828A87857E7D838686878B8981888B8C8687838D958D919196A1
959D978A989F9A9BA5B4BAB0A5A5A2ACBAB3AEAEBABBBFBCB1B1BBBDBEC0BCB7B0B8C3BF
C1BDB1ADB5BEC1C7C4BEBEC2C5C8C5C8C7C7C2C3C2C0C0C5C4C1BAA37D6E69686D686D6A
716F737E7270737077737573757B777775727477726F737070746B6B6D706B6F6B6A6B69
63676462656C6E70717D828189898B8F929495969695999695929193928F9090938F958D
91918F91918D8F8E948D9195969797969893918C928D8E888A8C8F8E8D8F8E8D93929193
92918F8E8B8E8F908F8C8D908F8F8C8E8D908E8E8A8D908D90938F92908B91918F918C8E
9092918D909096AACBD5D7DEE1E3DED9D3BF995631242C23272D2D2B2A2A292B2E362D33
39353B3932363D3638343C3836352D2D2F2B2F2D34333737322E292F2C2F2F2E312E2F38
35363B362D272220
A4A4A9AEAFAEADACA9A99DA09B9695938883796D655D53515663707880888C94999D9FA0
A6A4A8A3A9A5A6A8A6A5A3A3A5A5A6A2A3A29A9A968C8C8280756C60594F4A4B4A505557
50555656585A5E605F5F5E605E606266615E6962636667606868676469686A696B69716F
696B73716D7573757D72737A76787274747776737B7D7C7B7C7A7D7B797C787D7E807C7E
7F807E79807E7B797C7A797A8198B19369666D7F7C7C7B747B78788175767B7A787D7C76
827A7A7A7A77858B8982868784867F7579838B828D8F828D8B8A8590928A95978F888EA2
9391A49F96939EA8A7A0A0ADB5B2A2A1AEB1B0B8B6B9B7BBBEBDBAB2AAB9BDBEBBB4BABC
C1C2BFBBB7AEB4C2C4C3C2C1C1C0C1C5C3C9C7C6C4C2C1C2BFB0997F6D686B6B6D6F6B73
7574758072757676727775777677767675777378777273747074717572717170686C6A6C
656A686966696C6F6E7A7F8284878C919092949699989594949293908E93918D9091938D
918F9392939092909193939A97999A9097928F918C8F888B8A8F90908D8D8C8F8E919895
8F908D8D908D8E8D8F8E8E8F8C8C8A8C8E8E8E8A8B8B8C8E9191928D908F928F928D8D8E
8E8D8F8C9294A4B8CED8DADFE3E4E4E0DAD1BB8B442726222A2B2C2729292B2E2B322E31
32373C3D35373634343C353A322D2C282B2C292930322E3933322F372F2F2B2D2F292E30
312F3733312D2824
A6A6A8A9AEB1ACADAAAAA3A19E9C95948E8A7A7569695A5C5B636F787F868D96999CA29F
A6A9A5A6A8A6A3A6A4A3A3AAA3AAA5A3A8A19F9897928F847D766A615E5151484B4E4B50
5256575B605C635E605F635F5B605F6863646261636464626667676B6A67686A6B6A6E6D
686C6E6E7679737777717179717A777B777B74797D7A79787C7D7B78777F7A7A7F827B7C
7B7D7B7A7B7E7B7B7C7C7A7D7D87AFC68D6F717D7C7B7A827D807D7E7A76767D7A7A7779
7D7F797E857D80848B8386838080858082898D8C858A8F898A87908F9499938E8A909A9E
9E9C9FA8A09A9293A5AD969EAEB3B6B0A5A6ADB8B8BDBEBCBBBABEBFB5B1B1B7BCBEC0BA
B7C0BCC1C7C0B9B5BDC0C2C8C9C7C0C4BFC3C3C4CCC9C3B7A07F706A6E6A6C6E706E7174
7474767A77727878747A7A77767576777576727375757371706C726D6E6C6D70696A6D6E
676964666A6E717174788181868C889090949594939390909291928F909493909095918F
94939093949392929392979A959A989495948C8C8B91928B8E8E8C8F8D8F948C90919190
8E90908F908D91938E958F8D8B8C878A8D908D8B8A8A8E8F9390918E9393978F918F8C8D
8E8A8A8B909FB3C9CFD6DBE1E3E4E5E5E1DBD1B77A3422272A282425272B2C2B33322C34
342F3438353431312F3B3D34353833292E2E2D2E2C2E3436363338302F2D2B292E2A2F29
3134363837343231
A4A4A6A6A6ACACB0A6AAA6A69E9C97958F8E807A7268675B5C68707A84869594999A9F9F
A9A9A7A5A7A5A6A6A2A9A3A6A8A4A3A7A49E9D9A96938A8780736C625B544E4A534E5455
57555A585E595D61625D5F6061625F636560625F666167676369626768676964696A6F6A
72706E737179707575737077787875807A7B727A7C7F787880787D7878797C7D7C7D7D81
7D7F7C7F7F7D7C7A787C797A7F7E92B298797B807C7D7E898880817E807B78807E7D7B7C
7E7D7B7E7C7F7C8388858482838D848080868081938B858491848E959A8A9AA19795A3A5
A09BA4A497A3A397A0B0A5ACADA5A7B2B7B8B4B5B0B1BCC1C0B4B7BDBDC0B7AEADB7BFC1
C3B8B0BABDC0C4C5C1BBBDC4C7C9CACAC7C2BDC5C6C7B9927F6C696C6E6F6F7073777675
747575787A7C787A787C7878787D797A7779757577747472716E73716F6F686D6A6B6869
6C6A60636E6D6B6F75788083878B888F8F9193969496938F9191928E9194919194959393
97949494919296999594959398969F989692968F8E908D8D8C8C908E8F91918E95908C90
8E909195908F8F9493918F8F8C8E8B8C8B908E8E8F8A8E8D918E928F9190928E8B8C8E8A
8F8E8D9097B0BFCBD5DADBDEE2E3E6E7E4E2DACCA65B24282928292D2C2C2A2D322A272F
2F2F363434353739333737383536312D2F2B2D302D2D333438373331302B2C2D2C302E2D
322E3334363C3A34
A1A1A3A7AAA9ABAEACA9A5A19E9E9695928D877F756E65636566737D82868D959B999FA1
A4A6A6ABA6A8A2ACA7A6A3A2A5A5A5A3A59E9E98949188847F7870645857534A4D4F5253
5D5A58555E595C5F60616361635F5B6360635F656460656B686263676669686A726B756C
6E7074757373767A71717C7575787879767973787979797A7B7D7B7E7D7D7F7D7B7C7B7D
7B817E7D807B7F7B7D7C807B797C7E877E7A828785838F8C8C8A8786847D76807D837979
7578787879797E89888B8D878587837C798088868B93867E8C8D8D90949A9D989F959091
A0A4A4ABA2A3A8A0A3AE9B9FB0B0ADA6ABAFB5C0AAA3B3B8BCBEB5B1AFBDC0C0B7A8AFBD
C5C0C0BAB3BBC1C5C7C3C2C2C3C3C4C9CECAC6C3B8A58D797272756F707070777B767876
787576777C7B79757B797874797477777775777576737373706E7170696B6C6C6E6D6569
65666368696F7272787981838A888B8E908F939593949492909292908F90929593939591
939393949593959893969998989B94989391929091908D8C8C8E90919292909291979494
918E8D918C8D8A8E9191908B8F8C8B908C908E8E8C8D8F8E908E8E8C90928E908C8B8E8C
8F898D94A9BAC7CFD5D8DBDEE2E4E5E5E5E7E2D9C3853823282B292B2B292F292A2F3031
3332353337373535333536343536352E2E2C2D2A2F2B3331393C3034302C2F302B2B2D2E
2E2D2B3438393933
A2A29FA5ACA7A9AAACADA9A8A19F9D9C97968B877A796E6A6A656C757E88889497999CA0
9FAAA9A5A6A4A7A7A5A2A3A7A3A5A5A5A2A0A19C98928D8C807B70615D5659534A4B4C54
5A5157555C5E5C6461666E6A615D6464646362676065616B66696667636A69686B6F6F6F
706F71717E737672797B7775787B7B7678797A797A7A797F817D7A7C80797A7B7F80817D
7E7C827D807C82817D847F7C767C79807C778891A7AC968F97939190888984867E7C857A
7B7A7F777A7B7586898A7F8D87847C7A8384818D91938C858B7E909B918DA49793929D98
8EA0ADAA9E98A6A0A5B4B2A5A1A2A7B1AAADAABBBCB7B0A7A5B7C1BFB3B2B6BCC0C1B6B2
B5C0C1C3C2BDC1BEC0BFC5C8C8C8C2C4C5C9C6B79F826A7374746C75736F717371787A79
7D787976787A7A777A7975787A797A7A7676777673757573757172707071706C706E6D6B
69676767706C707075757D838786888F8F9292949495938F91918F928E8E939494969593
9090959198979395949797999A9A9597908F8C8E90908E8F8E8E8F918F8F939290909194
8D90918F8E8D918D8D8D8E8C8E8F8B8B8D8E8D8F8C8C8F8D8F8E8D938F8E908F8D8D8A8A
87878E93B1C2C9D0D4D7DBDDE0E2E4E4E6E7E5DFD7B9702926242D28292A2E2E2D293033
282D33353337393B36363538343D3D3B312C2F2D2F2B2D31353233363532362C272A3234
362A2D2B30373231
A0A0A5A1AAA9AAACACACA9A8A2A19C9A99968E88807874706D67707780878A9A969B9DA5
A2A9A8A8A3A6AAA4A5A1A4A5A2A0A6A5A19E9F9C958A8E8582776A605954504E5256565F
645B5E5C605F64686A6363616565625F626666626264656463686D666B6E6C6A6B6D6F70
7070726B78727D707474787177777B7F7779777B757879778179797E7D797C787E7A7E7B
7B7C837F7E7E817D7C807C7C7C7D7C7E7C797C8AAEB49A9098A39B9693918E867F81817C
7A7E7D77787D78847F8688858D858684888583808B9B8E90999090A0989595979D989599
A09794A7AFA4ABA0A9AEA8A9AD9F9BABAEB9B2B1AEB6B7B0A9ACBBBBC0BFB5B4BABFBEC2
BEBBBCBFC3C7C9C3BEBDC1BFC6CACACAC2BAA584706F6E79797871737A777777757D7976
787D7B747A7A7F767C797A7C797B787C7A7973767174727072707670716D6F696A6D696C
646663696C6C707475798086848A8E938D929193919192918C94908F8E92919593939391
949296929A979D9A95999A96969B9597948E8E8F93929092908D918E9291929093939590
9091938B8F908D908F8E8D908B8C878B8E8D8D8D8A908E898C8F8E8E8F8D918D8C8B8B8B
8A8B93AAC2C7CFD4DADCDCDEE0E4E5E4E7E5E2E0D6B4702F24212A26282428292D302E30
3331292E343A35333233303333333534332E302D2E2D303232314D373432352F2F2C3736
382E2D2E39333238
A2A2A3A1A3A7ABA9B0AFA7ABA59EA19A95978F8B857C797377757278838C98969A9D9EA3
A7A5A5A4A5A8A5A5A4A2A0A5A6A5A4A39F9E9F979792908480726A635A554D4E4C4D4F57
65675B6465635F615E5F636565636268626266626364636363666A6A666A6A6A6C6D6D74
716E757279767574777575797B77777779777B7B7A7C7A7F7C77787778787E7D847F7D7F
7F7F7E837E7E7E807B827E7F807D7D7B7E7B797F848F827F899FA69F9698939286817E7E
7573797B7D887C8687878D85878B8888838A848B8897A1989192959A8E93958D99AAA292
96A7A1A1B0B0AC9CA0ACA5A9B0ACA9A49FACB9B8ACABACB0BCB3ABB0BAC2C5BEB6B1BDC3
C6C3BDBABBC0C6C7C3C8C3BEBEC7C9C7B1997F6E6D6D72777679757677767977787E7B78
7A7878787A7E7F767A7B7B7F7C7B7B7778737273717776777371746F72716E6E6F6E6969
67676B686D716C7375747D8186898A8D8B909691929494948D94938F9194919293939A94
9195949695999B9A979999969697919195918E8E98929394908F90919291959093929394
9090908B90908E8E8D8C8E8E8E8B8D8C8A8C8A8D8B89888B918D908B8D8F90968D8B8A88
8A8DA1B8CACED3D8DCDCDDE0E3E3E3E3E4E4E2DFD7BB83432C2C272B2B27292C322B3035
2B312A302D34373536373032373634343535332C2D2E35302F33332E31302D2F312E3A30
38322B2B282F3035
A0A0A2A2A3A5A3A8A8AEAEA7AAA2A29E9B95978E90857D7C797578777D898C92989A9BA0
A1A3A4A8A6A4A9A8A2A5A3A5A7A0A5A1A0A09B97979187877E72696258554E4D4E575555
585C626060635C626265626465636968635E6661696663625F656C6E6C6D6A6A696F6F72
7173777174747A7676787B7B7B79787E797D7C7C7E7A747B7C7A8178777C817E7C7B7D7B
7F82807C7F7C7D827E8080807E7F827C7D7E77787A7C7B77798A8F8D9994959D948B8981
7A7674787A8B81858E848A88908A98958C95968A8C8E8F98A18F8FA2978C9A9D9493A3A3
8F9EA0AAA797A7ADA6A4A1A7B5B1AFACADA6ACB1B9BBAAA1B4B4BEB9B0ACBCC3C2B9B2B8
BEC0C1C5C2BFC3BFC1C4C8C6C3C3BEA98976726E6D73757C7C7A7B7A7D7C7D86817F7B76
787778807C7E7C7B7B7A7F7D7C797A7878747675757373716D70706C6F736D6C6C6D6A69
67696C696F717371737B807E828989919193949492908D918F939091908F999092949793
9395939797999896959C99989794959393949491978F95938F928F8D9493909297908F90
8D8F8D90928B908D8F8D8E8D8B8C8D8E878C8A8E8C8A898E8F898B8C8C8D8B8B8B878989
8996ACC0CED3D6DBDCDDDEE0E1E2E3E3E4E2DFD9CDB8844D302E2E2A2A2A262E33272B29
332E292B3634363831313937383131363E333C3D363433392E2E30363B33342F2E31312B
282C2E2C2E322D33
9E9E9EA0A1A6A4A7A7ACAFACAAA5A5A09E9895918D8782817B7B7A7F7E878A91969A9DA1
A5A7A4A4A5A6A6A4A1A5A7A6A8A4A8A4A29F9F99969585887E786B5E5A564D504E525658
535F5C5E6363615E5F5E5F6364645F6668646463656562656668686F6E6766696D6D6D72
747371717774757779787B79787A797C7E7A7A7A7F7F7A797C7A7F7C7D7E7F7D7B817A7B
7A807F7B7F817C7C7F7C807E7C887F7B7C817D7B7B7D7C797F7E8480838685919C90968F
8A81797A7E83898F97958F8C8E988E919388948D8B9095889E9F94949A9593929499909E
A79F9096A9A69FA2A9ADA2A8B2B5B3AEA7B6AFA6AEBCBBB2A5A3B7C0BDB1ACB6BABCBCBA
BBB9BBC3C4C8C8C5C1BFC4C6C3B49E807171706D7670747E7F7C7D7B7A7F7E827D7E7C7F
7A7C797F7D82817C797D79807D7A777D7B787A7372716F756F7272717471706F70766A6D
726E6D6B6A6F70707A787F83858A8C8D8D8F939294969690909292919190939494979493
969896999896989696969D95949595929792949391929291919497929393918E93938E92
8F8F918F908B918D8C908D868B898B8B8B898E8C8D8A8E8E8D8E8D8D8C8F8C8E888D858A
8CA4B7C6D1D3DADDDEDEDDE0E1E3E4E4E4E2DAD3C7A6785841332C2A2E27282C262C272E
2A2F30353839393A383C32353D36393336313335373132332C323037373C3A302F2F392D
282A2C2D2E322E2E
A2A2A39C9FA1A3A6A9ADABABAAA6A5A19E9C999790898788817D7E7F7F868C9093989B9E
A1A3A6A5A7A3A7A3A2A4A7A8A6A5A5A5A2A2A399908F8A8581786C5F5C5550504E525755
58595D62635F5F65686565666B63646563656B68686967656A6768696A69666F6F6B6F73
7B737373787878777B7777797A7B75778081797E7E817E7D7A817B7B807E7F7A81857D7E
7F817C80847E7C848185837C83827F81808080797E7C827A82827D7E7E81808085868488
8B85857E7D7A888E9696918D8594908E9B91908B98949496948C91A28C869D9A939D9C9C
9DA0AA999AA5ADA196A8B5B6B5A8B9B7A8B8BCB8ACA6A7BABCAEAEB0B5BBBCB1A9B6BBC3
C4C1B7BEBFC0C9C9CBC5BFB8A99079726F7473777973757A7C7E7E7D7A877F7F807F7A84
7F7B7E7A797D7E7E7D7B7B7D79787C7C7B767B7778787577756A737372736F7174706C6E
706B6A65727C6D737B7D7F818A8F8C968D8B908E9290908E8D9090919394959495959492
979B969A999998989A9A99959794949293979595939796908D939691929492929093928F
8F919094908F8F8A918D898C8E8E8B8A8B8A8D8D8C8E8F8E8E8E8D8A8C8C8D8F89888A8C
99B3C2CBD4D7DCDDDFDEDFE1E1E4E4E2E3DDD7CCB793786853432C292A2E292D2A2A2431
34292A2E2E343535333634343437353035343633342F2F2C2B303837353232302E2D2A29
3628292E2E37302C
9E9EA2A3A1A3A7A6A8A8AAA7ABA6A7A2A19E9E98938D888A83817F838687898F91979CA2
A1A5A5A5A4A2A3A4A0A3A2A2A7A7A2A5A3A3A198948D8C867F7770625A554A4F53575859
59595C5F605F5E6365666668666062676665636768666768706868676A66677071707079
7976757479777B76797579767B7A7E797B7F7F7D7E807B7E7E7C7D7F807A7D7F7E858384
85817A81837E7E7E7E7D7A80837F7E7F817E7D7B8183787A7E7E80848286827F80817D81
817D8485847E8483909A9293858B9591959B9C938F97908C888E90A2A09296A0A09C98AA
A290A5AEA99BA8B3ADA3A8BBBFB5B2AEB2B2A8B2B7B1A5A8B1BCC0B1A5AFB7BFB7B3B8B8
BDC2C3C5BFBFC1C6C5BCAF9D7F716F73757C737476747B7C7E7D7F7E7B7A81827E7F8083
7C7E7F7C7A827E82807A767D7E7A7B7A7D7A76767C7676797C6F71717573747071726B71
6B6B6C6A6B7C6D74777C7E85888C8A8D8C94919196908F8E918E938F8E94939494969598
9C99989C999A99989B99939C959793999699999596939194949293939392949494929293
90928F8F91938F8D8E8C878C8B8F8B8D8F8A8D8E8E8D8D8F8D8D8E8B8E8C8E8E8A8A8993
ABBECACFD3D7DADEDEE0E0E1E2E3E3E2DED7D0BFA4857A71635B3D342F36252B29282836
372C313034323331313735373836383A3234343534362D302B2B2D303335393B3031312C
3030292B2B2C2E33
A0A0A0A19F9EA2A4A5A9A7A9ABA9A7AAA1A19D9C9390908D8484818087878A8D92949B9F
9EA4A2A4A5A3A6A1A4A4A3A4A3A6A2A6A09CA196909089897A766D615E5652545858565B
63625C626860676366666B6868625F6C65676968646864696C6A666369686C6C6D737175
7A76757374797A7A78777F7A7B7B7B78787D7D7E7A7F807F837F7E7C7F7F7A7E7E818082
81838B7E7F7B7F818081827F83847A8081807D7B807E7A7A7F83817D7C7C8080807E7C7A
7F7C7F807E8083818A90989488908C8E9292A2958793878E868D949492979A8F97AAACA3
A1A19FA1ACADA8A9B3BAACB0B3B9BBABAFAEB2ABA8A8B6AFA5ACB9BCBBB5AEB6BABFC4BE
B5B8C1C7C0C4C1C0B49F8476727075737376757C76787D7B7C7B817D7C7F7D7C817C8382
7C7D7E7F7A77807D817F7B7C7C7B777C7B7A7A7779787674776C7073756F6F6D6F727373
6E696A666A706D747A7B7D8486858B8D8F929092928B8F919192908F9495939595959596
9A9799999A989E999B999A9695949799979B959496959393919497999492949593919390
8D908F8E959394908C8B8C908C8D89878A8D8D8A8F8F8D8B8E8E8E8A8E8C8D928A888A9B
B4C5CCD1D6D9DCDEDEE0DEE0E3E4E4DEDAD1C8B19178797E6F6251403127272D312A2E29
2D2E35312F2F35353038383A3736383831382E373832352D3329292E343633352F35312F
302F2E33322B3033
A2A2A19EA1A1A1A3A5A8A8A9AAA8A7A5A5A29B9A9893928E898688898A8A85908E979A9F
A4A2A3A4A4A7A3A1A3A3A2A5A6A6A3A39F9F9C96938C8C837E7668665F5554514F5A5757
5F5D5D6066626663676D686B66666A6B626A6B6666696966656A696A6C706F6B6C6E6D75
7274777276787B787A7E797B77767877817D7D7B817C827B7D7E7E7C7C7C7E7E827D7F7E
7F8780827F7C82817F7A808381837F807F818383827E7A8182837E8080817E7B8080817E
827E7B817C7F7F808A8D8D8D8A918F9690969C93928C84948D918C8F968EA3A6A19EAFB0
A19FA8ADA6AFB4B1ACB8B3B6B0A9B4B8B7ACA2AAACABAAADB7B5AEA8B6BBBEB9ACB8C0C4
C2C2BFC0BEB7B0A391826B6E73747577787C74837B7B7C7D80807F7C7D7E7E7D817E8180
7C7E807B7A79817C777D7C7C797C7D82767B777778797778756F70727572707272717173
6D6A6A686B6F736F757C858387868D8C8C919293938E91948E9190939694949393959697
9696999C9799999B979D949C959597979696979597969697989497969393969393919593
90928B8E938F8E8F8C8D908C8D8B8B8B8B8D8D8A8A8D8D8E8F908B8B8B8F8891898F99AB
BEC9CFD4D8D9DCDEE0E0DFE1E3E2E1DBD4C9B6997E767A79787369513A2F2D2D29252629
2C2F2B2D2A2D2F312C2E32353A333C3632382D3135353434343235342D302C3334323131
3333292D2A2C2C2A
A0A0A09B9DA2A3A19DA2A9A7ABA8AAAAA5A39E9A9A9392908F8C8A8B928C888E9397999E
A0A4A3A5A5A1A2A1A29DA1A3A5A7A1A2A4A29A97938F89837E786D656155565353515959
605E5B5967666565666968676966666964636C6A66656567686C6668636D686D6C6B6F75
7174747477757879777D7D7E74767B777A7A7D7E8182827E817C7A7E7A7A807D7B7F837D
7D7F828081818482807E83818382887F838583807C877C867E80807F7F7E837F81818181
817C807E7F7E7D7B7E848D908C9293989C8B9DA09791878D94959A9091949797AEADA2AA
B5ADA0A7ACA9A4B7B8B8ADB9B9B9AFA9BABCB7A19FAEAEA8AFB5C0B6AFAEBABCBCBCC1C3
C2BEBBB6AF9E8D7D7675737777747573777C767A7D7D7F7C7E807C7E7C7C817F82817B7D
7F80817D807E847F7B7C7D7C7D7E7C807C7B7578767B787874777B7577726F73716F706D
6D696D686C6E6E7077767F8388888C8E8B8E9B928F8F8E8D8E9094908F94989191979A98
989A9CA1979C99979A999697989896999B9997979897989A9696999A9499979691939395
91909297938F8C8D8B8C8F8F8F8C8D8E8C8E928B8D928F8F8F8E8F8A92898F8F9198A8BA
C5CDD1D6D9DADCDDDEE0E3E3E4E3DDD5CEBEA78975707476787973644C3A312A2A28282A
2D2E2C292B2E2E302A2E2C33333B37353234393537353231353230312F322C2D30302F33
2D2C2F2B29312C2D
A1A19FA19F9F9BA1A3A0A5A6AAACADAAACA6A1A09999938E8F8F8D8F908A8E8D92959B9F
A4A5A6A4A2A0A5A3A4A0A1A3A2A3A5A4A29F9C99928D8C8883746A645D5756525354595A
5D6061595F636364676D6767666965686662656668696B686F6E6767666D6C706E6F7272
7071757677757A7A7975787B777478787C7D7B7D827E807C7C827D7D7C7C80807E7E807B
7F7D878B81807D82817F827F7B82847E83877F82827E7C7C7D838086807F80858A817C81
7F807E7D827E7B807E7D7E848A8F94968D9697959593979A89949F9198959C96A1AAB0AE
9D9EAFA6A1A7B0A9AAB9C1BAABB8B6AEACAAB6BAB0A8A5B2B3B3B7BBBFBFBBB8BCBBBDBD
BBB29D8E838172726E6F727978787A7B7978797A7E7C7D8080858280817D827C807F7B7E
7F817F7B7C7E8080817B80807D807C7B7C77777579757979767372757673736E71706F6E
6E6B6A686E69707274747B87868A8E8A8E8F93928F919091929493929191959497979597
9D9C989B989D9B9A96999C9A9E97999C989B98979998989798979C9A9599999698939393
9690909295908C908B908E8E8A8B8C8B89908D8D8F8A8C8F8A8C888E8C8D9091959DB4C0
CAD1D4D8DADADDE0E0E1E2E1E1DED7CFC0AB8E7871707872777C7B665D4B342D2B2B292A
2C292A2F2C2C2B2B2E302D2F38343137333234373434343736383333302F272C2B2D2B2F
312C2C2E31282A2F
A2A2A3A19FA1A0A0A0A3A6A6AAABAEA6A9A8A19E9D99979392928F8F908F93939096999D
A1A3A4A7A4A8A0A2A3A0A1A1A3A2A4A1A19B9E9A94908783807A6C63595E515459595C5B
5F5A65636364626B666A6966696B69646665656368686B666664676768686E6C716F7370
72746E7475797A7C797C7B7B7A7A797D7E7E7A7C847F7C787C7A7D7E7A7F847B7C7E7F7D
807F8084818285808082827F808983808382807D7F827B817E807D81858180868D818283
808187817D807C7D7E7B797C7E8A83919791999A94969B949FA1999393978E939F9FA4B5
B19B9EA6B2A2A6B0B4B4B0B6BAACA9B0BABBB4B0B4B9B9B2A8B2B9BABFC1C1C1BCBAAA9C
928D80767571727B70747A7A78797C7B7B7C7A7B7F8186828283828481808280887F7D80
80807E7B7C7C7E7D7D7E7B7F7F7F7D807D7E7F7A7A7675797578777B776D716E73706F70
706B6A6E6D6F7274777E7D8482878E888C918E93928F8E8F90909190919696969397959A
999C9B99999B999B98999B989A9A999C979B98949F9798999C9A9C98959698969C949493
919296958F908F908D918F908C94908C8D8D8E8D8F8B8C8E8C8D8D8B8E90939497A9BDC7
CED2D7D9DBDBDDE0DEE0E2E1DFDAD2C9B69D816E6B6C75787E7B8174675D483A302A2529
292A2A2D2B282C2D2E2A2F323539323A3637383638353B36363337392D312F292A2C2B2B
2C2A2F2D312B2F33
A3A3A3A0A3A0A29E9C9EA1A6A8A9AAA9ADAAA3A09C9B9A99909393938D92939692979C9A
A1A3A29FA0A4A39E9F9FA1A2A8A2A3A3A19C9B99968D8B8480796F645F5C5B545258575B
5C61616962636465646665676866686A636B65676B676A676662666565686B6A70717471
7270707071787778777A79757579777B7B807D7C7D827D7A7F7E7F817B807E7C8381817E
7E7E7E7F7C7F7F817C7F8583857F7F82827F7A7D7D848282837E7B7D8181848384848080
8080857E7F7F8381797C7D7B7E837D818495918E978D909A97939C969091919396999F9C
A2B2A194A7ABB3ACADBAB4A2AEB8B7B0A9BCC7BAADB2BDC3BAB2AFB9C0C3BBAE9E9D917A
77787377797374777378827A7B7D7A7E7D7C7B7F807F848384837E8182838281827B7E7A
83827C807E7F817D7E7F7F817D7C7E7E7C7F7F7C7F75787879797676756E7371726F7270
6D6C6B6A6E6C71727A777D8583868A8B8D8E9293918B918E8F978F91929997959799979A
9C999A999A9D9A9A9993959A9998999998989597999D9B9B9A9A9B989696979A9A969698
9595969394918F908E8F8F8F8E948E8C898C8F8F928D8C8E90908D8B90939196A3B8C4CB
D2D6D9D9DADDDEDFE0E0E0DEDBD6CBBCA9866C6F676C707876787E7D766A5D4C332B262A
2B2D312B2C2A312D2D2C313236323738353436483C413939383F3F38342C2E272B2C2A2A
2F342E3136312F2D
A3A3A0A0A2A09FA4A0A2A3A3AAA7AAABACA8A4A39F9B9A99969693959597979394949A9E
A2A6A2A0A3A1A49DA1A09CA1A5A3A4A2A19E9B97998A8B84827E6D685C5F595352555C5A
5F5F5C5E5F676466676C6B686B696A6E656568656C646866666A666768696B6C706F7274
6F70716C707776797A7D7A77797D7B7C7C807C7A7B7D7C7D7C7C807E7F8080827A7D7E80
7D7D7F808283827E808085827F7C7D7E808180827F817F7E80817E857D80837F81828783
7E817E827F8280817F8081807D80807E8188847E858E7C899D8C84969A8F8F8F8E90989D
A09EA7ADA99AACB9AFA1B3B3A8A3B3C0B7A8B3C2C1B4AFBBC4C3B6A4A2A0A18F7C7B7872
757675747476797B797B7F7A7F7C7C7B80797E7D7E838483838181838483818184807E80
81837A7E7F817F80817D84827D7D7D7F837E7D797B7A7779797976747170706F746F7272
706C6D6B6E6D707377797C7C808A88908F908F8F8F8C918E919692939696949898989C9A
9E9A9C9E9B9A9B9E9896999A979D999A999B999A9B9B9B979B9A9E989995989696969998
9696939590928E939792928E9091908D928D8E8F918A938C8F8C8C8C8E919098B0C0CBCE
D1D7DADCDDDFDEDDE0DDDEDBD7D0C6AF9574696C69666E7572727C7E7A736E624E3C2C27
2F28262A2A2C2D2A2930313233333A3D34333C37373D3A3C3938343334312E2A2A2C2E2E
312E272E2D303035
A3A39FA5A4A3A09DA0A0A2A5A4A3ABABA9ABA2A0A09D9A9B969895999596949497989A9C
9FA4A2A2A6A3A2A49D9FA4A8A49FA2A39F9D9E99938F9282847C6B66615B5A5156545D5A
6363616461676768676C68656C6E716B666467656466656C66676964676A666C726C6F6F
707271737677797978787A7D757B7A7B7A7A7C7A7F7E7D7E7C7F7D817D7D827F847E7C7E
7F7A807F7F7E8482807C7D7D80818283857E7F827F7D7D807C7D82847F81848184858881
867E8282807D7A7D817F817C7C7D858487817E7E7E7E7984858D7D829A9C8890918F938C
959A989EB4B39CA2B7AFA4A7B5B19FAFBFBDAEB1BBC0BEAFA8A7A88F7F7A787571737671
777671757A797C7B7D7A7B7C7D7E837D7B7D80807C80818383838184838280828280797D
7E7D7F7D7D7C7C7F807B857A7E7D7D7C7C7B7C7C78787879767674767571757672706F6E
6C6A70676C71737577787F84838A8D8B8B938E949191918C9092959495989596999D9999
9B9C9C9C9B9D9D9C9799969B989B9B979B9798989C9C9A989A9B9C9999969698959A9896
9398939094939391929091938E958E8F92918E8E8F8B8F91918C8E8C8E8F98A8B9C6CCD3
D6D8DBDCDEE0DEDFDEDFDDDAD2CCBDA07E6F6D7D706F6F707671737C767D786A5942302D
2F2C2E2B2B30302F2D2A2E3231343232393637383A403F3B3B38383333332D302B2B312B
2C302E2B2F30302D
A4A49FA1A49FA2A09F9EA3A4A3A4A8A6A7A8A5A0A49C9A9F99989D99999698969A9A999B
9EA5A1A4A6A5A5A0A1A19DA4A2A1A1A49F9C9A9A958F8C837C7469675C59574E55535E5B
595A5F5F65636A6468666D69686D686D696A656C6A6B656666656866666B686D746F716E
7675747373787D79767A797B787A7D787A7C7B7A7A7D7A7B79817D827E7E7B817C7E797F
7B81817E808281837C7F7C80808481808483817E7E7A7F808183958F828482808186838C
82797F7F827F7D7E85807C8082898C8981797B7E827E7C7B7F7F807E84958D888C8B8789
84889C8D92B2B89E9CB1BAAAA2B2B1A6A6AEB8AEA0A4A79B867C7F7C7277777675747679
77767B7A7879807D7C7D7E7F7D7D7D7E7A807E817E80858285807F847F817C80807F7E79
7F7C7D817C7F807D7D7B827D7F7E807B7C7F7E7C7D7B78767477727075706F7678716F6E
716E6B6A70717673777980818588898C8C8F8F908E91958F90969593979797969A9B9A9D
9C999E9E9B979C9999989A98969999979A98989D9C999A9B9B999D9B98999B99969A9899
9595969392969394959390908E948D8E8E8F8E97898F9190918E8E8C8C909EB2C0CCCED4
D6DCDCDDDEDFE0E0E0DEDAD4CFC0AC8D6C626776696A6D75757774797D7D7C7369585240
2F2D2B2C2A3230302C2A2B312E2E303434363C3A373C383D343738383E352A3B322F362C
2D2C2F2E342D2C2F
A1A19F9EA19F9DA2A0A0A0A3A2A2A7ACAAADAAA3A2A19D9B99999C9B9A9C9E9B9E9BA09A
A0A3A5A4A0A09F9F9FA19EA1A3A2A1A6A1A09898968F87817E716A616058534E5254605C
5E6261626365646469676B666A67636A626663666B6966656C6566676B68686C726D6B6E
6F757876757778787973767A767A7F7C7B7A7C79777B807C7D7C7C7E827E827E797B7B7D
7A81807B7F8082818180897F818B7F7E827F7F7E7D7C7D7C867F868684807E8282828185
7C8084807D7C80827C7D7D82828484827F7B7E7E7A80807C7A7A7F807A7C7E7D7C7E7B7D
827B82948B90ABB19A90A8B4A2929AA3938C8F9483767A7C77747779767B7C7B7C76777A
797A7B79787C7B7E797A7A82807D807B7F807F807F7F7F8181818284827D7C7F7E7D8080
847B8182817F7D7D8380827D7D81837F797D807D827C7A7A7477767074766F757672706F
6F676B6E6C707472747A827E868B8A8D8B8F93968F9297919596989A9A97969999999E9C
9F9B9D9A9A9A9B989B9B9A9B9A9A9C989F9D989A999B9E9D999C9C98979C9E9C99999999
989795949596969390908C8E93948F8E8F8D8F918D8C90908A92908C8F99AABBC8D0D0D6
D9DCDDDDDFDFE0DFDFDDD6D0C8B29A7665646A66696C6C7079716F7279817D7F78665E51
3B2F2C3130302A2D2B2C2A2F322C31313536323A393B3F3D3A353433333037363C312F2B
2C2C2F32302E312D
A2A2A19CA1A4A49DA0A1A1A2A2A4A7A8ADAAAAAFA6A39FA19C9C9F9C9B9C9C9C9B999C9B
9CA0A1A0A4A0A1A19D9E9F9EA2A4A09EA29D99999490847F7C756A61605D544F57565B5E
5D6164666861636D6A6365676B64656A64646A6F69646667656469666565666A6E6C6B6E
6F72727775747975787A7A78797A7C7B817F7A7D80807B7F7E7B7B817C7D7D7D7D7E7C7F
7B7C7C7E7E817E7F7D7E7F7C84807F7E81817E7F7D7C7F7B808080828180848180818285
837F83857F8080817F807E7E808686817E7F81847F7B807B85828283827E7F7C7D787B7D
7875777C7E7980928F80808C8A7D797D7D76757A7475737478777778777D7E797578787B
7B877D817B7E7D7F7C7A837F82828180817F807F7B828181818282817F827C7E82827D81
7E7C807F85847E7F807D7D7D7E807D7C817B7B797B7B7C7C747579717070737475757173
6E6B6C6C70727172737B807E85878B8B8A8D8F918F92938F95969796989798979D9C9A9B
9C9B9E9E9C9C999A989A9D97979E97999B9798979D989C9A9D9A9B9997999C989C9A9999
98949A949795948F9093908E91918F8D908F909090908E8F8D8C908D929FB6C5CCD1D4D9
D9DBDEDFDEDEE0E0DEDBD3CCC1A8876B626A666C6B6A6E707274717578797982827B6B61
4F39322C2B29282E302E2931313133333631363C3B353B39353E373A3534323435322D2B
2B2D2E2E312F2B30
9F9FA4A0A2A3A5A1A3A29FA2A1A3A6A7A9A9AAA7ACA5A1A1A19F9F9E9C9EA09E9E9E9D99
9FA0A29FA7A09F9DA09FA09DA0A1A0A1A1A29A95928E958081796D625E57554F5A575761
5F5C61666364676964666A676B6D6A6965656E6A63666C6A666863636C6966696C6F6D6F
6D717271737C7C777B797875757477797D7B787E7B807D7A7B797E787D7F7F7D8380767B
7A7C7F7A7D79828480828480827D807F808180807D7F7E7F7C7E8083807D80807E807F7E
81817E8480827D7D7D84808081817C837D8180827E7E8180868281807F7D807B7E7B7E7F
7B767A7E7C7C7A797C727A757671787872777C7676747A77797478757D7A7A7A7B7C7E7A
7D807F807F8180827E837F7C7B818181808081807C808084828281857C7E7E7F8383827C
7C8181807B7D7B81807B807D827D7F827E757777787E7B7875757B757274727471716F6F
6E6D6E6A6D6D7373787A7F7F878A8B8C8B908F94929492949595979A9B9A99989C9F9D9E
A19C99999B9B9A999B9A9B9F979C9A9C9B9998979A9D9C9D99989A9C9796A09D9E9D9798
9B9897979597939292928F92908F918D9190928E8C8D8B918B8D8D8D97B0BDC8CFD4D8DB
DDDCDEDFDDDFE0DEDFD6CDC6B394786461676A6C6D6C6A6F6D747277777A7A7D82897772
5F49402C302B282A2B2A2D2E2F3030303937353C39453E3E3A3931343634323833332F2E
2C2C2C30332E292D
A0A09EA1A29F9EA09C9FA1A2A09FA5A5A9AAA8ABA8A5A2A19FA2A49C9DA0A0A19F9E9F9C
9EA4A5A1A29E9BA0A2A1A2A19FA1A2A2A09D9A968E8B887D7C7069655D56595151535A5D
5962646B6766636866646B66686866696668696C61636B64646169656867676A6A6A6F71
6E707373727A7879797A757777767A807B7C7F797C80797D7B79807B7A7D827C837E7B7D
7C817C81807C807F7F807F81887D84817D817B7D7E81837D7C818483817C808384837F83
8082828380827C877F8182828283827D7E7F7D837D7D807E878481817D7D7B80817B7D7B
7B787D7A7878777477767A7B777A78747477777A757274767877787D7C7E807D81817F7E
8381818081818682807F817C7C7E81817F7D807F787C7F82848289837C7D7D7C8383857C
7E7E807D7D807D7F7C7E8280827D817C7D7C7D7A7B7A7A78747179757372737773717873
6E716D6C6E727578787E7C7F8889858E8F918F93929795959699999A989A979C9A9E9E9A
9EA0999B9C9C9C9B999B9A9D9B9B999D969A99989A99999A999A9A9C9A9E9A9A9D9C9D9D
9B9899979695929497969195959197918D91928C8F8C8A8D8C8C8C94A3B5C4CBD2D7DADB
DCDDDEDFDEDFDFE0DAD3CABAA2866C6368676D68696D6B716F726D7472797A7C84838176
715E513D2E2D2B2D29292A2B2E2B2C34302E3636373A3C3D36343436313A313334313035
312B2E2D2D2D2931
A3A3A19EA1A49FA19EA0A4A5A1A0A6A3A5A8AAABAAA8A7A6A3A4A39FA0A3A2A4A0A0A1A0
9DA2A1A0A3A0A0A1A19E9FA3A1A29FA19D9D9A97928A897F797366645F58545153585A59
6457596C66667169666C65636364656664666662646B6566636962676666636867696B6F
706F7272767B78797578787A76777E7A788076777A7C787A7B777B81807F827D7B7D7B80
7A7D797C7C7E7D7E7A7F7C7C82807C8282807C8480827F82837E828484827F8181867C81
80807D808082827D7F7C81818080867C817F818081807B8282807D7E7C7C7A807D7D7E7D
7E797A7A7A78757476787975757976787B797A797678737B787979787C807F807C827F81
8684847E7F828183807E827C7E8380837F7D7F807E7B80818281817F7E7D7B7D807D8281
7D7D7B837F7F7F807E7A8180877E7B827E7D787F7C7A797877737570747275736E78756E
6F6D6D736F70747F7A7C828586878B928E9193939292949898999E999C9C9E9A9C9C9F9B
9F9F9B999C9C9E9A9C989E999C9E9A999D9B9D9899989A989C989A9D9F9EA09C9D9B9B9C
9C989999979898969595969494968F92948F908F908F8D8A8C8B8D99AFC1CCD1D5D7DADA
DDDEDEE0E0E1DEDCD4CDC6AE95786462696D6B6D6A70717572716F7174787C7A7D84837E
7C71615134362F2A2C2C2D2A2E292B2F342F343A3537333A333C34322E35373731312D2E
312E2C2D2C2F292C
A4A4A6A2A3A19DA3A2A3A4A3A1A2A1A7A5A4A5A7AAA8A6A5A5A4A3A3A0A1A4A5A4A7A69E
A1A49CA19F9FA0A0A2A1A1A0A2A1A2A59E9D9A99928E867F7A7468646059534F51555C64
5C5B65626A6A6767696467636469676B666666656664646D656368666B666A696A6D7470
737376727278787579757B7A787A7C7878797A797E817779797B807E827B7B7D7E7F7D80
7E7E7C80797D7A7F7C7B77827F807C7F8580837F82827C837E8086837C827E817E807F7F
84847F7F84828180828180818382857D7E7F81827E807D837F7E7D80847F768279797980
7B7B7E77767379777A797A797B79797B757778787B7878767B7A777C7D817F7F7D7D7F82
82818284858382817E80817B7F827D837C7A7E7D7F8380817D7F807D7E7F78797F81807E
8080807D7D7F817A807C7C7F807F827D7E7C7C7E7B7A787579727374757776736E757271
73746D6D6F72737B7C7C8182848A8B8F8E8F949695929498989E989A989CA09B9B9AA09D
9C9E99A19E9E9AA09D9D989B9A9D989D9D989B96979A99989B9A9D9E9E9D9D9B9D9B999C
9E9A9998959B989998949695959794928F93918E8F8F8F8C8E8B93A6B9C5CED5D6D8DADD
DDDEDDE0E0E1DEDAD2C9BFA1846B6465686872686B706F6E73757377787A7B7980858184
8579705B4B38302B262D322C292A2E342D292D30323337353138313433353130312F2F30
34302C2D2F2C2F32
A4A4A0A2A29F9E9F9DA0A29FA4A19EA4A0A7A7A8A9A9A9A6A2A4A3A3A5A19EA4A2A4A6A0
9FA29F9F9F9DA09F9EA3A1A1A29EA3A29E9B9C99909188887E766D60575B57525353565C
636465636664666565686D6F65666A6665656366636A6967646A6A66626568686970726E
7170767574757675787B76757975727B77767C7C7D7B7D7C7F7C817D7C7B7D7F80807F7A
817C7F7A79787D827A847E83818281838882857E8282817E7C7B828680877D80807F8383
8384867E817F847F7E8081848383807C7E837F807F7F817E7B7E7E7B847A7A7A78797C82
787A7C79767A7A7A7C7A7574757C7578787A75787B777C7A7E7A7A7E7D7C80827D7C7984
83837F7F86828383807F7F7F7F7E7E81807A807D7F8282847E817D7E827F8280807C7D7E
7F7F7B7C7B7B7F7F817F80807C817D7F7E7D7A7B7F7C7A7877737673747375737375706F
716A6D6E6E7477777C7E838486898E8E94949298929597979B9A9A999B9C9C9E9CA2A0A0
9C9B9E9D9D9C9C9B9C9FA1999D9B9E999A9B9C9B9B9995999C9D9F9C9F9C9F9B9F99A09C
9AA0989A9599979C94949295959192949194958E8D8D8D8E8B8D99B0C1CACFD3D7DADCDD
DEDEDFE1E0DFDDD7D0C5AF8E75626263716F706C6D7072727679797177797D7D83808084
8486786C5C49342C272D282E312C31312D282F3B41434C463F3F3F40393E333435313334
322D302D2D2E2E3A
9F9FA09EA39E9DA0A2A3A0A29E9FA2A4A4A4A3A7A5A9A9A7A8A9A5AAA8A7A3A6A4A4A4A3
A2A2A2A39D9E9D9FA2A2A09EA2A2A2A1A39D98988F8A8B837C7670645D5450525853575B
5B5F5E65636963686D69666864636764646964666766666867696768646469676A6F6E70
6F757373727776737B79787877767478787D7D817A817B7D7C7C7F7D7B7B7F7C7F827F80
7D7D7B7D797C7D7D7F817B827E7F8180837F7E7F8383817D7F7D7F80827C8281827E7F85
7F81818184807D827C80807F8482807D817F7F807E7D7E7F7E7E7D797B7E7C7B78757A7F
7C7975787B7D7E7D807A7B767A777878797578777B79777A7C7F7D7D7D7D7E827C817E81
817E828587838181858182847E7F817C8280817E8180808380857D7D7E7C7E817C7E7E7F
7F7B7C7F7D7E7D8080827F797C7F7E81817F7D7E7E7A77797974777B7E767F7875736E6F
696C68686B6B71747C7F7F8689888E8F8F929498959697989A9A9C9B9C9F9FA09CA19D9E
9D9C9F9E9B9C9D9C9A9CA09A9A9E9B9C9B9F9B9E98989A9C999D9EA29C9D9C9D9A9C999D
9898999B9D989997969699949B9490969293908F8E8F8B8E8C91A3B9C5CED2D5D8DBDDDE
DDDEDFDFE1DED9D2CAB99C7D666362636B696F6E6F7073737277787775797C7E797E8580
878680766B5C4A362D2B30322C28292A2B282E353235343737373E3A383D363835343238
352E2C332F2F3434
9E9E9F9F9F9E9DA0A4ABACA69FA3A1A3A1A6A4A5AAA7A9A8A6AAA6AAA8A5A6A8A7A5A2A3
A4A19EA19A9D9FA09E9FA0A19DA1A1A0A1A09B95908B86857E786B665E59525453535C59
665A5B64636967676968656467626765646A6668666663686166696B686A6A6B6F6B6C72
72707072787571757C7C73797A7179797B827B78797A7E82867B827C827D7C7F83857F7C
7C7D817E7A7D7F7F787A7B7E7D7C808180807E7E83827D7B807D7C808180808387858886
888D89868283817F81857E7F838280818084807D7F7D807E7E807C7B7D787B7B7C78767E
798376797E7C7C7D7F7E7E7B76767B757C7B7C7679787C7C7F7B7D80808181807D827D81
8381838184848381868682847F817F807F8181808082818481827F7D7E7E7D7E797F7F79
7D7A7C8085827D7D7D81807D7D807E7B817F7B7B7A787E7A777674727D777B7371736F6F
706C6E69706C78747C7F8086888A8C8D8D9294949696989B9A9D9A9A9E9D9F9A9C9C9CA0
9B9B9F9D9D9DA09DA09D9D9B9D9B9A9C9EA39C9C999A9C9C9F9C9D9C9C9B9C9C9D9E9B9C
9A9D99999E9C9A959596979798969091979291928C918C8E8E9BAEBFC8D2D5D7DBDBDCDD
DEDFE0E0DEDDD4CCC0A88972606068676F6C706F77737671757E7E7C797C7A807C808285
8385858276695B41382C27292D2B2C2A2E2C2E2F33312D313233363535362E3B343A3332
322F3433322C2C2C
A0A09EA09DA0A1A29F9E9DA5A2A2A2A0A7A2A4A3A4A6A9A7A5A7A5A5A8A6A9A9A4A9A7A8
A1A2A29E9C9F9C9F9DA29F9AA19FA1A09FA09C98938B878284766B6C61595A56555E585D
6561646865636366636C686467666767666565686865636865696B696B686B666E6E706F
746F6E7477787576767A79777777757A7C7E797D78777D7C7E807F807F7F7D847E867F85
817F7D7E7C7D7C827B797E81857C7F827B827C7E8283827F84837E7D7B817E827C7D847F
848181807F8380827E7D827F7E818284807E827D797D80827D7E7F7A817D7C807C7A7A7A
7D7D7E787D86807C7E7D7E7E7D7A787C7D797A7877797D7E7B767A808181837F81828083
8485818283868382857E7F7F83827F7C7C807E7F81817D827C807E807D807D7C7C7E7B7C
7A7C80847E7F807D7E817C7E7F7D807E83817B797E757E78757975717679727073767170
6D676A6D6E7176797A7C84828A8D8B8C8F9394999A9A9B9C9BA0999C9D9AA19FA09D9D9E
9F999E9E9F9CA09F9F9D9C9C9C9D989F9B9E9C9A9B9CA29F9C9D9C9D9C9E989C9C9C9B9B
989B9C999C9D999A959996959498979798948F938F93908D94A9B9C7CCD6D6D8DBDBDEDC
DDDEDFDFDED4CDC9B1977A69636A69656B727275727171777979777C7C7D817D7F798187
7D8988867D79695B4B3C2A2B2A2829292F2D2F363534393C39383835332F31373133302E
34303736352F322C
A0A09C9EA09D9B9FA09EA1A3A6A1A39FA29DA0A8A3A5A6A6A9A6A9A7A9A9A7A8A7A8A5A9
A7A3A3A1A09EA19F9B9F9FA09EA1A6A2A39E999B908F89857E726D635F5D575A5958595D
636364676367696F6868676968696969676669676C6867676767655F636A68686C6B6F72
6F747275767775777A7B7A757B7B767B7D81797C7C7B7F7B7B84807F827E807E8184807E
82807F857C7C7D7F7D797D808485848183837F7F827F7C7C80848086837F83808182817E
837F8081807F817F7C7F7F8682878584817E817F7D84807E7E7C7A7C7B7C7F7A7C79797A
7A797A7C7B7D807A7C827E847A777B78787B7C77787A78817C7D7D81817F8184817B8387
82838481858585868784817E8080828284827F8180807C85807D7D807D7F7A7D7C837E7E
7C81817E78807B817D817D7F8080817F827D7B7E7C797876747B767277726F6E72726C79
70686E6E7073767A787D818688898B919095969894969A9E9C9E9CA09E9E9EA09E9C9E9C
9FA09B9E9E9D9DA09D9D999C9B9D98A0A0A09C9D9E979F9E9D9D9C9F9C9B979C9B9C9C99
9D9D9F9C9B9E9897999A9D959B94939492978E908F918E90A2B5C1CBD0D6D7DBDFDEDFDE
DFDFDFDFDCD1C9BDA5856A676C636F6B70717271747375777B797C7E7C777A777C798085
7F8581878A827C756147342E2C2C282C2C262B2F322E363B313644343335343238333332
323036373532302E
A1A1A09E9D9E9D9DA39EA29F9EA0A0A3A3A1A0A3A2A4A5A3A8AAA6A5A8A6A7A7A7A6A5A8
A9A6A09BA2A29F9F9E9F9EA0A0A49FA3A19E9998938D85827C736D675F6052565C5C615A
5C68646360636967676B6B6A69696C68626867646868676465606966666668676F6F6F73
6C737573717673767B737B797C7C7A7A767E807A7C7D7F7C818082827F817F8082808281
7D7E827E7F7E7F827D7B7F8281808683858486807F827E8180848385867D84807E848281
828381837D8181838084828186878289878381817D7E7E7D7C7C7A7B7D797E787B77767B
79787C787D7D7D7B7C8184807B7A797D797B7E7F7B7D7E7D7A7C7F838282807F80818381
827F81818188858385828381808185827C7F7E83828282837E7C8081827D807B7A807E7F
7C81807A7B7D7D7D82837E83827B7F7E7D7E7E827C7C7C7C7B77757179737170726B746E
6F676D70717776777D7C8282888A8D919297999B969D9C9B9F9A9DA09CA2A4A19F9D9F9E
A19D9E9E9F9F9C9FA09B9EA09E9D9C9B9E9D9F9C9B9B9C9C9C9E9CA29B9A9C9A9C9E9C9A
999C9C9B9B9A989A99969A98989791949692908E8E8F8E98ACBACACDD3D5D8DBDADBDEDF
DDDFDFDDD6CFC1B08C716A6967696B6E6974717074777576787A797A7B787A797B81817E
7D8083838587817A71634B3A2E2B28262A2C2B2B2D33393E3234343039362E31343B3131
353132363B353338
9C9C9FA19D9DA099A2A09D9F9EA2A4A1A1A1A4A1A0A4A5A5A8A7ABA8AAAAAAABABA6A9A7
A9A4A0A0A19EA1A0A19D9E9EA0A3A0A4A49D9C98938D89837D77706660585D595E596060
5D60626A636165686A696967686C696A696F646567666664636A666A696D6A696C6F706D
706F7276757576777B7B79817C7D77787C7E7D7E807F817F7F857B807F827C82817F7E87
7D7E7F80828081817E817F818381808583838285838084828585838385857F7E80808484
84877F7F82807F86808284828587828185817E7E807F7E817C7C7B797E7B7C7A7B757678
7B7B787A7B7E7D7D807E7E7E827D7D7D7B7E81797C7B7D777D7D7C81827F807E8385817E
807D817F87858382828180848081847C8281807E7D8384817E817F7F827F7E807A7F8181
82817E7C7D817D7F7C817E7E817F827C797F7E7E7E7D7A777A797871766E716E6C6E726C
68696C6E6F74767B7C808489898A8F8F9295969A99999C9CA0A09EA3A19EA1A09C9F9F9E
9E9E9CA1A29FA29FA09F9DA29F9F9E9B9A9E9A9C9E9D9A9F9D9D9C979D9D999EA09C9C9C
9C9D9D9C9B9A9A989996999897969494968E8F8E8B8D91A3B3C1CBD1D4D8D8DADCDDE0DF
DEDFDDD9D5C9B89A7E6D6A69686D6C7075737275747478757B797D7E7D7D797E7B7C7F7C
7C7F828087838483796B5E4638342725303228283636353437342B2E3A3B36343532322F
31312F33323B3738
9D9D9D9BA09F9B9B9E9E9FA29E9E9D9FA09FA3A09E9FA1A5A7A5A9A7A9A9A7ABA9A7A6A6
A9A5A3A29FA19F9F9D9F9DA09FA49FA19FA49D9999938C8884796D69645C5A57565C5C64
625F5F636566656767686F696C6D6D6B6B6C6E6364656663686862646768686A6B6C6F71
757171717575757A7B777878787D7876787E7C7C7E7E7E7E81807B7A8083847E81837F7A
827B7C7D7E7B837F7D81837F80837E84828281818383857D868183838681858182808280
858A8286827E7C80818580827F8684848787807D827E8786817D7B7C8077787D7A7C7B79
7D7D786C7D7D7F807C7C777C7C7E7E7F7F817D7D7C7D7B7F7C7B7F808382817F817F8381
807E7E85858782828583807E827F7D7E7E7E7F7F78828081807E7D7D7F7E827E7A7E7E7E
7C7F7B7E7D7D7D7A81817F7E807F827D7D7F7F7F797D777C7978797674736874706E6E6F
6D696B696B6B737A817A8386878B8F8C929797989B9B9D9D9F9FA09EA29FA3A1A19C9E9F
A29F9F9FA0A19EA19E9CA19E9E9B939F9E9F9D9C9D9C9D9E9DA09C999D9B9C9A9EA09C9E
9D909E9B9B999B9B9B99999699989895939390828D8C96A1B5BDC7BFCDD2D1D6D8D9DBDA
DEDEDDDAD2CCBCA084736F736B76717273767A7576747777757B7C797B79787D7D81777D
7C7D7F847F828483877E786F574333313428292C38352E29302F2B2B3032313438363333
31342F32333D3939
9E9EA19D9D9F9E9EA1A09EA3A6A09D9EA0A1A0A1A0A0A4A4A4A6A4A5A7A8A9ACAAA9A9A9
A6A6A0A0A29F9F9F9C9BA19E9EA5A2A2A6A0989D958E8B847E727166615E5B5756575F60
62636167626465696E6C706E6D6F6865696B6D636665676C686D6768696C6A6B6A6C6E70
6F747376757A777D7C7C7B7A7A7A777C7B7D7C7D7B837C8080827F817E7C837E7F817D80
847D7C7E7E8382807D7F848184807F8382828386847F858486848380828085827F838283
82837F837F7F7C828483858085828183818581878482807F7D7E7A7F79747C7B7B7B7A7E
797D7D7E797F7F7E7E7A7E7E7C7E7D7E82797A7E7F7C7C81807C84828580857F827C827D
8184808284847F8185877E7E82827E7E83807D7B797D8180807F7C7F817D7F7E7C7E837D
7F807B7F807C837F807D837F808282817E7F807E7A7A7A707678747676767772706C7070
716D6B6C736F7C7D7F8887888A898F969599999E9F9C9C9C9E9FA4A29EA3A09EA09A989E
A29F9D9FA1A1A19B9C9C9E9DA29C9E9E9A9C98999E9B9B9D9F9E9A9B989D9F9D9F9C9B9A
9A9C9F98999B9B9A959599999594938E9492938B9093A7B8C6CBCED4D8D8DBDBDFDEDEDD
DEDDD8D0C6AE97766A6A6B69696E6F727475767A7677797D7D7E76797977777C797D7C7D
7A7F7D7E827E83858A827B6C5B4836292B272A32322B2F2D322F2D2E352D313435323231
332D312C35363833
9D9D9E9F9FA09DA09E9FA1A09F9EA39F9FA19F9E9FA5A2A2A1A5A7A6A8A5A9A6A8A7A6A5
A4A6A5A49F9FA09E9F9B9F9F9EA3A3A5A3A29D9F8F8D8980847472655F595D5B57555A5D
5D6364666168666A6C6B686871686467696B666668676665686A6664666B666F6B6F6B6A
6D7071757476767879797B7B797F7F7D807A797B807F7D7D7F7F7F7E8185847E827F7C7E
7F7F7F7D8281817F8183827E82808082808082877F8081818387848081817F8781838581
827E7D88807F7D828186848A8686828481868288837F80807D777B7C7B787A7B7B7D777B
7E7F7A7A807F82808083807D7E807F7D817B7E797E807D7D827B848286828080837E8481
8281838A868580848281827D827F7E7E80837E7F7F7F848180807F8281847E7C78808279
7F807B7B7E7F7E7E837C84857D818182838085837A7A7B737578747777757573716C716D
6D6D6C686B7476797C84868A898C94949797989C9E9E9E9CA09FA5A1A19EA29D9F9F9BA0
A2A09C9FA39E9E9FA09F9D9E9D9C9E9E9D9F9A98999C9A9D9F9C9A9B9897989C9A9CA19E
989F9D9A96989799959698979495948F948E908F929DB3C4C7D0D2D5D9DBD9DBDDDCDDDE
DDD8D3CBBAA07F66616A716E717177767174757574757D7C767E747D787A7B79787F7880
787C817D818386838484827A715F4A2F2B282C2D2E32312F322E292E2F36292E2F303533
3235312D35383A39
9D9D9EA09E9C9D9FA09EA09EA19EA09B9DA09DA2A09CA0A19FA5A3A7AAA8AAA9AAA8A5AA
AAA6A5A0A3A1A19F9F9A9D9FA1A4A2A5A0A59D9B928F8D8280737066685A595853565D5D
6069616262696A6A67666C68686A69696A6B64686968656B6A6A6764686B6A6D6B70696F
73717375737577777C78797D7B787C7D7B7E817D7E7F7F7F7D8379847E7D827C817F817D
7E7E8382867D8180827F8082817D83818380848581868183828282808380867F857B8682
807C7D81807E7A807F8182888588838587838584817E7C807D817D7B797A787A7B7B7D7D
7A777B7E8285807E7D7D7E7B7B807C7C7B7A7D7D81817C7B8280808584827F7F8281817F
7E808183828181858787888084807B7C8181807E7E8084818281818081817C7E7F827D7D
7B7D7F7D7C7F7D7C7F7B7F82817F85807F7D7D7C7D80787177767B727B776F6C7171716F
706C6C6C707375787E7F83858B92949198969D9D9B9C9F9E9FA0A3A2A19F9FA3A1A39F9F
9F9FA0A2A1A29D9F9FA0A19E9CA0A19E9E9F9B9B9B9C9A9E9D999A989E9C9D9F999F9C9D
9D999999979B959A9796949494919196958F949095A9BAC8CDD0D5D6D8DBDBDDDDDDDEDD
DAD5CBC2AB8F6E67696A6B70717275757273757A7D797A7D7D79797E7B7B78777B76787B
787C7C857D7B828381878A84826C594733313028282C2F2E2B3033362A2B2B3A32313633
352E35332F33333F
9F9F9D9DA19D9D9D9C9C9EA39F9E9E9E9FA09CA29F9FA09D9DA1A3A5A5A5A9A8A7ACA7A3
A6A4A6A39F9C9FA0A09C9EA19EA2A1A09F9D9A98938E8B807C766F66605658535554565F
5F6361656566646967636A676A6C6867696D6963696B63686767636A69676C6D6C6C6F6F
7375727574797D787B77757C7A7A7F797D7D7E807F7F7D7D78817C7F8780817C80808080
807E7F8083808283858281857C818680848282808083848681838082827F868985808382
83807F82818282838185868584898C8A8B858183807E7D7D7D807D7D7C7D78797C787D7B
7B7C7F7F818180807C7B7F7C7D7B7C7E7A7D81837D7E817D81818082817E7F7F7E86847F
8389848183858586848884818285818181807B7E81807E807F7E827E7B7E7E7F7F7F7E7C
7D7E7D7D7F817F7C7C7C8284817D7D7D7F7C7B7B7B7C7D75787D7A717A76746E736F6E6D
6A6B6C6B72707A7C818287878D8F91979A9B9AA09E9E9EA1A7A2A3A1A2A6A0A0A0A09EA3
A19F9CA1A0A19A9BA29E9C9F9D9E9C9E9B9A9C999E9F9D9D9D9D9C9D9C9B9999989E9E9C
999A9797989796989A9B9597949395909194908FA2B0C3CBCFD2D8D9D8DBDBDADDDDDDDC
D8D0C5B5997D65676A6B6C6D6E7574737579797777767B797B7B787A78797B79797B777C
7D7E7C837B7F808683858988857370594A352B27292932302F302B2C2B2F2D2F2E302E2F
31353A372F36394D
9D9D9F9B9F9D9D9A9F9FA1A2A09E9B9EA1A09FA09C9AA09F9E9B9FA1A7A7A9A5A9A5ABA5
A4A6A6A79FA29EA69F9EA0A09DA0A3A0A69F9A9A938F8A817A726E6261575B5C54555455
605F636766646B6768696A686B6A756B676B6B6B6468676569636667686B6C6D6D6B6B6C
7074757575797C7977747C7E7A7E7F7C7B7B80857F7F8081807E7C7F817C837D7F80847F
827F7F7F817E83828082818581848582828385838183837C7E8282837F82808482858382
7D817C827F8281848380888584868D8E83818384817F7E7B7E7C7E7D8177797D7C7D7B7E
7C7F81807F82807D7E7E7E807B7C7D80817D7F7D807F7F857B7C80817C7E7E7F88858481
86848383868386848185808A7F807D807F7F81807E817F807F7D807A7E7D807D7A7F807C
8084817E7F7F7B7E7E7F8384817E7C7D7E7B797D76787A7C7F797F7A73776B6E706E716A
6D6769696E73777B7A7F848B89939193999A9EA09EA59F9FA2A1A1A39FA3A1A1A0A39D9F
9C9E9F9F9F9D9D9D9EA0A09FA09F989B9A9E9E979BA09E9F9D9C9C99989D979C9D989D9C
9A989A979999949897959697949394949090929BADBEC7CED1D5D6D8DBDCDEDDDDDFDDD8
D0C9C0A58F6D6768686F6E7274736C6F7E7E7C797C7B78797E7D7F7C7A7A778073747B7E
7B77797F7B7D7D82818686898A857E725E46372B302C2E37302E282C282C2E2E2E2D3333
2E2B313834343031
9999999C999E9C9D9F9D9D9FA09E9F9C9E9C9CA39E9C9B9C9BA0A1A5A0A3A5A6A6A8A6A8
A9A6A6A4A1A2A2A0A39F9F9FA0A1A1A0A29C969A958F8C857A746D635C5657564E535461
5D6061656468676569646C656B67686769696567666465696C67666569686C6A6F6F6C6C
71727172777A7A7778777E767A797A7C7B7B7D7E7E818382817C837C7E81847F83828184
7D81837D82807D8381808182828481838183848080827F807F7D82807F817E8980808485
82837E8282818784888686808B8C827E858D7F838485817A7E7A7E7F7C80817E7B7D7E81
7F7B827E7F80818183807C7D7D7D7E837F817F7D797E807F797F7F847E82858482838085
857F82818284838782838682827E817F7F7E7F7C7E7D817E817E807C877D7F7B7F808380
7D82807B817F7F80828083837F807F7F7F7F7C7D7B79797C7C7C7E7776726D71716C6B6A
686A6A6D6C747277777F82898B8E9093999C9DA29D9CA2A1A0A4A0A1A1A3A2A29DA09F9F
9FA19CA59F9EA09E9D9EA09E9F9E9E9D9D9E9A9F989C9A9C9C9B9899989A9897969B9898
9A9798989897999498979699928D9392919392A3B3C4CCCED4D5D9D8DADBDEDDDEDDDBD5
CEC2B2927964686A6B6C6E6F727274737C7D7A7B7E7E797C7B787C7D767877787A78817C
7D7D777B7A7F7E7F808786888787897E6F6052353229303C342E262725292F2A2A2E2D2E
2D2E37343B3C2F30
9B9B999A979E9D9A9DA3A29EA19E9C9F9F9E9C9D9D9D9C9E9D9D9FA1A0A4A7A6A8A8A5A7
A8A4A7A5A2A3A3A3A39D9D9DA2A2A29FA39D9797918F8C857D787267605F585552585B65
5F5E61616065696B696E676D6A6A686468696C666867686563686A6268686E6B7171706F
7170737178777B79797B7876787D777D7E7D7F7F807D8281807C7F7B86847F8282848184
7F83827F818284847B81857E82807E80827F8183838182817E80848688858185857E837F
80807F80857C817F8082828D938486838688827F8181827E82817D7F7D7D797D7B817E7E
7D81817B7D7E7F817D80817A807F7C7E7E82827F7A837C7E7F807E837F80868481848085
8281828481828385828382867E8082827E827E7B7F7C80808080827A817F7D7B807D807F
7F80827F817D7E7C7D7C7F7F808581817D7E7B7E7F7D7B797F85797574706F6B6C6E6D6A
6969686E7170787A807E888D8D91949B9A9A9E9FA1A2A1A1A2A3A1A2A2A8A6A3A19EA0A1
A1A19FA29F9E9FA29F9F9FA09E9D989C979B9D9A989B9B9D999A9C9C999A9A9899999D98
9797989798989698969497939595939391939DADBDC6CBD1D5D5D9D9DCDBDDDEDCDBD6D0
C7BAA5836A65646A6A6C6B72777276797A777A7A767E7C7B7F7C797D7D7A7A78797A7476
7D7C7F7E79787D8484828085878A8C86826F5E48393E4B4A3130282F2B2E3028272E2E2C
292E30313437363A
9C9C9D98989D9FA19FA09CA09E9E9E9F9FA29B9C9E9CA09E9A9C9F9DA2A3A4A7A6A5A5A9
A9A6A3A6A4A3A5A1A5A69B9E9F9EA0A19F9C9A9B968E8A818078716A635D595959565C5E
625E5F636665666B6E666A6769686763656F6A6B676467696A636568686B6B6F6C6B6D74
6C6F70737878777D797B7C78787A747B7F837D81828083807D78837C7F808B807E828183
827E7E82828382837E7E7F7F828182838380837D85828084828186848886858D81828186
848284828082818288848683828285867F7D8484818184807F8080817F7E83847E837C7C
7F7E7E7E7B827F80807D8080817F827F807E82807D7F7F7F858582808583868282898782
8585808585808184878287808285837F7E7F817F818084827F80807B7E807D7C7A7D7D80
7D7F827D817C807C7C817E7C7F8080807C7C797F7F78797B78767673756E6F6E6F6C6B6E
6A6A6B6C6F7675757D8585878E959697989B9E9F9DA4A1A5A5A3A4A0A1A3A7A3A19D9BA1
A0A1A0A2A1A09EA29EA1A0A2A09C9C999C9B9F9B9F9B999D9E9B9C999699949C9C989798
969897989A98969796979595948F91908F96A7B4C5C9CFD4D5D9DADADCDBDBDCDCD8D3CB
C0A99674666A686E6B6F716F76767B7C767A7D7974777A767B80787979787A777678777B
797781817E7C7D828184818D8A878C858480715E4A3B4C3F2F302B2D302C32282C342C2D
2C36313437373636
9C9C9D99989C9C9D9CA39CA09E9D9E9DA09D9B9C9E9A9F9D9A9A9B9BA09DA2A6A9A7AAA6
A6AA9FA4A5A4A4A4A3A3A0A3A1A0A5A49D9B9B97988E8B84857E74656360565957585E5F
62636862636B6B686A67656667686B67656767676B6E6D6763656B69686A6B676B6A6D6C
6F71717371747D78757C7976797D777C7E7F7F7C7F827F868080867F8280808283847F7F
8486828785838180847E7E817E8581808083838384888182808283858485848285838081
8084807F81857C7E89807C8183818387807E83838683817E80808480837C7D7F7F7F8084
7E817D857F7C82838284887D807F83857F807F81807F8485878B83818483838484867F82
8583827E7F7E8183828082848282848683837E81828084837B7E7E7F7C7E7D7B7F7D7F80
7C7F7E837E7C7F81807C7D7F87807F817E7E7B7F7C787D777878757A727371716C6C7070
696B6D696D7070727981848B92939593989D9E9C9BA4A1A1A1A3A5A19FA1A3A0A0A29FA0
9FA1A4A49FA09FA0A2A19FA19D9B9B9C999B9A9D9E999D999A989A9A97979B9896959A98
999798969696959498979599988E8F93939FACBFC7CCD0D4D8D8D9DBDBDCDBDFDBD5CEC2
B3997E716C656C736B6C6F71747274787275797378767A777B7B7879797B747B797B7879
7C7C7E817F7F7F7F808483858785858A888C7D71614938333A3A2E363F33323036332F2F
2E2F2E2F2F2F303D
9F9F9B9D99979C9D9E9E999E9D9E9E9F9FA29E9E9E9E9D9B969B9A9B9D9DA2A2A7A4A7AA
A6A5A2A5A5A5A8A3A5A2A2A0A09C9FA09E9D9895968B888A84797969625B5D575A615F60
6066626463676168816A67676968646365676C66616468646B6668686668696E6F6E7673
6F6F757973777C757578787774807D7C7F7A7A7B7E7E7D807F828183858381818380847F
837F7F8184808280817E8083828280858083858583838582828584838386858084858380
8684858380827E8483868283828588837F8284818387837C82818484837F807E82827F84
817F7F81817E8084828381807F847E827F7F827F7F81807F848283858586888587828182
82838383848384828483828186838182807E847F7E8282817C7D7C7D7A817E7E7C838180
807D807E7F8082807D7E7E8381807F7E7D7E797B797C7B78787879727275706F6C71756B
6A6A6667696E6E727E83888B9196989A9A9B9B9E9DA49EA4A3A3A1A5A09FA3A39D9FA0A1
A2A2A2A59FA3A3A0A2A1A3A09D9A979E9E9E9B9B9B989C9B98999A96979A98989998989B
9696989898949596979496968E8F8F8F96A7B8C4C9D1D1D6D7D8D9DADBDCDBDCD8D4CCBB
A4896C6A66696A6C6F75726D79717877747676727372797C7E7E7C78777A77757A79757C
80817F7D85848580838182868287878A878E857F745B47363135292A2D2C2D36353E2F33
342B2E3131383436
9B9B9B9A9C9C9D9C9F999BA29F9F9B9C9E9D9F9C9D9999999A9C989CA19DA2A7A7A6A8A6
A8A0A3A7A3A6A6A7A4A4A1A19FA4A1A3A09CA194928D88827E796F69645D6357565E5D62
635C676367696766776B6A6A6567696D66696E695F646762676D63676567686B70717171
737074717872767A7A787E7A79817D7E7C807B797980837F7E837F8183807F848582827E
7F858384807F8181847F838182828582828181858484818181838386838187868384847F
7F83838680827E8586808388848280848785868683808580818083889183817F84838281
837E828389817F83868383827F82817F838080807F837F81818184848887898C908A8388
8782837E83877F8388817F847F857E818080837C8483807B817C7D7E7E81807C7C7B7E81
837C7B808081837E7F81838280827F7E7D7E7A7B7B7B7B7B847C79706F7072706F6A6E6A
706B6B676D6F6F7380848B8D919B93999A999B9FA1A3A2A3A2A4A6A7A0A29EA19FA0A2A0
A2A1A3A1A19EA2A39EA2A09D989E9B9D9E9B999B9B9B9C9B9D98A0999796999898999898
97979899989894989994969794909193A0B2BDC9CFD1D4D5D7D9DADBDCDCDBD8D6CCC4AF
937868696D716A697172716E7577747874777A73787B7E7F757C737B7F7B7C7C787C7C7E
7C8086867F7D8380838282868286878A858A8E8681705F493C342E2D2D2929313135312C
282B302F312F3732
9C9C9BA19B9C9C999F9EA09B9E9C9FA29DA29B9F99999F9E99969BA09E9EA0A2A3A4A5A7
A5A4A7ABA8A5A5A2A3A5A49EA1A3A3A19D9B9C91938C8788837F7F74675E6255575A595F
605F6562666A69676A6B6D69686E6C6A65676665696765656A6C6468676764696C727071
72726F737A7575777778767A7E7A7C747B7C807D7C7F7F7E808082808383828583818081
7E80868481818487848384858582838382827F8285838785828580838684828485867E82
818383858282828583848482888083818485867E83858481857F828985808286807F8481
858381818B88858083828481858383847E7F817F7E868085858186878785858C8D888583
8285828486837D8A7E7F7F868F867E85857F7C7F818180848082828884807B7B7D7E7F7F
7F817F828183837F827E7E7E827F7F7D827E797D7A807B788A797877746F73736C6E6A69
6D6964666D71757B82878A8D94949398999E9C9C9DA3A4A1A2A3A1A4A1A39FA19FA5A5A4
A3A3A6A6A0A3A1A0A19F9C9C9F9D9F9D9F9BA39F989A9E9E9D9C9D9A99989997989B979C
999D9B9A99969599989597969C959098AABAC5CCCFD2D7D8D9D9DBDCDEDFDCD5CFC6B9A2
88716370706D6B717572716D75787577737A797979787B7B7B7A787E75767E7A74787A79
797F7F827E7E7E7D7F81838284848785868C8C87857E7064523F34332B2B374335322D2F
39322E322E352E34
9A9A9A9B9DA09D9C9E9E9F9CA1999F9FA09FA09C9E9B9C9F9B989A9A9D9B9FA3A1A5A6A5
A5A2A6A9A4A8A6A6AAA3A4A0A6A6A3A19A9A9C95938F908D887E7F715F63585657595F5F
5F6360626B636463696C6E6B69726C6B6A666768686D676A6D666E6966656A6B6F727570
757373737B7B7D7A787978767F7D7E7A7A7B817F81827D80818283838183808383838483
828582858985838584878182808385858280808582848086838083878487868584848084
81858681867F8383818182818383808282848B8787868384848285868383838182808488
878282848688848482828780877F848C8180847F8185828283878683858A8C8785868882
8385828686848387817F828D9181807F7F817F8081837F8383828288817D847C837F857F
7F7D848186848481857E7E7F828381807E79837B7A7E7A76787678737174726C6F6D716B
6C6565686E72757B82888D8B9298959A999E9E9EA1A1A2A3A2A2A1A5A1A29CA2A2A1A1A0
A7A7A3A2A3A2A3A19F9B9E9F9F9DA09D9C9F9E9B9B9D9A9A9A9C9B9B99999B969898989A
97979C969597989B999795939692969FB4C0C9CFD3D6D7DADAD9DADBDBDBD8D3CBBFAD92
75676766686A6A6D707072747072777578797E787D7779797C7C7A7C7A7C7B7A787E7B7B
797C7C827C7C7F82827E7D81838187868788868888847E6E624C4130262D32322D322F31
3B31332B2A2C2D34
9D9D9F9B9E9D9A9A9F9D9A9C9D9FA19D9F9E9FA09B999A9C999B9A9EA0A0A1A2A6A6A7A7
A8A6A5A9A7AAA7A6A7A7A2A1A9A4A3A1A09B99958D8F85827D746D645E645E575E585D61
5F63676B62646567656A64686E69676A67676C66676967696262686565686D6E6B6E7472
7278727976767676787A7D79787B7F7B787C81807F7F83827F80837E827E838485878284
7D888182848484848285818281857F858384828487828281808782878488848386828A89
868382848183888086878385828880818382898B84868587828A83828481838087858285
8D838181827F827E8080878388847F81828080807D858286848988888888878885858383
858782838482828285858782868481827F837E7B8081828784808183817A7D807E7D7D7F
8183808382827E8484807C7D7F80827F807D7F7D7D7C7B797473756F7176746D706C7168
656A66676E75788180898B8E8F969A9B9A9EA09F9EA1A6A1A0A1A0A4A2A09FA19FA6A3A5
A3A5A19EA4A2A3A59F9E9F9C9C9EA0A0A1A1999C9D9B9A9A9B979E9A999D9A98999B9A97
979898979A98979696949493909199ACBBC7CCD1D4D7DAD9DAD9DCDBDBDCD4CDC6B19C87
696667686D6C6B6F70756F7A727879747778797D7D7F787D837D827F7A777B7B7A7B8679
7C7C797C7E777D7C827E7E8083808781828487868A8B827B6E5D5339322B282E342E2E2B
322E312E30312E32
9D9D9B9D9F99969A9C9F9F9E9A9D9B9C9B99999D9D999C9C9B969A9898A0A39FA1A5A6A9
A8A6A5A7A7A8A6A6A3A8A4A5A6A3A0A19E9E9893918986817A706C685F585C5A54585E5F
576069646F6564656D68656869676B6E6B686A69636A6E6965676664666867666D6F7170
7174717975757578777D797E7C7A7C7879837E7D81807F7F7E8084858282808583848380
7F828484848184848486857D828182838483828888818580868585878487848591898685
85867E83847F8385878A858486848283818E838786848283858787868487878987878582
8C808185857B847D818284818288838183827E8284828284838A8A858787898885848183
83858380828880848383838487858482807F83807B87837E808181817E7E7C7E7F817D81
848385807F838182858282827E888084807C7E7F7D7E7B74717271717275786F6F6D7469
6C696966707379818C8D9790949396989D999AA2A0A1A3A1A1A4A3A19FA19F9F9FA3A3A4
A2A5A1A2A1A29FA19CA2A19EA1A19C9E9E9C9E9B989B9B9B96989C999E9D95989B959795
999B979697979698969494959298A9B7C2CCCFD3D7D9D8D8D9DCDADCDBD7D2CABBAB8E77
6467706B686A6E71747574737779797778767B777B797D777A7A7E7E7B797F7A797A7E7C
7E7E7F817B797E7E7E7E7D817F8081827D848384888984837C7160503D2F2D322B2D2E28
30322F2F2C282D35
9C9C9B9D9E9C9D999C9D999B9E9D9B9D999C9BA09C9D9A9D9A95969B979EA4A1A1A3A5A5
ABA5A7A6A6A9A9A6A6A7A8A6A8A7A6A09D9F9C968F8D8C84827A6D68635D5A545A585D5B
5C5E666867655F626A706F6A6D676F6D626965656A666E6565686868646469686B70706F
727271717379797C797F7D7C76807C807D7D8280828082807F8183817E7E828284818481
868382828187828283847F85817F82858486848A8884868683838E848687878783888785
858786838983828785828284818383818086848583847F82858286868587838886818284
898287858581817C7E808486848485837F8480818381838286848A8784878D8985858384
85848181838484828187818182818283837E7D808384837F80807C80827B7A7F817F8180
8282827F8281818181807F8180827F817E7E7B7E74767A7D7478777072737B776E696E6C
6A65676B73777A82898F8F92949098999C9F9BA09EA3A6A7A0A39F9C9DA0A2A0A3A2A2A5
9F9FA0A7A1A2A39A9D9D9F9CA1A09FA19E999A98989B989999979A9B9C9B95989B949598
99989698969997969599999194A2B1C1C7CED1D4D7D7D8DBDCDCDCDBDBD4CEC4B39B7C71
6969646B716C6C727A747471727376797A7978777B7A7578737D797A76787F77797D777C
7D7D7B78777C7B81807F7E828083847F8183858486868A87857A705F523E2F31302A2830
2B3030302D2A3135
9E9E9F9D9B9E9D9A9E9E9E9F9B9C9AAB9D9B9D9E9C9C9A9C969B979F979D9DA0A4A2A3A6
A8A4A9A9A9ABACA9A6A7A6A9A8A2A5A09F9C9B988F8E838079746E70655C5D595C5C5B5B
5B626967696468676B6B6F686C6B6A69636A6A67686769676C6B666465686A6D6F6E6F6E
6F71767174757778797C7D7E7E7C807D7F80867F7E7E817E8184847E7F83847F81847F86
81828781808381838082817E81868581838786848187848483858A868088858185858382
828384838482828A82848086808484888282888584838286848183818385818782868085
858281828382878182847F8284838384817E858583848284848286878387888987818180
88887F81838081858086818383858586847E7E8380827F7E7E807E7E817F7C8182838284
7C81847E808383817F7C81888081818281827A7F7B797A787475746C73747E6B6F706869
686A696F7279808889909294979898999E9CA09FA09FA0A49FA1A3A09F9CA1A0A2A19FA1
A3A3A4A3A09E9F9E9EA09C9B9C9D9B9B9E969A989A9A9D9D9A9AA29C9997979795979798
989A97999A9898999496969199ACBAC3C9CED2D5D7D8DADBDBDBDCDBD6D0C6BBA48E7069
696D686E6D6C6B707974767273767A7B747478777E7E797977797B7E7A7B787B7D787A7B
79797E797A7E7D7C7B7D7F797F7E7F7F827D8285848581898C867B7064544035332A2B32
2E2E2D2B352E3730
9E9E9F9B9B9E9E9C9D9C97A09D9C9C9B9B9F9B9B989B9B9A989C99999B999C9DA0A0A5A6
A7A7AAA7A8A8A7AAA8ABA9A6A8A5A4A5A19A9E98909186827D7F716B635B5E595860605D
5F64646966616868676C6B6C676C6E6A677369666563686A6D6666626664696A6E697172
72737278757776787B7C7A7D7B7F7979797C847C7F7D7C81817E7F7C7F7F86818581867E
84808085848182828282827E8681838480838084838282828381838C8783868582828282
8684868485838187888580818280848488858786848486887F86887E85828287867F8483
867E82818582847F84828686807E848183817E83838681818681858A84858982897E8182
83858583818088818284838282827F82888080848181847E807E7D827E7D817D7F807F81
80807B838183837D858281847E867D7B78797A827C7A79777575756B73706F74696D6B6B
67686D7176777F898D91939396979A9A9CA0A0A5A19EA2A1A09F9F9F9FA0A0A19FA1A5A4
A3A0A5A5A3A29E9D9C9B9D9D9B979A9D9D9A9D9B979A9A9C9B9C99989797979899979A9A
9899999998989C9997999494A3B4C1C7CED0D5D7D7D9DADADADADBD8D3CCC0B0947A676B
6B6C6A6A6D70707076767072757178757A79757A7C7A787A7B76787873787C7B7C777578
7A7E7D79797F7E7D817D7A7D7E7B7A7D7A7D7E81808581848388837C71675942362F3248
3430302F36343133
9D9D9D9DA09D9C9C9F9B9A9E9C9B9AA09F9B9E989EA0969B9A9B989B9B9D9D9A9D9F9FA4
A6A6A6A8ABA9A7ADABA9A8A9A8A9A6A3A39E9E94928C88867B736D69675B575B605C5C59
6063646766636B6969696F6E6A6A6D6B716C656967676B69666467676A66696F71706E72
7372777A797474787B797777797A7A7E7E7C7F7D7D807A807D8082808080838484838681
858385868582858281838080848586817C87818483867F84838586878A8A848883898582
7F83818985838282888587817E818287847E888683808386848087838584838284818682
817F85848283807F8180828684818185827C808282868084898886868B85858287828182
84838283848484838082837E838B8088837E7F827F7E8681827E81807E7F837D7F847F83
7E7C587E8084817E81847F8282817C817F787C7D7A7F7C7571786F696E6D717270706B67
64676B757C83858E8E908F94999A999B9DA2A1A1A29E9D9CA09B9D9C9C9C9DA49FA0A2A1
A39DA2A3A09F9F9E9A9F9A9BA2989D9B9B9F9B9A9B9A969C9A9C99969B98979C95969B9B
99969996989698949396969BA9BAC4C9CED2D5D6D7D9DADBDBDDD8D8CEC5B49C846B676B
696E74736C747370747C717776767B77747C767A787B787D7D77797A7C7C767A7D767A78
7B7F7B7B7D7C7B7C7D767A7C7D82827E7C7F827F7E7D7E81858985857C746D5F47393C42
312A282D2C323132
9E9E9D9C9D999F9CA19EA09D9C999CAB9C9BA29B9D9D9E9E979B9898999A979D9C9CA3A5
A2A3A7ACAAA9ABAAAAA5A5ACA4ABA7A6A7A29F958D8B89827D756C66645F545A5957615F
5961616465676B696767696A696D6B6C6B686B6466616967656669676663696C72726D74
70737276777875787A797B7A7B807A8282797D7E7C827F7C7F7F8A7F8181848381848486
82878382817F80838084837E7F838780807F5E8387888185868483858485878684838582
828486858783838580848283818784848181818287818385888185848485878383878285
82827E7D82827F8481848481818284868181847E82848285828887898585858783858181
8A7F8283827F838181838680838B86848082818180807E8481838180807C8183807C867E
7F7B577D7D80807F7B7B828084847F7D79807D7878797A797374707171716F6F6B6F6A67
66696E797981858F899392969697999BA39E9FA09E9E9E989B9D9BA0999B9E9EA09C9E9F
A2A39FA2A0A09E9E9CA09B9F9C989C9A9A9D9A9D9A9D9B9A999D9A98989D9798999B9A9B
9A989C97A09A9397979798A6B4C3C9CDD2D4D5DAD9DCD9DBDADBD9D2C9BAA78F7469676A
676A6B6E7170767372757B78787678797B79797C7A78757A7F74767A767C777A81797B79
797B7777787B79797E7A797A7C80807D7C787B7F7C817A808583838A80817C6E5F493C32
32282E2B302F3032
9C9C9C9F9F9B9694A09F9E9E9C9B9D9E9B9F9E989D9B9B9A9B96989A9C9B9A98999D9C9D
A6A2A4A6A8A9AAABABABABACAEABAAA6A7A7A093908A85827E746A6B605C595B5657575E
645E6366606468666566696967696C6B6B66666867676A68686E67646568686B716F7272
6F727474747777797E7B7F7C7A7D7C807F7C837E7F7F837E837D84807E8182807E808882
848684828286828283857E82818185837F82888184868486848383858486868385868681
86857E84838784858183848885848480858288848580858382847F858283878484828283
82828582818485857F8182828882858180827F878083818482858585868C85847F858082
877C81817D81878185818783877E857F8082827F82818081828381817E8381817E818680
817D818184818181828182807C817F7D807D7D7A77777A79747171756C6D6D6E686C686C
696A72778085868B8D919694979999A0A0A0A19C9C9B9C9A98A09B9B999A9C9E9D9F9B9E
9E9F9D999E9C9B9F9E9C9C999B979B9A9A999D9B9E9899989899999A9593979B9B9B999E
99979697999B969595979BADBAC6CAD0D4D4D6D7D8DADADDDAD8D5CCC0B099806B686A68
686A7170726F7375787977777B757A79787A7D78757A787A7B7977787577787D78787B7C
787C7B7B7C7F7B7C797C797A7C7D7F7B7C7D7D7E7D807E818581818687877C7769574838
352C2C2B302E2D30
9C9C9CA09C9B9B989F9F9D9D9F9A9E9A9B9E999D9E9C9D9A97989A9A9B9E96999B9B9B9F
A0A0A7A5ABA7A8A9ABADADA6A8AAA5A8A4A39E95908E8488837C7168615A5A595A5B5F63
69616264646469686765676968686367666B6E6A64676765676966656A6E6C6F706C6D6D
71757873777B7C7D797D797B7B7A7B7F7B7D83817D81857F7E807F8086808483807F8381
8183858387837D837C838182818286828083878187858A82848685838384858584878785
8182807F847F848483878384818A828181828385867F87828681828280828883887F8183
827E827F7E807F7D847D817F818181818581818283838081868081808484808285808181
847F808181838280858184828282828383817E817F7E827D817F81807E817E7E80807F7C
807C8280848080818181817F81847F7E7D78777B7076767A76707374716B6E6A6E6A6764
6D71787C81888C8A8F9496979B9A9FA0A29FA39B9A9E9A979A9C98979B9D9BA0A19E9E9D
9FA09C9D9B9D9E9B9B9D9B9B9B9A9A9F999C9D9D9B9B9999989E9A9E96999B9D99959B9A
9798999A9B969695979BA8B8C2CACED1D5D5D8D7D9D9DADBD9D6D0C6B7A58D6F6A64646A
696C6D6F736E75757B7A737776757A7C79757979767778777875797977777978797C7C7D
7A7B767E7A7B7A797B7D7E7C7A7C7C7C7F7D82817B7E7D7C7F8184888383827E726B5B4D
3D2F30342F2E3333
9B9B9D9E9B9A9B9DA19B9B9D9D9D9D989C9B99999C9D9B99979A999B9A979B9D98969BA3
A3A2A4A6AAA8AAA8AAADA9ACACACA9A8AAA09B9A958C8A837979716A615E5B5C5A5B595B
615D6667626365666C6569676368697069676B6A69686766636B6763646E696D6D6D6A73
7274747275747D77767C7F787C7E7C787E7C7E807E8280817D8083818381808081808882
8383807F83807F828384808082808385828484818583868789868987898A858485808587
8C8184858482888A858984848C858382807C858581838387847F7D7F83808683827D8382
8280817C807F807F81868681818283847E7C7C80807E8383828081838483848282848082
80808183828588828184858083858086807E827F817D837F81817F7D7C7D7F7B7C807A7C
817D8281817B7E807F82787B7D827D7D7C7F7C7D747778787273706F6F71676F6967666C
6F75767C82878C8B909596959B999E9DA1A2A09D9D989D9B9A9C9A989AA19C9F9D9B9C9B
9F9B999899999A9D9C9D9C9A99989A989A979B9C9697999A9C9A9D9C979E999B9A9E9B98
9E94999A999A9B9596A1B3BEC7CDD1D3D5D7D8D9D8D8D9DAD7D4CCBDAC947C6E6968686C
6E71707375757576777A747877797A777C7777817E787A7877787B797D7A7B7C7E7A7B7B
7D7F7B757A7E7C797E7E817A7A7C7E817D7C7D7F7E7F7F7D7E7D83837C827F7E7D776961
523B352E312F2E2C
9B9B9E9E9FA09D9DA39D9FA09F9A9C9D9B9BA29E9D999C989C9B979998979D9A9B9A999C
A1A0A8A5AAAAB0A9ACA9AAAEADA7A8AAA5A2A097939389887C786E72615E5A57585C5D5F
5E67636869676866696E6B6768656C6C66666B696B676C67666D73676A6B67726E716E72
6E7277757778797C77787F7A7E7D827C7D7D81807A7E7E81817D85858581858482837F81
8480818482828481807F83818286818B80858482858585868486858A8682858384838785
88828585817E8C838780858384838685848485878683848282888184847B858386838886
82807D807C7F8281828688858B8486847F8282838483848184868285828285837E818482
868686818384888385847F80837F7B84827F83827D7C847C7F7E83807B7E807B827E817F
8182837F807E808282837F7D7E7C80787E807A7E7A777A747170706C6F716F6A66676B6A
7375798386888C938F9995989A9C9C9EA29F9E9C9A9B999999999798999B9C9D999C9A9A
9A9E9C9F9B9D9E9F999D9D9A9C9C98999A9A989A989A9C9B9A9C9C999A9C9B99999D9C9B
9B999C98979A98959CA9BAC3CACDD3D3D4D8D8DAD8D9DBD8D5CCC4B39F827067666D6C6A
706F737174767B77767D777975797D76777A7777767C7C7C7876797A787C7D7C7E7D7B76
7B7E7B797C7E7B7B787C7D7B7E7C7C7D80817D807C80807F80817F7D80827D7F80817B6C
5E494030322E2F31
9F9F9B9D9E9F9C9D9FA2A2A0999999979B9A9C999B9998989A9A99979898999A9C9D9899
9D9EA4A2A8A9A9AAAFADADABABAFAAACA6A4A39A969688857C79726E5E5E5A535656585D
5D646165696E6A6D6A68676563696A6C656766636A67696B67676B6A6A696B696D707070
71737377797A7D7D7E807F7C807D7B7A81787B7F7F847F80817F8183828382847E84867F
848685868386838383818181868580838183838484868684888582828588868383848283
8486848481838484828284868287818683838486858282847F86857F898981818C888482
8983828182828180808188898284838181847E7D80848581868684858585857F8285827D
828785848588838483858282817F8082818086827F81807F7D8282817E807C8580828480
8183828282837D8282827D817E7D827C7E7A787576797874777071736F6A6A6D63657174
7A7B7E88898D8F91949C989A9B9D9EA3A09FA09B9E9C949895979B9993999A989A989997
9B9999A19C999B9A9C9A999A999699989B9A979A9B97979798979B979B9A989AA19D9E9E
9C999C999B979596A5B4C2C9CDD0D3D7D7D7D9D9DADADAD7D1C9BBA98D7A666167686F6C
72717572767772747774777679747B7776797C7B7E797E7C7B7C777B7A7C7F7C7C7D7F7D
7A807D787C7B777E7B797D7979777A7E7E8081807A7F818380807D7D7B7C7880817E7F7C
725E53464332372F
A0A0A39EA0A29F9C9FA39EA39B9B9C9899A09A9A9E969B989A9A989A979599A09E9B9B9A
9F9FA4A6A8A7A9ABABABABAEACADA9A7A7A69F9C94918A827A7E6B6B6162595E5B635C63
61606068686D6F6866636A676A656A666266686C6C6C656B686A6B68666673676C6B6F71
787873777578787B80797C7B7B7D777D7C7A81848581818286877D817E8781858481817B
847E85858282837F7D86827E8282828286838886878588858486868486868A8385878383
8683867F858181828383857F8786878685838583888684858580858588868389858A827D
8483807E8386808083828584888A81808483827E82848383848682878486857F84848281
84888381838786848582817E837D827E7E8184837F7B848180807E7F7E807F7F8083857D
838082807E817E7F81828181807B7D7B7B7A7C7A7B7E777474706E6F6E67676866667276
7A7E7D84898D919690969A9D9E9D9E9FA39D9B9B9A9798989899999897979D989E959A98
9E9B9B9C9A99999799999799979A9C9D9B9A9B989A9998979A989A9E9B9A9C9B9D999D9E
9A9C9B9A979698A1AEC1C7CBCFD3D4D6D8D9DADCDCDBD9D4CDC3B29B826C6A6466676D69
71757473777C7673787A7976797A7F7A7A7C7D7E787876797D797C7A7E767A817D7C7B7F
7F787D7A7A7A767E7D7A7D7A7A7B7E7B7D7F797A7B7D7D7E7D7E7E7C7778767F7E7E8281
7F7E79705C4F403A
A4A49E9BA19F9FA0A1A09B9F9A9A9C9A9C9C999D989999969C9C9A9A9C989B9D9D999897
9D9FA1A5A5A8AAAAABADB0ABAAB0ABABA8A79E9E969390817B776F6E66605C5F595F6061
666563646C686A6A696B6C69646A686C6A6469686A6C69666C686F67696B6F686C6F6F72
77737678787A77797C7A7A807D7A7D7E7C7C7D7C828583818582817F8585818087838384
847D8082828583827F8181818987878582878689878A8A88868685898688888486868A86
83847F85877E828483838586868585858586848287868885848584888386878980848081
7F7E808483838184847F7E83848A817B8182818282808088828583878483868183868081
82848682848886868482847D868084827E81828580808382808186847B7A7C80857F8382
7F7E838381857F7F7E8380817F7F7E7D7B787A7B7C7C77747272766C6F696A68656E6D78
7A80808B8A9092979795999B9DA19FA49F9D9F999797979998979A9792999B949A9C9799
9A989C9E9B9A9A98989A97979898999B969A95999E9F9B989A9B989A9C9E9B9C9F9A9B9D
9D9C9A9896989DA9BAC2C8D0D1D4D6D7D8DADAD9DADBD7D1C8BAA38C706761686669706F
6F78747775767879787C7A7A757A7A7C7A7C7B7A797C7677747D79757A787B7F7E7B7D7C
7F7A787D7F7B7A817C7B76767F7A797C807F7F7C807E827E7C7D797B7773727B7A7A7E7E
888F94928B7C674D
A2A2A2A1A29DA3A1A6A2A2A09BA3A09B9D9CA1A19A9C9A9D999D9A989C9A9A9C9A9E9BA0
9EA7A0A6A6A5A6ACABAFADAAACACA7AFA8A7A2A19394998C8277766A61615E5C58616760
686569696969686E6E6C6B69686D6D6D6C6A6A6C6E6D6B6D6D6E6E6C686A6A6C6D6F766F
71767977707A797A7D7A797C7B82817B7A7F8483848187818083837F8789848683838082
867E817E8582818380838180878588868086828785858687848784888684858588858686
848583848587898685838583878884878889858A88878589878884858C84838B86838184
837E83838483818483808785858783848585838582838385888684878487868A83838385
8181858A8A8E8684848180808586818486858380817F83847E828786817F7E827F83867F
7E848380837F837D80827E807F847E81797C7C79777A797775726F717369666768707476
7A84878B8C9192979998999F9F9FA39EA2A19B9B949499959A97979B979D9B989D9C9A9A
9F9F9C9E9A99979D99979A989A9998999897979E9A9A9898999D9A9E9E9D9A9A9CA0A0A0
9D9C9C989B9B9EB1C0C6CED0D3D3D4D7DADADADADCD8D3CCC0AC987A6B6A6567686F6971
747577757776797B7F797775787D79767B7A7D8079777B76797C7B787A79797B7A7C8176
7C7E7C7E7E7F7B7B7C7D7676807A7E7E7E827C7E7E7A827C7E7F777B727974777673787C
89A2A8A9ABAA9B80
A2A2A2A1A29DA3A1A6A2A2A09BA3A09B9D9CA1A19A9C9A9D999D9A989C9A9A9C9A9E9BA0
9EA7A0A6A6A5A6ACABAFADAAACACA7AFA8A7A2A19394998C8277766A61615E5C58616760
686569696969686E6E6C6B69686D6D6D6C6A6A6C6E6D6B6D6D6E6E6C686A6A6C6D6F766F
71767977707A797A7D7A797C7B82817B7A7F8483848187818083837F8789848683838082
867E817E8582818380838180878588868086828785858687848784888684858588858686
848583848587898685838583878884878889858A88878589878884858C84838B86838184
837E83838483818483808785858783848585838582838385888684878487868A83838385
8181858A8A8E8684848180808586818486858380817F83847E828786817F7E827F83867F
7E848380837F837D80827E807F847E81797C7C79777A797775726F717369666768707476
7A84878B8C9192979998999F9F9FA39EA2A19B9B949499959A97979B979D9B989D9C9A9A
9F9F9C9E9A99979D99979A989A9998999897979E9A9A9898999D9A9E9E9D9A9A9CA0A0A0
9D9C9C989B9B9EB1C0C6CED0D3D3D4D7DADADADADCD8D3CCC0AC987A6B6A6567686F6971
747577757776797B7F797775787D79767B7A7D8079777B76797C7B787A79797B7A7C8176
7C7E7C7E7E7F7B7B7C7D7676807A7E7E7E827C7E7E7A827C7E7F777B727974777673787C
89A2A8A9ABAA9B80
A2A2A2A1A29DA3A1A6A2A2A09BA3A09B9D9CA1A19A9C9A9D999D9A989C9A9A9C9A9E9BA0
9EA7A0A6A6A5A6ACABAFADAAACACA7AFA8A7A2A19394998C8277766A61615E5C58616760
686569696969686E6E6C6B69686D6D6D6C6A6A6C6E6D6B6D6D6E6E6C686A6A6C6D6F766F
71767977707A797A7D7A797C7B82817B7A7F8483848187818083837F8789848683838082
867E817E8582818380838180878588868086828785858687848784888684858588858686
848583848587898685838583878884878889858A88878589878884858C84838B86838184
837E83838483818483808785858783848585838582838385888684878487868A83838385
8181858A8A8E8684848180808586818486858380817F83847E828786817F7E827F83867F
7E848380837F837D80827E807F847E81797C7C79777A797775726F717369666768707476
7A84878B8C9192979998999F9F9FA39EA2A19B9B949499959A97979B979D9B989D9C9A9A
9F9F9C9E9A99979D99979A989A9998999897979E9A9A9898999D9A9E9E9D9A9A9CA0A0A0
9D9C9C989B9B9EB1C0C6CED0D3D3D4D7DADADADADCD8D3CCC0AC987A6B6A6567686F6971
747577757776797B7F797775787D79767B7A7D8079777B76797C7B787A79797B7A7C8176
7C7E7C7E7E7F7B7B7C7D7676807A7E7E7E827C7E7E7A827C7E7F777B727974777673787C
89A2A8A9ABAA9B80
A2A2A2A1A29DA3A1A6A2A2A09BA3A09B9D9CA1A19A9C9A9D999D9A989C9A9A9C9A9E9BA0
9EA7A0A6A6A5A6ACABAFADAAACACA7AFA8A7A2A19394998C8277766A61615E5C58616760
686569696969686E6E6C6B69686D6D6D6C6A6A6C6E6D6B6D6D6E6E6C686A6A6C6D6F766F
71767977707A797A7D7A797C7B82817B7A7F8483848187818083837F8789848683838082
867E817E8582818380838180878588868086828785858687848784888684858588858686
848583848587898685838583878884878889858A88878589878884858C84838B86838184
837E83838483818483808785858783848585838582838385888684878487868A83838385
8181858A8A8E8684848180808586818486858380817F83847E828786817F7E827F83867F
7E848380837F837D80827E807F847E81797C7C79777A797775726F717369666768707476
7A84878B8C9192979998999F9F9FA39EA2A19B9B949499959A97979B979D9B989D9C9A9A
9F9F9C9E9A99979D99979A989A9998999897979E9A9A9898999D9A9E9E9D9A9A9CA0A0A0
9D9C9C989B9B9EB1C0C6CED0D3D3D4D7DADADADADCD8D3CCC0AC987A6B6A6567686F6971
747577757776797B7F797775787D79767B7A7D8079777B76797C7B787A79797B7A7C8176
7C7E7C7E7E7F7B7B7C7D7676807A7E7E7E827C7E7E7A827C7E7F777B727974777673787C
89A2A8A9ABAA9B80
A2A2A2A1A29DA3A1A6A2A2A09BA3A09B9D9CA1A19A9C9A9D999D9A989C9A9A9C9A9E9BA0
9EA7A0A6A6A5A6ACABAFADAAACACA7AFA8A7A2A19394998C8277766A61615E5C58616760
686569696969686E6E6C6B69686D6D6D6C6A6A6C6E6D6B6D6D6E6E6C686A6A6C6D6F766F
71767977707A797A7D7A797C7B82817B7A7F8483848187818083837F8789848683838082
867E817E8582818380838180878588868086828785858687848784888684858588858686
848583848587898685838583878884878889858A88878589878884858C84838B86838184
837E83838483818483808785858783848585838582838385888684878487868A83838385
8181858A8A8E8684848180808586818486858380817F83847E828786817F7E827F83867F
7E848380837F837D80827E807F847E81797C7C79777A797775726F717369666768707476
7A84878B8C9192979998999F9F9FA39EA2A19B9B949499959A97979B979D9B989D9C9A9A
9F9F9C9E9A99979D99979A989A9998999897979E9A9A9898999D9A9E9E9D9A9A9CA0A0A0
9D9C9C989B9B9EB1C0C6CED0D3D3D4D7DADADADADCD8D3CCC0AC987A6B6A6567686F6971
747577757776797B7F797775787D79767B7A7D8079777B76797C7B787A79797B7A7C8176
7C7E7C7E7E7F7B7B7C7D7676807A7E7E7E827C7E7E7A827C7E7F777B727974777673787C
89A2A8A9ABAA9B80
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{544, 544},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008P000282000`400?l00000o`00003oo`38h=So
0<SPf280b>3H003o0<SPf?l0b>3H8P38h=P00?l0b>3Ho`38h=PR0<SPf000o`38h=So0<SPf280b>3H
003o0<SPf?l0b>3H8P38h=P00?l0b>3Ho`38h=PR0<SPf000o`38h=So0<SPf280b>3H003o0<SPf?l0
b>3H8P38h=P00?l0b>3Ho`38h=PR0<SPf000o`38h=So0<SPf280b>3H003o0<SPf?l0b>3H8P38h=P0
0?l0b>3Ho`38h=PR0<SPf000o`38h=So0<SPf280b>3H003o0<SPf?l0b>3H8P38h=P000`0b>3H0P0/
;2`02P0g=cL0@T9203Hf=P0_;bl0<S8b03<c<`0k>c/0<c<c02l_;`0c<c<203De=@0504m?C`1]KFd0
TI6A0;Rh^033`l<00P34a<@05@38b<P0a/K60<K6aP37alL0`L710<30`02o_kl0]kNg0;:b/P2OWil0
N7Qh06UYJ@1^KVh0MgMg08>3P`27QhL0SXj>09^KV`2OWil0YJFU0:>SX`020:NWY`1=0;:b/P2^[Zh0
][Jf0;Bd]02c/k<0];Bd0;Fe]@2b/[80][Jf0;Bd]02g]kL0][Jf0;Ng]`2_[jl0/k>c0:f][@2SXj<0
Ogmo04i>CP1OGel0GUiN04E5A@0h>3P0=CDe04M7A`0`<300:b/[02LW9`0[:b/0:2PX02TY:@0f=SH0
?Shn04I6AP0l?3`08R8R02HV9P0f=SH0BDU902/[:`0_;bl0Bd];04M7A`0o?cl0EEEE03Ph>010@400
?Shn04Q8B016ATH0>CTi04I6AP18B4P0ADE505ADE011@D40>CTi03De=@0j>SX0BDU906QXJ01QHF40
ATI608R8R02RXZ80G5aL03Xj>P0e=CD0=SHf04a<C013@d<09BDU03<c<`0k>c/0>SXj04Q8B01bLW80
0P1aLG401P0b<S809RHV030`<01ADE40CTi>04];B`80A4A40380B4Q803lo?`1fMWH0RXZ:07IfMP1M
GEd0>c/k03De=@10@400Ogmo09BDU01MGEd0EEEE02d];@0T92@0<S8b03De=@0b<S80:2PX030`<00b
<S80ADE50492@P1?Cdl0DE5A04=3@`10@400AdM702l_;`0X:2P0=SHf03De=@0d=3@0BTY:07AdM01P
H600;Bd]02TY:@0n?Sh0GemO06IVIP19BDT0De=C07UiN@1JFUX0>SXj03Ti>@1;Bd/0De=C055AD@80
DU9B00P0E5AD05iNGP1JFUX0Fe]K05UIF@1MGEd0IVIV06ATI080Jf][00/0K6a/06i^KP1^KVh0L71`
075aL@1`L700NGUi07IfMP1jNWX0MWIf07inOP0207UiN@0907QhN01nOWh0Ng]k07emO@1jNWX0O7al
07inOP1mOGd0Ph>300@0PX:200D0OGem07]kN`1oOgl0OWin07moO`020861P@0D07emO@1oOgl0PH61
0820P01nOWh0PX:208B4Q026QXH0Q8B408F5Q@26QXH0Q8B408N7Q`22PX80QHF508>3P`22PX80Ph>3
08B4Q023Ph<208N7Q`80RHV900H0SHf=08^;R`25QHD0QXJ608R8R025QHD208B4Q00808Z:RP26QXH0
RHV908J6QP27QhL0RXZ:08V9R@2<S8`208f=S@0508Z:RP2@T900SXj>08b<S02=SHd00P2;Rh/0202?
Shl0TY:B092@T02?Shl0TY:B09BDU02@T900SHf=0P2?Shl00`2ATI40Shn?08j>SP0208n?S`0409FE
U@2BTY80Ti>C092@T0<0TY:B00@0T92@09>CT`2DU9@0UiNG0P2EUID00`2GUiL0UIFE09VIV@0209FE
U@<0U9BD00@0UiNG09BDU02GUiL0UIFE0P2HV9P06`2CTi<0UIFE09RHV02FUYH0VIVI09FEU@2KVi/0
WinO09bLW02TY:@0V9RH09bLW02NWYh0Vi^K09fMW@2PX:00WinO0:BTY02OWil0Xj>S0:FUY@2XZ:P0
YJFU0:>SX`2VYZH0Xj>S0:RXZ0030:VYZ@80[:b/00@0[Zj^0;2`/02/[:`0/k>c0P2h^;P01@2i^KT0
^;Rh0;Zj^P30`<00_kno0080`<3000D0`l?30<;2`P33`l<0`L710<K6aP020<O7a`050<_;b`3:b/X0
bl_;0<c<c03>c/h00P3?cll20=7Ad@050<o?c`3@d=00dm?C0=?Cd`3Bd]800P3De=@00`3<c<`0WIfM
07IfMP0206e]K@0J071`L01VIVH0GemO05iNGP1HF5P0GEeM05]KF`1MGEd0FUYJ05iNGP1RHV80GUiN
065QH@1RHV80Jf][06QXJ01ZJVX0JFUY06IVIP1hN7P0O7al07inOP1oOgl0PX:208F5Q@27QhL208B4
Q0060861P@1nOWh0P82007UiN@1oOgl0OGem0P1nOWh01P1iNGT0OGem0820P024Q8@0RXZ:08^;R`80
S8b<0P27QhL06`22PX80O7al07MgM`1fMWH0K6a/06ATI01OGel0EUIF05aLG01JFUX0FEUI05ADE01A
DE40CTi>04Q8B01=CDd0BTY:04Q8B01>CTh0ADE5055AD@1FEUH0FEUI05]KF`1JFUX0GEeM05YJFP02
05aLG00905ADE01GEeL0De=C051@D01DE5@0FEUI061PH01NGUh0IVIV0080L71`00@0MgMg07inOP20
P800NWYj0`21PH402`1lO7`0Ng]k07MgM`1aLG40IFEU061PH01DE5@0Bd];03hn?P0l?3`0>c/k0080
>SXj0P0c<c<0500/;2`0:BTY02XZ:P0b<S80;Rh^03@d=00f=SH0>c/k04A4A018B4P0C4a<05=CD`1N
GUh0FUYJ065QH@1XJ6P0I6AT06QXJ01YJFT0K6a/3P38h=P000`0b>3H0P0/;2`02P0g=cL0<c<c03Hf
=P0_;bl0<S8b03<c<`0k>c/0<c<c02l_;`0c<c<203De=@0504m?C`1]KFd0TI6A0;Rh^033`l<00P34
a<@05@38b<P0a/K60<K6aP37alL0`L710<30`02o_kl0]kNg0;:b/P2OWil0N7Qh06UYJ@1^KVh0MgMg
08>3P`27QhL0SXj>09^KV`2OWil0YJFU0:>SX`020:NWY`1=0;:b/P2^[Zh0][Jf0;Bd]02c/k<0];Bd
0;Fe]@2b/[80][Jf0;Bd]02g]kL0][Jf0;Ng]`2_[jl0/k>c0:f][@2SXj<0Ogmo04i>CP1OGel0GUiN
04E5A@0h>3P0=CDe04M7A`0`<300:b/[02LW9`0[:b/0:2PX02TY:@0f=SH0?Shn04I6AP0l?3`08R8R
02HV9P0f=SH0BDU902/[:`0_;bl0Bd];04M7A`0o?cl0EEEE03Ph>010@400?Shn04Q8B016ATH0>CTi
04I6AP18B4P0ADE505ADE011@D40>CTi03De=@0j>SX0BDU906QXJ01QHF40ATI608R8R02RXZ80G5aL
03Xj>P0e=CD0=SHf04a<C013@d<09BDU03<c<`0k>c/0>SXj04Q8B01bLW800P1aLG401P0b<S809RHV
030`<01ADE40CTi>04];B`80A4A40380B4Q803lo?`1fMWH0RXZ:07IfMP1MGEd0>c/k038b<P10@400
Ogmo09BDU01MGEd0EEEE02d];@0T92@0<S8b03De=@0b<S80:2PX030`<00b<S80ADE50492@P1?Cdl0
DE5A04=3@`10@400AdM702l_;`0X:2P0=SHf03De=@0d=3@0BTY:07AdM01PH600;Bd]02TY:@0n?Sh0
GemO06IVIP19BDT0De=C07UiN@1JFUX0>SXj03Ti>@1;Bd/0De=C055AD@80DU9B00P0E5AD05iNGP1J
FUX0Fe]K05UIF@1MGEd0IVIV06ATI080Jf][00/0K6a/06i^KP1^KVh0L71`075aL@1`L700NGUi07If
MP1jNWX0MWIf07inOP0207UiN@0907QhN01nOWh0Ng]k07emO@1jNWX0O7al07inOP1mOGd0Ph>300@0
PX:200D0OGem07]kN`1oOgl0OWin07moO`020861P@0D07emO@1oOgl0PH610820P01nOWh0PX:208B4
Q026QXH0Q8B408F5Q@26QXH0Q8B408N7Q`22PX80QHF508>3P`22PX80Ph>308B4Q023Ph<208N7Q`80
RHV900H0SHf=08^;R`25QHD0QXJ608R8R025QHD208B4Q00808Z:RP26QXH0RHV908J6QP27QhL0RXZ:
08V9R@2<S8`208f=S@0508Z:RP2@T900SXj>08b<S02=SHd00P2;Rh/0202?Shl0TY:B092@T02?Shl0
TY:B09BDU02@T900SHf=0P2?Shl00`2ATI40Shn?08j>SP0208n?S`0409FEU@2BTY80Ti>C092@T0<0
TY:B00@0T92@09>CT`2DU9@0UiNG0P2EUID00`2GUiL0UIFE09VIV@0209FEU@<0U9BD00@0UiNG09BD
U02GUiL0UIFE0P2HV9P06`2CTi<0UIFE09RHV02FUYH0VIVI09FEU@2KVi/0WinO09bLW02TY:@0V9RH
09bLW02NWYh0Vi^K09fMW@2PX:00WinO0:BTY02OWil0Xj>S0:FUY@2XZ:P0YJFU0:>SX`2VYZH0Xj>S
0:RXZ0030:VYZ@80[:b/00@0[Zj^0;2`/02/[:`0/k>c0P2h^;P01@2i^KT0^;Rh0;Zj^P30`<00_kno
0080`<3000D0`l?30<;2`P33`l<0`L710<K6aP020<O7a`050<_;b`3:b/X0bl_;0<c<c03>c/h00P3?
cll20=7Ad@050<o?c`3@d=00dm?C0=?Cd`3Bd]800P3De=@00`3<c<`0WIfM07IfMP0206e]K@0J071`
L01VIVH0GemO05iNGP1HF5P0GEeM05]KF`1MGEd0FUYJ05iNGP1RHV80GUiN065QH@1RHV80Jf][06QX
J01ZJVX0JFUY06IVIP1hN7P0O7al07inOP1oOgl0PX:208F5Q@27QhL208B4Q0060861P@1nOWh0P820
07UiN@1oOgl0OGem0P1nOWh01P1iNGT0OGem0820P024Q8@0RXZ:08^;R`80S8b<0P27QhL06`22PX80
O7al07MgM`1fMWH0K6a/06ATI01OGel0EUIF05aLG01JFUX0FEUI05ADE01ADE40CTi>04Q8B01=CDd0
BTY:04Q8B01>CTh0ADE5055AD@1FEUH0FEUI05]KF`1JFUX0GEeM05YJFP0205aLG00905ADE01GEeL0
De=C051@D01DE5@0FEUI061PH01NGUh0IVIV0080L71`00@0MgMg07inOP20P800NWYj0`21PH402`1l
O7`0Ng]k07MgM`1aLG40IFEU061PH01DE5@0Bd];03hn?P0l?3`0>c/k0080>SXj0P0c<c<0500/;2`0
:BTY02XZ:P0b<S80;Rh^03@d=00f=SH0>c/k04A4A018B4P0C4a<05=CD`1NGUh0FUYJ065QH@1XJ6P0
I6AT06QXJ01YJFT0K6a/3P38h=P000`0b>3H0P0[:b/04`0b<S80;bl_03Hf=P0_;bl0<S8b034a<@0l
?3`0=CDe02d];@0g=cL0>3Ph0410@01BDU80L71`09JFUP30`<00`/;20<G5a@34a<@00P38b<P04`36
a/H0aLG50<G5a@30`<00_Kfm0;Vi^@2d];@0YjNW0820P01YJFT0KFe]07QhN023Ph<0RHV9092@T02J
VYX0XJ6Q0::RXP2YZJT00P2ZZZX01@2b/[80/K6a0;Fe]@2c/k<0]KFe0080];Bd02L0][Jf0;Fe]@2f
][H0]KFe0;Ng]`2e]KD0/k>c0:j^[P2][Jd0XZ:R07QhN019BDT0EeMG05YJFP0o?cl0;bl_03Ti>@17
AdL0?Cdm030`<00V9RH0;Rh^02/[:`0/;2`0;bl_0410@011@D40?Cdm02TY:@0X:2P0=SHf04e=C@0b
<S80=CDe0451@@0i>CT0ADE504I6AP0f=SH00P0o?cl0201=CDd0AdM703`l?01<C4`0ATI604];B`1E
EED0>3Ph0`0f=SH04P0l?3`0EEEE05MGE`17AdL0JFUY0:JVYP1gMgL0?3`l02l_;`0l?3`0BDU903Ph
>00V9RH0B4Q803lo?`0e=CD0B4Q807MgM`80Lg=c00H0:b/[028R8P0m?Cd0Fe]K04Y:BP1DE5@204I6
AP1=04m?C`1NGUh0R8R807QhN01JFUX0>c/k03Lg=`0];Bd0BDU907inOP29RHT0IFEU06=SH`0c<c<0
9bLW02l_;`0Z:RX09bLW038b<P0m?Cd0?Shn05]KF`14A4@0DU9B04Y:BP0o?cl0@T920451@@0^;Rh0
:BTY03@d=00/;2`0>CTi05=CD`1_Kfl0ADE503Ti>@1<C4`0D51@06a/K01^KVh0I6AT07AdM01JFUX0
=cLg03Ti>@0c<c<0?Cdm04m?C`1BDU80DE5A04i>CP1EEED0FEUI05=CD`1HF5P0FEUI06=SH`1RHV80
JVYZ06QXJ01YJFT0KVi^075aL@1`L700MGEe079bLP1eMGD0MgMg07IfMP1cLg<0MgMg07alO01mOGd0
Ng]k07YjNP1mOGd00P1lO7`0101nOWh0O7al0861P@1nOWh307]kN`0507inOP1mOGd0Ng]k08>3P`1o
Ogl00P1nOWh01021PH40PX:207emO@1oOgl208:2PP0>07emO@21PH40P82008:2PP21PH40QHF508J6
QP21PH40QhN708:2PP21PH40Ph>30820P023Ph<208B4Q080QHF501@0R8R808J6QP2:RXX0SHf=08^;
R`2>SXh0Ph>308F5Q@24Q8@0QHF508Z:RP25QHD0QhN708V9R@27QhL0Rh^;08b<S02:RXX0R8R808Z:
RP80SHf=00<0TY:B08V9R@2=SHd00P2>SXh01@2ATI40TY:B096AT@2DU9@0TY:B0080T92@00X0TI6A
09>CT`2>SXh0T92@08j>SP2;Rh/0SXj>092@T02FUYH0UiNG0P2BTY801`2DU9@0TY:B092@T02@T900
UIFE09JFUP2EUID00P2DU9@03@2JVYX0U9BD09JFUP2DU9@0UIFE09>CT`2DU9@0V9RH09JFUP2HV9P0
U9BD09>CT`2DU9@00P2FUYH0102EUID0V9RH09RHV02BTY8209JFUP80W9bL00l0X:2P09^KV`2KVi/0
WIfM09jNWP2LW9`0WYjN0::RXP2PX:00Y:BT0::RXP2VYZH0YjNW0:RXZ02VYZH00P2TY:@02@2XZ:P0
YjNW0:ZZZP2ZZZX0[:b/0:f][@2/[:`0[Jf]0:j^[P020;Bd]00=0;Ng]`2f][H0^k^k0;jn_P2m_Kd0
`L710<30`031`L40`/;20<?3``35aLD0`l?30<W9b@020<S8b0070<c<c03:b/X0c<c<0<c<c03=cLd0
clo?0=?Cd`020=CDe0040=3@d03AdM40dm?C0=;BdP80e=CD00@0eMGE0<G5a@2:RXX0IFEU0P1LG5`0
1@1PH600GEeM05=CD`1HF5P0FEUI0080GUiN01d0GEeM05MGE`1HF5P0G5aL06ATI01QHF40IFEU06m_
K`1/K6`0J6QX06i^KP1]KFd0MgMg075aL@1eMGD0O7al07emO@25QHD0Ph>30861P@25QHD0OWin07al
O01hN7P0O7al07UiN@1jNWX0Ng]k07YjNP0207QhN00307inOP25QHD0PX:20080R8R800@0SXj>08J6
QP29RHT0P8200P1mOGd0401cLg<0LW9b06UYJ@1TI6@0H61P05aLG01KFe/0HV9R05UIF@1FEUH0DE5A
05MGE`1BDU80C4a<04m?C`18B4P204];B`0604m?C`1GEeL0GEeM05mOG`1QHF40EUIF0P1JFUX02@1D
E5@0EEEE055AD@1EEED0Cdm?05ADE01LG5`0GUiN06IVIP0206YZJP0Z07AdM01fMWH0OGem07inOP23
Ph<0Q8B407moO`1mOGd0P82007MgM`1eMGD0JFUY061PH01HF5P0Cdm?04i>CP16ATH0?clo03Xj>P0e
=CD0<c<c03Hf=P0^;Rh0;Bd]034a<@0];Bd0<30`03@d=00^;Rh0=3@d03De=@0k>c/0ATI604E5A@1?
Cdl0D51@05aLG01PH600I6AT06QXJ01TI6@0HV9R3P38h=P000`0b>3H0P0^;Rh2038b<P0@03@d=00a
<C40<S8b03<c<`0k>c/0=cLg03Xj>P0f=SH0=cLg04A4A01GEeL0MgMg09fMW@31`L40a<C40<?3``80
aLG501<0b<S80<O7a`39bLT0a<C40<;2`P2o_kl0^KVi0;>c/`2/[:`0QhN706ATI01]KFd0Kfm_07em
O@27QhL0Shn?09VIV@2PX:00XZ:R00<0Zj^[00X0/k>c0;2`/02`/;00/[:b0;6a/@2b/[80]KFe0;Bd
]02c/k<0];Bd0P2g]kL0B@2f][H0];Bd0:j^[P2[Zj/0VIVI07=cL`1TI6@0H61P05IFEP1>CTh0<c<c
03Lg=`0l?3`0@d=302h^;P0W9bL0;2`/02HV9P0W9bL0;Rh^03/k>`0o?cl0>CTi02l_;`0[:b/0>SXj
04U9B@0l?3`0<S8b04e=C@0l?3`0>CTi04A4A00f=SH0@d=303hn?P1;Bd/0CTi>0410@01MGEd0ATI6
04a<C01?Cdl0=3@d02h^;P0g=cL0=CDe03lo?`1DE5@0ADE503De=@1?Cdl0V9RH08V9R@11@D40<S8b
04E5A@0n?Sh0<30`034a<@14A4@0?clo03Ti>@1ADE40MgMg07IfMP1gMgL0:b/[02PX:01;Bd/0GUiN
04];B`1:BTX00P1<C4`0701XJ6P0Ng]k08J6QP1VIVH0?Cdm02TY:@0/;2`0>c/k04m?C`24Q8@0NGUi
07]kN`1YJFT0>3Ph030`<00W9bL08b<S02PX:00j>SX0?3`l04e=C@1JFUX0EeMG04];B`0m?Cd0=CDe
04E5A@0/;2`202XZ:P80>3Ph01D0?Cdm061PH01LG5`0Bd];04i>CP1GEeL0IVIV08>3P`29RHT0P820
05aLG00a<C40<c<c03Hf=P0a<C40=cLg04Q8B019BDT0CTi>051@D01OGel00P1CDe<01@1HF5P0Fe]K
05aLG01QHF40JVYZ00<0KFe]01D0L71`075aL@1dM7@0NGUi07IfMP1hN7P0Lg=c07IfMP1iNGT0NWYj
07emO@1fMWH0NGUi07emO@1jNWX0N7Qh07moO`1nOWh0NWYj07alO020P8000P1mOGd207inOP80Ogmo
0100O7al0820P023Ph<0OWin07emO@22PX80Ogmo08B4Q022PX80QHF507moO`21PH40Ogmo0861P@25
QHD0PH610P22PX803021PH40QXJ608F5Q@22PX80QhN708V9R@26QXH0Q8B408J6QP2;Rh/0QhN708^;
R`80R8R800D0Rh^;08F5Q@26QXH0PX:208F5Q@0208R8R00408N7Q`29RHT0R8R808n?S`80RXZ:00X0
SXj>08^;R`2=SHd0SXj>08b<S02=SHd0T92@08f=S@2BTY80Ti>C0P2?Shl05`2CTi<0TI6A09:BTP2>
SXh0TY:B096AT@2CTi<0U9BD09>CT`2>SXh0SHf=09FEU@2=SHd0TY:B08n?S`2EUID0U9BD09FEU@2C
Ti<0T92@09BDU02FUYH0UIFE0080UiNG00`0UIFE09BDU02@T900TY:B096AT@2HV9P0TY:B09FEU@2F
UYH0VIVI09BDU02?Shl309>CT`0309VIV@2BTY80UYJF0080UIFE0140V9RH09VIV@2MWId0Vi^K09RH
V02LW9`0VYZJ09fMW@2KVi/0X:2P09jNWP2QXJ40Xj>S0:RXZ02TY:@0XZ:R0:BTY0020:JVYP060:FU
Y@2YZJT0Z:RX0:NWY`2[Zj/0[jn_0P2/[:`0102b/[80/K6a0;Bd]02f][H30;Vi^@0@0<30`02m_Kd0
_[jn0<;2`P30`<00`/;20<K6aP37alL0a/K60<W9b@3=cLd0bLW90<c<c03=cLd0c<c<0<g=c@80clo?
00L0d];B0=7Ad@3AdM40cLg=0=CDe03Cdm<0e=CD0080emOG00@0eMGE0<30`01kNg/0EEEE0P1<C4`0
5`1ADE40De=C05MGE`1KFe/0G5aL05eMG@1PH600Fe]K05MGE`1PH600EUIF05aLG01UIFD0Jf][06m_
K`1YJFT0MWIf07=cL`1dM7@0LW9b06][J`1eMGD0NGUi0080Ogmo00h0PX:208F5Q@1nOWh0N7Qh07em
O@1jNWX0O7al07QhN01gMgL0NGUi07QhN01iNGT0NWYj07MgM`80PH6100P0Q8B408F5Q@28R8P0R8R8
08B4Q021PH40OWin07alO080MGEe00/0LG5a06QXJ01OGel0G5aL069RHP1LG5`0GEeM05]KF`1EEED0
GEeM05QHF002055AD@0904];B`1CDe<0D51@04];B`1>CTh0FUYJ05IFEP1IFET0EEEE0080F5QH00@0
EUIF059BDP1CDe<0De=C0P1=CDd00`1GEeL0IVIV05mOG`0206UYJ@0506m_K`1gMgL0OWin07moO`22
PX800P21PH405@20P800OWin07inOP1jNWX0Kfm_06EUI@1PH600EeMG051@D01>CTh0B4Q803/k>`0i
>CT0=cLg038b<P0g=cL0;Bd]03@d=00a<C40=3@d034a<@0203De=@0<03Ph>00m?Cd0?Shn04M7A`1;
Bd/0D51@05UIF@1MGEd0I6AT06IVIP1RHV80H61P3P38h=P000`0b>3H0P0f=SH0500`<300;bl_03De
=@0e=CD0<S8b03Lg=`0i>CT0?Cdm03<c<`0g=cL0>3Ph0410@01PH600N7Qh09nOW`30`<00`l?30<;2
`P33`l<0bLW90`38b<P04@36a/H0`L710<71`@2m_Kd0]KFe0:j^[P24Q8@0JFUY07=cL`1eMGD0N7Qh
08R8R02BTY80UiNG09nOW`2SXj<0ZJVY0080[Zj^00T0];Bd0;6a/@2_[jl0/K6a0;:b/P2e]KD0][Jf
0;:b/P2c/k<00P2e]KD02@2g]kL0^k^k0;6a/@2[Zj/0[Zj^09RHV01gMgL0JFUY06QXJ00205MGE`0Q
03De=@0d=3@0>3Ph03Lg=`0`<300:BTY03De=@0/;2`0;Bd]02/[:`0c<c<0>3Ph03/k>`0`<300:RXZ
03Ph>00j>SX0?3`l03Ti>@13@d<0=CDe03Xj>P18B4P0>SXj03lo?`0n?Sh0C4a<05=CD`19BDT0FEUI
04Q8B01?Cdl0AdM70080<C4a0100=cLg03hn?P11@D40DE5A03dm?@0a<C40?3`l08J6QP2<S8`0CDe=
03`l?015ADD0?Shn02h^;P0c<c<0=CDe0P0n?Sh02P1<C4`0Kfm_079bLP1hN7P0:BTY02XZ:P1FEUH0
GUiN04Y:BP18B4P2075aL@80SHf=00`0Lg=c04=3@`0/;2`08b<S030`<00k>c/0DU9B08J6QP1UIFD0
OWin06EUI@0d=3@303<c<`0604A4A017AdL0>CTi04i>CP1OGel0Fe]K0P11@D406P0k>c/0?Shn02PX
:00d=3@0=CDe04e=C@1<C4`0DU9B06UYJ@1ADE40?clo055AD@1MGEd0Ph>308B4Q01nOWh0H61P030`
<00T92@0:BTY02XZ:P0X:2P0;bl_03dm?@10@400ATI60P1;Bd/204i>CP80FUYJ0180GEeM05aLG01Y
JFT0Kfm_06EUI@1YJFT0K6a/06i^KP1fMWH0LW9b075aL@1fMWH0Kfm_07]kN`1gMgL0NGUi07YjNP1k
Ng/207QhN00707inOP1kNg/0OGem0820P01jNWX0Ng]k07moO`020820P00407moO`1mOGd0O7al07]k
N`80Ogmo00<0P82008B4Q028R8P00P21PH404023Ph<0Q8B408B4Q01nOWh0PH6108F5Q@22PX80QXJ6
08F5Q@28R8P0PH610820P023Ph<0QXJ608B4Q028R8P208J6QP0@08R8R02>SXh0S8b<08J6QP2;Rh/0
QXJ608V9R@24Q8@0QHF508B4Q023Ph<0R8R808^;R`2=SHd0Rh^;08b<S080SHf=00<0R8R8092@T02@
T9000P2?Shl0202=SHd0RHV908^;R`2;Rh/0T92@08f=S@2>SXh0TI6A0P2@T900102ATI40U9BD09>C
T`2BTY82096AT@0909FEU@2@T900Shn?08j>SP2?Shl0T92@09FEU@2>SXh0TI6A0080Ti>C00D0TI6A
09:BTP2DU9@0VIVI09RHV00209NGU`0309JFUP2EUID0Ti>C0080Ti>C00<0UIFE09:BTP2BTY800P2C
Ti<0:P2BTY80U9BD09>CT`2CTi<0V9RH09JFUP2DU9@0UIFE09NGU`2JVYX0V9RH09ZJVP2FUYH0Vi^K
09NGU`2HV9P0Vi^K09nOW`2PX:00WYjN09fMW@2SXj<0YjNW0:6QX@2TY:@0XZ:R0:6QX@2SXj<0XZ:R
0:JVYP2YZJT0[Zj^0:VYZ@2^[Zh0[jn_0:VYZ@2`/;00/K6a0;Rh^02d];@0^k^k0;fm_@80^[Zj0P2n
_[h01031`L40`/;20<?3``33`l<20<K6aP080<[:bP3;bl/0bLW90<_;b`3=cLd0c/k>0<c<c03;bl/2
0<o?c`070=3@d03De=@0d];B0<k>cP3EeMD0dm?C0=;BdP020=CDe0030=;BdP2b/[80JFUY00<0B4Q8
00@0CTi>05EEE@1EEED0EeMG0P1LG5`01P1MGEd0F5QH06=SH`1TI6@0H61P065QH@80IfMW0P1ZJVX0
901aLG40LW9b07IfMP1cLg<0M7Ad071`L01fMWH0MgMg07QhN020P800OGem07inOP1mOGd0Ng]k07in
OP1bLW80MgMg07EeM@1dM7@0L71`07IfMP1iNGT0N7Qh07MgM`1mOGd0O7al07moO`21PH40QXJ60820
P022PX80OGem07inOP1gMgL0Lg=c06m_K`80IVIV00D0I6AT05YJFP1NGUh0I6AT05QHF00205mOG`07
06=SH`1KFe/0EeMG059BDP1EEED0CDe=05=CD`0204a<C00>05ADE01EEED0F5QH05IFEP1CDe<0E5AD
059BDP1CDe<0CTi>04];B`1CDe<0FUYJ05MGE`1QHF4206i^KP0406m_K`1eMGD0MgMg07inOP80P820
00D0Ph>307emO@1nOWh0O7al07IfMP0206e]K@0306QXJ01OGel0E5AD0080DU9B00X0@d=303Xj>P0h
>3P0<C4a03De=@0i>CT0;Rh^03De=@0f=SH0<S8b0P0e=CD0300j>SX0=3@d03Lg=`10@400@d=304i>
CP1CDe<0F5QH05YJFP1MGEd0GUiN05YJFPh0b>3H000<0<SPf080<30`02P0>CTi03@d=00f=SH0=SHf
038b<P0i>CT0?clo03<c<`0g=cL0>SXj0410@016ATH0J6QX0861P@2OWil0a<C40<?3``35aLD0alO7
0<K6aP39bLT0cLg=0<W9b@37alL0a<C40<71`@2m_Kd0^;Rh0:^[Z`23Ph<0JFUY06e]K@1eMGD0OWin
08F5Q@2ATI40UYJF0::RXP2SXj<0Z:RX0P2^[Zh00`2a/K40/[:b0;6a/@020;6a/@090;:b/P2d];@0
/K6a0;Fe]@2d];@0]kNg0;Bd]02h^;P0/[:b0080[Jf]00P0YJFU08:2PP1iNGT0OWin06IVIP1MGEd0
<c<c03@d=080<S8b02T0<C4a02`/;00_;bl0>SXj02/[:`0Y:BT0=SHf03/k>`0e=CD0:BTY04];B`0f
=SH0<S8b03@d=00m?Cd0?3`l02d];@0j>SX0@D5103Hf=P10@400>c/k04];B`1HF5P0ADE505EEE@13
@d<0DE5A0492@P0j>SX0>3Ph03Xj>P11@D40C4a<04Q8B00h>3P0:BTY03De=@1WIfL0RXZ:05UIF@02
04];B`0703Lg=`0^;Rh0<30`03<c<`0j>SX0?clo051@D00206YZJP0707UiN@0U9BD0<c<c05mOG`1=
CDd0De=C04E5A@0208J6QP0G09ZJVP20P800GUiN038b<P0[:b/09BDU030`<00j>SX0F5QH07alO01T
I6@0P820051@D00c<c<0;Rh^04U9B@17AdL0>3Ph03Lg=`0k>c/0GEeM05]KF`0n?Sh00P0o?cl08`1G
EeL0<c<c02LW9`0f=SH0CDe=04m?C`1ADE40L71`07alO018B4P0E5AD061PH01fMWH0R8R807IfMP1@
D500;bl_028R8P0W9bL09BDU02HV9P0[:b/0:RXZ034a<@0g=cL0>SXj03hn?P19BDT0CTi>055AD@1H
F5P0EEEE05]KF`1OGel0HF5Q0080IVIV00D0JVYZ06][J`1YJFT0LG5a07IfMP0307AdM00807=cL`1i
NGT0OWin07QhN01iNGT0N7Qh07UiN@1eMGD207QhN00407MgM`1kNg/0NWYj0820P080PX:200`0Ogmo
0820P01lO7`0OGem07]kN`20P800Ogmo07alO021PH40OWin07moO`26QXH208B4Q00408:2PP23Ph<0
Ph>308>3P`80QhN70180PX:208F5Q@21PH40P82007emO@24Q8@0SHf=08R8R026QXH0R8R808Z:RP2;
Rh/0QhN708b<S026QXH0R8R808N7Q`28R8P208J6QP0508N7Q`2:RXX0SHf=08b<S02=SHd00P2:RXX0
1029RHT0Rh^;092@T02:RXX508f=S@0B096AT@2>SXh0Shn?09>CT`2ATI40T92@09:BTP2ATI40UYJF
09>CT`2DU9@0T92@09BDU02ATI40S8b<08f=S@2?Shl0UiNG0P2CTi<0202@T900Ti>C092@T02BTY80
T92@09>CT`2FUYH0VYZJ0P2EUID04`2CTi<0UIFE09VIV@2DU9@0TI6A09ZJVP2BTY80UIFE09JFUP2@
T900TI6A09BDU02BTY80U9BD09JFUP2GUiL0UIFE09JFUP2LW9`00P2KVi/02@2LW9`0VYZJ09bLW02M
WId0VYZJ09^KV`2JVYX0WYjN0:>SX`020::RXP070:JVYP2TY:@0YZJV0::RXP2TY:@0WinO0::RXP03
0:RXZ0030:b/[02a/K40/K6a0080[Jf]0P2b/[820;Vi^@0:0;^k^`2i^KT0^;Rh0;jn_P2m_Kd0`<30
0<71`@32`/80a<C40<?3``@0bLW900P0b/[:0<g=c@3=cLd0cLg=0<k>cP3Cdm<0d=3@0=7Ad@80dm?C
00X0d];B0=?Cd`3Bd]80dm?C0=CDe03Bd]80cLg=0:2PX01MGEd0ADE50P1?Cdl0801=CDd0D51@059B
DP1EEED0De=C05MGE`1IFET0GemO06=SH`1XJ6P0Hf=S06ATI01ZJVX0J6QX06][J`1aLG40Lg=c071`
L01cLg<0MgMg07YjNP1fMWH0NWYj07MgM`1kNg/0NWYj07emO@22PX80Ng]k07EeM@1jNWX0M7Ad0P1e
MGD01@1cLg<0LG5a07AdM01fMWH0MgMg0080N7Qh00d0Lg=c07MgM`1kNg/0P82007inOP21PH40OWin
08>3P`1iNGT0MGEe079bLP1ZJVX0J6QX0080GEeM00<0Fe]K05eMG@1GEeL00P1OGel0101SHf<0GEeM
05MGE`1IFET205MGE`0A04e=C@1?Cdl0EUIF04m?C`1DE5@0Fe]K05IFEP1?Cdl0EeMG055AD@1;Bd/0
De=C04Y:BP1;Bd/0Cdm?05UIF@1JFUX00P1OGel0601XJ6P0MGEe07EeM@1iNGT0P82008B4Q01mOGd0
PX:207moO`1lO7`0MGEe06m_K`1^KVh0JVYZ065QH@1NGUh0FEUI04m?C`1;Bd/0AdM70410@00m?Cd0
@D5103Lg=`80;2`/00<0;bl_03/k>`0g=cL00P0g=cL02`0j>SX0@d=30492@P0i>CT0@D5104];B`1>
CTh0HF5Q05YJFP1HF5P0GemO00h0b>3H000<0<SPf080;bl_01H0=cLg03De=@0b<S80=cLg03@d=00c
<c<0>CTi03dm?@0h>3P0=cLg03`l?017AdL0JVYZ0820P02NWYh0`l?30<C4a035aLD0alO70<[:bP3;
bl/0cLg=0P39bLT04031`L40`<300;Zj^P2e]KD0ZZZZ07moO`1WIfL0KVi^07IfMP1nOWh0QXJ6096A
T@2FUYH0WinO0::RXP2VYZH20:n_[`0H0;>c/`2a/K40[jn_0;6a/@2][Jd0/K6a0;Fe]@2a/K40/k>c
0;Fe]@2d];@0^;Rh0;Jf]P2d];@0[jn_0:BTY02XZ:P0T92@08B4Q026QXH0LG5a05iNGP0o?cl0?3`l
0P0e=CD202`/;00G03Lg=`0n?Sh0:2PX02LW9`0b<S80>3Ph03De=@0];Bd0;2`/04A4A00_;bl0<S8b
03lo?`12@T80?clo03De=@0m?Cd0>3Ph0492@P0h>3P0?Shn04i>CP12@T800P17AdL0801@D500<c<c
02l_;`0/;2`0@T9206][J`18B4P0>3Ph03@d=00^;Rh0<30`065QH@2ATI40J6QX04i>CP1<C4`0?3`l
02/[:`0b<S80<30`03Ph>00i>CT0Fe]K07EeM@1dM7@0Ng]k02l_;`0j>SX0EeMG04Y:BP1?Cdl0GEeM
0P2FUYH0:P2<S8`0L71`03lo?`0];Bd0;2`/03@d=00X:2P0;bl_05IFEP1WIfL0NWYj06MWI`0_;bl0
;Bd]03lo?`1?Cdl0>CTi02/[:`0b<S80CDe=05]KF`17AdL0ATI604m?C`1PH600EeMG02`/;00^;Rh0
B4Q804i>CP0l?3`0EeMG07MgM`1mOGd0EEEE06EUI@1^KVh0P82007QhN01BDU80<c<c02DU9@8092@T
00h08b<S02HV9P0Y:BT0;Bd]02h^;P0c<c<0?Shn0410@019BDT0CTi>055AD@1KFe/0GEeM05QHF080
Hf=S0P1ZJVX0201WIfL0IFEU06][J`1[Jf/0MgMg071`L01]KFd0LW9b0P1hN7P01`1eMGD0NGUi07Ad
M01iNGT0OGem07EeM@1gMgL00P1jNWX00`1kNg/0O7al0861P@0208:2PP0@0861P@1nOWh0Ogmo07in
OP1mOGd0PH6107emO@1nOWh0O7al07moO`20P800PX:208B4Q027QhL0PH6108F5Q@80P8200P26QXH0
4`24Q8@0QHF50820P023Ph<0PX:20861P@24Q8@0PX:208J6QP29RHT0QXJ608B4Q028R8P0RXZ:08J6
QP2:RXX0QHF508J6QP24Q8@00P26QXH0102;Rh/0SXj>08n?S`2=SHd408Z:RP0508j>SP2?Shl0S8b<
08V9R@2;Rh/00P2>SXh01`2ATI40SXj>08f=S@2DU9@0T92@096AT@2?Shl00P2ATI402`2DU9@0TI6A
08j>SP2CTi<0T92@09>CT`2BTY80T92@09>CT`2FUYH0UIFE00<0TY:B00@0TI6A09:BTP2HV9P0UYJF
0`2GUiL0202?Shl0UYJF09JFUP2FUYH0UiNG096AT@2EUID0U9BD0P2EUID0102ATI40T92@096AT@2A
TI4309JFUP0309BDU02IVIT0Vi^K0080Vi^K0P2JVYX02P2IVIT0U9BD09VIV@2MWId0X:2P0:>SX`2R
XZ80X:2P0:JVYP2WYjL20:JVYP030:NWY`2VYZH0YJFU0080YjNW00@0[:b/0:^[Z`2b/[80/;2`0P2^
[Zh20;:b/P80^;Rh00`0^k^k0;Zj^P2j^[X0^k^k0;jn_P2o_kl0`L710<?3``35aLD0a/K60<W9b@34
a<@20<W9b@050<g=c@3?cll0clo?0<k>cP3?cll00P3AdM400`3Bd]80dM7A0=;BdP020=;BdP080=CD
e03Bd]80e=CD0=?Cd`36a/H0Rh^;04a<C01?Cdl2055AD@0=04E5A@1FEUH0EUIF05UIF@1FEUH0FUYJ
06][J`1UIFD0IfMW06IVIP1RHV80I6AT06YZJP0206QXJ006075aL@1fMWH0M7Ad07MgM`1iNGT0N7Qh
0P1eMGD05`1dM7@0N7Qh07moO`1fMWH0Ng]k07QhN01nOWh0N7Qh07=cL`1gMgL0MGEe07AdM01cLg<0
K6a/075aL@1bLW80MGEe079bLP1`L700MGEe07QhN01iNGT0OWin0080Ogmo00L0PX:207MgM`1fMWH0
L71`06][J`1YJFT0HF5Q0080GEeM01L0GemO05iNGP1NGUh0Hf=S06MWI`1XJ6P0HV9R05YJFP1LG5`0
EEEE05=CD`1HF5P0De=C05YJFP1FEUH0EeMG04m?C`1HF5P0EEEE04U9B@1?Cdl0CTi>04E5A@0204e=
C@0>04i>CP1@D500FEUI05UIF@1RHV80J6QX06m_K`1eMGD0NGUi07alO020P800Ogmo07UiN@1mOGd2
07IfMP0@06UYJ@1[Jf/0JFUY06=SH`1GEeL0F5QH055AD@1CDe<0@41003dm?@0i>CT0=3@d038b<P0_
;bl0;2`/02l_;`80<c<c00P0=3@d03Ph>00c<c<0ADE503Xj>P0m?Cd0ATI604e=C@80DU9B00<0Fe]K
05iNGP38h=P03@38h=P000`0b>3H0P0`<3007`0e=CD0<C4a03De=@0i>CT0<c<c03De=@0l?3`0@d=3
03Ti>@0k>c/0>SXj04Y:BP1XJ6P0PX:209^KV`30`<00`l?30<G5a@37alL0bl_;0<c<c03:b/X0bl_;
0<S8b037alL0`l?30;^k^`2b/[80YJFU07]kN`1VIVH00P1cLg<01`1oOgl0PX:2096AT@2GUiL0WIfM
0:BTY02XZ:P00P2/[:`01P2a/K40[jn_0;2`/02c/k<0/;2`0;Jf]P80/k>c0140/[:b0;Rh^02f][H0
][Jf0;>c/`2b/[80/k>c0:ZZZP2YZJT0U9BD07]kN`25QHD0MgMg05IFEP17AdL0>CTi03Lg=`0202l_
;`0302h^;P0i>CT0@D510080<S8b03D0>3Ph03lo?`0a<C40;bl_02h^;P10@400<C4a059BDP12@T80
>SXj03`l?00g=cL0>CTi03Ph>00g=cL0=3@d0410@00o?cl0?3`l0410@00o?cl0@d=302PX:00`<300
<C4a05ADE01aLG40?3`l02PX:00c<c<0:BTY02/[:`1EEED0S8b<08:2PP1@D500?clo03<c<`0/;2`0
<30`02XZ:P0a<C40;Bd]05ADE01fMWH0Kfm_07inOP0g=cL0@D5105MGE`1;Bd/0J6QX08J6QP0209>C
T`0@08F5Q@1DE5@0;bl_02TY:@0V9RH0:BTY02XZ:P0c<c<0DU9B06ATI01fMWH0C4a<02/[:`0k>c/0
CDe=03hn?P80:2PX02H0>c/k055AD@1GEeL0@T9204Q8B01^KVh0L71`03Xj>P0S8b<0<c<c05mOG`19
BDT0AdM705QHF01iNGT0JVYZ03hn?P1PH600Lg=c071`L01SHf<0:b/[02<S8`0V9RH0820P01hN7P0S
8b<092@T02TY:@0[:b/0;2`/03<c<`0d=3@0?3`l04A4A018B4P0Cdm?04i>CP80EEEE00H0GemO06IV
IP1ZJVX0Kfm_06QXJ01/K6`206m_K`0<075aL@1]KFd0KFe]079bLP1fMWH0N7Qh07UiN@1kNg/0M7Ad
07IfMP1gMgL0LW9b0`1jNWX00`1oOgl0OWin08:2PP0208:2PP0507moO`1lO7`0O7al07emO@1nOWh0
0P1lO7`0;`1mOGd0OWin07moO`1nOWh0PH610820P025QHD0Q8B40820P021PH40Rh^;08J6QP25QHD0
Ph>308F5Q@20P800Q8B408J6QP21PH40Ph>308B4Q026QXH0QhN708F5Q@24Q8@0Ph>308V9R@2;Rh/0
QhN708Z:RP2=SHd0QhN708R8R027QhL0RXZ:08R8R02CTi<0SHf=08j>SP2:RXX0Shn?08Z:RP2;Rh/0
T92@08^;R`2<S8`0RXZ:0080SHf=0140RXZ:08n?S`2ATI40TI6A08f=S@2@T900Shn?08j>SP2BTY80
UIFE08n?S`2>SXh0SHf=09:BTP2IVIT0U9BD096AT@0209:BTP0509>CT`2BTY80UIFE08n?S`2CTi<0
0`2EUID01P2DU9@0TY:B09:BTP2DU9@0SXj>09RHV080UIFE00L0TI6A09>CT`2ATI40TI6A09:BTP2C
Ti<0UYJF0080TI6A00@0V9RH09FEU@2FUYH0UYJF0P2IVIT01`2KVi/0VYZJ09JFUP2DU9@0VIVI09JF
UP2IVIT00`2NWYh00`2RXZ80Xj>S0:FUY@020:JVYP030:BTY02ZZZX0Z:RX0080YZJV00L0ZJVY0:j^
[P2_[jl0/[:b0;6a/@2`/;00/k>c0080/[:b0P2g]kL0302j^[X0_;bl0;no_`2k^k/0_Kfm0<71`@30
`<00aLG50<?3``34a<@0clo?0<[:bP<0c<c<00@0cLg=0<k>cP3=cLd0c/k>0P3AdM401@3Bd]80dm?C
0=?Cd`3Cdm<0dM7A00<0eMGE00D0d];B0;jn_P1oOgl0@d=304Q8B00204Y:BP0D051@D01ADE40FEUI
05aLG01/K6`0Jf][06MWI`1VIVH0HV9R06][J`1XJ6P0H61P06ATI01^KVh0LG5a06YZJP1fMWH0NWYj
079bLP1gMgL207YjNP0707QhN01fMWH0MgMg07QhN01eMGD0Ng]k07MgM`0207AdM080Lg=c00L0LG5a
07EeM@1]KFd0LG5a06i^KP1[Jf/0L71`00@0LW9b01@0MWIf07EeM@1jNWX0Ng]k07alO01jNWX0MgMg
07=cL`1]KFd0JFUY06EUI@1OGel0GEeM05YJFP1OGel0HF5Q061PH01XJ6P0IfMW06=SH`80HF5Q00P0
De=C05]KF`1LG5`0E5AD04m?C`1CDe<0E5AD05IFEP80Bd];00P0Cdm?055AD@1LG5`0BTY:04Q8B017
AdL0De=C05IFEP80E5AD00L0FEUI06EUI@1/K6`0Kfm_07QhN01kNg/0O7al0080OGem00L0PX:207em
O@1gMgL0M7Ad06IVIP1[Jf/0KFe]0080GUiN01<0EUIF05=CD`1;Bd/0AdM703Xj>P0n?Sh0=3@d03Ph
>00d=3@0<C4a03@d=00h>3P0>SXj03Ti>@0k>c/0Bd];03Lg=`0c<c<0?3`l0080ATI600<0AdM704i>
CP1FEUH03P38h=P000`0b>3H0P0a<C404`0f=SH0=cLg03Ph>00a<C40<30`03@d=00g=cL0?3`l03/k
>`0n?Sh0?Cdm04Q8B01YJFT0O7al096AT@2g]kL0a<C40<K6aP39bLT00P3<c<`04`3;bl/0b/[:0<S8
b038b<P0`l?30;Ng]`2[Zj/0VIVI07=cL`1YJFT0M7Ad071`L01lO7`0QHF508b<S02HV9P0X:2P0:BT
Y02YZJT00P2^[Zh02`2a/K40/[:b0:j^[P2_[jl0/;2`0;Jf]P2d];@0/k>c0;Bd]02b/[80]kNg0080
];Bd0240[Zj^0;6a/@2^[Zh0YjNW09JFUP21PH40M7Ad06e]K@1>CTh0ADE503hn?P0e=CD0<S8b02PX
:00b<S80?Cdm04i>CP0j>SX0:BTY03/k>`0`<300<c<c02PX:00a<C40=3@d02XZ:P10@400@d=303Hf
=P0d=3@0=SHf03/k>`0d=3@00`0o?cl09013@d<0>c/k0492@P1>CTh0>CTi02TY:@0c<c<0=3@d05YJ
FP1OGel09BDU02LW9`0_;bl0;Bd]02h^;P1CDe<0Ph>308Z:RP1FEUH0ATI6034a<@0[:b/0<C4a03@d
=00_;bl0:BTY04M7A`1cLg<0Jf][08:2PP10@400@T9204U9B@1CDe<0QHF5096AT@80RHV90240MGEe
04i>CP0/;2`0:b/[02PX:00W9bL0;2`/03hn?P1RHV80KVi^06IVIP0^;Rh0?3`l04a<C00i>CT09RHV
02PX:00[:b/0CDe=04m?C`15ADD0B4Q806a/K01oOgl0EUIF02XZ:P0Y:BT0?3`l05UIF@0k>c/0EUIF
069RHP1cLg<00P1BDU806@1OGel0G5aL04Y:BP1GEeL0<S8b02/[:`0b<S808B4Q02@T900W9bL09RHV
02XZ:P0W9bL0<30`03De=@0a<C40>SXj03dm?@16ATH0AdM704i>CP1HF5P0EEEE05]KF`1JFUX00P1V
IVH306a/K00:06e]K@1^KVh0LW9b071`L01cLg<0MGEe07UiN@1hN7P0O7al07EeM@80N7Qh00L0LW9b
07IfMP1lO7`0NGUi07moO`1kNg/0P82000<0OWin0P1kNg/00`1iNGT0PH6107moO`0207alO080OGem
00d0P82008F5Q@24Q8@0Ph>308:2PP24Q8@0PX:208Z:RP25QHD0P82007moO`25QHD0PH6100<0Q8B4
00T0PH6108N7Q`26QXH0R8R808>3P`24Q8@0R8R808^;R`29RHT00P2:RXX02@28R8P0RHV908Z:RP25
QHD0RXZ:08J6QP2?Shl0RXZ:08R8R00208b<S00<08^;R`2<S8`0SHf=092@T02<S8`0TY:B08n?S`2;
Rh/0S8b<08^;R`2=SHd0TY:B0P2@T9000`2ATI40S8b<08n?S`0209:BTP0A08b<S02BTY80TY:B09>C
T`2DU9@0UYJF09>CT`2DU9@0Shn?096AT@2DU9@0UiNG09FEU@2@T900Ti>C09FEU@2FUYH00P2EUID0
1`2?Shl0SHf=09FEU@2EUID0V9RH09:BTP2IVIT00`2EUID01`2ATI40Ti>C09>CT`2CTi<0V9RH09JF
UP2EUID00P2GUiL209ZJVP0809VIV@2KVi/0V9RH09RHV02FUYH0VYZJ09bLW02MWId209nOW`0:0:BT
Y02RXZ80YZJV0:BTY02ZZZX0ZJVY0:ZZZP2[Zj/0YZJV0:ZZZP80[Jf]0100/[:b0;2`/02`/;00]kNg
0;6a/@2b/[80]kNg0;^k^`2h^;P0_;bl0;jn_P2j^[X0_kno0<?3``35aLD0alO70P35aLD0103:b/X0
bLW90<W9b@3<c<`30<k>cP050<g=c@3?cll0d];B0=3@d03AdM400P3Cdm<0103De=@0eMGE0=KFeP3E
eMD20=?Cd`040;2`/01VIVH0@41004U9B@80CTi>00H0De=C055AD@1JFUX0Hf=S065QH@1NGUh206AT
I00:06EUI@1XJ6P0JFUY06IVIP1/K6`0JVYZ06m_K`1`L700Lg=c07UiN@80MgMg00`0MWIf07alO01f
MWH0MgMg07]kN`1gMgL0MGEe07UiN@1gMgL0NGUi075aL@1bLW8207AdM009079bLP1dM7@0KFe]07=c
L`1YJFT0K6a/06m_K`1]KFd0KVi^0080Kfm_0P1hN7P0101jNWX0NGUi07QhN01dM7@2075aL@0406][
J`1YJFT0HV9R065QH@80H61P00P0GEeM061PH01PH600H61P06=SH`1RHV80I6AT05YJFP80H61P00P0
FUYJ051@D01@D500Cdm?055AD@19BDT0B4Q804Y:BP<0Bd];00@0EeMG04a<C016ATH0CDe=0P1@D500
0`1CDe<0FEUI06IVIP02075aL@0D07AdM01iNGT0OGem07]kN`1mOGd0Ng]k07IfMP1eMGD0K6a/06YZ
JP1^KVh0I6AT05UIF@1MGEd0EeMG04U9B@1>CTh0?3`l03lo?`0j>SX203Ti>@0?034a<@0c<c<0?Cdm
04=3@`0n?Sh0=CDe03Hf=P0`<300;Rh^034a<@0n?Sh0>c/k04A4A01;Bd/0G5aL00h0b>3H000<0<SP
f080<30`00P0>3Ph03lo?`0m?Cd0<c<c038b<P0g=cL0?3`l03lo?`80?Shn0P1:BTX01`1XJ6P0Ng]k
08n?S`2^[Zh0`<300<[:bP39bLT00P3<c<`04@3:b/X0b<S80<S8b037alL0`<300;Ng]`2/[:`0SHf=
071`L01VIVH0L71`07AdM020P800QHF508n?S`2JVYX0WinO0080YZJV0P2][Jd20;>c/`80];Bd01h0
/[:b0;Rh^02c/k<0];Bd0;Ng]`2h^;P0^KVi0;Rh^02i^KT0];Bd0:j^[P2YZJT0X:2P08V9R@1bLW80
J6QX05eMG@10@400?3`l03Ti>@0g=cL0=SHf02`/;00d=3@0>SXj03hn?P0a<C40:b/[03Hf=P0a<C42
02h^;P0602/[:`0`<300;Bd]03Lg=`0_;bl0=cLg0P0m?Cd03`0e=CD0>SXj03Ti>@0c<c<0=cLg03Ti
>@19BDT0@D5103hn?P0c<c<0=3@d03Xj>P16ATH0JFUY04e=C@0202HV9P0H02/[:`0];Bd0<S8b04M7
A`1cLg<0T92@06=SH`12@T80<C4a02TY:@0b<S80=3@d03De=@0Z:RX0?clo07EeM@1WIfL0OGem04];
B`0o?cl0@41006IVIP2>SXh0RXZ:0P25QHD0;`1]KFd0?Shn038b<P0[:b/092@T02DU9@0i>CT0DU9B
06UYJ@1fMWH0FEUI02d];@1=CDd0@T9202@T900Q8B4092@T030`<01FEUH0D51@0451@@1/K6`0QXJ6
06ATI00h>3P09BDU02TY:@0k>c/0EeMG04A4A01>CTh0JFUY07alO01_Kfl0HF5Q04i>CP0Z:RX0=CDe
05=CD`0b<S809BDU02h^;P0P8200:b/[02PX:00T92@0:BTY0080<C4a00P0<c<c03Lg=`0`<300=cLg
03Ti>@0n?Sh0Bd];04e=C@80EeMG00L0H61P05iNGP1VIVH0IfMW06IVIP1/K6`0L71`0080LW9b0P1e
MGD0101cLg<0MgMg07AdM01eMGD307AdM00707EeM@1iNGT0N7Qh07emO@1nOWh0N7Qh07emO@020861
P@0807inOP1mOGd0O7al07YjNP20P800O7al07moO`21PH4207alO00908:2PP1nOWh0Ph>307alO023
Ph<0P82008:2PP27QhL0R8R800<0PX:200<0Q8B408>3P`23Ph<00P23Ph<02@26QXH0QHF508Z:RP26
QXH0Q8B408N7Q`2=SHd0Rh^;08V9R@0208^;R`0308N7Q`2:RXX0R8R80080QhN700<0S8b<08Z:RP27
QhL00P2=SHd02029RHT0SHf=08Z:RP2>SXh0RXZ:08n?S`2:RXX0SHf=0P2<S8`01P2?Shl0TY:B09>C
T`2ATI40Rh^;08n?S`80Ti>C00h0UIFE09:BTP2DU9@0TY:B09>CT`2GUiL0Ti>C08n?S`2BTY80Shn?
09BDU02CTi<0VIVI09>CT`80TI6A00<0UIFE09BDU02DU9@00P2DU9@0502?Shl0Ti>C09NGU`2DU9@0
Ti>C09:BTP2>SXh0UYJF09>CT`2@T900TI6A09>CT`2FUYH0UIFE09>CT`2@T900U9BD09JFUP2EUID0
VIVI0P2GUiL01`2EUID0UYJF09ZJVP2IVIT0W9bL0:>SX`2LW9`00P2OWil01`2SXj<0YJFU0:BTY02T
Y:@0YJFU0:RXZ02^[Zh00P2YZJT05`2[Zj/0/;2`0;>c/`2b/[80];Bd0;Jf]P2a/K40/[:b0;Ng]`2i
^KT0_;bl0;Vi^@2j^[X0^k^k0;no_`34a<@0aLG50<W9b@38b<P0aLG50<W9b@3<c<`0bLW90080c<c<
00D0cLg=0<o?c`3?cll0clo?0=;BdP020=7Ad@0:0=3@d03De=@0dM7A0=OGe`3Fe]H0eMGE0=?Cd`3:
b/X0XJ6Q05ADE080CDe=0`1@D500601EEED0F5QH05IFEP1LG5`0Fe]K05IFEP1GEeL0FUYJ06MWI`1`
L700KFe]06][J`1VIVH0K6a/06UYJ@1cLg<0MgMg07QhN01jNWX0Ng]k07MgM`1kNg/0NWYj07MgM`80
M7Ad00D0N7Qh07EeM@1fMWH0L71`07AdM00307=cL`0307AdM01/K6`0Lg=c0080Jf][00@0K6a/06YZ
JP1[Jf/0J6QX0P1^KVh00`1aLG40MGEe07=cL`0207EeM@0<075aL@1`L700JVYZ06YZJP1RHV80GEeM
05iNGP1HF5P0EUIF05QHF01MGEd0HV9R0P1PH6002`1SHf<0IVIV06ATI01UIFD0EeMG05EEE@1CDe<0
D51@04E5A@14A4@0BTY:0080@d=300H0D51@0492@P11@D40B4Q804];B`16ATH204M7A`09055AD@1O
Gel0FEUI06MWI`1ZJVX0KFe]07EeM@1jNWX0Ng]k0080NWYj01l0MWIf07QhN01_Kfl0K6a/06e]K@1Y
JFT0GUiN05]KF`1LG5`0CTi>04m?C`16ATH0BDU903Xj>P10@400=3@d03/k>`0h>3P0?clo03Xj>P0i
>CT0=cLg03<c<`0e=CD0>c/k03Ti>@0j>SX0=cLg03/k>`16ATH0DU9B00h0b>3H000<0<SPf080<S8b
02P0=3@d03Ph>00f=SH0=CDe038b<P0g=cL0ADE503lo?`12@T80@d=30410@018B4P0H61P07UiN@2=
SHd0Zj^[0;^k^`36a/H0b<S80<k>cP3;bl/0b/[:0<S8b036a/H0alO70;bl_02`/;00W9bL0861P@1Y
JFT0I6AT07]kN`1bLW80Ng]k08J6QP2ATI40Vi^K09nOW`2VYZH0ZZZZ0P2`/;002`2b/[80/K6a0;:b
/P2c/k<0];Bd0;Rh^02b/[80]KFe0;Jf]P2j^[X0^;Rh0080^KVi00X0][Jf0;2`/02UYJD0V9RH07Mg
M`1XJ6P0DU9B04Y:BP0j>SX0=SHf0P0o?cl0500h>3P0<C4a03<c<`0b<S80<30`02PX:00/;2`0>SXj
03De=@0];Bd0:2PX03Lg=`0^;Rh0;Bd]03@d=00c<c<0>3Ph04E5A@11@D40>SXj0P0c<c<0600g=cL0
?Cdm03hn?P0k>c/0?clo03hn?P0`<300:b/[0451@@1FEUH0JFUY03Ti>@0Z:RX0:BTY02/[:`0Y:BT0
;2`/03hn?P1[Jf/0RHV906m_K`13@d<0<S8b02<S8`80;bl_00`0<C4a03@d=016ATH0MGEe06a/K01i
NGT0@d=3038b<P10@400MgMg08f=S@25QHD207emO@1505ADE00o?cl0=cLg02XZ:P0];Bd0B4Q805EE
E@1VIVH0IFEU08>3P`1@D500BDU904m?C`0`<300820P024Q8@0S8b<0?3`l05IFEP11@D40DE5A09:B
TP1jNWX0Bd];034a<@0S8b<0;2`/03dm?@19BDT0DE5A05eMG@1dM7@0OWin06UYJ@10@400;2`/02TY
:@0h>3P0ADE502l_;`0Z:RX09bLW02PX:00^;Rh0>3Ph030`<00i>CT0>3Ph02l_;`0a<C40<c<c038b
<P0f=SH0<C4a038b<P0l?3`0BTY:04e=C@1DE5@0G5aL05iNGP1WIfL0HV9R06UYJ@1ZJVX0Lg=c071`
L01dM7@0LW9b0080M7Ad00H0Ng]k07=cL`1cLg<0Lg=c07EeM@1dM7@307MgM`0407alO01mOGd0O7al
07inOP80O7al00d0OGem07moO`1mOGd0P82008>3P`22PX80PH6107moO`1mOGd0Ng]k0820P022PX80
Ogmo0080P82000D0PX:208B4Q026QXH0PX:208N7Q`0208:2PP0608J6QP24Q8@0Q8B408:2PP25QHD0
QhN70P25QHD01P28R8P0QXJ608N7Q`26QXH0QhN708R8R080QhN700/0RHV908b<S02>SXh0QhN708V9
R@2:RXX0R8R808^;R`2:RXX0SXj>08n?S`0208b<S00G08f=S@2<S8`0SHf=08Z:RP2<S8`0SHf=08n?
S`2ATI40TY:B08j>SP2DU9@0T92@09:BTP2;Rh/0Ti>C09FEU@2DU9@0TI6A09BDU02EUID0TY:B09BD
U02=SHd00`2CTi<01`2@T900UIFE09:BTP2BTY80TI6A09FEU@2CTi<00P2DU9@01`2@T900Shn?08n?
S`2CTi<0TY:B08n?S`2@T9000P2EUID01P2CTi<0SHf=09>CT`2ATI40UIFE09>CT`<0UIFE00<0Ti>C
09JFUP2CTi<00`2GUiL00`2HV9P0Vi^K09RHV00209fMW@0D0:2PX02OWil0Xj>S0::RXP2SXj<0Y:BT
0:VYZ@2WYjL0[:b/0:RXZ02][Jd0ZJVY0:f][@2`/;00/K6a0;2`/02d];@0/[:b0;>c/`2d];@20;Ng
]`080;Zj^P2k^k/0^k^k0;jn_P30`<00`L710<?3``37alL30<W9b@<0c<c<00T0c/k>0<o?c`3>c/h0
d=3@0=7Ad@3Bd]80d=3@0=7Ad@3?cll00P3=cLd02@3GemL0f=SH0=GEe@3Cdm<0aLG508R8R01;Bd/0
@D51055AD@0205EEE@05055AD@1IFET0E5AD059BDP1QHF400P1XJ6P06P1VIVH0KFe]06][J`1ZJVX0
LG5a06QXJ01[Jf/0K6a/075aL@1cLg<0L71`07AdM01iNGT0MWIf07MgM`1jNWX0NGUi07]kN`1bLW80
Lg=c07AdM01cLg<0LW9b075aL@1bLW80Lg=c0P1eMGD206m_K`03075aL@1bLW80Jf][0080JFUY01@0
Jf][06MWI`1TI6@0IfMW06YZJP1_Kfl0LW9b07QhN01eMGD0N7Qh06m_K`1ZJVX0IVIV065QH@1RHV80
F5QH05IFEP1EEED0De=C05]KF`<0HV9R00H0GemO06EUI@1RHV80HV9R05IFEP1IFET2051@D00504=3
@`11@D40B4Q804E5A@1:BTX00P17AdL01019BDT0AdM704A4A01QHF4204E5A@0804];B`1FEUH0DU9B
065QH@1VIVH0KVi^07=cL`1gMgL207YjNP0P07]kN`1lO7`0MWIf07=cL`1_Kfl0KVi^06e]K@1TI6@0
HF5Q05]KF`1IFET0De=C04];B`11@D40@T9203hn?P0l?3`0=SHf03Ti>@0j>SX0<c<c03Xj>P0n?Sh0
<C4a03@d=00f=SH0<c<c03Ph>00c<c<0>3Ph0451@@10@40>0<SPf0003038h=P203@d=00C03Ph>00k
>c/0>SXj03Xj>P0d=3@0?Cdm0492@P0l?3`0?Cdm04M7A`14A4@0B4Q806IVIP1eMGD0SHf=0::RXP2b
/[80`/;20<?3``020<S8b00C0<W9b@34a<@0aLG50<;2`P2h^;P0Xj>S092@T01mOGd0JFUY06QXJ01`
L700MGEe0820P027QhL0TI6A09ZJVP2OWil0YJFU0:VYZ@020;:b/P060;2`/02b/[80/[:b0;Fe]@2`
/;00][Jf0P2e]KD04`2k^k/0]kNg0;Zj^P2l_;`0^KVi0;Bd]02a/K40Zj^[09jNWP1oOgl0Fe]K04A4
A00o?cl0<C4a03Hf=P0j>SX0?Shn03Lg=`0];Bd00P0k>c/01@0a<C40;Rh^03Lg=`0n?Sh0>c/k0080
;Bd]00X0<30`02d];@0`<300>SXj03<c<`0f=SH0@41004=3@`0e=CD0=cLg0P0i>CT08`0c<c<0>3Ph
03hn?P13@d<0?Cdm038b<P0`<300CDe=06EUI@1EEED0<S8b02PX:00];Bd0<C4a03Lg=`0Y:BT0?clo
05MGE`1nOWh0Kfm_03/k>`14A4@09RHV03@d=00a<C40;Rh^02TY:@0j>SX0J6QX06UYJ@1hN7P0@d=3
02l_;`1DE5@0RXZ:0080Ph>30P1VIVH0:P0k>c/0>3Ph03<c<`0X:2P09bLW055AD@1bLW80IFEU07Qh
N01gMgL0B4Q804e=C@0m?Cd08R8R02DU9@0S8b<0;bl_04A4A01CDe<0BTY:07moO`26QXH0EeMG02XZ
:P0T92@0:BTY03Hf=P1FEUH0De=C05iNGP1[Jf/0NGUi06][J`11@D40<C4a02d];@0W9bL0?Cdm03@d
=00Y:BT0;Rh^03@d=080:2PX0180<c<c02HV9P0e=CD0=3@d02XZ:P0];Bd0;bl_038b<P0c<c<0<S8b
02l_;`0i>CT0?Cdm04i>CP1ADE40E5AD05]KF`1MGEd206ATI00<06IVIP1^KVh0KFe]06e]K@1aLG40
M7Ad07=cL`1gMgL0Lg=c079bLP1cLg<0M7Ad0P1fMWH00`1hN7P0NWYj07emO@0207inOP0807emO@1l
O7`0O7al07emO@1lO7`0NWYj08>3P`1nOWh20820P00908J6QP20P800O7al08>3P`26QXH0P8200861
P@22PX80P8200080Ph>30P20P8006021PH40PX:208R8R028R8P0PH6108F5Q@28R8P0Rh^;08Z:RP24
Q8@0QXJ608R8R02:RXX0Ph>308N7Q`2>SXh0Rh^;08R8R02:RXX0R8R808V9R@2<S8`0Rh^;08f=S@80
RXZ:00L0QXJ608R8R02?Shl0T92@08b<S02>SXh0Shn?0080T92@00h0TI6A08f=S@2>SXh0SXj>09FE
U@2BTY80TI6A08j>SP2BTY80SXj>09:BTP2ATI40Shn?08f=S@80U9BD00`0UIFE09>CT`2ATI40T92@
09>CT`2@T900TY:B09BDU02CTi<0TY:B092@T02BTY8309>CT`05092@T02?Shl0SXj>092@T02ATI40
0P2?Shl01@2ATI40V9RH092@T02ATI40TY:B00D0Ti>C00D0U9BD09RHV02EUID0UIFE09NGU`0209JF
UP0309FEU@2KVi/0VIVI0080WinO00H0W9bL0::RXP2SXj<0XZ:R0:BTY02UYJD40:NWY`0D0:^[Z`2Y
ZJT0/;2`0;2`/02a/K40][Jf0;Bd]02e]KD0]kNg0;>c/`2j^[X0^k^k0;Zj^P2l_;`0^KVi0;jn_P31
`L40`l?30<S8b036a/H20<S8b0040<W9b@3:b/X0bLW90<o?c`80c/k>00P0d];B0=3@d03AdM40d];B
0=7Ad@3Cdm<0d=3@0=?Cd`80e]KF00P0dm?C0=CDe03@d=00_Kfm07QhN016ATH0@d=304e=C@80EUIF
00P0DE5A05EEE@1RHV80GEeM05iNGP1VIVH0JFUY06][J`80JVYZ00<0JFUY06i^KP1`L7000`1^KVh2
079bLP0:07inOP1fMWH0NWYj07QhN01gMgL0M7Ad07UiN@1hN7P0M7Ad071`L0<0MGEe00<0L71`07If
MP1aLG400P1aLG401`1`L700K6a/06m_K`1[Jf/0JFUY06QXJ01TI6@00P1RHV800`1SHf<0I6AT06e]
K@02071`L00R075aL@1bLW80JVYZ06][J`1TI6@0GUiN05]KF`1JFUX0FEUI05ADE01FEUH0DE5A05aL
G01KFe/0FUYJ069RHP1VIVH0HV9R06=SH`1MGEd0G5aL05MGE`1EEED0CDe=04a<C014A4@0@T920410
@01:BTX0B4Q804a<C016ATH0@d=3055AD@80@T9201L0B4Q804m?C`1=CDd0EeMG06EUI@1ZJVX0L71`
075aL@1hN7P0LW9b07IfMP2UYJD0Lg=c07MgM`1eMGD0LG5a06UYJ@1RHV80Hf=S05IFEP1LG5`0EUIF
05=CD`0204I6AP0403hn?P0o?cl0?3`l03Hf=P80>c/k00@0>CTi0492@P0h>3P0=3@d0P0g=cL01@0h
>3P0<S8b03Lg=`0e=CD0<c<c00h0b>3H000<0<SPf080=CDe0P0j>SX04@14A4@0@D5103/k>`0l?3`0
@T9203hn?P15ADD0BDU904Y:BP1DE5@0IfMW07AdM02=SHd0WYjN0:ZZZP2h^;P0_Kfm0080`l?30P30
`<004@2l_;`0][Jf0:b/[02FUYH0QhN707EeM@1XJ6P0HV9R06YZJP1eMGD0OGem08J6QP2@T900VYZJ
09jNWP2UYJD0Zj^[0080[:b/02h0/[:b0;>c/`2c/k<0/[:b0;>c/`2k^k/0]KFe0;Bd]02h^;P0^KVi
0;Jf]P2i^KT0^[Zj0;>c/`2e]KD0/;2`0:JVYP2GUiL0MGEe04i>CP16ATH0>SXj02h^;P11@D40BDU9
0410@00m?Cd0=3@d03Hf=P0[:b/0<C4a030`<00f=SH0=3@d02`/;00d=3@0<C4a02l_;`0[:b/0?3`l
03Ph>00a<C40?3`l0492@P0h>3P0=cLg0P0e=CD07@0f=SH0=CDe0451@@15ADD0>c/k034a<@0f=SH0
Fe]K061PH00h>3P0;bl_02/[:`0_;bl0<30`02LW9`0Y:BT0@T9204U9B@1_Kfl0I6AT03<c<`0_;bl0
92@T02DU9@0Z:RX0:BTY02XZ:P0m?Cd0HF5Q0080L71`00H0@41003Hf=P1YJFT0RHV908:2PP1kNg/2
04m?C`0d034a<@0[:b/0:RXZ02l_;`0a<C40ADE506UYJ@1UIFD0QXJ607IfMP1BDU80B4Q802XZ:P0M
7Ad07QhN01lO7`0k>c/0EeMG05YJFP1QHF40PX:206IVIP0c<c<09BDU02/[:`0o?cl0BTY:06EUI@1Y
JFT0Lg=c075aL@1/K6`0EEEE04m?C`14A4@0@41003De=@19BDT0;Bd]02XZ:P0^;Rh0<30`02DU9@0]
;Bd0<30`02h^;P0[:b/0;Rh^038b<P0a<C40:b/[02l_;`80=SHf0100;bl_03@d=00f=SH0@D5104A4
A01;Bd/0De=C05YJFP1LG5`0GUiN06EUI@1PH600K6a/071`L01bLW80L71`0P1eMGD02@1dM7@0LW9b
07YjNP1dM7@0MWIf07QhN01gMgL0NWYj07]kN`0207alO00407emO@1kNg/0Ng]k0861P@80Ogmo01@0
O7al0820P01oOgl0PH6108F5Q@20P800Ogmo0820P022PX80Ogmo08:2PP1nOWh0PX:208>3P`22PX80
Ogmo08:2PP24Q8@0Ph>308j>SP80Q8B400d0QHF508:2PP2<S8`0RXZ:08J6QP27QhL0RXZ:08V9R@22
PX80Ph>308R8R02:RXX0QXJ60080RHV900H0QhN7092@T02;Rh/0RHV908f=S@26QXH208V9R@0408f=
S@2<S8`0Shn?09:BTP<0SHf=00d0Shn?08b<S02<S8`0S8b<092@T02?Shl0Ti>C08n?S`2BTY80U9BD
09>CT`2<S8`0Shn?0080SXj>00L0TY:B09BDU02CTi<0TI6A09>CT`2@T900SHf=0080U9BD00D0UYJF
09NGU`2>SXh0SXj>09BDU002092@T00609:BTP2<S8`0UIFE09>CT`2@T900SXj>0P2?Shl00`2@T900
TY:B09JFUP0209>CT`0609BDU02KVi/0U9BD09:BTP2CTi<0UYJF0P2IVIT01P2HV9P0UYJF09VIV@2J
VYX0W9bL09ZJVP80WIfM00/0WinO0:2PX02SXj<0Y:BT0::RXP2SXj<0YjNW0:FUY@2WYjL0ZJVY0:f]
[@020:VYZ@030;6a/@2d];@0/[:b0080/k>c00X0/[:b0;Fe]@2g]kL0_;bl0;Zj^P2k^k/0_;bl0;no
_`33`l<0a/K60P33`l<01@36a/H0b<S80<c<c03<c<`0cLg=0080clo?00<0d];B0=?Cd`3Bd]800P3B
d]800`3?cll0dM7A0=CDe0020=GEe@060=CDe03Cdm<0dm?C0<o?c`2_[jl0HF5Q0P14A4@03@19BDT0
DU9B059BDP1CDe<0F5QH05UIF@1NGUh0I6AT069RHP1TI6@0J6QX06UYJ@1ZJVX00P1/K6`2071`L080
LG5a00D0KVi^06m_K`1fMWH0M7Ad07YjNP0207MgM`0@075aL@1bLW80Ng]k07QhN01cLg<0MWIf06m_
K`1bLW80LG5a07QhN01]KFd0Kfm_071`L01]KFd0IfMW06][J`80J6QX00`0I6AT06UYJ@1UIFD0HF5Q
061PH01UIFD0Hf=S06][J`1XJ6P0Kfm_075aL@1]KFd206a/K080HF5Q01T0Fe]K05IFEP1DE5@0C4a<
04];B`1@D500DU9B05MGE`1NGUh0GemO05eMG@1TI6@0IFEU05iNGP1CDe<0Cdm?04e=C@1@D500B4Q8
04I6AP1:BTX0ATI604a<C018B4P0BTY:0080BDU90P18B4P03@11@D40BTY:04i>CP1BDU80FUYJ069R
HP1VIVH0KVi^07MgM`1dM7@0Lg=c07alO01dM7@00P1hN7P06`1aLG40Jf][06QXJ01YJFT0IFEU05eM
G@1JFUX0E5AD04Y:BP11@D40ADE503Ph>00l?3`0=SHf03`l?00k>c/0=SHf03Xj>P0f=SH0<30`03@d
=00e=CD0<30`02`/;00`<300;bl_03Lg=`0>0<SPf0003038h=P2038b<P0704=3@`0j>SX0?clo03lo
?`10@400?Cdm04E5A@0204e=C@0O055AD@1<C4`0Fe]K06i^KP1fMWH0S8b<09bLW02VYZH0[jn_0;>c
/`2j^[X0_kno0;bl_02j^[X0/k>c0:RXZ02OWil0Rh^;08N7Q`1kNg/0KFe]065QH@1/K6`0KVi^07mo
O`25QHD0Shn?09RHV02PX:00YJFU0:f][@020;2`/0040;6a/@2d];@0/k>c0;6a/@<0];Bd01D0/K6a
0;Rh^02i^KT0^k^k0;Zj^P2e]KD0/k>c0;6a/@2ZZZX0YZJV0::RXP2LW9`0MGEe05YJFP17AdL0>c/k
04E5A@18B4P0?3`l04Y:BP15ADD00P0a<C404`0/;2`09bLW03<c<`0f=SH0:RXZ02h^;P0f=SH0<30`
02`/;00f=SH0>CTi03De=@0j>SX0A4A403lo?`0i>CT0=3@d03Xj>P0k>c/00`0n?Sh01@0c<c<0=3@d
0410@01UIFD0DE5A0080<S8b01X0;Rh^02PX:00];Bd0:b/[02h^;P0o?cl0A4A406IVIP1RHV80>3Ph
02l_;`0X:2P0;Rh^02/[:`0W9bL0<S8b04A4A01TI6@0KVi^06YZJP0m?Cd0BTY:07MgM`22PX80O7al
06UYJ@80=SHf02H08R8R02PX:00W9bL09BDU038b<P1TI6@0KFe]06IVIP2BTY80Kfm_04A4A00];Bd0
92@T01hN7P0P8200:RXZ03hn?P1RHV80EUIF07AdM01gMgL0B4Q802<S8`0`<300@d=304M7A`1UIFD0
LW9b06][J`1gMgL0NGUi07=cL`1YJFT0EEEE04a<C014A4@0BDU904M7A`80:BTY02409RHV02LW9`0[
:b/09BDU03Lg=`0^;Rh0:RXZ02TY:@0X:2P0;Rh^034a<@0l?3`0;Bd]02h^;P0_;bl0=CDe03Ph>00j
>SX0>c/k04A4A01>CTh0Cdm?05IFEP1EEED0Fe]K06=SH`1RHV80K6a/075aL@1`L700LG5a071`L01a
LG400P1`L7002@1_Kfl0LG5a07IfMP1fMWH0NGUi07]kN`1lO7`0Ng]k0820P00207alO00308:2PP20
P800O7al00<0P8200P1nOWh00`23Ph<0PX:207emO@020861P@0;07inOP22PX80PX:207emO@21PH40
PX:20820P022PX80Q8B408V9R@28R8P00P26QXH03028R8P0QhN708^;R`2CTi<0R8R808V9R@2<S8`0
R8R808Z:RP28R8P0QhN708Z:RP80RHV900<0RXZ:08j>SP2=SHd00`2=SHd01P2>SXh0S8b<08b<S02@
T900SHf=08n?S`80SHf=0P2?Shl01@2ATI40SHf=08f=S@2BTY80UYJF0080TI6A00H0T92@09:BTP2B
TY80TI6A09JFUP2?Shl309>CT`0309FEU@2ATI40TY:B0080Shn?00L0UYJF09:BTP2JVYX0Ti>C08f=
S@2>SXh0TI6A0080SXj>0P2BTY802`2ATI40U9BD08j>SP2<S8`0SXj>09:BTP2@T900TY:B08j>SP2B
TY80UYJF0080T92@0P2BTY801`2DU9@0Ti>C09VIV@2FUYH0U9BD09NGU`2IVIT00P2JVYX00`2KVi/0
WIfM09ZJVP0209nOW`0:0:6QX@2TY:@0Y:BT0:NWY`2SXj<0YjNW0:VYZ@2UYJD0ZJVY0:ZZZP80[Jf]
00P0/K6a0;>c/`2a/K40/[:b0;6a/@2f][H0^[Zj0;^k^`80_;bl00<0_Kfm0<30`033`l<00P34a<@0
2P33`l<0a/K60<O7a`3;bl/0cLg=0<[:bP3@d=00clo?0=CDe03Cdm<20=7Ad@0?0=;BdP3AdM40d=3@
0=?Cd`3GemL0eMGE0=KFeP3Hf=P0dm?C0<c<c02MWId0EUIF04I6AP19BDT0DU9B0080De=C00@0FUYJ
05aLG01MGEd0GEeM0P1SHf<03P1TI6@0J6QX06QXJ01XJ6P0LW9b06i^KP1_Kfl0K6a/06][J`1^KVh0
M7Ad071`L01fMWH0LW9b0P1cLg<00`1fMWH0MGEe07UiN@0207YjNP0307QhN01dM7@0LG5a0080M7Ad
0P1aLG402P1fMWH0KFe]06][J`1ZJVX0IFEU06][J`1YJFT0IVIV06UYJ@1UIFD2069RHP05065QH@1N
GUh0IfMW06YZJP1]KFd00P1ZJVX02@1WIfL0Hf=S069RHP1NGUh0F5QH05MGE`1BDU80CDe=059BDP02
05ADE080EUIF00/0GUiN065QH@1SHf<0I6AT065QH@1GEeL0D51@05IFEP1@D500DU9B04a<C00204E5
A@0504];B`1<C4`0CTi>04A4A01ADE400P1;Bd/03019BDT0C4a<0451@@1?Cdl0De=C05QHF01RHV80
JVYZ075aL@1dM7@0LG5a07IfMP80NWYj01`0NGUi07EeM@1[Jf/0Jf][06m_K`1^KVh0HF5Q05iNGP1C
De<0CDe=04I6AP18B4P0?3`l03Xj>P0i>CT0?3`l03Lg=`11@D40>CTi03Hf=P0c<c<0=3@d030`<00h
>3P0<c<c03De=@0^;Rh0;Bd]3P38h=P000`0b>3H0P0j>SX0:00k>c/0>3Ph03/k>`0j>SX0?Cdm03lo
?`19BDT0CTi>059BDP1ADE40DU9B05MGE`1^KVh0MGEe08f=S@2JVYX0YJFU0:b/[02a/K40]KFe0;Bd
]02c/k<0[jn_0:VYZ@2QXJ40Ti>C08J6QP1lO7`0LW9b06IVIP1SHf<0KFe]06m_K`1lO7`0Q8B408j>
SP2IVIT0WYjN0:JVYP2XZ:P20:n_[`030;2`/02^[Zh0/k>c0080];Bd00L0/[:b0;Jf]P2e]KD0]kNg
0;Jf]P2j^[X0^;Rh0080];Bd02D0[Zj^0:^[Z`2WYjL0YJFU09fMW@26QXH0GUiN04A4A00l?3`0BDU9
04Q8B00h>3P0=SHf038b<P0h>3P0<30`03Xj>P0X:2P0;bl_03@d=00_;bl0<C4a03/k>`0S8b<0:2PX
02l_;`0c<c<0<C4a03Xj>P15ADD0>3Ph03Hf=P0k>c/0Bd];030`<00b<S80?3`l0080=SHf0200>SXj
051@D01SHf<0?Cdm02d];@0c<c<0;bl_02`/;00f=SH0<S8b03@d=00k>c/0BTY:065QH@1/K6`0@T92
02/[:`0a<C40;Rh^02PX:00Y:BT0;Rh^03hn?P1TI6@0LW9b05YJFP0l?3`0K6a/07inOP1kNg/0MgMg
04m?C`80;2`/02L09RHV02TY:@0P820092@T04E5A@1]KFd0JFUY06i^KP2<S8`0IFEU03/k>`0O7al0
8R8R01hN7P0W9bL0?Cdm04i>CP19BDT0EEEE07EeM@1PH600;Rh^03De=@16ATH0A4A404M7A`1`L700
J6QX071`L01iNGT0PX:206MWI`1<C4`0De=C06UYJ@1@D500GEeM04A4A00c<c<00`0V9RH09`0/;2`0
:2PX04i>CP0h>3P08b<S02LW9`0T92@09RHV02`/;00^;Rh0:RXZ02`/;00d=3@0=CDe03Hf=P0i>CT0
=3@d04=3@`16ATH0Cdm?05ADE01FEUH0Fe]K05UIF@1HF5P0IFEU06MWI`1]KFd0KVi^06a/K01]KFd0
Kfm_07MgM`1bLW80MGEe07IfMP1jNWX0O7al07QhN00207alO00?07emO@1jNWX0NWYj07]kN`1mOGd0
NWYj07moO`1lO7`0NWYj07]kN`23Ph<0Ogmo0861P@22PX80Q8B40080PX:20P1nOWh01`1oOgl0PH61
07moO`1lO7`0Ph>308:2PP26QXH00P23Ph<01P25QHD0QXJ608J6QP29RHT0S8b<08N7Q`80RHV90140
R8R808F5Q@27QhL0R8R808F5Q@27QhL0S8b<08R8R02BTY80Rh^;09>CT`2=SHd0S8b<08f=S@2;Rh/0
Shn?08f=S@0208n?S`0408b<S029RHT0SXj>08n?S`80SXj>00H0UIFE08n?S`2ATI40Ti>C08f=S@2B
TY82092@T00309>CT`2DU9@0SHf=0080TI6A0`2BTY801`2?Shl0TI6A08n?S`2ATI40UIFE09BDU02?
Shl00P2@T9003`2ATI40T92@092@T02@T900RHV9096AT@2?Shl0S8b<08f=S@2<S8`0TY:B09>CT`2A
TI40S8b<092@T00209:BTP0309>CT`2BTY80TY:B0080U9BD0200UYJF09:BTP2EUID0VIVI09bLW02J
VYX0W9bL09fMW@2KVi/0VIVI0::RXP2OWil0XZ:R0:>SX`2UYJD0Z:RX0:FUY@2TY:@0Z:RX0:VYZ@2^
[Zh0ZZZZ0:b/[02][Jd0/;2`0;Fe]@2b/[80];Bd0;Fe]@2g]kL0_Kfm0;^k^`<0_Kfm00L0`L710<C4
a033`l<0`/;20<C4a038b<P0b/[:0080cLg=01H0clo?0=3@d03AdM40eMGE0=?Cd`3De=@0dm?C0=CD
e03EeMD0dm?C0=;BdP3EeMD0emOG0=KFeP3EeMD0e]KF0<G5a@2;Rh/0De=C04Y:BP18B4P0CTi>0P1J
FUX0201HF5P0GEeM05]KF`1NGUh0I6AT069RHP1NGUh0IVIV0P1WIfL01P1^KVh0Kfm_06e]K@1cLg<0
L71`06][J`80KFe]01D0L71`06m_K`1`L700M7Ad075aL@1iNGT0MGEe07MgM`1fMWH0LW9b07=cL`1_
Kfl0LW9b07=cL`1/K6`0L71`07AdM01aLG40KVi^06][J`1WIfL00P1YJFT02@1WIfL0H61P05aLG01M
GEd0GUiN05]KF`1LG5`0HV9R06IVIP0206QXJ00406EUI@1TI6@0JFUY061PH080EeMG01X0GEeM05AD
E01?Cdl0BTY:05EEE@1DE5@0DE5A05ADE01GEeL0GUiN069RHP1]KFd0JVYZ06ATI01PH600GUiN05QH
F01ADE40EEEE04];B`1=CDd0Cdm?04Y:BP1CDe<0Bd];04i>CP80?Shn02X0BTY:04Q8B014A4@0A4A4
05=CD`1MGEd0Hf=S06MWI`1jNWX0M7Ad06m_K`1eMGD0Ng]k07MgM`1oOgl0MGEe06i^KP1[Jf/0K6a/
06UYJ@1UIFD0HF5Q05iNGP1DE5@0ATI604Q8B013@d<0?Shn03dm?@0n?Sh0?Cdm03/k>`0f=SH0?clo
03/k>`0e=CD0>3Ph038b<P0c<c<0>SXj03@d=00c<c<>0<SPf0003038h=P2038b<P0X03Xj>P0h>3P0
=SHf02l_;`11@D40@d=304i>CP1EEED0EeMG05QHF01CDe<0I6AT07EeM@1iNGT0QhN709ZJVP2UYJD0
Z:RX0:j^[P2`/;00/k>c0;6a/@2][Jd0YZJV09fMW@2BTY80QHF508:2PP1iNGT0I6AT06=SH`1[Jf/0
LW9b07YjNP24Q8@0SHf=09FEU@2MWId0Xj>S0:RXZ080[Jf]0P2^[Zh00`2e]KD0/k>c0;>c/`020;Fe
]@030;Bd]02f][H0/k>c0080^;Rh00d0]kNg0;:b/P2`/;00ZZZZ0:JVYP2TY:@0WinO09>CT`1ZJVX0
@41003hn?P1?Cdl0ATI60080<S8b0280>CTi030`<00_;bl0:RXZ02d];@0j>SX0>CTi03De=@0d=3@0
=cLg02XZ:P0[:b/0;bl_038b<P0h>3P0@D5104=3@`19BDT0BTY:03Ti>@0o?cl0<c<c03Ph>010@400
?Cdm02/[:`0o?cl0KFe]05aLG00f=SH09BDU03Ph>00^;Rh0:2PX0P0`<3005P0j>SX0@41005ADE01M
GEd0GemO05ADE00h>3P0;bl_02`/;00[:b/09bLW03De=@1:BTX0GUiN075aL@1KFe/0BTY:07emO@1l
O7`0N7Qh06UYJ@0c<c<202@T900U02l_;`0T92@0820P038b<P1IFET0Fe]K061PH01eMGD0P82004i>
CP0[:b/0820P02LW9`0k>c/0>CTi05UIF@1:BTX0>SXj07QhN01jNWX0>c/k034a<@1FEUH0C4a<03Xj
>P1TI6@0N7Qh069RHP1jNWX0OGem069RHP0h>3P0@41006m_K`1aLG40HF5Q05MGE`0203Hf=P0602h^
;P0];Bd0;Bd]02d];@0^;Rh0<C4a0P0Z:RX01P0X:2P09BDU024Q8@0Z:RX09RHV02<S8`80;2`/00T0
=CDe03Ti>@0i>CT0@41004I6AP19BDT0C4a<04e=C@1EEED00P1HF5P04P1GEeL0GUiN061PH01VIVH0
IFEU06=SH`1[Jf/0KVi^06m_K`1dM7@0Lg=c07QhN01dM7@0MWIf07QhN01fMWH0N7Qh07YjNP80N7Qh
00@0Ng]k07YjNP1lO7`0Ng]k0P1oOgl04`1nOWh0OGem0861P@1oOgl0Q8B408J6QP23Ph<0PH6107al
O01oOgl0PX:20861P@1oOgl0OGem0861P@23Ph<0OWin08B4Q029RHT00`27QhL01P29RHT0QXJ608F5
Q@28R8P0QhN708V9R@80QHF500d0QXJ608F5Q@28R8P0RXZ:08n?S`2@T900SHf=092@T029RHT0Shn?
08^;R`2<S8`0SHf=00<0T92@00d0Shn?08b<S02<S8`0S8b<08j>SP2<S8`0SHf=09BDU02BTY80TI6A
092@T02DU9@0Shn?0080TI6A00H0SXj>08V9R@2ATI40U9BD09>CT`2>SXh3092@T00508f=S@2BTY80
UYJF09:BTP2>SXh00P2<S8`01@2ATI40SXj>08j>SP2@T900Rh^;0080SXj>00P0SHf=08^;R`2=SHd0
Shn?09>CT`2=SHd0T92@08f=S@80T92@00X0U9BD09FEU@2ATI40T92@09JFUP2GUiL0TY:B09>CT`2J
VYX0VIVI0P2LW9`03P2MWId0Vi^K09VIV@2OWil0X:2P0:6QX@2RXZ80YJFU0:NWY`2XZ:P0Zj^[0:RX
Z02YZJT0/;2`0P2_[jl20;6a/@030;Jf]P2b/[80^KVi0080_;bl0P2n_[h00`2m_Kd0_[jn0;no_`02
0<C4a0060<O7a`38b<P0aLG50<S8b03<c<`0c/k>0P3=cLd00`3?cll0dM7A0=CDe0030=?Cd`0;0=;B
dP3De=@0e=CD0=OGe`3EeMD0f=SH0=GEe@3De=@0dm?C0;bl_01lO7`00P1>CTh02@1;Bd/0E5AD05MG
E`1GEeL0DU9B05ADE01LG5`0GEeM065QH@02069RHP0706IVIP1WIfL0KVi^06][J`1]KFd0J6QX07=c
L`0206i^KP0806m_K`1[Jf/0JFUY06m_K`1/K6`0Lg=c079bLP1dM7@207=cL`0=07AdM01aLG40M7Ad
06m_K`1bLW80Lg=c07AdM01gMgL0LG5a06e]K@1YJFT0KVi^06IVIP0206QXJ00806MWI`1RHV80H61P
061PH01KFe/0FUYJ05]KF`1IFET3065QH@0505mOG`1WIfL0HV9R05mOG`1KFe/00P1EEED01@1HF5P0
CTi>04i>CP1>CTh0DU9B0080DE5A00<0EUIF05UIF@1NGUh00P1WIfL02P1XJ6P0IfMW06=SH`1XJ6P0
E5AD04m?C`1KFe/0CTi>04m?C`1FEUH204];B`0504Y:BP10@400@41004=3@`11@D400P0m?Cd0301?
Cdl0E5AD05eMG@1WIfL0JFUY06a/K01]KFd0MGEe07MgM`1hN7P0NWYj07emO@80LG5a00D0Jf][06QX
J01YJFT0IFEU069RHP0205=CD`0504E5A@1;Bd/0AdM70492@P0l?3`00P0h>3P02P0m?Cd0?clo0492
@P0l?3`0>CTi03Hf=P0h>3P0=cLg03/k>`0`<30>0<SPf0003038h=P202l_;`0B03Ti>@0e=CD0=CDe
03Xj>P12@T80BDU9051@D01ADE40FEUI05IFEP1IFET0I6AT07AdM01mOGd0SHf=09^KV`2RXZ80YJFU
0P2^[Zh0502_[jl0[Jf]0:VYZ@2TY:@0VIVI08f=S@21PH40N7Qh06i^KP1QHF40H61P06UYJ@1fMWH0
O7al08J6QP2<S8`0UIFE09nOW`2WYjL0ZJVY0P2ZZZX0202`/;00/K6a0:n_[`2b/[80];Bd0;:b/P2f
][H0]KFe0P2d];@01`2e]KD0^;Rh0;Jf]P2c/k<0[Zj^0:NWY`2YZJT00P2RXZ804@2DU9@0KVi^03hn
?P0j>SX0AdM7059BDP0^;Rh0:b/[030`<00d=3@0:b/[03@d=00];Bd0>CTi04Y:BP17AdL0<C4a0080
;2`/00X0:BTY03Ph>00b<S80=SHf0410@015ADD0A4A403/k>`0h>3P0?Cdm0P0h>3P08`10@400?clo
038b<P1;Bd/0MgMg04m?C`0/;2`09bLW02l_;`0b<S80:RXZ03<c<`0a<C40?Cdm03hn?P16ATH0BTY:
05]KF`1NGUh0>SXj03@d=00W9bL0:b/[02`/;00f=SH0BTY:05UIF@1WIfL0HV9R06a/K01mOGd0KVi^
07UiN@1TI6@0<c<c00809bLW02l0;Rh^02DU9@0^;Rh0Cdm?061PH019BDT0JFUY08:2PP1^KVh0<C4a
02DU9@0M7Ad09bLW034a<@1BDU80EEEE0410@01KFe/0OGem05eMG@0_;bl0D51@04i>CP0a<C40AdM7
07UiN@1jNWX0GemO07]kN`1gMgL0?clo03Hf=P1PH600MWIf06YZJP1aLG40C4a<03<c<`0i>CT0<30`
02h^;P0];Bd0=SHf03Ti>@0k>c/0?Cdm0492@P0203Ti>@0302l_;`0W9bL0:BTY0080:2PX01L09RHV
02XZ:P0X:2P0:BTY034a<@0k>c/0?Cdm0451@@1:BTX0ADE504];B`1CDe<0CTi>05UIF@1EEED0EUIF
05YJFP1SHf<0H61P05iNGP1VIVH0Kfm_07=cL`02079bLP0507EeM@1hN7P0OGem07alO01jNWX00P1h
N7P0401iNGT0N7Qh07UiN@1lO7`0NGUi07inOP1lO7`0PH610820P022PX80OWin08:2PP25QHD0OWin
07alO022PX820820P00K08:2PP20P800OWin08:2PP21PH40RHV908R8R029RHT0PX:208B4Q026QXH0
QHF508V9R@2:RXX0RHV908b<S029RHT0PX:208N7Q`29RHT0QXJ608^;R`27QhL0Rh^;096AT@2BTY80
RXZ:00<0SXj>00h0S8b<08Z:RP2@T900S8b<092@T02?Shl0SHf=08^;R`2=SHd0UiNG092@T02BTY80
UIFE092@T080U9BD00X0TY:B09>CT`2?Shl0SXj>08^;R`2@T900Ti>C09JFUP2>SXh0Shn?0P2ATI40
1P2@T900TI6A09>CT`2?Shl0SHf=08V9R@80Shn?0P2ATI40102>SXh0Shn?08^;R`2<S8`208n?S`05
08b<S02>SXh0SXj>09:BTP2@T9000P2?Shl02@2@T900Shn?09:BTP2FUYH0V9RH09NGU`2FUYH0Ti>C
09FEU@0209ZJVP0309VIV@2LW9`0W9bL0080Vi^K01@0WIfM09nOW`2WYjL0YZJV0:6QX@2UYJD0ZJVY
0:BTY02ZZZX0[:b/0:j^[P2b/[80/;2`0;Bd]02g]kL0]KFe0;Vi^@2j^[X0^k^k0;Zj^P80_Kfm0140
_;bl0<71`@30`<00`l?30<C4a035aLD0bLW90<_;b`37alL0b/[:0<g=c@3@d=00c/k>0<o?c`3Cdm<0
emOG0=GEe@040=?Cd`0=0=CDe03GemL0e=CD0=SHf03EeMD0e=CD0<o?c`2][Jd0IfMW04Q8B01BDU80
Cdm?051@D00205=CD`0405eMG@1JFUX0G5aL06ATI080H61P01<0HF5Q06EUI@1UIFD0KVi^06e]K@1Z
JVX0LW9b071`L01]KFd0LG5a06a/K01UIFD0JVYZ06][J`1/K6`0Kfm_06YZJP1hN7P0LG5a00<0M7Ad
00H0N7Qh071`L01hN7P0LG5a071`L01bLW8206i^KP0306YZJP1aLG40L71`0080Kfm_00H0JVYZ06MW
I`1QHF40FUYJ05IFEP1HF5P205YJFP0S05mOG`1KFe/0EeMG05aLG01TI6@0HV9R05mOG`1EEED0Fe]K
05UIF@1HF5P0D51@04I6AP1:BTX0ATI604m?C`1=CDd0D51@05QHF01MGEd0GemO06QXJ01^KVh0KFe]
06=SH`1RHV80Fe]K05QHF01QHF40De=C051@D017AdL0Cdm?04U9B@1<C4`00P16ATH07P0l?3`0@d=3
0410@00j>SX0BDU9051@D01KFe/0I6AT06a/K01WIfL0Lg=c06m_K`1[Jf/0LW9b07IfMP1iNGT0Lg=c
06m_K`1^KVh0JFUY06i^KP1UIFD0H61P05aLG01DE5@0Cdm?04a<C01;Bd/0@D5103lo?`80?3`l00D0
>c/k03`l?00k>c/0?Cdm03lo?`0203Hf=P0303<c<`0o?cl0>3Ph00h0b>3H000<0<SPf080<c<c00T0
<S8b03/k>`0n?Sh0>SXj04A4A01DE5@0FEUI059BDP1IFET00P1JFUX01`1ZJVX0Lg=c07emO@2@T900
Vi^K0:FUY@2XZ:P00`2^[Zh20:b/[00A0:BTY02LW9`0Shn?0861P@1iNGT0MGEe05eMG@1SHf<0KFe]
079bLP1hN7P0QXJ608f=S@2IVIT0WYjN0:FUY@2_[jl00P2a/K402@2^[Zh0/;2`0;>c/`2e]KD0/[:b
0;Fe]@2b/[80/k>c0;Bd]0020;Ng]`80^[Zj00P0][Jf0:j^[P2WYjL0YZJV0:FUY@2RXZ80UIFE06m_
K`80?clo00`0CTi>04a<C00^;Rh08b<S02d];@0h>3P0:b/[02h^;P0W9bL0;Bd]038b<P0^;Rh203<c
<`0`02d];@0_;bl0<C4a02h^;P0j>SX0>CTi03dm?@0o?cl0?Shn03@d=00o?cl0;Rh^02l_;`14A4@0
=cLg038b<P1CDe<0JVYZ03lo?`0X:2P0;2`/03Ti>@0g=cL0;bl_03<c<`0e=CD0ADE504I6AP19BDT0
?3`l061PH01[Jf/0@T9203De=@0U9BD0;2`/030`<00c<c<0GEeM05mOG`1YJFT0Kfm_07AdM01]KFd0
I6AT06YZJP1=CDd0=SHf0P0];Bd0E00W9bL08R8R034a<@1KFe/0@D5105=CD`1`L700Ogmo04Y:BP0R
8R8092@T01hN7P0/;2`0?Cdm051@D00d=3@0C4a<079bLP1VIVH0>CTi0492@P1>CTh0=CDe03@d=01>
CTh0PH6107EeM@1ZJVX0PX:206ATI01:BTX0IFEU07emO@1^KVh0K6a/06MWI`0i>CT0:BTY03Xj>P0[
:b/0:RXZ02h^;P0d=3@0;Rh^034a<@0[:b/0:RXZ02d];@0/;2`0:BTY02XZ:P0T92@09RHV02/[:`0U
9BD0:2PX02@T900U9BD0;Rh^02l_;`0b<S80<C4a03/k>`0o?cl0?Cdm03lo?`17AdL0DE5A05=CD`1D
E5@0Fe]K05iNGP1HF5P0FEUI05iNGP1SHf<0JFUY06e]K@1/K6`0N7Qh07=cL`1eMGD0N7Qh07alO080
Ng]k00h0N7Qh07]kN`1jNWX0NWYj07UiN@1jNWX0OGem07moO`1nOWh0Ogmo0820P01lO7`0P8200861
P@80P82000L0PH6108>3P`25QHD0Ph>307moO`1nOWh0QHF50080Q8B400@0QHF50820P027QhL0QhN7
0P25QHD208V9R@0308^;R`2:RXX0QhN700@0QhN701H0Rh^;08R8R029RHT0Rh^;08b<S02@T900SHf=
08j>SP2BTY80SXj>096AT@2:RXX0SHf=09:BTP2CTi<0T92@096AT@2?Shl0TY:B09>CT`2DU9@0UIFE
0P2BTY80102FUYH0UIFE096AT@2<S8`208n?S`0>08j>SP2EUID0SHf=08n?S`2CTi<0T92@08b<S02?
Shl0TY:B096AT@2@T900Shn?08V9R@2=SHd208j>SP03096AT@2<S8`0T92@0080T92@00/0SXj>08b<
S02=SHd0Shn?096AT@2;Rh/0SXj>08f=S@2?Shl0Ti>C09BDU00209JFUP80UiNG00D0UIFE09RHV02G
UiL0VYZJ09fMW@0309nOW`050:2PX02NWYh0XZ:R0:FUY@2YZJT00P2TY:@20:JVYP030:^[Z`2][Jd0
/;2`0080/K6a00T0][Jf0;Rh^02e]KD0^;Rh0;^k^`2m_Kd0^k^k0;jn_P2m_Kd00P31`L401@35aLD0
`/;20<G5a@36a/H0bLW90080b/[:0`3=cLd01@3@d=00dM7A0=;BdP3De=@0eMGE0080e=CD00@0dm?C
0=GEe@3De=@0e=CD0P3Fe]H02@3Hf=P0e]KF0<c<c02MWId0FEUI04I6AP1GEeL0DU9B05MGE`0205IF
EP0A05iNGP1MGEd0FEUI06=SH`1RHV80HF5Q06MWI`1VIVH0JVYZ06][J`1^KVh0J6QX06e]K@1/K6`0
KVi^071`L01ZJVX00`1YJFT01`1VIVH0I6AT079bLP1_Kfl0L71`07AdM01hN7P00P1aLG400`1`L700
KVi^06e]K@02079bLP0I06m_K`1]KFd0L71`071`L01bLW80MWIf075aL@1_Kfl0JFUY06=SH`1NGUh0
FUYJ05ADE01EEED0F5QH05ADE01BDU80EEEE05ADE01EEED0GUiN05aLG01FEUH0EEEE051@D00205IF
EP0G051@D01>CTh0@d=304];B`16ATH0Cdm?05ADE01HF5P0GUiN06EUI@1TI6@0J6QX06a/K01cLg<0
Fe]K06IVIP1CDe<0DE5A04U9B@1>CTh0AdM704I6AP13@d<00P16ATH00`0n?Sh0@d=303dm?@020410
@00I04a<C01BDU80G5aL06YZJP1[Jf/0JVYZ06m_K`1]KFd0L71`079bLP1gMgL0Ng]k07AdM01gMgL0
LG5a06YZJP1]KFd0JFUY05eMG@1IFET0Cdm?04U9B@15ADD0ATI60492@P0203hn?P060410@00i>CT0
?Cdm0451@@0l?3`0=3@d0P0e=CD00`0b<S80;bl_0<SPf00=0<SPf0003038h=P202`/;00C03<c<`0e
=CD0?Cdm04=3@`1GEeL0DE5A05eMG@1KFe/0GemO05iNGP1PH600Kfm_07YjNP24Q8@0UIFE09jNWP2X
Z:P0ZJVY0;2`/0030:n_[`0B0:RXZ02VYZH0VYZJ08f=S@23Ph<0NGUi06UYJ@1JFUX0H61P06][J`1`
L700Ng]k08R8R02CTi<0Vi^K09nOW`2TY:@0Z:RX0P2][Jd01`2_[jl0[Zj^0;6a/@2c/k<0];Bd0;Fe
]@2g]kL00P2e]KD01P2i^KT0^k^k0;Ng]`2h^;P0];Bd0;2`/080ZZZZ00h0Xj>S09jNWP2>SXh0JVYZ
03dm?@10@400Cdm?04a<C00e=CD0:BTY02PX:00b<S80;Rh^030`<080;Bd]00L0<30`02LW9`0a<C40
;bl_03Lg=`0_;bl0>CTi0080;bl_01H0>3Ph0410@00k>c/0?3`l02h^;P0e=CD0>CTi03@d=00i>CT0
=SHf038b<P1BDU80JFUY038b<P0/;2`0;Bd]03Hf=P0d=3@0;Rh^034a<@0e=CD0;bl_0P0n?Sh04`0g
=cL0FUYJ071`L01;Bd/0=SHf02l_;`0X:2P0=CDe03Ph>01MGEd0HV9R06UYJ@1dM7@0MGEe06=SH`1/
K6`0IfMW04];B`0d=3@00P0];Bd06`0_;bl0:RXZ03De=@13@d<0;Rh^069RHP1`L700HF5Q030`<00U
9BD0;Bd]028R8P0X:2P0CDe=03De=@11@D40Q8B407UiN@11@D40C4a<04e=C@0j>SX0?Cdm04Q8B01E
EED0Ogmo06a/K00207YjNP0;06=SH`1lO7`0TI6A08R8R01_Kfl0HF5Q04a<C00e=CD0<c<c04Y:BP0Y
:BT00`0Z:RX02P0[:b/0:BTY02d];@0X:2P0:BTY02/[:`0a<C40;Bd]03<c<`0j>SX202TY:@0<02XZ
:P0a<C40:2PX02HV9P0U9BD09bLW02PX:00Z:RX0>CTi03@d=00g=cL0?clo0P1<C4`01@1>CTh0DU9B
05IFEP1FEUH0FEUI0080GEeM00H0I6AT06EUI@1SHf<0JFUY071`L01bLW8207IfMP80NGUi00h0MgMg
07UiN@1kNg/0Ng]k07QhN01lO7`0OGem0820P021PH40Ph>30820P021PH40OWin08:2PP80P82000@0
O7al08:2PP22PX80Q8B40P23Ph<02`25QHD0Q8B408J6QP24Q8@0Ogmo08N7Q`2;Rh/0RHV908F5Q@2>
SXh0R8R800<0Rh^;00H0R8R808Z:RP27QhL0QhN708F5Q@29RHT208f=S@0808^;R`2<S8`0SXj>08Z:
RP2;Rh/0Shn?08j>SP2?Shl208j>SP0309FEU@2CTi<0S8b<0080SXj>00T0Ti>C09:BTP2@T900TY:B
09>CT`2EUID0TI6A09BDU02CTi<00P2@T9001`2ATI40Shn?08n?S`2>SXh0Shn?092@T02=SHd00P2?
Shl01@2=SHd0S8b<08Z:RP29RHT0T92@0080RXZ:02<0Shn?09:BTP2>SXh0SXj>08n?S`2<S8`0Shn?
096AT@2>SXh0TI6A08b<S02?Shl0TI6A09>CT`2?Shl0TI6A09>CT`2JVYX0UYJF09ZJVP2IVIT0UiNG
09VIV@2NWYh0X:2P09nOW`2PX:00WinO0:6QX@2OWil0XZ:R0:>SX`2VYZH0ZJVY0:NWY`020:VYZ@03
0:j^[P2a/K40/K6a0080/[:b00<0];Bd0;Zj^P2g]kL00P2i^KT0202j^[X0^k^k0;no_`2n_[h0`<30
0<?3``32`/80alO70P36a/H01@39bLT0c<c<0<c<c03>c/h0clo?0080d=3@00L0e]KF0=;BdP3De=@0
eMGE0=;BdP3Cdm<0e]KF0080emOG00`0e]KF0=OGe`3Hf=P0f=SH0=KFeP34a<@0QXJ604Y:BP1=CDd0
DU9B05=CD`1DE5@205IFEP0:05YJFP1RHV80H61P06=SH`1VIVH0IFEU06ATI01VIVH0K6a/06MWI`80
JVYZ00X0KVi^075aL@1]KFd0J6QX06IVIP1SHf<0HV9R06IVIP1UIFD0IfMW0P1]KFd01`1/K6`0Lg=c
07AdM01_Kfl0LW9b06a/K01_Kfl00P1ZJVX0301^KVh0K6a/071`L01cLg<0Ng]k07emO@22PX80OWin
07QhN01aLG40IVIV05QHF080EUIF00X0DE5A04i>CP1ADE40De=C051@D01>CTh0EEEE05ADE01CDe<0
EUIF0P1JFUX03@1@D500E5AD051@D01ADE40CDe=0451@@17AdL0BDU905ADE01HF5P0HV9R06EUI@1_
Kfl00P1WIfL02P1ZJVX0J6QX06IVIP1NGUh0Fe]K055AD@1@D500BTY:0492@P14A4@20451@@0?04U9
B@0j>SX0>c/k03Xj>P12@T80ATI6059BDP1DE5@0Hf=S06QXJ01VIVH0KVi^071`L01bLW80MgMg0080
Lg=c0P1bLW801`1^KVh0IFEU06IVIP1WIfL0H61P05YJFP1DE5@00P1:BTX03P18B4P0>c/k04=3@`11
@D40?Shn03Ph>00i>CT0>c/k03lo?`0f=SH0=cLg03Ph>00a<C40;Bd]3P38h=P000`0b>3H0P0/;2`0
4P0f=SH0@d=303lo?`1:BTX0Cdm?05IFEP1MGEd0F5QH06EUI@1KFe/0JFUY071`L01lO7`0Ph>309BD
U02QXJ40[:b/0:f][@80/;2`01@0/[:b0:n_[`2/[:`0YJFU09jNWP2?Shl0Ogmo07AdM01RHV80FEUI
05mOG`1VIVH0Kfm_0861P@26QXH0TY:B09RHV02LW9`0YJFU0:RXZ080Zj^[00H0[jn_0;:b/P2`/;00
/K6a0;Fe]@2f][H40;Fe]@0G0;Ng]`2i^KT0^KVi0;Bd]02_[jl0/;2`0:VYZ@2WYjL0WinO08R8R01V
IVH0ADE504U9B@1HF5P0CDe=03Ph>00Z:RX0<S8b03<c<`0e=CD0:RXZ02LW9`0[:b/00`0^;Rh05P0d
=3@0<C4a02d];@0d=3@0>SXj03Ti>@0h>3P0ATI60410@017AdL0=3@d02h^;P0c<c<0<C4a038b<P0f
=SH0<30`051@D01UIFD0=SHf02XZ:P0W9bL203<c<`0I03De=@0];Bd0>CTi03Lg=`16ATH0ADE503@d
=01:BTX0K6a/04e=C@0m?Cd0:BTY02HV9P0c<c<0CTi>06ATI01EEED0J6QX07inOP1hN7P0IVIV07Ee
M@1PH600BDU903Ph>00203`l?00^0492@P0f=SH0<30`02h^;P0h>3P0JFUY06QXJ011@D40:2PX04M7
A`0R8R80;2`/0451@@0i>CT0=SHf07EeM@2;Rh/0CTi>03<c<`1HF5P0=SHf03<c<`0m?Cd0DU9B05iN
GP1hN7P0Kfm_075aL@1[Jf/0QHF50:6QX@2EUID0OGem06IVIP0n?Sh0>c/k02<S8`0/;2`0ADE503Lg
=`0S8b<08B4Q02h^;P0_;bl0;Bd]02`/;0809RHV0P0d=3@01@0`<300<c<c02d];@0/;2`0<C4a00@0
;2`/00@092@T02`/;00/;2`0:BTY0P0X:2P00`0Y:BT0:2PX03Hf=P0203Xj>P0>0451@@14A4@0CDe=
05EEE@1>CTh0EEEE05eMG@1PH600FEUI069RHP1^KVh0L71`07=cL`1fMWH207YjNP0<07]kN`1oOgl0
P82008:2PP1nOWh0P82008:2PP1mOGd0Ogmo0861P@23Ph<0Q8B40P20P8001022PX80P8200861P@1m
OGd208B4Q00N08N7Q`24Q8@0QhN708N7Q`28R8P0QHF508>3P`25QHD0Shn?08R8R025QHD0RHV908F5
Q@26QXH0SXj>08^;R`2>SXh0QhN708b<S029RHT0SHf=08Z:RP27QhL0SXj>08Z:RP2=SHd0RXZ:08^;
R`2<S8`0SHf=0P2:RXX01P2=SHd0Shn?09:BTP2?Shl0Ti>C08b<S080Shn?00D0Ti>C096AT@2ATI40
TI6A09:BTP02096AT@0A09:BTP2>SXh0Shn?09BDU029RHT0SHf=092@T02=SHd0T92@08j>SP2<S8`0
TI6A08f=S@27QhL0RXZ:08^;R`2<S8`00`2;Rh/0202ATI40SHf=08n?S`2>SXh0Rh^;08b<S02>SXh0
S8b<0P2?Shl01@2CTi<0Shn?08n?S`2CTi<0Shn?0080UIFE0P2FUYH00`2DU9@0Vi^K09VIV@0209fM
W@0909jNWP2QXJ40WYjN0:2PX02QXJ40XZ:R0:FUY@2VYZH0Y:BT0080Z:RX00@0[:b/0:n_[`2a/K40
/[:b0P2a/K400`2c/k<0][Jf0;Fe]@020;Rh^080^[Zj00h0_kno0<30`02o_kl0`l?30<G5a@36a/H0
alO70<[:bP38b<P0c<c<0<g=c@3<c<`0c/k>0=3@d080dm?C00L0e=CD0=GEe@3Cdm<0e=CD0=?Cd`3G
emL0eMGE00<0emOG00X0e]KF0=GEe@3@d=00^k^k075aL@18B4P0D51@05=CD`1IFET0EEEE0P1JFUX0
101KFe/0G5aL06=SH`1PH602065QH@0606ATI01WIfL0Kfm_06a/K01`L700IVIV0P1[Jf/0101/K6`0
JVYZ06YZJP1VIVH206EUI@0806UYJ@1RHV80JVYZ06UYJ@1WIfL0Jf][06e]K@1`L70206m_K`0R06e]
K@1UIFD0Jf][06UYJ@1VIVH0Kfm_07moO`2:RXX0VYZJ09FEU@2ATI40SXj>08F5Q@1hN7P0IfMW05UI
F@1EEED0E5AD04m?C`18B4P0Bd];04Y:BP1;Bd/0Cdm?04];B`1=CDd0Cdm?05EEE@1BDU80EEEE04m?
C`1<C4`0CDe=04];B`80AdM700T0Cdm?051@D01?Cdl0De=C065QH@1OGel0IVIV06a/K01ZJVX00P1_
Kfl01`1TI6@0Fe]K05]KF`1HF5P0ATI604];B`16ATH00`15ADD07016ATH0@41003dm?@0o?cl0@410
04U9B@1?Cdl0H61P06MWI`1XJ6P0Lg=c06][J`1aLG40Lg=c07AdM01iNGT0MgMg075aL@1dM7@0JFUY
06IVIP1RHV80JFUY05]KF`1DE5@0BDU904Q8B014A4@20492@P0;03hn?P0l?3`0@4100410@012@T80
@4100492@P0i>CT0>SXj034a<@0`<3003P38h=P000`0b>3H0P0];Bd01P0g=cL0A4A404U9B@1@D500
EEEE05mOG`80FEUI0200HV9R061PH01/K6`0MWIf07]kN`28R8P0U9BD0::RXP2ZZZX0[jn_0;:b/P2c
/k<0/[:b0:j^[P2ZZZX0YJFU09VIV@2>SXh0PH6106e]K@1JFUX0EUIF05iNGP1YJFT0LG5a07inOP25
QHD0U9BD09RHV02QXJ40YZJV0:ZZZP80Zj^[00<0/k>c0;6a/@2a/K400P2c/k<02`2b/[80^KVi0;Bd
]02g]kL0]KFe0;Zj^P2i^KT0]KFe0;>c/`2a/K40ZZZZ0080Z:RX0140WIfM08:2PP1PH600CTi>04a<
C01IFET0GEeM04];B`0/;2`0:BTY034a<@0e=CD0<30`02d];@0c<c<0<C4a02h^;P0203Ph>00Z03<c
<`0j>SX0>c/k03<c<`0W9bL0<30`03lo?`11@D40?Shn03/k>`0_;bl0:b/[03<c<`0d=3@0<c<c02d]
;@1@D500FEUI03Hf=P0V9RH0;Bd]03De=@0b<S80<30`03<c<`0a<C40@D5104U9B@18B4P0<c<c0492
@P1dM7@0De=C03Hf=P0/;2`08B4Q034a<@1:BTX0De=C055AD@1YJFT0NWYj0P1VIVH0101[Jf/0FEUI
04A4A00g=cL202h^;P0D03<c<`0`<300;bl_02/[:`1=CDd0L71`05UIF@0[:b/0:RXZ02TY:@0f=SH0
@D5104A4A00a<C40FEUI09FEU@1_Kfl0<C4a0492@P14A4@203Hf=P0M04=3@`17AdL0Hf=S075aL@1_
Kfl0LG5a06i^KP2OWil0ZJVY09:BTP1YJFT0@d=302l_;`0h>3P0<30`034a<@19BDT0;bl_02<S8`0]
;Bd0:BTY02PX:00`<300?clo02h^;P0[:b/0=3@d02h^;P0`<3000P0^;Rh00`0X:2P0<c<c02l_;`03
02l_;`<0<C4a0100;bl_02LW9`0_;bl0;Bd]03@d=00W9bL09BDU02TY:@0];Bd0>CTi03lo?`14A4@0
DU9B055AD@1JFUX0Hf=S0P1XJ6P206e]K@0:06m_K`1/K6`0L71`071`L01cLg<0MWIf07UiN@1lO7`0
NWYj07]kN`80Ogmo00<0NGUi07emO@1mOGd00P1lO7`0201nOWh0PH6107emO@1oOgl0QHF508B4Q022
PX80PH610P25QHD01026QXH0RHV908Z:RP24Q8@208R8R00C08^;R`27QhL0QXJ608Z:RP28R8P0S8b<
08N7Q`2;Rh/0SHf=08^;R`2>SXh0R8R808^;R`28R8P0QHF508^;R`2ATI40SHf=08^;R`0208f=S@05
08b<S02@T900T92@08n?S`2ATI400P2>SXh00`2@T900U9BD09:BTP02096AT@0=09>CT`2DU9@0U9BD
092@T02CTi<0UiNG08^;R`2ATI40SHf=08n?S`2ATI40RXZ:092@T00308j>SP0608V9R@2<S8`0Rh^;
08N7Q`2;Rh/0S8b<0P2@T90208n?S`0608f=S@2<S8`0TI6A08^;R`2<S8`0SXj>0P2?Shl01`2>SXh0
Shn?09:BTP2?Shl0T92@09NGU`2BTY800P2EUID01`2JVYX0UIFE09^KV`2NWYh0W9bL09fMW@2LW9`0
0`2NWYh03P2SXj<0X:2P0:BTY02SXj<0YZJV0:ZZZP2XZ:P0[:b/0;6a/@2`/;00/[:b0:n_[`2b/[80
]KFe0P2d];@02@2j^[X0^k^k0;^k^`2i^KT0_kno0<;2`P2o_kl0`<300<G5a@020<O7a`090<_;b`39
bLT0c<c<0<_;b`3@d=00dM7A0=?Cd`3=cLd0d=3@00<0e=CD00H0dm?C0=CDe03De=@0e]KF0=WIf@3E
eMD20=KFeP080=?Cd`3@d=00[:b/061PH01<C4`0DU9B05ADE01HF5P305YJFP09065QH@1PH600HV9R
05iNGP1UIFD0H61P06YZJP1XJ6P0KFe]0080JVYZ01/0I6AT06MWI`1XJ6P0JVYZ06ATI01VIVH0HV9R
06EUI@1NGUh0GemO06=SH`1RHV80IVIV06ATI01/K6`0JVYZ06UYJ@1/K6`0KFe]06YZJP1TI6@0JVYZ
06ATI01ZJVX0Lg=c08>3P`2IVIT00P2SXj<04@2UYJD0XJ6Q09fMW@2<S8`0L71`05mOG`1JFUX0D51@
05=CD`18B4P0De=C04i>CP1=CDd0A4A4051@D019BDT0CTi>0080Bd];0180C4a<04Q8B01ADE40DU9B
04i>CP1:BTX0B4Q804E5A@19BDT0DU9B05EEE@1IFET0I6AT06MWI`1XJ6P0L71`07=cL`1bLW82069R
HP0505YJFP1HF5P0EEEE055AD@18B4P00P1:BTX00`1=CDd0ATI60410@0020410@00H0492@P17AdL0
D51@05=CD`1NGUh0IFEU06a/K01ZJVX0KFe]07IfMP1gMgL0LG5a07AdM01hN7P0LW9b06UYJ@1VIVH0
J6QX06EUI@1LG5`0EeMG051@D015ADD0@T920P10@4002`13@d<0>c/k04A4A015ADD0?Cdm0451@@15
ADD0?Cdm038b<P0i>CT0;bl_00h0b>3H000<0<SPf080:b/[01<0?Cdm04Q8B01@D500FEUI05mOG`1H
F5P0Hf=S05iNGP1RHV80Hf=S06QXJ01cLg<0P82008f=S@2JVYX0XJ6Q0:VYZ@2_[jl0/k>c0080];Bd
01<0/[:b0:n_[`2XZ:P0VIVI08V9R@23Ph<0JVYZ05QHF01FEUH0GUiN06=SH`1aLG40Ogmo08N7Q`2C
Ti<0UIFE0:2PX02WYjL0ZJVY0080[Zj^00T0/K6a0;2`/02a/K40/[:b0;Bd]02b/[80][Jf0;Bd]02c
/k<00P2f][H0102j^[X0/k>c0;2`/02^[Zh20:VYZ@0Y0:BTY02KVi/0Ng]k05eMG@1DE5@0Hf=S05iN
GP1PH600Fe]K03@d=00X:2P0;2`/02h^;P0Y:BT0:RXZ02/[:`0f=SH0;bl_03<c<`0j>SX0;bl_03Xj
>P0k>c/0;Bd]02XZ:P0];Bd0BDU904E5A@0l?3`0<c<c02l_;`0^;Rh0=CDe034a<@0`<300;bl_04e=
C@1BDU80=SHf02TY:@0^;Rh00P0`<3001P0e=CD0;Rh^02l_;`0d=3@0Bd];05EEE@80?3`l0140PH61
065QH@0o?cl0:RXZ02PX:00i>CT0A4A405IFEP1?Cdl0KFe]06QXJ01?Cdl0JFUY05iNGP0o?cl0<30`
02PX:00202l_;`0Y034a<@0/;2`0:b/[03@d=01MGEd0IVIV05=CD`0V9RH09bLW02/[:`0m?Cd0@D51
038b<P14A4@0TY:B08Z:RP12@T80;Rh^04];B`0];Bd0=SHf03Ti>@1?Cdl0B4Q806a/K01WIfL0K6a/
07=cL`2=SHd0YJFU09FEU@1kNg/0EUIF02XZ:P0b<S80A4A402PX:00d=3@0E5AD02l_;`0V9RH00P0T
92@0100];Bd0:BTY02d];@0/;2`202PX:00402h^;P0o?cl0:2PX02LW9`80;2`/00D0:BTY02/[:`0_
;bl0<S8b03De=@0203Ph>00803@d=00f=SH0=SHf03De=@0`<300:b/[02LW9`0Y:BT202PX:00802TY
:@0[:b/0;Rh^038b<P15ADD0D51@04i>CP1HF5P205iNGP03065QH@1VIVH0Jf][0080Jf][01@0KVi^
075aL@1cLg<0MGEe07QhN022PX80O7al07]kN`1lO7`0Ng]k07YjNP1lO7`0Ogmo08>3P`22PX80PH61
08B4Q025QHD0QXJ60820P080Q8B400`0RHV908R8R028R8P0R8R808b<S02:RXX0S8b<08^;R`28R8P0
TI6A08Z:RP27QhL208^;R`0N08Z:RP2<S8`0S8b<08^;R`25QHD0RXZ:08f=S@2;Rh/0S8b<09>CT`2?
Shl0T92@08j>SP2@T900SXj>096AT@2=SHd0TI6A092@T02CTi<0Shn?09>CT`2DU9@0T92@09:BTP2A
TI40TY:B09RHV02?Shl0T92@102?Shl208j>SP80T92@00T0TY:B096AT@2@T900RXZ:08b<S029RHT0
Rh^;08j>SP2@T9000P2?Shl01@2BTY80SHf=08f=S@2;Rh/0T92@0080SHf=00D0SXj>092@T02FUYH0
Rh^;08n?S`02092@T00609JFUP2EUID0UIFE09JFUP2HV9P0UiNG0P2FUYH01@2GUiL0Vi^K09^KV`2P
X:00VYZJ0080XZ:R00<0X:2P0:6QX@2VYZH00P2YZJT01`2[Zj/0Z:RX0:j^[P2_[jl0[Zj^0:n_[`2^
[Zh00`2b/[802P2g]kL0^[Zj0;Zj^P2k^k/0_[jn0;no_`31`L40`/;20<G5a@39bLT20<S8b0040<_;
b`3:b/X0cLg=0<g=c@80d=3@00<0e=CD0=3@d03AdM400P3De=@00`3Cdm<0d];B0=CDe0020=OGe`03
0=GEe@3Fe]H0dm?C0080eMGE00P0c<c<09nOW`1GEeL0C4a<05EEE@1IFET0FUYJ05UIF@80G5aL0300
HF5Q06=SH`1SHf<0I6AT06IVIP1UIFD0K6a/06e]K@1/K6`0Jf][06QXJ01TI6@0IVIV06][J`1UIFD0
Jf][06UYJ@1TI6@0IVIV069RHP1OGel0GEeM06EUI@1WIfL0I6AT06IVIP1WIfL0Kfm_06QXJ01UIFD0
IfMW06=SH`1NGUh0G5aL06a/K01mOGd0Shn?0:6QX@2^[Zh0/k>c0;Rh^02g]kL0/[:b0:NWY`2EUID0
OWin061PH01FEUH205ADE00N05eMG@1EEED0GUiN051@D01?Cdl0@d=304E5A@1:BTX0CDe=04m?C`1=
CDd0CTi>04e=C@1<C4`0CTi>04Y:BP19BDT0ATI604e=C@1;Bd/0G5aL05mOG`1NGUh0IfMW06][J`1d
M7@0L71`06YZJP1[Jf/0HF5Q0P1KFe/0401=CDd0D51@04m?C`1?Cdl0De=C055AD@17AdL0ATI603lo
?`13@d<0?Cdm04Y:BP1>CTh0EeMG065QH@1UIFD206UYJ@0306i^KP1iNGT0LG5a0080L71`0180Kfm_
06UYJ@1YJFT0J6QX06=SH`1RHV80H61P05MGE`1@D500@T9204=3@`0l?3`0?Cdm04A4A01=CDd0BDU9
04=3@`0o?cl20410@080?3`l00<0=cLg0<SPf038h=P03038h=P000`0b>3H0P0`<3001`12@T80DU9B
05IFEP1MGEd0IVIV06UYJ@1VIVH00P1WIfL02P1VIVH0IfMW07EeM@1oOgl0SHf=09VIV@2RXZ80YJFU
0:f][@2a/K420;>c/`0C0;:b/P2[Zj/0YJFU09RHV027QhL0NGUi06IVIP1JFUX0EeMG065QH@1ZJVX0
LG5a07emO@2:RXX0Shn?09ZJVP2NWYh0Y:BT0:ZZZP020:n_[`040;6a/@2`/;00/K6a0;:b/P80/k>c
00@0]KFe0;Bd]02e]KD0]KFe0P2g]kL06`2c/k<0/;2`0:n_[`2YZJT0YJFU0:>SX`2KVi/0MWIf051@
D01EEED0Kfm_06MWI`1]KFd0Fe]K03<c<`0/;2`0:b/[02XZ:P0[:b/0<30`03Ti>@0`<300<S8b03hn
?P0e=CD0<C4a03<c<`0203Hf=P0802LW9`0d=3@0?3`l04M7A`0g=cL0>CTi02/[:`0Y:BT2030`<009
03@d=00c<c<0C4a<04Q8B017AdL0=SHf02l_;`0/;2`0;bl_0080<c<c01L0:RXZ03/k>`1EEED0EEEE
0451@@0n?Sh0OWin061PH00k>c/0<30`02l_;`0j>SX0@D5105MGE`1HF5P0JFUY05iNGP1@D500GUiN
04a<C00];Bd0:2PX02h^;P0203Lg=`0h03@d=00/;2`0:RXZ04I6AP1^KVh0EeMG03`l?00S8b<09BDU
02`/;00g=cL0=SHf03Ti>@1PH600T92@05]KF`0X:2P0=3@d0492@P0g=cL0:b/[04U9B@1<C4`0De=C
05]KF`1?Cdl0K6a/07UiN@2MWId0UYJF06i^KP1HF5P0ADE503Lg=`0n?Sh0DU9B03@d=016ATH0@T92
038b<P0/;2`0:RXZ02DU9@0a<C40=SHf02l_;`0b<S80:RXZ02DU9@0Y:BT0;2`/02d];@0X:2P0;bl_
03@d=00a<C4202/[:`0J030`<00e=CD0>SXj0492@P14A4@0BDU9051@D01BDU80ATI603Xj>P0g=cL0
<S8b034a<@0/;2`0=3@d02HV9P0U9BD0;2`/02d];@0f=SH0>c/k04Y:BP1CDe<0E5AD05]KF`1SHf<2
06IVIP0:06=SH`1YJFT0KFe]079bLP1dM7@0NWYj07]kN`1nOWh0N7Qh07]kN`80OGem00`0OWin08:2
PP2@T900Q8B408>3P`24Q8@0Ogmo08F5Q@21PH40RXZ:08R8R02:RXX208N7Q`0808B4Q026QXH0S8b<
08V9R@2<S8`0RHV908F5Q@29RHT208^;R`0;096AT@2;Rh/0SHf=08f=S@2>SXh0QXJ608N7Q`2;Rh/0
RXZ:08V9R@2ATI400`2?Shl01P2=SHd0Shn?08j>SP2ATI40Shn?092@T080TI6A0P2DU9@01P2BTY80
U9BD096AT@2ATI40Ti>C096AT@80T92@00<0TY:B092@T02>SXh00P2=SHd01@2<S8`0TI6A092@T02<
S8`0TI6A0080Rh^;00@0RXZ:08^;R`2<S8`0S8b<0P2>SXh00`29RHT0S8b<08f=S@0308b<S00@08V9
R@2;Rh/0TY:B096AT@2;Rh/0SHf=09NGU`2?Shl0T92@09:BTP2EUID0Ti>C09NGU`2HV9P0Vi^K09bL
W080VIVI00<0W9bL09fMW@2PX:000P2QXJ400`2OWil0YJFU0:FUY@020:RXZ00K0:b/[02YZJT0[Jf]
0:n_[`2][Jd0[jn_0:j^[P2b/[80]KFe0;Jf]P2g]kL0^;Rh0;^k^`2o_kl0`L710<30`031`L40`l?3
0<O7a`38b<P0alO70<S8b03<c<`0d=3@0<g=c@3@d=00c/k>0080d=3@103Cdm<20=;BdP0@0=?Cd`3E
eMD0e]KF0=OGe`3Hf=P0e]KF0=GEe@3Fe]H0`L7108J6QP1ADE40CDe=055AD@1CDe<0FUYJ06=SH`80
HF5Q00X0IVIV06EUI@1TI6@0IVIV065QH@1]KFd0IVIV06MWI`1ZJVX0J6QX0P1SHf<03@1TI6@0IfMW
06MWI`1RHV80IfMW06EUI@1PH600HV9R05eMG@1NGUh0HV9R05iNGP1SHf<00P1RHV80901WIfL0I6AT
05eMG@1NGUh0Fe]K05iNGP1RHV80KVi^08>3P`2JVYX0Zj^[0;Zj^P34a<@0a/K60<O7a`32`/80^KVi
0:VYZ@2FUYH0PX:2069RHP1HF5P0DU9B04Q8B01@D500EEEE04e=C@18B4P0ATI604E5A@0m?Cd0ADE5
04e=C@19BDT0ATI604];B`80C4a<01<0AdM704Y:BP13@d<0Bd];04e=C@1ADE40EeMG05aLG01TI6@0
KFe]07=cL`1^KVh0L71`07=cL`1XJ6P0GemO061PH01BDU80CTi>0080C4a<0100Cdm?04a<C017AdL0
?clo03hn?P10@400?3`l04Q8B01=CDd0DE5A05aLG01QHF40H61P06EUI@1/K6`0LG5a0P1`L7004@1_
Kfl0KVi^06YZJP1ZJVX0IfMW06=SH`1QHF40H61P05QHF01?Cdl0ADE504=3@`0h>3P0@D5103lo?`19
BDT0ADE50080@T9200D0BTY:04I6AP10@400?clo03Ti>@0>0<SPf0003038h=P203Lg=`0A04e=C@1E
EED0GUiN06QXJ01`L700Kfm_075aL@1cLg<0K6a/06YZJP1_Kfl0MgMg08B4Q02:RXX0X:2P0:BTY02]
[Jd00P2^[Zh05@2b/[80[jn_0:j^[P2ZZZX0XZ:R09>CT`26QXH0MgMg06=SH`1EEED0F5QH061PH01W
IfL0KVi^07moO`2?Shl0Ti>C09bLW02QXJ40Z:RX0:ZZZP020:f][@070:j^[P2b/[80/;2`0;:b/P2`
/;00/[:b0;6a/@020;>c/`1<0;Jf]P2g]kL0]kNg0;Bd]02c/k<0/;2`0:f][@2WYjL0YJFU09ZJVP1`
L700A4A405IFEP1fMWH0KFe]06][J`1QHF40?Shn02`/;00W9bL09BDU02TY:@0`<300:b/[02h^;P0]
;Bd0<30`03hn?P0^;Rh0;Bd]03lo?`0j>SX0;bl_03<c<`0k>c/0@d=303Ti>@0^;Rh0:RXZ03<c<`0^
;Rh0<C4a02/[:`15ADD0C4a<04M7A`14A4@0<c<c030`<00X:2P0;Bd]03<c<`0_;bl0;Rh^03Hf=P1@
D500DU9B0492@P0l?3`0P820065QH@10@400<30`02`/;00g=cL0?3`l04i>CP1FEUH0Hf=S05ADE01C
De<0Fe]K03lo?`0W9bL0:RXZ03<c<`80;Rh^02L0=SHf02d];@0`<300G5aL05mOG`17AdL0:RXZ02d]
;@0h>3P0<C4a030`<00_;bl0Bd];07YjNP1gMgL0?Shn038b<P0o?cl0A4A404=3@`0i>CT0FUYJ04m?
C`1EEED0@T9204I6AP1QHF40S8b<09JFUP22PX80B4Q804m?C`17AdL0:2PX03Ti>@19BDT0@T9205=C
D`0i>CT00P0Y:BT0100W9bL08b<S02PX:00];Bd2034a<@0@02d];@0Y:BT09RHV02/[:`0T92@09BDU
02d];@0_;bl09RHV02`/;00X:2P0:RXZ02`/;00f=SH0AdM704Q8B080D51@01<0EeMG059BDP1MGEd0
FUYJ059BDP13@d<0>SXj03Ti>@1:BTX0:RXZ02HV9P0^;Rh09bLW02@T900b<S80>c/k04=3@`1DE5@0
GEeM0080H61P0P1TI6@0101XJ6P0K6a/06m_K`1eMGD207MgM`0307IfMP1iNGT0OGem0080O7al00D0
OWin07]kN`24Q8@0Ph>308:2PP0308B4Q00@08:2PP28R8P0RHV908R8R026QXH0R8R808Z:RP26QXH0
QhN708J6QP2;Rh/0QHF508J6QP27QhL0R8R8096AT@80Rh^;00T0SHf=08n?S`29RHT0Rh^;08n?S`2:
RXX0SHf=096AT@2?Shl00`2>SXh03P2@T900Shn?092@T02?Shl0U9BD09>CT`2>SXh0UIFE092@T02B
TY80U9BD09JFUP2@T900TY:B0`2ATI401@2?Shl0TI6A08n?S`2CTi<0SXj>0080Shn?00<0R8R808b<
S02;Rh/00P2;Rh/00`2>SXh0SHf=08V9R@0308b<S00A08^;R`2=SHd0SXj>08^;R`28R8P0S8b<08Z:
RP2?Shl0TY:B092@T02?Shl0TI6A09JFUP2CTi<0UYJF09:BTP2GUiL00P2EUID03@2IVIT0V9RH09ZJ
VP2MWId0Vi^K09jNWP2MWId0WYjN09nOW`2PX:00XJ6Q0:BTY02XZ:P00P2ZZZX0102XZ:P0[Jf]0:f]
[@2YZJT20;2`/00?0:j^[P2b/[80]KFe0;Vi^@2d];@0^k^k0;Vi^@2m_Kd0_[jn0<C4a031`L40a<C4
0<K6aP37alL0bLW90080b<S800L0clo?0<g=c@3>c/h0clo?0=GEe@3AdM40dm?C00@0e]KF00@0e=CD
0=?Cd`3Fe]H0f=SH0`3GemL02P3EeMD0d];B0;:b/P1XJ6P0BDU904e=C@1DE5@0FEUI061PH01QHF42
05iNGP08065QH@1XJ6P0Hf=S06ATI01VIVH0HV9R06QXJ01TI6@206MWI`0X06IVIP1RHV80GemO06UY
J@1TI6@0HF5Q06=SH`1WIfL0IFEU06ATI01EEED0F5QH05MGE`1FEUH0Fe]K05QHF01RHV80G5aL05iN
GP1PH600GemO05]KF`1GEeL0Fe]K075aL@29RHT0WYjN0;6a/@33`l<0b/[:0<o?c`3>c/h0b/[:0<71
`@2i^KT0ZZZZ09NGU`1jNWX0HF5Q05]KF`80CTi>01/0Bd];04a<C010@400@D5104=3@`0k>c/0>SXj
0492@P19BDT0BTY:04e=C@1DE5@0CDe=04Y:BP1?Cdl0BTY:04I6AP19BDT0ATI605QHF01FEUH0HV9R
06QXJ01/K6`0Jf][06i^KP1aLG400P1YJFT00`1UIFD0Fe]K05UIF@0205QHF00I04Y:BP1;Bd/0ATI6
03hn?P12@T80BDU903lo?`14A4@0CDe=05=CD`1FEUH0GEeM05iNGP1OGel0Jf][075aL@1bLW80LG5a
06][J`1aLG40KFe]06MWI`1UIFD0Hf=S061PH00205eMG@0?05=CD`1<C4`0BDU90410@00h>3P0>CTi
03hn?P1;Bd/0ADE504A4A016ATH0AdM704E5A@0j>SX0=SHf00h0b>3H000<0<SPf080=cLg00H0D51@
05QHF01MGEd0IVIV071`L01^KVh207=cL`0N07AdM01`L700MGEe07MgM`2;Rh/0Ti>C0::RXP2XZ:P0
ZJVY0:b/[02b/[80/K6a0:j^[P2_[jl0ZJVY0::RXP2GUiL0Q8B407IfMP1YJFT0FUYJ05]KF`1NGUh0
JFUY06i^KP21PH40Rh^;09>CT`2HV9P0WinO0P2ZZZX20:n_[`0G0:b/[02][Jd0[jn_0;6a/@2b/[80
/;2`0;Bd]02a/K40];Bd0;Ng]`2f][H0^[Zj0;Bd]02b/[80/;2`0:j^[P2YZJT0XJ6Q09RHV01]KFd0
ATI6065QH@1iNGT00P1/K6`0?01WIfL0C4a<02`/;00W9bL09RHV02d];@0b<S809bLW02/[:`0^;Rh0
<c<c03/k>`0b<S80>CTi03lo?`10@400:RXZ02PX:00j>SX0@T9203Xj>P0i>CT0;Bd]038b<P0a<C40
>CTi04I6AP0i>CT0AdM703lo?`0f=SH0:b/[02HV9P0W9bL0;Bd]02/[:`0e=CD0:RXZ03<c<`16ATH0
De=C04E5A@11@D40NWYj05ADE00k>c/0=3@d02d];@11@D40?clo05YJFP1RHV80Fe]K05UIF@1DE5@0
BDU902h^;P0W9bL0;bl_02PX:080<C4a0P0/;2`0:012@T80HF5Q05QHF011@D40<C4a0492@P16ATH0
=CDe03@d=00/;2`0ATI607IfMP1BDU80:b/[03/k>`12@T80CDe=034a<@0`<300Fe]K059BDP1:BTX0
@41005QHF01ZJVX0UIFE09>CT`24Q8@0B4Q805aLG019BDT09RHV03De=@18B4P0F5QH05]KF`0d=3@0
:2PX02XZ:P0U9BD202HV9P0<02d];@0/;2`0<C4a03<c<`0^;Rh09RHV02LW9`0V9RH092@T02l_;`0W
9bL092@T0P0U9BD202TY:@0302d];@0j>SX0@4100080DE5A01<0E5AD059BDP1OGel0HV9R06EUI@1O
Gel0H61P05]KF`1=CDd0?Shn02`/;00`<300;Bd]02HV9P0^;Rh0;bl_02d];@10@400B4Q80080E5AD
01X0HV9R06EUI@1YJFT0J6QX06i^KP1cLg<0MWIf07QhN01gMgL0N7Qh07emO@20P800Ng]k07emO@1k
Ng/0PH6107moO`27QhL0PX:208J6QP2:RXX0Q8B408F5Q@27QhL0Ph>308^;R`80QXJ600/0R8R808N7
Q`29RHT0SHf=08N7Q`28R8P0S8b<08R8R02ATI40RXZ:08j>SP02092@T00708j>SP2<S8`0SHf=08b<
S02:RXX0Rh^;08f=S@0308n?S`0309:BTP2<S8`0Shn?0080Shn?00T0UIFE08n?S`2@T900T92@09BD
U02@T900TI6A092@T02>SXh00P2BTY804@2<S8`0SHf=096AT@2FUYH0TI6A09:BTP2<S8`0Shn?08f=
S@2?Shl0SXj>08Z:RP2<S8`0SXj>08f=S@28R8P0Shn?00<0Rh^;01P0SHf=096AT@29RHT0RHV908f=
S@2?Shl0SXj>08n?S`2=SHd0T92@096AT@2BTY80Ti>C096AT@2BTY80Ti>C096AT@2FUYH0UIFE09^K
V`2JVYX0V9RH09bLW02OWil30:2PX080Xj>S00D0Y:BT0:RXZ02YZJT0YZJV0:NWY`020:ZZZP090:b/
[02b/[80/;2`0:b/[02c/k<0][Jf0;Rh^02i^KT0^[Zj0080_[jn00l0^k^k0<71`@31`L40a<C40<G5
a@37alL0bl_;0<S8b03>c/h0c<c<0<g=c@3>c/h0d=3@0=?Cd`3Bd]800P3De=@0103Cdm<0eMGE0=CD
e03De=@20=GEe@0>0=[JfP3EeMD0f=SH0=WIf@3EeMD0c/k>0:2PX01JFUX0CTi>059BDP1EEED0HV9R
05mOG`1RHV8206ATI0<0IFEU00@0J6QX069RHP1XJ6P0JFUY0P1_Kfl01`1SHf<0IfMW061PH01OGel0
H61P06=SH`1LG5`00P1RHV80@P1QHF40FUYJ05YJFP1IFET0EUIF05=CD`1HF5P0G5aL05iNGP1GEeL0
GUiN05eMG@1IFET0Fe]K05UIF@1JFUX0N7Qh08b<S02QXJ40/k>c0<G5a@3?cll0d];B0=?Cd`3Bd]80
bl_;0<?3``2e]KD0Y:BT08n?S`1mOGd0JFUY05EEE@1ADE40A4A40451@@0o?cl0?3`l0492@P0j>SX0
=3@d03Xj>P0o?cl0?Shn04Y:BP10@400CTi>04I6AP1:BTX0ATI604=3@`11@D40C4a<04Q8B01BDU80
FUYJ05iNGP1TI6@0JFUY06QXJ01/K6`0JFUY06IVIP1QHF40H61P05YJFP80Hf=S00`0E5AD04Y:BP16
ATH0ADE504Q8B014A4@0ADE504A4A01CDe<0DE5A05ADE01KFe/205eMG@0?06UYJ@1^KVh0LG5a079b
LP1cLg<0Kfm_06a/K01UIFD0JFUY06IVIP1WIfL0GemO05aLG01NGUh0D51@0080B4Q800/0@T9203Hf
=P10@400A4A40410@014A4@0B4Q804E5A@1;Bd/0@41003Xj>P0>0<SPf0003038h=P203lo?`08055A
D@1OGel0G5aL06IVIP1aLG40LW9b07IfMP1bLW8207EeM@80Ogmo00<0Rh^;09RHV02VYZH00P2[Zj/0
0`2d];@0/K6a0;6a/@020:n_[`060:^[Z`2RXZ80UYJF08Z:RP1fMWH0K6a/0P1ADE402@1OGel0J6QX
07=cL`20P800Rh^;09:BTP2NWYh0Xj>S0:NWY`030;2`/0040:j^[P2_[jl0[Jf]0;2`/080/K6a01L0
/[:b0;Bd]02c/k<0][Jf0;Ng]`2h^;P0]kNg0:n_[`2`/;00ZJVY0:FUY@2PX:00UIFE06a/K01;Bd/0
JFUY07inOP1gMgL0MGEe06QXJ01BDU80:b/[02`/;00202d];@0f03@d=00c<c<0:RXZ030`<00n?Sh0
>SXj02l_;`0];Bd0@41003Hf=P0];Bd0;Rh^03Ti>@11@D40=CDe034a<@0Y:BT0=CDe038b<P0a<C40
=SHf03Ph>00m?Cd0=cLg038b<P0a<C40;bl_02LW9`0/;2`0;Bd]034a<@0[:b/0>3Ph04I6AP1JFUX0
E5AD03dm?@1PH600GUiN03`l?00b<S80<30`0410@00j>SX0ATI6059BDP1FEUH0Fe]K05=CD`0k>c/0
:RXZ02d];@0[:b/0;Bd]0P0^;Rh0=`0[:b/0:RXZ04=3@`1KFe/0Cdm?04M7A`1DE5@0B4Q80451@@0l
?3`0B4Q8038b<P1MGEd0HV9R038b<P0^;Rh0A4A404E5A@0j>SX0=3@d055AD@1@D500CDe=04E5A@1@
D500Fe]K08B4Q02LW9`0S8b<06][J`1=CDd0F5QH03Xj>P0T92@0<c<c04e=C@1YJFT0AdM702`/;00d
=3@0<C4a02PX:00d=3@0;Rh^02/[:`0];Bd0=SHf03@d=00];Bd0:BTY02XZ:P0W9bL09BDU02XZ:P0V
9RH00`0S8b<02`0Z:RX09bLW02/[:`0`<300=cLg04I6AP1;Bd/0CDe=055AD@1EEED0Fe]K0080IFEU
00d0KVi^06IVIP1TI6@0J6QX05ADE01>CTh0>SXj02/[:`0S8b<0820P01hN7P0W9bL0;2`/0080>c/k
01<0BTY:05EEE@1NGUh0I6AT06IVIP1YJFT0Kfm_07=cL`1eMGD0MWIf07YjNP1oOgl0NWYj07moO`22
PX80PH6108B4Q023Ph<0QHF50080Q8B40180QXJ608F5Q@2;Rh/0QhN708Z:RP25QHD0Rh^;08V9R@2<
S8`0RXZ:08V9R@2:RXX0R8R808f=S@2:RXX0S8b<08n?S`2BTY8208^;R`0308b<S02:RXX0Rh^;0080
SHf=00P0SXj>08n?S`2=SHd0SXj>08n?S`2>SXh0Shn?09BDU080Shn?0P2DU9@01P2=SHd0TI6A092@
T02CTi<0TI6A092@T080SXj>00h0S8b<08j>SP2?Shl0TI6A08j>SP2;Rh/0TI6A08Z:RP27QhL0T92@
08j>SP2;Rh/0RHV908b<S080SXj>00T0Rh^;08f=S@28R8P0R8R808^;R`29RHT0R8R808Z:RP2<S8`0
0P2=SHd04P2@T900SHf=092@T02CTi<0U9BD09VIV@2CTi<0T92@09:BTP2EUID0UYJF09VIV@2GUiL0
W9bL09ZJVP2IVIT0XZ:R0:>SX`80WinO00/0XZ:R0:6QX@2QXJ40YZJV0:RXZ02/[:`0ZZZZ0:JVYP2Y
ZJT0YjNW0:ZZZP020:n_[`80/k>c00@0]KFe0;Vi^@2j^[X0_;bl0P2n_[h01P31`L40`l?30<G5a@35
aLD0a/K60<[:bP80bLW900L0cLg=0<c<c03<c<`0c<c<0=7Ad@3De=@0dm?C00<0e=CD0140eMGE0=CD
e03EeMD0e=CD0=OGe`3Jf]X0f=SH0=KFeP3Hf=P0e]KF0<[:bP2>SXh0DE5A05=CD`1@D500FUYJ05]K
F`0205mOG`80IVIV00d0J6QX069RHP1]KFd0JVYZ06EUI@1VIVH0IfMW06][J`1ZJVX0I6AT06=SH`1U
IFD0Hf=S0080IFEU00@0GUiN06=SH`1PH600HV9R0P1HF5P02P1CDe<0EeMG05ADE01@D500EEEE05=C
D`1JFUX0F5QH05YJFP1EEED2059BDP0705iNGP1eMGD0SXj>0::RXP2e]KD0`l?30<k>cP020=GEe@0P
0=CDe03AdM40b/[:0<71`@2`/;00X:2P08n?S`22PX80L71`05eMG@1EEED0CDe=04Y:BP13@d<0?clo
03`l?00f=SH0?3`l03/k>`0g=cL0BTY:04E5A@13@d<0BTY:04e=C@1<C4`0?3`l04E5A@13@d<0ADE5
04i>CP1FEUH205MGE`0806EUI@1TI6@0L71`06YZJP1YJFT0J6QX06EUI@1NGUh205aLG00305ADE01?
Cdl0Bd];0080AdM700`0@D5104];B`1<C4`0D51@04a<C01?Cdl0EeMG05iNGP1MGEd0GemO06e]K@1`
L70207AdM003079bLP1[Jf/0IFEU0080J6QX0180GUiN05MGE`1LG5`0H61P05QHF01:BTX0E5AD04Q8
B00i>CT0>c/k0451@@0m?Cd0ATI604i>CP1=CDd0ADE50451@@0h>3P>0<SPf0003038h=P204A4A00U
055AD@1GEeL0Hf=S06MWI`1aLG40L71`07=cL`1bLW80M7Ad07YjNP22PX80Q8B408Z:RP2JVYX0YZJV
0:b/[02^[Zh0/;2`0;:b/P2`/;00[jn_0;2`/02/[:`0XJ6Q09JFUP27QhL0NGUi069RHP1ADE40De=C
05]KF`1YJFT0LG5a08B4Q02@T900UIFE09bLW0020:FUY@0A0:ZZZP2b/[80/[:b0:b/[02`/;00/K6a
0:f][@2c/k<0[jn_0;6a/@2d];@0]KFe0;Vi^@2g]kL0^;Rh0;Ng]`2a/K400P2/[:`0;02WYjL0XZ:R
09>CT`1SHf<0CTi>07QhN020P800Lg=c06a/K01LG5`0D51@03@d=00Y:BT0=CDe02XZ:P0j>SX0=SHf
02TY:@0_;bl0<c<c03De=@0d=3@0;Bd]034a<@0h>3P0:b/[030`<00g=cL0@41003Ph>00e=CD0;Bd]
03@d=00a<C40=CDe03Ti>@13@d<0>3Ph034a<@0Z:RX0;Bd]030`<00/;2`0=CDe0P0^;Rh00`0e=CD0
ATI603hn?P02055AD@090492@P1?Cdl0C4a<03dm?@0/;2`0;Bd]03Ti>@0m?Cd0C4a<0080EUIF00L0
E5AD03dm?@0Z:RX0:BTY02`/;00g=cL0=SHf0080:b/[02h09BDU02l_;`1DE5@0B4Q805UIF@1WIfL0
DE5A03hn?P0g=cL0>SXj03Ti>@0m?Cd0KFe]04=3@`0Z:RX0>3Ph04];B`0k>c/0@T9205QHF01GEeL0
Cdm?04=3@`1@D500EeMG07QhN02;Rh/0UYJF07IfMP10@400>SXj04m?C`0`<300=CDe04I6AP1RHV80
Hf=S03lo?`0Z:RX0<C4a02h^;P0/;2`0;Rh^02l_;`0Y:BT0:RXZ0P0a<C40900d=3@0;Bd]02/[:`0[
:b/09BDU02XZ:P0S8b<08R8R02<S8`0U9BD0:b/[03<c<`0_;bl0<S8b03/k>`15ADD0ATI604i>CP1<
C4`0DE5A05UIF@1XJ6P0HV9R06IVIP1]KFd0Jf][06YZJP1[Jf/0LW9b06EUI@1?Cdl0=SHf02LW9`0R
8R80;Rh^02<S8`80:b/[00P0;Rh^03/k>`1?Cdl0GEeM069RHP1VIVH0JFUY071`L080MGEe00/0MgMg
07alO01hN7P0Q8B407moO`20P800Q8B408>3P`28R8P0PX:208B4Q00208J6QP0408Z:RP29RHT0Rh^;
08N7Q`80R8R800@0S8b<08R8R02@T900SHf=0P28R8P01P27QhL0RXZ:08f=S@2=SHd0Rh^;08Z:RP80
Rh^;00D0SHf=08b<S02=SHd0Shn?08j>SP0208f=S@03096AT@2=SHd0S8b<0080S8b<00D0RXZ:092@
T02<S8`0SXj>08f=S@0208n?S`07092@T02>SXh0TY:B08f=S@2<S8`0T92@08^;R`0208b<S00<08f=
S@2;Rh/0QhN708Z:RP2ATI40S8b<08V9R@28R8P0SXj>08n?S`2=SHd0R8R80`2:RXX0202<S8`0RHV9
08V9R@2<S8`0Rh^;08j>SP2?Shl0T92@0P2>SXh01@2CTi<0TI6A09JFUP2EUID0Ti>C0080TI6A00l0
UIFE09jNWP2JVYX0Vi^K09ZJVP2HV9P0WinO0:6QX@2RXZ80X:2P0:BTY02PX:00YJFU0:RXZ02UYJD0
0P2ZZZX07@2UYJD0YjNW0:ZZZP2/[:`0/;2`0:n_[`2d];@0/[:b0;Ng]`2h^;P0_kno0;bl_02o_kl0
_;bl0;jn_P34a<@0alO70<K6aP35aLD0b/[:0<W9b@3=cLd0c/k>0<o?c`3AdM40clo?0=7Ad@3Bd]80
dM7A0080dm?C0P3EeMD02`3De=@0d];B0=?Cd`3GemL0fMWI0=OGe`3Hf=P0fMWI0=GEe@33`l<0O7al
0080CTi>00D0EeMG05YJFP1QHF40IVIV061PH00206=SH`0506ATI01YJFT0J6QX06][J`1WIfL00P1V
IVH0201/K6`0IFEU06QXJ01PH600G5aL05eMG@1SHf<0J6QX0P1PH6006@1RHV80Hf=S05mOG`1CDe<0
EEEE059BDP1CDe<0CTi>04e=C@1<C4`0EEEE04m?C`1FEUH0D51@04m?C`1GEeL0G5aL07=cL`28R8P0
WinO0;Fe]@35aLD0clo?0=?Cd`3EeMD00P3De=@0:03=cLd0a/K60;^k^`2[Zj/0Y:BT09:BTP26QXH0
OGem069RHP1MGEd0EEEE04e=C@0l?3`0@41003Hf=P0e=CD0=3@d03De=@11@D40?clo04=3@`1<C4`0
DE5A04Y:BP18B4P0ATI604A4A011@D40A4A404];B`1BDU80EUIF05YJFP1QHF40IfMW06YZJP1[Jf/0
KFe]06EUI@1YJFT2061PH00<05]KF`1DE5@0BDU904U9B@1;Bd/0B4Q804Y:BP19BDT0Cdm?059BDP1=
CDd0EUIF0P1KFe/05P1SHf<0J6QX06][J`1_Kfl0MGEe075aL@1_Kfl0I6AT06QXJ01RHV80GUiN05QH
F01RHV80FUYJ05UIF@1ADE40Cdm?04Y:BP14A4@0>c/k03dm?@13@d<204I6AP040492@P0n?Sh0=cLg
03`l?0h0b>3H000<0<SPf080BDU900@0EUIF05eMG@1SHf<0Hf=S0P1[Jf/02@1/K6`0M7Ad07YjNP1k
Ng/0Q8B408N7Q`2>SXh0Vi^K0:RXZ0020:n_[`040;>c/`2e]KD0];Bd0;6a/@80Zj^[0140XJ6Q09RH
V029RHT0Ng]k06IVIP1;Bd/0DU9B061PH01WIfL0M7Ad0861P@2:RXX0TY:B09bLW02PX:00Z:RX0:BT
Y0030:j^[P060:n_[`2`/;00[jn_0;>c/`2b/[80/k>c0P2f][H00`2g]kL0^KVi0;Rh^0020;>c/`0>
0;6a/@2/[:`0YjNW0:6QX@2EUID0FUYJ04e=C@1kNg/0OWin07MgM`1XJ6P0G5aL04a<C00d=3@202TY
:@0A02PX:00h>3P0<c<c034a<@0`<300=CDe02l_;`0/;2`0;Bd]030`<00c<c<0:2PX03@d=00];Bd0
>c/k03Xj>P0c<c<00P0Z:RX0200i>CT0<30`03Hf=P11@D40=cLg030`<00];Bd0;Rh^0P0d=3@06P0]
;Bd0:RXZ030`<00a<C40<c<c03`l?012@T80D51@0410@014A4@0E5AD0410@00[:b/0<S8b03@d=00h
>3P0D51@05]KF`1GEeL0F5QH038b<P0/;2`0;Rh^02l_;`0b<S80;Bd]0P0W9bL02@0T92@0=CDe04U9
B@1HF5P0Kfm_05UIF@14A4@0=3@d030`<00203@d=00D055AD@1RHV80;Bd]030`<00l?3`0>3Ph03Ti
>@1GEeL0KFe]061PH00f=SH0>SXj04A4A01SHf<0MWIf07inOP2;Rh/0GUiN03Lg=`15ADD205=CD`0F
05eMG@1]KFd0J6QX051@D00k>c/0;2`/02h^;P0e=CD0;Rh^02`/;00`<300:RXZ02l_;`0/;2`0:b/[
02d];@0b<S80:RXZ02TY:@0[:b/09bLW02PX:0809BDU00X0;bl_02DU9@0_;bl0@D51034a<@0c<c<0
?Cdm04Y:BP1=CDd0D51@0P1?Cdl03`1QHF40I6AT06IVIP1XJ6P0HV9R06a/K01]KFd0MgMg07AdM01b
LW80IVIV05MGE`0h>3P09bLW02<S8`0202LW9`0H020P800W9bL0<c<c04U9B@1GEeL0Fe]K06EUI@1X
J6P0Jf][07=cL`1jNWX0OWin07]kN`1lO7`0Ph>30861P@1lO7`0PX:208>3P`26QXH0PX:208F5Q@28
R8P0RHV90P27QhL01@26QXH0R8R8092@T02=SHd0RXZ:00<0Rh^;00P0SXj>08N7Q`2;Rh/0RXZ:08b<
S02;Rh/0RHV908^;R`80S8b<0100SHf=08Z:RP2;Rh/0S8b<08j>SP2=SHd0Ti>C09BDU02ATI40Shn?
096AT@2<S8`0TI6A08Z:RP2?Shl0T92@0P2BTY801@2?Shl0T92@08j>SP2:RXX0SHf=0080S8b<00H0
Shn?09>CT`2<S8`0Shn?08R8R029RHT208f=S@0608j>SP2;Rh/0RHV9096AT@2;Rh/0SHf=102;Rh/0
1028R8P0QHF508V9R@2?Shl2092@T00609:BTP2?Shl0Shn?096AT@2CTi<0TI6A0P2CTi<02@2BTY80
Ti>C09RHV02JVYX0V9RH09ZJVP2KVi/0V9RH09jNWP020::RXP080:>SX`2RXZ80Xj>S0::RXP2WYjL0
ZJVY0:NWY`2/[:`20:VYZ@060:RXZ02/[:`0[jn_0:j^[P2a/K40^;Rh0P2i^KT02P2m_Kd0_kno0;no
_`30`<00`/;20<?3``35aLD0b<S80<W9b@38b<P20<_;b`0;0<g=c@3?cll0d=3@0=;BdP3@d=00d];B
0=?Cd`3Fe]H0dm?C0=KFeP3De=@00P3Cdm<0103De=@0emOG0=GEe@3Jf]X20=SHf00:0=CDe02a/K40
JVYZ04];B`1DE5@0EUIF05eMG@1KFe/0H61P06MWI`80Hf=S0100IfMW06][J`1ZJVX0Jf][06MWI`1Y
JFT0KVi^06MWI`1UIFD0H61P065QH@1LG5`0IfMW06ATI01SHf<0Fe]K0P1LG5`05P1KFe/0De=C051@
D01@D500Cdm?055AD@1>CTh0BDU904e=C@1;Bd/0ATI604i>CP1;Bd/0BTY:051@D01GEeL0Jf][08>3
P`2RXZ80][Jf0<O7a`3<c<`20=7Ad@0B0=;BdP3De=@0cLg=0<S8b02o_kl0^[Zj0;2`/02PX:00U9BD
09:BTP23Ph<0LW9b05YJFP1;Bd/0BDU904E5A@0l?3`0=cLg0P0f=SH00`0e=CD0A4A403lo?`0204E5
A@80B4Q800h0BDU904=3@`12@T80?3`l04Q8B01=CDd0DE5A059BDP1HF5P0Hf=S06YZJP1]KFd0Kfm_
06IVIP<0IFEU01H0HF5Q05EEE@1EEED0C4a<05=CD`1:BTX0B4Q804a<C01;Bd/0CDe=04a<C01?Cdl0
DE5A05YJFP1RHV80KVi^06UYJ@1`L700Lg=c071`L01_Kfl0Jf][0P1VIVH04P1NGUh0FUYJ05iNGP1N
GUh0FUYJ059BDP1?Cdl0Bd];04a<C013@d<0@41003`l?011@D40@T9204U9B@11@D40?3`l03/k>`h0
b>3H000<0<SPf080DU9B00D0F5QH05UIF@1PH600H61P065QH@0206UYJ@0;06e]K@1eMGD0NGUi08F5
Q@26QXH0Shn?09fMW@2YZJT0[Zj^0;:b/P2c/k<00P2f][H04@2d];@0/k>c0:b/[02VYZH0V9RH08N7
Q`1iNGT0IFEU04Y:BP1=CDd0H61P06IVIP1dM7@0OWin08Z:RP2DU9@0WIfM0080YjNW00<0Z:RX0:^[
Z`2[Zj/00`2a/K40102`/;00/K6a0;2`/02b/[820;Bd]00P0;Fe]@2h^;P0^;Rh0;>c/`2a/K40[Zj^
0:f][@2[Zj/0XJ6Q092@T01FEUH0Cdm?075aL@1oOgl0MWIf06e]K@1IFET0De=C03lo?`0];Bd09bLW
02d];@11@D40;bl_02/[:`0];Bd0<c<c03Xj>P0_;bl0<30`02d];@0d=3@202h^;P0402l_;`0a<C40
=SHf030`<080:b/[00X0<S8b02h^;P0d=3@0@D5103`l?00i>CT0<30`038b<P0];Bd0=CDe0P0`<300
5@0b<S80<c<c03De=@0^;Rh0=cLg04i>CP0k>c/0?3`l04E5A@0g=cL0<C4a02`/;00c<c<0=3@d04];
B`1ADE40FUYJ05EEE@0];Bd0:2PX03@d=00203Lg=`0Y02PX:00Q8B408B4Q02TY:@0l?3`0@41005QH
F01QHF40AdM702l_;`0/;2`0<30`03Lg=`0o?cl0GUiN04a<C00/;2`0>SXj02l_;`0^;Rh0@41005eM
G@1^KVh0Bd];030`<00h>3P0@41006MWI`1MGEd0J6QX07moO`1@D500@T9205EEE@1VIVH0NGUi09JF
UP2KVi/0Lg=c0410@00b<S800P0c<c<0400`<300;bl_02l_;`0];Bd0<S8b030`<00_;bl0<S8b034a
<@0^;Rh0:RXZ02LW9`0[:b/0;2`/02XZ:P0W9bL202TY:@0>02XZ:P0b<S80;Bd]02d];@0_;bl0>3Ph
03Xj>P19BDT0Bd];04E5A@1=CDd0DE5A05iNGP1WIfL206EUI@0:06i^KP1aLG40NGUi07UiN@1gMgL0
L71`075aL@1WIfL0CTi>02XZ:P80:BTY01h08B4Q02LW9`0[:b/0<S8b0410@01<C4`0DU9B06ATI01U
IFD0LW9b07UiN@1mOGd0OWin07]kN`1lO7`0OWin07emO@21PH40QHF508B4Q020P800Ph>308V9R@24
Q8@0R8R808F5Q@22PX80RHV908j>SP2:RXX208^;R`80S8b<00T0RXZ:08R8R028R8P0Rh^;08b<S025
QHD0Rh^;08n?S`2;Rh/00P2:RXX02`2<S8`0RHV908^;R`2;Rh/0TI6A09:BTP2@T900Ti>C08b<S02?
Shl0Rh^;0080S8b<0P2?Shl0502@T900TI6A08j>SP2CTi<0SHf=08n?S`2<S8`0SXj>092@T02>SXh0
T92@08V9R@2;Rh/0RXZ:08^;R`29RHT0RXZ:08n?S`2;Rh/0RXZ:0P2?Shl208^;R`80T92@00@0SXj>
08f=S@2:RXX0Rh^;0`2@T9001P2DU9@0Ti>C096AT@2@T900Ti>C092@T080Ti>C0100U9BD09JFUP2H
V9P0VIVI09RHV02IVIT0WYjN09fMW@2OWil0XJ6Q0:>SX`2OWil0Y:BT0:NWY`2PX:00XZ:R0P2UYJD0
1@2YZJT0[:b/0;2`/02][Jd0[Zj^0080/K6a00H0/k>c0;Jf]P2i^KT0^k^k0;no_`2n_[h20;no_`03
0<;2`P35aLD0a/K60080b<S800X0b/[:0<c<c03=cLd0cLg=0<k>cP3@d=00d];B0=7Ad@3De=@0e]KF
0P3Cdm<0203Fe]H0eMGE0=CDe03Bd]80e=CD0=SHf03GemL0f=SH0P3GemL02P3>c/h0WinO065QH@1A
DE40E5AD05=CD`1KFe/0HF5Q05iNGP1WIfL206IVIP0906UYJ@1]KFd0K6a/06m_K`1YJFT0J6QX06UY
J@1WIfL0K6a/0080GEeM01h0HF5Q06EUI@1NGUh0HV9R05iNGP1IFET0HF5Q05EEE@1DE5@0DU9B04];
B`18B4P0E5AD04Y:BP18B4P0ATI604=3@`12@T80A4A404a<C01:BTX0Bd];04m?C`1PH600P82009nO
W`2f][H0a<C40<_;b`3>c/h30<o?c`0A0<[:bP36a/H0`l?30;Rh^02e]KD0[jn_0:NWY`2QXJ40V9RH
08^;R`1dM7@0H61P05ADE01;Bd/0>SXj03Hf=P0b<S800P0d=3@0200i>CT0=SHf0410@010@400@T92
04Y:BP1<C4`0?Shn1011@D402@1<C4`0E5AD05QHF01OGel0HF5Q06i^KP1YJFT0J6QX06UYJ@0206MW
I`0B05aLG01HF5P0FUYJ04e=C@1@D500Cdm?04Y:BP1CDe<0C4a<04e=C@1<C4`0DU9B04i>CP1ADE40
FEUI06EUI@1RHV80K6a/0P1bLW801@1eMGD0Kfm_06QXJ01UIFD0HF5Q0080GUiN00D0HV9R05IFEP1I
FET0DE5A04U9B@0204A4A00803hn?P0d=3@0?clo03dm?@14A4@0BTY:04M7A`15ADD>0<SPf0003038
h=P205IFEP0X05iNGP1JFUX0EeMG069RHP1SHf<0HV9R06EUI@1/K6`0KVi^07EeM@23Ph<0RXZ:08b<
S02PX:00YjNW0:ZZZP2_[jl0];Bd0;Fe]@2g]kL0][Jf0;>c/`2`/;00ZZZZ09NGU`29RHT0MgMg05iN
GP18B4P0FEUI05aLG01VIVH0M7Ad08>3P`2;Rh/0Ti>C09ZJVP2WYjL0ZZZZ0:VYZ@80[Jf]00T0/[:b
0:n_[`2_[jl0/[:b0;Bd]02c/k<0/K6a0;Fe]@2b/[800`2h^;P04@2e]KD0/k>c0;6a/@2][Jd0YjNW
0:JVYP2;Rh/0G5aL05UIF@1_Kfl0Ng]k07QhN01aLG40Fe]K05QHF01:BTX0;2`/00<0;Rh^03D0>CTi
030`<00];Bd0:b/[030`<00^;Rh0<C4a02/[:`0b<S80>CTi02l_;`0^;Rh0<S8b02d];@0`<300;Bd]
038b<P0f=SH0<S8b03Lg=`11@D40>c/k02h^;P0/;2`0>SXj03<c<`0g=cL0=SHf030`<00_;bl0:RXZ
02`/;00[:b/0<S8b03`l?00k>c/0?clo04A4A00i>CT0=SHf03Ti>@0_;bl0;Rh^04I6AP18B4P0DU9B
05=CD`0e=CD0<C4a038b<P0g=cL0<C4a02/[:`0202DU9@0<02l_;`13@d<0>c/k05EEE@1;Bd/0>3Ph
02XZ:P0^;Rh0;bl_03Ph>019BDT0F5QH0P0c<c<09`0k>c/0;bl_03De=@17AdL0J6QX05]KF`0g=cL0
<30`04E5A@1CDe<0FEUI04E5A@1=CDd0MgMg04M7A`18B4P0I6AT07QhN029RHT0SXj>08:2PP1[Jf/0
=3@d02/[:`0/;2`0;bl_034a<@0f=SH0;Bd]02`/;00Y:BT0<C4a02/[:`0_;bl0=cLg02/[:`0Z:RX0
:b/[02l_;`0202`/;00I02TY:@0T92@08R8R024Q8@0Y:BT0:b/[02`/;00c<c<0=CDe03Hf=P12@T80
Cdm?04a<C017AdL0ATI605IFEP1OGel0Hf=S06QXJ01YJFT0KVi^07MgM`1iNGT0MWIf07=cL`0207Ee
M@0E079bLP1IFET0>SXj03Xj>P0/;2`08B4Q02<S8`0Z:RX0<S8b03dm?@1<C4`0G5aL06=SH`1XJ6P0
M7Ad07QhN01lO7`0OGem07alO023Ph<0P82000<0QHF501d0P82008F5Q@29RHT0R8R808N7Q`2<S8`0
RHV908R8R02@T900S8b<08J6QP2=SHd0Rh^;08n?S`2<S8`0QhN708Z:RP2;Rh/0S8b<08>3P`2<S8`0
Shn?08^;R`29RHT0Rh^;08Z:RP2;Rh/0RHV908b<S002092@T00<09FEU@2BTY80TY:B08n?S`2=SHd0
Rh^;092@T02BTY80Shn?09FEU@2>SXh0RXZ:0P2>SXh02P2=SHd0Shn?08f=S@2;Rh/0SXj>08^;R`2:
RXX0RHV908^;R`25QHD208^;R`0308j>SP28R8P0S8b<0080SXj>0180S8b<08f=S@2>SXh0SXj>096A
T@2;Rh/0S8b<08^;R`2=SHd0TY:B096AT@2>SXh0T92@096AT@2BTY80TI6A09:BTP2EUID209>CT`04
09RHV02FUYH0V9RH09fMW@80Vi^K00@0VYZJ0:6QX@2TY:@0X:2P0P2VYZH07@2WYjL0XZ:R0:BTY02V
YZH0Z:RX0:VYZ@2_[jl0];Bd0:j^[P2a/K40];Bd0;>c/`2f][H0]kNg0;Vi^@30`<00_kno0;jn_P33
`l<0`L710<?3``36a/H0b<S80<W9b@3;bl/0c<c<0<k>cP3@d=00clo?0080c/k>01X0d];B0=CDe03D
e=@0eMGE0=KFeP3De=@0dm?C0=KFeP3Cdm<0dM7A0=GEe@3Fe]H0emOG0=WIf@3Jf]X0e=CD0<S8b029
RHT0Cdm?055AD@1FEUH0F5QH05UIF@1LG5`0IFEU06MWI`80JVYZ00D0KVi^075aL@1aLG40K6a/06e]
K@0306QXJ00906MWI`1SHf<0HV9R069RHP1OGel0G5aL05mOG`1GEeL0EEEE0080EeMG00<0D51@04e=
C@1<C4`00P1;Bd/04P13@d<0@T920451@@0o?cl0=3@d03/k>`0f=SH0>SXj03hn?P19BDT0FUYJ0820
P02PX:00]kNg0<;2`P38b<P0b/[:0<_;b`80bLW901L0b<S80<71`@33`l<0_[jn0;^k^`2o_kl0];Bd
0;6a/@2YZJT0X:2P08n?S`1fMWH0JFUY04m?C`15ADD0@410038b<P0d=3@0=SHf03Ti>@0e=CD0>SXj
0410@00204E5A@0?04a<C015ADD0@D5104=3@`12@T80B4Q804M7A`1GEeL0EEEE069RHP1PH600HV9R
06IVIP1XJ6P0IfMW0080IVIV00P0HF5Q05eMG@1MGEd0EeMG05ADE01:BTX0ATI6051@D080Bd];00L0
CTi>059BDP1DE5@0DU9B05EEE@1JFUX0H61P0080J6QX00X0K6a/079bLP1eMGD0K6a/06UYJ@1QHF40
GUiN05aLG01OGel0EUIF0P1BDU802`1<C4`0D51@04A4A015ADD0?Cdm03Xj>P0l?3`0AdM704Q8B017
AdL0ATI600h0b>3H000<0<SPf080EUIF02P0Fe]K05iNGP1KFe/0FEUI05]KF`1RHV80Hf=S06IVIP1^
KVh0LW9b07]kN`24Q8@0SHf=09fMW@2TY:@0[:b/0:j^[P2c/k<0][Jf0;Rh^02g]kL0];Bd0:j^[P2U
YJD0U9BD08R8R01gMgL0GEeM04M7A`1ADE40H61P06MWI`1dM7@0P82008^;R`2FUYH0WIfM0:>SX`2V
YZH0Zj^[0P2^[Zh09@2b/[80/;2`0;2`/02a/K40]KFe0:j^[P2b/[80/K6a0;:b/P2d];@0^KVi0;Rh
^02g]kL0/[:b0;2`/02^[Zh0ZJVY0:6QX@28R8P0I6AT06i^KP1VIVH0M7Ad07]kN`1fMWH0FUYJ05QH
F01ADE40=3@d03Lg=`0^;Rh0<c<c03Ti>@0];Bd0:BTY02d];@0b<S800P0^;Rh0:`0d=3@0<C4a030`
<00];Bd0;Rh^034a<@0W9bL0<c<c02/[:`0^;Rh0=3@d03De=@0f=SH0@D5103`l?00d=3@0<S8b030`
<00c<c<0;bl_034a<@0`<300:RXZ030`<00[:b/0<30`03<c<`0j>SX0B4Q804I6AP1BDU80>c/k034a
<@0j>SX0=cLg038b<P0n?Sh0@D5104I6AP10@400;Bd]02PX:00`<3000P0a<C40;P0U9BD09RHV02HV
9P0f=SH0>CTi03lo?`16ATH0>SXj02DU9@0];Bd0<S8b03Xj>P11@D40BDU904Y:BP0/;2`0=SHf038b
<P0a<C40?clo04=3@`1FEUH0>SXj03/k>`11@D40BTY:05EEE@0j>SX0>c/k04Q8B01cLg<0C4a<06QX
J026QXH0S8b<07]kN`1hN7P0Ng]k03hn?P0d=3@0<30`02XZ:P0`<300<C4a03<c<`0_;bl203<c<`0W
02TY:@0^;Rh0=SHf03De=@0Y:BT0:b/[02HV9P0b<S80:BTY02PX:00V9RH08R8R024Q8@0V9RH09bLW
034a<@0b<S80=CDe02h^;P0f=SH0?3`l04Q8B019BDT0Bd];05ADE01JFUX0F5QH05]KF`1YJFT0JVYZ
071`L01aLG40OGem07UiN@1gMgL0N7Qh07=cL`1eMGD0Kfm_0080Fe]K0180?Shn02l_;`0S8b<08R8R
024Q8@0Z:RX0=3@d04m?C`1GEeL0IVIV06][J`1eMGD0OWin07moO`21PH40P82007moO`23Ph<208:2
PP80QHF500@0R8R808N7Q`26QXH0S8b<0P27QhL03`29RHT0RXZ:08b<S02;Rh/0QXJ608f=S@2>SXh0
RHV908f=S@2;Rh/0S8b<08V9R@2;Rh/0SHf=08Z:RP0308^;R`0K08R8R029RHT0SHf=096AT@2=SHd0
UIFE092@T02>SXh0S8b<08Z:RP2;Rh/0SXj>092@T02=SHd0Ti>C092@T02<S8`0RHV908^;R`2<S8`0
SXj>08n?S`29RHT0Rh^;08Z:RP27QhL0S8b<0080R8R800T0QXJ608^;R`2=SHd0S8b<08Z:RP2@T900
S8b<08j>SP2ATI400`2>SXh208^;R`0908Z:RP2?Shl0SXj>096AT@2@T900TI6A08n?S`2CTi<0UIFE
0080V9RH00<0Ti>C09BDU02EUID00P2IVIT00`2MWId0VYZJ09jNWP020:2PX0070:6QX@2PX:00YJFU
0:>SX`2VYZH0X:2P0:>SX`020:RXZ00C0:f][@2`/;00/K6a0:j^[P2c/k<0^k^k0;Ng]`2i^KT0^;Rh
0;Vi^@2m_Kd0`L710<30`02o_kl0`/;20<C4a038b<P0bl_;0<S8b0020<c<c080c/k>00<0clo?0=;B
dP3?cll00P3AdM420=;BdP0F0=GEe@3De=@0eMGE0=KFeP3Bd]80d=3@0=?Cd`3Fe]H0fMWI0=[JfP3H
f=P0e=CD0;Jf]P1[Jf/0CDe=05=CD`1FEUH0GUiN061PH01XJ6P0JVYZ06i^KP80JFUY01/0KVi^06e]
K@1[Jf/0K6a/06QXJ01UIFD0J6QX069RHP1[Jf/0Hf=S05iNGP1SHf<0GUiN05aLG01NGUh0F5QH059B
DP1EEED0F5QH05EEE@1=CDd0ATI604M7A`11@D40?Shn03/k>`0f=SH00P0d=3@0800];Bd0<30`03Lg
=`0h>3P0BTY:06=SH`25QHD0XJ6Q0;Fe]@34a<@0b/[:0<_;b`3:b/X0alO70<K6aP32`/80`<300;no
_`2n_[h0`/;20<K6aP2o_kl0`L710;bl_02^[Zh0YJFU092@T01iNGT0F5QH04E5A@0n?Sh0=SHf0P0c
<c<203@d=00;03De=@0f=SH0@D5104M7A`1<C4`0@d=304a<C012@T80@D5104E5A@14A4@00P1>CTh0
101DE5@0FUYJ05eMG@1SHf<206][J`80K6a/00T0GemO06=SH`1VIVH0De=C055AD@1<C4`0Bd];04a<
C01@D5000P1BDU802P1=CDd0C4a<059BDP1@D500EUIF05YJFP1SHf<0Jf][06a/K01bLW8207=cL`0C
06QXJ01WIfL0J6QX06EUI@1KFe/0EUIF05ADE01ADE40DU9B05=CD`19BDT0ADE503Ti>@0j>SX0?Shn
0410@00n?Sh0@d=30410@00>0<SPf0003038h=P205ADE080FEUI00l0FUYJ05EEE@1JFUX0Fe]K06AT
I01RHV80I6AT06a/K01kNg/0Q8B408f=S@2MWId0YJFU0:^[Z`2`/;000`2g]kL0502f][H0];Bd0:j^
[P2TY:@0UIFE08>3P`1cLg<0FUYJ04E5A@1BDU80HV9R06IVIP1aLG40P82008f=S@2FUYH0Vi^K0:>S
X`2YZJT0Zj^[0P2`/;020;:b/P0K0;6a/@2b/[80/k>c0;:b/P2a/K40/;2`0;6a/@2f][H0]kNg0;Vi
^@2f][H0/[:b0:n_[`2ZZZX0YZJV0:2PX026QXH0IVIV06e]K@1RHV80LW9b07alO01fMWH0Fe]K05IF
EP1BDU80?Shn0080;Bd]00P0:RXZ03@d=00d=3@0<S8b02l_;`0/;2`0:b/[02h^;P80<C4a00<0=CDe
03Hf=P0/;2`00P0];Bd07@0`<300:RXZ02/[:`0h>3P0=cLg03@d=013@d<0?clo034a<@0d=3@0<S8b
03<c<`0Z:RX0;Bd]02XZ:P0^;Rh0>c/k034a<@0b<S80;bl_03Ti>@0o?cl0@T9204i>CP0l?3`0=3@d
0492@P0g=cL0<C4a0080?3`l00P0>c/k03Ti>@0Z:RX0:b/[02l_;`0];Bd0<S8b02XZ:P80;2`/0140
=SHf0451@@10@400=cLg038b<P0S8b<0<30`03dm?@1;Bd/0>c/k04Y:BP11@D40?Cdm03`l?00f=SH0
>SXj0492@P020451@@0H03Ti>@0n?Sh0AdM704m?C`0n?Sh0ATI604Y:BP1TI6@0P82007EeM@2>SXh0
UiNG0820P01NGUh0HV9R07MgM`1HF5P0C4a<0451@@0c<c<0;bl_03<c<`0e=CD0;bl_0P0[:b/02P0Z
:RX0:b/[02PX:00^;Rh0;Bd]02PX:00];Bd0<30`034a<@0X:2P2028R8P0602@T900S8b<09BDU02XZ
:P0];Bd0=SHf0P0^;Rh04`0d=3@0>SXj04E5A@19BDT0CDe=051@D01CDe<0E5AD06a/K01[Jf/0JVYZ
07AdM01jNWX0OGem07=cL`1fMWH0LG5a07UiN@1dM7@00P1eMGD0101VIVH0?Shn02XZ:P0T92@202<S
8`0=02`/;00m?Cd0C4a<05IFEP1UIFD0Kfm_07]kN`1oOgl0OGem07inOP21PH40PX:208J6QP0308F5
Q@0608R8R027QhL0QXJ608Z:RP26QXH0QHF50P2;Rh/01P2:RXX0Rh^;08f=S@2<S8`0R8R808^;R`80
RXZ:00l0RHV908n?S`2=SHd0T92@08Z:RP2CTi<0QhN7092@T02>SXh0SHf=092@T02?Shl0SHf=092@
T02?Shl00P2@T9001`2?Shl0SHf=08n?S`2CTi<0Shn?09:BTP2@T9000P2;Rh/0202@T900SHf=08n?
S`2=SHd0RXZ:08R8R02:RXX0Rh^;0`29RHT02@26QXH0Rh^;08b<S02:RXX0RHV908b<S02>SXh0S8b<
08f=S@0208R8R00308b<S02:RXX0RXZ:0080SXj>01H0TI6A09>CT`2@T900U9BD096AT@2BTY80UIFE
09RHV02IVIT0UIFE09VIV@2HV9P0UYJF09RHV02MWId0W9bL09jNWP2OWil0XJ6Q0:>SX`2RXZ80WinO
0`2TY:@05P2UYJD0YjNW0:RXZ02ZZZX0[:b/0;2`/02_[jl0/k>c0;Vi^@2g]kL0][Jf0;fm_@2k^k/0
_kno0<71`@32`/80`L710<G5a@34a<@0alO70<_;b`39bLT20<_;b`060<o?c`3@d=00clo?0=7Ad@3?
cll0d=3@0P3AdM402P3EeMD0e=CD0=KFeP3GemL0eMGE0=CDe03Cdm<0eMGE0=SHf03Fe]H20=SHf00;
0=3@d02RXZ80HV9R04Y:BP1ADE40F5QH05iNGP1OGel0IVIV06][J`1VIVH00P1^KVh206][J`80KFe]
00@0L71`06][J`1[Jf/0J6QX0P1SHf<05@1KFe/0I6AT05]KF`1OGel0FEUI05EEE@1>CTh0D51@059B
DP1@D500BTY:04Q8B00o?cl0ATI603/k>`0e=CD0<c<c02h^;P0/;2`0=CDe034a<@0203Ti>@0704M7
A`1/K6`0T92@0:NWY`2i^KT0`/;20<S8b0020<_;b`030<K6aP2k^k/0_;bl0080^KVi00<0^[Zj0<G5
a@3;bl/00P38b<P08036a/H0a<C40;Fe]@2SXj<0UIFE07MgM`1JFUX0@D5103/k>`0h>3P0=cLg03De
=@0a<C40=SHf03Lg=`0k>c/0ADE504I6AP17AdL0D51@04i>CP16ATH0@d=30451@@16ATH0CDe=04U9
B@1DE5@0F5QH065QH@1[Jf/0JVYZ0P1[Jf/0201YJFT0HV9R05aLG01HF5P0DE5A04a<C018B4P0CDe=
0P1:BTX01`1?Cdl0BTY:04];B`1?Cdl0E5AD05MGE`1NGUh00P1SHf<0301UIFD0Jf][079bLP1`L700
M7Ad06YZJP1RHV80GemO05iNGP1DE5@0De=C05ADE080EUIF00T0DE5A04e=C@0o?cl0?3`l03/k>`0i
>CT0>c/k04A4A012@T803P38h=P000`0b>3H0P1IFET0:01JFUX0H61P05eMG@1LG5`0FUYJ05]KF`1V
IVH0HV9R05eMG@1XJ6P0MgMg07YjNP28R8P0VIVI0:FUY@2ZZZX0/[:b0;Fe]@2g]kL0^;Rh0;Bd]02^
[Zh0Zj^[0:>SX`2EUID0P820071`L01DE5@0Bd];05MGE`1RHV80IFEU07=cL`23Ph<0Shn?09JFUP2L
W9`0X:2P0:FUY@2XZ:P20:b/[00O0;2`/02a/K40];Bd0;>c/`2`/;00/K6a0:j^[P2b/[80/;2`0;Fe
]@2i^KT0^[Zj0;Ng]`2b/[80[Zj^0:RXZ02VYZH0XJ6Q08N7Q`1bLW80L71`065QH@1`L700OGem07al
O01SHf<0GEeM05]KF`0i>CT0;Bd]02`/;00202PX:00903Hf=P0/;2`0<S8b03hn?P0b<S80;bl_03<c
<`0d=3@0<30`0080;2`/0P0c<c<00`0`<300<C4a038b<P02030`<00502d];@0c<c<0<c<c034a<@0c
<c<00P0a<C406`0c<c<0<30`038b<P0b<S80A4A40451@@0h>3P0:b/[02l_;`0n?Sh0BDU9051@D00k
>c/0?clo04U9B@0l?3`0?Shn0451@@12@T80:RXZ02`/;00_;bl0<30`02TY:@0Z:RX0;2`/02TY:@02
034a<@0A03Ph>00i>CT0=cLg02`/;00X:2P09bLW03/k>`1@D500ATI603De=@17AdL0?Cdm03Lg=`0l
?3`0=3@d02l_;`0/;2`00P0e=CD07`14A4@0@41004=3@`16ATH0Fe]K07AdM01nOWh0Rh^;09RHV02M
WId0Ti>C08J6QP1UIFD0AdM705QHF01WIfL0Ogmo0820P01hN7P0Bd];038b<P0];Bd0=CDe03Hf=P0]
;Bd0<C4a02HV9P0_;bl0:b/[02XZ:P0/;2`00`0[:b/01P0Z:RX0;bl_02PX:00T92@09BDU02PX:080
8b<S00L0:BTY034a<@0_;bl0;bl_034a<@0g=cL0?clo00<0CDe=00d0Bd];059BDP1NGUh0J6QX06MW
I`1eMGD0Lg=c07AdM01`L700OWin07IfMP1eMGD0MgMg0080NWYj00P0MgMg069RHP1;Bd/0:RXZ02PX
:00T92@0:RXZ02d];@80CTi>0100FUYJ06=SH`1dM7@0NWYj0861P@1nOWh0Ogmo0820P025QHD0P820
08R8R025QHD0QhN708B4Q02:RXX0QhN70P29RHT01@2:RXX0S8b<08^;R`2;Rh/0Shn?00<0Rh^;00<0
QhN708^;R`29RHT00P2;Rh/03`2>SXh0R8R808j>SP2>SXh0S8b<08j>SP2<S8`0TI6A08j>SP2ATI40
Shn?08f=S@2?Shl0TI6A08j>SP02092@T00<096AT@2?Shl0Shn?08b<S02;Rh/0SXj>08f=S@2;Rh/0
Shn?08R8R02?Shl0RXZ:0P2;Rh/01@29RHT0QhN708R8R026QXH0RHV90080RXZ:00D0RHV908b<S02>
SXh0SXj>08V9R@0208^;R`0308N7Q`2?Shl0Rh^;0080Shn?00H0Rh^;092@T02FUYH0T92@09>CT`2@
T90209JFUP<0UiNG00H0UYJF09bLW02KVi/0Vi^K09VIV@2MWId20:2PX00809nOW`2RXZ80YJFU0:JV
YP2YZJT0Z:RX0:ZZZP2XZ:P20:VYZ@<0[Zj^00@0/K6a0;Jf]P2j^[X0_;bl0P2n_[h01`33`l<0`L71
0<G5a@38b<P0a/K60<C4a039bLT00P3;bl/02@3<c<`0cLg=0=3@d03AdM40c/k>0<g=c@3?cll0d];B
0=3@d0030=CDe0040=KFeP3EeMD0eMGE0=GEe@<0emOG00`0fMWI0=SHf03Fe]H0b<S808^;R`1=CDd0
D51@05EEE@1JFUX0HV9R065QH@1YJFT206a/K080JVYZ00H0K6a/06i^KP1/K6`0K6a/06UYJ@1XJ6P2
069RHP0=061PH01ZJVX0GEeM05MGE`1JFUX0G5aL05]KF`1EEED0F5QH055AD@1:BTX0DU9B04];B`02
0492@P0F0410@00k>c/0;bl_02d];@0X:2P0;Bd]02XZ:P0Y:BT0:b/[02d];@1:BTX0L71`09FEU@2^
[Zh0_kno0<G5a@3:b/X0cLg=0<W9b@32`/80/k>c0:b/[080[Zj^0140^k^k0<?3``37alL0b/[:0<_;
b`3<c<`0b/[:0<30`02h^;P0[Jf]09BDU01eMGD0EEEE04M7A`0i>CT0=CDe03Hf=P0203De=@0B03Xj
>P0m?Cd0@d=303lo?`15ADD0DE5A05=CD`13@d<0@D5104E5A@13@d<0ADE504a<C01@D500De=C065Q
H@1RHV80IfMW0`1]KFd02P1^KVh0JVYZ061PH01HF5P0DE5A051@D01DE5@0CDe=051@D01<C4`204m?
C`0M04i>CP1?Cdl0F5QH05QHF01PH600HF5Q06QXJ01ZJVX0LW9b07EeM@1fMWH0IFEU069RHP1OGel0
H61P05UIF@1EEED0D51@05=CD`1?Cdl0E5AD04A4A011@D40?Shn03Ph>00l?3`0>c/k04E5A@13@d<0
3P38h=P000`0b>3H0P1OGel0:01MGEd0GUiN05QHF01EEED0De=C05YJFP1KFe/0EEEE05]KF`1XJ6P0
Lg=c07UiN@27QhL0VIVI0:BTY02YZJT0/[:b0;Jf]P2g]kL0^;Rh0;Bd]02c/k<0YJFU09nOW`2>SXh0
Ogmo06][J`1?Cdl0A4A4059BDP1GEeL0JFUY07IfMP26QXH0S8b<09JFUP2NWYh0Y:BT0:NWY`2[Zj/2
0:b/[0030;6a/@2_[jl0/;2`00D0/;2`01P0/[:b0;Fe]@2j^[X0^[Zj0;Rh^02a/K40[jn_0:^[Z`2X
Z:P0XZ:R08Z:RP1`L700O7al061PH01]KFd0PH6107YjNP1OGel0E5AD05IFEP0_;bl09bLW02HV9P0[
:b/2038b<P0902PX:00j>SX0@T9203hn?P0i>CT0?3`l03Ti>@0`<300>3Ph0080;Bd]02<0=3@d02`/
;00^;Rh0:b/[03De=@0`<300<S8b02d];@0d=3@0:RXZ03@d=00_;bl0>3Ph02/[:`0g=cL0>CTi03Hf
=P12@T80B4Q80492@P0b<S80=CDe03dm?@14A4@0CDe=03Ti>@0k>c/0A4A403/k>`10@400?Cdm030`
<00_;bl0:RXZ034a<@0202l_;`03034a<@0Z:RX0;Bd]0080=CDe0P0f=SH03P0/;2`09BDU02<S8`0f
=SH0C4a<04U9B@0e=CD0?Cdm04m?C`0k>c/0=CDe038b<P0a<C40:b/[0P0a<C406@0[:b/0A4A404A4
A013@d<0LG5a0861P@1mOGd0PX:20:6QX@2[Zj/0XJ6Q08F5Q@1cLg<0Fe]K06EUI@1DE5@0I6AT07Ad
M01iNGT0SHf=07EeM@0f=SH0;bl_02h^;P0e=CD00P0];Bd03`0Y:BT0;bl_02`/;00[:b/0:RXZ02`/
;00_;bl0<30`02/[:`0Y:BT0;Bd]02XZ:P0X:2P08b<S020P800302LW9`0E02TY:@0/;2`0:b/[034a
<@0n?Sh0BDU904m?C`18B4P0C4a<051@D01FEUH0HV9R06QXJ01bLW80Lg=c07IfMP1aLG40MgMg07=c
L`1gMgL0MGEe0080Ng]k01l0NWYj079bLP1VIVH0?Shn02`/;00Z:RX0:BTY0410@00^;Rh0>SXj051@
D01GEeL0IFEU07IfMP1jNWX0Ph>308:2PP23Ph<0QHF50861P@28R8P0Shn?08F5Q@29RHT0QXJ608F5
Q@26QXH0QHF508Z:RP28R8P0Shn?00<0SHf=00X0QhN708n?S`28R8P0RXZ:08V9R@2<S8`0Shn?08f=
S@2:RXX0SHf=0P2;Rh/02P26QXH0S8b<09:BTP2ATI40S8b<092@T02?Shl0SHf=08n?S`2=SHd208n?
S`0J08b<S02>SXh0T92@096AT@2;Rh/0S8b<08Z:RP29RHT0S8b<08R8R02@T900SHf=08V9R@2:RXX0
Rh^;08V9R@27QhL0S8b<08V9R@2=SHd0Rh^;08V9R@2;Rh/0SXj>096AT@29RHT208F5Q@0408^;R`2:
RXX0Rh^;08n?S`80TY:B00@0Shn?09BDU02CTi<0T92@0P2ATI400`2GUiL0V9RH09VIV@0209ZJVP06
09fMW@2KVi/0WIfM09^KV`2IVIT0WinO0P2RXZ802`2OWil0XJ6Q0:NWY`2/[:`0[Jf]0:ZZZP2XZ:P0
Zj^[0:f][@2^[Zh0/;2`0080]KFe00H0^;Rh0;bl_02n_[h0_[jn0;no_`31`L420<;2`P070<K6aP35
aLD0b<S80<K6aP39bLT0c<c<0<g=c@020<k>cP090=7Ad@3?cll0d=3@0=3@d03Bd]80d=3@0=;BdP3C
dm<0e]KF0080e=CD00@0emOG0=SHf03De=@0f=SH0P3IfMT01@3Jf]X0f=SH0<C4a01fMWH0Cdm?0080
E5AD00H0F5QH069RHP1XJ6P0JVYZ06e]K@1/K6`206IVIP80Jf][0P1/K6`0;`1UIFD0J6QX06QXJ01W
IfL0GUiN065QH@1NGUh0E5AD05YJFP1MGEd0EUIF05EEE@1>CTh0BTY:055AD@19BDT0A4A403dm?@0l
?3`0>c/k03De=@0_;bl0<30`02LW9`0];Bd09BDU02PX:00/;2`0:b/[04=3@`1/K6`0VIVI0;>c/`33
`l<0alO70<k>cP3=cLd0bl_;0<30`02][Jd0WIfM09jNWP2[Zj/0][Jf0<30`036a/H0c/k>00<0d=3@
01@0bLW90<C4a02l_;`0Y:BT08f=S@1dM7@0FEUI0492@P0f=SH0@41003Hf=P0e=CD0>c/k0451@@0o
?cl0BTY:04A4A01<C4`0BTY:04a<C0<0A4A400L0AdM70492@P1;Bd/0E5AD05QHF01SHf<0IVIV0080
JVYZ00H0Jf][06i^KP1VIVH0H61P05aLG01KFe/205EEE@80DU9B0200C4a<04e=C@1ADE40E5AD04i>
CP1FEUH0F5QH05UIF@1LG5`0Hf=S06][J`1eMGD0LG5a079bLP1_Kfl0JFUY06MWI`1SHf<0GemO05QH
F01BDU80C4a<04U9B@1?Cdl0B4Q804A4A00n?Sh0?3`l03Xj>P0i>CT0>c/k0492@Ph0b>3H000<0<SP
f080FUYJ02P0GEeM05QHF01HF5P0F5QH055AD@1CDe<0F5QH05MGE`1MGEd0HF5Q071`L01jNWX0RHV9
09ZJVP2WYjL0ZZZZ0;Bd]02i^KT0^;Rh0;Vi^@2g]kL0[Jf]0:VYZ@2JVYX0Rh^;07MgM`1TI6@0Bd];
04=3@`1:BTX0FUYJ06UYJ@1dM7@0QhN708b<S02GUiL0WinO0::RXP2XZ:P0Zj^[0P2`/;00102c/k<0
[Jf]0:n_[`2`/;020;6a/@080:n_[`2b/[80[Zj^0;Rh^02d];@0_;bl0;Fe]@2^[Zh20:f][@0@0:JV
YP2PX:00S8b<06m_K`1aLG40GEeM06a/K028R8P0QHF506][J`1MGEd0Bd];030`<00_;bl0;Bd]02DU
9@80<c<c02@0<S8b030`<00g=cL0=SHf03/k>`11@D40Cdm?03Hf=P0g=cL0<30`03<c<`0a<C40<c<c
02TY:@0[:b/0<30`03Lg=`0c<c<0=3@d03`l?00d=3@0=cLg02h^;P0];Bd0=3@d03`l?00e=CD0;bl_
03`l?015ADD0AdM703Xj>P0a<C40>c/k04=3@`18B4P203Ph>00703Lg=`0m?Cd0A4A40492@P0c<c<0
;Bd]02h^;P0402l_;`0h02LW9`0^;Rh0<c<c03<c<`0[:b/0;2`/02h^;P0W9bL0:2PX03De=@16ATH0
>CTi03@d=01=CDd0C4a<03dm?@0e=CD0:RXZ02l_;`0Y:BT0;2`/02TY:@0Z:RX0?Cdm04Q8B01/K6`0
RXZ:07IfMP23Ph<0Ti>C09FEU@2LW9`0Shn?07=cL`1YJFT0LG5a06UYJ@1SHf<0GEeM05MGE`1_Kfl0
OGem07IfMP0c<c<0:b/[034a<@0b<S80=3@d03De=@0a<C409RHV02d];@0Z:RX0:b/[02XZ:P0];Bd2
02HV9P0402@T900/;2`0:RXZ02@T90809BDU01D0<C4a030`<00`<300:RXZ02d];@0Z:RX0;Rh^03De
=@15ADD0D51@04i>CP1=CDd0Cdm?05]KF`1QHF40IFEU06i^KP1bLW80M7Ad07EeM@1jNWX00P1dM7@0
201eMGD0OGem07emO@1hN7P0M7Ad07QhN01PH600A4A40P0_;bl202PX:00=02/[:`0h>3P0C4a<05UI
F@1^KVh0NGUi07emO@20P800QXJ608:2PP1nOWh0Q8B408V9R@0208R8R00:08J6QP24Q8@0QHF508R8
R02:RXX0R8R808f=S@2>SXh0S8b<08R8R080Rh^;00L0QHF508^;R`2;Rh/0S8b<08Z:RP2=SHd0Rh^;
0080SHf=00D0RXZ:08^;R`2<S8`0Shn?09>CT`02092@T00>09>CT`2BTY80T92@08j>SP2<S8`0TY:B
08b<S02?Shl0TI6A09>CT`2=SHd0T92@08Z:RP29RHT208N7Q`0@08j>SP2:RXX0Rh^;08V9R@2=SHd0
R8R808^;R`2:RXX0R8R808V9R@28R8P0S8b<08Z:RP2<S8`0Shn?08V9R@80S8b<0P2;Rh/02`29RHT0
SXj>096AT@2>SXh0T92@09:BTP2DU9@0T92@096AT@2DU9@0UIFE00<0V9RH00h0Vi^K09jNWP2KVi/0
Vi^K09ZJVP2MWId0WYjN09nOW`2QXJ40Y:BT0:6QX@2UYJD0ZZZZ0:^[Z`80ZZZZ00X0[Zj^0:ZZZP2`
/;00];Bd0;Jf]P2b/[80]KFe0;Zj^P2l_;`0_[jn0P30`<003@33`l<0aLG50<O7a`35aLD0a/K60<O7
a`39bLT0b/[:0<g=c@3<c<`0cLg=0<k>cP3@d=000P3Bd]800`3Cdm<0d=3@0=3@d0020=CDe080eMGE
00D0f=SH0=KFeP3GemL0emOG0=SHf0020=[JfP050=CDe02`/;00IVIV055AD@1CDe<00P1NGUh01@1U
IFD0HF5Q06EUI@1/K6`0JFUY0080Jf][00P0JFUY071`L01XJ6P0KVi^06ATI01WIfL0I6AT069RHP80
GemO0180HF5Q05YJFP1KFe/0GUiN05QHF01FEUH0CDe=04Q8B019BDT0@D5103dm?@16ATH0>SXj030`
<00/;2`0;bl_02d];@0Z:RX202PX:00P02HV9P0T92@0:RXZ04A4A01/K6`0W9bL0;Vi^@37alL0cLg=
0<k>cP3@d=00cLg=0<71`@2/[:`0Vi^K09VIV@2QXJ40/;2`0<30`037alL0cLg=0=3@d03Cdm<0e=CD
0=;BdP3>c/h0`/;20;Jf]P2WYjL0SXj>071`L01ADE4203hn?P0303Lg=`0f=SH0?3`l0080=cLg00@0
@41004A4A018B4P0BDU90P1>CTh02@1=CDd0BDU904U9B@16ATH0BDU904Y:BP1BDU80G5aL05mOG`02
06MWI`0>06UYJ@1[Jf/0Lg=c06MWI`1RHV80GEeM05IFEP1DE5@0D51@04Y:BP1CDe<0E5AD05EEE@1A
DE42059BDP0905ADE01?Cdl0E5AD061PH01VIVH0Jf][06e]K@1dM7@0MGEe0080IVIV00l0H61P05UI
F@1JFUX0EUIF04m?C`1:BTX0D51@04e=C@15ADD0@41003`l?00n?Sh0>3Ph03Hf=P0l?3`03P38h=P0
00`0b>3H0P19BDT0901DE5@0EUIF051@D01DE5@0Cdm?05ADE01@D500CTi>05=CD`1JFUX0IVIV07Mg
M`28R8P0VIVI0:RXZ02/[:`0/k>c0;Ng]`2h^;P0_;bl0;Fe]@2a/K40ZZZZ09^KV`29RHT0NGUi069R
HP19BDT0@d=305=CD`1DE5@0J6QX07EeM@21PH40SXj>09>CT`80X:2P02@0YJFU0:f][@2_[jl0[jn_
0;6a/@2`/;00/[:b0;6a/@2_[jl0[Zj^0:f][@2_[jl0/K6a0;:b/P2i^KT0][Jf0;Rh^02`/;00[Jf]
0:b/[02WYjL0WIfM096AT@1/K6`0Kfm_06=SH`1OGel0QXJ608^;R`1bLW80BDU904E5A@0b<S80>3Ph
02h^;P0W9bL203De=@0c03Hf=P0/;2`0;Rh^03Lg=`0^;Rh0AdM704m?C`18B4P0?clo030`<00Z:RX0
:BTY02d];@0[:b/0;bl_02h^;P0d=3@0?clo03dm?@0f=SH0;Rh^02l_;`0g=cL0=CDe03@d=00o?cl0
?Shn03@d=00h>3P0?clo04E5A@0l?3`0=SHf03De=@11@D40Bd];03Ti>@0g=cL0CTi>03Lg=`13@d<0
?Shn038b<P0a<C40<30`02h^;P0_;bl0:RXZ02l_;`0Y:BT0=3@d0080<c<c00h0;2`/02LW9`0U9BD0
:b/[03@d=00l?3`0>3Ph02h^;P0f=SH0GEeM04I6AP0e=CD0?3`l03<c<`80<C4a0P0T92@0;P0c<c<0
CDe=06QXJ023Ph<0PH6107IfMP2ATI40SXj>08:2PP26QXH0N7Qh06QXJ01LG5`0GemO07YjNP1UIFD0
?clo05eMG@22PX80N7Qh06a/K00];Bd0:RXZ02/[:`0/;2`0<c<c03Ph>00];Bd0;Rh^03@d=00Y:BT0
<S8b02XZ:P0^;Rh0:BTY02d];@0X:2P0:BTY02PX:00_;bl09RHV02DU9@0T92@0:b/[02XZ:P0a<C42
02TY:@0B02d];@0^;Rh0?3`l04Y:BP1@D500Cdm?04e=C@1KFe/0F5QH06IVIP1XJ6P0LW9b07IfMP1a
LG40MgMg07IfMP1aLG40M7Ad0P1lO7`01`1gMgL0NWYj07AdM01dM7@0Hf=S04];B`0d=3@00P0/;2`0
200Y:BT0;2`/0451@@1CDe<0Hf=S075aL@1iNGT0PH610P24Q8@01020P800QHF508Z:RP27QhL208V9
R@0708B4Q026QXH0QXJ608Z:RP29RHT0Rh^;08j>SP0208Z:RP0808^;R`2=SHd0SHf=08V9R@2<S8`0
Shn?08Z:RP2;Rh/208b<S00708j>SP2=SHd0SHf=08^;R`2>SXh0Ti>C08f=S@05092@T00508n?S`2E
UID0SHf=08n?S`2ATI400`2>SXh00`29RHT0SHf=08V9R@0208^;R`0>08N7Q`29RHT0SHf=08N7Q`2;
Rh/0RHV908R8R02<S8`0SXj>08V9R@2=SHd0R8R8092@T029RHT408^;R`0@08b<S02=SHd0SHf=09:B
TP2CTi<0T92@09>CT`2BTY80TI6A09:BTP2DU9@0UiNG09bLW02MWId0Vi^K09ZJVP80WIfM01L0Vi^K
09bLW02NWYh0W9bL09nOW`2TY:@0XZ:R0:NWY`2UYJD0YjNW0:VYZ@2`/;00[Zj^0:f][@2/[:`0/[:b
0;Bd]02g]kL0/[:b0;Rh^02g]kL0_;bl0;no_`020<;2`P080<C4a033`l<0aLG50<?3``39bLT0b<S8
0<_;b`3:b/X30<o?c`040=3@d03AdM40d];B0=?Cd`80dM7A00H0eMGE0=CDe03De=@0e]KF0=OGe`3H
f=P20=KFeP070=SHf03IfMT0fm_K0=SHf03=cLd0UiNG05QHF00205IFEP0605]KF`1PH600IFEU069R
HP1XJ6P0KFe]0`1YJFT01@1/K6`0KFe]06UYJ@1_Kfl0I6AT0080IFEU00L0H61P06EUI@1RHV80FUYJ
05EEE@1GEeL0EUIF00<0D51@00T0AdM704Y:BP0o?cl0>3Ph03Hf=P0a<C40:BTY02d];@0_;bl00P0/
;2`0300U9BD08b<S020P800T92@0;2`/04E5A@1cLg<0VIVI0;^k^`35aLD0cLg=0<k>cP80d=3@0280
aLG50;Bd]02JVYX0UiNG09bLW02^[Zh0_[jn0<O7a`3?cll0d];B0=GEe@3GemL0e=CD0=3@d03=cLd0
`/;20;Fe]@2LW9`0QhN7069RHP1;Bd/0BTY:0451@@0o?cl0=CDe038b<P0o?cl0?Cdm03lo?`18B4P0
BDU9051@D01=CDd0CTi>0P1@D5001P16ATH0A4A404a<C01<C4`0E5AD05UIF@80GUiN01l0IfMW06m_
K`1aLG40KVi^079bLP1IFET0Fe]K059BDP1JFUX0DE5A05EEE@1ADE40EUIF051@D01DE5@0EUIF059B
DP1GEeL0FEUI05eMG@1UIFD0IfMW06a/K01`L700LG5a06][J`1TI6@0H61P05IFEP1HF5P0EUIF0080
BDU900D0AdM704A4A00o?cl0?clo03/k>`0203@d=00303`l?00o?cl0b>3H00d0b>3H000<0<SPf080
>c/k00<0CDe=055AD@1>CTh00P1<C4`0301:BTX0ATI604Q8B016ATH0EUIF06MWI`1kNg/0Shn?09^K
V`2[Zj/0/[:b0;6a/@80]kNg01@0^;Rh0;Bd]02b/[80ZZZZ09ZJVP26QXH0Lg=c05YJFP15ADD0?3`l
04i>CP1JFUX0Jf][07IfMP21PH40SHf=09BDU02MWId0X:2P0:JVYP<0Zj^[01l0/[:b0;2`/02b/[80
/[:b0:n_[`2^[Zh0[:b/0:f][@2`/;00/K6a0;Rh^02g]kL0/[:b0;6a/@2/[:`0YZJV0:FUY@2SXj<0
UIFE07UiN@1PH600IfMW05IFEP26QXH0Shn?06][J`19BDT0@d=303@d=00f=SH0>3Ph00809bLW0180
<S8b0451@@0/;2`0:b/[03De=@0b<S80=3@d03Xj>P14A4@0@T9203Hf=P0c<c<0<C4a02TY:@0Z:RX0
<C4a030`<00e=CD203/k>`80;Bd]00l0<S8b02l_;`0^;Rh0=cLg04I6AP10@400<S8b034a<@0k>c/0
AdM703lo?`0n?Sh0=SHf04A4A00o?cl00P0d=3@03@0l?3`0>CTi03`l?010@400<C4a03<c<`0b<S80
<30`02`/;00Z:RX09bLW02PX:00d=3@00P0[:b/0300V9RH0:BTY02h^;P0l?3`0BTY:03Ti>@0`<300
9RHV03Lg=`1@D500>SXj030`<080;bl_0P0a<C40700V9RH0<C4a059BDP1UIFD0P82008^;R`2CTi<0
TI6A08n?S`23Ph<0Q8B408:2PP1bLW80D51@055AD@1UIFD0LW9b07alO01]KFd0RXZ:08b<S01YJFT0
DE5A02d];@0X:2P08B4Q02PX:00b<S8203Lg=`0V02/[:`0U9BD0:2PX02d];@0[:b/0;Bd]02XZ:P0S
8b<0:2PX02TY:@0/;2`0:BTY02`/;00X:2P09BDU02LW9`0[:b/09RHV030`<00Z:RX0;2`/030`<00d
=3@0>c/k04Y:BP1;Bd/0AdM7055AD@1GEeL0HF5Q06ATI01YJFT0K6a/07=cL`1dM7@0Lg=c075aL@1g
MgL307IfMP0D079bLP1gMgL0MgMg06m_K`1PH600?clo02l_;`0[:b/0:BTY02XZ:P0e=CD0CDe=05mO
G`1TI6@0MgMg07moO`22PX80QXJ60861P@22PX8208N7Q`0408^;R`27QhL0QhN708F5Q@<0RHV90`2;
Rh/308R8R00J08^;R`2=SHd0S8b<08j>SP2=SHd0RHV908b<S02:RXX0TI6A08^;R`29RHT0TI6A08n?
S`2EUID0Shn?092@T02ATI40TY:B09>CT`2;Rh/0S8b<08n?S`2<S8`0RXZ:08n?S`2;Rh/208f=S@04
08j>SP2:RXX0QhN708^;R`80R8R800T0RXZ:08b<S029RHT0QXJ608R8R02<S8`0Ti>C08b<S028R8P0
0P2<S8`00`2>SXh0Rh^;08^;R`0208n?S`0308^;R`29RHT0S8b<0080Shn?00@0TI6A09:BTP2BTY80
TY:B0P2CTi<02`2EUID0UYJF09VIV@2GUiL0VIVI09jNWP2OWil0X:2P09^KV`2MWId0WinO0080WIfM
00<0XZ:R0:BTY02WYjL00P2YZJT01`2][Jd0/[:b0;>c/`2a/K40[Zj^0;6a/@2d];@00P2i^KT00`2k
^k/0_;bl0;no_`020<71`@070<?3``36a/H0aLG50<G5a@34a<@0b<S80<W9b@030<g=c@080=3@d03?
cll0dM7A0=7Ad@3?cll0dM7A0=?Cd`3Bd]820=CDe00B0=OGe`3Cdm<0e]KF0=OGe`3IfMT0e]KF0=[J
fP3GemL0f=SH0=KFeP3:b/X0PH6105ADE01FEUH0F5QH05aLG01QHF40IFEU0P1ZJVX07`1XJ6P0K6a/
071`L01`L700J6QX06MWI`1XJ6P0IfMW05mOG`1TI6@0Hf=S05YJFP1QHF40GemO05UIF@1HF5P0EEEE
05=CD`1;Bd/0DU9B04Q8B010@400>CTi03hn?P0i>CT0;Rh^034a<@0`<300:RXZ038b<P0T92@00P0U
9BD0600a<C409RHV02<S8`0Z:RX0A4A407=cL`2DU9@0]KFe0<?3``39bLT0c/k>0<g=c@3De=@0alO7
0;Vi^@2RXZ80VIVI09FEU@2SXj<0]kNg0<G5a@3<c<`0dm?C0=KFeP80f=SH01d0dm?C0=3@d037alL0
_[jn0:^[Z`2DU9@0Ng]k05eMG@1FEUH0Bd];04U9B@0e=CD0>c/k03`l?013@d<0>SXj04U9B@17AdL0
CTi>051@D01CDe<0CTi>04m?C`1;Bd/0BDU90492@P15ADD0Bd];05MGE`0205aLG00D061PH01^KVh0
Kfm_06i^KP1ZJVX0HF5Q05iNGP1KFe/0FEUI05ADE01?Cdl0EEEE05ADE01FEUH0EEEE05QHF01ADE40
DU9B05QHF01KFe/206EUI@0?06YZJP1_Kfl0KVi^079bLP1WIfL0Hf=S05mOG`1LG5`0EUIF04Y:BP16
ATH0@d=303lo?`18B4P0>CTi00<0=3@d00<0=SHf03dm?@38h=P03@38h=P000`0b>3H0P0^;Rh04P0i
>CT0ATI604=3@`17AdL0ADE504=3@`11@D40@d=304A4A01EEED0IfMW07UiN@2@T900XZ:R0:RXZ02`
/;00/[:b0;Jf]P80]kNg0100/[:b0;6a/@2/[:`0Vi^K08>3P`1XJ6P0EEEE03hn?P11@D40BTY:05YJ
FP1XJ6P0N7Qh08F5Q@2BTY80UiNG0P2NWYh0=02VYZH0[Jf]0:ZZZP2ZZZX0[Zj^0;6a/@2^[Zh0/[:b
0:f][@2^[Zh0ZZZZ0;2`/02c/k<0/[:b0;Jf]P2h^;P0/k>c0;Bd]02`/;00Zj^[0:NWY`2SXj<0VIVI
0820P01LG5`0GUiN05QHF01oOgl0TI6A06QXJ017AdL0@D5103`l?00a<C40?Shn02/[:`0];Bd0<S8b
03Lg=`0U9BD0;2`/02PX:00[:b/0:2PX03<c<`0a<C40>SXj03lo?`0g=cL0;Bd]02XZ:P0`<302038b
<P0B02l_;`0g=cL0?clo02d];@0X:2P0;2`/02d];@0a<C40=cLg03hn?P0h>3P0:b/[02XZ:P0g=cL0
B4Q804A4A017AdL0>3Ph0P0o?cl03`0h>3P0>SXj03Ti>@0g=cL0?Cdm0410@00h>3P0<30`03Ph>012
@T80=CDe02l_;`0V9RH0:2PX02`/;00302<S8`0:02LW9`0`<300@D5104Q8B00j>SX09bLW02/[:`0f
=SH0>SXj03De=@80;bl_01l0;Rh^02/[:`0U9BD0?3`l05aLG01WIfL0J6QX08>3P`2MWId0YJFU092@
T01oOgl0L71`08B4Q02=SHd0MGEe04U9B@1IFET0HV9R05iNGP1iNGT0M7Ad07alO01`L700EEEE0410
@00X:2P09BDU02HV9P0g=cL0=3@d0080=cLg0180<30`02TY:@0W9bL09BDU034a<@0X:2P0:b/[02XZ
:P0];Bd0:RXZ02TY:@0V9RH092@T02DU9@0^;Rh09bLW02DU9@0W9bL202PX:00A02l_;`0b<S80<30`
03Xj>P17AdL0C4a<04I6AP1=CDd0EUIF05]KF`1RHV80JVYZ06e]K@1`L700M7Ad07=cL`1dM7@00`1f
MWH04P1eMGD0M7Ad0861P@1hN7P0NGUi06YZJP1FEUH0>3Ph02`/;00Y:BT0:b/[02l_;`0n?Sh0C4a<
05iNGP1[Jf/0M7Ad08>3P`80PH6100P0Q8B408>3P`27QhL0R8R808^;R`27QhL0RHV908f=S@80R8R8
0P29RHT01@28R8P0QXJ608V9R@28R8P0QhN70080RHV900H0Rh^;08Z:RP2:RXX0QXJ608b<S02=SHd2
08j>SP0<08f=S@2?Shl0U9BD08n?S`2>SXh0TI6A09BDU02ATI40SHf=08n?S`2>SXh0SHf=0P2>SXh2
08^;R`0308b<S02=SHd0S8b<0080RHV900@0QhN708R8R029RHT0RHV90P26QXH02029RHT0Rh^;08^;
R`2=SHd0RXZ:08F5Q@2;Rh/0RXZ:0P2;Rh/3092@T00=08j>SP2=SHd0TI6A092@T02DU9@0Ti>C09BD
U02ATI40U9BD09RHV02KVi/0VYZJ09JFUP0209VIV@0809jNWP2KVi/0VYZJ09jNWP2KVi/0WYjN0:2P
X02RXZ830:BTY0080:VYZ@2VYZH0[:b/0;6a/@2b/[80[jn_0;6a/@2c/k<20;Ng]`80^;Rh01P0^k^k
0;fm_@30`<00`L710<;2`P35aLD0`l?30<C4a035aLD0alO70<c<c03;bl/0cLg=0<k>cP3?cll0d=3@
0=;BdP3@d=00clo?0=;BdP3Cdm<0eMGE0=OGe`3Fe]H20=OGe`@0f=SH0100fMWI0=SHf03Hf=P0e=CD
0;Rh^01VIVH0DE5A05IFEP1LG5`0GemO06ATI01RHV80JVYZ06][J`1VIVH0J6QX0P1TI6@04@1VIVH0
J6QX06IVIP1VIVH0IfMW05mOG`1PH600G5aL05YJFP1HF5P0EUIF055AD@1BDU80DE5A04Q8B01;Bd/0
ADE50080?Cdm00@0=cLg038b<P0e=CD0<c<c0P0^;Rh03P0U9BD09bLW028R8P0S8b<09BDU02LW9`0^
;Rh0=SHf0451@@1UIFD0Rh^;0:VYZ@2o_kl0aLG50`3:b/X02P34a<@0_Kfm0:^[Z`2OWil0V9RH09jN
WP2`/;00`/;20<_;b`3AdM420=KFeP0N0=WIf@3Fe]H0dm?C0<c<c030`<00]kNg0::RXP2?Shl0N7Qh
061PH01?Cdl0ATI603lo?`0k>c/0>CTi03lo?`0i>CT0@T9204I6AP1>CTh0CDe=05ADE01CDe<0E5AD
059BDP17AdL0@41004A4A01:BTX0De=C0`1JFUX02@1WIfL0IFEU06m_K`1/K6`0Jf][06IVIP1RHV80
G5aL05UIF@0205IFEP80De=C00H0D51@05]KF`1?Cdl0D51@05mOG`1JFUX2065QH@0306][J`1/K6`0
J6QX0080IfMW00T0I6AT05aLG01LG5`0EeMG059BDP15ADD0>c/k03Xj>P11@D400P0f=SH0100j>SX0
=3@d03<c<`0i>CT>0<SPf0003038h=P3030`<003034a<@0h>3P0=SHf0080?3`l01D0=SHf03Ti>@0g
=cL0C4a<06a/K020P800U9BD0:>SX`2ZZZX0[Jf]0;>c/`2e]KD0][Jf0;Fe]@2`/;00Zj^[0:JVYP2N
WYh0R8R806a/K01?Cdl00P0m?Cd02`17AdL0Fe]K06ATI01gMgL0QHF508j>SP2JVYX0WinO0:BTY02U
YJD0Zj^[0080[Jf]0P2`/;002`2_[jl0/K6a0;6a/@2`/;00[Zj^0:n_[`2a/K40/k>c0;Zj^P2g]kL0
];Bd0080[jn_00d0[Jf]0:JVYP2TY:@0VIVI08V9R@1PH600FEUI05]KF`1lO7`0QXJ605mOG`14A4@0
?Shn0080?3`l00<0<S8b02LW9`0X:2P00P0e=CD00`0Z:RX0;bl_02`/;00202l_;`0903Ti>@0/;2`0
:b/[038b<P11@D40=CDe03Ti>@0e=CD0?3`l0080;bl_0280>CTi0492@P0j>SX0;2`/038b<P0d=3@0
?Cdm0451@@0k>c/0<30`02h^;P0];Bd0=SHf0451@@15ADD0@T9203hn?P0g=cL0?3`l03hn?P0m?Cd0
?Shn03/k>`0h>3P0<30`02XZ:P0j>SX0?3`l04=3@`0m?Cd0<S8b030`<00/;2`0:2PX0P0];Bd03@0W
9bL0<S8b03dm?@0n?Sh0>CTi03dm?@0_;bl0<c<c03Lg=`0a<C40;Bd]02PX:00V9RH00P0/;2`0<@13
@d<0G5aL06YZJP1XJ6P0Kfm_09RHV02VYZH0Ti>C07UiN@1UIFD0LG5a08V9R@25QHD0IFEU05UIF@1Q
HF40CDe=069RHP1JFUX0Bd];06=SH`1NGUh0CTi>04];B`0];Bd0:BTY02LW9`0Z:RX0;2`/03De=@0g
=cL0<S8b02/[:`0X:2P0;2`/02d];@0`<300<c<c03hn?P0k>c/0>SXj03Ti>@0/;2`0;Bd]02/[:`0b
<S80:2PX02HV9P0T92@00`0Z:RX202PX:00?02h^;P0l?3`0@d=304];B`17AdL0EEEE05UIF@1QHF40
JFUY06QXJ01aLG40KVi^07UiN@1bLW80Lg=c00<0MWIf00T0N7Qh07MgM`1fMWH0NWYj07IfMP1[Jf/0
CTi>03Hf=P0[:b/00P0X:2P03@0d=3@0@T9205ADE01TI6@0KFe]07inOP20P800QHF508>3P`22PX80
QHF508b<S02;Rh/00P28R8P00`27QhL0QXJ608Z:RP0208V9R@0608R8R02;Rh/0Shn?08J6QP2=SHd0
Rh^;0P29RHT208^;R`0308Z:RP29RHT0RHV90080SXj>00X0Rh^;08n?S`2ATI40TI6A08j>SP2ATI40
U9BD08f=S@2<S8`0T92@0`2ATI402@2>SXh0Rh^;08Z:RP2>SXh0S8b<08Z:RP25QHD0Rh^;08B4Q002
08j>SP0408N7Q`26QXH0R8R808N7Q`80RXZ:00H0SHf=08V9R@27QhL0QHF508Z:RP2<S8`408j>SP0R
08b<S02?Shl0TY:B09BDU02CTi<0V9RH09JFUP2CTi<0U9BD09NGU`2IVIT0WIfM09^KV`2LW9`0V9RH
09^KV`2MWId0W9bL09nOW`2QXJ40X:2P09jNWP2RXZ80Y:BT0:RXZ02TY:@0YZJV0:RXZ02[Zj/0/K6a
0;Jf]P2`/;00[jn_0;>c/`80];Bd0P2g]kL01`2h^;P0_;bl0<30`031`L40a<C40<G5a@34a<@00P38
b<P01`3;bl/0c<c<0<g=c@3<c<`0clo?0<g=c@3?cll00P3@d=00103?cll0d];B0=GEe@3Fe]H30=CD
e0030=OGe`3Hf=P0fMWI0080fMWI00d0f=SH0=WIf@3IfMT0dm?C0:JVYP1JFUX0CTi>05IFEP1KFe/0
H61P065QH@1TI6@0KFe]0080JFUY0`1VIVH03P1UIFD0IVIV06EUI@1RHV80GEeM05iNGP1IFET0GEeM
05QHF01ADE40Cdm?04e=C@18B4P0BDU90P1:BTX02@10@400?3`l03Xj>P0e=CD0;bl_03@d=00a<C40
9RHV02LW9`0202XZ:P0C02<S8`0V9RH0:b/[03De=@0d=3@0=SHf04=3@`1PH600Ng]k09VIV@2_[jl0
`<300<O7a`3:b/X0a/K60<?3``2j^[X0]KFe0:VYZ@020:6QX@070:RXZ02m_Kd0alO70=3@d03Bd]80
dm?C0=[JfP020=?Cd`0?0<k>cP37alL0^k^k0:b/[02FUYH0QHF506UYJ@1IFET0DU9B04I6AP1:BTX0
@D5103Xj>P0i>CT0?Cdm0080BTY:00@0Bd];04i>CP1BDU80F5QH0P1?Cdl0101=CDd0BTY:04E5A@1<
C4`205MGE`0405YJFP1KFe/0GUiN06ATI080Jf][0P1VIVH0501NGUh0GemO05UIF@1FEUH0Fe]K05eM
G@1ADE40De=C05aLG01DE5@0EeMG05YJFP1KFe/0HF5Q06IVIP1SHf<0KFe]06IVIP1YJFT0I6AT0P1N
GUh205ADE00704Y:BP18B4P0>3Ph03hn?P0m?Cd0>3Ph03@d=00203<c<`0303De=@38h=P0b>3H00`0
b>3H000<0<SPf080<S8b02@0;bl_02h^;P0^;Rh0;Bd]03De=@0b<S80>3Ph03Hf=P0e=CD0D51@06UY
J@26QXH0VIVI09nOW`2WYjL0[:b/0;6a/@2f][H0];Bd0:n_[`2][Jd0YjNW0:6QX@2JVYX0Rh^;06a/
K01<C4`0?Shn03`l?01?Cdl0F5QH06MWI`1lO7`0RHV9092@T02GUiL20:2PX0090:RXZ02ZZZX0[:b/
0:b/[02][Jd0[jn_0;2`/02][Jd0[jn_00<0[Zj^00<0/K6a0;Fe]@2e]KD00P2e]KD20;2`/00=0:b/
[02VYZH0XJ6Q09VIV@2<S8`0IFEU04e=C@1JFUX0N7Qh07moO`1KFe/0ATI604=3@`0204I6AP0N030`
<00Y:BT0:RXZ03De=@0m?Cd0<S8b02TY:@0X:2P09RHV02`/;00`<300;2`/02LW9`0[:b/0;bl_03Lg
=`1:BTX0ADE503hn?P0i>CT0;bl_03@d=00n?Sh0=SHf030`<00^;Rh0<30`0451@@10@400=SHf0P0]
;Bd05`0[:b/0<C4a04E5A@1@D500ATI603lo?`0c<c<0>SXj03lo?`0f=SH0>CTi03Ph>00o?cl0>3Ph
03@d=00m?Cd0>SXj03@d=00a<C40<S8b03<c<`0];Bd09bLW0080:BTY0100;bl_03Ph>00o?cl0?Cdm
03@d=00Z:RX0;2`/038b<P0h>3P0<30`02l_;`0T92@0:2PX02`/;01<C4`0Hf=S0P1]KFd0901aLG40
QhN709VIV@2CTi<0N7Qh06ATI01eMGD0TY:B08N7Q`1[Jf/0KVi^079bLP1@D500F5QH05mOG`0i>CT0
@d=306i^KP1`L700EUIF04A4A00Z:RX09bLW02TY:@0W9bL0<30`02l_;`0g=cL0>c/k034a<@0^;Rh0
:RXZ03Lg=`0`<300;Bd]03<c<`80;Rh^01T0:BTY02XZ:P0Z:RX0;Rh^02l_;`0[:b/0:2PX028R8P0Y
:BT0:RXZ02d];@0[:b/0:RXZ02`/;00c<c<0>SXj04=3@`14A4@0DE5A05EEE@1KFe/0GUiN06UYJ@1/
K6`0LG5a0080LW9b00<0MgMg06i^KP1^KVh00P1gMgL05P1cLg<0N7Qh07MgM`1cLg<0LG5a06QXJ017
AdL0<S8b02/[:`0U9BD0:b/[03Lg=`1?Cdl0G5aL06IVIP1bLW80OGem08>3P`24Q8@0PX:208B4Q026
QXH208R8R007092@T025QHD0QhN708N7Q`29RHT0R8R808Z:RP0208b<S00408R8R02:RXX0SHf=08^;
R`80S8b<00/0RHV908R8R02<S8`0SHf=092@T02>SXh0RHV9092@T02?Shl0SXj>08f=S@02096AT@05
08j>SP2;Rh/0SXj>08j>SP2=SHd00P2>SXh01@28R8P0SHf=08b<S02>SXh0QhN70080Rh^;00d0R8R8
08N7Q`29RHT0QhN708R8R025QHD0R8R808b<S02;Rh/0RXZ:08b<S029RHT0QhN70080Rh^;00`0SXj>
09:BTP2BTY80SXj>08n?S`2@T900U9BD096AT@2CTi<0VYZJ09RHV02GUiL209VIV@80VYZJ00@0W9bL
09ZJVP2JVYX0Vi^K0P2NWYh0102QXJ40W9bL0::RXP2PX:020:BTY0040::RXP2TY:@0ZJVY0:^[Z`80
[Jf]00P0/K6a0;2`/02_[jl0/k>c0;Rh^02f][H0^[Zj0;Vi^@80_;bl00T0_Kfm0<C4a033`l<0a/K6
0<G5a@38b<P0a/K60<c<c03;bl/00P3=cLd20<k>cP<0d=3@00P0dm?C0=7Ad@3De=@0e=CD0=OGe`3D
e=@0eMGE0=OGe`<0f=SH00l0f][J0=WIf@3Hf=P0f=SH0<_;b`29RHT0CTi>055AD@1DE5@0GEeM05mO
G`1NGUh0I6AT06IVIP1TI6@00P1VIVH206YZJP0>05mOG`1JFUX0HV9R05aLG01JFUX0Fe]K05QHF01K
Fe/0E5AD059BDP1@D500CDe=04I6AP14A4@203lo?`0:03dm?@0k>c/0>SXj03@d=00i>CT0;bl_02d]
;@0_;bl0;Rh^034a<@80;Bd]03P0;2`/034a<@0e=CD0>c/k0451@@1LG5`0EeMG06m_K`28R8P0YJFU
0;Ng]`34a<@0aLG50<?3``31`L40_;bl0;>c/`2XZ:P0X:2P0:6QX@2VYZH0^KVi0<C4a03=cLd0d];B
0=KFeP3Hf=P0emOG0=KFeP3Cdm<0c<c<0<30`02a/K40XJ6Q08^;R`1iNGT0Jf][05MGE`1=CDd0Bd];
04A4A00k>c/0>CTi03/k>`0o?cl0?Shn04U9B@1@D500CDe=05=CD`1BDU80CDe=04m?C`1;Bd/0BDU9
04i>CP80FUYJ00X0GemO06=SH`1XJ6P0I6AT06m_K`1ZJVX0LG5a06UYJ@1UIFD0GemO0P1KFe/06P1H
F5P0EEEE05UIF@1FEUH0De=C05UIF@1MGEd0GUiN05]KF`1QHF40IFEU069RHP1ZJVX0JFUY069RHP1S
Hf<0HV9R061PH01HF5P0EEEE04a<C019BDT0>c/k03Xj>P0l?3`0>3Ph0P0c<c<00`0`<300<S8b0<SP
f00=0<SPf0003038h=P202/[:`0602XZ:P0Y:BT0:RXZ02HV9P0/;2`0;Bd]0P0Y:BT0800a<C40AdM7
06ATI026QXH0UiNG0::RXP2XZ:P0[:b/0;>c/`2d];@0][Jf0:j^[P2[Zj/0Y:BT09jNWP2@T900Q8B4
06i^KP18B4P0?Cdm03Ti>@1;Bd/0G5aL06=SH`1jNWX0QHF508n?S`2JVYX0XJ6Q0:>SX`2VYZH0Zj^[
0P2YZJT02@2_[jl0/[:b0;:b/P2`/;00[Zj^0;6a/@2_[jl0[Jf]0:n_[`020;Bd]00<0;>c/`2e]KD0
/[:b0:j^[P2[Zj/0YZJV09nOW`2MWId0Shn?06ATI012@T80GemO0P1fMWH02@1NGUh0De=C05ADE01A
DE40EUIF03Ti>@0Y:BT0;Bd]02h^;P0203Ph>00a02PX:00W9bL09RHV02LW9`0];Bd0;2`/02DU9@0Z
:RX0:b/[030`<00i>CT0CDe=059BDP0e=CD0<S8b03/k>`0f=SH0;bl_02/[:`0_;bl0<C4a04U9B@16
ATH0=SHf034a<@0Y:BT0<C4a03Hf=P0n?Sh0AdM704=3@`0k>c/0>3Ph04];B`12@T80=SHf03hn?P0k
>c/0?clo03Ti>@0g=cL0?3`l03Hf=P0Z:RX0:BTY038b<P0n?Sh0:b/[02d];@0203Xj>P80?Shn03d0
>SXj03Ti>@0/;2`0:BTY02l_;`0e=CD0?3`l03Ph>00^;Rh092@T02`/;017AdL0K6a/06YZJP1NGUh0
Kfm_07moO`29RHT0SHf=07]kN`1cLg<0QhN709BDU02;Rh/0J6QX07=cL`2;Rh/0GemO06IVIP1NGUh0
Cdm?04i>CP1SHf<0L71`05eMG@19BDT0;bl_02PX:00_;bl0:2PX02/[:`0_;bl0<30`03<c<`0f=SH0
?Cdm03<c<`0/;2`0;Rh^02`/;00Y:BT0:b/[03Hf=P0a<C40;Bd]02TY:@0W9bL09RHV02TY:@0W9bL0
:BTY00809bLW00<0:BTY02/[:`0W9bL00P0/;2`03P0b<S80?3`l04A4A016ATH0Bd];05QHF01IFET0
Fe]K06MWI`1UIFD0K6a/07IfMP1_Kfl0Lg=c0P1dM7@08P1eMGD0N7Qh075aL@1iNGT0M7Ad07IfMP1g
MgL0M7Ad05mOG`14A4@0;2`/02@T900W9bL0;bl_04M7A`1IFET0GemO06QXJ01cLg<0Q8B408F5Q@28
R8P0RHV908B4Q028R8P0RHV908^;R`28R8P0QHF508J6QP28R8P0Rh^;08b<S02:RXX208^;R`80S8b<
0P2=SHd00`2:RXX0Rh^;08^;R`0208^;R`06092@T02>SXh0SHf=09:BTP2:RXX0Shn?0P2@T9003P2B
TY80U9BD08^;R`2>SXh0S8b<092@T02<S8`0RHV908R8R02=SHd0S8b<08j>SP2:RXX0S8b<0P27QhL0
3P28R8P0QhN708J6QP2;Rh/0RXZ:08b<S029RHT0RXZ:08f=S@29RHT0Rh^;08Z:RP28R8P0SXj>0`2B
TY805P2ATI40Shn?092@T02CTi<0TI6A09>CT`2JVYX0U9BD09JFUP2GUiL0UIFE09NGU`2JVYX0UiNG
09bLW02NWYh0Vi^K09nOW`2LW9`0WIfM09bLW02RXZ820:>SX`0C0:FUY@2YZJT0Z:RX0:RXZ02YZJT0
[Jf]0;Bd]02a/K40/k>c0;6a/@2e]KD0]kNg0;bl_02k^k/0_Kfm0;^k^`2m_Kd0`<300<G5a@030<S8
b0070<W9b@38b<P0c<c<0<c<c03?cll0c<c<0<g=c@030=7Ad@80d];B00<0dm?C0=CDe03Fe]H00P3D
e=@20=SHf080fMWI00T0f][J0=WIf@3Kfm/0fm_K0=OGe`2k^k/0JVYZ04];B`1CDe<00P1IFET01`1P
H600G5aL06][J`1SHf<0HV9R06=SH`1QHF400P1MGEd02`1PH600GemO05mOG`1KFe/0FUYJ05UIF@1D
E5@0EeMG05UIF@1?Cdl0Bd];0080BDU900`0@D510410@00o?cl0=3@d03Ph>00e=CD0<S8b03Ph>00e
=CD0:RXZ02/[:`0c<c<3034a<@0h03Ph>00i>CT0@41004a<C01ADE40HV9R06=SH`1WIfL0MWIf09:B
TP2^[Zh0_Kfm0;no_`32`/80`L710;^k^`2`/;00YZJV09NGU`2OWil0YJFU0;:b/P33`l<0cLg=0=;B
dP3Fe]H0f][J0=SHf03GemL0dm?C0<c<c033`l<0][Jf0:RXZ02DU9@0Q8B406m_K`1MGEd0FEUI04m?
C`1<C4`0@41003dm?@0i>CT0=SHf03Xj>P17AdL0DE5A04i>CP1@D500EEEE05=CD`1>CTh0CDe=051@
D01=CDd205EEE@0:05aLG01NGUh0H61P06MWI`1YJFT0K6a/06UYJ@1ZJVX0Hf=S05aLG080Fe]K01/0
EeMG05IFEP1JFUX0EUIF05EEE@1HF5P0GEeM061PH01MGEd0FUYJ06=SH`1UIFD0IfMW06IVIP1WIfL0
Hf=S069RHP1QHF40G5aL05eMG@1ADE40C4a<03`l?00h>3P0>c/k03Ph>00d=3@00P0e=CD00`0c<c<0
b>3H0<SPf00<0<SPf0003038h=P202TY:@0X02<S8`0X:2P08B4Q01lO7`0P82008b<S028R8P0Y:BT0
<30`04E5A@1VIVH0SXj>09ZJVP2OWil0ZZZZ0:JVYP2`/;00/K6a0;Jf]P2`/;00ZZZZ0::RXP2MWId0
TI6A07alO01iNGT0ATI603Ph>00k>c/0ATI605=CD`1TI6@0MWIf08J6QP2<S8`0Vi^K09nOW`2SXj<0
YjNW0:^[Z`80[Jf]0P2^[Zh0602_[jl0/K6a0:f][@2a/K40/[:b0;2`/02b/[80];Bd0;>c/`2g]kL0
][Jf0:n_[`2[Zj/0Z:RX0:JVYP2QXJ40WIfM08j>SP1aLG40Bd];059BDP1iNGT0OGem06ATI080DE5A
01/0FEUI05aLG00c<c<0:2PX02<S8`0`<300>c/k03Xj>P0_;bl0:RXZ030`<00/;2`0=3@d02/[:`0Y
:BT09RHV02XZ:P0];Bd0<C4a03dm?@1HF5P0@41003`l?00j>SX0=CDe02/[:`0Z:RX00P0];Bd0701@
D500CDe=03Ph>00g=cL0<c<c02l_;`0];Bd0>CTi0492@P14A4@0?3`l03dm?@17AdL0?Shn0451@@15
ADD0@d=303dm?@0c<c<0>SXj03@d=00W9bL0:BTY02h^;P0g=cL0?Cdm02XZ:P0h>3P203@d=00403Lg
=`0e=CD0<S8b030`<08092@T0100:b/[02@T900/;2`0=3@d02h^;P0Y:BT0>c/k065QH@1WIfL0FUYJ
06IVIP1kNg/0OWin075aL@1mOGd0PH610P2?Shl04P2ATI40IfMW04Y:BP1aLG40P82005MGE`1ZJVX0
EeMG06IVIP1mOGd0Lg=c05eMG@18B4P0<C4a02LW9`0T92@0<30`02/[:`80;Rh^00P0<C4a03Lg=`0d
=3@0>c/k03@d=00/;2`0;Rh^02PX:080;Bd]00<0<S8b034a<@0Y:BT00P0X:2P202HV9P0602d];@0Z
:RX0;2`/02LW9`0Y:BT0;2`/0P0Y:BT00`0_;bl0<c<c03Lg=`0203/k>`0904Q8B01HF5P0F5QH05MG
E`1PH600J6QX071`L01eMGD0MgMg00<0LW9b00<0MGEe07QhN01dM7@00P1fMWH207QhN00H07EeM@1/
K6`0Cdm?03De=@0W9bL092@T02l_;`0d=3@0CDe=05MGE`1VIVH0Kfm_07UiN@24Q8@0PX:208R8R021
PH40R8R808V9R@2:RXX0RHV908J6QP2:RXX0QXJ60P28R8P01`2;Rh/0RXZ:08b<S028R8P0SHf=08^;
R`2<S8`00P2>SXh01@2<S8`0SHf=08f=S@2>SXh0RHV90080Shn?00`0SXj>09>CT`2BTY80T92@08b<
S02CTi<0RXZ:08V9R@2=SHd0S8b<08^;R`2<S8`308^;R`0308n?S`29RHT0Rh^;0080R8R80P29RHT0
2026QXH0RHV908Z:RP25QHD0SHf=08b<S02:RXX0SXj>0`2;Rh/0102ATI40Ti>C09>CT`2CTi<3096A
T@09092@T02CTi<0TY:B09JFUP2CTi<0UYJF09NGU`2CTi<0V9RH0080UiNG00L0Vi^K09RHV02KVi/0
XZ:R09ZJVP2OWil0XZ:R0080Xj>S0P2UYJD20:RXZ00;0:JVYP2[Zj/0Zj^[0;>c/`2a/K40/k>c0;Bd
]02g]kL0^;Rh0;fm_@2k^k/00P2l_;`02P30`<00`L710<;2`P37alL0bLW90<O7a`33`l<0b<S80<_;
b`3AdM420=3@d0030<g=c@3AdM40dM7A0080d=3@00D0e=CD0=;BdP3De=@0e]KF0=CDe0020=GEe@0E
0=OGe`3Hf=P0fMWI0=[JfP3GemL0f][J0=_Kf`3De=@0[:b/05QHF015ADD0CTi>05YJFP1HF5P0I6AT
05aLG01OGel0HV9R05iNGP1QHF40EeMG0080GEeM01T0GUiN061PH01GEeL0EeMG059BDP1HF5P0C4a<
05EEE@1=CDd0Cdm?04A4A01;Bd/0A4A403lo?`13@d<0?clo03/k>`0n?Sh0=3@d03Xj>P0h>3P0=SHf
038b<P0d=3@0;bl_0080=3@d01/0?3`l0492@P1:BTX0D51@05]KF`1UIFD0J6QX071`L01dM7@0MgMg
08R8R02KVi/0[Zj^0;Rh^02k^k/0^[Zj0;Fe]@2_[jl0X:2P09>CT`2HV9P0Y:BT0;6a/@2o_kl0bLW9
0=?Cd`3De=@00P3IfMT03P3Jf]X0dm?C0=3@d03:b/X0_[jn0:n_[`2NWYh0S8b<07alO01ZJVX0GemO
05ADE01?Cdl0ATI60P0o?cl01P0i>CT0?3`l0451@@1GEeL0D51@055AD@80FEUI00@0C4a<04Y:BP16
ATH0BTY:0P1ADE408`1=CDd0EEEE05aLG01FEUH0Jf][06a/K01_Kfl0JFUY06IVIP1PH600Fe]K05eM
G@1OGel0FUYJ05aLG01HF5P0Fe]K061PH01IFET0G5aL05eMG@1JFUX0GEeM06EUI@1VIVH0IFEU06YZ
JP1VIVH0HF5Q06=SH`1MGEd0Fe]K05UIF@1?Cdl0ADE50080?clo00D0>c/k03Ti>@0g=cL0=3@d03De
=@0>0<SPf0003038h=P202LW9`0502HV9P0R8R808B4Q024Q8@0N7Qh00P0R8R802@0Z:RX0=3@d04M7
A`1WIfL0SHf=09JFUP2OWil0Z:RX0:b/[0020;2`/00F0;:b/P2_[jl0Z:RX0:>SX`2IVIT0Shn?07]k
N`1ZJVX0ADE503De=@0m?Cd0Bd];05=CD`1[Jf/0MGEe08J6QP2?Shl0UYJF09fMW@2TY:@0YZJV0:ZZ
ZP80[Zj^0P2][Jd20;6a/@060;2`/02b/[80/K6a0:n_[`2`/;00/[:b0`2d];@0702_[jl0/;2`0:VY
Z@2RXZ80W9bL09^KV`2CTi<0Ogmo05iNGP1BDU80LG5a08:2PP1UIFD0De=C05UIF@1MGEd0GemO03Ti
>@0W9bL09BDU02TY:@0b<S80>c/k03@d=00Y:BT0;Bd]034a<@0_;bl202h^;P0502TY:@0];Bd0:BTY
02`/;00`<3000`18B4P0100o?cl0=SHf030`<00_;bl203@d=00504a<C01;Bd/0>CTi02l_;`0`<300
0P0d=3@05@0c<c<0>CTi04I6AP11@D40?3`l04M7A`13@d<0>SXj03Ph>015ADD0@T9203`l?00e=CD0
:BTY02PX:00V9RH0=SHf03<c<`0d=3@0<S8b03<c<`0203Xj>P0703Ph>00d=3@0=SHf034a<@0];Bd0
<c<c02DU9@0202HV9P0Q02LW9`0^;Rh0CTi>05IFEP1NGUh0Cdm?061PH01eMGD0PX:2075aL@1PH600
T92@0:JVYP2<S8`0QhN707QhN014A4@0?Shn04a<C01EEED0IfMW069RHP1LG5`0P82008B4Q01ZJVX0
@41003Lg=`0d=3@0:2PX02LW9`0h>3P0<30`0080:b/[00P0;Rh^03@d=00h>3P0=cLg04Q8B011@D40
<c<c02d];@80:b/[01D0=3@d03Ti>@0^;Rh0;bl_02XZ:P0[:b/0:BTY02HV9P0Y:BT09bLW02HV9P0Y
:BT0;Bd]02/[:`0];Bd0:b/[03@d=00f=SH0?Cdm03/k>`14A4@00P1EEED01@1@D500GEeM06IVIP1Y
JFT0LG5a0080MWIf0P1dM7@05`1hN7P0MgMg07IfMP1fMWH0P82007UiN@1hN7P0MGEe07MgM`1ZJVX0
Cdm?03Lg=`0U9BD09bLW02d];@15ADD0DU9B06UYJ@1ZJVX0LG5a07moO`24Q8@0QXJ60080R8R801L0
QXJ608R8R026QXH0QhN708B4Q028R8P0RXZ:08N7Q`2:RXX0Rh^;08V9R@2=SHd0SXj>08b<S02;Rh/0
SHf=08n?S`2>SXh0SHf=092@T02?Shl0SHf=092@T00208f=S@0608j>SP2=SHd0Ti>C08n?S`2BTY80
SXj>0P2<S8`02`29RHT0RXZ:08V9R@2<S8`0Rh^;08V9R@2<S8`0QhN708^;R`28R8P0QhN70080Q8B4
00<0QXJ608Z:RP28R8P00P26QXH00`2@T900RHV908b<S00208j>SP0308f=S@2ATI40TY:B0080TY:B
00T0TI6A08n?S`2BTY80U9BD09VIV@2CTi<0UIFE09RHV02GUiL00P2FUYH02P2IVIT0UiNG09ZJVP2L
W9`0VYZJ09nOW`2QXJ40Vi^K0::RXP2OWil20:>SX`070:BTY02WYjL0YZJV0:ZZZP2XZ:P0ZJVY0:^[
Z`020;2`/080/[:b0`2i^KT02P2j^[X0_kno0<30`030`<00`/;20<K6aP34a<@0a/K60<W9b@38b<P2
0<_;b`080<k>cP3@d=00c/k>0=3@d03AdM40d];B0=3@d03Bd]820=?Cd`030=GEe@3Cdm<0eMGE0080
e=CD0P3Hf=P04`3Kfm/0f=SH0=[JfP3Jf]X0fMWI0<g=c@2?Shl0BTY:04I6AP1>CTh0FUYJ05=CD`1T
I6@0G5aL05mOG`1PH600HV9R05eMG@1KFe/00P1EEED01P1ADE40F5QH055AD@1NGUh0DE5A051@D080
CTi>02l0B4Q804a<C013@d<0?3`l03hn?P13@d<0ADE503lo?`14A4@0?Cdm03lo?`10@400A4A403lo
?`11@D40@T9203hn?P12@T80@410059BDP1FEUH0F5QH05aLG01[Jf/0MgMg07UiN@1kNg/0P82008N7
Q`2=SHd0Ti>C09fMW@2[Zj/0[jn_0;6a/@2ZZZX0YjNW09ZJVP2EUID0Ti>C09nOW`2/[:`0_;bl0<S8
b03Bd]80eMGE0=_Kf`020=[JfP0H0=WIf@3Bd]80b/[:0<30`02`/;00WYjN09>CT`25QHD0Lg=c06UY
J@1NGUh0De=C04i>CP1:BTX0@D5103Xj>P0n?Sh0?Cdm04I6AP1;Bd/0CTi>05EEE@1FEUH0De=C0P1=
CDd05`1@D500Cdm?04m?C`1;Bd/0E5AD059BDP1FEUH0HV9R06IVIP1ZJVX0KFe]06i^KP1NGUh0EeMG
05UIF@1EEED0G5aL05YJFP1MGEd0G5aL05iNGP1MGEd0EeMG0080Fe]K00@0H61P06=SH`1WIfL0J6QX
0P1WIfL0201QHF40GemO05aLG01NGUh0F5QH05MGE`1;Bd/0@T920P0k>c/0100j>SX0=cLg03Ph>00l
?3`>0<SPf0003038h=P202LW9`0502HV9P0R8R808B4Q024Q8@0N7Qh00P0R8R802@0Z:RX0=3@d04M7
A`1WIfL0SHf=09JFUP2OWil0Z:RX0:b/[0020;2`/00F0;:b/P2_[jl0Z:RX0:>SX`2IVIT0Shn?07]k
N`1ZJVX0ADE503De=@0m?Cd0Bd];05=CD`1[Jf/0MGEe08J6QP2?Shl0UYJF09fMW@2TY:@0YZJV0:ZZ
ZP80[Zj^0P2][Jd20;6a/@060;2`/02b/[80/K6a0:n_[`2`/;00/[:b0`2d];@0702_[jl0/;2`0:VY
Z@2RXZ80W9bL09^KV`2CTi<0Ogmo05iNGP1BDU80LG5a08:2PP1UIFD0De=C05UIF@1MGEd0GemO03Ti
>@0W9bL09BDU02TY:@0b<S80>c/k03@d=00Y:BT0;Bd]034a<@0_;bl202h^;P0502TY:@0];Bd0:BTY
02`/;00`<3000`18B4P0100o?cl0=SHf030`<00_;bl203@d=00504a<C01;Bd/0>CTi02l_;`0`<300
0P0d=3@05@0c<c<0>CTi04I6AP11@D40?3`l04M7A`13@d<0>SXj03Ph>015ADD0@T9203`l?00e=CD0
:BTY02PX:00V9RH0=SHf03<c<`0d=3@0<S8b03<c<`0203Xj>P0703Ph>00d=3@0=SHf034a<@0];Bd0
<c<c02DU9@0202HV9P0Q02LW9`0^;Rh0CTi>05IFEP1NGUh0Cdm?061PH01eMGD0PX:2075aL@1PH600
T92@0:JVYP2<S8`0QhN707QhN014A4@0?Shn04a<C01EEED0IfMW069RHP1LG5`0P82008B4Q01ZJVX0
@41003Lg=`0d=3@0:2PX02LW9`0h>3P0<30`0080:b/[00P0;Rh^03@d=00h>3P0=cLg04Q8B011@D40
<c<c02d];@80:b/[01D0=3@d03Ti>@0^;Rh0;bl_02XZ:P0[:b/0:BTY02HV9P0Y:BT09bLW02HV9P0Y
:BT0;Bd]02/[:`0];Bd0:b/[03@d=00f=SH0?Cdm03/k>`14A4@00P1EEED01@1@D500GEeM06IVIP1Y
JFT0LG5a0080MWIf0P1dM7@05`1hN7P0MgMg07IfMP1fMWH0P82007UiN@1hN7P0MGEe07MgM`1ZJVX0
Cdm?03Lg=`0U9BD09bLW02d];@15ADD0DU9B06UYJ@1ZJVX0LG5a07moO`24Q8@0QXJ60080R8R801L0
QXJ608R8R026QXH0QhN708B4Q028R8P0RXZ:08N7Q`2:RXX0Rh^;08V9R@2=SHd0SXj>08b<S02;Rh/0
SHf=08n?S`2>SXh0SHf=092@T02?Shl0SHf=092@T00208f=S@0608j>SP2=SHd0Ti>C08n?S`2BTY80
SXj>0P2<S8`02`29RHT0RXZ:08V9R@2<S8`0Rh^;08V9R@2<S8`0QhN708^;R`28R8P0QhN70080Q8B4
00<0QXJ608Z:RP28R8P00P26QXH00`2@T900RHV908b<S00208j>SP0308f=S@2ATI40TY:B0080TY:B
00T0TI6A08n?S`2BTY80U9BD09VIV@2CTi<0UIFE09RHV02GUiL00P2FUYH02P2IVIT0UiNG09ZJVP2L
W9`0VYZJ09nOW`2QXJ40Vi^K0::RXP2OWil20:>SX`070:BTY02WYjL0YZJV0:ZZZP2XZ:P0ZJVY0:^[
Z`020;2`/080/[:b0`2i^KT02P2j^[X0_kno0<30`030`<00`/;20<K6aP34a<@0a/K60<W9b@38b<P2
0<_;b`080<k>cP3@d=00c/k>0=3@d03AdM40d];B0=3@d03Bd]820=?Cd`030=GEe@3Cdm<0eMGE0080
e=CD0P3Hf=P04`3Kfm/0f=SH0=[JfP3Jf]X0fMWI0<g=c@2?Shl0BTY:04I6AP1>CTh0FUYJ05=CD`1T
I6@0G5aL05mOG`1PH600HV9R05eMG@1KFe/00P1EEED01P1ADE40F5QH055AD@1NGUh0DE5A051@D080
CTi>02l0B4Q804a<C013@d<0?3`l03hn?P13@d<0ADE503lo?`14A4@0?Cdm03lo?`10@400A4A403lo
?`11@D40@T9203hn?P12@T80@410059BDP1FEUH0F5QH05aLG01[Jf/0MgMg07UiN@1kNg/0P82008N7
Q`2=SHd0Ti>C09fMW@2[Zj/0[jn_0;6a/@2ZZZX0YjNW09ZJVP2EUID0Ti>C09nOW`2/[:`0_;bl0<S8
b03Bd]80eMGE0=_Kf`020=[JfP0H0=WIf@3Bd]80b/[:0<30`02`/;00WYjN09>CT`25QHD0Lg=c06UY
J@1NGUh0De=C04i>CP1:BTX0@D5103Xj>P0n?Sh0?Cdm04I6AP1;Bd/0CTi>05EEE@1FEUH0De=C0P1=
CDd05`1@D500Cdm?04m?C`1;Bd/0E5AD059BDP1FEUH0HV9R06IVIP1ZJVX0KFe]06i^KP1NGUh0EeMG
05UIF@1EEED0G5aL05YJFP1MGEd0G5aL05iNGP1MGEd0EeMG0080Fe]K00@0H61P06=SH`1WIfL0J6QX
0P1WIfL0201QHF40GemO05aLG01NGUh0F5QH05MGE`1;Bd/0@T920P0k>c/0100j>SX0=cLg03Ph>00l
?3`>0<SPf0003038h=P202LW9`809BDU00h08R8R01lO7`0L71`07alO028R8P0W9bL0<30`04M7A`1_
Kfl0RXZ:09NGU`2OWil0ZZZZ0:^[Z`80/;2`01H0/K6a0:n_[`2ZZZX0X:2P09>CT`2;Rh/0OWin06][
J`13@d<0?3`l0410@016ATH0EeMG06MWI`1hN7P0QHF5096AT@2EUID0WIfM0:>SX`2XZ:P0ZZZZ0P2[
Zj/0402^[Zh0[Jf]0:f][@2a/K40[:b/0:n_[`2e]KD0[:b/0;2`/02d];@0]KFe0;Bd]02e]KD0[jn_
0:j^[P2VYZH20:2PX00909^KV`2ATI40QhN7079bLP1PH600L71`0861P@1PH600A4A40080Fe]K00<0
H61P03Ph>00X:2P00P0S8b<0100/;2`0<c<c03Lg=`0^;Rh202LW9`04030`<00^;Rh0;2`/02PX:080
;Bd]0100;2`/02h^;P0^;Rh0@41004E5A@17AdL0@41003<c<`0/;2`0;Rh^02l_;`0m?Cd0AdM70451
@@0`<300<S8b0P0c<c<03@0e=CD0?clo04A4A010@400A4A404M7A`0o?cl0=cLg03dm?@0f=SH0@T92
03`l?00[:b/00P0Y:BT01P0V9RH0;bl_02l_;`0a<C40<S8b03De=@<0=3@d02L0<30`03Ti>@0b<S80
@T9205EEE@0V9RH0820P028R8P0X:2P0A4A406IVIP1QHF40BDU905ADE01TI6@0Ogmo0820P01TI6@0
SXj>0:b/[02IVIT0JVYZ071`L01HF5P0:RXZ034a<@0g=cL0EeMG06MWI`1JFUX0KFe]08:2PP1cLg<0
HV9R03lo?`0m?Cd0FUYJ03dm?@0^;Rh00P0`<300300];Bd0;bl_030`<00g=cL0=SHf030`<00n?Sh0
<C4a03<c<`0];Bd0:BTY02HV9P80;bl_00@0=CDe034a<@0Y:BT0;Bd]0P0[:b/05P0f=SH0;2`/02h^
;P0Y:BT0;2`/03De=@0Y:BT0:b/[02h^;P0_;bl0?3`l03Xj>P0o?cl0BTY:04m?C`1>CTh0EeMG05mO
G`1[Jf/0LG5a07MgM`1jNWX307QhN00507]kN`1fMWH0M7Ad07AdM01iNGT00P1gMgL03`1eMGD0LG5a
06=SH`13@d<0;bl_02XZ:P0V9RH0<S8b04E5A@1NGUh0JFUY06a/K01iNGT0Ogmo08:2PP0208F5Q@03
08N7Q`26QXH0QhN70080QXJ601<0Q8B408J6QP2;Rh/0R8R808B4Q02<S8`0R8R808Z:RP2CTi<0RHV9
08^;R`2<S8`0SHf=08Z:RP2ATI40U9BD08b<S02:RXX0RHV90080S8b<00H0SHf=08n?S`2?Shl0SHf=
092@T02>SXh208Z:RP0809:BTP2=SHd0S8b<08V9R@2:RXX0Rh^;08N7Q`2=SHd208N7Q`0=08B4Q023
Ph<0Q8B408V9R@27QhL0QHF508R8R02:RXX0S8b<08j>SP2=SHd0RHV908b<S00209:BTP80RXZ:00D0
SHf=096AT@2ATI40Ti>C09:BTP0209FEU@03096AT@2IVIT0V9RH0080V9RH00P0UYJF09VIV@2MWId0
WIfM0:6QX@2NWYh0XJ6Q0::RXP80Y:BT00X0YJFU0:ZZZP2YZJT0Z:RX0:ZZZP2XZ:P0[:b/0:RXZ02]
[Jd0/K6a0P2e]KD0102j^[X0][Jf0;^k^`2l_;`20;jn_P80`/;20100a/K60<O7a`3:b/X0b/[:0<_;
b`38b<P0c<c<0<k>cP3?cll0d=3@0<o?c`3AdM40d];B0=CDe03EeMD0e=CD0P3Cdm<0103EeMD0f=SH
0=GEe@3Hf=P20=WIf@0C0=_Kf`3IfMT0fm_K0=_Kf`3IfMT0a/K607UiN@1=CDd0BTY:05ADE01FEUH0
DE5A061PH01OGel0EEEE05YJFP1NGUh0FEUI05ADE00205MGE`0R059BDP1CDe<0CDe=05MGE`1<C4`0
CTi>04A4A019BDT0@41004];B`17AdL0BTY:0451@@0o?cl0A4A404I6AP1:BTX0B4Q804a<C017AdL0
Bd];04Q8B01ADE40D51@04Y:BP19BDT0De=C05MGE`1QHF40IFEU07EeM@1gMgL0OWin08R8R080S8b<
0P2@T9008`2FUYH0U9BD09bLW02QXJ40ZZZZ0:FUY@2QXJ40VYZJ09NGU`2FUYH0VYZJ0:>SX`2f][H0
a/K60<o?c`3De=@0fm_K0=kNgP3Kfm/0f][J0=?Cd`3@d=00aLG50;Zj^P2VYZH0VIVI08b<S01nOWh0
L71`069RHP1JFUX0D51@04a<C018B4P0?3`l0080?Shn00T0ATI604U9B@1@D500EEEE05QHF01LG5`0
FUYJ05=CD`1FEUH00P1?Cdl09`1:BTX0C4a<04a<C01@D500G5aL065QH@1SHf<0K6a/06i^KP1NGUh0
EUIF05eMG@1KFe/0GUiN061PH01MGEd0GemO06ATI01NGUh0EUIF05]KF`1JFUX0Fe]K065QH@1UIFD0
IfMW06UYJ@1TI6@0F5QH05iNGP1RHV80GUiN05aLG01ADE40D51@04i>CP0o?cl0=SHf03Xj>P0203<c
<`0303De=@38h=P0b>3H00`0b>3H000<0<SPf0808B4Q02P07alO02@T900S8b<09BDU02LW9`0R8R80
9BDU02LW9`0f=SH0ATI606i^KP29RHT0Vi^K0:6QX@2VYZH0[:b/0;6a/@2b/[80[jn_0:j^[P2YZJT0
WYjN096AT@22PX80N7Qh061PH00l?3`0=CDe03dm?@1=CDd0EEEE06UYJ@1mOGd0Q8B4092@T02EUID0
W9bL0:FUY@2YZJT0ZZZZ0P2[Zj/0102b/[80[Jf]0:^[Z`2b/[820;6a/@030;2`/02_[jl0[Zj^0080
/k>c01`0/[:b0;>c/`2`/;00Zj^[0:FUY@2SXj<0VYZJ09VIV@2BTY80SHf=07alO01/K6`0Jf][07]k
N`1LG5`0A4A4059BDP1IFET0GemO03/k>`0W9bL0;Rh^02/[:`0/;2`0<30`03lo?`0l?3`0:2PX0P0Z
:RX202d];@0302/[:`0_;bl0;2`/0080;2`/00<0;bl_03<c<`0i>CT00P18B4P04@0d=3@0;Bd]034a
<@0_;bl0A4A404E5A@0i>CT0<30`03Ph>00a<C40<30`03De=@11@D40BTY:03hn?P10@400AdM70080
=SHf0P0i>CT02@0d=3@0=SHf02d];@0^;Rh0;bl_02/[:`0`<300:b/[03Ph>00203Ti>@<0<C4a02/0
9BDU034a<@0`<300AdM707AdM00_;bl08R8R02@T900b<S80GemO07AdM01KFe/0D51@05eMG@1ZJVX0
Q8B4071`L01gMgL0[:b/09jNWP1`L700EEEE04i>CP0g=cL0<30`02l_;`11@D40C4a<04=3@`1JFUX0
EUIF061PH01KFe/0DU9B05iNGP1RHV80UiNG07EeM@0^;Rh0:RXZ03Hf=P0d=3@0>c/k00<0=cLg00/0
=CDe03Lg=`0c<c<0;Rh^02/[:`0Z:RX09BDU02PX:00a<C40@D5102h^;P0202PX:00<02`/;00_;bl0
;Bd]02h^;P0[:b/0;Bd]02/[:`0^;Rh0:b/[034a<@0Y:BT0>c/k0P0j>SX02P0o?cl0B4Q805ADE01?
Cdl0De=C05]KF`1TI6@0Lg=c071`L01gMgL207=cL`0=07UiN@1kNg/0NWYj075aL@1fMWH0M7Ad07Qh
N01fMWH0N7Qh07AdM01cLg<0GEeM03Ti>@0202d];@09030`<015ADD0FEUI06=SH`1VIVH0MWIf07mo
O`22PX80QXJ60080R8R800d0Ph>308F5Q@2:RXX0RHV908R8R024Q8@0QXJ608Z:RP28R8P0QXJ608R8
R02:RXX0Shn?0080Rh^;0100SXj>08n?S`2<S8`0T92@096AT@2@T900Rh^;08V9R@2=SHd0RHV908b<
S02?Shl0TY:B08n?S`28R8P0S8b<0P2:RXX00`2BTY80Shn?08Z:RP0208N7Q`0708Z:RP2;Rh/0RXZ:
08F5Q@27QhL0QXJ608V9R@0208R8R00708V9R@28R8P0QXJ608^;R`2?Shl0TI6A08f=S@0308j>SPD0
TY:B00l0Ti>C096AT@2EUID0U9BD09:BTP2IVIT0UIFE09ZJVP2EUID0Vi^K09VIV@2JVYX0WinO0:6Q
X@2LW9`00P2PX:001P2QXJ40YJFU0:JVYP2WYjL0Z:RX0:NWY`<0ZZZZ0P2/[:`05P2^[Zh0/[:b0;Rh
^02h^;P0^[Zj0;Jf]P2m_Kd0_[jn0;no_`2m_Kd0aLG50<C4a036a/H0bLW90<_;b`38b<P0bLW90<c<
c03=cLd0clo?0<k>cP3?cll20=7Ad@80d];B0P3Cdm<00`3EeMD0e]KF0=KFeP020=OGe`040=WIf@3J
f]X0f=SH0=_Kf`80fMWI0100fm_K0=OGe`2h^;P0HV9R04I6AP1BDU80E5AD05YJFP1DE5@0F5QH05mO
G`1BDU80De=C055AD@1CDe<0DU9B0P1>CTh01P1ADE40De=C04Y:BP1BDU80De=C04e=C@80BTY:00<0
C4a<04M7A`1=CDd00P18B4P0101>CTh0C4a<04i>CP1@D502055AD@0305=CD`1FEUH0CTi>0080GUiN
00`0FEUI061PH01TI6@0K6a/06e]K@1`L700OGem0861P@26QXH0SHf=09FEU@2IVIT209^KV`0A09ZJ
VP2@T900SXj>09NGU`2SXj<0X:2P09^KV`2JVYX0UIFE09JFUP2CTi<0VYZJ0:f][@30`<00bl_;0=?C
d`3IfMT00P3MgMd06@3Kfm/0e]KF0=?Cd`3:b/X0_kno0;>c/`2LW9`0Shn?08>3P`1hN7P0Jf][065Q
H@1OGel0EEEE055AD@1;Bd/0B4Q804E5A@1:BTX0D51@05ADE01FEUH0GUiN061PH01JFUX00P1GEeL2
055AD@0Z04m?C`1;Bd/0Bd];051@D01CDe<0GEeM06ATI01XJ6P0Jf][06MWI`1SHf<0I6AT061PH01O
Gel0FUYJ05mOG`1QHF40GEeM05UIF@1KFe/0FUYJ05aLG01WIfL0G5aL06IVIP1YJFT0Kfm_06UYJ@1O
Gel0IfMW069RHP1QHF40FUYJ05MGE`1?Cdl0ADE504U9B@10@400>SXj02d];@0e=CD0=3@d3P38h=P0
00`0b>3H0P0R8R808`0N7Qh08B4Q01hN7P0Q8B4092@T02HV9P0c<c<0:b/[03Hf=P15ADD0Hf=S08b<
S02KVi/0Xj>S0:JVYP2][Jd0/[:b0:n_[`2a/K40[Zj^0:RXZ02OWil0Shn?08F5Q@1fMWH0G5aL03/k
>`0e=CD0>SXj04U9B@1EEED0Jf][07alO026QXH0Shn?0080W9bL00<0Xj>S0:^[Z`2ZZZX00P2^[Zh0
1@2][Jd0[jn_0:^[Z`2`/;00/K6a00<0/[:b00@0[Zj^0;6a/@2c/k<0];Bd0P2_[jl06@2/[:`0Z:RX
0:BTY02OWil0UYJF09:BTP2;Rh/0OWin07alO01cLg<0JFUY05iNGP1:BTX0C4a<05aLG01NGUh0A4A4
02LW9`0Y:BT0:RXZ02LW9`0];Bd0?Shn04=3@`0c<c<00P0b<S80800`<300;Rh^02l_;`0_;bl0;2`/
03Lg=`0^;Rh0;bl_02`/;00e=CD0@D5104a<C00g=cL0>3Ph03<c<`0];Bd0@d=304E5A@0n?Sh0=3@d
02d];@0c<c<0>3Ph03dm?@0l?3`0AdM703lo?`13@d<0B4Q803dm?@0k>c/0<S8b0P0c<c<0200^;Rh0
;2`/02l_;`0Z:RX0;Rh^030`<00e=CD0<S8b0P0d=3@3038b<P80;Bd]0440;Rh^04Y:BP1eMGD0@D51
024Q8@0`<300BDU907]kN`1fMWH0L71`061PH01QHF40Ng]k08>3P`1XJ6P0V9RH09nOW`1jNWX0EUIF
03`l?00`<300>CTi04M7A`1EEED0B4Q803@d=012@T80BTY:04E5A@1:BTX0Bd];03Ph>013@d<0JFUY
09NGU`2HV9P0?clo02d];@0n?Sh0ADE505EEE@1LG5`0<c<c038b<P0[:b/0:BTY03<c<`0b<S80<c<c
02TY:@0T92@09RHV02l_;`0i>CT0<30`02l_;`0[:b/0;Bd]02`/;00b<S80<30`038b<P0Y:BT0;2`/
02LW9`0202TY:@0302XZ:P0h>3P0>CTi0080=SHf00T0AdM704i>CP1>CTh0DE5A05EEE@1MGEd0Jf][
06i^KP1aLG400P1fMWH0:01hN7P0NGUi07IfMP1dM7@0MgMg07AdM01gMgL0MWIf07QhN01kNg/0OGem
06EUI@1;Bd/0=SHf02HV9P0[:b/0?Shn05MGE`1HF5P0GemO06m_K`1jNWX0Ogmo08J6QP25QHD0QXJ6
0861P@24Q8@0Rh^;08Z:RP24Q8@0QXJ608:2PP27QhL0RHV908N7Q`2CTi<0RHV908j>SP2<S8`208n?
S`0408f=S@2>SXh0Shn?09>CT`80SXj>0140Rh^;08b<S02ATI40Rh^;09:BTP2?Shl0SXj>08f=S@29
RHT0R8R808Z:RP2=SHd0RHV908R8R027QhL0S8b<08R8R00208^;R`0A08R8R029RHT0Q8B408Z:RP25
QHD0R8R808Z:RP2=SHd0R8R808f=S@2:RXX0SHf=08n?S`2=SHd0Shn?08b<S02DU9@00`2BTY802`2@
T900Ti>C09BDU02GUiL0TY:B09FEU@2GUiL0V9RH09ZJVP2HV9P0Vi^K00<0W9bL0P2NWYh00`2OWil0
X:2P0:>SX`020:FUY@070:VYZ@2/[:`0Z:RX0:RXZ02_[jl0[:b/0:j^[P020:f][@030;:b/P2f][H0
^k^k0080^k^k01D0^KVi0;jn_P2o_kl0_kno0<;2`P33`l<0a/K60<O7a`38b<P0bLW90<[:bP3;bl/0
c<c<0<o?c`3@d=00clo?0=7Ad@3@d=00e=CD0=?Cd`3EeMD00P3De=@0203EeMD0e]KF0=GEe@3GemL0
f=SH0=[JfP3Hf=P0fMWI0P3Kfm/0403Jf]X0eMGE0:FUY@1NGUh0BDU9055AD@1DE5@0F5QH04I6AP1G
EeL0GemO05=CD`19BDT0DU9B051@D01ADE4204i>CP0704a<C01?Cdl0B4Q8055AD@1:BTX0BDU904a<
C002059BDP0305IFEP1CDe<0De=C0080DU9B00X0Cdm?05QHF01EEED0F5QH05eMG@1LG5`0HV9R05mO
G`1VIVH0Hf=S0P1TI6@02@1_Kfl0KVi^07]kN`1jNWX0QXJ608V9R@2<S8`0TI6A09BDU00209jNWP05
0:2PX02LW9`0V9RH09>CT`2@T9000P2ATI40:02EUID0UYJF08n?S`2;Rh/0Shn?09BDU02VYZH0_Kfm
0<[:bP3Bd]80fMWI0=[JfP3Lg=`0gMgM0=OGe`3De=@0c/k>0<C4a02i^KT0YjNW09ZJVP2:RXX0PH61
07MgM`1[Jf/0GemO05aLG01GEeL0EUIF059BDP19BDT0Bd];04M7A`1<C4`0De=C05UIF@1RHV80Hf=S
061PH01NGUh205YJFP0<05=CD`18B4P0B4Q804E5A@1@D500FEUI065QH@1WIfL0Hf=S06QXJ01]KFd0
IVIV0P1MGEd0101OGel0G5aL065QH@1OGel205eMG@0705aLG01GEeL0GemO05mOG`1UIFD0Hf=S06UY
J@0206EUI@05061PH01LG5`0I6AT05eMG@1GEeL00P1;Bd/01P15ADD0?3`l03Lg=`0b<S80=SHf03`l
?0h0b>3H000<0<SPf0808b<S00L0:BTY024Q8@0N7Qh07alO02<S8`0Q8B40;Rh^0080<c<c01l0CDe=
06][J`2:RXX0Vi^K0:VYZ@2ZZZX0[Zj^0;6a/@2][Jd0/;2`0:b/[02VYZH0WYjN08^;R`21PH40Kfm_
051@D00i>CT0>SXj03`l?015ADD0DU9B06m_K`1mOGd0QHF5096AT@2IVIT0WIfM0::RXP2WYjL0Zj^[
00<0[Zj^00H0/;2`0;:b/P2^[Zh0/;2`0;6a/@2b/[830;2`/0070;Fe]@2d];@0/K6a0;6a/@2ZZZX0
YZJV0:FUY@0209ZJVP12092@T028R8P0P82007inOP1[Jf/0IVIV05MGE`1>CTh0DU9B05aLG01TI6@0
A4A402/[:`0V9RH0;Bd]02XZ:P0[:b/0<30`0492@P0j>SX0;Rh^02`/;00];Bd09bLW02/[:`0b<S80
;Bd]02/[:`0_;bl0;Bd]03<c<`0d=3@0?clo04M7A`19BDT0=CDe030`<00];Bd0@41004I6AP0o?cl0
<c<c03Hf=P0h>3P0=cLg03Hf=P13@d<0@41003Ti>@14A4@0DE5A03Xj>P0g=cL0=SHf03De=@0_;bl0
;2`/02d];@0X:2P0;2`/02DU9@0X:2P0=SHf034a<@0Y:BT0:b/[0P0X:2P0>00n?Sh0;bl_02d];@0c
<c<0=3@d05=CD`16ATH0:b/[04U9B@1eMGD0O7al06m_K`1ZJVX0G5aL06ATI027QhL0Q8B408R8R02L
W9`0MGEe04=3@`0j>SX0<C4a03De=@18B4P0Hf=S04];B`0[:b/0<C4a04I6AP0d=3@0=cLg03lo?`0l
?3`0;2`/03`l?018B4P0JVYZ08f=S@1=CDd0?Cdm05YJFP1XJ6P0LW9b08J6QP0o?cl09RHV02d];@0Z
:RX0<C4a03Ti>@0c<c<0<C4a02LW9`0V9RH0:RXZ0P0f=SH0100];Bd0:RXZ038b<P0a<C4202PX:00D
038b<P0Z:RX0:b/[02PX:00V9RH0:BTY02d];@0^;Rh0<30`038b<P0n?Sh0B4Q804U9B@1<C4`0CTi>
05IFEP1LG5`0IFEU07EeM@1cLg<207IfMP0W07UiN@1gMgL0LG5a07IfMP1dM7@0MGEe07AdM01lO7`0
MWIf07EeM@1iNGT0LG5a05eMG@19BDT0<30`02`/;00i>CT0Bd];05MGE`1KFe/0IVIV079bLP22PX80
Ph>30820P026QXH0Ph>308J6QP28R8P0RXZ:08J6QP27QhL0QXJ608b<S028R8P0SHf=08n?S`2ATI40
Shn?0080TI6A0P2>SXh01@2@T900Ti>C09FEU@2ATI40RHV90080RXZ:01D0SXj>08n?S`2BTY80TY:B
092@T02=SHd0Rh^;08j>SP2<S8`0SXj>08b<S029RHT0RXZ:08b<S029RHT0R8R808^;R`25QHD0Q8B4
08N7Q`2;Rh/00P28R8P208^;R`80S8b<00@0RHV908b<S02DU9@0Rh^;0P2ATI405P2EUID0U9BD09BD
U02@T900TI6A09>CT`2JVYX0UIFE09>CT`2FUYH0VYZJ09VIV@2GUiL0XJ6Q09ZJVP2NWYh0WIfM09^K
V`2MWId0WinO0:2PX02RXZ820:>SX`80Z:RX0P2YZJT07@2XZ:P0ZJVY0:^[Z`2/[:`0/;2`0;6a/@2c
/k<0];Bd0;Zj^P2n_[h0^k^k0;Rh^02m_Kd0_kno0<30`031`L40`l?30<C4a036a/H0bl_;0<W9b@3<
c<`0c/k>0<c<c03@d=00clo?0=3@d03?cll0d];B0080dm?C00`0f=SH0=?Cd`3EeMD0dm?C0=OGe`3D
e=@0emOG0=WIf@3Hf=P0fMWI0=[JfP3Kfm/20=[JfP050<k>cP2@T900EeMG04A4A01>CTh00P1CDe<0
1`13@d<0FEUI065QH@1=CDd0AdM704Y:BP17AdL00`15ADD03`14A4@0B4Q804a<C01BDU80Cdm?055A
D@1?Cdl0E5AD05YJFP1OGel0EeMG05UIF@1LG5`0GEeM05iNGP02061PH080I6AT00<0JFUY06a/K01^
KVh00P1^KVh01`1_Kfl0Lg=c07YjNP23Ph<0Ogmo08N7Q`2:RXX00P2@T9002P2FUYH0W9bL09jNWP2U
YJD0Xj>S09jNWP2JVYX0U9BD09>CT`23Ph<20820P00V08N7Q`25QHD0QHF508B4Q02HV9P0XZ:R0;fm
_@3:b/X0dM7A0=GEe@3Hf=P0gMgM0=kNgP3Kfm/0emOG0=7Ad@39bLT0_Kfm0;6a/@2PX:00TI6A08R8
R01kNg/0LW9b06YZJP1OGel0F5QH05aLG01DE5@0De=C055AD@15ADD0CTi>055AD@1EEED0EeMG05]K
F`1QHF4305iNGP0G05ADE01@D500A4A404A4A01>CTh0EEEE05MGE`1TI6@0HF5Q06UYJ@1cLg<0IVIV
061PH01OGel0GEeM05YJFP1PH600G5aL05mOG`1QHF40H61P05UIF@1KFe/00P1PH6001P1QHF40IFEU
06UYJ@1ZJVX0Hf=S061PH080HF5Q00T0GemO04m?C`19BDT0Bd];03dm?@0f=SH0>3Ph03De=@0i>CT0
3P38h=P000`0b>3H0P0T92@03P0V9RH09BDU02<S8`0S8b<08R8R02DU9@0Y:BT0<30`03`l?01EEED0
JFUY07inOP2HV9P0Zj^[0P2^[Zh0602_[jl0[Zj^0:b/[02/[:`0YjNW09NGU`2?Shl0PX:206YZJP1;
Bd/0?clo03`l?00j>SX0A4A405ADE01/K6`0Ng]k08V9R@2=SHd0V9RH09nOW`2SXj<0YjNW0:b/[0<0
Zj^[00@0/;2`0:f][@2^[Zh0[:b/0P2a/K401`2b/[80/k>c0;6a/@2d];@0]kNg0;:b/P2_[jl00P2[
Zj/02`2SXj<0X:2P09VIV@2BTY80Ph>307moO`20P800Kfm_06e]K@1ADE40ADE50080De=C00`0EEEE
03Xj>P0[:b/09BDU02HV9P0X:2P0<S8b03@d=00j>SX0@T9203<c<`0d=3@202d];@0:02`/;00_;bl0
;2`/02l_;`0^;Rh0:b/[02l_;`0d=3@0?Cdm03lo?`80A4A40180=3@d038b<P0i>CT0A4A40492@P10
@400<30`03<c<`0b<S80<C4a03Ti>@12@T80>CTi0451@@1FEUH0>c/k03De=@0c<c<2030`<00902h^
;P0_;bl0:RXZ02d];@0W9bL0;2`/03Lg=`0];Bd0:RXZ00<0:2PX01X0>CTi03Xj>P0c<c<0>3Ph02PX
:00j>SX0>CTi04=3@`1XJ6P0HV9R065QH@1OGel0GEeM05MGE`1iNGT0QXJ607AdM02ATI40Shn?05=C
D`0e=CD0<30`02l_;`0o?cl0F5QH04Y:BP80:BTY01d0>CTi0451@@0b<S80>SXj03@d=00`<300;Bd]
03Ph>00i>CT0DU9B08F5Q@1CDe<0A4A405YJFP1^KVh0IVIV07emO@1CDe<0:2PX02HV9P0`<300;Rh^
03<c<`0b<S80=3@d02`/;00R8R809RHV02l_;`0303<c<`0<02/[:`0a<C40<c<c02`/;00Z:RX0:BTY
02h^;P0_;bl092@T02HV9P0];Bd0<C4a0P0b<S802P0l?3`0Bd];04=3@`18B4P0BDU9051@D01DE5@0
Fe]K06YZJP1_Kfl207AdM00:079bLP1aLG40MgMg07AdM01cLg<0LW9b07IfMP1nOWh0OGem07UiN@80
NWYj00/0KVi^05EEE@0b<S80:2PX034a<@18B4P0DU9B05YJFP1MGEd0KVi^0820P00208:2PP0408F5
Q@23Ph<0QhN708F5Q@80QXJ600P0Rh^;08F5Q@2:RXX0Rh^;08V9R@2=SHd0SXj>08f=S@80Shn?0P2A
TI401P2@T900TI6A09FEU@2;Rh/0SHf=08b<S080Rh^;0`2?Shl0102ATI40SXj>08b<S02CTi<208n?
S`0808j>SP2:RXX0R8R808B4Q025QHD0QXJ608^;R`2:RXX208N7Q`80R8R800D0RXZ:08V9R@2=SHd0
Shn?08V9R@0208b<S080Ti>C00<0Shn?09:BTP2@T9000P2ATI40202@T900V9RH09JFUP2FUYH0Ti>C
09RHV02FUYH0UIFE0P2IVIT02@2MWId0VYZJ09bLW02NWYh0W9bL09nOW`2PX:00WinO0:6QX@030:JV
YP0G0:NWY`2YZJT0Z:RX0:VYZ@2[Zj/0[jn_0:^[Z`2_[jl0/;2`0;Jf]P2e]KD0_;bl0;jn_P2l_;`0
_Kfm0<30`02n_[h0`<300<71`@32`/80aLG50<W9b@3:b/X00P3<c<`20<k>cP080=7Ad@3?cll0d];B
0=3@d03Bd]80eMGE0=CDe03EeMD20=?Cd`0>0=KFeP3De=@0e=CD0=SHf03IfMT0f][J0=SHf03Jf]X0
g=cL0=[JfP3IfMT0a<C408B4Q01JFUX204U9B@0:04e=C@1?Cdl0BTY:04Y:BP1EEED0C4a<0492@P13
@d<0ATI604];B`80CDe=0140Bd];04m?C`1ADE40Fe]K04m?C`1EEED0FEUI05YJFP1UIFD0H61P05mO
G`1PH600HF5Q06][J`1ZJVX0J6QX06IVIP0206i^KP0U07EeM@1fMWH0M7Ad07MgM`21PH40MgMg07al
O020P800QXJ608R8R026QXH0RXZ:092@T02CTi<0VIVI09jNWP2RXZ80X:2P09fMW@2KVi/0UiNG09:B
TP2@T900QXJ607emO@1iNGT0OWin0820P024Q8@0QhN709>CT`2QXJ40][Jf0<O7a`3=cLd0dm?C0=OG
e`020=_Kf`0@0=[JfP3GemL0dm?C0<o?c`37alL0^KVi0:b/[02JVYX0S8b<0820P01hN7P0KVi^06QX
J01RHV80Fe]K05MGE`80DU9B00P0AdM7055AD@1@D500DE5A05]KF`1UIFD0HV9R06EUI@80GEeM00h0
FEUI05MGE`18B4P0@41004Q8B01;Bd/0De=C05aLG01OGel0IVIV06QXJ01WIfL0HV9R05eMG@80GemO
00P0HV9R05eMG@1MGEd0GUiN05]KF`1OGel0Fe]K05iNGP80GEeM00D0IFEU06i^KP1ZJVX0IVIV069R
HP0205iNGP0905MGE`1LG5`0Cdm?04];B`15ADD0>SXj03Ti>@0j>SX0>CTi00h0b>3H000<0<SPf080
8b<S01/092@T01lO7`0Q8B40:2PX02TY:@0S8b<0:2PX030`<017AdL0GEeM06m_K`24Q8@0U9BD09fM
W@2WYjL0[Zj^0:n_[`2^[Zh0/;2`0:RXZ02RXZ80WYjN08Z:RP1hN7P0HF5Q0492@P0n?Sh00P12@T80
2`1:BTX0EeMG06a/K01oOgl0Rh^;09BDU02JVYX0XJ6Q0:FUY@2/[:`0Zj^[0080[jn_00P0[:b/0:f]
[@2`/;00[Zj^0:n_[`2a/K40/[:b0;6a/@80/k>c03@0/[:b0;>c/`2c/k<0ZJVY0:^[Z`2VYZH0Xj>S
0:2PX02GUiL0SXj>0861P@1lO7`0PX:207MgM`1QHF40De=C04i>CP1OGel0DE5A04];B`10@400;Bd]
02DU9@0X:2P0:RXZ02TY:@0_;bl0<c<c03Xj>P0k>c/0@D5103Hf=P0_;bl0<C4a03Hf=P0`<300>SXj
02/[:`0];Bd0<30`02`/;00k>c/0=SHf03`l?016ATH0@D5103<c<`0h>3P0ADE50410@00j>SX0<S8b
0P0e=CD05@0i>CT0>SXj04a<C011@D40BDU904i>CP0i>CT0=cLg038b<P0W9bL0<30`02PX:00Z:RX0
=cLg03Hf=P0a<C40;bl_02`/;00X:2P0:BTY02HV9P0202PX:01D03/k>`1=CDd0ADE502TY:@0/;2`0
;bl_03hn?P1;Bd/0D51@03lo?`0g=cL0?3`l04Q8B01TI6@0O7al0861P@1ZJVX0WYjN07=cL`0d=3@0
=CDe03Ti>@0o?cl0ADE503/k>`0W9bL0:RXZ02d];@0h>3P0@41004i>CP15ADD0>CTi0492@P0b<S80
:RXZ0410@01FEUH0OWin06i^KP1LG5`0I6AT06QXJ01OGel0P82007EeM@0_;bl09bLW02XZ:P0c<c<0
<30`03@d=00h>3P0<C4a02TY:@0^;Rh0:2PX02l_;`0b<S80:b/[02`/;00_;bl0=SHf038b<P0i>CT0
:BTY02XZ:P0S8b<09RHV02DU9@0[:b/0=3@d02d];@0d=3@0>c/k04=3@`15ADD0A4A404I6AP1=CDd0
Cdm?05eMG@1WIfL0KVi^0P1bLW801P1`L700M7Ad07=cL`1hN7P0M7Ad07]kN`80NWYj0P1mOGd03@1n
OWh0Ng]k07IfMP1RHV80C4a<034a<@0_;bl0=CDe04i>CP1HF5P0GUiN069RHP1gMgL00`27QhL0202:
RXX0R8R808F5Q@24Q8@0R8R808J6QP28R8P0SXj>0`2;Rh/00`2<S8`0SXj>092@T00208n?S`0508b<
S02@T900T92@096AT@2@T9000P2?Shl01@2ATI40SHf=08n?S`2>SXh0Shn?0080SHf=0P2?Shl04`2;
Rh/0S8b<08Z:RP2:RXX0QhN708J6QP2;Rh/0R8R808b<S02;Rh/0QXJ608R8R029RHT0R8R808Z:RP2=
SHd0S8b<08Z:RP2;Rh/00P2@T9001@2?Shl0TY:B096AT@2EUID0TI6A0080TY:B0P2DU9@02`2CTi<0
UYJF09NGU`2EUID0VIVI09^KV`2GUiL0VIVI09NGU`2KVi/0VYZJ0080WinO00H0WYjN09nOW`2QXJ40
XZ:R0:FUY@2TY:@20:NWY`040:^[Z`2ZZZX0ZJVY0:VYZ@80[:b/00D0/;2`0;6a/@2f][H0]kNg0;^k
^`020;jn_P0:0;bl_02o_kl0`L710<71`@30`<00`/;20<G5a@37alL0bl_;0<k>cP80c<c<0`3@d=00
103Bd]80dM7A0=?Cd`3Cdm<20=GEe@0:0=CDe03Cdm<0f=SH0=GEe@3Hf=P0emOG0=SHf03GemL0f=SH
0=_Kf`80f][J0100f=SH0;Vi^@1nOWh0I6AT055AD@1BDU80DE5A04a<C00k>c/0?Cdm04U9B@1=CDd0
ADE504=3@`1@D500DE5A0P1@D5004`1ADE40FUYJ05UIF@1MGEd0FEUI05EEE@1PH600HV9R06IVIP1S
Hf<0JFUY06i^KP1_Kfl0Lg=c07IfMP1eMGD0LG5a07EeM@21PH400P1oOgl04`1lO7`0PH610861P@1n
OWh0Ph>308N7Q`29RHT0SHf=08Z:RP2DU9@0T92@09NGU`2KVi/0W9bL09fMW@2JVYX0WinO09RHV02B
TY800P2>SXh00`25QHD0PH6107emO@020861P@0:08>3P`28R8P0TY:B09^KV`2_[jl0`L710<_;b`3C
dm<0e=CD0=[JfP80gMgM01T0f][J0=CDe03@d=00bLW90<30`02b/[80YZJV08n?S`23Ph<0NGUi07Ee
M@1]KFd0IFEU06IVIP1IFET0Fe]K05MGE`1=CDd0Bd];05QHF01ADE40G5aL05eMG@1PH600Hf=S0080
GemO00X0GUiN05MGE`19BDT0BDU904M7A`1:BTX0CDe=05EEE@1BDU80Hf=S0P1[Jf/0401YJFT0I6AT
05iNGP1PH600GemO06EUI@1SHf<0GUiN05eMG@1OGel0G5aL05IFEP1LG5`0GUiN06QXJ01ZJVX206UY
J@0<065QH@1OGel0GUiN05eMG@1BDU80Fe]K04i>CP1=CDd0A4A403`l?00f=SH0>c/k3P38h=P000`0
b>3H0P0U9BD0400W9bL08B4Q02<S8`0Q8B4092@T02<S8`0[:b/0=CDe04I6AP1WIfL0Lg=c08J6QP2B
TY80Vi^K0:>SX`2ZZZX20:n_[`080:ZZZP2YZJT0XZ:R09NGU`29RHT0Kfm_05YJFP14A4@203dm?@0<
0451@@1@D500GEeM06a/K021PH40R8R809>CT`2KVi/0XZ:R0:>SX`2`/;00[Zj^0P2][Jd01P2/[:`0
/K6a0;2`/02`/;00/K6a0:j^[P80/K6a02X0/[:b0;6a/@2e]KD0];Bd0;6a/@2`/;00ZJVY0::RXP2T
Y:@0WYjN09BDU02;Rh/0P82007alO026QXH0QhN7065QH@18B4P0CDe=065QH@19BDT0?Shn04A4A00/
;2`09bLW02PX:00];Bd0;Rh^02`/;00c<c<0<S8b03<c<`0e=CD0=3@d02d];@0h>3P0<30`02l_;`0`
<300:RXZ034a<@0/;2`2030`<00M03<c<`0b<S80?Cdm04Q8B00i>CT0<C4a04E5A@1:BTX0?Cdm03@d
=00`<300;Rh^03De=@0i>CT0AdM7051@D01BDU80B4Q803/k>`0^;Rh0;2`/02XZ:P0a<C40:RXZ02TY
:@0_;bl0>3Ph03Lg=`0a<C400P0/;2`0=@0Y:BT0:b/[02HV9P0V9RH0=3@d051@D01IFET0<30`02LW
9`0a<C40@D5104=3@`0f=SH0<C4a03Ph>00m?Cd0Cdm?07UiN@1mOGd0Ng]k07emO@2:RXX0BDU9038b
<P15ADD0C4a<0410@00/;2`09bLW020P800W9bL0;bl_03Lg=`0l?3`0BDU905]KF`1RHV80AdM7034a
<@0Y:BT0?Cdm05aLG01hN7P0Ogmo07UiN@1LG5`0Fe]K059BDP28R8P0Ogmo03Xj>P0S8b<0:BTY0080
<c<c0P0l?3`02`0e=CD09BDU03De=@0[:b/0<C4a03@d=00^;Rh0<30`03<c<`0_;bl0<S8b0080;Rh^
00<0;Bd]02TY:@0T92@00P0W9bL01`0Y:BT0;2`/03@d=00i>CT0?Shn03dm?@13@d<00P16ATH0101?
Cdl0EEEE05mOG`1YJFT2071`L00:06m_K`1cLg<0MgMg07=cL`1bLW80MGEe07UiN@21PH40OWin07mo
O`80Ng]k00h0NGUi075aL@1FEUH0A4A403Hf=P0b<S80?Cdm055AD@1LG5`0HF5Q06i^KP24Q8@0RXZ:
08N7Q`80Q8B400T0R8R808F5Q@26QXH0QXJ608B4Q029RHT0Rh^;08N7Q`2=SHd00P2<S8`01P29RHT0
T92@08n?S`2@T900SHf=08n?S`80TI6A01/0Rh^;09BDU02=SHd0Ti>C092@T02>SXh0Rh^;08f=S@2;
Rh/0SXj>092@T029RHT0Rh^;08V9R@2>SXh0Rh^;08J6QP2>SXh0RHV908b<S026QXH0R8R808J6QP2:
RXX0RHV908N7Q`2;Rh/00P2:RXX208b<S00609FEU@2?Shl0TI6A096AT@2FUYH0TI6A0P2EUID0102N
WYh0Ti>C09FEU@2GUiL209^KV`0G09VIV@2KVi/0VIVI09^KV`2HV9P0VIVI09bLW02NWYh0XZ:R0:BT
Y02QXJ40X:2P0:BTY02SXj<0YJFU0:JVYP2WYjL0Z:RX0:ZZZP2/[:`0ZJVY0:b/[02ZZZX00P2e]KD0
202f][H0]KFe0;bl_02m_Kd0^k^k0;jn_P2o_kl0_[jn1034a<@02@38b<P0bl_;0<W9b@3<c<`0c/k>
0<o?c`3AdM40d];B0=?Cd`020=;BdP0K0=?Cd`3GemL0emOG0=KFeP3EeMD0fMWI0=GEe@3GemL0f=SH
0=OGe`3Hf=P0e]KF0=WIf@3Lg=`0fMWI0=?Cd`2^[Zh0P82007EeM@1HF5P0DU9B051@D01>CTh0ADE5
04m?C`1>CTh0HV9R0080C4a<01L0DU9B05MGE`1EEED0EEEE05IFEP1QHF40GemO069RHP1SHf<0IVIV
06MWI`1[Jf/0KFe]071`L01aLG40Lg=c07]kN`1gMgL0NGUi07YjNP1mOGd0Ogmo08J6QP0208B4Q00@
08F5Q@29RHT0QhN708J6QP2:RXX0QhN708^;R`2<S8`0T92@096AT@2BTY80UiNG096AT@2CTi<0Vi^K
09RHV080VYZJ0P2ATI40:`2<S8`0RXZ:08V9R@24Q8@0QXJ608F5Q@26QXH0Rh^;08f=S@2GUiL0YJFU
0;Rh^036a/H0clo?0=?Cd`3IfMT0f][J0=gMg@3Kfm/0eMGE0=3@d03<c<`0aLG50;bl_02][Jd0UiNG
08Z:RP1nOWh0MGEe071`L01/K6`0IfMW06IVIP1KFe/0EUIF04e=C@1?Cdl0CDe=04i>CP1FEUH0FEUI
05mOG`1VIVH00P1UIFD0801RHV80FUYJ05=CD`1=CDd0AdM704E5A@1;Bd/0De=C04m?C`1KFe/0HF5Q
06i^KP1VIVH0IFEU065QH@1TI6@0GemO05]KF`1RHV80I6AT05iNGP1LG5`0GEeM05UIF@1OGel0Fe]K
065QH@1XJ6P0IVIV06UYJ@1SHf<0FUYJ0P1NGUh0201DE5@0EUIF055AD@1<C4`0@41003dm?@11@D40
=CDe3P38h=P000`0b>3H0`0W9bL09`0Q8B407QhN01lO7`0S8b<0:BTY02XZ:P0c<c<0Cdm?06UYJ@1m
OGd0Rh^;09>CT`2HV9P0WYjN0:>SX`2XZ:P0YjNW0:RXZ02UYJD0VYZJ08j>SP24Q8@0L71`05YJFP17
AdL0>c/k0410@011@D40CDe=05iNGP1^KVh0P82008^;R`2ATI40X:2P0::RXP2ZZZX0[Jf]0:^[Z`02
0;2`/0<0/K6a0P2_[jl20;6a/@1>0;:b/P2a/K40];Bd0;:b/P2c/k<0/;2`0:^[Z`2XZ:P0YZJV0:2P
X02LW9`0V9RH08f=S@20P800Q8B409BDU02BTY80I6AT04=3@`1BDU80H61P0451@@12@T80Bd];03<c
<`0f=SH0;2`/034a<@0X:2P0<30`02d];@0^;Rh0<C4a03@d=00a<C40?3`l03<c<`0^;Rh0<C4a02h^
;P0[:b/0;2`/02XZ:P0^;Rh0=cLg02h^;P0[:b/0>c/k04];B`0n?Sh0;2`/0410@017AdL0?3`l03Hf
=P0c<c<0?Shn03Xj>P0i>CT0A4A4061PH01EEED0Bd];03/k>`0c<c<0:RXZ02PX:00a<C40:b/[02l_
;`0a<C40<c<c02l_;`0a<C40<c<c02h^;P0[:b/09RHV0P0W9bL01P0[:b/0DU9B05YJFP0g=cL0;2`/
03Lg=`80=SHf0P0_;bl0BP0f=SH0ATI606ATI01lO7`0NGUi07AdM026QXH0JFUY03Ph>013@d<0EEEE
03`l?00`<300=3@d030`<00S8b<0;Rh^02l_;`0f=SH0ADE507QhN02ATI40MGEe03/k>`0c<c<0;bl_
03hn?P1VIVH0K6a/071`L01XJ6P0Bd];04e=C@1EEED0VYZJ07]kN`1;Bd/0:BTY02LW9`0a<C40<30`
03De=@14A4@0?3`l02l_;`0U9BD0:2PX02HV9P0a<C40=CDe02l_;`0a<C40<c<c02h^;P0/;2`09bLW
030`<00/;2`0:2PX02d];@0[:b/0;Bd]02`/;00b<S80=SHf03Xj>P0k>c/0=cLg04E5A@17AdL0C4a<
05=CD`1JFUX0Hf=S0P1ZJVX06@1_Kfl0LG5a07AdM01dM7@0MGEe07AdM01kNg/0NWYj07emO@1oOgl0
Ng]k07YjNP1iNGT0MWIf06UYJ@17AdL0>3Ph03@d=00i>CT0DU9B05UIF@1OGel0JFUY07inOP22PX80
0P25QHD01`24Q8@0R8R808R8R02:RXX0Q8B408R8R02<S8`00P29RHT01`2?Shl0RHV908R8R02>SXh0
Rh^;08j>SP2ATI400P2>SXh01P2ATI40SXj>096AT@2ATI40S8b<08j>SP80SHf=01h0S8b<08j>SP2?
Shl0SHf=08n?S`2=SHd0SXj>092@T02<S8`0QhN708V9R@2:RXX0R8R808N7Q`2<S8`0RHV908N7Q`28
R8P0SXj>08Z:RP28R8P0S8b<09:BTP2>SXh0Shn?096AT@2?Shl0T92@09BDU02FUYH309NGU`0409FE
U@2@T900UYJF09FEU@80VYZJ00h0UYJF09bLW02LW9`0VIVI09JFUP2KVi/0WYjN09nOW`2TY:@0XZ:R
0:>SX`2TY:@0XZ:R0:VYZ@80YJFU0100ZZZZ0:b/[02YZJT0ZZZZ0:f][@2^[Zh0[:b/0;>c/`2h^;P0
^[Zj0;^k^`2m_Kd0^k^k0;fm_@32`/80`<300P31`L401037alL0a<C40<O7a`3:b/X20<_;b`0W0<[:
bP38b<P0d=3@0<o?c`3AdM40eMGE0=CDe03Bd]80dM7A0=GEe@3De=@0dm?C0=CDe03EeMD0e=CD0=KF
eP3GemL0dm?C0=SHf03GemL0f=SH0=[JfP3Hf=P0bLW909ZJVP25QHD0P82006MWI`1JFUX0G5aL04e=
C@1;Bd/0Cdm?05EEE@1WIfL0De=C055AD@1HF5P0GEeM00<0GUiN00L0I6AT06=SH`1^KVh0Kfm_071`
L01fMWH0MGEe0080N7Qh00L0OWin07moO`1nOWh0QXJ608N7Q`22PX80QHF50080R8R80P29RHT02P26
QXH0SXj>08j>SP2=SHd0SXj>08b<S02>SXh0T92@08^;R`2<S8`208f=S@0308j>SP2CTi<0V9RH0080
W9bL01@0Vi^K09RHV02GUiL0Ti>C08^;R`2@T900S8b<08R8R026QXH0QhN708^;R`28R8P0TY:B09^K
V`2c/k<0a<C40<k>cP3Cdm<0emOG0=[JfP80g=cL00X0emOG0=GEe@3>c/h0alO70<30`02_[jl0VYZJ
08j>SP20P800N7Qh0P1aLG4206QXJ00:06ATI01OGel0F5QH05=CD`1HF5P0Cdm?05EEE@1FEUH0GUiN
065QH@80IFEU01T0IfMW05]KF`1GEeL0CTi>04e=C@12@T80ATI604Y:BP1EEED0Fe]K06=SH`1/K6`0
KFe]06QXJ01VIVH0IFEU065QH@1MGEd0H61P065QH@1SHf<0FUYJ05ADE01GEeL0FUYJ0080GemO00l0
IFEU06][J`1XJ6P0IfMW05mOG`1NGUh0Fe]K05UIF@1JFUX0EUIF04];B`17AdL0@T9203hn?P0d=3@0
3P38h=P000`0b>3H0P0W9bL06`0V9RH0:RXZ02LW9`0P82008R8R02PX:00V9RH0<30`04i>CP1YJFT0
PH6108n?S`2GUiL0Vi^K0:6QX@2SXj<0Y:BT0::RXP2NWYh0XJ6Q09JFUP2=SHd0QXJ607EeM@1QHF40
BDU90492@P0203dm?@0;04a<C01FEUH0KVi^07alO02<S8`0Ti>C09RHV02PX:00Xj>S0:VYZ@2^[Zh0
0P2`/;00102b/[80[Zj^0;6a/@2a/K420;2`/0030;6a/@2`/;00[Zj^0080/[:b01L0/K6a0:j^[P2^
[Zh0ZJVY0:BTY02SXj<0Vi^K09>CT`2;Rh/0OGem08R8R02MWId0TY:B05eMG@0k>c/0Bd];05eMG@10
@400=3@d0451@@0f=SH0;Rh^02XZ:P0202TY:@0a02PX:00];Bd0;Rh^02l_;`0b<S80;2`/034a<@0c
<c<0=cLg030`<00/;2`0:RXZ02h^;P0/;2`0=cLg03hn?P0d=3@0:b/[038b<P0m?Cd0Bd];03De=@0i
>CT0@d=30451@@0i>CT0=cLg03Hf=P0d=3@0=cLg03lo?`1<C4`0D51@04=3@`0i>CT0;Rh^02d];@0d
=3@0>CTi034a<@0e=CD0@D5104A4A00g=cL0;2`/02/[:`0Y:BT09bLW02HV9P0202TY:@0I02/[:`17
AdL0J6QX051@D00a<C40=3@d03Hf=P0a<C40;2`/02/[:`0f=SH0B4Q806][J`1kNg/0N7Qh07MgM`1_
Kfl0@d=303Hf=P1OGel0?Cdm02/[:`0m?Cd0>SXj03<c<`0202TY:@0R02@T900n?Sh0GEeM09^KV`2F
UYH0GUiN03<c<`0_;bl0=CDe0492@P1GEeL0FEUI04I6AP1LG5`0@T9205MGE`20P800WinO0820P01K
Fe/09RHV024Q8@0a<C40<c<c034a<@0i>CT0=SHf02l_;`0W9bL09BDU02XZ:P0i>CT0?clo03Ph>080
<c<c00D0=3@d02XZ:P0[:b/0=cLg02l_;`0202`/;00>02DU9@0^;Rh0:2PX02l_;`0l?3`0;bl_02/[
:`0a<C40?3`l04I6AP19BDT0DE5A05EEE@1SHf<206][J`0306i^KP1_Kfl0KVi^0080MWIf0P1hN7P0
101fMWH0PH6107YjNP1iNGT207moO`0=07UiN@1/K6`0D51@0492@P0d=3@0<c<c04e=C@1LG5`0Fe]K
06UYJ@1eMGD0OGem08B4Q00208>3P`0>08^;R`29RHT0RHV908J6QP27QhL0TI6A08Z:RP29RHT0R8R8
08^;R`29RHT0SXj>08Z:RP28R8P208j>SP07092@T02>SXh0SHf=092@T02ATI40Ti>C08j>SP02092@
T00708b<S02=SHd0SHf=08b<S02@T900S8b<08^;R`0208b<S00F08V9R@28R8P0R8R808Z:RP27QhL0
SHf=08Z:RP27QhL0Rh^;096AT@2<S8`0Rh^;08n?S`2>SXh0Ti>C092@T02=SHd0TI6A08j>SP2BTY80
UIFE09NGU`80Ti>C01l0UIFE096AT@2HV9P0UYJF09BDU02GUiL0V9RH09NGU`2KVi/0UiNG09VIV@2L
W9`0WIfM09bLW02OWil0X:2P09nOW`2RXZ80Y:BT0:>SX`2WYjL0ZJVY0:RXZ02/[:`0[Jf]0:^[Z`2^
[Zh0]KFe0;2`/02c/k<0][Jf0080^;Rh00D0_Kfm0;bl_02n_[h0`<300<;2`P030<C4a0030<S8b039
bLT0b/[:0080bl_;00H0c<c<0<_;b`3?cll0d=3@0<o?c`3AdM430=?Cd`0;0=GEe@3Cdm<0eMGE0=CD
e03GemL0e]KF0=OGe`3De=@0eMGE0=CDe03GemL00P3IfMT04@3EeMD0_[jn08b<S02:RXX0R8R8079b
LP1ZJVX0JFUY05IFEP1>CTh0De=C061PH01XJ6P0FUYJ05]KF`1LG5`0Hf=S0080IFEU00P0JVYZ06MW
I`1^KVh0KFe]07MgM`1hN7P0Ng]k07inOP80PH610P22PX801`25QHD0S8b<08f=S@29RHT0S8b<08^;
R`2DU9@00`2<S8`00`29RHT0Rh^;08N7Q`0208j>SP0G08b<S02;Rh/0SHf=08b<S02:RXX0Rh^;08b<
S02DU9@0UYJF09NGU`2BTY80VIVI09NGU`2@T900UIFE096AT@2@T900S8b<08^;R`2<S8`0R8R808F5
Q@29RHT00P2BTY801P2[Zj/0`L710<_;b`3@d=00fMWI0=_Kf`80gMgM0P3Fe]H0203Bd]80bl_;0<;2
`P2d];@0YJFU09FEU@22PX80MGEe0P1aLG4206i^KP0:06MWI`1RHV80HF5Q05mOG`1KFe/0EeMG05eM
G@1JFUX0GEeM061PH0<0Hf=S0P1RHV801P1ADE40CTi>04e=C@1BDU80CDe=05ADE080FEUI00@0IFEU
06MWI`1VIVH0J6QX0P1UIFD02`1QHF40Hf=S05iNGP1QHF40Fe]K05QHF01DE5@0EEEE05mOG`1KFe/0
GemO0080HV9R00`0IVIV06=SH`1OGel0Fe]K061PH01SHf<0G5aL04m?C`1=CDd0ATI603Hf=P0m?Cd>
0<SPf0003038h=P202DU9@0X02TY:@0S8b<09bLW02<S8`0V9RH0:b/[02DU9@0^;Rh0Cdm?06MWI`1o
Ogl0TY:B09RHV02MWId0WinO0:ZZZP2RXZ80Y:BT0::RXP2PX:00UiNG08b<S026QXH0MWIf05]KF`16
ATH0>SXj03/k>`0m?Cd0CDe=05eMG@1`L700Ogmo08V9R@2CTi<0VYZJ0::RXP2VYZH0ZJVY0;2`/080
[jn_00@0/;2`0:n_[`2`/;00/K6a0P2^[Zh06P2a/K40[jn_0;2`/02a/K40/k>c0;6a/@2`/;00[jn_
0:NWY`2ZZZX0Y:BT09jNWP2DU9@0QhN708:2PP2<S8`0Z:RX09:BTP1RHV80>3Ph04M7A`1PH600ADE5
03dm?@0j>SX0<S8b0P0Y:BT01@0a<C40:RXZ038b<P0[:b/0>3Ph0080<S8b00@0<c<c02h^;P0`<300
=CDe0P0`<3009P0_;bl0<C4a02TY:@0/;2`0?3`l02h^;P0Z:RX0;Rh^03@d=00k>c/0?Cdm038b<P0m
?Cd0BTY:03hn?P11@D40>3Ph03`l?00b<S80@T9203dm?@1?Cdl0>SXj03dm?@0^;Rh0>3Ph03`l?00b
<S80=3@d03Ti>@0f=SH0?clo03Xj>P0n?Sh0;Rh^02LW9`0/;2`08b<S0P0T92@0<`0Z:RX0>c/k05]K
F`1WIfL0@D5103Lg=`0_;bl0:2PX02TY:@0];Bd0=SHf04a<C01GEeL0MGEe07UiN@1_Kfl0FUYJ03@d
=01BDU80CDe=02DU9@0^;Rh0@D5103<c<`0`<300:BTY02PX:00g=cL0D51@07=cL`2HV9P0T92@05]K
F`0l?3`0;2`/03Lg=`0k>c/0De=C04m?C`0d=3@0FEUI075aL@1hN7P0Zj^[0:ZZZP2YZJT0NWYj03De
=@0Q8B409bLW02d];@02030`<00=03/k>`0_;bl0:b/[02LW9`0V9RH0<S8b04I6AP0g=cL0=3@d03Lg
=`0b<S80;2`/034a<@02038b<P0@030`<00Z:RX0:2PX02PX:00/;2`0<30`03De=@0_;bl0=3@d03<c
<`0j>SX0@41004i>CP1:BTX0Cdm?05YJFP80J6QX00@0Kfm_075aL@1cLg<0M7Ad0P1eMGD01@1jNWX0
OWin08>3P`22PX80OGem0080Ng]k01/0NGUi06m_K`1LG5`0@T92034a<@0b<S80ADE505IFEP1OGel0
H61P06e]K@1mOGd0PX:20861P@22PX80R8R808F5Q@24Q8@0QXJ608N7Q`2;Rh/0SXj>08Z:RP28R8P0
QXJ608^;R`2>SXh00P2<S8`03@2;Rh/0SHf=092@T02@T900Ti>C096AT@2>SXh0SHf=08j>SP2=SHd0
S8b<08j>SP2<S8`0102?Shl06@2;Rh/0SHf=08V9R@2<S8`0R8R808B4Q029RHT0QXJ608j>SP2;Rh/0
SXj>08N7Q`2<S8`0SHf=08j>SP2=SHd0S8b<08Z:RP2?Shl0Rh^;09:BTP2@T900TI6A09>CT`2FUYH0
0P2EUID01`2DU9@0UYJF09NGU`2GUiL0UIFE09JFUP2EUID00P2GUiL00`2JVYX0VIVI09fMW@0209fM
W@0309jNWP2OWil0WYjN0080Y:BT0P2WYjL20:RXZ0060:f][@2[Zj/0[jn_0;6a/@2b/[80];Bd0P2f
][H0102j^[X0]kNg0;fm_@2o_kl20<30`0030<71`@38b<P0aLG50080aLG50`3:b/X01`3<c<`0cLg=
0<c<c03?cll0d];B0=7Ad@3Cdm<00P3Bd]80103Cdm<0eMGE0=7Ad@3De=@20=OGe`0I0=KFeP3GemL0
eMGE0=GEe@3De=@0e]KF0=SHf03IfMT0dM7A0:f][@1oOgl0RXZ:092@T027QhL0MWIf06m_K`1LG5`0
EUIF05QHF01OGel0Kfm_05iNGP1WIfL0JVYZ06i^KP0206][J`0J075aL@1eMGD0MgMg07EeM@1kNg/0
Ogmo08:2PP24Q8@0P82008F5Q@2<S8`0R8R808j>SP2;Rh/0SHf=096AT@2DU9@0TI6A09FEU@2@T900
TI6A08j>SP2<S8`0T92@08j>SP2@T90208Z:RP80Rh^;00T0QhN708J6QP2@T900Shn?096AT@2BTY80
Ti>C09BDU02JVYX00P2EUID07`2?Shl0TI6A08n?S`2=SHd0T92@08V9R@22PX80QHF508^;R`2HV9P0
UIFE0:BTY02l_;`0b/[:0<k>cP3GemL0g]kN0=cLg03MgMd0f=SH0=GEe@3De=@0c/k>0<G5a@2h^;P0
Z:RX09ZJVP29RHT0O7al07EeM@1dM7@00P1aLG401@1/K6`0JFUY069RHP1UIFD0GUiN0080Fe]K00<0
E5AD05eMG@1NGUh00P1VIVH08@1YJFT0HV9R061PH01HF5P0D51@04Y:BP1=CDd0BTY:04m?C`1DE5@0
Fe]K05eMG@1QHF40HV9R06UYJ@1[Jf/0IfMW06ATI01YJFT0IVIV06MWI`1QHF40GemO05]KF`1GEeL0
GemO05iNGP1JFUX0HV9R065QH@1UIFD0HF5Q05mOG`0205aLG00705mOG`1HF5P0F5QH051@D019BDT0
A4A403/k>`0>0<SPf0003038h=P202PX:00@02DU9@0R8R808B4Q024Q8@0];Bd0:BTY02/[:`0e=CD0
ATI605]KF`1bLW80T92@09RHV02LW9`0XZ:R0:NWY`80XZ:R01H0YJFU09nOW`2IVIT0Shn?0820P01`
L700I6AT04=3@`0b<S80>c/k03lo?`1>CTh0F5QH071`L022PX80SHf=09BDU02LW9`0Xj>S0:JVYP2^
[Zh0[Jf]0P2b/[80:P2`/;00[Zj^0:n_[`2][Jd0[jn_0;2`/02b/[80[jn_0;Fe]@2a/K40/[:b0;Bd
]02`/;00Zj^[0:f][@2TY:@0XZ:R09^KV`2CTi<0QXJ608^;R`2EUID0[Zj^096AT@1[Jf/0>SXj04i>
CP1MGEd0HF5Q03<c<`0i>CT0>3Ph02/[:`0Z:RX0<C4a02/[:`0a<C40<S8b03Ph>00m?Cd0=cLg03`l
?080=3@d00X0<c<c03Ti>@0b<S80;2`/03<c<`0/;2`0<30`03De=@0`<300;2`/0P0a<C403P0j>SX0
@d=303Lg=`0g=cL0Cdm?04U9B@15ADD0=cLg03Hf=P0a<C40<30`03`l?013@d<0@T920P0g=cL03@0o
?cl0=cLg04E5A@0o?cl0?Cdm03<c<`0h>3P0@d=304I6AP11@D40=3@d02l_;`0W9bL00P0T92@01P0`
<300?Shn05EEE@1_Kfl0EeMG03De=@80;2`/04T09bLW02/[:`0g=cL0=3@d04M7A`1ZJVX0Jf][069R
HP11@D40@d=304m?C`0Z:RX08R8R034a<@0_;bl0;2`/03Hf=P0h>3P0A4A4069RHP1oOgl0UIFE08>3
P`1^KVh0DU9B03Ti>@0/;2`0<30`034a<@0o?cl0ADE504Q8B024Q8@0O7al09fMW@2c/k<0Zj^[0;Bd
]02SXj<0JVYZ02TY:@0/;2`0<c<c038b<P0d=3@0>c/k03dm?@0^;Rh0<30`02/[:`0d=3@0@41003Hf
=P0i>CT0@D5103@d=00e=CD0<30`03<c<`0g=cL0<30`02d];@0^;Rh0:b/[03@d=00^;Rh0<30`02XZ
:P0a<C40;2`/03Ph>010@400Bd];0080D51@00@0EEEE06ATI01TI6@0L71`0P1]KFd08`1`L700MGEe
07=cL`1kNg/0NWYj07moO`1lO7`0NWYj07]kN`1lO7`0Ng]k07UiN@1YJFT0DU9B03Lg=`0_;bl0@d=3
05EEE@1SHf<0F5QH06][J`1dM7@0OWin08:2PP23Ph<0R8R808Z:RP24Q8@0RHV908J6QP2?Shl0Rh^;
08V9R@2:RXX0Rh^;0080S8b<0P2>SXh01@2<S8`0Rh^;08n?S`2EUID0UiNG0080TI6A00L0SHf=08V9
R@2=SHd0RXZ:08V9R@2=SHd0SXj>0080S8b<01H0T92@08^;R`28R8P0Rh^;08N7Q`28R8P0QXJ608^;
R`29RHT0Rh^;08f=S@2;Rh/0RXZ:08N7Q`2;Rh/0SHf=08j>SP2=SHd0S8b<092@T02?Shl0T92@0P2C
Ti<04@2EUID0UiNG09FEU@2EUID0UYJF09BDU02EUID0UYJF09NGU`2JVYX0VIVI09^KV`2IVIT0WYjN
09fMW@2NWYh0VYZJ00<0WYjN00H0X:2P09nOW`2PX:00Y:BT0:JVYP2TY:@20:f][@030:j^[P2][Jd0
[Zj^0080/[:b0P2f][H0102j^[X0]KFe0;bl_02m_Kd20<71`@050<30`035aLD0a<C40<?3``37alL0
0P39bLT01@3:b/X0bl_;0<_;b`3?cll0d=3@0080d];B00D0dm?C0=7Ad@3Bd]80e=CD0=?Cd`020=CD
e0080=KFeP3EeMD0eMGE0=KFeP3Hf=P0emOG0=CDe03Fe]H20=SHf00A0<[:bP2GUiL0NWYj08n?S`2E
UID0Rh^;07]kN`1fMWH0HF5Q069RHP1WIfL0Jf][071`L01XJ6P0Kfm_071`L01eMGD00P1dM7@01@1g
MgL0OWin0861P@1nOWh0PX:20080QXJ600<0RXZ:08f=S@2?Shl00`2@T900102BTY80Shn?096AT@2E
UID3092@T00K09>CT`2<S8`0T92@096AT@28R8P0SHf=08Z:RP27QhL0SXj>08n?S`26QXH0R8R808j>
SP2@T900U9BD096AT@2EUID0Shn?09NGU`2BTY80U9BD09:BTP2ATI40SXj>08^;R`2=SHd0RXZ:00<0
QHF50P2@T9001P2RXZ80^;Rh0<O7a`3>c/h0e]KF0=cLg080gMgM0100f][J0=OGe`3Cdm<0d=3@0<W9
b@2n_[h0/;2`0:>SX`2>SXh0PX:207QhN01bLW80KVi^075aL@1]KFd0K6a/0P1ZJVX01P1UIFD0G5aL
061PH01CDe<0GUiN05]KF`80GEeM02D0IVIV06ATI01VIVH0H61P05IFEP1DE5@0F5QH055AD@1<C4`0
Cdm?05=CD`1JFUX0G5aL06ATI01XJ6P0JFUY06YZJP1RHV80IfMW05mOG`1PH600GEeM05mOG`1HF5P0
DU9B05QHF01MGEd0EeMG05QHF01MGEd0H61P065QH@1OGel0G5aL05UIF@1NGUh0HV9R0080Fe]K00<0
E5AD04M7A`0o?cl03P38h=P000`0b>3H0P0W9bL0:00Y:BT09RHV02PX:00X:2P0820P02LW9`0b<S80
=SHf04Y:BP1UIFD0M7Ad08f=S@2JVYX0Vi^K0:JVYP2YZJT0[:b/0:JVYP2RXZ80Y:BT09ZJVP2?Shl0
PX:207MgM`1MGEd0AdM703Ti>@0k>c/0?clo04];B`1MGEd0LG5a08:2PP2<S8`0Vi^K09ZJVP2YZJT0
YjNW0:b/[02^[Zh20;Bd]080/K6a01d0[Jf]0:n_[`2_[jl0/K6a0;2`/02_[jl0];Bd0;:b/P2c/k<0
/K6a0;:b/P2][Jd0Z:RX0:FUY@2OWil0VYZJ09:BTP27QhL0T92@09nOW`2[Zj/0Rh^;06QXJ011@D40
B4Q805eMG@1LG5`0;bl_03dm?@02038b<P80:RXZ00@0<C4a02XZ:P0`<300A4A40P1@D5002`1?Cdl0
A4A403Hf=P0`<300<S8b034a<@0_;bl0<C4a030`<00b<S80<c<c0080<30`01l0;2`/038b<P0i>CT0
ADE50492@P0h>3P0@d=304i>CP11@D40>c/k03Lg=`0c<c<0?3`l03hn?P0j>SX0A4A403dm?@14A4@0
ADE503hn?P0j>SX0>c/k030`<00/;2`0;bl_03lo?`19BDT0>SXj04Q8B00i>CT0:2PX00<0:RXZ0140
=3@d04a<C01^KVh0J6QX03Ph>00Y:BT0:b/[02h^;P0c<c<0>CTi030`<013@d<0GUiN06QXJ01OGel0
?Cdm04=3@`0202XZ:P0[034a<@0o?cl0>SXj03Ph>01@D500GemO06a/K01dM7@0OWin09:BTP1ZJVX0
DU9B04E5A@0l?3`0;2`/03Ti>@0c<c<0BDU905MGE`1dM7@0Ph>307moO`2][Jd0Vi^K09>CT`2GUiL0
/;2`09BDU00i>CT092@T02d];@0b<S80<C4a03/k>`0i>CT0<30`02d];@0Y:BT0;2`/03/k>`0n?Sh0
=cLg030`<00203@d=00602h^;P0c<c<0<S8b02h^;P0j>SX0:b/[0P0_;bl02`0c<c<0;bl_02h^;P0a
<C40;bl_03Ph>00m?Cd0@d=304Q8B01@D500GUiN0080HF5Q00@0JVYZ06e]K@1aLG40Lg=c0P1fMWH0
3`1iNGT0Ng]k08:2PP1nOWh0Ng]k07emO@1jNWX0Ng]k07alO01_Kfl0EUIF04A4A00f=SH0=cLg04i>
CP0205mOG`0;069RHP1bLW80Ng]k0820P024Q8@0PX:208J6QP25QHD0R8R808V9R@2:RXX00P28R8P0
3P2;Rh/0SHf=08j>SP2BTY80T92@08j>SP2;Rh/0Shn?092@T02BTY80Ti>C08f=S@2@T900SHf=0P2<
S8`02@2=SHd0Rh^;08^;R`2?Shl0S8b<08^;R`2:RXX0RHV908J6QP0308R8R00808Z:RP26QXH0QHF5
08Z:RP2;Rh/0R8R808N7Q`2:RXX208n?S`0809>CT`2?Shl0Shn?08n?S`2ATI40Shn?096AT@2CTi<2
09BDU080UiNG00<0TI6A09>CT`2GUiL00`2HV9P209^KV`0@09NGU`2KVi/0VYZJ09^KV`2MWId0VYZJ
09^KV`2OWil0X:2P09jNWP2QXJ40Xj>S0:NWY`2TY:@0[Jf]0;6a/@<0[jn_00H0][Jf0;Fe]@2h^;P0
^;Rh0;Jf]P2l_;`20;no_`050<71`@33`l<0`l?30<G5a@37alL00P35aLD20<W9b@0;0<[:bP3;bl/0
clo?0<o?c`3@d=00d];B0=7Ad@3De=@0dm?C0=CDe03EeMD00P3Cdm<01@3De=@0f=SH0=GEe@3Bd]80
e=CD0080emOG00P0eMGE0=OGe`3GemL0e=CD0;no_`1nOWh0NWYj096AT@80TY:B00P0Ph>30861P@1Y
JFT0JVYZ06e]K@1cLg<0NGUi075aL@80N7Qh00d0Ng]k07alO01lO7`0Ogmo08>3P`24Q8@0OWin08J6
QP28R8P0Shn?092@T02BTY80T92@0080TI6A0240Ti>C09FEU@2@T900SXj>092@T02BTY80SXj>08^;
R`2>SXh0TI6A08n?S`2=SHd0SXj>08V9R@2:RXX0SHf=08n?S`2<S8`0Ph>308Z:RP2;Rh/0R8R808b<
S02@T900TI6A08j>SP2EUID0TY:B09>CT`2EUID0TI6A092@T02:RXX00P29RHT09@23Ph<0PH6108>3
P`2=SHd0TY:B0:>SX`2c/k<0aLG50<g=c@3AdM40f][J0=gMg@3Lg=`0f][J0=WIf@3EeMD0d=3@0<_;
b`31`L40]kNg0:FUY@2ATI40QXJ607IfMP1dM7@0Lg=c079bLP1^KVh0Jf][06MWI`1NGUh0HV9R06IV
IP1QHF40GEeM05UIF@1HF5P00P1JFUX02`1PH600IVIV061PH01PH600GemO05EEE@1?Cdl0E5AD04];
B`1:BTX0DU9B0080F5QH01d0IfMW06UYJ@1VIVH0IfMW06a/K01UIFD0I6AT05mOG`1QHF40GUiN05]K
F`1IFET0EeMG05ADE01NGUh0EUIF05eMG@1LG5`0H61P05iNGP1OGel0GEeM065QH@1SHf<0IVIV05YJ
FP1DE5@0Bd];04E5A@0>0<SPf0003038h=P202XZ:P0J02HV9P0P820092@T01lO7`0N7Qh092@T02PX
:00b<S80Cdm?06UYJ@1lO7`0Shn?09ZJVP2NWYh0Y:BT0:RXZ02[Zj/0[:b/0:JVYP2UYJD0VYZJ08f=
S@26QXH0LW9b05iNGP11@D4203Xj>P0<04A4A019BDT0G5aL075aL@26QXH0S8b<09NGU`2MWId0YJFU
0:RXZ02][Jd0[Zj^0P2a/K400`2c/k<0[jn_0;2`/0020:n_[`0N0;2`/02a/K40[Jf]0;:b/P2c/k<0
/;2`0;>c/`2a/K40Zj^[0:RXZ02QXJ40WIfM09VIV@2>SXh0Shn?09FEU@2SXj<0Y:BT08J6QP1RHV80
?clo03dm?@1PH600EeMG03Ti>@0e=CD0<S8b02LW9`0X:2P09bLW0P0Z:RX02P0[:b/0?clo04i>CP1>
CTh0FUYJ05aLG01?Cdl0?Shn0410@00`<30202h^;P03030`<00Z:RX0;2`/0080:BTY0P0[:b/02P0b
<S80@T9204U9B@0e=CD0>3Ph04Y:BP0m?Cd0<C4a03<c<`0_;bl203Hf=P0903/k>`15ADD0@41004=3
@`16ATH0B4Q803/k>`0c<c<0:BTY0080:b/[00H0AdM703lo?`0a<C40=cLg03dm?@0b<S8202h^;P09
02TY:@0];Bd0De=C061PH01QHF40?Cdm034a<@0`<300=CDe0080=cLg0200>3Ph04E5A@1VIVH0Ng]k
05UIF@0f=SH08b<S02DU9@0[:b/0B4Q806=SH`1`L700EEEE06i^KP28R8P0Lg=c06m_K`1lO7`0Ph>3
05MGE`1DE5@0Bd];03/k>`0a<C40?clo03<c<`1NGUh0NWYj08:2PP1cLg<0WIfM09nOW`80O7al02L0
Lg=c0:RXZ02ZZZX0FEUI02HV9P0U9BD0=SHf02d];@0a<C40>SXj03<c<`0Y:BT0;Rh^02LW9`0b<S80
?Cdm03Lg=`0c<c<0<30`034a<@0`<300<C4a03<c<`0g=cL0;bl_038b<P0];Bd0:BTY03<c<`0e=CD0
<30`02LW9`0_;bl0<S8b03Xj>P0o?cl0BTY:051@D01IFET00P1MGEd01P1RHV80JFUY06a/K01eMGD0
M7Ad07YjNP80NGUi01P0OGem07inOP1kNg/0OGem07alO01nOWh0Ng]k079bLP1RHV80D51@03Ph>00/
;2`0A4A405ADE01OGel0Hf=S079bLP1fMWH0Ng]k08:2PP26QXH0QHF508R8R02:RXX208R8R00408V9
R@2;Rh/0SHf=096AT@80SHf=00P0R8R808j>SP2>SXh0T92@096AT@2DU9@0TY:B08^;R`<0SHf=00@0
RHV908f=S@2=SHd0Rh^;0P2:RXX06`29RHT0RXZ:08Z:RP24Q8@0RHV908Z:RP26QXH0QhN708>3P`26
QXH0RHV908N7Q`26QXH0Q8B408J6QP2:RXX0SXj>092@T02;Rh/0S8b<08j>SP2?Shl0TY:B09BDU02@
T900TI6A09:BTP0209ZJVP0I096AT@2BTY80V9RH09RHV02GUiL0VYZJ09NGU`2LW9`0V9RH09^KV`2N
WYh0XJ6Q09fMW@2OWil0XJ6Q0:>SX`2TY:@0XZ:R0:>SX`2UYJD0ZJVY0:NWY`2][Jd0[:b/0:f][@02
0:n_[`030;Fe]@2i^KT0^;Rh0080^KVi0P2n_[h20<30`0060<71`@33`l<0aLG50<K6aP3:b/X0b<S8
0P39bLT00`3:b/X0c<c<0<c<c0030<o?c`070=7Ad@3Bd]80dm?C0=CDe03Fe]H0e=CD0=KFeP020=CD
e0030=?Cd`3EeMD0e=CD00<0emOG0P3Fe]H0403=cLd0Zj^[06e]K@1gMgL0RHV9096AT@2?Shl0SXj>
08R8R01hN7P0Kfm_07IfMP1hN7P0O7al0861P@20P80208:2PP80Q8B400<0S8b<08F5Q@29RHT00P2<
S8`07P2=SHd0T92@09BDU02@T900U9BD08j>SP2BTY80UIFE08j>SP2DU9@0SXj>08f=S@2CTi<0TI6A
092@T02CTi<0T92@08f=S@2ATI40RXZ:08f=S@2<S8`0QXJ608f=S@28R8P0QHF508f=S@29RHT0QhN7
08Z:RP80S8b<01@0Rh^;08j>SP2DU9@0SXj>08b<S02?Shl0Rh^;08f=S@2<S8`0QhN708:2PP27QhL0
SHf=092@T02DU9@0WYjN0:n_[`32`/80bl_;0=?Cd`80fMWI01L0gMgM0=[JfP3Hf=P0e]KF0=7Ad@3<
c<`0a/K60;Vi^@2ZZZX0Vi^K08N7Q`1lO7`0MWIf071`L01_Kfl0KVi^06][J`1^KVh0IFEU065QH@1N
GUh0HF5Q05UIF@0205YJFP80I6AT00l0GEeM06ATI01PH600HV9R06ATI01IFET0EUIF059BDP1>CTh0
BDU904m?C`1CDe<0EEEE065QH@1WIfL00P1/K6`03P1_Kfl0Jf][06IVIP1RHV80G5aL05iNGP1JFUX0
F5QH05]KF`1IFET0F5QH05YJFP1LG5`0GUiN0P1RHV802@1QHF40GemO05]KF`1RHV80J6QX05]KF`1E
EED0DE5A04Q8B00>0<SPf0003038h=P302`/;00A02l_;`0X:2P09BDU02<S8`0X:2P0;2`/03Ph>01A
DE40J6QX08F5Q@2@T900W9bL0:6QX@2WYjL0[:b/0:^[Z`2ZZZX00P2SXj<0502GUiL0SHf=08B4Q01/
K6`0F5QH0451@@0f=SH0=CDe04=3@`1?Cdl0GEeM07EeM@24Q8@0SHf=096AT@2LW9`0Z:RX0:VYZ@2^
[Zh0/[:b0P2_[jl0202`/;00[Jf]0;>c/`2b/[80[jn_0;6a/@2`/;00[jn_0`2b/[801`2d];@0/[:b
0:ZZZP2ZZZX0YJFU09nOW`2NWYh00P2=SHd03@2IVIT0YJFU09nOW`25QHD0GemO0451@@0i>CT0IFEU
05EEE@0d=3@0;2`/03Lg=`0T92@00P0U9BD06@0Y:BT0;Bd]02<S8`0X:2P0>c/k03Hf=P10@400EEEE
05iNGP1MGEd0Cdm?03Ph>00];Bd0<S8b02LW9`0Z:RX0;Rh^02/[:`0^;Rh0:2PX02/[:`0f=SH0?Shn
0492@P11@D400P0m?Cd05`0n?Sh0=3@d03<c<`0^;Rh0>CTi034a<@0d=3@0>c/k04E5A@0n?Sh0>SXj
03`l?00h>3P0;2`/03<c<`0^;Rh0=cLg05iNGP13@d<09bLW03@d=00j>SX0?3`l0080=CDe00T0:RXZ
03@d=01=CDd0CDe=059BDP19BDT0=SHf03Ti>@0j>SX00P0l?3`0>P0j>SX0D51@06m_K`1XJ6P0>3Ph
02HV9P0M7Ad09BDU04e=C@2;Rh/0YZJV0:6QX@1dM7@0K6a/0:6QX@22PX80JVYZ08:2PP1bLW80Fe]K
06ATI01EEED0AdM703/k>`12@T80A4A406UYJ@21PH40LG5a07UiN@2NWYh0Ng]k07MgM`20P800CDe=
08J6QP2TY:@0RXZ:02HV9P0R8R80;2`/02h^;P0e=CD0>c/k03Xj>P0d=3@0<C4a02l_;`0e=CD0?clo
034a<@0n?Sh0?clo03Hf=P0c<c<0;Rh^03Ti>@0e=CD2030`<00=03@d=00c<c<0>3Ph02`/;00^;Rh0
;2`/02d];@0b<S80=3@d0410@01;Bd/0EEEE05IFEP0205EEE@0F05IFEP1UIFD0KFe]07=cL`1fMWH0
M7Ad07UiN@1jNWX0P82007emO@1nOWh0P82007YjNP1oOgl0Ng]k07IfMP1]KFd0EeMG03Xj>P0a<C40
@T9205ADE080HF5Q0200IfMW06e]K@1jNWX0Ph>308F5Q@22PX80Rh^;08R8R029RHT0S8b<08V9R@2;
Rh/0Shn?08f=S@2:RXX0RHV908N7Q`2;Rh/0S8b<08j>SP2CTi<0U9BD08n?S`29RHT0S8b<08Z:RP2<
S8`0RXZ:08J6QP29RHT0SHf=08N7Q`80RHV90P2:RXX02@27QhL0R8R808V9R@2=SHd0R8R808Z:RP29
RHT0QhN708J6QP0308N7Q`0<08^;R`2<S8`0SXj>08^;R`2=SHd0T92@08n?S`2=SHd0TY:B09NGU`2B
TY80U9BD0P2KVi/02@2FUYH0UIFE09FEU@2FUYH0VIVI09ZJVP2DU9@0WYjN09bLW00209jNWP0?09nO
W`2LW9`0XJ6Q09jNWP2QXJ40Y:BT0:JVYP2UYJD0ZJVY0:JVYP2ZZZX0[Zj^0:b/[02^[Zh0[Jf]0080
/;2`0140]KFe0;Vi^@2k^k/0^[Zj0;bl_02n_[h0`l?30;no_`30`<00aLG50<C4a035aLD0alO70<W9
b@37alL0bLW90<k>cP020<g=c@80clo?0P3AdM401`3De=@0d];B0=;BdP3EeMD0dm?C0=CDe03Fe]H0
0P3De=@00`3EeMD0emOG0=SHf0030=KFeP0?0=;BdP39bLT0RHV906IVIP1hN7P0R8R809:BTP2ATI40
S8b<08Z:RP20P800LW9b07YjNP22PX80Ph>300<0QXJ600X0QhN708R8R028R8P0TI6A08j>SP2<S8`0
SXj>09:BTP2ATI40Ti>C0P2EUID2096AT@05092@T02DU9@0Shn?08n?S`2>SXh00P2?Shl01P2@T900
SHf=08j>SP2=SHd0Shn?08^;R`80QXJ600P0RXZ:08N7Q`29RHT0QHF508>3P`28R8P0QXJ608B4Q080
S8b<00H0Rh^;08j>SP2<S8`0SHf=08N7Q`2:RXX208f=S@0L08^;R`2:RXX0SXj>08Z:RP2BTY80VIVI
09fMW@2NWYh0XZ:R0;6a/@33`l<0c<c<0=7Ad@3De=@0e]KF0=gMg@3Jf]X0eMGE0=CDe03AdM40cLg=
0<[:bP32`/80/;2`09nOW`2<S8`0P82007QhN080LG5a00X0Lg=c071`L01[Jf/0IVIV06EUI@1WIfL0
GemO05iNGP1JFUX0E5AD0P1NGUh02@1PH600HV9R06QXJ01TI6@0GUiN05eMG@1NGUh0EEEE04e=C@02
04];B`0G05ADE01CDe<0GEeM06=SH`1VIVH0Kfm_06i^KP1[Jf/0JFUY06QXJ01RHV80H61P069RHP1I
FET0GEeM05QHF01FEUH0Fe]K05QHF01KFe/0IFEU05eMG@1TI6@00P1OGel01P1NGUh0HF5Q05mOG`1K
Fe/0DE5A04];B`h0b>3H000<0<SPf080:b/[01T0:2PX02HV9P0X:2P08b<S02DU9@0S8b<0;bl_03Ti
>@1FEUH0KFe]08:2PP2ATI40VIVI0:>SX`2ZZZX0[:b/0:RXZ02^[Zh0ZJVY0::RXP2HV9P0R8R807in
OP1UIFD0De=C0080=3@d00d0=CDe0492@P1>CTh0Fe]K079bLP26QXH0S8b<09JFUP2NWYh0YjNW0:VY
Z@2^[Zh0/K6a0080/[:b00P0]KFe0:n_[`2a/K40/[:b0;>c/`2][Jd0/;2`0;:b/P80/K6a01H0]KFe
0;Ng]`2ZZZX0Zj^[0:NWY`2UYJD0WinO09fMW@2=SHd0Rh^;09bLW02SXj<0V9RH08B4Q01YJFT0>CTi
03<c<`1GEeL0Cdm?03Hf=P0b<S80?Cdm0P0Z:RX00`0V9RH0;Rh^02HV9P0202`/;00N02l_;`0a<C40
<S8b03Xj>P18B4P0DE5A06=SH`1JFUX0B4Q803Ti>@0c<c<0<C4a038b<P0];Bd0:RXZ02d];@0[:b/0
=SHf03Ti>@13@d<0ADE503lo?`0m?Cd0CDe=03/k>`0_;bl0=CDe030`<00];Bd0<S8b0P0m?Cd02P0e
=CD0>SXj03Ph>00g=cL0;bl_02d];@0g=cL0A4A406MWI`0e=CD202XZ:P1H038b<P0g=cL0=SHf03Hf
=P0_;bl0>SXj0451@@0e=CD0>SXj05QHF019BDT0?Shn04E5A@0k>c/0ATI604];B`1YJFT0LW9b04i>
CP0W9bL09RHV02DU9@17AdL0QHF509>CT`2DU9@0W9bL07moO`1[Jf/0SXj>07MgM`1IFET0RXZ:07in
OP1cLg<0K6a/069RHP1JFUX0?3`l04=3@`12@T80LW9b07moO`1/K6`0SHf=08N7Q`1RHV80K6a/079b
LP0j>SX0GUiN08:2PP1fMWH0:b/[024Q8@0Z:RX0>c/k03`l?010@400>3Ph03De=@0k>c/0<30`02h^
;P14A4@0?3`l03dm?@15ADD0>3Ph03Hf=P0^;Rh0<30`03@d=00f=SH0<30`03Lg=`0j>SX0=3@d02d]
;@0T92@0;bl_02d];@0a<C40>3Ph0451@@18B4P0Cdm?05ADE080DE5A0280FEUI061PH01_Kfl0K6a/
06e]K@1dM7@0MWIf07YjNP1lO7`0Ng]k07emO@1nOWh0O7al07moO`1lO7`0MgMg07IfMP1JFUX0ADE5
03De=@0n?Sh0Cdm?05UIF@1PH600I6AT06m_K`1hN7P0PH6108:2PP20P800Q8B408V9R@24Q8@0Rh^;
0P2<S8`03P2=SHd0R8R8092@T02>SXh0Rh^;08j>SP2;Rh/0Ti>C08j>SP2@T900Rh^;08f=S@29RHT0
Rh^;0P2:RXX02P2<S8`0Rh^;08R8R02<S8`0Rh^;08Z:RP29RHT0Rh^;08N7Q`26QXH208Z:RP0:08b<
S024Q8@0Ph>308V9R@2:RXX0QhN708^;R`2:RXX0Rh^;08b<S080SXj>0P2@T9001P2BTY80T92@09:B
TP2CTi<0UIFE09RHV080VYZJ01L0UiNG09VIV@2KVi/0V9RH09bLW02KVi/0VYZJ09bLW02MWId0W9bL
09fMW@2OWil0WYjN09nOW`2VYZH0X:2P0::RXP2TY:@0XJ6Q0:NWY`2YZJT0[:b/0:VYZ@020:^[Z`04
0:j^[P2d];@0/K6a0;Rh^080^k^k0140^[Zj0;^k^`31`L40`L710;no_`31`L40`l?30<W9b@36a/H0
bLW90<K6aP3:b/X0c<c<0<_;b`3<c<`0clo?0=3@d0020<g=c@080<o?c`3Cdm<0d];B0=?Cd`3De=@0
eMGE0=KFeP3EeMD20=CDe0030=GEe@3GemL0emOG0080emOG0140eMGE0=CDe032`/80Jf][05aLG01i
NGT0Q8B408f=S@2ATI40S8b<08n?S`26QXH0Ng]k08B4Q029RHT0RXZ:08j>SP02092@T00308j>SP2<
S8`0S8b<0080TI6A00/0Shn?092@T02ATI40UYJF08n?S`2DU9@0UYJF092@T02CTi<0TI6A08n?S`02
08j>SP06096AT@2<S8`0S8b<096AT@2>SXh0SHf=0P2>SXh09@2=SHd0QhN708R8R029RHT0QXJ608N7
Q`23Ph<0OWin08F5Q@22PX80QhN708J6QP27QhL0QXJ608R8R029RHT0Rh^;092@T02;Rh/0RXZ:08b<
S02>SXh0RXZ:092@T02HV9P0X:2P0:FUY@2YZJT0[:b/0:VYZ@2b/[80`L710<W9b@3@d=00eMGE0=KF
eP3Ogml00P3Hf=P03`3EeMD0dm?C0<k>cP37alL0`<300;Bd]02RXZ80SHf=0861P@1kNg/0Kfm_071`
L01YJFT0K6a/06][J`0206QXJ00506e]K@1QHF40Hf=S065QH@1HF5P00P1KFe/0601MGEd0GemO06AT
I01YJFT0H61P065QH@1OGel0GEeM05YJFP1@D500CTi>04I6AP1BDU80F5QH069RHP1VIVH0KVi^071`
L01ZJVX0J6QX06=SH`1VIVH0IFEU06=SH`80FUYJ0100EUIF05QHF01QHF40FUYJ05iNGP1PH600GUiN
06EUI@1IFET0G5aL065QH@1SHf<0IfMW05mOG`1IFET0EEEE3P38h=P000`0b>3H0P0U9BD06@0R8R80
820P02HV9P0V9RH08R8R02HV9P0e=CD0?Shn05YJFP1eMGD0Ph>309NGU`2IVIT0YJFU0:^[Z`2^[Zh0
ZJVY0:NWY`2TY:@0WinO09ZJVP2<S8`0O7al06a/K016ATH00P0^;Rh03@0k>c/0?Shn04U9B@1MGEd0
NGUi08>3P`2@T900V9RH09jNWP2QXJ40Z:RX0:j^[P2a/K400`2b/[801@2`/;00/K6a0:j^[P2_[jl0
/[:b0080/k>c00@0[jn_0;2`/02b/[80]KFe0P2[Zj/04`2WYjL0XJ6Q09fMW@2IVIT0SHf=09:BTP2P
X:00WYjN08n?S`28R8P0NGUi03Lg=`0a<C40AdM704I6AP0`<300:2PX03dm?@0c<c<00P0Z:RX04`0^
;Rh09BDU02DU9@0W9bL0:BTY03Ti>@0e=CD0<S8b03@d=00g=cL0E5AD06=SH`1TI6@0EUIF03/k>`0h
>3P0=SHf02l_;`0/;2`00P0];Bd07@0/;2`0=3@d03hn?P14A4@0?3`l03dm?@0n?Sh0>c/k0410@00f
=SH0<C4a030`<00a<C40@41002l_;`0`<300?3`l03<c<`0f=SH0:2PX03<c<`0_;bl0@d=305IFEP0Y
:BT08b<S02`/;00^;Rh0;Bd]0080=3@d04D0?Cdm03hn?P0e=CD09RHV02`/;01FEUH0Hf=S04I6AP11
@D40=SHf04A4A01=CDd0IVIV069RHP11@D409bLW02DU9@0l?3`0OGem07inOP1YJFT0IfMW07moO`22
PX80Fe]K07=cL`27QhL0OGem08R8R025QHD0KVi^05QHF01@D500ADE503Lg=`10@400EEEE07=cL`1g
MgL0RHV909BDU01_Kfl0De=C05UIF@1PH600;Rh^03Ti>@17AdL0?3`l02@T900V9RH09BDU03<c<`12
@T80?Cdm03Xj>P0f=SH0=CDe02l_;`0Y:BT0>c/k03hn?P0f=SH0BDU903Xj>P0e=CD0=SHf034a<@0d
=3@00P0a<C403@0c<c<0@T9203<c<`0`<3009bLW03Hf=P0/;2`0;bl_03@d=00l?3`0@41004Y:BP1@
D5000P1GEeL03@1HF5P0G5aL06e]K@1XJ6P0K6a/075aL@1dM7@0Ogmo07QhN01nOWh0OGem07inOP21
PH400`20P800401fMWH0GemO04Y:BP0g=cL0=3@d04U9B@1DE5@0HV9R06MWI`1/K6`0Lg=c07emO@25
QHD0P82008F5Q@29RHT208N7Q`0508n?S`2>SXh0T92@08^;R`29RHT00P2=SHd02@2;Rh/0S8b<08V9
R@2@T900Shn?08V9R@2>SXh0Shn?08^;R`0208f=S@0=08b<S02;Rh/0S8b<08^;R`2:RXX0QHF508V9
R@28R8P0T92@08J6QP27QhL0S8b<08R8R00208^;R`0808V9R@28R8P0QhN708V9R@2:RXX0SHf=08Z:
RP2;Rh/2092@T00708j>SP2DU9@0SXj>09>CT`2EUID0UiNG09:BTP0209>CT`80U9BD00<0V9RH09JF
UP2OWil00P2IVIT01@2KVi/0W9bL09^KV`2PX:00WinO0080XJ6Q0100ZZZZ0:JVYP2TY:@0YJFU0:BT
Y02SXj<0ZJVY0:^[Z`2ZZZX0[Jf]0:b/[02`/;00][Jf0;>c/`2i^KT0^[Zj0P2l_;`00`2m_Kd0`L71
0<?3``020<71`@80b<S800D0bLW90<S8b037alL0b/[:0<_;b`020<g=c@80clo?00L0dM7A0<k>cP3B
d]80d];B0=7Ad@3Bd]80dm?C0080eMGE00@0dm?C0=CDe03De=@0e]KF0P3De=@02@3GemL0f][J0=GE
e@3AdM40[Zj^04U9B@1CDe<0Ng]k08>3P`0208n?S`80T92@00T0Rh^;08>3P`2<S8`0UIFE09:BTP2A
TI40Ti>C09:BTP2;Rh/0102ATI407@2@T900TI6A09BDU02ATI40T92@08b<S02ATI40U9BD09JFUP2B
TY80SXj>092@T02<S8`0T92@08^;R`2<S8`0Shn?08f=S@2?Shl0SHf=08Z:RP29RHT0R8R808F5Q@27
QhL0Rh^;08>3P`26QXH0QhN70080PH6100P0QHF508V9R@26QXH0PX:208F5Q@28R8P0RXZ:08^;R`80
R8R802<0RHV908b<S02?Shl0VYZJ0:FUY@2][Jd0];Bd0;Fe]@2f][H0/k>c0;^k^`31`L40b<S80=3@
d03De=@0emOG0=cLg03Jf]X0f=SH0=KFeP3Bd]80c/k>0<_;b`35aLD0^;Rh0::RXP2CTi<0Ph>307Ui
N@1_Kfl0Lg=c06a/K01ZJVX0L71`06m_K`0206UYJ@0406EUI@1TI6@0HV9R05MGE`80HV9R0140GEeM
05aLG01PH600IFEU06IVIP1XJ6P0HF5Q05iNGP1JFUX0De=C04i>CP16ATH0CTi>05=CD`1KFe/0Hf=S
06IVIP0206i^KP0306UYJ@1UIFD0Hf=S0080IfMW0180GemO05QHF01KFe/0EeMG05]KF`1NGUh0G5aL
05mOG`1KFe/0I6AT06=SH`1LG5`0HV9R061PH01RHV80HF5Q061PH01DE5@>0<SPf0003038h=P2024Q
8@0?02<S8`0T92@08R8R01lO7`0R8R80;2`/038b<P12@T80GemO07AdM028R8P0UIFE09RHV02RXZ80
Z:RX0080Zj^[01L0ZZZZ0::RXP2RXZ80V9RH08Z:RP1jNWX0HF5Q04U9B@0e=CD0;bl_03@d=00l?3`0
BTY:05]KF`1eMGD0PH6109:BTP2GUiL0Vi^K0:FUY@2[Zj/0ZJVY0:n_[`020;>c/`80/K6a03`0/[:b
0;6a/@2c/k<0/K6a0:n_[`2a/K40[jn_0;Bd]02a/K40]KFe0:j^[P2a/K40Zj^[0:JVYP2PX:00V9RH
08Z:RP2GUiL0Y:BT0:2PX027QhL0NWYj07AdM00k>c/0=cLg03Ph>00m?Cd0;2`/030`<00i>CT0<S8b
034a<@0W9bL0;2`/02LW9`0V9RH09bLW02d];@0d=3@0?3`l02h^;P0X:2P0;2`/03/k>`16ATH0DU9B
05EEE@18B4P0@T9203Xj>P0`<300;bl_02d];@0d=3@0:BTY02h^;P0a<C40A4A40410@00k>c/203Hf
=P80@D5100D0?clo03Hf=P0g=cL0<S8b03Hf=P0203<c<`0<034a<@0f=SH0;bl_03Ti>@0l?3`0Bd];
03Hf=P0T92@0:2PX02/[:`0/;2`09bLW0P0/;2`03`0o?cl0ADE503<c<`0/;2`0;bl_04m?C`1_Kfl0
F5QH03<c<`0k>c/0?Cdm065QH@1]KFd0DE5A03@d=002034a<@1305eMG@1mOGd0JVYZ0492@P17AdL0
EUIF05QHF010@400G5aL09>CT`2>SXh0OGem079bLP1YJFT0HF5Q0492@P0m?Cd0@D5106=SH`1bLW80
PH6108N7Q`2DU9@0Ph>3059BDP0f=SH0FEUI06a/K00f=SH0>c/k03@d=00X:2P08R8R02HV9P0X:2P0
@d=304E5A@0f=SH0@D51030`<00];Bd0:b/[02@T900k>c/0BDU903Xj>P14A4@0?Cdm03<c<`0g=cL0
=3@d03<c<`0d=3@0>SXj03Lg=`15ADD0=SHf03<c<`0_;bl0=CDe02XZ:P0d=3@0<C4a03@d=00i>CT0
ADE504i>CP0204m?C`0:05IFEP1NGUh0JVYZ06a/K01WIfL0LG5a07MgM`1mOGd0M7Ad07]kN`80P820
0100Ogmo0820P01nOWh0OWin07alO01XJ6P0DU9B03/k>`0_;bl0?Shn051@D01MGEd0I6AT06EUI@1`
L700NGUi0P23Ph<01`25QHD0Ph>308:2PP26QXH0R8R808V9R@2:RXX00P2;Rh/00`2>SXh0Rh^;08b<
S00208^;R`0C08Z:RP2;Rh/0SXj>08^;R`2?Shl0SHf=092@T02?Shl0RXZ:08b<S02;Rh/0SHf=08^;
R`26QXH0R8R808Z:RP2;Rh/0QhN708>3P`0308R8R00808n?S`2<S8`0RXZ:08N7Q`28R8P0RXZ:08j>
SP27QhL208b<S00808^;R`2>SXh0UIFE09NGU`2BTY80TI6A09FEU@2DU9@209:BTP0409JFUP2EUID0
UIFE09^KV`80W9bL00<0WIfM09jNWP2NWYh00P2MWId03P2QXJ40YjNW0:6QX@2UYJD0Z:RX0:BTY02W
YjL0ZJVY0:NWY`2VYZH0Z:RX0:b/[02][Jd0/[:b0P2f][H01P2e]KD0^KVi0;Zj^P2n_[h0`<300<;2
`P80`l?300/0`L710<C4a037alL0aLG50<[:bP37alL0b<S80<W9b@3;bl/0c<c<0<g=c@020<c<c007
0=3@d03>c/h0d=3@0=GEe@3@d=00dm?C0=CDe0030=KFeP030=CDe03Fe]H0e]KF0080f=SH01H0emOG
0=KFeP3EeMD0c/k>09>CT`0`<300CTi>07UiN@1jNWX0SHf=09:BTP2;Rh/0SHf=09BDU02<S8`0Ti>C
09FEU@2BTY80UYJF096AT@2?Shl0T92@0P2>SXh0102;Rh/0Shn?092@T02>SXh208n?S`0508b<S02:
RXX0TY:B08n?S`2BTY800`2@T9000`2<S8`0SHf=092@T00208j>SP0:08b<S02;Rh/0S8b<08f=S@2;
Rh/0SXj>08Z:RP28R8P0RXZ:08R8R080Q8B400L0PX:20861P@23Ph<0Q8B408J6QP21PH40QXJ60080
QhN70P28R8P01`26QXH0RHV909:BTP2MWId0Z:RX0;Vi^@2n_[h00P2m_Kd30<30`00N0<C4a039bLT0
cLg=0=?Cd`3GemL0fm_K0=[JfP3IfMT0e]KF0=;BdP3?cll0cLg=0<O7a`2m_Kd0YjNW09RHV025QHD0
OGem07AdM01cLg<0LG5a06m_K`1`L700LW9b06e]K@1[Jf/0IFEU06UYJ@1SHf<0G5aL0P1PH6001@1N
GUh0FEUI05YJFP1PH600IFEU0080IVIV00T0H61P05UIF@1@D500ATI60492@P1<C4`0D51@05aLG01T
I6@00`1XJ6P02`1YJFT0IfMW06EUI@1VIVH0HF5Q06EUI@1LG5`0Fe]K05MGE`1LG5`0GEeM0080GUiN
00X0F5QH05iNGP1PH600G5aL06ATI01KFe/0GemO06ATI01OGel0Fe]K3P38h=P000`0b>3H0P0V9RH0
3`0U9BD0:BTY028R8P0Q8B409RHV02LW9`0b<S80@d=3061PH01gMgL0R8R809bLW02IVIT0WYjN0:VY
Z@020:^[Z`0E0:VYZ@2UYJD0WinO09^KV`29RHT0NGUi05iNGP14A4@0;Rh^02d];@0d=3@0@D5104e=
C@1PH600MgMg08:2PP2BTY80UiNG09fMW@2WYjL0ZZZZ0080[Jf]0`2a/K40802_[jl0/K6a0;2`/02b
/[80/K6a0;:b/P2a/K40/k>c0;Bd]02a/K40]kNg0;2`/02a/K40ZJVY0:RXZ02RXZ80VYZJ08Z:RP2B
TY80XJ6Q0:>SX`1oOgl0LG5a06UYJ@0f=SH0>c/k03Lg=`0k>c/0=3@d02LW9`0d=3@0=CDe0P0[:b/0
3@0/;2`0;Rh^02TY:@0X:2P0:BTY03@d=00i>CT0<S8b02h^;P0[:b/0<c<c02d];@0j>SX00P15ADD0
2`14A4@0?Cdm0492@P0a<C40:2PX030`<00f=SH0<30`03@d=010@400AdM70080?Cdm00X0>3Ph03lo
?`0o?cl0@d=30410@00];Bd0:b/[02TY:@0a<C40=SHf0P0a<C4203<c<`0804Y:BP1KFe/0=CDe02TY
:@0W9bL0:RXZ02/[:`0];Bd203<c<`0V03hn?P12@T80;Rh^02<S8`0Y:BT0?Shn05iNGP1KFe/0?Shn
03Hf=P1EEED0K6a/05ADE00l?3`0?Cdm03hn?P1EEED0J6QX06IVIP1CDe<0Cdm?06EUI@1>CTh0@D51
05EEE@1UIFD0RXZ:08>3P`1WIfL0KVi^06YZJP1MGEd0Bd];05YJFP1bLW80OGem08V9R@2EUID208b<
S00Q05QHF00^;Rh0=SHf05QHF01cLg<0:b/[02`/;00f=SH0;bl_02XZ:P0W9bL0<30`02h^;P0l?3`0
A4A403`l?00c<c<0=CDe03lo?`0Y:BT0=3@d04E5A@0n?Sh0>c/k03lo?`0f=SH0>3Ph02/[:`0`<300
>c/k03hn?P0f=SH0@T920080=CDe00<0<S8b02PX:00/;2`00P0];Bd0100c<c<0>CTi04e=C@1?Cdl2
05=CD`0Z05IFEP1EEED0Hf=S06QXJ01YJFT0LG5a07QhN01lO7`0OWin07YjNP1mOGd0Ph>30820P025
QHD0P82007alO01hN7P0KFe]05=CD`19BDT0=CDe03Ph>01FEUH0Fe]K06MWI`1^KVh0K6a/07emO@25
QHD0Q8B40861P@26QXH0PX:208F5Q@28R8P0RXZ:08^;R`26QXH0QHF508b<S02:RXX0Rh^;0P2:RXX0
6@2>SXh0Shn?08n?S`2>SXh0Ti>C08j>SP2ATI40Rh^;08n?S`2ATI40Shn?08b<S027QhL0RHV908F5
Q@27QhL0RXZ:08R8R025QHD0QhN708V9R@28R8P0S8b<08N7Q`2>SXh00P2:RXX02P29RHT0Shn?08b<
S02>SXh0SHf=08n?S`2@T900Shn?09>CT`2@T90209JFUP0>09BDU02GUiL0UiNG09RHV02IVIT0Vi^K
09ZJVP2LW9`0Vi^K09VIV@2KVi/0XJ6Q0:>SX`2RXZ820:>SX`0:0:BTY02WYjL0YJFU0:BTY02ZZZX0
Z:RX0:NWY`2UYJD0Zj^[0:b/[080/K6a00/0][Jf0;Ng]`2g]kL0^;Rh0;Vi^@2l_;`0`L710<;2`P31
`L40`l?30<;2`P020<O7a`030<K6aP3:b/X0bLW90080b/[:00<0bl_;0<k>cP3<c<`00P3<c<`0103A
dM40d=3@0=3@d03Cdm<20=7Ad@090=OGe`3De=@0e]KF0=SHf03Fe]H0eMGE0=OGe`3Hf=P0emOG0080
f=SH0140eMGE0<30`01WIfL08b<S04E5A@1kNg/0OGem08V9R@2>SXh0SHf=096AT@2DU9@0QhN709^K
V`2BTY80UYJF09BDU00209:BTP0E09FEU@2BTY80TY:B08f=S@2@T900SHf=08n?S`2@T900SXj>08f=
S@2?Shl0TY:B08f=S@2?Shl0SHf=08j>SP2<S8`0T92@08V9R@2?Shl0S8b<0080SXj>01D0Shn?08^;
R`2:RXX0SHf=08^;R`28R8P0PX:208R8R026QXH0P8200861P@1oOgl0Q8B408N7Q`20P800Q8B408N7
Q`25QHD0Ph>308Z:RP24Q8@00P28R8P0:@2>SXh0WYjN0:b/[02j^[X0`<300<K6aP38b<P0a/K60<S8
b035aLD0b<S80<K6aP39bLT0d=3@0=7Ad@3GemL0f][J0=_Kf`3Jf]X0fMWI0=GEe@3AdM40cLg=0<W9
b@2j^[X0[:b/09VIV@29RHT0Ogmo07QhN01bLW80M7Ad079bLP1aLG40Kfm_07=cL`1`L700IVIV06e]
K@1[Jf/0HV9R00<0HF5Q02T0G5aL05UIF@1SHf<0IFEU06ATI01ZJVX0IFEU05eMG@1FEUH0CDe=04U9
B@1;Bd/0CTi>05EEE@1NGUh0Hf=S06MWI`1YJFT0K6a/06QXJ01/K6`0IVIV06=SH`1TI6@0Hf=S05iN
GP1JFUX0EEEE069RHP1SHf<0Fe]K05iNGP1QHF40GemO06=SH`1MGEd0F5QH05eMG@1UIFD0HV9R06=S
H`0>0<SPf0003038h=P202LW9`0L028R8P0U9BD09bLW02PX:00Z:RX0;2`/02l_;`1=CDd0JFUY07Qh
N02:RXX0UiNG09^KV`2RXZ80ZJVY0:f][@2/[:`0ZZZZ0:FUY@2OWil0VIVI08V9R@1gMgL0HF5Q03De
=@0Y:BT0;Bd]038b<P80ATI600X0Hf=S07MgM`25QHD0T92@09VIV@2MWId0YZJV0:ZZZP2^[Zh0/[:b
0P2c/k<01`2`/;00/k>c0;Bd]02c/k<0/[:b0;>c/`2a/K400P2b/[80702d];@0[jn_0;6a/@2e]KD0
/K6a0:VYZ@2VYZH0X:2P09^KV`2DU9@0RHV909RHV02TY:@0MgMg06e]K@1PH600=3@d03Ti>@0g=cL0
:b/[03<c<`0a<C40=cLg04I6AP0[:b/0:2PX030`<00^;Rh202`/;00A02d];@0Y:BT0>CTi030`<00Y
:BT0;2`/034a<@0/;2`0<S8b03dm?@19BDT0Bd];04=3@`0m?Cd0<30`02XZ:P0d=3@00`0b<S802P10
@400@d=30410@013@d<0?Cdm04U9B@0h>3P0?clo0451@@0`<30202XZ:P80;2`/0P0[:b/0200g=cL0
>CTi04Y:BP1DE5@0;2`/02LW9`0Y:BT0:2PX0P0^;Rh202TY:@0:03/k>`1<C4`0;Bd]02TY:@0V9RH0
>CTi055AD@1OGel0CDe=03lo?`80GEeM00`0=3@d02HV9P0];Bd0EUIF06a/K01FEUH0AdM704i>CP1Q
HF40LW9b065QH@1[Jf/207AdM00707QhN01kNg/0I6AT06YZJP1YJFT0H61P079bLP0207EeM@0?07Yj
NP2CTi<0Shn?08f=S@1[Jf/0<C4a02/[:`0a<C40JVYZ07IfMP0Y:BT0:RXZ030`<00j>SX0:BTY0080
9bLW01T0;bl_03/k>`14A4@0?Shn03dm?@0o?cl0>c/k02h^;P0d=3@0C4a<03dm?@0^;Rh0?3`l03lo
?`0m?Cd0?3`l034a<@1>CTh0E5AD04I6AP13@d<0=cLg02d];@0b<S80;bl_0080:RXZ00D0;2`/02d]
;@0j>SX0@d=304Q8B002051@D00Z05IFEP1HF5P0GUiN06=SH`1[Jf/0M7Ad07MgM`1lO7`0P82007mo
O`1mOGd0OWin08B4Q020P800Ph>308:2PP1oOgl0M7Ad05QHF01=CDd0=cLg03<c<`1BDU80EUIF06UY
J@1WIfL0J6QX07UiN@20P800PH6108F5Q@23Ph<0Q8B408>3P`25QHD0S8b<08R8R02=SHd0RHV909:B
TP2:RXX0Rh^;0P29RHT208b<S00808j>SP2<S8`0SXj>08Z:RP2CTi<0TI6A08n?S`2<S8`208V9R@03
08B4Q02@T900QHF50080QhN700H0Rh^;08F5Q@28R8P0S8b<08R8R029RHT208^;R`0408Z:RP2;Rh/0
RXZ:08^;R`80SHf=00T0Shn?08b<S02CTi<0Ti>C08f=S@2BTY80TI6A08n?S`2JVYX00P2IVIT01`2A
TI40V9RH09^KV`2FUYH0W9bL09jNWP2JVYX00`2MWId01`2OWil0XZ:R0:>SX`2TY:@0YJFU0:NWY`2T
Y:@00P2VYZH03`2XZ:P0Zj^[0:j^[P2/[:`0[jn_0;2`/02c/k<0][Jf0;Rh^02g]kL0^KVi0;jn_P30
`<00`L710;jn_P020<?3``040<C4a038b<P0alO70<O7a`80b<S800D0bLW90<g=c@3AdM40clo?0<g=
c@020<o?c`080=3@d03AdM40d];B0=?Cd`3Bd]80e=CD0=KFeP3GemL20=KFeP040=GEe@3De=@0emOG
0=_Kf`80fMWI01@0e=CD0;>c/`15ADD0820P03hn?P1oOgl0NWYj08R8R02CTi<0T92@096AT@2GUiL0
TI6A09FEU@2IVIT0TY:B09FEU@2@T900Shn?092@T080Ti>C00T0SHf=08n?S`2BTY80SHf=09:BTP2;
Rh/0U9BD09NGU`2CTi<00P2<S8`0202ATI40SHf=08j>SP2>SXh0S8b<08^;R`29RHT0T92@0P2=SHd0
=02:RXX0RHV908J6QP25QHD0RHV908F5Q@27QhL0PX:208B4Q020P800O7al0820P022PX80Q8B408J6
QP27QhL0PX:20820P025QHD0PH6108:2PP2;Rh/0UYJF0:ZZZP2e]KD0_kno0<[:bP3<c<`0cLg=0<[:
bP3<c<`0bl_;0<W9b@37alL0bLW90<g=c@3@d=00e]KF0=_Kf`3Lg=`0fm_K0=KFeP3EeMD0dm?C0<c<
c036a/H0_kno0;6a/@2QXJ40SHf=07]kN`1eMGD207IfMP0907QhN01aLG40L71`06e]K@1/K6`0J6QX
071`L01XJ6P0IfMW0080HF5Q01@0FUYJ069RHP1OGel0GEeM069RHP1QHF40JFUY06YZJP1OGel0FUYJ
05eMG@1DE5@0C4a<059BDP1HF5P0EeMG06IVIP1SHf<0IVIV06][J`80JVYZ0`1SHf<03`1YJFT0GemO
05eMG@1MGEd0H61P06EUI@1OGel0GEeM061PH01JFUX0FEUI05eMG@1IFET0G5aL05eMG@02061PH0h0
b>3H000<0<SPf0808B4Q02P0820P01hN7P0R8R808B4Q02TY:@0/;2`0<c<c04I6AP1VIVH0OWin08n?
S`2GUiL0XZ:R0:VYZ@2ZZZX0[Zj^0;2`/02ZZZX0YJFU09nOW`2HV9P0QXJ607UiN@1MGEd0ADE502DU
9@0V9RH0<c<c03`l?017AdL0J6QX07QhN023Ph<0T92@09RHV02NWYh0Z:RX0:f][@2_[jl0/K6a0`2b
/[80102`/;00/k>c0;6a/@2_[jl20;Bd]080/[:b0100/k>c0;Jf]P2b/[80/k>c0:j^[P2VYZH0YJFU
09nOW`2LW9`0SXj>08J6QP2DU9@0WIfM07alO01]KFd0FEUI0P0g=cL02@0h>3P0;Bd]02`/;00d=3@0
?3`l0492@P0/;2`0:2PX030`<00202TY:@0702PX:00_;bl0:BTY03Ph>00g=cL0<S8b02h^;P02030`
<00902d];@0d=3@0>CTi03lo?`0n?Sh0?clo03De=@0`<300;Bd]0080<C4a00D0>3Ph04=3@`1@D500
@d=304M7A`0203Xj>P0D038b<P0c<c<0?3`l03`l?00c<c<0;2`/02l_;`0g=cL0;Rh^034a<@13@d<0
ATI604];B`12@T80;2`/034a<@0[:b/09BDU02PX:00W9bL202HV9P0^03Hf=P18B4P0=CDe02/[:`0W
9bL0;Bd]03lo?`1GEeL0JVYZ04Q8B01CDe<0>CTi02@T900R8R80?Shn06a/K01MGEd0@D5104];B`1@
D500Fe]K065QH@1WIfL0NWYj07QhN01iNGT0N7Qh07=cL`1QHF40MWIf08:2PP1fMWH0JFUY075aL@23
Ph<0Shn?08f=S@25QHD0Ng]k04=3@`0Y:BT0<C4a03dm?@1`L700H61P02LW9`80:BTY01X0ATI603Hf
=P0U9BD0;Rh^02TY:@0];Bd0@T9204M7A`19BDT0@D51034a<@0/;2`0<C4a04a<C014A4@0<S8b03@d
=00o?cl0>c/k03hn?P17AdL0OGem06UYJ@13@d<0@D5103Ti>@80;bl_00P0;Rh^03<c<`0];Bd0<C4a
038b<P0i>CT0@d=304M7A`80Bd];00T0De=C05QHF01JFUX0Fe]K06][J`1aLG40NGUi07]kN`1jNWX0
0P20P8003P1nOWh0P82008:2PP20P800PX:20820P01iNGT0HV9R05=CD`0f=SH0<30`051@D01GEeL0
IFEU0P1VIVH01@1fMWH0PH6108J6QP23Ph<0QHF50080Q8B400L0PX:208R8R025QHD0Rh^;08V9R@2;
Rh/0QHF50080RXZ:00D0TY:B08j>SP2:RXX0QhN708f=S@0208Z:RP<0T92@0P2;Rh/04`2:RXX0QHF5
08B4Q024Q8@0RHV908F5Q@29RHT0R8R808J6QP2<S8`0RXZ:08R8R02?Shl0Rh^;08Z:RP2=SHd0S8b<
08R8R02<S8`00P2>SXh01@2?Shl0SHf=09:BTP2>SXh0Ti>C00<0UIFE0P2GUiL00`2DU9@0UIFE09^K
V`0209fMW@0309VIV@2PX:00Vi^K0080WinO00l0XJ6Q0:BTY02RXZ80Xj>S0:NWY`2YZJT0YZJV0:BT
Y02ZZZX0/;2`0:b/[02[Zj/0ZZZZ0:j^[P2a/K400P2f][H01@2i^KT0_;bl0;bl_031`L40`<300080
_kno00<0alO70<K6aP35aLD00P37alL01`39bLT0b<S80<_;b`3;bl/0d=3@0=;BdP3>c/h00P3?cll2
0=3@d0070=7Ad@3Cdm<0eMGE0=OGe`3Bd]80e]KF0=CDe0030=KFeP0I0=CDe03Hf=P0fm_K0=[JfP3H
f=P0c/k>09bLW00Y:BT08B4Q03`l?021PH40N7Qh08>3P`2BTY80Shn?08^;R`2GUiL0Shn?09FEU@2F
UYH0U9BD09JFUP2BTY80U9BD08n?S`0208j>SP0Q08^;R`2DU9@0Shn?08f=S@29RHT0T92@09:BTP2D
U9@0SXj>08Z:RP29RHT0S8b<08^;R`2>SXh0S8b<08j>SP2:RXX0RHV908n?S`2>SXh0RHV908n?S`2:
RXX0RHV908f=S@29RHT0QHF508J6QP24Q8@0QXJ60861P@23Ph<0OGem0080PH6101<0QHF50861P@26
QXH0PH6107alO023Ph<0Rh^;08f=S@2NWYh0[Zj^0;fm_@38b<P0c<c<0<o?c`3Bd]80dM7A0<o?c`3=
cLd0bl_;0080b<S800D0c/k>0=3@d03Cdm<0f=SH0=_Kf`020=[JfP80eMGE00X0clo?0<K6aP31`L40
][Jf0:2PX02@T900PH6107UiN@1jNWX0MgMg0P1cLg<01`1`L700LG5a06m_K`1/K6`0Jf][06UYJ@1W
IfL00P1RHV80301LG5`0Fe]K05YJFP1NGUh0HV9R06ATI01WIfL0I6AT06MWI`1XJ6P0HF5Q05MGE`80
EEEE00X0Fe]K05MGE`1JFUX0GEeM06=SH`1TI6@0Jf][06ATI01[Jf/0IfMW0P1XJ6P206ATI00>05mO
G`1KFe/0HF5Q06IVIP1KFe/0G5aL05mOG`1HF5P0FUYJ065QH@1KFe/0GUiN065QH@1SHf<>0<SPf000
3038h=P201lO7`808B4Q01X09BDU020P800S8b<0<30`02l_;`1>CTh0Hf=S07inOP2@T900VYZJ0:2P
X02UYJD0[Zj^0:f][@2^[Zh0[:b/0:ZZZP2QXJ40VIVI08Z:RP1aLG40EeMG04A4A00V9RH09bLW02/[
:`80AdM700L0GemO07EeM@28R8P0T92@09RHV02OWil0YJFU00<0[Jf]0P2c/k<02`2b/[80[jn_0;>c
/`2c/k<0/;2`0;>c/`2a/K40/k>c0;Bd]02c/k<0];Bd0080/[:b01L0[jn_0:NWY`2VYZH0Y:BT09fM
W@2BTY80Rh^;092@T02KVi/0Ng]k06][J`1EEED0=3@d03De=@0_;bl0:BTY02h^;P0d=3@0=CDe03Xj
>P0c<c<0:b/[02d];@0202h^;P0702d];@0^;Rh0;Bd]038b<P0^;Rh0;bl_03<c<`0202`/;00V03Ph
>00a<C40<30`03Ti>@11@D40?Cdm03De=@0`<300<C4a02/[:`0j>SX0@D5104M7A`1<C4`0B4Q804=3
@`0j>SX0>c/k03@d=00];Bd0=CDe03Lg=`0l?3`0<C4a030`<00[:b/0<30`03`l?00g=cL0A4A404E5
A@0f=SH0:RXZ02h^;P0W9bL0;Bd]02PX:00S8b<202@T900E034a<@0l?3`0?clo02PX:00[:b/0;Bd]
03Hf=P1LG5`0M7Ad06=SH`14A4@09BDU02@T900[:b/0EeMG05IFEP0m?Cd0@D5104U9B@1CDe<0Fe]K
0080HF5Q03d0NGUi07alO01PH600IVIV08:2PP21PH40Ph>307UiN@1UIFD0FEUI07]kN`2>SXh0OWin
07QhN02;Rh/0FUYJ02/[:`0V9RH0:b/[03De=@1iNGT0D51@02HV9P0Y:BT09RHV04Y:BP16ATH09RHV
024Q8@0N7Qh092@T03dm?@0o?cl0ATI603/k>`0e=CD0=cLg03<c<`17AdL0@d=304a<C00b<S80?3`l
04U9B@1WIfL0LW9b07emO@1PH600A4A403/k>`0h>3P0>SXj03Hf=P0`<300>CTi02d];@0/;2`0;bl_
02d];@0o?cl0Bd];0080A4A400d0C4a<05UIF@1EEED0HV9R06EUI@1]KFd0MgMg07]kN`1gMgL0NWYj
0861P@1mOGd0Ogmo00<0PX:200T0Q8B407inOP1WIfL0E5AD03lo?`0b<S80C4a<05ADE01QHF400P1U
IFD00`1bLW80Ogmo08B4Q00208F5Q@80Q8B401D0QhN708F5Q@22PX80RHV908^;R`29RHT0Rh^;08j>
SP2:RXX0SHf=08^;R`29RHT0R8R808b<S02;Rh/0RXZ:092@T02:RXX0SXj>08b<S02@T9000`29RHT0
2@24Q8@0RXZ:08F5Q@29RHT0QXJ608R8R029RHT0QXJ608^;R`0208V9R@0408Z:RP2<S8`0SXj>08^;
R`80SHf=00T0SXj>08^;R`2CTi<0Ti>C09:BTP2@T900UIFE09>CT`2BTY800P2GUiL0202FUYH0UIFE
09jNWP2NWYh0WinO09jNWP2OWil0WIfM0P2NWYh01`2OWil0Xj>S0:2PX02QXJ40YZJV0:NWY`2UYJD0
0P2ZZZX0102][Jd0[:b/0:f][@2_[jl20;2`/080][Jf00P0^KVi0;^k^`2n_[h0`/;20<30`031`L40
_kno0<;2`P80a<C40P35aLD01`39bLT0bl_;0<g=c@3=cLd0dM7A0<k>cP3AdM400P3?cll20=;BdP09
0=?Cd`3AdM40dm?C0=GEe@3Fe]H0eMGE0=CDe03EeMD0emOG0080e]KF0P3Hf=P05P3Jf]X0f=SH0<_;
b`22PX808B4Q020P800d=3@0OGem0861P@1oOgl0TI6A08f=S@29RHT0UYJF08Z:RP2GUiL0U9BD09:B
TP2DU9@0TY:B09fMW@2CTi<308j>SP80Shn?01/0SXj>09JFUP2@T900Ti>C08j>SP2=SHd0SXj>08^;
R`28R8P0SXj>08Z:RP2<S8`0RHV908R8R02;Rh/0S8b<08j>SP27QhL0S8b<08R8R029RHT0RXZ:08R8
R02:RXX0QXJ608>3P`21PH400P23Ph<01P21PH40O7al07emO@20P800OWin08:2PP80Ogmo00h0P820
08F5Q@2<S8`0YZJV0;>c/`31`L40bl_;0=3@d03Cdm<0e]KF0=;BdP3?cll0c/k>0<[:bP80b<S800@0
cLg=0=7Ad@3Bd]80f=SH0P3Kfm/0303IfMT0e]KF0=GEe@3?cll0bl_;0<C4a02k^k/0ZJVY09NGU`25
QHD0O7al07YjNP80MgMg101cLg<0101^KVh0Jf][06UYJ@1YJFT2065QH@04061PH01MGEd0EeMG05iN
GP80IFEU0200J6QX06=SH`1[Jf/0J6QX069RHP1PH600EeMG05EEE@1IFET0De=C05EEE@1IFET0GEeM
061PH01UIFD0J6QX06a/K01]KFd0JVYZ06UYJ@1SHf<0IVIV069RHP1KFe/0IFEU065QH@1OGel0HF5Q
05YJFP1HF5P0EEEE05UIF@80HF5Q00<0GemO06=SH`38h=P03@38h=P000`0b>3H0P0S8b<06P0O7al0
8b<S01dM7@0R8R808b<S02`/;00j>SX0CTi>06YZJP1mOGd0T92@09fMW@2PX:00YZJV0:j^[P2][Jd0
ZZZZ0:j^[P2][Jd0Xj>S09RHV02:RXX0LW9b05MGE`0j>SX092@T0P0Z:RX0300h>3P0B4Q806=SH`1i
NGT0QHF5096AT@2LW9`0XJ6Q0:RXZ02/[:`0[jn_0;2`/080[jn_00@0];Bd0;6a/@2`/;00/[:b0P2c
/k<06P2a/K40[jn_0;:b/P2e]KD0/K6a0;:b/P2`/;00[Jf]0:RXZ02[Zj/0X:2P09fMW@2HV9P0Shn?
09FEU@2GUiL0NGUi06ATI01JFUX0>CTi03Lg=`0o?cl0;2`/030`<00h>3P0<C4a0P0c<c<06P0Z:RX0
>CTi03Ti>@0^;Rh0<30`02h^;P0`<300<S8b03@d=00^;Rh0:BTY02/[:`0f=SH0<30`02l_;`0Z:RX0
;Bd]03Ph>00l?3`0@d=303De=@0`<300;Rh^02LW9`0h>3P0BTY:0P19BDT04@17AdL0?clo03lo?`0_
;bl0<c<c034a<@0f=SH0?clo04=3@`0d=3@0<S8b02l_;`0/;2`0<S8b04=3@`14A4@0=3@d0080:RXZ
00@0:2PX02l_;`0Z:RX0;Rh^0P0S8b<0>P0f=SH0>3Ph04E5A@0l?3`0>3Ph02h^;P0a<C40FEUI07=c
L`1XJ6P0=3@d024Q8@0S8b<0?Shn05=CD`0];Bd0:b/[03De=@11@D40ADE505]KF`1OGel0M7Ad08F5
Q@1bLW80C4a<06ATI02=SHd0Shn?075aL@1MGEd0F5QH07UiN@2BTY80Ph>305eMG@1oOgl0MWIf03Ph
>00V9RH0;2`/02l_;`0l?3`0Ng]k0492@P0S8b<0;Bd]02XZ:P0c<c<0EeMG02l_;`0Q8B40820P02DU
9@0_;bl0A4A40492@P11@D4203De=@0?03Xj>P1?Cdl0IFEU05QHF00n?Sh0BDU906EUI@23Ph<0JFUY
05EEE@1>CTh0?Cdm03De=@0d=3@0=SHf0080>3Ph00<0?Cdm03<c<`0Y:BT00P0e=CD01@0c<c<0AdM7
04A4A014A4@0Bd];0080EEEE00@0EeMG06=SH`1YJFT0MGEe0P1lO7`01`1jNWX0P82007alO01oOgl0
Ph>30861P@20P8000P1nOWh04`1TI6@0D51@04Q8B00/;2`0>c/k04e=C@1DE5@0IfMW05iNGP1/K6`0
N7Qh08>3P`24Q8@0QHF50861P@23Ph<0QXJ608F5Q@24Q8@00`28R8P01@2:RXX0S8b<08b<S02<S8`0
Shn?0080S8b<00<0SXj>08b<S02:RXX0102:RXX06@2;Rh/0SXj>08R8R028R8P0PX:208B4Q025QHD0
QhN708J6QP28R8P0RHV908R8R02;Rh/0QhN708^;R`2=SHd0Rh^;08b<S02@T900SHf=08j>SP2@T900
SHf=096AT@2BTY800P2ATI400`2FUYH0V9RH09JFUP0209^KV`0409BDU02FUYH0V9RH09bLW080WinO
00<0W9bL09jNWP2MWId00P2MWId0202PX:00XZ:R0:NWY`2RXZ80Y:BT0:NWY`2ZZZX0YjNW0P2^[Zh0
5P2`/;00[Zj^0;6a/@2b/[80]KFe0;>c/`2i^KT0^[Zj0;fm_@32`/80`L710<C4a030`<00`l?30<K6
aP35aLD0a/K60<S8b03;bl/0b/[:0<g=c@3>c/h20<o?c`030<k>cP3=cLd0clo?0080d];B00@0dm?C
0=CDe03Cdm<0eMGE103Fe]H00`3GemL0fMWI0=SHf0030=SHf0090=OGe`2n_[h0GemO01/K6`0N7Qh0
=CDe07EeM@24Q8@0QHF50080SHf=00D0RHV909:BTP2;Rh/0TY:B09NGU`0209>CT`0309BDU02PX:00
SXj>0080T92@00L0SXj>09>CT`2ATI40Shn?096AT@2@T900SXj>0080S8b<00H0TI6A08V9R@2:RXX0
RXZ:08f=S@2<S8`308V9R@0=08^;R`2?Shl0RHV908b<S029RHT0SXj>08N7Q`2;Rh/0QHF508J6QP27
QhL0RXZ:08N7Q`020820P00X07alO020P800OGem08:2PP21PH40OGem0861P@26QXH0PH61092@T02W
YjL0_[jn0<G5a@3;bl/0dM7A0=GEe@3IfMT0emOG0=7Ad@3>c/h0bl_;0<S8b039bLT0cLg=0=7Ad@3C
dm<0f=SH0=[JfP3Lg=`0fm_K0=KFeP3De=@0dM7A0<k>cP37alL0_;bl0:f][@2JVYX0SXj>0861P@80
N7Qh00L0MGEe071`L01gMgL0N7Qh06YZJP1[Jf/0IfMW0080IVIV0P1SHf<02P1LG5`0Fe]K05mOG`1V
IVH0HV9R06EUI@1ZJVX0IVIV06m_K`1VIVH206ATI003069RHP1MGEd0FUYJ0080EEEE00D0EUIF05QH
F01OGel0IfMW06EUI@0206UYJ@80J6QX0100JFUY06][J`1OGel0Fe]K05aLG01MGEd0HV9R05aLG01H
F5P0G5aL05IFEP1NGUh0GEeM05MGE`1PH600Fe]K3P38h=P000`0b>3H0`0O7al0400M7Ad07QhN02DU
9@0X:2P0<30`04A4A01CDe<0KFe]08B4Q02FUYH0XZ:R0:2PX02YZJT0/;2`0:n_[`2a/K420:NWY`0B
0:6QX@2HV9P0R8R807MgM`1GEeL0>3Ph02PX:00[:b/0;Rh^03/k>`1<C4`0Hf=S07YjNP26QXH0TI6A
09bLW02SXj<0YZJV0P2^[Zh01@2d];@0/;2`0;2`/02_[jl0];Bd0080/;2`102b/[809`2`/;00];Bd
0;Bd]02a/K40/;2`0;:b/P2UYJD0YZJV09nOW`2JVYX0Shn?08b<S02KVi/0VYZJ07emO@1[Jf/0HV9R
03`l?00n?Sh0ADE502`/;00];Bd0=cLg03De=@0/;2`0:2PX02d];@0k>c/0;2`/02h^;P0];Bd0=3@d
02h^;P0d=3@0<c<c034a<@0/;2`0;Bd]02TY:@02030`<00D038b<P0d=3@0<c<c03De=@0n?Sh0=SHf
03Lg=`0^;Rh0<C4a03@d=01>CTh0F5QH05ADE01?Cdl0B4Q80451@@0e=CD0@41003Lg=`0Y:BT20451
@@80=3@d00`09bLW02l_;`0^;Rh0A4A403hn?P0];Bd0=cLg03Ph>00a<C40;Bd]02/[:`0S8b<202HV
9P1102PX:00g=cL0@D5103/k>`0a<C40:2PX03Ti>@1EEED0Kfm_06YZJP0i>CT09BDU03De=@19BDT0
=cLg020P800W9bL0>3Ph03De=@11@D40De=C069RHP1mOGd0R8R807EeM@1DE5@0LG5a08b<S02BTY80
KVi^05aLG01[Jf/0TY:B08R8R01TI6@0HV9R07AdM01@D500:RXZ028R8P0U9BD0;2`/04M7A`1lO7`0
<S8b02@T900];Bd0;Rh^02XZ:P1=CDd0Cdm?02PX:00Q8B408R8R02d];@1<C4`0BTY:05UIF@19BDT0
A4A404Q8B01iNGT0Z:RX0:NWY`1nOWh00P1]KFd00`1XJ6P0ATI603`l?00204A4A00403Lg=`0h>3P0
<S8b03lo?`80=cLg00H0=3@d02XZ:P0g=cL0=cLg03De=@0k>c/204U9B@0U04Q8B01<C4`0EUIF05UI
F@1NGUh0Jf][07AdM01nOWh0OGem07alO01jNWX0P8200861P@22PX80OWin08:2PP21PH40Ogmo07Ee
M@1CDe<0AdM703De=@0i>CT0DU9B05MGE`1WIfL0JFUY06MWI`1dM7@0PH6108F5Q@23Ph<0OWin08B4
Q025QHD0Q8B408R8R00208N7Q`0808>3P`27QhL0RHV908b<S02:RXX0RHV908Z:RP2>SXh308^;R`06
08f=S@2:RXX0QhN708N7Q`2:RXX0SXj>0P2:RXX408J6QP0:08N7Q`24Q8@0R8R808N7Q`2:RXX0QXJ6
08B4Q02;Rh/0SXj>08f=S@80Shn?00X0TI6A092@T02>SXh0TI6A09BDU02EUID0TI6A09JFUP2DU9@0
VIVI0P2KVi/06`2EUID0VYZJ09NGU`2IVIT0WinO09fMW@2NWYh0WIfM09bLW02NWYh0WinO0:6QX@2R
XZ80Y:BT0:NWY`2XZ:P0[:b/0:RXZ02WYjL0Zj^[0:b/[02d];@0/K6a0;Fe]@2b/[80]KFe0;Jf]P02
0;Zj^P0@0;bl_032`/80_kno0<?3``32`/80a<C40<G5a@36a/H0aLG50<W9b@3:b/X0c<c<0<g=c@3<
c<`0c/k>0<g=c@80d=3@00<0d];B0=3@d03Bd]80103Cdm<20=KFeP050=OGe`3Fe]H0e]KF0=WIf@3G
emL00P3Jf]X05P3Kfm/0e=CD0;:b/P18B4P07AdM024Q8@0_;bl0NGUi08F5Q@24Q8@0SXj>08n?S`2=
SHd0V9RH08f=S@2@T900TY:B09>CT`2BTY80Vi^K09VIV@2=SHd2096AT@0<08j>SP2?Shl0SHf=08j>
SP2@T900SHf=096AT@2?Shl0SHf=08V9R@2;Rh/0S8b<0P2:RXX01`2=SHd0R8R808j>SP2>SXh0RXZ:
08j>SP29RHT00P2;Rh/09`2:RXX0QhN708^;R`25QHD0QXJ608b<S01oOgl0Q8B407alO020P800PH61
08:2PP24Q8@0O7al08>3P`20P800OWin0820P023Ph<0T92@0:^[Z`2n_[h0bLW90<o?c`3Cdm<0eMGE
0=WIf@3Fe]H0dM7A0<c<c03=cLd0bLW90<_;b`3>c/h0clo?0=?Cd`3Hf=P0gmoO0=_Kf`020=WIf@0D
0=KFeP3Cdm<0c/k>0<S8b031`L40];Bd09nOW`2>SXh0QHF507YjNP1dM7@0LG5a071`L01dM7@0MGEe
079bLP1YJFT0J6QX06YZJP1XJ6P206][J`0505]KF`1OGel0GemO06EUI@1YJFT00P1[Jf/0201ZJVX0
L71`06QXJ01ZJVX0IFEU06ATI01NGUh0Fe]K0P1HF5P06@1EEED0E5AD05YJFP1QHF40IVIV06MWI`1Y
JFT0JVYZ06a/K01XJ6P0IfMW05]KF`1GEeL0GEeM069RHP1PH600GemO05EEE@1HF5P0EEEE061PH01N
GUh0G5aL05YJFP1MGEd03P38h=P000`0b>3H0P0O7al03`0N7Qh071`L01dM7@0S8b<09BDU02l_;`1<
C4`0FEUI075aL@24Q8@0VIVI09nOW`2XZ:P0ZJVY0:f][@020:j^[P0G0:VYZ@2TY:@0W9bL09>CT`27
QhL0MWIf05IFEP0`<3009BDU02HV9P0Z:RX0>c/k04];B`1SHf<0N7Qh08B4Q02DU9@0Vi^K0:6QX@2Y
ZJT0Zj^[0;:b/P2c/k<00P2a/K400`2c/k<0/;2`0;Bd]0020:n_[`0O0;:b/P2_[jl0/;2`0:j^[P2d
];@0/k>c0;6a/@2`/;00ZJVY0:NWY`2OWil0X:2P09RHV02CTi<0SHf=096AT@2JVYX0QhN70861P@1[
Jf/0=SHf04I6AP1?Cdl0;2`/02XZ:P0Y:BT0:RXZ038b<P0];Bd0:BTY03Ti>@0202d];@0A02h^;P0[
:b/0;2`/03Hf=P0i>CT0=cLg02d];@0[:b/0<C4a030`<017AdL0<30`03Xj>P0_;bl0<C4a03De=@0j
>SX00P0e=CD0700[:b/0=3@d05eMG@1GEeL0EUIF04m?C`16ATH0@41003Lg=`0e=CD0;2`/02h^;P0n
?Sh0@T9204a<C00h>3P0<c<c030`<00g=cL0@d=303`l?00[:b/0;Bd]03Hf=P0l?3`0:b/[03Ti>@0c
<c<202h^;P0?02`/;00b<S80CDe=04=3@`0V9RH0;Rh^03Ph>01GEeL0JFUY07=cL`11@D4092@T03`l
?00o?cl09RHV00808R8R03P0:RXZ030`<015ADD0G5aL06][J`1mOGd0Shn?09>CT`1oOgl0J6QX08V9
R@2=SHd0QHF506YZJP1lO7`0SXj>06m_K`1=CDd0Jf][05eMG@0X:2P07alO02<S8`0T92@0;Bd]05AD
E01ZJVX0;2`/02PX:00W9bL0:RXZ02TY:@0d=3@0IFEU04Q8B00d=3@0>c/k04U9B@1aLG40OGem07mo
O`23Ph<0Ng]k07inOP2GUiL0Xj>S09ZJVP25QHD0PX:207AdM01CDe<0@D5102l_;`0l?3`0ATI603<c
<`80>3Ph00T0<c<c034a<@0l?3`0=SHf02l_;`0a<C40=SHf038b<P0f=SH00P11@D408016ATH0ADE5
059BDP1MGEd0Fe]K06][J`1aLG40MgMg07moO`20P800O7al07]kN`1lO7`0PH6107emO@24Q8@0Ogmo
07YjNP1fMWH0G5aL051@D00f=SH0;Rh^04Y:BP1KFe/0GemO069RHP1UIFD0LG5a07inOP1oOgl0Ph>3
0`24Q8@04@28R8P0QhN708F5Q@29RHT0PH6108B4Q027QhL0R8R808^;R`28R8P0RHV908b<S02?Shl0
SHf=08^;R`2<S8`0SHf=0080S8b<01X0RXZ:08b<S02;Rh/0QHF508B4Q02;Rh/0QXJ608R8R023Ph<0
QXJ608V9R@28R8P0SXj>08^;R`28R8P0Rh^;08j>SP2?Shl0T92@08n?S`2<S8`0SHf=08b<S02@T900
U9BD09NGU`80UYJF00/0UIFE09NGU`2KVi/0Vi^K09ZJVP2IVIT0V9RH09^KV`2JVYX0WinO09fMW@02
09jNWP0709bLW02PX:00XJ6Q0:RXZ02YZJT0YjNW0:VYZ@020:ZZZP0<0:VYZ@2/[:`0Z:RX0;:b/P2_
[jl0]KFe0;Ng]`2j^[X0^;Rh0;Zj^P2i^KT0_[jn0P2o_kl02P33`l<0aLG50<K6aP35aLD0a/K60<O7
a`36a/H0b/[:0<c<c03=cLd20<c<c0030<k>cP3AdM40clo?0080d=3@0`3Cdm<0103Fe]H0eMGE0=OG
e`3EeMD20=KFeP0K0=SHf03IfMT0f][J0=_Kf`3Jf]X0emOG0=3@d02EUID0:2PX01hN7P0Q8B40:2PX
06e]K@22PX80QhN708j>SP2=SHd0Rh^;09FEU@2=SHd0TI6A09>CT`2?Shl0TI6A09nOW`2BTY80TI6A
0080UiNG00H0Shn?08j>SP2@T900Shn?08f=S@2?Shl2092@T00N08n?S`2:RXX0RXZ:092@T02;Rh/0
RXZ:08R8R02;Rh/0S8b<08f=S@28R8P0Rh^;08Z:RP2<S8`0Rh^;08V9R@26QXH0PH6108F5Q@27QhL0
R8R808>3P`1mOGd0PX:207alO01nOWh0Ng]k07alO01kNg/0OGem0P1lO7`03@1mOGd0P82008n?S`2W
YjL0_kno0<[:bP3@d=00dm?C0=OGe`3Hf=P0emOG0=;BdP3>c/h00`3;bl/04P3>c/h0dM7A0=7Ad@3F
e]H0f][J0=cLg03IfMT0emOG0=SHf03De=@0dM7A0<c<c036a/H0^[Zj0:RXZ02FUYH0RXZ:07inOP80
MWIf00P0M7Ad07]kN`1dM7@0KFe]06MWI`1ZJVX0IfMW06=SH`80I6AT00@0H61P06EUI@1MGEd0H61P
0P1WIfL00`1XJ6P0JVYZ06m_K`0206i^KP0<06YZJP1PH600HV9R069RHP1MGEd0G5aL05QHF01GEeL0
F5QH05eMG@1PH600IFEU0P1ZJVX206QXJ00706EUI@1LG5`0H61P065QH@1LG5`0Hf=S05eMG@0205EE
E@0305IFEP1KFe/0G5aL0080GUiN00<0E5AD0<SPf038h=P03038h=P000`0b>3H0P0N7Qh201lO7`0U
02DU9@0R8R8092@T03@d=010@400G5aL06e]K@29RHT0U9BD0:2PX02YZJT0Z:RX0:b/[02][Jd0Zj^[
0:JVYP2SXj<0Vi^K096AT@25QHD0MGEe05eMG@0d=3@092@T028R8P0/;2`0>3Ph04];B`1PH600LW9b
08B4Q02CTi<0Vi^K0::RXP2XZ:P0[Jf]0;2`/0030;:b/P070;Bd]02^[Zh0[Zj^0:b/[02^[Zh0Zj^[
0:b/[0020:^[Z`0D0:n_[`2a/K40/;2`0:j^[P2YZJT0YjNW0:>SX`2OWil0VYZJ09BDU02:RXX0QXJ6
08b<S028R8P0Ti>C075aL@0l?3`0AdM704e=C@0];Bd202l_;`80:b/[00H0;Rh^03<c<`0[:b/0:RXZ
02`/;00^;Rh202/[:`0>02d];@0g=cL0<c<c03Ph>00[:b/0;Bd]03Lg=`1=CDd0AdM703De=@0Z:RX0
;Rh^030`<00a<C42038b<P0403<c<`0k>c/0H61P05EEE@80FEUI01@0EeMG04i>CP0k>c/0:2PX03<c
<`0^;Rh0<30`03Lg=`0l?3`0<c<c02XZ:P0^;Rh0=3@d03`l?00j>SX09bLW03De=@0c<c<0;Rh^030`
<080;bl_0P0e=CD202h^;P1B059BDP1;Bd/0:2PX03Hf=P0l?3`0ATI605eMG@1UIFD0AdM702l_;`11
@D40=cLg028R8P0S8b<09bLW02XZ:P0d=3@0@41004];B`1dM7@0PH6108n?S`2GUiL0RHV9071`L024
Q8@0MWIf08n?S`26QXH0NWYj0861P@1QHF40Fe]K07=cL`17AdL09BDU028R8P0V9RH09bLW038b<P1P
H600FEUI038b<P0j>SX0?clo059BDP19BDT0ATI607]kN`2<S8`0L71`08V9R@26QXH0RXZ:08j>SP25
QHD0OWin07=cL`1WIfL0JVYZ07AdM01XJ6P0CDe=05aLG01ZJVX0I6AT05mOG`0k>c/0?Shn03dm?@0i
>CT0;Bd]02`/;00^;Rh0=CDe03Xj>P0f=SH0<S8b02l_;`0`<300<C4a02l_;`80?Shn00/0B4Q804];
B`1=CDd0De=C05QHF01UIFD0KVi^07IfMP1kNg/0P82007UiN@0207alO00@08:2PP20P800PH6107al
O01jNWX0NGUi05mOG`1<C4`0@410034a<@16ATH0EEEE06=SH`1]KFd0IfMW079bLP80Ng]k00`0PH61
07emO@21PH40QHF508B4Q026QXH0R8R808N7Q`25QHD0P82008b<S026QXH208b<S080T92@0P2<S8`0
102?Shl0RHV908^;R`2?Shl208^;R`80RHV900@0QHF508:2PP28R8P0QHF50P26QXH208V9R@0508b<
S02;Rh/0RHV908f=S@27QhL00P2@T90308f=S@0508n?S`2>SXh0TY:B09BDU02GUiL00P2IVIT01P2D
U9@0V9RH09ZJVP2JVYX0WIfM09bLW080WIfM00P0UYJF09fMW@2OWil0XJ6Q0::RXP2PX:00XJ6Q0::R
XP80YJFU00l0Z:RX0:ZZZP2XZ:P0Z:RX0:FUY@2ZZZX0/;2`0;Fe]@2a/K40^;Rh0;Ng]`2f][H0^KVi
0;jn_P2m_Kd00P2o_kl01@33`l<0_kno0<C4a033`l<0a/K60080b<S800<0b/[:0<_;b`3:b/X00P3>
c/h01P3=cLd0c/k>0<k>cP3@d=00d];B0=3@d080e=CD00D0eMGE0=?Cd`3EeMD0fMWI0=KFeP020=SH
f00I0=WIf@3Kfm/0fMWI0=[JfP3Lg=`0emOG0<S8b01jNWX08R8R020P800N7Qh09BDU05mOG`23Ph<0
PH6108j>SP29RHT0S8b<09NGU`2=SHd0T92@09BDU02CTi<0V9RH09nOW`0209:BTP80Shn?0180SXj>
08f=S@2@T900SHf=08n?S`2>SXh0TI6A08n?S`2CTi<0S8b<08j>SP2:RXX0Rh^;08b<S028R8P0S8b<
08f=S@2:RXX208n?S`0A08^;R`2:RXX0T92@08j>SP2;Rh/0RXZ:08F5Q@2:RXX0Q8B40861P@22PX80
O7al0861P@1hN7P0OGem07alO01kNg/00P20P8002@1oOgl0R8R80861P@2BTY80Xj>S0;^k^`3;bl/0
d=3@0=?Cd`020=KFeP0?0=GEe@3AdM40c/k>0<g=c@3<c<`0b/[:0<g=c@3?cll0dM7A0=KFeP3Hf=P0
f][J0=SHf03Jf]X0emOG0080eMGE00d0d=3@0<W9b@2m_Kd0[:b/09bLW02=SHd0PX:207alO01gMgL0
LW9b07MgM`1iNGT0Lg=c0080JVYZ01d0Jf][06IVIP1QHF40HF5Q06IVIP1SHf<0HV9R05]KF`1SHf<0
I6AT06QXJ01/K6`0L71`06a/K01]KFd0KVi^06e]K@1QHF40FUYJ05eMG@1IFET0G5aL05]KF`1JFUX0
GemO069RHP1NGUh0KFe]06a/K00206QXJ00806UYJ@1SHf<0IfMW069RHP1NGUh0GEeM06EUI@1PH602
05ADE00505MGE`1MGEd0FEUI05]KF`1HF5P03P38h=P000`0b>3H0P0P82003`0N7Qh071`L01hN7P0R
8R809bLW02d];@18B4P0Hf=S07AdM02DU9@0UIFE09^KV`2SXj<0Z:RX0:f][@020:b/[00G0:RXZ02R
XZ80Vi^K08n?S`23Ph<0N7Qh05MGE`0b<S80;2`/02LW9`0/;2`0=SHf04=3@`1TI6@0MWIf08N7Q`2E
UID0VYZJ0:2PX02VYZH0[Jf]0;2`/02b/[800P2d];@00`2b/[80[Zj^0:f][@030:f][@0P0:^[Z`2Y
ZJT0YjNW0:b/[02^[Zh0/K6a0:f][@2ZZZX0Z:RX0:6QX@2KVi/0VIVI09NGU`2;Rh/0Ph>308J6QP1o
Ogl0Ti>C07YjNP13@d<0?clo03/k>`0_;bl0=cLg03<c<`0Y:BT0;bl_02d];@0b<S80;Bd]030`<00[
:b/202d];@0/030`<00b<S80?clo038b<P0_;bl0;Rh^038b<P0o?cl0EeMG06UYJ@1:BTX0;Bd]02XZ
:P0[:b/0<S8b02l_;`0c<c<0;bl_03hn?P1MGEd0C4a<04e=C@1MGEd0Fe]K04];B`0^;Rh09RHV03Ph
>00a<C40=3@d02d];@0l?3`0@D5103De=@0`<300=CDe04I6AP0g=cL0;2`/02d];@0V9RH0<C4a03<c
<`0/;2`403<c<`1;0410@01BDU80>3Ph02DU9@0f=SH0?Shn03/k>`1DE5@0G5aL05ADE00m?Cd0@d=3
034a<@0[:b/0;2`/02LW9`0d=3@0>c/k0451@@1IFET0N7Qh0820P02>SXh0Shn?08b<S01iNGT0O7al
071`L029RHT0SXj>07QhN026QXH0Hf=S06e]K@1XJ6P0ATI603hn?P0b<S80>3Ph051@D01YJFT0M7Ad
05UIF@1ZJVX0PH6108n?S`2SXj<0UiNG08Z:RP2EUID0TY:B09nOW`28R8P0LW9b06][J`1fMWH0M7Ad
06MWI`1CDe<0@41003Ti>@16ATH0B4Q802h^;P0g=cL0@T9204Q8B01LG5`0Fe]K04Y:BP0i>CT0>c/k
03<c<`0b<S80=CDe0080>3Ph00@0=cLg02l_;`0a<C40<c<c0P0_;bl203Hf=P0>04Q8B019BDT0BDU9
04Y:BP1ADE40G5aL06UYJ@1bLW80OWin07moO`1kNg/0NWYj07QhN01nOWh207emO@0=0861P@1hN7P0
N7Qh05mOG`18B4P0>CTi02/[:`0k>c/0E5AD061PH01RHV80IFEU06a/K00207]kN`0407emO@1lO7`0
OWin0861P@D0Q8B400H0QHF508V9R@28R8P0SHf=08V9R@2@T90308n?S`0408^;R`2<S8`0RHV908f=
S@80RHV900T0T92@08J6QP24Q8@0PX:208N7Q`25QHD0QXJ608N7Q`2<S8`00P29RHT0102:RXX0Rh^;
08f=S@2;Rh/4092@T00308b<S02=SHd0Shn?0080Ti>C00D0U9BD09NGU`2FUYH0UYJF09^KV`0209fM
W@0;09NGU`2LW9`0WYjN09fMW@2LW9`0XJ6Q0:2PX02NWYh0Xj>S0:6QX@2OWil00`2TY:@00`2VYZH0
ZJVY0:ZZZP020:NWY`060:^[Z`2`/;00]KFe0;>c/`2h^;P0^KVi0P2h^;P20;jn_P0>0;bl_030`<00
`/;20<30`035aLD0alO70<W9b@37alL0b/[:0<_;b`3>c/h0bl_;0<k>cP3=cLd20<o?c`060<k>cP3@
d=00d];B0=?Cd`3IfMT0dm?C0P3EeMD01`3Fe]H0emOG0=KFeP3GemL0f=SH0=WIf@3Jf]X00`3Kfm/0
0`3GemL0][Jf05MGE`0201/K6`0@01lO7`0T92@0GEeM07moO`23Ph<0RHV908^;R`2<S8`0UIFE08b<
S02ATI40UiNG09>CT`2NWYh0VIVI09:BTP@0SXj>00T0TI6A08f=S@2>SXh0T92@08J6QP2=SHd0SXj>
08^;R`2@T9000P2<S8`04`2;Rh/0R8R808R8R02<S8`0SHf=08b<S029RHT0R8R808Z:RP2<S8`0Rh^;
08V9R@28R8P0QhN708Z:RP26QXH0RHV908B4Q023Ph<00P20P80307inOP80O7al01X0OGem07moO`20
P800Ph>308b<S02MWId0][Jf0<W9b@3>c/h0e=CD0=OGe`3Hf=P0emOG0=?Cd`3AdM40c/k>0<_;b`3:
b/X0cLg=0=3@d03Cdm<0e=CD0=WIf@3Jf]X0fMWI0=gMg@80e]KF0140eMGE0<k>cP39bLT0a<C40;Fe
]@2XZ:P0U9BD08V9R@20P800NWYj07MgM`1eMGD0Ng]k075aL@1XJ6P0IfMW06QXJ00405mOG`<0Hf=S
00@0J6QX06a/K01YJFT0IVIV0P1^KVh0201cLg<0Jf][06i^KP1VIVH0HF5Q06=SH`1LG5`0GemO0P1K
Fe/205aLG00B05iNGP1WIfL0K6a/06QXJ01WIfL0HV9R06UYJ@1/K6`0I6AT069RHP1SHf<0JFUY069R
HP1BDU80DE5A05EEE@1LG5`0F5QH0P1ADE4>0<SPf0003038h=P2024Q8@0T028R8P0N7Qh08b<S028R
8P0X:2P0;bl_0492@P1WIfL0PH6108V9R@2FUYH0W9bL0:NWY`2YZJT0[:b/0:f][@2[Zj/0YjNW0:2P
X02KVi/0TI6A07emO@1dM7@0FUYJ03Lg=`0Y:BT092@T02l_;`0n?Sh0Cdm?06=SH`1iNGT0QXJ609FE
U@2IVIT0Xj>S0P2ZZZX02@2`/;00/[:b0;2`/02`/;00[jn_0:ZZZP2/[:`0ZZZZ0:b/[0020:^[Z`07
0:NWY`2YZJT0ZZZZ0:VYZ@2/[:`0Zj^[0:VYZ@020:6QX@0309^KV`2HV9P0VIVI0080S8b<00X0Ph>3
07YjNP1oOgl0MgMg04M7A`0k>c/0;Bd]02l_;`0i>CT0<C4a0P0^;Rh0300a<C40;2`/030`<00`<300
:b/[02d];@0[:b/0;Rh^03@d=00f=SH0=3@d034a<@80;Bd]00l0=cLg05=CD`1OGel0GUiN03hn?P0f
=SH0<S8b02l_;`0X:2P0;2`/03/k>`0i>CT0I6AT05]KF`1?Cdl00P1KFe/05@1EEED0>3Ph02`/;00h
>3P0;2`/02HV9P0Y:BT0=3@d04e=C@1BDU80<S8b0410@013@d<0=3@d02HV9P0Y:BT0<c<c030`<00Z
:RX09BDU02h^;P02030`<00=03<c<`0n?Sh0BDU9034a<@0];Bd0=3@d02LW9`0^;Rh0D51@05mOG`1I
FET0@D5103De=@0302l_;`1403Ph>00f=SH0=cLg0492@P1QHF40N7Qh07]kN`2;Rh/0SXj>0820P01o
Ogl0PH61079bLP26QXH0UIFE07emO@1kNg/0Jf][06i^KP1FEUH0DU9B06IVIP1WIfL0Kfm_08f=S@2I
VIT0Shn?07UiN@2BTY80ZJVY0;6a/@2f][H0YJFU08f=S@1iNGT0LW9b08R8R01bLW80?clo03De=@0m
?Cd0DU9B04i>CP0i>CT0<S8b034a<@0d=3@0@T92030`<00d=3@0@41003`l?019BDT0De=C04i>CP0f
=SH0?Cdm03Ph>00b<S80<30`04A4A00l?3`0>CTi03<c<`0_;bl0<S8b02XZ:P0`<30203<c<`0N0492
@P1;Bd/0@d=304e=C@1ADE40FEUI06MWI`1bLW80N7Qh07]kN`1oOgl0P82007MgM`25QHD0O7al07Ui
N@1nOWh0Ng]k07alO01^KVh0?clo03Xj>P0_;bl0>3Ph05ADE01MGEd0HV9R06a/K01^KVh0NGUi0P1m
OGd01P20P800Q8B408B4Q025QHD0Ph>308J6QP80Ph>300H0QHF508f=S@29RHT0T92@08^;R`2<S8`2
096AT@08092@T029RHT0Shn?08J6QP27QhL0RHV908Z:RP2<S8`208J6QP080861P@28R8P0QhN708J6
QP28R8P0QXJ608Z:RP29RHT208Z:RP80SHf=00@0S8b<08f=S@2@T900S8b<0P2>SXh01@2?Shl0Ti>C
092@T02DU9@0Ti>C0080U9BD00X0VIVI09^KV`2KVi/0V9RH09NGU`2PX:00WIfM09nOW`2QXJ40WinO
0P2NWYh209nOW`0L0:>SX`2RXZ80Y:BT0:FUY@2ZZZX0ZJVY0:^[Z`2/[:`0ZJVY0:^[Z`2^[Zh0]KFe
0;Ng]`2i^KT0^k^k0;Zj^P2o_kl0`L710;no_`31`L40`/;20<30`035aLD0a/K60<O7a`3:b/X0bLW9
0<[:bP80cLg=00T0c<c<0<k>cP3?cll0dM7A0=3@d03AdM40d];B0=?Cd`3Bd]800P3De=@01P3EeMD0
emOG0=[JfP3Hf=P0eMGE0=SHf080fMWI01T0gMgM0=kNgP3Kfm/0d];B0:FUY@10@4006QXJ01`L700O
7al08R8R04i>CP22PX80R8R808n?S`2=SHd0Rh^;09BDU02@T900TI6A09NGU`2JVYX0W9bL09:BTP2A
TI40SHf=0080S8b<00H0SHf=09:BTP2=SHd0SXj>08n?S`2=SHd308n?S`0608V9R@2>SXh0Ti>C08R8
R02>SXh0QhN70P2;Rh/0102=SHd0Rh^;08b<S02:RXX208b<S00908Z:RP25QHD0Q8B408F5Q@29RHT0
QXJ60820P01mOGd0P8200080Ph>300<0OGem07YjNP1lO7`00P1lO7`02@1kNg/0O7al08F5Q@28R8P0
Vi^K0;Fe]@39bLT0c/k>0=CDe0020=OGe`0=0=SHf03Cdm<0d=3@0<k>cP3<c<`0b/[:0<g=c@3>c/h0
d];B0=KFeP3IfMT0f][J0=_Kf`020=SHf080e]KF00P0d];B0<g=c@39bLT0_kno0:j^[P2MWId0Shn?
0820P080N7Qh00L0MWIf07UiN@1cLg<0JVYZ06UYJ@1WIfL0HV9R0080Fe]K00T0HV9R06=SH`1MGEd0
HV9R06MWI`1QHF40Hf=S06EUI@1^KVh00P1bLW801@1^KVh0L71`075aL@1WIfL0H61P0080G5aL0P1I
FET03`1NGUh0H61P06=SH`1WIfL0JVYZ06MWI`1UIFD0IfMW06][J`1/K6`0H61P05aLG01MGEd0GemO
06=SH`0205UIF@0505]KF`1FEUH0EUIF051@D01ADE403P38h=P000`0b>3H0P0N7Qh06@0R8R80820P
01hN7P0U9BD0:2PX038b<P1:BTX0Kfm_07emO@2:RXX0UYJF09fMW@2UYJD0Zj^[0:j^[P2ZZZX0Zj^[
0:JVYP2RXZ80UYJF08n?S`1mOGd0K6a/05IFEP0d=3@00P0W9bL03@0[:b/0?Shn04i>CP1SHf<0OWin
08R8R02DU9@0VIVI0:>SX`2WYjL0[Jf]0;2`/02d];@00`2`/;00102^[Zh0/;2`0;:b/P2^[Zh30:f]
[@80[:b/0P2a/K405P2][Jd0YJFU0::RXP2NWYh0WIfM09RHV02KVi/0TY:B08b<S01oOgl0MGEe07Ad
M01UIFD0Bd];03`l?00o?cl0=cLg03`l?00g=cL0;Rh^02PX:00^;Rh202d];@07030`<00b<S80<S8b
02d];@0[:b/0;Rh^038b<P0202XZ:P0X03`l?00/;2`0;2`/0492@P1:BTX0C4a<05=CD`1:BTX0?3`l
030`<00b<S80:BTY030`<00j>SX0Kfm_07YjNP1ADE40FEUI05ADE00n?Sh0<30`02l_;`0`<300;Bd]
02`/;00T92@0;bl_04I6AP1HF5P0?3`l03Xj>P0k>c/0<30`02HV9P0Y:BT0<30`02XZ:P0/;2`0:RXZ
02PX:080:BTY0100=CDe03Ti>@17AdL0@D5103Hf=P0X:2P08R8R02XZ:P1?Cdl0Hf=S05MGE`0j>SX0
=SHf02h^;P0Z:RX0<c<c0P0m?Cd01@12@T80IfMW06e]K@1kNg/0Ogmo0080R8R803/0O7al07emO@29
RHT0PH6108n?S`2KVi/0P82006m_K`1OGel0FEUI04i>CP1QHF40OWin0861P@1jNWX0R8R809BDU02J
VYX0UYJF09>CT`2GUiL0YJFU09RHV020P800G5aL04U9B@0l?3`0FUYJ07AdM00h>3P0:2PX038b<P11
@D40Bd];03Ph>00c<c<0;bl_03`l?018B4P0>3Ph034a<@10@400?Cdm03lo?`13@d<0>c/k03Lg=`13
@d<0=CDe03Xj>P0`<300>c/k03dm?@0n?Sh0<S8b030`<00a<C40<S8b03Hf=P02030`<00F03dm?@1;
Bd/0AdM704];B`1=CDd0EeMG06IVIP1_Kfl0NGUi07emO@1nOWh0P82007alO01oOgl0Ng]k07YjNP1k
Ng/0P82007]kN`1/K6`0B4Q803Ti>@80<30`00/0DU9B05UIF@1NGUh0IfMW06YZJP1bLW80O7al07mo
O`29RHT0P82008B4Q00308F5Q@0B0861P@26QXH0QHF508^;R`27QhL0QXJ608V9R@2:RXX0Shn?092@
T02<S8`0SHf=08b<S02:RXX0TI6A0861P@29RHT0R8R80P29RHT01@27QhL0QXJ608Z:RP29RHT0Rh^;
0080RHV90P2;Rh/01`2=SHd0RXZ:08^;R`28R8P0Rh^;08n?S`2=SHd00P2?Shl0202CTi<0U9BD09>C
T`2HV9P0TI6A09>CT`2JVYX0V9RH0P2OWil01P2HV9P0Vi^K09jNWP2KVi/0WYjN09nOW`80XJ6Q0P2R
XZ80102VYZH0YjNW0:^[Z`2VYZH20:VYZ@030:^[Z`2][Jd0[Zj^0080/K6a00<0/;2`0;Bd]02e]KD0
0P2k^k/0202l_;`0_kno0<71`@2o_kl0_Kfm0<;2`P33`l<0aLG50P36a/H01@3:b/X0b<S80<g=c@3=
cLd0c/k>0080cLg=0P3?cll00`3@d=00d];B0=3@d0020=?Cd`0A0=CDe03EeMD0eMGE0=GEe@3IfMT0
f=SH0=OGe`3Jf]X0fm_K0=cLg03Jf]X0h>3P0=gMg@3=cLd0QXJ602<S8`0N7Qh00P0M7Ad0400Q8B40
AdM708>3P`28R8P0RHV908Z:RP2;Rh/0UIFE092@T02=SHd0UYJF09bLW02OWil0Shn?092@T02<S8`2
09:BTP0I08b<S02ATI40Shn?09BDU02>SXh0Shn?08Z:RP2BTY80RXZ:08j>SP2<S8`0SHf=08Z:RP2;
Rh/0Shn?08^;R`2:RXX0SXj>08f=S@28R8P0RHV908Z:RP28R8P0QXJ608N7Q`0208F5Q@0608J6QP29
RHT0Q8B408:2PP20P800Q8B40P1nOWh00`21PH40Ogmo07YjNP0207]kN`0>07inOP27QhL0Q8B409VI
V@2g]kL0a/K60=3@d03EeMD0e]KF0=WIf@3EeMD0dm?C0=7Ad@3>c/h20<g=c@0J0<o?c`3Bd]80dm?C
0=KFeP3Hf=P0f][J0=_Kf`3IfMT0f][J0=SHf03Fe]H0dm?C0=;BdP3=cLd0`/;20;Jf]P2TY:@0VIVI
08J6QP1nOWh0N7Qh07EeM@1dM7@0K6a/06i^KP1WIfL206IVIP80I6AT0`1QHF40101PH600HF5Q06EU
I@1UIFD206][J`80LG5a0100L71`06m_K`1_Kfl0JFUY06ATI01PH600GEeM05YJFP1KFe/0GemO05iN
GP1LG5`0I6AT06UYJ@1WIfL0J6QX0P1VIVH03@1YJFT0IfMW05aLG01MGEd0HF5Q061PH01JFUX0EeMG
05]KF`1DE5@0DU9B055AD@1<C4`03P38h=P000`0b>3H0P0N7Qh09P0R8R808B4Q01`L700R8R80:2PX
03Hf=P1?Cdl0GEeM07emO@2>SXh0UYJF09jNWP2UYJD0Zj^[0;6a/@2^[Zh0ZZZZ0:NWY`2PX:00UYJF
08j>SP1nOWh0Kfm_04I6AP0/;2`09BDU02@T900X:2P0<c<c051@D01TI6@0NGUi08Z:RP2GUiL0X:2P
0:6QX@2XZ:P0Zj^[0P2b/[820;6a/@80/[:b00H0/;2`0;:b/P2b/[80/;2`0;Jf]P2c/k<30;:b/P04
0;Bd]02a/K40[:b/0:VYZ@80XZ:R00l0W9bL09RHV02BTY80R8R807UiN@1fMWH0Jf][05=CD`13@d<0
>SXj03/k>`14A4@0B4Q803Lg=`0/;2`0100[:b/0100Z:RX0;bl_030`<00^;Rh202/[:`80;Rh^00H0
=SHf02d];@0V9RH0;Bd]02TY:@0h>3P203/k>`0Q04Y:BP1IFET0C4a<02l_;`0W9bL0:RXZ03@d=01N
GUh0SHf=05MGE`1ADE40De=C03`l?00e=CD0<C4a030`<00/;2`0<C4a02l_;`0`<300?clo05=CD`1@
D500A4A403Ph>00_;bl09bLW02TY:@0e=CD0<30`02l_;`0[:b/09bLW0080:b/[05@0=3@d03Hf=P13
@d<0C4a<03`l?00W9bL08b<S02/[:`1CDe<0HF5Q04Y:BP0`<300>SXj03@d=00g=cL0Bd];05QHF01@
D500GEeM079bLP1iNGT0PX:207]kN`21PH40NGUi075aL@25QHD0QXJ60820P02?Shl0V9RH092@T01_
Kfl0DE5A03hn?P1ADE40P82008F5Q@1lO7`0QXJ609NGU`2NWYh0/;2`0;Rh^02ZZZX0RXZ:07QhN01G
EeL0@41002TY:@0T92@09bLW03<c<`1JFUX0EEEE038b<P0Y:BT0@D5104Q8B00n?Sh0=3@d03<c<`0m
?Cd0CTi>03dm?@0[:b/0?Cdm03Xj>P11@D40@410030`<00j>SX0?clo03`l?00b<S80;2`/03De=@0n
?Sh0>c/k034a<@0_;bl0<S8b03@d=00b<S82034a<@0903De=@13@d<0ADE504I6AP1?Cdl0EUIF06AT
I01_Kfl0N7Qh0080O7al00<0P82007YjNP1mOGd00P1lO7`05`1nOWh0Ng]k07IfMP1]KFd0CTi>03/k
>`0_;bl0;Rh^05ADE01MGEd0F5QH061PH01ZJVX0KVi^07UiN@23Ph<0PX:208>3P`20P800Q8B408F5
Q@28R8P0PX:20080Q8B400l0R8R808b<S02>SXh0Rh^;08V9R@2<S8`0SHf=096AT@2;Rh/0R8R808Z:
RP27QhL0R8R808j>SP27QhL00P29RHT0102<S8`0QXJ608R8R02;Rh/208Z:RP0908V9R@2?Shl0QhN7
08b<S02;Rh/0SXj>092@T02;Rh/0RXZ:0080Shn?00T0T92@09:BTP2FUYH0Shn?096AT@2BTY80UIFE
09NGU`2MWId00P2HV9P0202JVYX0WinO09fMW@2MWId0Vi^K09nOW`2QXJ40XZ:R0P2QXJ402P2VYZH0
YJFU0:RXZ02ZZZX0ZJVY0:^[Z`2][Jd0[jn_0;6a/@2`/;020;6a/@030;>c/`2d];@0^;Rh0080^k^k
0P2n_[h01P2o_kl0`<300<?3``32`/80a<C40<O7a`80aLG500/0bLW90<c<c03@d=00clo?0=3@d03<
c<`0d=3@0=7Ad@3?cll0d=3@0=?Cd`020=CDe0070=SHf03De=@0eMGE0=KFeP3EeMD0e]KF0=SHf002
0=[JfP080=_Kf`3Lg=`0g=cL0=[JfP34a<@0JVYZ01/K6`0L71`201hN7P0@020P800m?Cd0OGem08N7
Q`23Ph<0T92@08N7Q`2DU9@0Ti>C09:BTP2ATI40VIVI09RHV02@T900TI6A08n?S`80U9BD0180T92@
09FEU@2?Shl0T92@08f=S@2ATI40SHf=08j>SP2=SHd0RXZ:08j>SP2@T900S8b<08f=S@2<S8`0RHV9
08^;R`2<S8`208j>SP0608f=S@2<S8`0RXZ:08Z:RP25QHD0QhN70P24Q8@208>3P`80Q8B400<0PH61
07emO@1mOGd00P20P8002`1kNg/0OWin07]kN`1jNWX0PX:20861P@2CTi<0[jn_0<?3``3=cLd0dm?C
0080emOG00T0f=SH0=KFeP3Cdm<0d=3@0<k>cP3=cLd0c/k>0=7Ad@3Bd]800P3Fe]H00`3Jf]X0fm_K
0=WIf@020=WIf@0=0=SHf03EeMD0dm?C0<c<c037alL0_;bl0:n_[`2LW9`0SXj>08N7Q`1iNGT0L71`
06m_K`0306YZJP0K06=SH`1ZJVX0IVIV06IVIP1RHV80HF5Q06ATI01RHV80HF5Q05mOG`1SHf<0KFe]
07AdM01aLG40M7Ad07EeM@1bLW80Kfm_06UYJ@1ZJVX0JFUY061PH01QHF40G5aL05eMG@1PH600GemO
0080HF5Q0P1XJ6P00`1/K6`0I6AT06YZJP0206QXJ003069RHP1YJFT0Fe]K0080GemO00D0EEEE05IF
EP1BDU80E5AD04m?C`0>0<SPf0003038h=P201dM7@0X020P800O7al0820P028R8P0[:b/0=3@d04Y:
BP1[Jf/0NGUi08b<S02IVIT0WinO0:JVYP2`/;00[jn_0;2`/02/[:`0YjNW0::RXP2FUYH0T92@07mo
O`1YJFT0ATI602LW9`0T92@09RHV02TY:@0f=SH0D51@06IVIP1mOGd0QhN709BDU02LW9`0Xj>S0:ZZ
ZP2/[:`0[jn_0;6a/@80/k>c00@0/K6a0;:b/P2b/[80[jn_0P2b/[801P2a/K40];Bd0;Jf]P2d];@0
][Jf0;Fe]@80/;2`00L0ZJVY0:FUY@2OWil0W9bL09VIV@2BTY80QhN70080O7al0140M7Ad04A4A00l
?3`0>CTi03dm?@15ADD0AdM703@d=00b<S80<C4a038b<P0[:b/0;2`/02/[:`0a<C40;Bd]02TY:@02
02/[:`0?03@d=00_;bl0;Bd]02LW9`0`<300=3@d02l_;`0e=CD0;bl_034a<@15ADD0OGem07UiN@1F
EUH0?Shn0080;Rh^01P0CDe=08F5Q@1RHV80BDU905EEE@1:BTX0<30`02d];@0Y:BT0;Rh^02l_;`0c
<c<0>3Ph03dm?@1;Bd/0DE5A04Q8B00f=SH0;Rh^02HV9P0h>3P0=SHf02/[:`0V9RH202@T9080;2`/
02L0<C4a03Xj>P14A4@0ATI603De=@0X:2P071`L02TY:@1?Cdl0GemO03/k>`10@400>3Ph03hn?P1M
GEd0N7Qh06i^KP1YJFT0Kfm_07MgM`1jNWX0MWIf06UYJ@1`L700J6QX075aL@25QHD0RXZ:08J6QP28
R8P0TY:B092@T01eMGD0A4A403lo?`1cLg<0Rh^;08Z:RP2DU9@00P2LW9`0:`2OWil0^;Rh0;no_`2a
/K40WinO05mOG`0i>CT0:BTY02<S8`0T92@0820P028R8P0d=3@0HF5Q0492@P0Z:RX0=SHf04a<C00m
?Cd0<C4a02l_;`0g=cL0?Cdm03hn?P0`<300?3`l03Ph>010@400>CTi02`/;00i>CT0>c/k03`l?00b
<S80<C4a02l_;`0o?cl0>SXj03Lg=`0i>CT0<S8b034a<@0e=CD00P0f=SH03P0i>CT0@d=304E5A@11
@D40Bd];04e=C@1JFUX0LG5a07QhN01kNg/0P82007moO`1lO7`0Ogmo0P1kNg/05P1hN7P0NWYj07=c
L`1VIVH0DU9B03`l?00`<300;2`/04m?C`1LG5`0Fe]K05eMG@1VIVH0L71`07emO@1nOWh0Ogmo0820
P024Q8@0Ogmo08J6QP22PX8208B4Q00308J6QP28R8P0RHV90080Rh^;00@0SHf=08^;R`2;Rh/0SXj>
0P29RHT02@2;Rh/0RXZ:08R8R029RHT0QhN708^;R`28R8P0SXj>08Z:RP0208V9R@80SHf=0100RHV9
08^;R`2>SXh0Shn?08j>SP2@T900TI6A08n?S`2>SXh0Ti>C092@T02?Shl0TI6A09FEU@2BTY80V9RH
0P2CTi<00`2KVi/0VYZJ09ZJVP0209ZJVP0;09fMW@2KVi/0X:2P0:6QX@2OWil0WIfM0:BTY02RXZ80
Xj>S0:FUY@2TY:@00P2UYJD02`2ZZZX0[Zj^0:j^[P2^[Zh0];Bd0;2`/02c/k<0];Bd0;:b/P2e]KD0
][Jf0080_;bl00@0_kno0<71`@31`L40_kno0P34a<@03@35aLD0b<S80<O7a`39bLT0bl_;0<g=c@3B
d]80c/k>0<o?c`3>c/h0d=3@0=7Ad@3@d=000P3Bd]80203EeMD0dM7A0=GEe@3EeMD0e=CD0=OGe`3F
e]H0emOG0P3Jf]X40=cLg00<0=GEe@2_[jl0ADE501XJ6P0L71`07QhN01lO7`0W9bL0?Shn0820P02<
S8`0Q8B40P2<S8`02@2CTi<0Shn?08n?S`2GUiL0VYZJ09JFUP2ATI40Ti>C08f=S@02096AT@80TY:B
00h0TI6A09>CT`2?Shl0T92@09>CT`2BTY80SHf=08n?S`2<S8`0RXZ:092@T029RHT0SXj>08R8R080
Rh^;00X0SHf=08^;R`2<S8`0S8b<08N7Q`2;Rh/0R8R808Z:RP21PH40RHV90P23Ph<01P26QXH0QHF5
0820P01jNWX0OGem07inOP80Ng]k01L0O7al07QhN01hN7P0NWYj0820P02DU9@0/K6a0<C4a03>c/h0
d];B0=KFeP3IfMT0f][J0=SHf03Fe]H0dm?C0<o?c`3@d=00clo?0<g=c@3AdM40eMGE0=KFeP020=WI
f@0C0=SHf03IfMT0f=SH0=SHf03Fe]H0dm?C0=3@d03;bl/0`l?30;Bd]02XZ:P0UiNG08Z:RP1lO7`0
LG5a06e]K@1YJFT0JVYZ06][J`0206IVIP80I6AT00<0GemO05eMG@1PH6000P1OGel05P1RHV80HF5Q
06i^KP1bLW80MgMg07IfMP1eMGD0Kfm_06UYJ@1[Jf/0IfMW06IVIP1MGEd0GemO05YJFP1KFe/0G5aL
05mOG`1RHV80IVIV06YZJP1[Jf/206a/K080IfMW00D0HF5Q06ATI01NGUh0GUiN05eMG@0205aLG004
05YJFP1BDU80DU9B051@D0h0b>3H000<0<SPf0807AdM00h0820P02@T900O7al0;Bd]02/[:`0l?3`0
Bd];06IVIP1lO7`0TI6A09VIV@2UYJD0ZZZZ0:n_[`80/K6a01L0[jn_0:RXZ02MWId0V9RH08j>SP1i
NGT0IVIV04Q8B00Z:RX0820P02HV9P0Y:BT0>3Ph04m?C`1WIfL0OGem08^;R`2CTi<0UiNG09bLW02Z
ZZX0Zj^[0;>c/`030;2`/0040;Jf]P2b/[80/k>c0:n_[`80/k>c00D0];Bd0;>c/`2d];@0/K6a0;>c
/`020;Fe]@0g0:j^[P2[Zj/0Z:RX09nOW`2KVi/0UiNG08j>SP22PX80OGem08R8R01dM7@0AdM703Lg
=`0b<S80=CDe0492@P17AdL0?3`l03@d=00_;bl0<c<c02`/;00Z:RX0:b/[02l_;`0];Bd0?Cdm02h^
;P0Z:RX0<30`02/[:`0Z:RX0;Rh^02l_;`0Z:RX0:2PX02DU9@0V9RH0;2`/03@d=01QHF40PH6107Yj
NP1MGEd0@T9203Ph>00o?cl0Ng]k06i^KP1;Bd/0?Shn03<c<`0a<C40;Rh^02/[:`0202TY:@0?038b
<P0c<c<0=SHf04I6AP1@D500ATI603Lg=`0V9RH0:2PX03<c<`0j>SX0:RXZ02LW9`0_;bl0:2PX0080
<30`00`0;bl_03Lg=`15ADD0>SXj03De=@0W9bL0820P02l_;`1DE5@0BTY:03De=@0d=3@203`l?014
06ATI01lO7`0L71`07AdM01_Kfl0K6a/065QH@1CDe<0EEEE06YZJP1JFUX0GemO08Z:RP29RHT0S8b<
08R8R02<S8`0UYJF092@T022PX80NWYj08n?S`2>SXh0S8b<08F5Q@28R8P0SXj>07moO`2OWil0_;bl
0:b/[02UYJD0Ph>30410@00];Bd09RHV02d];@0X:2P0:BTY02DU9@0k>c/0CTi>02l_;`0i>CT0Cdm?
04a<C00f=SH0<30`03<c<`0n?Sh0@T9203Ph>00n?Sh0>3Ph04E5A@0b<S80;Rh^03<c<`0o?cl0>c/k
03Hf=P0a<C40=cLg03lo?`0j>SX0<c<c038b<P0e=CD2034a<@80>3Ph00T0<c<c03`l?01<C4`0@410
04Y:BP1@D500F5QH06i^KP1jNWX00P1kNg/01@1mOGd0Ogmo07inOP1lO7`0NGUi00<0MWIf00d0L71`
05iNGP0g=cL0<C4a02h^;P1@D500Fe]K05eMG@1PH600J6QX079bLP1jNWX0OGem0080O7al00@0PH61
0820P025QHD0QHF50P27QhL02029RHT0RXZ:08R8R028R8P0RHV908b<S02:RXX0QXJ60P2:RXX01P2=
SHd0Rh^;08^;R`28R8P0RXZ:08V9R@80RXZ:00l0S8b<08V9R@2@T900Rh^;08f=S@29RHT0R8R808f=
S@2>SXh0S8b<08j>SP2@T900TY:B08n?S`2ATI400P2BTY800`2?Shl0TY:B09NGU`0309FEU@0309NG
U`2MWId0VIVI0080VYZJ00D0WYjN09bLW02LW9`0WinO09fMW@030:2PX080XZ:R01h0YZJV0:BTY02V
YZH0YJFU0:RXZ02][Jd0[jn_0:b/[02b/[80/k>c0;Fe]@2g]kL0]KFe0;Jf]P2h^;P0^[Zj0;^k^`2m
_Kd0_kno0<?3``32`/80a/K60<G5a@36a/H0alO70<W9b@38b<P0bl_;0<[:bP3?cll20=3@d080clo?
0P3@d=001`3Bd]80d=3@0=?Cd`3Bd]80eMGE0=CDe03GemL00P3Hf=P01@3Fe]H0fMWI0=[JfP3Lg=`0
gMgM0080fm_K01D0d=3@09^KV`0_;bl071`L01hN7P0P82007AdM02@T900e=CD0N7Qh08n?S`25QHD0
RXZ:08^;R`2FUYH0SXj>08f=S@2NWYh0WIfM09>CT`2?Shl00P2@T90209>CT`80Shn?00l0TY:B096A
T@2@T900SXj>09:BTP2ATI40SXj>08n?S`2ATI40QXJ608b<S02;Rh/0S8b<08Z:RP2>SXh00P2<S8`0
202?Shl0S8b<08R8R02:RXX0R8R808V9R@28R8P0P8200P24Q8@07023Ph<0QHF508:2PP1kNg/0Ph>3
07inOP1lO7`0N7Qh07alO01jNWX0MgMg07]kN`1jNWX0P82008f=S@2/[:`0`L710<g=c@3Cdm<0emOG
0=SHf03Lg=`0fMWI0=SHf03Fe]H0d];B0<k>cP3?cll20=3@d080e]KF01L0f=SH0=WIf@3IfMT0fMWI
0=OGe`3EeMD0e=CD0=?Cd`3AdM40cLg=0<O7a`2k^k/0/K6a09^KV`2?Shl0Ng]k071`L01/K6`0JVYZ
06QXJ01WIfL0J6QX06EUI@0305iNGP0?06=SH`1KFe/0HF5Q069RHP1QHF40IfMW06QXJ01[Jf/0Lg=c
07EeM@1fMWH0LW9b06UYJ@1ZJVX0IVIV0080H61P00L0FUYJ05eMG@1LG5`0G5aL05iNGP1SHf<0J6QX
0080JFUY00@0JVYZ06][J`1WIfL0JVYZ0P1XJ6P02@1OGel0G5aL069RHP1TI6@0GemO05IFEP1ADE40
FUYJ05eMG@0>0<SPf0003038h=P2028R8P0>01lO7`0P82007alO02LW9`0V9RH0=SHf04];B`1WIfL0
Ng]k08b<S02JVYX0Y:BT0:RXZ02/[:`30:f][@0G0:NWY`2OWil0UYJF08^;R`1lO7`0HV9R04=3@`0X
:2P092@T02PX:00Y:BT0>3Ph05=CD`1]KFd0Ng]k08N7Q`2DU9@0WYjN0::RXP2WYjL0ZZZZ0;6a/@2d
];@00P2b/[80202e]KD0/[:b0;2`/02`/;00[Jf]0;Fe]@2g]kL0/K6a102e]KD07`2a/K40[Zj^0:^[
Z`2VYZH0XZ:R09bLW02FUYH0RHV908F5Q@21PH40U9BD0820P014A4@0<C4a038b<P0^;Rh0>c/k04A4
A00n?Sh0@41003Lg=`0i>CT0:RXZ02@T900V9RH0:b/[02d];@0[:b/0;2`/02d];@0_;bl00P0/;2`0
:00a<C40<30`03<c<`0Z:RX0:2PX02DU9@0^;Rh0:BTY03dm?@1HF5P0NWYj07moO`1aLG40BDU903hn
?P1^KVh0LW9b04=3@`0i>CT0<c<c02TY:@0^;Rh0:2PX02XZ:P0_;bl0;Rh^02/[:`0i>CT0?3`l04U9
B@1;Bd/0@41002LW9`0^;Rh0>c/k03Lg=`0S8b<09bLW02DU9@0W9bL202h^;P1603Lg=`0n?Sh0B4Q8
03/k>`0l?3`0:BTY02<S8`0m?Cd0EEEE0451@@0h>3P0AdM704E5A@0d=3@0@T9206MWI`1iNGT0Ogmo
075aL@1GEeL0?Cdm0410@01>CTh0IFEU061PH01RHV80Rh^;08Z:RP28R8P0QhN708^;R`2FUYH0W9bL
0:6QX@2IVIT0TY:B08Z:RP1hN7P0H61P07alO02<S8`0Fe]K06=SH`2PX:00ZJVY09^KV`2MWId0MGEe
04e=C@1ADE40GUiN04e=C@0k>c/0:2PX02`/;00_;bl0:2PX03<c<`17AdL0BTY:03`l?00f=SH0;Rh^
03lo?`0m?Cd0<C4a04i>CP14A4@0@41003<c<`80<S8b00`0?Shn03dm?@0e=CD0>SXj03Hf=P0o?cl0
?Shn038b<P0/;2`0<C4a03De=@0^;Rh2038b<P0I02h^;P0d=3@0BDU90410@00n?Sh0Cdm?05=CD`1U
IFD0LW9b07]kN`1iNGT0MgMg07moO`1kNg/0OGem07YjNP1lO7`0Ng]k07alO01aLG40G5aL04I6AP0c
<c<0;2`/04=3@`0205YJFP0E061PH01ZJVX0KVi^07alO01gMgL0Ng]k07alO01oOgl0PH6108>3P`22
PX80QhN708>3P`28R8P0QXJ608R8R029RHT0R8R808^;R`2<S8`0Rh^;0080RXZ:00<0SHf=08Z:RP29
RHT00P26QXH01029RHT0R8R808N7Q`26QXH208b<S00408f=S@2;Rh/0S8b<08J6QP<0SXj>0P2;Rh/0
302ATI40SHf=092@T02@T900UIFE08n?S`2MWId0U9BD09NGU`2CTi<0UYJF09ZJVPD0WIfM01H0WYjN
0:2PX02MWId0WIfM0:2PX02SXj<0XJ6Q09jNWP2VYZH0YjNW0:RXZ02VYZH0ZZZZ0:j^[P2`/;00[jn_
0:^[Z`2^[Zh0/k>c0;6a/@2g]kL0][Jf0P2h^;P0102i^KT0_;bl0;jn_P2n_[h20<;2`P80aLG500d0
a/K60<S8b039bLT0bLW90<S8b039bLT0d=3@0=7Ad@3?cll0cLg=0=3@d03Bd]80d=3@0080d];B00<0
dm?C0=CDe03Fe]H00P3Fe]H0803Hf=P0fMWI0=[JfP3Jf]X0g=cL0=kNgP3Ogml0gMgM0=[JfP35aLD0
M7Ad02@T900N7Qh07alO01dM7@0R8R80820P03@d=01[Jf/0SHf=08N7Q`2;Rh/0S8b<09>CT`2:RXX0
Shn?09jNWP2KVi/0UIFE08j>SP2EUID0Ti>C0`2BTY800`2ATI40Ti>C092@T002092@T00508j>SP2B
TY80S8b<092@T02ATI400P2;Rh/01P2>SXh0S8b<08R8R02;Rh/0SHf=08n?S`80Rh^;0P29RHT208B4
Q00308:2PP20P800Q8B40080Q8B400<0QHF508:2PP1nOWh00P20P800501lO7`0Ng]k07]kN`1gMgL0
OGem07alO01hN7P0OWin08N7Q`2UYJD0_[jn0<_;b`3AdM40eMGE0=WIf@3Lg=`0fm_K0=WIf@3EeMD0
dm?C0`3AdM401`3Cdm<0eMGE0=CDe03Fe]H0f=SH0=[JfP3Hf=P00P3IfMT20=KFeP0?0=;BdP3@d=00
bl_;0<?3``2f][H0Xj>S09JFUP25QHD0MGEe06IVIP1XJ6P0IVIV05mOG`1SHf<0GemO0080GEeM01<0
FEUI05iNGP1FEUH0G5aL061PH01KFe/0HV9R06][J`1/K6`0L71`06m_K`1cLg<0Kfm_07=cL`1^KVh0
K6a/06=SH`1OGel0GUiN0080H61P00T0FUYJ05iNGP1MGEd0HF5Q06EUI@1XJ6P0JVYZ06MWI`1YJFT0
0P1WIfL02P1[Jf/0HF5Q069RHP1UIFD0HV9R065QH@1NGUh0FEUI05MGE`1CDe<>0<SPf0003038h=P2
01lO7`0X02<S8`0P82008B4Q02<S8`0Z:RX0=SHf04Y:BP1UIFD0Ng]k08j>SP2HV9P0Y:BT0:NWY`2]
[Jd0[Zj^0:f][@2YZJT0YJFU09jNWP2HV9P0Rh^;07]kN`1OGel0?Shn02@T900N7Qh092@T02XZ:P0g
=cL0D51@06e]K@23Ph<0RHV9096AT@2MWId0XZ:R0:FUY@2_[jl0/k>c0;Ng]`<0];Bd0280/k>c0;:b
/P2d];@0/[:b0;>c/`2e]KD0/k>c0;Bd]02f][H0]KFe0;Jf]P2_[jl0[Zj^0:ZZZP2UYJD0X:2P09fM
W@2CTi<0SHf=08N7Q`20P800VIVI07emO@0l?3`0<C4a02PX:00^;Rh0<S8b03De=@0h>3P0>SXj04A4
A00o?cl0>3Ph0P0Y:BT0<00[:b/0>CTi02DU9@0/;2`0:BTY03<c<`0/;2`0;Bd]02l_;`0Z:RX0<C4a
02d];@0_;bl08R8R02PX:00U9BD0;2`/03Ph>01CDe<0OWin08n?S`1eMGD0CTi>07=cL`1gMgL0E5AD
03lo?`0d=3@092@T02`/;00X:2P09bLW02`/;00Y:BT0;bl_03Hf=P0j>SX0ADE504e=C@0m?Cd09bLW
02/[:`0i>CT0<c<c024Q8@0W9bL09RHV02PX:080;bl_01`0:RXZ03Lg=`17AdL0=cLg03Ph>00Z:RX0
9RHV0410@01:BTX0?Shn0492@P0e=CD0<S8b03@d=016ATH0KFe]08N7Q`26QXH0KVi^04E5A@0^;Rh0
@T9204I6AP1EEED0CDe=05eMG@28R8P0S8b<0P2=SHd0=P2;Rh/0TY:B09JFUP2LW9`0XJ6Q09FEU@1g
MgL0BTY:05ADE02?Shl0PH6104A4A00l?3`0LG5a09bLW02WYjL0WinO09bLW02:RXX0UIFE0:f][@2/
[:`0Ng]k030`<00W9bL0;Bd]02PX:00];Bd0ATI604e=C@0n?Sh0=CDe030`<00k>c/0?3`l03<c<`0m
?Cd0A4A403dm?@0l?3`0=3@d03De=@12@T80ATI603Ph>00b<S80<C4a03Hf=P0g=cL0<c<c03@d=00^
;Rh0<c<c03Lg=`80<S8b0100?clo02l_;`12@T80?Shn03/k>`1:BTX0De=C05mOG`1^KVh0N7Qh07]k
N`1dM7@0OGem07alO01mOGd0P8200P1iNGT04@1kNg/0M7Ad05iNGP16ATH0<c<c02l_;`1;Bd/0FEUI
05iNGP1OGel0KFe]071`L01hN7P0Ng]k07alO021PH40Ph>30080P82000<0PX:208V9R@2:RXX00`2<
S8`00`28R8P0QHF508^;R`0208^;R`0308Z:RP28R8P0RHV90080RHV901@0QhN708R8R026QXH0RXZ:
08V9R@2:RXX0Rh^;08N7Q`2:RXX0RHV908^;R`29RHT0S8b<08f=S@2<S8`0SHf=08j>SP2@T900SXj>
092@T080Ti>C0P2BTY8209FEU@0509:BTP2FUYH0UiNG09jNWP2JVYX00P2NWYh03`2OWil0WYjN0:2P
X02PX:00W9bL0:>SX`2TY:@0YZJV0:2PX02QXJ40YZJV0:BTY02XZ:P0[:b/0:^[Z`020;2`/0040:^[
Z`2][Jd0];Bd0;>c/`80][Jf00@0^KVi0;Rh^02k^k/0_[jn0P2l_;`0202o_kl0`/;20<;2`P33`l<0
a<C40<G5a@39bLT0cLg=0P3<c<`01@3AdM40d=3@0<o?c`3>c/h0dm?C0080d=3@00@0d];B0=GEe@3F
e]H0e=CD103GemL07`3Hf=P0f][J0=_Kf`3Lg=`0gMgM0=oOg`3MgMd0f=SH0;Rh^01?Cdl08B4Q028R
8P0N7Qh07alO01dM7@0P8200;Bd]069RHP2?Shl0R8R808^;R`2=SHd0TY:B08^;R`2BTY80WYjN09FE
U@2ATI40SXj>09NGU`2EUID00P2ATI40202CTi<0TY:B096AT@2:RXX0T92@08n?S`2CTi<0TI6A0`2B
TY805`2?Shl0S8b<09:BTP2>SXh0Rh^;096AT@2:RXX0SXj>08f=S@26QXH0Rh^;08j>SP25QHD0Q8B4
0861P@26QXH0S8b<08J6QP23Ph<0QHF508:2PP1oOgl0P8200080Ng]k00h0OWin07]kN`1jNWX0MgMg
07EeM@1fMWH0NWYj08>3P`2QXJ40^[Zj0<[:bP3Bd]80emOG0=[JfP80fm_K0P3IfMT01@3De=@0d];B
0=7Ad@3AdM40dm?C0080eMGE00<0f=SH0=WIf@3Jf]X0103IfMT0403Fe]H0eMGE0=;BdP3>c/h0alO7
0;fm_@2[Zj/0Vi^K08N7Q`1iNGT0IVIV06ATI01PH600HV9R06=SH`1MGEd205]KF`0;05aLG01GEeL0
DU9B05YJFP1TI6@0IFEU05eMG@1VIVH0K6a/06e]K@1`L7000P1eMGD03@1dM7@0Kfm_06QXJ01VIVH0
GemO06ATI01OGel0G5aL05]KF`1IFET0GUiN069RHP1SHf<00P1ZJVX306QXJ00;06MWI`1XJ6P0IFEU
06QXJ01_Kfl0HF5Q06YZJP1[Jf/0I6AT05IFEP1?Cdl03P38h=P000`0b>3H0`0N7Qh08`0P82007AdM
028R8P0Z:RX0>SXj04i>CP1`L700PH6108n?S`2JVYX0XJ6Q0:JVYP2[Zj/0[jn_0:f][@2ZZZX0YjNW
09^KV`2HV9P0SXj>07UiN@1MGEd0>3Ph02<S8`0Q8B408b<S02TY:@0d=3@0De=C06YZJP21PH40S8b<
09>CT`2PX:00XZ:R0080Zj^[00H0[jn_0;Bd]02c/k<0/k>c0;Fe]@2b/[820;2`/00Y0;>c/`2`/;00
/k>c0;Fe]@2d];@0]KFe0;Ng]`2`/;00[jn_0:^[Z`2YZJT0YZJV09bLW02MWId0TY:B08^;R`24Q8@0
RHV909^KV`1gMgL0@d=302XZ:P0U9BD0;Bd]034a<@0g=cL0>CTi03Lg=`0h>3P0@D5103Ti>@0d=3@0
;Bd]02h^;P0b<S80;2`/02LW9`0V9RH0<S8b030`<00T92@00P0_;bl2030`<00@02h^;P0Z:RX0820P
02HV9P0Q8B409RHV03Ph>01SHf<0Rh^;092@T01[Jf/0O7al08J6QP1VIVH0DU9B038b<P80:2PX0180
:b/[02`/;00Y:BT0:b/[03De=@0n?Sh0;bl_038b<P16ATH0@41002h^;P0d=3@0=cLg034a<@0U9BD0
:RXZ02d];@0`<30202/[:`03034a<@0j>SX0>SXj0080<c<c0100;bl_02TY:@12@T80A4A40451@@0n
?Sh0ATI60451@@0h>3P0I6AT07emO@26QXH0Ogmo06ATI00l?3`0=3@d0P0i>CT01@0o?cl0ATI605IF
EP28R8P0Vi^K0080Rh^;01P0RXZ:08j>SP2HV9P0VIVI0:2PX01mOGd0DE5A03De=@1jNWX0SXj>08B4
Q00n?Sh0EUIF07YjNP2LW9`0/k>c0:^[Z`2LW9`0PX:208^;R`2b/[80b<S80:RXZ016ATH302<S8`0K
02PX:016ATH0CDe=03dm?@0o?cl0<C4a03hn?P16ATH0>3Ph04A4A011@D40>SXj03Ti>@0a<C40>SXj
04=3@`14A4@0=3@d02h^;P0_;bl0=CDe038b<P0j>SX0<C4a030`<00d=3@0<30`0080=CDe0140?Shn
03Hf=P0`<300>3Ph03Lg=`0k>c/0CTi>05IFEP1ZJVX0LG5a07YjNP1fMWH0OGem07moO`1lO7`0Ng]k
07emO@0207QhN00M07IfMP1TI6@0E5AD02h^;P0[:b/0?3`l05ADE01FEUH0HV9R06IVIP1`L700MGEe
07UiN@21PH40QHF50861P@27QhL0QXJ607moO`2:RXX0Rh^;08V9R@27QhL0QXJ608j>SP25QHD0Rh^;
08V9R@26QXH00P29RHT00`27QhL0S8b<08V9R@0208J6QP0608f=S@27QhL0Rh^;08B4Q02;Rh/0Q8B4
0P2:RXX01P2<S8`0SHf=08f=S@2ATI40SHf=08b<S0<0T92@0P2?Shl01P2DU9@0Ti>C09>CT`2BTY80
V9RH09FEU@80VIVI0P2JVYX209NGU`0909nOW`2MWId0WinO0::RXP2SXj<0X:2P0::RXP2UYJD0WinO
0080YZJV0P2UYJD20:b/[0040;Bd]02`/;00ZZZZ0;2`/080/K6a0200]KFe0;Rh^02j^[X0_;bl0;Rh
^02m_Kd0^k^k0;jn_P31`L40`/;20<G5a@32`/80a/K60<[:bP3<c<`0c/k>0<c<c03=cLd0c/k>0=7A
d@3@d=00d];B0=3@d03Cdm<0d];B0=SHf03Bd]80eMGE0=CDe03GemL0eMGE0=SHf080emOG00<0fm_K
0=gMg@3MgMd00P3Ng]h0103Lg=`0d];B09NGU`0d=3@201/K6`0?01`L700P82007alO01`L700^;Rh0
HF5Q092@T02;Rh/0SHf=08n?S`2JVYX0Rh^;09BDU02PX:00UiNG0080Ti>C01h0UiNG09JFUP2CTi<0
Ti>C08j>SP2@T900U9BD08n?S`2DU9@0SXj>09BDU02CTi<0UIFE08n?S`2@T900SXj>08f=S@29RHT0
Shn?08^;R`2=SHd0Rh^;08R8R029RHT0Shn?08Z:RP2<S8`0QhN708R8R027QhL308J6QP0308V9R@23
Ph<0Ogmo0080Ph>30100OGem0820P01oOgl0Ogmo07emO@1lO7`0N7Qh07UiN@1kNg/0Ogmo09NGU`2h
^;P0bLW90<o?c`3De=@0fMWI0P3Kfm/02P3IfMT0emOG0=KFeP3@d=00c/k>0=7Ad@3?cll0d];B0=GE
e@3GemL20=[JfP0@0=_Kf`3IfMT0fMWI0=SHf03GemL0e]KF0=CDe03AdM40alO70<30`02f][H0Y:BT
096AT@1nOWh0KFe]069RHP80HF5Q02h0I6AT05]KF`1LG5`0G5aL05QHF01JFUX0F5QH05MGE`1JFUX0
Fe]K05mOG`1/K6`0J6QX06e]K@1^KVh0KFe]07=cL`1bLW80Kfm_071`L01XJ6P0Hf=S061PH01SHf<0
GUiN05UIF@1JFUX0F5QH05mOG`1RHV80IFEU06e]K@1ZJVX0IVIV06YZJP1YJFT0GemO06ATI01[Jf/0
GemO061PH01/K6`0JVYZ06QXJ01PH600Fe]K3P38h=P000`0b>3H0P0O7al0:00R8R8092@T02<S8`0T
92@0;2`/03Xj>P1IFET0JVYZ08F5Q@2EUID0VIVI09jNWP2TY:@0[:b/0:j^[P2[Zj/0[:b/0:RXZ02Q
XJ40Vi^K08^;R`1eMGD0EeMG03Lg=`0Q8B408b<S02PX:00_;bl0=cLg05MGE`1[Jf/0OWin08N7Q`2F
UYH0WIfM0::RXP2WYjL0[jn_0;2`/02c/k<20;:b/P0U0;Fe]@2d];@0/K6a0;Bd]02a/K40/k>c0;6a
/@2d];@0]KFe0;Rh^02e]KD0/[:b0;6a/@2/[:`0Z:RX0:FUY@2OWil0VYZJ09>CT`2<S8`0RHV908n?
S`2OWil0Q8B404Q8B00];Bd0:BTY02HV9P0/;2`0>3Ph03Hf=P0Y:BT0=SHf03De=@0l?3`0>SXj03De
=@0202d];@0^02PX:00/;2`0:BTY02`/;00_;bl0;Bd]02LW9`0X:2P08b<S03Ph>00a<C40;Rh^02LW
9`0S8b<0:2PX02<S8`0W9bL0?Shn079bLP2GUiL0QHF507YjNP2:RXX0KVi^069RHP0n?Sh092@T02XZ
:P0T92@09bLW02PX:00_;bl0=SHf03De=@0g=cL0:RXZ04E5A@1<C4`0=3@d038b<P0k>c/0=SHf02LW
9`0^;Rh0<S8b03Lg=`80;Rh^00D0;Bd]03Hf=P0o?cl0;Bd]02/[:`02034a<@0I04U9B@16ATH0>3Ph
04Q8B01PH600@T9204a<C01^KVh0R8R807UiN@1dM7@0G5aL03Xj>P0f=SH0>CTi03`l?00f=SH0?3`l
04a<C021PH40XJ6Q08f=S@2;Rh/0RHV908R8R00209ZJVP0D09RHV01XJ6P0=3@d0492@P2<S8`0Vi^K
08Z:RP1bLW80N7Qh06i^KP1iNGT0Z:RX0:f][@2GUiL0LG5a05MGE`2JVYX0`/;20:RXZ014A4@202DU
9@80:b/[00`0?clo051@D01:BTX0AdM702l_;`0o?cl0AdM703`l?00n?Sh0>3Ph03@d=00l?3`203<c
<`0904=3@`10@400;Rh^03<c<`0f=SH0<30`038b<P0g=cL0=SHf0080=3@d0100<c<c03/k>`0k>c/0
>SXj038b<P0j>SX0=CDe03Xj>P0l?3`0BTY:051@D01MGEd0JFUY07=cL`1eMGD0MWIf0P1iNGT00`1o
Ogl0Q8B407QhN00207MgM`0H06MWI`1?Cdl0<30`02d];@0d=3@0FEUI05IFEP1KFe/0J6QX071`L01d
M7@0Ng]k08:2PP25QHD0PH6108F5Q@24Q8@0QHF508V9R@2:RXX0RHV90861P@27QhL0RXZ:0P29RHT0
502<S8`0RHV908R8R029RHT0R8R808N7Q`29RHT0Ph>308R8R02=SHd0RXZ:08b<S02:RXX0R8R808J6
QP2;Rh/0QhN708V9R@2<S8`0T92@0P2?Shl2092@T00409:BTP2ATI40TI6A096AT@80TY:B00@0Ti>C
092@T02FUYH0UIFE0P2GUiL01@2JVYX0VIVI09ZJVP2JVYX0WIfM0080WYjN00d0XZ:R0:BTY02RXZ80
XJ6Q0:FUY@2SXj<0Y:BT0:JVYP2SXj<0Z:RX0:^[Z`2`/;00[:b/0080/;2`00D0[jn_0;Fe]@2d];@0
];Bd0;Fe]@050;^k^`0:0<71`@30`<00a/K60<?3``34a<@0alO70<S8b03;bl/0cLg=0<_;b`80clo?
00X0dM7A0=;BdP3EeMD0e=CD0=7Ad@3?cll0dm?C0=GEe@3Fe]H0eMGE0P3Hf=P01@3Fe]H0f=SH0=SH
f03Jf]X0g=cL0080gmoO01X0g]kN0=[JfP39bLT0MGEe02HV9P0P82006a/K01`L700P82007QhN01dM
7@0X:2P0EEEE08b<S02?Shl0RXZ:08n?S`2BTY80Q8B409BDU02OWil0Ti>C09JFUP2GUiL0UIFE096A
T@80TY:B00P0U9BD096AT@2?Shl0Ti>C08f=S@2>SXh0Rh^;09NGU`80TI6A00`0UIFE092@T02<S8`0
T92@08j>SP29RHT0RXZ:08^;R`2>SXh0Rh^;08R8R02<S8`208V9R@0708F5Q@26QXH0OWin08F5Q@28
R8P0Q8B408:2PP0207inOP0B07moO`1mOGd0Ph>308>3P`1hN7P0Ogmo07inOP1iNGT0NWYj07alO01o
Ogl0Shn?0:n_[`33`l<0cLg=0=;BdP3Fe]H0f=SH0P3IfMT01@3Hf=P0eMGE0=7Ad@3@d=00clo?0080
d=3@01D0eMGE0=OGe`3Hf=P0f][J0=WIf@3Hf=P0fm_K0=[JfP3IfMT0e]KF0=CDe03Bd]80c<c<0<G5
a@2j^[X0[jn_09RHV028R8P0Lg=c06MWI`1OGel00P1PH6001@1NGUh0G5aL05aLG01LG5`0Fe]K0080
FEUI00X0H61P05iNGP1QHF40IfMW06YZJP1]KFd0Kfm_07=cL`1`L700LW9b0P1cLg<03P1aLG40J6QX
069RHP1QHF40FUYJ05aLG01HF5P0EeMG05UIF@1RHV80Hf=S06MWI`1XJ6P0IVIV0P1]KFd0101[Jf/0
IfMW06EUI@1WIfL206IVIP0406ATI01YJFT0HV9R05MGE`h0b>3H000<0<SPf0807QhN00T0820P01lO
7`0Q8B409BDU02d];@0m?Cd0EeMG07AdM029RHT00P2IVIT07@2NWYh0YjNW0:RXZ02^[Zh0[:b/0:^[
Z`2VYZH0WIfM09FEU@26QXH0L71`05=CD`0h>3P0820P02<S8`0U9BD0<30`03lo?`1BDU80JFUY07em
O@2:RXX0V9RH09VIV@2QXJ40YjNW0:ZZZP2^[Zh0[jn_0080][Jf0P2c/k<0>@2a/K40/[:b0;Bd]02b
/[80[jn_0;Bd]02a/K40]kNg0;Fe]@2f][H0/;2`0:n_[`2YZJT0YJFU0:2PX02JVYX0UiNG08f=S@25
QHD0UYJF0:b/[022PX80J6QX04Q8B016ATH0:b/[02h^;P0j>SX0<30`02LW9`0`<300<C4a03dm?@14
A4@0>c/k034a<@0c<c<0=SHf02XZ:P0W9bL0<c<c02XZ:P0/;2`0:b/[02XZ:P0W9bL0;Bd]03Ph>00e
=CD09RHV01lO7`0T92@09BDU02h^;P0];Bd0EEEE08R8R0020861P@0C08j>SP1_Kfl0Fe]K03hn?P0`
<300<S8b02d];@0`<300<c<c03De=@11@D40<S8b02d];@0Y:BT0ATI605EEE@0g=cL0=SHf03De=@02
03@d=003038b<P0a<C40@4100080=3@d04h0:2PX03De=@0h>3P0;2`/02l_;`0/;2`0>3Ph04m?C`1;
Bd/0?Shn05MGE`1RHV80@d=305UIF@1bLW80Ng]k07IfMP1/K6`0CTi>04A4A01;Bd/0ADE504I6AP0j
>SX0?Shn051@D01dM7@0Y:BT09RHV021PH40QXJ607moO`2=SHd0UYJF09RHV01iNGT0FEUI07=cL`2T
Y:@0WinO07UiN@1NGUh0DE5A03hn?P17AdL0RXZ:0;Jf]P2LW9`0Ph>303dm?@1aLG40XZ:R08n?S`0_
;bl071`L02@T900N7Qh09BDU04];B`1HF5P0Cdm?04a<C00b<S80ADE504a<C011@D40?clo038b<P0c
<c<0>CTi03Hf=P0a<C40?clo03dm?@0_;bl0;Bd]03<c<`0d=3@203Ph>00403@d=00f=SH0<30`03De
=@80@d=300D0=SHf03<c<`0a<C40=cLg0410@00203`l?00N04Y:BP1DE5@0GUiN06][J`1eMGD0LG5a
07MgM`1fMWH0P82007inOP1hN7P0NWYj07AdM01UIFD0Cdm?02d];@0[:b/0<C4a055AD@1KFe/0I6AT
06UYJ@1[Jf/0Kfm_07UiN@1oOgl0Q8B408F5Q@23Ph<0PX:20P26QXH05024Q8@0QHF50820P027QhL0
Shn?08R8R02:RXX0RHV908B4Q02:RXX0SHf=08b<S028R8P0QXJ608^;R`28R8P0QhN708^;R`29RHT0
QXJ60P2:RXX00`28R8P0RHV908Z:RP0208b<S006092@T02GUiL0T92@08j>SP2BTY80U9BD0`2ATI40
2@2CTi<0U9BD09BDU02EUID0VIVI09FEU@2LW9`0V9RH09ZJVP0209nOW`0309fMW@2OWil0Vi^K0080
XZ:R00L0X:2P0::RXP2UYJD0Z:RX0:>SX`2VYZH0YjNW0080ZZZZ0P2/[:`02`2b/[80/;2`0;:b/P2b
/[80];Bd0;>c/`2e]KD0^KVi0;fm_@2k^k/0_;bl0080_[jn00<0`/;20<O7a`32`/800P37alL02@3:
b/X0cLg=0<_;b`3<c<`0clo?0=3@d03AdM40d];B0=GEe@020=;BdP0=0=7Ad@3@d=00e]KF0=KFeP3H
f=P0e]KF0=kNgP3Hf=P0emOG0=WIf@3Lg=`0g]kN0=cLg0020=kNgP0I0=WIf@2h^;P0F5QH020P800N
7Qh07AdM020P800T92@08b<S01hN7P0V9RH0B4Q808b<S02@T900SHf=08n?S`2@T900QhN709JFUP2E
UID0Shn?09FEU@2DU9@0Ti>C096AT@02092@T00609BDU02@T900U9BD092@T02CTi<0S8b<0P2@T900
102ATI40TY:B08b<S02=SHd2092@T00T08n?S`26QXH0RHV908f=S@2>SXh0S8b<08N7Q`29RHT0QXJ6
08^;R`25QHD0R8R80820P023Ph<0QXJ60861P@1mOGd0PH6107moO`1mOGd0P82008B4Q01mOGd0NGUi
08B4Q025QHD0O7al07YjNP1gMgL0P82008f=S@2ZZZX0_[jn0<S8b03=cLd0e=CD0`3GemL00`3EeMD0
dm?C0<k>cP040<g=c@030=?Cd`3EeMD0emOG0080f=SH00<0f][J0=WIf@3IfMT00P3EeMD03P3Cdm<0
dM7A0<k>cP39bLT0`<300;Ng]`2NWYh0T92@07moO`1]KFd0H61P05iNGP1LG5`0FUYJ0P1QHF400`1L
G5`0Fe]K05iNGP0205mOG`0505iNGP1TI6@0IVIV06IVIP1/K6`00P1fMWH0301cLg<0MGEe07IfMP1c
Lg<0MWIf071`L01RHV80HF5Q05aLG01IFET0EEEE05UIF@80Fe]K0100H61P06=SH`1[Jf/0JFUY06QX
J01ZJVX0I6AT06IVIP1YJFT0I6AT065QH@1WIfL0IFEU069RHP1OGel0GUiN3P38h=P000`0b>3H0P0Q
8B40:00P82008b<S01lO7`0Y:BT0;Bd]04E5A@1KFe/0M7Ad08Z:RP2EUID0VIVI09nOW`2TY:@0ZZZZ
0:VYZ@2ZZZX0Zj^[0:JVYP2LW9`0Shn?08F5Q@1fMWH0Fe]K03Ti>@0T92@0820P02@T900`<300@410
05EEE@1^KVh0OGem08N7Q`2EUID0VYZJ0:>SX`2WYjL0ZJVY0;6a/@2d];@20;>c/`090;Bd]02a/K40
/[:b0;Bd]02a/K40/[:b0;2`/02b/[80];Bd00<0]KFe02T0/k>c0;Bd]02YZJT0Z:RX0:2PX02KVi/0
Ti>C08f=S@22PX80WinO0:j^[P1cLg<0MGEe075aL@0c<c<0:2PX02`/;00j>SX0=SHf030`<00[:b/0
:RXZ03De=@12@T80@41003De=@0f=SH0<30`02/[:`0];Bd0<C4a03Hf=P0/;2`0<S8b03@d=00Y:BT0
:RXZ03Ti>@0d=3@0:BTY02LW9`0202HV9P80:BTY01P0>CTi06EUI@1oOgl0RHV908Z:RP1`L700F5QH
03De=@0U9BD0:BTY030`<00[:b/0:BTY03Ph>013@d<0=SHf02d];@0U9BD0?3`l05EEE@0l?3`0=3@d
03Hf=P0_;bl203De=@0303Ti>@0l?3`0;2`/0080;2`/02T0;bl_03@d=00`<300<c<c02h^;P0l?3`0
D51@04U9B@0d=3@0EEEE06QXJ017AdL0H61P06i^KP1dM7@0LW9b06EUI@1KFe/0CTi>059BDP1GEeL0
Bd];03<c<`1<C4`0HV9R07QhN02IVIT0VYZJ08:2PP1cLg<0Jf][07UiN@2JVYX0X:2P09jNWP22PX80
Ogmo09FEU@1iNGT0A4A403@d=00202l_;`0E03Hf=P1XJ6P0_;bl0:b/[02KVi/0EEEE0492@P1[Jf/0
JVYZ02TY:@0R8R80:2PX020P800T92@0?clo05=CD`1?Cdl0CTi>03@d=011@D40BTY:0080Bd];00D0
=3@d038b<P0g=cL0>CTi02d];@0203<c<`80=3@d00P0;Rh^02l_;`0m?Cd0>SXj038b<P0e=CD0@D51
03Ph>080=SHf00h0=3@d02l_;`0a<C40=SHf03/k>`0l?3`0=cLg04E5A@1?Cdl0DU9B069RHP1[Jf/0
K6a/079bLP80N7Qh01@0Ng]k07UiN@1iNGT0LG5a06EUI@1<C4`0<30`02/[:`0^;Rh0C4a<05iNGP1I
FET0Jf][06i^KP1bLW80N7Qh08>3P`21PH40QHF508:2PP80QHF500P0Q8B408N7Q`29RHT0Ph>308V9
R@27QhL0R8R808J6QP80QhN700@0Rh^;08N7Q`29RHT0QhN70P2:RXX00`2<S8`0QHF508J6QP0408R8
R00608f=S@25QHD0RHV908b<S02ATI40T92@0P2?Shl03`2BTY80T92@08n?S`2BTY80UIFE08n?S`2A
TI40Ti>C09RHV02FUYH0VYZJ09RHV02IVIT0W9bL09VIV@0209^KV`0G0:2PX02OWil0WYjN0:2PX02O
Wil0XJ6Q0:NWY`2VYZH0Zj^[0:BTY02WYjL0Z:RX0:ZZZP2][Jd0[:b/0:j^[P2_[jl0/;2`0;:b/P2`
/;00/k>c0;Jf]P2e]KD00P2l_;`02P2k^k/0_;bl0;^k^`30`<00`/;20<?3``36a/H0aLG50<K6aP39
bLT20<_;b`060<k>cP3AdM40clo?0=3@d03?cll0dm?C1@3Bd]820=CDe0070=KFeP3GemL0f=SH0=SH
f03Kfm/0gMgM0=kNgP020=gMg@070=cLg03AdM40WYjN03hn?P0/;2`0:RXZ02DU9@02028R8P0@02DU
9@0P82008R8R03hn?P2>SXh0Ti>C092@T02>SXh0TY:B08V9R@2KVi/0TY:B092@T02GUiL0Ti>C09JF
UP<0UIFE00P0U9BD09FEU@2CTi<0U9BD09:BTP2CTi<0U9BD09FEU@80U9BD00L0Shn?08j>SP2BTY80
Shn?08f=S@2:RXX0Rh^;00<0SHf=00T0S8b<08N7Q`27QhL0R8R808F5Q@24Q8@0QXJ608N7Q`26QXH0
0P27QhL01@1nOWh0P8200820P021PH40PX:20080PH6100d0OWin0861P@1mOGd0NGUi07QhN01lO7`0
QXJ609nOW`2c/k<0`/;20<W9b@3?cll0d];B0080eMGE00@0d];B0=7Ad@3<c<`0cLg=0P3:b/X01P3?
cll0dM7A0=GEe@3IfMT0f][J0=OGe`@0f=SH0P3Fe]H03@3EeMD0dM7A0<_;b`36a/H0^[Zj0:ZZZP2H
V9P0QhN706m_K`1PH600GUiN05MGE`1LG5`00P1NGUh01P1OGel0GEeM05YJFP1JFUX0FEUI061PH0@0
IFEU00<0Jf][075aL@1bLW800P1`L7001P1dM7@0LW9b079bLP1WIfL0IVIV05mOG`80FEUI01<0FUYJ
05aLG01OGel0HF5Q069RHP1YJFT0Jf][06MWI`1ZJVX0JFUY06QXJ01SHf<0H61P05eMG@1UIFD0J6QX
06UYJ@1VIVH0HV9R00h0b>3H000<0<SPf0807alO02L0820P02DU9@0T92@0;Rh^04A4A012@T80GEeM
07IfMP2:RXX0Ti>C09bLW02QXJ40Z:RX0:^[Z`2^[Zh0Zj^[0:RXZ02QXJ40VIVI08n?S`23Ph<0MWIf
05MGE`0f=SH08b<S01lO7`0T92@0:b/[03dm?@1IFET0Kfm_07moO`28R8P0T92@09fMW@2SXj<0ZJVY
0:^[Z`2`/;000`2a/K403`2b/[80/k>c0:j^[P2`/;00];Bd0;>c/`2a/K40/;2`0;6a/@2f][H0];Bd
0;Jf]P2d];@0[:b/0:VYZ@020::RXP1409bLW02ATI40SXj>08J6QP2NWYh0^[Zj07UiN@1oOgl0LW9b
03Lg=`0`<300:b/[03Hf=P0l?3`0:RXZ02LW9`0Y:BT0;Rh^03Lg=`19BDT0@T9203@d=00e=CD0<30`
02XZ:P0/;2`0?Shn034a<@0Z:RX09RHV02@T900^;Rh0<c<c03Ti>@0j>SX0:RXZ02/[:`0/;2`0;Bd]
02HV9P0c<c<0CDe=07alO02EUID0SXj>07IfMP1IFET0>3Ph02@T900];Bd0:2PX02XZ:P0b<S80@410
04A4A00i>CT0:RXZ024Q8@0i>CT0CDe=03lo?`0c<c<0:b/[02XZ:P0o?cl0BTY:03hn?P0/;2`202PX
:00302LW9`0b<S80>c/k0080<30`03h0=cLg04i>CP1QHF40?clo03/k>`1DE5@0IfMW05UIF@1PH600
JVYZ07QhN01cLg<0HF5Q069RHP1LG5`0F5QH04m?C`18B4P0>3Ph05IFEP1YJFT0NWYj092@T02BTY80
SHf=07inOP1[Jf/0Ph>309jNWP2QXJ40WYjN06][J`1WIfL0P82004i>CP0^;Rh0<C4a02d];@0[:b/0
<C4a05ADE02g]kL0][Jf0:f][@1^KVh0?Cdm03@d=00j>SX0:2PX028R8P0S8b<09RHV02/[:`0c<c<0
EUIF059BDP17AdL0:b/[03Xj>P1=CDd0DE5A04];B`80<30`00@0>CTi03`l?00`<300<30`0P0];Bd2
03<c<`0702h^;P0g=cL0@4100451@@0l?3`0@T9203`l?00202`/;01002h^;P0];Bd0;Rh^030`<00j
>SX0>CTi03De=@0m?Cd0F5QH05MGE`1KFe/0IVIV06=SH`1YJFT0Kfm_07=cL`1lO7`0NGUi07QhN01b
LW80IFEU04];B`0c<c<0:2PX034a<@0o?cl0G5aL05YJFP1SHf<0L71`075aL@1gMgL0PX:208B4Q027
QhL0P82007moO`21PH40PX:208F5Q@26QXH0QhN708n?S`28R8P0S8b<08N7Q`25QHD0RHV908^;R`28
R8P0RXZ:08f=S@2>SXh0RHV908F5Q@28R8P0Rh^;08N7Q`28R8P0Rh^;08b<S028R8P0RHV908n?S`80
S8b<00@0Rh^;08j>SP2ATI40U9BD0P2@T9000`2BTY80U9BD08n?S`0209FEU@0309NGU`2HV9P0V9RH
0080VYZJ00h0WIfM09ZJVP2MWId0WIfM09jNWP2LW9`0WinO0:2PX02TY:@0Z:RX0:BTY02SXj<0Z:RX
0:JVYP80ZJVY0P2/[:`20:f][@030;6a/@2`/;00/k>c00<0];Bd0P2j^[X01P32`/80^k^k0;^k^`2m
_Kd0`L710<;2`P80`l?300D0a/K60<S8b039bLT0b/[:0<_;b`020<g=c@040<k>cP3Bd]80clo?0=7A
d@80dm?C0P3EeMD01@3Cdm<0eMGE0=GEe@3Fe]H0emOG0080f=SH00l0g=cL0=gMg@3Ng]h0gmoO0=gM
g@3IfMT0a/K606YZJP0W9bL0;bl_038b<P0S8b<08R8R02DU9@0W9bL00P0Q8B403P0i>CT0QHF509>C
T`2ATI40UIFE08f=S@27QhL0UYJF08f=S@2HV9P0UiNG09RHV02GUiL0Ti>C0P2ATI40102BTY80UIFE
092@T02?Shl3096AT@0909FEU@2BTY80TY:B09>CT`2:RXX0TY:B08n?S`2<S8`0TY:B00<0Rh^;00d0
RHV908f=S@25QHD0R8R80861P@1oOgl0Ph>308N7Q`28R8P0Q8B408J6QP21PH40QHF50080Q8B401L0
P8200861P@23Ph<0Ng]k07YjNP1lO7`0MgMg07YjNP1gMgL0N7Qh0820P02BTY80Z:RX0;Vi^@33`l<0
bl_;0<c<c03@d=00dM7A0<o?c`3>c/h0bLW90<S8b0020<[:bP070<k>cP3AdM40e]KF0=WIf@3Jf]X0
fMWI0=SHf0050=OGe`0=0=SHf03AdM40clo?0<[:bP2o_kl0/K6a0:6QX@2ATI40NWYj06EUI@1PH600
FEUI05YJFP0205aLG00805eMG@1LG5`0G5aL05aLG01HF5P0FEUI069RHP1WIfL206][J`0<06QXJ01c
Lg<0LW9b071`L01cLg<0MWIf07AdM01`L700Kfm_05eMG@1OGel0FEUI0P1LG5`04P1JFUX0EeMG05UI
F@1SHf<0I6AT06UYJ@1WIfL0IVIV06][J`1UIFD0Hf=S065QH@1WIfL0Hf=S06QXJ01/K6`0JVYZ06MW
I`h0b>3H000<0<SPf0<08B4Q02L09RHV02h^;P0f=SH0@41004Q8B01PH600MGEe08b<S02GUiL0W9bL
0:>SX`2/[:`0Zj^[0:j^[P2][Jd0ZJVY0:FUY@2IVIT0Ti>C0861P@1bLW80DE5A03<c<`0Q8B407QhN
020P800/;2`0@41005YJFP1^KVh0PX:208n?S`2BTY80VYZJ0::RXP2XZ:P0Zj^[0;2`/02d];@00`2b
/[80202a/K40/;2`0;2`/02a/K40/k>c0:b/[02f][H0]KFe0P2g]kL0702f][H0/[:b0:j^[P2/[:`0
YZJV0:2PX02MWId0Ti>C08f=S@21PH40UIFE0;>c/`1oOgl0NWYj075aL@0f=SH0<C4a02`/;00e=CD0
>SXj02l_;`0U9BD0:2PX02d];@0`<300>SXj0451@@0m?Cd2034a<@0302l_;`0^;Rh0=SHf00<0:b/[
00d09RHV02d];@0/;2`0=3@d03De=@0a<C40<30`02d];@0b<S80:b/[03<c<`10@400K6a/0080TY:B
01L0OWin06ATI00i>CT08b<S02@T900U9BD0:2PX0410@01GEeL0CDe=03Ti>@0[:b/09bLW038b<P1;
Bd/0@D5103Ti>@0_;bl0=CDe03dm?@12@T80>CTi02/[:`0202@T900_02XZ:P0b<S80=cLg03hn?P0f
=SH0=3@d05UIF@1HF5P0?Shn04=3@`1UIFD0K6a/06EUI@1IFET0LW9b07IfMP1TI6@0F5QH06ATI01L
G5`0@d=3059BDP18B4P0?Cdm05IFEP1TI6@0Kfm_08b<S028R8P0T92@08Z:RP1/K6`0LG5a08J6QP2X
Z:P0WinO06][J`1bLW80KVi^03<c<`0V9RH0<30`02<S8`0[:b/0<C4a05ADE02h^;P00P2j^[X04P2J
VYX0EEEE02XZ:P0V9RH08B4Q01dM7@0R8R809BDU02TY:@0h>3P0EeMG05EEE@1GEeL0:BTY03/k>`1:
BTX0EEEE04e=C@80;bl_00H0>CTi03/k>`0d=3@0=cLg03Ph>00a<C43038b<P0603Lg=`11@D40B4Q8
03dm?@10@400<c<c0P0];Bd03@0[:b/0<30`02/[:`0`<300>c/k03Xj>P0e=CD0?Cdm059BDP1KFe/0
G5aL06=SH`1MGEd00P1TI6@04`1WIfL0MWIf07inOP1kNg/0M7Ad06ATI019BDT0=SHf02l_;`0b<S80
?3`l06ATI01MGEd0GemO06e]K@1cLg<0OWin0861P@20P8000P22PX80<021PH40PX:20820P021PH40
PX:208B4Q028R8P0RXZ:08R8R029RHT0QhN708Z:RP2;Rh/0SXj>08Z:RP2>SXh0S8b<08J6QP24Q8@0
QXJ608V9R@28R8P0QhN708b<S02=SHd0RXZ:08N7Q`2;Rh/0RHV908j>SP2@T900Rh^;09JFUP2@T900
U9BD092@T02CTi<0S8b<09:BTP2DU9@0UYJF09FEU@2FUYH0V9RH09^KV`2IVIT0V9RH09fMW@80Vi^K
0P2OWil03@2KVi/0XZ:R0:RXZ02TY:@0YZJV0:NWY`2TY:@0ZJVY0:ZZZP2/[:`0ZZZZ0:VYZ@2/[:`0
0P2`/;001P2e]KD0/k>c0;Fe]@2b/[80][Jf0;bl_080^[Zj00/0_[jn0;Zj^P2n_[h0_kno0<;2`P33
`l<0aLG50<O7a`36a/H0bl_;0<W9b@020<g=c@0W0<o?c`3@d=00d=3@0<o?c`3>c/h0d];B0=?Cd`3F
e]H0dm?C0=CDe03EeMD0e]KF0=OGe`3Hf=P0f][J0=_Kf`3Lg=`0gMgM0=kNgP3Ogml0g=cL0=CDe02/
[:`0ADE5020P800V9RH0:2PX02@T900P82008b<S02PX:00O7al092@T03<c<`1gMgL0TI6A092@T02H
V9P0U9BD0080SXj>00H0Rh^;09RHV02DU9@0TI6A092@T02EUID309>CT`80VIVI00H0Ti>C09BDU02D
U9@0U9BD08n?S`2ATI4209:BTP0908j>SP2=SHd0SXj>08j>SP2<S8`0SHf=08n?S`29RHT0SHf=0080
S8b<02h0R8R808F5Q@24Q8@0QXJ60861P@27QhL0QHF508J6QP28R8P0Ph>308J6QP24Q8@0Ogmo0820
P01oOgl0OWin07alO01hN7P0OWin0820P01mOGd0NGUi07moO`2:RXX0VIVI0;2`/02k^k/0`l?30<O7
a`3;bl/0cLg=0<_;b`3:b/X0bl_;0<O7a`3=cLd0bl_;0<o?c`3AdM40e]KF0=SHf03Kfm/0emOG0=SH
f03GemL0f=SH0`3GemL03@3EeMD0e=CD0<k>cP3>c/h0a<C40;Zj^P2XZ:P0W9bL08J6QP1ZJVX0GUiN
05UIF@1LG5`00P1NGUh0201LG5`0GUiN05YJFP1JFUX0GemO05IFEP1MGEd0IVIV0P1WIfL0301YJFT0
Jf][06i^KP1aLG40L71`07AdM01fMWH0LG5a06m_K`1SHf<0GUiN05mOG`80G5aL00X0Fe]K05UIF@1N
GUh0GemO065QH@1ZJVX0Hf=S06UYJ@1[Jf/0HF5Q0P1SHf<01P1PH600HV9R079bLP1XJ6P0KVi^06EU
I@h0b>3H000<0<SPf08092@T00h0:BTY034a<@0[:b/0<30`03@d=019BDT0H61P07QhN02:RXX0Vi^K
09nOW`2ZZZX0[:b/0:n_[`80[Jf]01H0YJFU0::RXP2MWId0TY:B08>3P`1aLG40E5AD03De=@0U9BD0
92@T02PX:00];Bd0AdM705YJFP1/K6`0OWin08b<S02CTi<0VIVI09fMW@2XZ:P0[Jf]0P2a/K420;Bd
]0050;Ng]`2e]KD0/K6a0;6a/@2_[jl00P2c/k<0102b/[80][Jf0;Fe]@2f][H20;Fe]@0:0:j^[P2Y
ZJT0YJFU09jNWP2LW9`0UYJF08^;R`21PH40QXJ6096AT@80Ogmo00L0TI6A04I6AP0Y:BT0:b/[038b
<P0j>SX0>CTi0080:RXZ01D0:b/[02h^;P0`<300>CTi03dm?@0k>c/0<30`034a<@0d=3@0?3`l03@d
=00a<C40:b/[02h^;P0_;bl0<C4a03De=@0g=cL0=SHf03Ti>@0`<3000`0^;Rh06`0j>SX0FUYJ08^;
R`2GUiL0P82006ATI00l?3`0:b/[02DU9@0R8R80:b/[04M7A`1IFET0BTY:03hn?P0T92@0:2PX030`
<017AdL0?Shn030`<00V9RH0<c<c03hn?P14A4@0>3Ph02TY:@0202<S8`1703@d=00m?Cd0<S8b02h^
;P0`<300>3Ph06ATI01@D500=SHf04m?C`1VIVH0IfMW061PH01FEUH0K6a/06][J`1KFe/0F5QH05]K
F`1;Bd/0C4a<05UIF@1ADE40D51@055AD@1RHV80L71`08n?S`24Q8@0UiNG09ZJVP25QHD0KFe]07=c
L`2_[jl0YJFU08:2PP1gMgL0CDe=02XZ:P0];Bd0;Rh^02`/;00`<300>CTi05]KF`2h^;P0_[jn0;Rh
^02i^KT0LW9b02XZ:P0X:2P08R8R02PX:00/;2`0:b/[02d];@0g=cL0EeMG05=CD`1FEUH0<c<c03Lg
=`17AdL0GemO04m?C`0k>c/0>3Ph03De=@0j>SX00`0e=CD02P0g=cL0=SHf03@d=00a<C40?Cdm03/k
>`13@d<0?3`l03Hf=P0^;Rh202`/;00S02XZ:P0];Bd0<30`030`<00];Bd0>CTi03Xj>P0g=cL0C4a<
05MGE`1QHF40JVYZ06][J`1RHV80H61P05mOG`1^KVh0Lg=c07EeM@1dM7@0H61P04A4A00_;bl0<C4a
02XZ:P0o?cl0H61P05aLG01SHf<0IVIV075aL@1hN7P0O7al0820P024Q8@00P22PX802@1oOgl0Ph>3
07inOP1oOgl0PH6108J6QP29RHT0QhN708^;R`0308V9R@0908^;R`2=SHd0RXZ:08^;R`27QhL0QHF5
08J6QP2:RXX0SHf=0080Rh^;01H0SXj>08f=S@2<S8`0S8b<092@T02?Shl0QXJ608j>SP2BTY80Shn?
09>CT`2DU9@0T92@08j>SP2?Shl0TY:B09FEU@2FUYH0VIVI09fMW@2LW9`0WIfM0P2KVi/209ZJVP06
09nOW`2NWYh0W9bL09jNWP2PX:00YZJV0P2XZ:P00`2YZJT0YZJV0:RXZ0020:ZZZP040:f][@2_[jl0
[Zj^0;2`/080/[:b00L0]kNg0;Vi^@2h^;P0^k^k0;Ng]`2h^;P0^k^k0080_Kfm00X0_[jn0<;2`P35
aLD0`l?30<W9b@37alL0bLW90<c<c03=cLd0c/k>0P3@d=00303AdM40d=3@0=3@d03De=@0eMGE0=?C
d`3De=@0dM7A0=KFeP3GemL0f=SH0=_Kf`@0g=cL01/0g]kN0>3Ph03Kfm/0bl_;08R8R00a<C40820P
02DU9@0Y:BT08B4Q02@T900U9BD0:2PX024Q8@0S8b<0<c<c06a/K02ATI40TY:B09nOW`2EUID0SXj>
08B4Q02>SXh0TI6A09>CT`2DU9@00P2EUID209NGU`0E09JFUP2HV9P0Ti>C09:BTP2?Shl0TY:B096A
T@2FUYH0Ti>C08n?S`2HV9P0T92@08j>SP2DU9@0Rh^;08f=S@2@T900SXj>08f=S@2:RXX0QXJ60080
Rh^;0100P82008R8R024Q8@0QhN708F5Q@26QXH0Q8B408Z:RP25QHD0R8R808:2PP20P800Ph>307mo
O`1nOWh0P8200`1lO7`04`1oOgl0NGUi07inOP23Ph<0TY:B0::RXP2][Jd0^KVi0;no_`34a<@0aLG5
0<W9b@37alL0b<S80<W9b@3:b/X0c<c<0<o?c`3Cdm<00P3GemL20=WIf@0C0=SHf03IfMT0emOG0=KF
eP3GemL0e]KF0=GEe@3De=@0dm?C0<g=c@39bLT0_[jn0;Bd]02RXZ80Rh^;07=cL`1SHf<0FUYJ05aL
G00205IFEP0;061PH01JFUX0Fe]K05iNGP1MGEd0FUYJ05eMG@1TI6@0Hf=S06YZJP1[Jf/00P1/K6`0
3P1^KVh0L71`071`L01eMGD0LW9b06i^KP1ZJVX0IFEU05mOG`1KFe/0GUiN05]KF`1LG5`0GUiN0P1M
GEd01`1YJFT0HV9R06YZJP1`L700Hf=S06MWI`1PH6000P1NGUh0101[Jf/0IFEU06a/K01YJFT>0<SP
f0003038h=P201lO7`0X02PX:00W9bL0:b/[038b<P0f=SH0DE5A061PH01jNWX0TI6A09RHV02QXJ40
ZZZZ0:f][@2[Zj/0[Jf]0:j^[P2/[:`0YJFU0:2PX02LW9`0QXJ606e]K@1@D500;Rh^02HV9P0U9BD0
9RHV02l_;`18B4P0Fe]K06m_K`25QHD0SXj>09FEU@2JVYX0Xj>S0:BTY02[Zj/0/;2`0;>c/`80]kNg
00`0]KFe0;Bd]02a/K40];Bd0;>c/`2b/[80/k>c0;:b/P2d];@0][Jf0;6a/@2_[jl20:j^[P0B0:^[
Z`2SXj<0YJFU09fMW@2GUiL0TI6A08>3P`1dM7@0N7Qh06QXJ01jNWX0/[:b06UYJ@0_;bl0=CDe034a
<@0d=3@0<c<c0P0_;bl07`0];Bd0;Rh^038b<P0j>SX0?clo0410@00j>SX0;Rh^03@d=00g=cL0<S8b
02l_;`0d=3@0;Bd]034a<@0d=3@0;Bd]030`<00a<C40;bl_02d];@0c<c<0<S8b02PX:00f=SH0Cdm?
07emO@2HV9P0RXZ:06i^KP0f=SH00P0V9RH04P0W9bL0;Rh^04];B`1IFET0@T9203De=@0S8b<092@T
02PX:00o?cl0>c/k02h^;P0S8b<0;bl_03Xj>P0i>CT0=cLg03De=@80=cLg01h0?Cdm04Q8B00l?3`0
;Rh^02d];@1>CTh0GEeM03hn?P0j>SX0FEUI06YZJP1JFUX0EUIF06IVIP1aLG40IFEU055AD@1SHf<0
EEEE04M7A`1BDU80GEeM05UIF@1<C4`0EUIF069RHP1eMGD0TY:B08f=S@2DU9@309FEU@0=07UiN@2Q
XJ40YZJV092@T01ZJVX0:2PX020P800b<S80A4A403Hf=P0];Bd0<C4a06MWI`020;^k^`0E0;Jf]P35
aLD0Shn?02l_;`0P82008b<S02TY:@0W9bL0:2PX02DU9@0Y:BT0CDe=051@D01>CTh0;bl_03Ti>@18
B4P0IfMW05eMG@0c<c<0;bl_0080>3Ph00d0=CDe02h^;P0c<c<0?Cdm02/[:`0_;bl0;Rh^03/k>`0l
?3`0D51@03/k>`0e=CD0;Rh^0080:RXZ02H0:BTY038b<P0f=SH0;2`/02d];@0k>c/0?Cdm03De=@14
A4@0EeMG069RHP1/K6`0LW9b06][J`1TI6@0H61P06=SH`1WIfL0KFe]06m_K`1TI6@0@T9203<c<`0[
:b/0<S8b0410@01DE5@0G5aL05QHF01[Jf/0M7Ad07MgM`1lO7`0Q8B408R8R024Q8@0QXJ608:2PP80
Q8B400<0P82008F5Q@25QHD00P28R8P00`2<S8`0RHV908V9R@0208b<S00D08V9R@2?Shl0RXZ:08R8
R02:RXX0SXj>08R8R029RHT0SHf=08^;R`2<S8`0Rh^;08n?S`2@T900S8b<096AT@2>SXh0Shn?08j>
SP2ATI4309>CT`03096AT@2EUID0UIFE0080V9RH00H0VIVI09^KV`2MWId0W9bL09^KV`2PX:0209fM
W@0;0::RXP2PX:00WinO0:6QX@2OWil0XZ:R0:RXZ02SXj<0YZJV0:j^[P2][Jd00P2[Zj/02P2b/[80
/;2`0:n_[`2ZZZX0/K6a0;Ng]`2j^[X0^k^k0;Ng]`2k^k/20;Zj^P040;fm_@2j^[X0_Kfm0<30`080
`l?300L0alO70<W9b@3:b/X0cLg=0<c<c03>c/h0c<c<0080dM7A00H0dm?C0<o?c`3AdM40dm?C0=OG
e`3Cdm<20=GEe@030=KFeP3GemL0fMWI0080f][J00X0gMgM0=kNgP3Ng]h0h>3P0=cLg03GemL0/[:b
05=CD`0W9bL09RHV0P0Y:BT0100R8R808b<S02XZ:P0U9BD2020P800402l_;`1QHF40UIFE09>CT`80
Vi^K00P0TI6A0820P02ATI40U9BD09FEU@2IVIT0V9RH09BDU080UYJF01L0U9BD09^KV`2BTY80SXj>
09>CT`2DU9@0T92@09>CT`2EUID0TI6A08j>SP2ATI40Shn?092@T02ATI40T92@09:BTP2@T900Shn?
08^;R`2<S8`0RXZ:08n?S`0208^;R`0908N7Q`2:RXX0RXZ:08Z:RP28R8P0RXZ:08F5Q@26QXH0Q8B4
0080PX:201D0QHF50861P@1mOGd0O7al0820P01mOGd0Ng]k07YjNP1lO7`0OWin08j>SP2GUiL0Xj>S
0:j^[P2b/[80_Kfm0<71`@35aLD0alO70<?3``38b<P00P3;bl/00`3@d=00dM7A0=GEe@020=OGe`03
0=[JfP3GemL0f=SH0080f=SH00l0eMGE0=SHf03EeMD0d];B0=3@d03>c/h0bl_;0<G5a@2k^k/0[Zj^
09JFUP1jNWX0IVIV05]KF`1NGUh00P1FEUH06@1NGUh0GEeM05]KF`1RHV80GemO05MGE`1KFe/0H61P
06ATI01QHF40JVYZ06MWI`1ZJVX0Jf][06i^KP1aLG40LW9b07AdM01aLG40JVYZ06IVIP1QHF40Fe]K
05QHF01FEUH00P1HF5P03`1OGel0GUiN06ATI01RHV80J6QX06e]K@1VIVH0J6QX065QH@1OGel0HV9R
06MWI`1TI6@0HV9R06m_K`0>0<SPf0003038h=P2028R8P0?02DU9@0X:2P09bLW03Lg=`0i>CT0E5AD
06MWI`1kNg/0TY:B09VIV@2SXj<0[Jf]0:^[Z`2^[Zh0[:b/0080ZZZZ01L0YZJV09jNWP2KVi/0RXZ:
07]kN`1@D500:RXZ01lO7`0X:2P09BDU03<c<`17AdL0F5QH06e]K@23Ph<0T92@09BDU02GUiL0XZ:R
0:2PX02/[:`0/K6a0;>c/`020;Bd]00:0;Rh^02b/[80/;2`0;:b/P2`/;00/[:b0:n_[`2b/[80/k>c
0;Jf]P80]KFe01T0[Jf]0:^[Z`2YZJT0YJFU09nOW`2HV9P0UYJF08^;R`22PX80KVi^06][J`1XJ6P0
KFe]0:BTY029RHT0<c<c02PX:00];Bd0:b/[038b<P0e=CD0;Rh^02l_;`0Y:BT0:RXZ0080;bl_00L0
?Cdm03hn?P0`<300=SHf03@d=00^;Rh0=CDe0080;Bd]00d0;2`/02h^;P0b<S80>SXj02`/;00i>CT0
<C4a02h^;P0Z:RX0;2`/03<c<`1=CDd0K6a/0080Shn?00X0LW9b03Hf=P0T92@09RHV02/[:`0j>SX0
E5AD04i>CP0b<S80<C4a0P0X:2P01@0Y:BT0<S8b03De=@0a<C40:BTY0080=cLg00<0=SHf0410@01?
Cdl00P1EEED0B01FEUH0Fe]K04Y:BP0j>SX0<S8b05UIF@1?Cdl0=SHf04Q8B01LG5`0IFEU05MGE`1P
H600Lg=c06YZJP1YJFT0Fe]K05iNGP1CDe<0D51@055AD@1KFe/0GEeM04i>CP1@D500FUYJ07IfMP2B
TY80V9RH09JFUP2GUiL0S8b<09NGU`2KVi/0Shn?0:6QX@2ATI40De=C02LW9`0T92@0;Bd]05eMG@1@
D500<C4a038b<P1ZJVX0_;bl0;Bd]02f][H0d=3@0:2PX00^;Rh092@T02TY:@0T92@09BDU028R8P0S
8b<0:BTY04];B`16ATH0BTY:034a<@0d=3@0Cdm?06QXJ01IFET0<C4a02/[:`0`<300>3Ph02l_;`80
:b/[00X0=SHf038b<P0];Bd0:RXZ03Hf=P0g=cL0CTi>03hn?P0c<c<0=3@d0P0^;Rh0:@0_;bl0<30`
03Ph>00^;Rh0<S8b03<c<`0l?3`0>3Ph03dm?@1DE5@0GUiN06YZJP1cLg<0LW9b06m_K`1ZJVX0HF5Q
05iNGP1TI6@0KFe]06EUI@14A4@0>CTi02LW9`0/;2`0>3Ph05=CD`1OGel0F5QH07AdM01hN7P0MgMg
07IfMP1nOWh0Ph>308:2PP24Q8@0PX:207emO@21PH40Ogmo0080Q8B400D0QXJ608N7Q`2=SHd0RXZ:
08N7Q`0208^;R`0<08V9R@2<S8`0RHV908V9R@28R8P0SHf=08b<S028R8P0Rh^;08Z:RP2;Rh/0T92@
0P2=SHd0502<S8`0Shn?09:BTP2CTi<0SHf=09FEU@2CTi<0UiNG08j>SP2CTi<0U9BD09ZJVP2BTY80
UYJF09NGU`2HV9P0W9bL09jNWP2LW9`0WIfM0P2LW9`01`2OWil0XJ6Q0:6QX@2OWil0XZ:R0:FUY@2S
Xj<00P2XZ:P01P2b/[80ZZZZ0:^[Z`2_[jl0[Zj^0;:b/P80/;2`00`0[jn_0;>c/`2f][H0_Kfm0;Rh
^02g]kL0_kno0;bl_02k^k/0_[jn0;fm_@32`/820<K6aP050<O7a`39bLT0a/K60<_;b`3=cLd00P3>
c/h03@3Bd]80d=3@0=3@d03AdM40d];B0=KFeP3EeMD0dm?C0=GEe@3Cdm<0e]KF0=WIf@3Jf]X00P3K
fm/20=gMg@0N0=kNgP3Ph>00g=cL0<o?c`2<S8`0>CTi02TY:@0Z:RX0;2`/02LW9`0U9BD092@T02LW
9`0[:b/07QhN020P800[:b/0Fe]K09jNWP2DU9@0VIVI09bLW028R8P0PH61092@T02DU9@0UiNG09RH
V02IVIT0TI6A0P2CTi<0102GUiL0V9RH09VIV@2@T902096AT@0909JFUP2=SHd0T92@092@T02CTi<0
TI6A08f=S@2@T900TY:B0080SXj>00<0Rh^;08j>SP28R8P00P27QhL00`2:RXX0QhN708F5Q@0208J6
QP<0QhN700d0QHF508N7Q`26QXH0QHF508J6QP25QHD0Q8B407moO`1nOWh0NWYj07alO021PH40Ogmo
00<0NGUi00P0Ogmo08Z:RP2HV9P0XJ6Q0:^[Z`2b/[80_Kfm0<?3``80a<C400`0aLG50<O7a`36a/H0
c<c<0=7Ad@3Cdm<0eMGE0=OGe`3Hf=P0fMWI0=KFeP3Hf=P40=KFeP0<0=CDe03AdM40dM7A0<g=c@39
bLT0`/;20;Bd]02TY:@0RXZ:06m_K`1MGEd0F5QH0P1IFET03@1MGEd0Fe]K05YJFP1NGUh0IVIV05mO
G`1LG5`0GemO061PH01VIVH0JVYZ06EUI@1VIVH00P1/K6`0301^KVh0L71`07=cL`1aLG40Jf][06QX
J01SHf<0HV9R05YJFP1IFET0F5QH05eMG@80FEUI00H0HV9R065QH@1UIFD0K6a/06EUI@1WIfL206AT
I00505aLG01VIVH0JFUY06IVIP1WIfL03P38h=P000`0b>3H0P0V9RH02`0W9bL092@T02h^;P0e=CD0
>CTi055AD@1^KVh0OWin09JFUP2NWYh0YJFU0080[:b/01/0ZJVY0:f][@2/[:`0ZZZZ0:>SX`2NWYh0
Ti>C08Z:RP1gMgL0F5QH03<c<`0R8R80:BTY02PX:00];Bd0?clo05YJFP1aLG40PH61092@T02CTi<0
VIVI0:BTY02UYJD0Y:BT0;:b/P2a/K400P2`/;00202d];@0/k>c0;:b/P2d];@0[Zj^0;2`/02_[jl0
/[:b0P2d];@0602`/;00/k>c0;2`/02^[Zh0ZJVY0:FUY@2RXZ80W9bL09RHV029RHT0O7al06UYJ@1W
IfL0O7al06IVIP1bLW80MGEe02h^;P0W9bL0:2PX02TY:@0a<C40=3@d034a<@<0:RXZ00l0<S8b034a
<@0j>SX0ATI603/k>`0f=SH0>SXj034a<@0`<300:b/[03<c<`0b<S80<c<c02`/;00d=3@00P0Z:RX0
7`0^;Rh0;bl_02h^;P0];Bd0;2`/03Xj>P1PH600Q8B409:BTP1dM7@0;Rh^02XZ:P0^;Rh0;bl_03`l
?01OGel0CDe=03Hf=P0];Bd09BDU028R8P0Y:BT0:b/[04M7A`0V9RH0:RXZ03Hf=P0n?Sh0CDe=05aL
G01XJ6P00P1QHF40=`1YJFT0H61P04A4A00];Bd0<C4a04i>CP11@D40>c/k05MGE`1ZJVX0EeMG04Y:
BP1bLW80Lg=c06a/K01^KVh0IVIV06YZJP1RHV80CDe=05=CD`1BDU80FUYJ059BDP19BDT0F5QH07Ee
M@2CTi<0UYJF0:6QX@2HV9P0T92@08N7Q`2KVi/0VYZJ09BDU01oOgl0?3`l02<S8`0X:2P0>SXj05AD
E01:BTX0=3@d03Xj>P1[Jf/0`l?30:b/[02g]kL0dm?C0:f][@0i>CT07AdM028R8P0P82000P0O7al0
5@0R8R80:BTY04M7A`1>CTh0?Cdm030`<00f=SH0C4a<05QHF01?Cdl0<C4a03<c<`0b<S80;Rh^03Lg
=`0b<S80:2PX03<c<`0^;Rh0?Cdm03Lg=`0203Hf=P0404A4A013@d<0=SHf03<c<`80;Bd]0180<30`
03@d=00i>CT0ADE503lo?`0d=3@0>3Ph03Ti>@0h>3P0Bd];05QHF01PH600K6a/06e]K@1aLG40JVYZ
06QXJ01VIVH206=SH`0?05aLG010@400=SHf02LW9`0i>CT0?3`l055AD@1RHV80H61P071`L01jNWX0
NGUi07YjNP1nOWh0PX:20080OWin00T0Q8B407moO`1lO7`0O7al08:2PP26QXH0R8R808>3P`29RHT0
0P27QhL208V9R@0408j>SP2:RXX0S8b<08b<S080SHf=00h0RHV908f=S@2<S8`0Rh^;08f=S@2<S8`0
Rh^;08j>SP2@T900Shn?08j>SP2FUYH0UIFE09ZJVP80TI6A00`0Shn?096AT@2GUiL0Ti>C09NGU`2H
V9P0UiNG09JFUP2KVi/0W9bL09VIV@2QXJ4209jNWP090:2PX02MWId0Xj>S0:6QX@2TY:@0Xj>S0:BT
Y02VYZH0Zj^[00<0[:b/0P2^[Zh00`2`/;00]KFe0:j^[P020;6a/@80]kNg00T0^[Zj0;Rh^02k^k/0
_[jn0;fm_@2k^k/0_[jn0;no_`35aLD00`36a/H01P39bLT0bl_;0<g=c@3=cLd0c<c<0<o?c`<0d];B
00`0d=3@0=GEe@3EeMD0dm?C0=CDe03Cdm<0e]KF0=OGe`3IfMT0g=cL0=gMg@3Lg=`20=gMg@050=kN
gP3Hf=P0_;bl069RHP0Z:RX00P0Y:BT04`0_;bl0<S8b02HV9P0X:2P0:BTY02h^;P0P82007alO02/[
:`1=CDd0VIVI09:BTP2GUiL0XZ:R08F5Q@22PX80Rh^;09BDU02HV9P00P2DU9@0502FUYH0T92@092@
T02FUYH0T92@09:BTP2FUYH0Shn?09BDU02@T900Ti>C08n?S`2DU9@0TY:B09BDU02BTY80Rh^;096A
T@2=SHd0RHV90P2>SXh01`2ATI40Rh^;08j>SP2=SHd0R8R808N7Q`2:RXX00P26QXH03@28R8P0S8b<
08R8R028R8P0QhN708>3P`25QHD0Q8B408R8R023Ph<0PH6107inOP1jNWX00P1kNg/02`1iNGT0NWYj
07]kN`1mOGd0PH61092@T02JVYX0Y:BT0:^[Z`2`/;00]kNg0080_[jn00h0`l?30<G5a@36a/H0bl_;
0<c<c03AdM40dm?C0=KFeP3Hf=P0fMWI0=OGe`3Hf=P0eMGE0=KFeP80emOG00/0e=CD0=?Cd`3>c/h0
dM7A0<g=c@34a<@0_;bl0:f][@2FUYH0OWin06EUI@0305UIF@0H05eMG@1GEeL0G5aL069RHP1SHf<0
GUiN05]KF`1JFUX0FEUI05mOG`1WIfL0IVIV06ATI01XJ6P0Jf][06a/K01`L700Kfm_071`L01]KFd0
KVi^06MWI`1UIFD0GUiN0P1KFe/02@1HF5P0GEeM065QH@1JFUX0HF5Q06MWI`1]KFd0Hf=S06QXJ003
06EUI@0405iNGP1VIVH0JVYZ06UYJ@h0b>3H000<0<SPf0808R8R01T0820P02<S8`0Y:BT0<c<c03dm
?@1RHV80MGEe09JFUP2EUID0WYjN0:NWY`2XZ:P0ZZZZ0:JVYP2XZ:P0ZJVY0:BTY02RXZ80W9bL09>C
T`28R8P0Ng]k069RHP11@D409bLW00808b<S00d0:RXZ03lo?`1KFe/0Kfm_08>3P`2=SHd0T92@09ZJ
VP2RXZ80YZJV0:^[Z`2/[:`0/K6a0080/k>c00P0/[:b0;>c/`2a/K40[Zj^0:n_[`2^[Zh0/;2`0;Jf
]P<0];Bd0P2a/K403`2/[:`0Z:RX0:BTY02NWYh0VIVI09FEU@2<S8`0O7al06e]K@1/K6`0YZJV0861
P@1=CDd0EEEE03Xj>P0202PX:00E030`<00a<C40<30`02/[:`0^;Rh0:2PX02TY:@0k>c/0=3@d03<c
<`10@400@D51034a<@0k>c/0<30`02/[:`0/;2`0=3@d02TY:@0b<S80>CTi0080;Rh^00`0:RXZ02PX
:00];Bd0:BTY02l_;`0^;Rh0>SXj05QHF01iNGT0RXZ:07QhN00i>CT202LW9`0B03Xj>P18B4P0FUYJ
04Q8B00h>3P0:RXZ024Q8@0V9RH08b<S02/[:`0`<3008R8R02<S8`0i>CT0B4Q806ATI01YJFT0De=C
0P17AdL0=01VIVH0F5QH04=3@`0/;2`0=3@d04i>CP10@400CDe=05eMG@1QHF40CDe=04];B`1lO7`0
KFe]06a/K01]KFd0Lg=c06m_K`1GEeL0?clo04a<C01FEUH0Fe]K05MGE`19BDT0HV9R08B4Q02@T900
R8R809BDU02QXJ40SXj>07MgM`2LW9`0UIFE0861P@1ZJVX0=3@d02PX:00g=cL0ATI603De=@0];Bd0
?Shn04E5A@1cLg<0`l?309bLW02a/K40emOG0;Ng]`0o?cl202`/;00;02/[:`0X:2P07alO02DU9@0X
:2P0A4A405EEE@14A4@0=3@d03/k>`15ADD00P1?Cdl04@0b<S80<30`03@d=00f=SH0=3@d02d];@0`
<300<c<c030`<00i>CT0=3@d03/k>`0h>3P0AdM70492@P0g=cL0:RXZ0080<S8b0300;Rh^02l_;`0b
<S80=CDe038b<P0/;2`0=SHf03De=@0f=SH0?3`l04m?C`1NGUh0H61P06i^KP1ZJVX0MGEe071`L01_
Kfl0GUiN06EUI@1JFUX0>c/k034a<@0[:b/0;2`/0410@01@D500IFEU069RHP1WIfL0Ng]k07YjNP1a
LG40MgMg0861P@1mOGd0P82008B4Q01mOGd0NGUi0861P@23Ph<0QhN708V9R@28R8P0PH6108:2PP24
Q8@208F5Q@0308j>SP2:RXX0QhN70080RHV900<0RXZ:096AT@2<S8`00P2=SHd208b<S00508Z:RP2=
SHd0TI6A08j>SP2CTi<00P2ATI402@2GUiL0UIFE09>CT`2ATI40V9RH096AT@2DU9@0V9RH09NGU`02
09ZJVP0409^KV`2GUiL0WinO0:2PX080WIfM00H0WinO09jNWP2RXZ80XZ:R0:NWY`2XZ:P20:NWY`08
0:b/[02YZJT0Zj^[0:b/[02][Jd0[Zj^0:^[Z`2`/;020;Bd]0030;>c/`2b/[80]KFe0080^KVi00d0
^[Zj0;^k^`2n_[h0^[Zj0;jn_P2o_kl0a/K60<C4a036a/H0b<S80<c<c038b<P0b/[:0080c<c<00l0
c/k>0=7Ad@3Cdm<0d];B0=3@d03Bd]80e=CD0=?Cd`3De=@0e]KF0=WIf@3Jf]X0fm_K0=gMg@3Jf]X0
0P3MgMd02P3Ogml0g=cL0=3@d02JVYX0>SXj02<S8`0^;Rh09RHV030`<00c<c<202LW9`0B02`/;00Z
:RX0:b/[02LW9`0[:b/0BTY:08n?S`2EUID0Vi^K0:FUY@25QHD0RHV908Z:RP2>SXh0V9RH09JFUP2G
UiL0UIFE0P2@T9003P2DU9@0TI6A096AT@2>SXh0T92@09BDU02BTY80TI6A09:BTP2>SXh0T92@096A
T@2>SXh0T92@0P2<S8`04@2>SXh0RXZ:092@T02;Rh/0S8b<092@T02:RXX0RHV908^;R`29RHT0QHF5
08R8R024Q8@0RHV908N7Q`2:RXX0PH610080QHF500T0QXJ608F5Q@21PH40OGem0861P@20P800Ng]k
07QhN023Ph<00P1iNGT05P1cLg<0Ng]k08R8R02ATI40VIVI09nOW`2XZ:P0[:b/0;Ng]`2j^[X0_;bl
0;fm_@30`<00bl_;0<c<c03?cll0dm?C0=GEe@3GemL0fMWI0=SHf03GemL30=KFeP0=0=GEe@3De=@0
e=CD0=;BdP3?cll0c<c<0<S8b035aLD0/[:b09jNWP2:RXX0KFe]05]KF`0205=CD`80F5QH00X0EeMG
05]KF`1PH600H61P06=SH`1LG5`0EUIF05YJFP1RHV80I6AT0P1WIfL0301VIVH0KFe]06m_K`1^KVh0
LW9b071`L01^KVh0IfMW06ATI01MGEd0GemO05]KF`80De=C00@0FEUI05YJFP1PH600H61P0`1XJ6P0
1`1VIVH0K6a/06MWI`1QHF40Hf=S06YZJP1UIFD03P38h=P000`0b>3H0P0O7al02`0N7Qh09BDU030`
<00d=3@0?3`l05YJFP1ZJVX0PH6109>CT`2KVi/0YjNW0080Z:RX01T0ZJVY0:ZZZP2XZ:P0XZ:R0:2P
X02JVYX0Shn?07moO`1kNg/0HV9R03Ti>@0V9RH0820P02HV9P0[:b/0@T9205=CD`1cLg<0PH6108b<
S02BTY80Vi^K09jNWP2UYJD0ZJVY0080[jn_0P2d];@0B@2b/[80/K6a0;>c/`2_[jl0Zj^[0:f][@2^
[Zh0/K6a0:n_[`2b/[80]KFe0;Jf]P2a/K40ZZZZ0:RXZ02VYZH0WIfM09VIV@2BTY80Rh^;0820P01[
Jf/0OWin0<c<c02EUID0AdM704E5A@0n?Sh0;2`/02TY:@0X:2P0:b/[03<c<`0];Bd0;2`/02LW9`0^
;Rh0<30`03lo?`0c<c<0>CTi04];B`0o?cl0=CDe030`<00[:b/0;2`/02d];@0^;Rh0=3@d038b<P0_
;bl0=3@d02d];@0[:b/0<30`02XZ:P0`<300<C4a030`<01BDU80MGEe08N7Q`1cLg<0ADE502/[:`0^
;Rh0;bl_04Q8B01DE5@0C4a<03lo?`0W9bL00P0X:2P01P0R8R809bLW02l_;`0S8b<0;2`/04Y:BP80
Hf=S00/0FUYJ03dm?@0o?cl0?clo06MWI`1;Bd/0>3Ph02h^;P0k>c/0Cdm?04e=C@0205]KF`0E05QH
F01<C4`0GUiN07=cL`1dM7@0LG5a07IfMP1]KFd0KVi^04a<C00o?cl0De=C05]KF`1NGUh0EeMG04m?
C`1VIVH0SHf=09>CT`20P800NGUi0080U9BD01l0NWYj09NGU`2VYZH0SXj>05aLG00n?Sh0?3`l04i>
CP0m?Cd08b<S02LW9`0i>CT0Cdm?08J6QP2h^;P0P8200;Bd]03IfMT0_;bl04e=C@0X:2P0820P02LW
9`0V9RH092@T02DU9@0V9RH0>c/k05=CD`1:BTX0<c<c0080?3`l01<0C4a<04U9B@0g=cL0<c<c02h^
;P0e=CD0=3@d030`<00];Bd0<C4a03De=@0`<300<c<c03Ti>@0m?Cd0C4a<04I6AP0e=CD0=3@d0080
<S8b01L0=cLg02l_;`0d=3@0<30`02/[:`0/;2`0<c<c03Lg=`0d=3@0?Cdm05EEE@1PH600GUiN06a/
K01YJFT0JVYZ07AdM01kNg/0Jf][06ATI01KFe/0=3@d03<c<`0202TY:@0803/k>`1;Bd/0HF5Q06AT
I01[Jf/0N7Qh075aL@1iNGT207inOP060861P@1oOgl0QhN708:2PP1oOgl0P8200P26QXH01`2:RXX0
R8R808Z:RP21PH40QXJ60861P@2:RXX00P2;Rh/208V9R@0=09:BTP2?Shl0S8b<08Z:RP2BTY80S8b<
08f=S@2ATI40Shn?08b<S02;Rh/0S8b<09JFUP0209BDU007092@T02FUYH0WYjN09NGU`2FUYH0Ti>C
09NGU`0209RHV00609^KV`2LW9`0VYZJ09bLW02NWYh0WinO0P2UYJD00`2OWil0Y:BT0:>SX`020:6Q
X@050:NWY`2UYJD0Zj^[0:ZZZP2^[Zh00P2][Jd20:j^[P090;:b/P2c/k<0/k>c0;Ng]`2d];@0]KFe
0;Jf]P2j^[X0]kNg0080_Kfm00H0_[jn0;fm_@32`/80`l?30<K6aP39bLT20<K6aP<0b/[:00h0c<c<
0<k>cP3@d=00d=3@0<o?c`3Cdm<0dM7A0=3@d03De=@0dm?C0=KFeP3EeMD0fMWI0=[JfP80fMWI00/0
gMgM0=_Kf`3MgMd0gMgM0=WIf@2m_Kd0IfMW02/[:`0Y:BT0:RXZ02h^;P02030`<00D02PX:00/;2`0
;bl_02/[:`0S8b<07alO02/[:`14A4@0RHV909^KV`2IVIT0WIfM0861P@26QXH0Shn?08^;R`2FUYH0
UIFE09JFUP2EUID208n?S`0509>CT`2ATI40Ti>C08n?S`2DU9@00P2BTY802`2ATI40SXj>096AT@2?
Shl0U9BD09>CT`2ATI40Shn?08b<S02=SHd0Shn?0080S8b<0180T92@08^;R`2=SHd0RXZ:08V9R@26
QXH0QhN708b<S027QhL0S8b<08n?S`29RHT0R8R808F5Q@2:RXX0QhN708J6QP23Ph<207moO`0J07al
O021PH40Ogmo07YjNP1oOgl0O7al07QhN01oOgl0O7al08F5Q@2?Shl0V9RH09nOW`2TY:@0/;2`0;6a
/@2f][H0^[Zj0;no_`37alL0bl_;0<o?c`3AdM40e=CD0=OGe`3EeMD30=KFeP070=GEe@3Fe]H0e=CD
0=GEe@3De=@0dm?C0<o?c`020<c<c0060<K6aP2j^[X0ZJVY096AT@1gMgL0HF5Q0P1CDe<04`1@D500
E5AD05UIF@1KFe/0GUiN061PH01MGEd0Fe]K05UIF@1KFe/0G5aL06IVIP1WIfL0IFEU06QXJ01[Jf/0
KVi^06m_K`1bLW800P1cLg<0201^KVh0J6QX065QH@1NGUh0F5QH05UIF@1GEeL0Fe]K0P1HF5P02`1Q
HF40IFEU06QXJ01WIfL0JVYZ06UYJ@1SHf<0IFEU06UYJ@1RHV80J6QX00h0b>3H000<0<SPf0808b<S
00h0:RXZ02/[:`0b<S80=cLg04Q8B01UIFD0L71`08J6QP2EUID0WYjN0:JVYP2XZ:P0[:b/0:ZZZP80
[:b/01L0XZ:R09jNWP2IVIT0U9BD08F5Q@1hN7P0GEeM03`l?00[:b/0:2PX02TY:@0d=3@0@T9205=C
D`1`L700Ogmo08j>SP2DU9@0Vi^K09nOW`2WYjL0Zj^[0;6a/@040:n_[`0Q0;2`/02_[jl0/;2`0:n_
[`2e]KD0[jn_0;6a/@2c/k<0/[:b0;>c/`2`/;00[:b/0:VYZ@2WYjL0WinO09fMW@2IVIT0UYJF08b<
S020P800IFEU07UiN@32`/80WinO04a<C01JFUX0Bd];02`/;00U9BD08b<S02`/;00b<S80=CDe0080
;Bd]00<0:RXZ02`/;00/;2`00P0e=CD0;014A4@0De=C03`l?00d=3@0<C4a02XZ:P0/;2`0;Bd]02h^
;P0c<c<0?3`l034a<@0X:2P0<C4a02d];@0d=3@0<C4a030`<00b<S80FEUI071`L024Q8@0M7Ad05IF
EP0g=cL0;Bd]03Lg=`1CDe<0ADE504I6AP0l?3`09BDU02/[:`0W9bL08b<S02PX:00/;2`0<30`0492
@P1SHf<0HF5Q04I6AP0f=SH0:b/[0P1BDU80=@1LG5`0@T9203Hf=P0g=cL0B4Q805aLG01XJ6P0HF5Q
05IFEP1>CTh0Fe]K06YZJP1XJ6P0Kfm_075aL@1hN7P0JFUY05]KF`15ADD0?clo05UIF@1[Jf/0J6QX
05UIF@1@D500LG5a09:BTP2;Rh/0PX:206QXJ01iNGT0UIFE08F5Q@2IVIT0/k>c09fMW@1mOGd0GEeM
06EUI@1EEED0=3@d02PX:00S8b<0>3Ph04a<C02<S8`0X:2P061PH02k^k/0g=cL0;Zj^P16ATH09BDU
0080:b/[01d09bLW028R8P0U9BD09RHV03Hf=P1@D500BDU903Ti>@0l?3`0?Shn04i>CP1?Cdl0<S8b
03Hf=P0d=3@0;bl_03De=@0^;Rh0;bl_03<c<`0f=SH0=3@d02h^;P0b<S80>CTi04Y:BP1DE5@0>SXj
038b<P0202l_;`0R03Ph>00f=SH0>3Ph02l_;`0Y:BT0<30`03Lg=`0k>c/0=cLg03/k>`1>CTh0G5aL
06QXJ01cLg<0LG5a06m_K`1aLG40MGEe06e]K@1OGel0D51@02l_;`0X:2P09bLW02DU9@12@T80BTY:
05UIF@1XJ6P0Jf][07EeM@1`L700LG5a0820P080PH610P25QHD01@1mOGd0P82008:2PP28R8P0QHF5
0080QXJ600T0R8R808B4Q024Q8@0PH6108^;R`2:RXX0RHV908b<S028R8P00P2?Shl00`2:RXX0S8b<
08Z:RP0208n?S`0708b<S02;Rh/0TI6A08n?S`2;Rh/0TI6A09:BTP02096AT@0308j>SP2EUID0TY:B
0080Ti>C00P0V9RH09JFUP2FUYH0UYJF09^KV`2MWId0VYZJ0::RXP<0X:2P00D0WYjN0:FUY@2TY:@0
YZJV0:>SX`020:FUY@050:VYZ@2XZ:P0ZZZZ0:b/[02[Zj/00P2^[Zh01@2_[jl0/k>c0;Bd]02i^KT0
][Jf0080];Bd01@0]kNg0;^k^`2m_Kd0_Kfm0;jn_P2m_Kd0`/;20<?3``36a/H0`l?30<K6aP3:b/X0
bLW90<[:bP3>c/h0d=3@0<o?c`3@d=00dM7A0<o?c`80d=3@02@0dm?C0=GEe@3De=@0f=SH0=CDe03F
e]H0fm_K0=[JfP3Lg=`0gMgM0=cLg03MgMd0fm_K0=7Ad@2JVYX0A4A403Xj>P0U9BD0;Rh^02d];@0c
<c<0<S8b02l_;`0Z:RX0=3@d030`<00W9bL08B4Q02PX:00m?Cd0Ogmo0:6QX@2GUiL0V9RH08N7Q`22
PX8208b<S00409RHV02IVIT0TY:B09FEU@80TY:B0P2EUID01@2DU9@0TY:B092@T02BTY80TI6A0080
SHf=00h0Shn?08j>SP2BTY80T92@08b<S02>SXh0RHV908f=S@2:RXX0SXj>08b<S02=SHd0Rh^;08b<
S080RXZ:00X0Q8B408b<S02:RXX0RXZ:08^;R`2>SXh0R8R808B4Q028R8P0Q8B40P28R8P01P25QHD0
Ogmo08B4Q022PX80PH6107alO080OGem01H0O7al07YjNP1lO7`0N7Qh0820P027QhL0TI6A09bLW02M
WId0Y:BT0:ZZZP2_[jl0/k>c0;Vi^@31`L40aLG50<[:bP3?cll0dm?C0=OGe`3EeMD0f=SH0P3GemL0
1@3Hf=P0e]KF0=GEe@3GemL0e=CD0080dm?C00P0dM7A0<k>cP3:b/X0`/;20:n_[`2JVYX0Ogmo06YZ
JP80F5QH0240CTi>051@D01EEED0F5QH05]KF`1NGUh0G5aL05YJFP1GEeL0Fe]K05aLG01PH600I6AT
06MWI`1[Jf/0JVYZ06a/K01_Kfl0LW9b07=cL`1`L700Kfm_06UYJ@1PH600GemO065QH@1IFET0F5QH
05=CD`1HF5P0FUYJ05iNGP1VIVH0101WIfL01@1XJ6P0GemO069RHP1XJ6P0Hf=S00h0b>3H000<0<SP
f0808b<S02P09bLW02`/;00d=3@0@T9204m?C`1UIFD0LW9b08V9R@2GUiL0XZ:R0:VYZ@2UYJD0ZJVY
0:^[Z`2YZJT0Zj^[0::RXP2MWId0TY:B08b<S023Ph<0O7al05eMG@14A4@0:BTY02HV9P0];Bd0<S8b
04e=C@1QHF40LW9b07moO`2=SHd0VIVI09fMW@2PX:00YjNW0:^[Z`2a/K40/k>c0P2b/[80102`/;00
/[:b0:n_[`2_[jl20;6a/@0Y0;Jf]P2e]KD0/k>c0;:b/P2`/;00/[:b0:b/[02YZJT0Y:BT0:FUY@2L
W9`0U9BD08n?S`28R8P0P82008J6QP1aLG40WIfM08f=S@1;Bd/0Ti>C07QhN00b<S808R8R02DU9@0S
8b<0;Rh^03De=@0[:b/0<30`02PX:00[:b/0<c<c034a<@0];Bd0=3@d05]KF`1BDU80@T9203@d=00/
;2`00P0Z:RX0900b<S80=CDe038b<P0f=SH0<C4a038b<P0^;Rh0=3@d02d];@0_;bl0=3@d04a<C01^
KVh0Ph>307=cL`1<C4`0:BTY02HV9P0d=3@0Bd];03/k>`18B4P0;Rh^02LW9`0[:b/092@T028R8P0Z
:RX0=cLg04E5A@1PH600HF5Q04Y:BP0a<C409BDU02l_;`80HF5Q04P0EUIF04E5A@0j>SX0>3Ph04];
B`1TI6@0J6QX05UIF@1?Cdl0CDe=06MWI`1VIVH0IFEU06IVIP1UIFD0G5aL04a<C010@400A4A405=C
D`1PH600M7Ad07QhN01MGEd0DU9B071`L02=SHd0QHF508:2PP1ZJVX0J6QX08:2PP2>SXh0TI6A0;Jf
]P2VYZH0T92@07QhN01TI6@0>3Ph02LW9`0Q8B407alO02/[:`18B4P0RHV907emO@1>CTh0^[Zj0=cL
g02b/[80=CDe028R8P0c<c<092@T02TY:@0T92@0:2PX02DU9@0j>SX0Cdm?04E5A@0n?Sh0?3`l03@d
=017AdL0A4A4038b<P0/;2`0<S8b03@d=00_;bl202d];@0:02XZ:P0c<c<0<c<c03@d=00f=SH0=cLg
04];B`1JFUX0>SXj02h^;P80?3`l0100=cLg03Ti>@0b<S80>SXj02d];@0^;Rh0=cLg03lo?`0i>CT0
?3`l04M7A`1HF5P0IFEU07AdM01fMWH0MgMg0P1hN7P04`1ZJVX0Hf=S059BDP0h>3P0:b/[02XZ:P0X
:2P0?clo04A4A01QHF40JFUY06QXJ01eMGD0NGUi079bLP1kNg/0PH6108:2PP25QHD00P27QhL03`24
Q8@0PH6108J6QP27QhL0Q8B408J6QP29RHT0Ph>308^;R`28R8P0RHV908b<S02:RXX0SXj>08f=S@02
08b<S00<08V9R@2=SHd0SHf=08b<S02>SXh0S8b<08j>SP2?Shl0U9BD08V9R@2>SXh0T92@0`2ATI40
102EUID0UiNG09FEU@2BTY8209JFUP0709^KV`2HV9P0WIfM09bLW02OWil0XJ6Q0:2PX0020::RXP0<
09nOW`2UYJD0YZJV0:NWY`2UYJD0Y:BT0:FUY@2YZJT0Z:RX0:f][@2/[:`0[Zj^0P2a/K402`2d];@0
[jn_0;2`/02g]kL0^KVi0;Jf]P2c/k<0^KVi0;fm_@30`<00a<C40080`<3000<0`L710<;2`P36a/H0
0P36a/H00`3:b/X0bl_;0<_;b`030<c<c0030<o?c`3@d=00clo?0080d=3@00X0dm?C0=KFeP3AdM40
e=CD0=KFeP3Hf=P0fm_K0=cLg03Ph>00g]kN0P3MgMd03`3Fe]H0^[Zj06YZJP0X:2P0;2`/02LW9`0[
:b/0<30`038b<P0h>3P0:BTY02d];@0g=cL0?Cdm02/[:`0202HV9P0903Ti>@1/K6`0WYjN09NGU`2D
U9@0QXJ607inOP2;Rh/0S8b<0080UYJF00P0VIVI09>CT`2ATI40TI6A09:BTP2CTi<0UIFE092@T0<0
TI6A00X0TY:B08n?S`2>SXh0SHf=092@T02EUID0S8b<08f=S@2:RXX0SHf=102<S8`02P2:RXX0Rh^;
08b<S02<S8`0RHV908R8R02>SXh0R8R808^;R`26QXH208V9R@0608^;R`29RHT0R8R808>3P`25QHD0
P8200P22PX80101nOWh0PX:208:2PP1jNWX207alO00A07IfMP1iNGT0Ph>30820P02<S8`0U9BD09JF
UP2KVi/0WinO0:2PX02RXZ80Z:RX0;Jf]P2m_Kd0alO70<o?c`3EeMD00P3Hf=P01@3Fe]H0eMGE0=CD
e03GemL0e]KF0080emOG00/0d];B0=?Cd`3?cll0d];B0=3@d03=cLd0a/K60;^k^`2RXZ80SHf=06i^
KP0205QHF00=04e=C@1<C4`0D51@05=CD`1EEED0EUIF05eMG@1SHf<0EUIF05MGE`1LG5`0Fe]K05iN
GP0206UYJ@0806=SH`1[Jf/0K6a/06YZJP1_Kfl0M7Ad075aL@1YJFT206EUI@0:05eMG@1FEUH0FUYJ
05QHF01NGUh0G5aL05iNGP1UIFD0J6QX06EUI@<0IfMW00@0JVYZ06EUI@1[Jf/0IVIV3P38h=P000`0
b>3H0P0V9RH09`0Z:RX0=3@d04=3@`1CDe<0Hf=S06i^KP1hN7P0QXJ609RHV02TY:@0YJFU09nOW`2V
YZH0Zj^[0:NWY`2XZ:P0X:2P09VIV@2@T900QXJ608:2PP1bLW80GUiN03dm?@0];Bd0:2PX02l_;`0j
>SX0Bd];061PH01cLg<0PX:208n?S`2GUiL0WIfM0:6QX@2WYjL0[:b/0;2`/0040;:b/P0S0:n_[`2c
/k<0/[:b0;>c/`2a/K40[Zj^0:n_[`2a/K40];Bd0;Fe]@2c/k<0[Zj^0:RXZ02WYjL0WYjN09bLW02E
UID0TI6A08V9R@2>SXh0^k^k08j>SP23Ph<0Lg=c04U9B@1kNg/0Ogmo02PX:00O7al09RHV024Q8@0[
:b/0:RXZ034a<@0V9RH00P0X:2P04@0f=SH0<30`02DU9@0/;2`0ATI606IVIP1BDU80<S8b02/[:`0Y
:BT0<S8b034a<@0Z:RX0<S8b0410@00`<300>CTi00<0<S8b01@0<30`02l_;`1EEED0Lg=c07inOP1a
LG40De=C02`/;00[:b/0>SXj04i>CP0n?Sh0>c/k02LW9`0U9BD0:2PX02<S8`0Q8B40;2`/04Y:BP80
HV9R00D0@d=303<c<`0V9RH0;Rh^03`l?00206][J`0505MGE`15ADD0>c/k03dm?@1HF5P00P1RHV80
8@1;Bd/0>c/k04i>CP1bLW80Hf=S061PH01IFET0D51@04=3@`0n?Sh0ADE504Y:BP1OGel0GEeM071`
L020P800GUiN055AD@1/K6`0PX:208B4Q020P800LG5a06a/K01eMGD0VIVI09NGU`2^[Zh0YZJV09FE
U@1kNg/0D51@02`/;00202@T900Z02DU9@0c<c<0Hf=S08R8R01YJFT0Cdm?0;Vi^@3Jf]X0WinO030`
<00T92@09BDU02HV9P0T92@08b<S02HV9P0Z:RX0<c<c051@D00l?3`0>SXj03Ph>00_;bl0ADE504A4
A00b<S80<c<c02h^;P0d=3@0=cLg02l_;`0[:b/0;Bd]03De=@0a<C40=3@d03/k>`14A4@0DE5A059B
DP11@D40;bl_0P0d=3@0700k>c/0>3Ph03hn?P0l?3`0:b/[02XZ:P0h>3P0?Cdm03Xj>P0m?Cd0>SXj
059BDP1PH600L71`07=cL`1fMWH0N7Qh07EeM@1]KFd0HF5Q05EEE@0h>3P0;Rh^02PX:00W9bL0?3`l
04];B`1@D50206MWI`0E07EeM@1nOWh0MgMg07UiN@1nOWh0PH6108:2PP27QhL0RHV908F5Q@23Ph<0
PX:208F5Q@24Q8@0PH6108:2PP25QHD0QhN708V9R@28R8P0RHV90080Rh^;00D0TY:B08f=S@2;Rh/0
S8b<092@T00208b<S080SXj>01@0SHf=08b<S02=SHd0SXj>08f=S@2ATI40T92@08^;R`2DU9@0UYJF
09VIV@2EUID0VIVI09NGU`2KVi/0VYZJ09bLW02NWYh0X:2P09nOW`H0XJ6Q00H0Xj>S0:BTY02WYjL0
Z:RX0:^[Z`2][Jd20:ZZZP060:^[Z`2/[:`0[Zj^0;6a/@2_[jl0/k>c0P2e]KD01@2j^[X0]kNg0;Ng
]`2g]kL0^k^k0080_[jn00P0_kno0<30`031`L40`/;20<K6aP35aLD0a/K60<c<c0<0b/[:00<0c<c<
0<g=c@3=cLd00`3AdM402P3>c/h0dM7A0=GEe@3EeMD0e]KF0=GEe@3IfMT0fm_K0>3Ph03QhN420=gM
g@0O0=cLg03;bl/0UIFE03hn?P0T92@09BDU02PX:00^;Rh0>CTi06e]K@0j>SX0:2PX02h^;P0g=cL0
@T9203<c<`0T92@09RHV03Lg=`1/K6`0Xj>S09bLW02>SXh0QXJ608:2PP2=SHd0R8R809:BTP2GUiL0
U9BD09RHV002092@T00309>CT`2ATI40TY:B0080TI6A00l0TY:B09>CT`2CTi<0SXj>09>CT`2ATI40
UYJF09:BTP2?Shl0TY:B08j>SP29RHT0SHf=08j>SP2<S8`00P29RHT03P2?Shl0S8b<08f=S@2=SHd0
QHF508^;R`29RHT0S8b<08V9R@28R8P0Rh^;08V9R@27QhL0Q8B40P25QHD06`21PH40QHF50861P@1n
OWh0Q8B407alO01oOgl0NGUi07inOP1iNGT0PH6108B4Q022PX80QhN708b<S02>SXh0TI6A092@T02A
TI40Shn?09RHV02][Jd0^[Zj0<O7a`3=cLd0e=CD0=OGe`020=WIf@060=GEe@3De=@0e]KF0=KFeP3H
f=P0e]KF0P3De=@30=7Ad@060<g=c@38b<P0_Kfm0:f][@2GUiL0M7Ad0P1MGEd0:P1<C4`0Bd];04];
B`1=CDd0F5QH05EEE@1NGUh0H61P05mOG`1IFET0EUIF05MGE`1QHF40IVIV06EUI@1TI6@0HV9R06EU
I@1VIVH0K6a/07=cL`1eMGD0KVi^071`L01YJFT0H61P069RHP1KFe/0F5QH05iNGP1JFUX0GEeM05iN
GP1UIFD0IVIV06QXJ01WIfL0JFUY06][J`1YJFT0JVYZ06ATI0h0b>3H000<0<SPf0809BDU0280;Rh^
03Ti>@1?Cdl0GEeM06i^KP1cLg<0Ogmo08f=S@2IVIT0Xj>S0:BTY02RXZ80YJFU0:RXZ02YZJT0Y:BT
09jNWP2DU9@0TI6A08B4Q01mOGd0L71`05MGE`0j>SX0:BTY028R8P0`<300@D51059BDP1MGEd0LG5a
0861P@2=SHd0UiNG0P2OWil0102VYZH0[Jf]0:f][@2^[Zh20;:b/P030;Fe]@2f][H0/k>c00<0/[:b
00P0/;2`0;>c/`2c/k<0];Bd0:n_[`2][Jd0[Zj^0:RXZ080XZ:R01@0WIfM09JFUP2ATI40SHf=0:NW
Y`3GemL0WYjN06m_K`1SHf<0ATI605]KF`1SHf<0;bl_02DU9@0];Bd09BDU02TY:@0_;bl0;Rh^02XZ
:P80:b/[00/0<C4a03Lg=`0_;bl0;Rh^034a<@1DE5@0IfMW03Hf=P0a<C40<S8b03@d=00202h^;P06
04E5A@0m?Cd0<c<c03Lg=`0b<S80;bl_0P0Z:RX06P0c<c<0DE5A06UYJ@1nOWh0KFe]04a<C00b<S80
:RXZ03dm?@1HF5P0@41003/k>`0[:b/092@T02TY:@0U9BD09bLW03dm?@1QHF40KVi^05ADE00l?3`0
;Bd]02LW9`0Z:RX0>c/k0P1ZJVX0301?Cdl0@41003Ti>@1BDU80KVi^065QH@16ATH0<S8b04=3@`1N
GUh0IVIV05mOG`80De=C03/0AdM70410@00k>c/0FEUI05]KF`1SHf<0GemO07EeM@20P800G5aL055A
D@1[Jf/0MWIf075aL@21PH40QXJ607MgM`1iNGT0Xj>S0:RXZ02`/;00X:2P09BDU01eMGD0DE5A02/[
:`0W9bL09RHV02TY:@1@D500X:2P096AT@1>CTh0Cdm?0;Ng]`3Cdm<0RXZ:02PX:00T92@08R8R020P
800R8R80820P02DU9@0T92@0=cLg051@D00l?3`0BTY:04A4A00c<c<0@D5104M7A`0d=3@0<30`03@d
=00h>3P0<c<c02TY:@0202/[:`0902d];@0[:b/0<30`03Lg=`17AdL0C4a<04A4A00j>SX0=cLg00<0
>3Ph00P0;Bd]03hn?P0n?Sh0;Bd]02l_;`0^;Rh0@D5103/k>`80=cLg00H0Cdm?061PH01XJ6P0MWIf
07QhN01nOWh2075aL@0D06a/K01ADE40<S8b02HV9P0Y:BT0:2PX04m?C`19BDT0De=C06IVIP1SHf<0
Jf][07]kN`1fMWH0OWin07alO01nOWh0PX:208N7Q`29RHT308F5Q@0408Z:RP25QHD0QXJ608:2PP@0
RHV900D0QhN708f=S@29RHT0SXj>08f=S@0208j>SP0308f=S@2>SXh0Shn?00<0SXj>0180RHV908b<
S02<S8`0Rh^;092@T02?Shl0SXj>092@T02JVYX0U9BD09FEU@2IVIT0V9RH09VIV@2HV9P0W9bL09^K
V`2NWYh20:2PX00:0:6QX@2RXZ80XZ:R0::RXP2QXJ40Xj>S0:FUY@2WYjL0Z:RX0:b/[080Z:RX00P0
/;2`0:b/[02_[jl0[Jf]0;6a/@2b/[80/;2`0;Bd]080][Jf00P0]kNg0;^k^`2k^k/0_Kfm0;no_`30
`<00_[jn0<;2`P80a<C400D0alO70<W9b@39bLT0b<S80<W9b@040<c<c0060<k>cP3AdM40clo?0<o?
c`3AdM40dm?C0P3Fe]H09`3GemL0e]KF0=WIf@3IfMT0gMgM0=kNgP3MgMd0g=cL0=?Cd`2d];@0IVIV
034a<@0V9RH09bLW02l_;`0^;Rh0<c<c03dm?@0k>c/0;Rh^02d];@0c<c<0ATI603De=@0U9BD09RHV
03Ti>@1QHF40WinO0::RXP2>SXh0S8b<08:2PP2:RXX0SXj>092@T02<S8`0UYJF09:BTP0209NGU`0>
09>CT`2>SXh0U9BD09BDU02?Shl0TI6A08n?S`2ATI40SXj>09:BTP2?Shl0T92@09>CT`2<S8`208j>
SP0908^;R`2BTY80TY:B08b<S02=SHd0Rh^;08b<S02@T900Rh^;0080RXZ:0P2<S8`06P29RHT0R8R8
08N7Q`29RHT0T92@08F5Q@26QXH0QHF508R8R022PX80Ogmo07inOP25QHD0PX:20820P02:RXX0OGem
07moO`1mOGd0PH6108B4Q028R8P0QXJ608V9R@28R8P0Rh^;0P2:RXX03P26QXH0RXZ:0:NWY`2g]kL0
alO70<c<c03Cdm<0emOG0=WIf@3Hf=P0eMGE0=?Cd`3De=@0eMGE0P3Hf=P02`3EeMD0e=CD0=?Cd`3B
d]80dM7A0<o?c`39bLT0_kno0;>c/`2OWil0QHF50080JVYZ00<0EUIF04U9B@18B4P00P1@D500201C
De<0E5AD05]KF`1PH600GUiN05MGE`1HF5P0GUiN0P1SHf<01P1QHF40GemO06=SH`1VIVH0JVYZ071`
L080LW9b01<0Lg=c06m_K`1/K6`0HF5Q05iNGP1JFUX0EeMG065QH@1KFe/0GemO05aLG01QHF40IFEU
06=SH`1WIfL0J6QX06a/K01TI6@0IVIV00h0b>3H000<0<SPf080:2PX00/0=3@d04M7A`1DE5@0I6AT
07EeM@1kNg/0PH6108b<S02EUID0WinO0:FUY@020:>SX`0K0:FUY@2XZ:P0Xj>S09fMW@2GUiL0SHf=
08J6QP1iNGT0Jf][05QHF00l?3`0:b/[02XZ:P0d=3@0@D5105EEE@1QHF40MGEe08:2PP2:RXX0UYJF
09ZJVP2RXZ80YjNW0:RXZ02_[jl0];Bd0080/k>c00D0/K6a0;2`/02_[jl0/;2`0;:b/P020;6a/@05
0;>c/`2f][H0/K6a0;6a/@2d];@00P2/[:`0502SXj<0X:2P09RHV02DU9@0TY:B08V9R@2m_Kd0f][J
08n?S`1]KFd0LW9b04Q8B01=CDd0DE5A03Lg=`0_;bl0:2PX02`/;00[:b/0:2PX0P0];Bd202HV9P0_
02XZ:P0j>SX0;2`/034a<@0Z:RX0A4A406MWI`11@D40<C4a02`/;00c<c<0?3`l02l_;`0^;Rh0=3@d
03Xj>P0a<C40;Bd]02/[:`0];Bd09bLW02d];@1@D500I6AT07IfMP1/K6`0Bd];02/[:`0Y:BT0Cdm?
05YJFP1<C4`0=cLg02PX:00[:b/09bLW02@T900Y:BT0CDe=07IfMP1VIVH0@T9203<c<`0V9RH0:BTY
02XZ:P1<C4`00P1RHV805@1>CTh0BDU904a<C01MGEd0IFEU04U9B@0i>CT0?Shn04M7A`1KFe/0F5QH
05mOG`1:BTX0@41004a<C00o?cl0@d=306i^KP1YJFT0GemO05YJFP0207emO@0V06QXJ01SHf<0Kfm_
06][J`1]KFd0OGem096AT@2<S8`0N7Qh0:2PX02YZJT0[jn_09ZJVP2;Rh/0PX:205mOG`0`<30092@T
02XZ:P0f=SH0T92@0;jn_P1oOgl0@T92055AD@36a/H0dM7A075aL@0W9bL08B4Q02<S8`0U9BD09bLW
02DU9@0T92@09bLW030`<01HF5P203`l?0070492@P0b<S80?clo0451@@0`<300<C4a03De=@0203@d
=00:02`/;00d=3@0:RXZ034a<@0f=SH0;Rh^03Ph>00i>CT0?Shn04A4A080=cLg0P0n?Sh0<P0h>3P0
=3@d03<c<`0c<c<09bLW02d];@0b<S80@T9204Y:BP0k>c/0=CDe04e=C@1HF5P0Kfm_07EeM@1lO7`0
MWIf075aL@1[Jf/0Hf=S04];B`0f=SH0;Bd]02TY:@0^;Rh0BTY:04i>CP1FEUH0I6AT06a/K01PH600
MGEe06i^KP1jNWX0O7al07moO`20P800QXJ608N7Q`23Ph<0Q8B408:2PP21PH40Ph>308J6QP27QhL0
QXJ608N7Q`2:RXX0S8b<0`2>SXh03P2?Shl0S8b<08b<S02:RXX0R8R808f=S@2<S8`0RXZ:08b<S02;
Rh/0SHf=08j>SP2ATI40Rh^;0P2>SXh01@2DU9@0T92@096AT@2FUYH0V9RH00<0UIFE00L0UiNG09RH
V02LW9`0WinO0:2PX02NWYh0XZ:R0080X:2P00<0YJFU0::RXP2VYZH00P2WYjL04P2XZ:P0Zj^[0:j^
[P2/[:`0[Zj^0;:b/P2/[:`0/[:b0;6a/@2d];@0/[:b0;6a/@2e]KD0][Jf0;fm_@2i^KT0^[Zj0;^k
^`80_kno00@0_;bl0<;2`P33`l<0`l?30`36a/H20<W9b@060<_;b`3=cLd0b/[:0<c<c03>c/h0clo?
0P3Bd]806P3AdM40d];B0=KFeP3Fe]H0emOG0=_Kf`3IfMT0f][J0=cLg03Ng]h0g=cL0=SHf031`L40
P82004Y:BP0/;2`0:2PX02XZ:P0`<300=3@d030`<00l?3`0=SHf02l_;`0^;Rh0=CDe0P10@4003`0U
9BD0:RXZ03De=@1PH600VYZJ0:BTY02CTi<0RHV90861P@28R8P0SXj>09:BTP2:RXX0U9BD09>CT`02
092@T00A096AT@2@T900Ti>C092@T02HV9P0Shn?08f=S@2@T900TI6A09:BTP2@T900TY:B09BDU02@
T900TI6A08b<S02ATI400P2>SXh04@2<S8`0Shn?096AT@2?Shl0SHf=08Z:RP2;Rh/0RHV908Z:RP2;
Rh/0S8b<08Z:RP28R8P0QhN708Z:RP2;Rh/0QXJ60080QHF50100PH6108J6QP1lO7`0O7al07moO`20
P800Ph>307YjNP1lO7`0Ogmo08>3P`25QHD0R8R808F5Q@29RHT0R8R80P27QhL02@2;Rh/0P82008J6
QP2LW9`0];Bd0<;2`P3>c/h0d];B0=OGe`020=WIf@060=OGe`3Fe]H0eMGE0=KFeP3GemL0f=SH0P3D
e=@20=GEe@070=;BdP3=cLd0b<S80<71`@2i^KT0Y:BT08b<S00207EeM@0N061PH01@D500CTi>04i>
CP1BDU80D51@05EEE@1JFUX0IFEU061PH01OGel0EeMG05eMG@1SHf<0HV9R06ATI01RHV80I6AT06EU
I@1XJ6P0KFe]075aL@1eMGD0MWIf07MgM`1^KVh0JFUY069RHP1MGEd0F5QH0P1MGEd01P1OGel0G5aL
065QH@1PH600JFUY06YZJP<0JFUY00<0J6QX0<SPf038h=P03038h=P000`0b>3H0P0c<c<0:00h>3P0
Cdm?061PH01YJFT0MWIf07alO026QXH0QhN709:BTP2MWId0Xj>S0:NWY`2SXj<0YJFU0:BTY02QXJ40
VIVI09>CT`29RHT0Ph>307MgM`1WIfL0EEEE03De=@0Z:RX09RHV03De=@12@T80De=C05eMG@1]KFd0
PH6108^;R`2CTi<0WIfM09nOW`2WYjL0ZZZZ0;6a/@2c/k<20;Bd]0030;:b/P2_[jl0/[:b0080[jn_
0`2a/K406`2b/[80];Bd0;>c/`2^[Zh0[jn_0:^[Z`2SXj<0WIfM09VIV@2PX:00T92@08j>SP2o_kl0
aLG507YjNP1mOGd0PX:204e=C@1DE5@0?clo02`/;00Y:BT0:RXZ02PX:00Z:RX0:2PX03<c<`0402/[
:`0@03Hf=P0/;2`0;Rh^02h^;P0k>c/0GemO04i>CP0c<c<0;bl_030`<00k>c/0?3`l03De=@0h>3P0
=CDe034a<@80;2`/01`0;bl_02TY:@0`<300BTY:061PH01_Kfl0K6a/05YJFP0d=3@0;2`/04m?C`1C
De<0ATI602h^;P0W9bL0:2PX02/[:`0W9bL0<c<c059BDP1fMWH0De=C034a<@0W9bL0<30`02XZ:P0a
<C40De=C0P1MGEd0E01<C4`0E5AD05YJFP1UIFD0@d=3034a<@0h>3P0@T9204m?C`1>CTh0C4a<04];
B`19BDT0AdM705EEE@13@d<0Fe]K07AdM01XJ6P0GUiN05QHF01iNGT0MgMg07UiN@1cLg<0MGEe06m_
K`1gMgL0M7Ad09FEU@2>SXh0OGem08j>SP2TY:@0YjNW092@T01lO7`0Rh^;06YZJP10@400;2`/03/k
>`1VIVH0`/;20:j^[P1JFUX0>c/k05EEE@3@d=00c/k>06IVIP0/;2`0:2PX02DU9@0V9RH0:b/[02DU
9@0Z:RX0;Rh^03Lg=`1IFET0@T9203dm?@10@400=SHf03Xj>P14A4@0=SHf03Lg=`0h>3P0=SHf03Ti
>@0c<c<0;Bd]038b<P0f=SH0=CDe03Xj>P0e=CD0?Shn0451@@14A4@0>c/k03De=@<0?3`l00H0=SHf
03De=@0^;Rh0:b/[02l_;`0g=cL204U9B@0]03hn?P0o?cl0ADE505ADE01YJFT0Kfm_07YjNP1hN7P0
Lg=c06UYJ@1QHF40BDU903<c<`0_;bl0:b/[034a<@1@D500E5AD05IFEP1RHV80Lg=c06QXJ01cLg<0
IfMW07EeM@20P800OWin08F5Q@2=SHd0RXZ:08J6QP24Q8@0OWin0861P@24Q8@0QhN708R8R02:RXX0
R8R808V9R@2:RXX0SHf=08^;R`26QXH0SXj>0080SHf=00D0RHV908Z:RP2=SHd0Rh^;08Z:RP0208^;
R`0608b<S02?Shl0T92@08f=S@2>SXh0T92@0P2ATI403@2@T900UIFE09JFUP2IVIT0V9RH09VIV@2H
V9P0WIfM09bLW02QXJ40YJFU09jNWP2RXZ800P2PX:000`2SXj<0XZ:R0:FUY@020:FUY@080:NWY`2[
Zj/0[Zj^0:n_[`2ZZZX0[Jf]0;2`/02b/[820;Fe]@080;>c/`2_[jl0][Jf0;Vi^@2n_[h0^KVi0;Zj
^P2l_;`20;no_`080;fm_@31`L40a<C40<G5a@36a/H0`/;20<K6aP3:b/X40<c<c0070<o?c`3@d=00
dM7A0=?Cd`3AdM40e=CD0=GEe@020=KFeP80emOG02D0fMWI0=cLg03Ng]h0gMgM0=_Kf`3@d=00Vi^K
05ADE00f=SH0<30`02d];@0/;2`0<30`03<c<`0l?3`0A4A403`l?00`<300<c<c03Ph>014A4@0@D51
02`/;00Y:BT0=CDe059BDP2BTY80ZJVY09NGU`2:RXX0QXJ608V9R@2;Rh/0SHf=092@T02CTi<0U9BD
0080TY:B01/0UYJF09>CT`2EUID0UIFE09BDU02BTY80U9BD09>CT`2BTY80T92@08Z:RP2@T900UYJF
09BDU02?Shl0T92@08j>SP2=SHd0TI6A09:BTP2>SXh0S8b<08n?S`2>SXh0S8b<092@T027QhL00P2<
S8`00`29RHT0RXZ:08:2PP0208R8R00808^;R`25QHD0PX:20820P022PX80Ph>307moO`20P8020861
P@0J08B4Q01oOgl0OWin07emO@22PX80QXJ608f=S@2<S8`0RHV908f=S@2;Rh/0R8R807moO`23Ph<0
P82009JFUP2a/K40`L710<_;b`3Bd]80e]KF0=WIf@3Kfm/0eMGE0=KFeP3Cdm<60=CDe0080=KFeP3A
dM40c/k>0<c<c035aLD0_;bl0:VYZ@2EUID208F5Q@0?06YZJP1GEeL0BDU904A4A016ATH0BTY:059B
DP1NGUh0HF5Q05iNGP1MGEd0FEUI05QHF01MGEd0I6AT0080GUiN00L0GEeM06=SH`1TI6@0JVYZ06a/
K01`L700LW9b0080M7Ad00<0Lg=c06UYJ@1SHf<00P1OGel02`1MGEd0GemO05]KF`1LG5`0HV9R06IV
IP1ZJVX0IFEU06ATI01VIVH0IFEU00h0b>3H000<0<SPf080?3`l02P0ADE505MGE`1ZJVX0LW9b07in
OP22PX80RHV908b<S02CTi<0VYZJ0:>SX`2UYJD0XZ:R0:>SX`2TY:@0WYjN09JFUP2?Shl0Q8B40861
P@1dM7@0HF5Q04Q8B00b<S80;Bd]02`/;00e=CD0@41005=CD`1RHV80MGEe0820P02<S8`0V9RH09jN
WP2PX:00YJFU0:ZZZP2_[jl0/k>c0P2g]kL0202`/;00/K6a0;2`/02a/K40[:b/0;2`/02a/K40/;2`
0P2d];@04P2e]KD0/K6a0:n_[`2WYjL0Y:BT0:2PX02KVi/0UYJF08n?S`2<S8`0^;Rh0:^[Z`1dM7@0
NWYj07MgM`13@d<0EUIF03Lg=`80:RXZ00D0:BTY02XZ:P0W9bL0:BTY03De=@0302LW9`0=02XZ:P0f
=SH0;bl_02l_;`0W9bL0;Bd]04E5A@1MGEd0@410030`<00^;Rh0>3Ph03/k>`0203Ti>@0503<c<`0_
;bl0;Rh^02`/;00[:b/00P0Z:RX06@0o?cl0HV9R06m_K`1UIFD0I6AT03Xj>P0h>3P0Bd];04U9B@12
@T80;2`/02TY:@0a<C40:RXZ02TY:@0g=cL0Hf=S06ATI010@4009bLW02DU9@0/;2`0;Rh^03`l?01@
D5000P1SHf<0@`1UIFD0EeMG065QH@19BDT0;Rh^02l_;`12@T80@d=3051@D017AdL0Bd];04M7A`16
ATH0BTY:05EEE@16ATH0Kfm_07QhN01TI6@0FUYJ05QHF01fMWH0PH6109BDU025QHD0O7al0861P@1j
NWX0Ph>309FEU@28R8P0MgMg08b<S02JVYX0UIFE07alO01GEeL0PX:207UiN@1?Cdl0;Rh^03dm?@2[
Zj/0a/K608J6QP0h>3P0=3@d06ATI03Jf]X0^k^k04i>CP0Y:BT08b<S02HV9P0[:b/0<30`02@T900U
9BD0:RXZ03Lg=`1MGEd0@D5103Xj>P0l?3`0=CDe03Ph>010@4000P0c<c<01`0`<300<S8b03Lg=`0_
;bl0:b/[034a<@0e=CD00P0c<c<01P0f=SH0>c/k0451@@1>CTh0?clo02l_;`80<30`0380<C4a03@d
=00Z:RX0;2`/02HV9P0];Bd0=3@d04U9B@1:BTX0?Cdm0451@@12@T80G5aL06IVIP1cLg<0MWIf07em
O@1_Kfl0JVYZ05iNGP11@D40;Bd]030`<00Y:BT0;bl_04U9B@1ADE40EeMG05iNGP1iNGT0Lg=c07em
O@1UIFD0IVIV07QhN01eMGD0PH6108Z:RP27QhL0R8R808J6QP1nOWh0Ogmo0861P@27QhL0R8R808^;
R`26QXH0RXZ:08R8R080Rh^;00P0QhN708b<S02?Shl0S8b<08Z:RP2;Rh/0RXZ:08V9R@80S8b<00T0
RHV908n?S`2>SXh0Shn?096AT@2@T900SXj>08f=S@2CTi<00P2EUID02`2FUYH0U9BD09ZJVP2JVYX0
W9bL09nOW`2MWId0WinO0:FUY@2NWYh0XZ:R0080Xj>S00X0YJFU0:JVYP2UYJD0YjNW0:FUY@2[Zj/0
[Jf]0;:b/P2^[Zh0[Jf]0`2^[Zh03P2_[jl0/k>c0;Fe]@2h^;P0]KFe0;Jf]P2j^[X0];Bd0;Ng]`2m
_Kd0`/;20<71`@30`<00`/;20P33`l<01037alL0a/K60<O7a`3<c<`20<g=c@030<c<c03=cLd0c/k>
0080dM7A00@0dm?C0=7Ad@3Bd]80dm?C0P3Fe]H0103GemL0fMWI0=[JfP3Jf]X20=cLg00B0=?Cd`2a
/K40K6a/0451@@0f=SH0;Bd]02XZ:P0X:2P0<c<c02`/;00k>c/0@T9204E5A@0c<c<0=SHf03lo?`15
ADD0?Shn0P0V9RH03@0`<300BDU908b<S02^[Zh0Vi^K08V9R@27QhL0Rh^;08N7Q`2FUYH0U9BD08n?
S`2EUID00P2?Shl01`2BTY80Shn?09FEU@2CTi<0SHf=09BDU02BTY800`2ATI401P2>SXh0Ti>C096A
T@2?Shl0SXj>08b<S0<0T92@0P2=SHd0102@T900TI6A08b<S02;Rh/208f=S@0F08^;R`2:RXX0RHV9
08^;R`26QXH0QHF508N7Q`23Ph<0QXJ608V9R@1oOgl0PX:207inOP24Q8@0PH6108F5Q@1mOGd0OWin
07emO@1oOgl0OGem0820P080QHF50140R8R808f=S@2>SXh0R8R808N7Q`1nOWh0OGem07alO02<S8`0
[jn_0;no_`39bLT0bl_;0=GEe@3GemL0f=SH0=OGe`020=CDe00>0=GEe@3GemL0eMGE0=OGe`3De=@0
eMGE0=?Cd`3Bd]80clo?0<c<c039bLT0`<300;:b/P2LW9`208b<S00907]kN`1RHV80E5AD04I6AP17
AdL0ADE504e=C@1KFe/0GemO0080Hf=S01P0GEeM05ADE01KFe/0GEeM05mOG`1RHV80GemO065QH@1T
I6@0Hf=S06EUI@1ZJVX0KFe]07AdM01`L700Kfm_06e]K@1ZJVX0I6AT06EUI@1RHV80Fe]K05mOG`1H
F5P205mOG`80HV9R0P1WIfL00`1XJ6P0b>3H0<SPf00<0<SPf0003038h=P204M7A`0X04i>CP1NGUh0
KVi^07QhN01nOWh0Q8B408V9R@2@T900V9RH09NGU`2OWil0XZ:R09nOW`2PX:00XJ6Q0::RXP2MWId0
SHf=08N7Q`1kNg/0KVi^05QHF018B4P0<C4a02TY:@0[:b/0=cLg04E5A@1GEeL0HF5Q071`L01jNWX0
RHV909NGU`2MWId0XJ6Q0:FUY@2[Zj/0/K6a0;:b/P80/K6a00L0[jn_0;:b/P2_[jl0[jn_0;6a/@2]
[Jd0[jn_0080/k>c01@0]kNg0;:b/P2][Jd0ZZZZ0:VYZ@2WYjL0X:2P09ZJVP2CTi<0T92@08f=S@2/
[:`0YZJV092@T01aLG40I6AT0410@01=CDd0FEUI02PX:0<09RHV00T0<S8b030`<00_;bl0;Rh^02LW
9`0[:b/0;Rh^03<c<`0b<S800P0^;Rh0:P0];Bd0=cLg04I6AP13@d<0=3@d03<c<`0i>CT0@D5103lo
?`0`<300:RXZ02/[:`0b<S80;2`/02d];@0T92@0;Rh^03<c<`1?Cdl0IfMW06IVIP1NGUh0@D5103Hf
=P10@400?Cdm03Ph>00V9RH09BDU02XZ:P0];Bd0;2`/03Ti>@1^KVh0G5aL03`l?00[:b/09BDU02PX
:00];Bd0?Cdm055AD@80KVi^0400KFe]06IVIP1FEUH0;bl_02/[:`0j>SX0@D5104];B`1=CDd0C4a<
051@D018B4P0?Shn04U9B@1<C4`0Hf=S07IfMP1dM7@0IFEU05MGE`1ADE40LW9b08^;R`2GUiL0RXZ:
0820P01oOgl0QHF50861P@2<S8`0R8R807=cL`2:RXX0TI6A08n?S`1/K6`0>c/k06UYJ@1mOGd0D51@
03Ph>01TI6@0`l?30;2`/01EEED0;Rh^03@d=01aLG40dm?C0:6QX@0g=cL092@T02PX:00V9RH092@T
02d];@0X:2P09BDU02d];@0l?3`0HF5Q04U9B@0j>SX0?3`l0P0f=SH02P14A4@0=3@d038b<P0^;Rh0
=3@d03/k>`0Z:RX0;Bd]02h^;P0a<C42038b<P0603De=@11@D40A4A404U9B@13@d<0>3Ph0P0e=CD0
;@0c<c<0;Bd]02h^;P0b<S80;2`/02h^;P0g=cL0@d=304Y:BP12@T80Bd];03Ti>@1>CTh0GEeM06UY
J@1eMGD0Ng]k06][J`1/K6`0G5aL0492@P0[:b/0<S8b02XZ:P0`<300CTi>05IFEP1KFe/0K6a/07Yj
NP1`L700Ogmo079bLP1ZJVX0KFe]06a/K01iNGT0Q8B408N7Q`29RHT0Ph>30820P01nOWh0Q8B408Z:
RP0208V9R@0K08f=S@2<S8`0RHV908n?S`2<S8`0Rh^;08Z:RP2>SXh0RHV908b<S028R8P0RHV908f=
S@2;Rh/0SHf=08R8R027QhL0Rh^;096AT@2@T900TI6A08f=S@2?Shl0TI6A09BDU02FUYH0V9RH0080
UYJF00P0V9RH09^KV`2QXJ40Xj>S09jNWP2QXJ40X:2P0:6QX@<0XZ:R00D0YJFU0:ZZZP2YZJT0ZZZZ
0:f][@020;6a/@0A0:b/[02[Zj/0[jn_0;6a/@2`/;00];Bd0:n_[`2c/k<0]KFe0;Rh^02g]kL0^KVi
0;Fe]@2k^k/0_[jn0<30`032`/800P33`l<20<K6aP040<[:bP39bLT0bl_;0<W9b@80c<c<00H0clo?
0=3@d03@d=00clo?0=?Cd`3De=@20=?Cd`030=KFeP3Jf]X0fMWI0080fMWI0P3Jf]X07`3Lg=`0f=SH
0<71`@1nOWh0?3`l03Ti>@0`<300;Rh^02TY:@0[:b/0<c<c03@d=00l?3`0ATI604=3@`0d=3@0>CTi
03dm?@0n?Sh0?3`l02d];@0V9RH0<30`0451@@23Ph<0[jn_09nOW`2;Rh/0SHf=08j>SP29RHT00P2A
TI403`2DU9@0UYJF09BDU02DU9@0UYJF09FEU@2ATI40U9BD096AT@2CTi<0T92@09JFUP2BTY80TI6A
08j>SP0209:BTP0:08j>SP2<S8`0Rh^;08f=S@2ATI40SHf=08n?S`29RHT0S8b<092@T080RXZ:00d0
SHf=08^;R`2=SHd0R8R808Z:RP23Ph<0Q8B408R8R02:RXX0Ph>308B4Q026QXH0QHF50080Ogmo00/0
PX:207inOP1iNGT0OGem07inOP1oOgl0OGem07alO021PH40Ph>308N7Q`0208Z:RP80QhN70P20P800
2@1kNg/0O7al08J6QP2XZ:P0_[jn0<S8b03>c/h0dm?C0=GEe@020=KFeP030=?Cd`3De=@0e=CD0080
emOG0P3EeMD20=CDe0070=?Cd`3AdM40cLg=0<[:bP2o_kl0][Jf0:6QX@0209NGU`0@08>3P`1_Kfl0
FEUI04Y:BP12@T80@41004a<C01>CTh0EUIF065QH@1SHf<0H61P05YJFP1IFET0F5QH05aLG080Fe]K
00T0GEeM05mOG`1SHf<0I6AT06YZJP1`L700KVi^06YZJP1_Kfl00P1^KVh00`1ZJVX0I6AT05mOG`02
05iNGP0605UIF@1DE5@0FUYJ061PH01RHV80IfMW0P1XJ6P>0<SPf0003038h=P205UIF@0X05iNGP1W
IfL0NGUi07moO`24Q8@0R8R809>CT`2ATI40U9BD09bLW02MWId0X:2P09^KV`2JVYX0W9bL09nOW`2H
V9P0SHf=0861P@1eMGD0I6AT04m?C`12@T80=CDe02d];@0/;2`0<C4a04];B`1FEUH0IFEU07=cL`21
PH40QhN709BDU02IVIT0X:2P0:JVYP2ZZZX0[:b/0;:b/P80/;2`00P0];Bd0;2`/02a/K40/K6a0;2`
/02a/K40/[:b0:j^[P80/[:b03P0]KFe0;6a/@2a/K40ZZZZ0:FUY@2SXj<0Vi^K09JFUP2;Rh/0SHf=
0:FUY@2l_;`0^;Rh06a/K01LG5`0@d=306MWI`2EUID0>SXj02HV9P0U9BD09RHV02DU9@0[:b/0<S8b
02XZ:P0/;2`0<C4a02l_;`0f=SH0;bl_02PX:00^;Rh0<30`02l_;`14A4@0BDU903Ph>00i>CT0A4A4
04Q8B00l?3`0<S8b02l_;`0];Bd0=SHf03@d=00];Bd0:b/[02TY:@0g=cL0AdM706EUI@1TI6@0De=C
03lo?`80=cLg00D0=SHf034a<@0V9RH0:BTY02XZ:P0202/[:`0:0410@01SHf<0CTi>030`<00S8b<0
9BDU02PX:00i>CT0ADE505aLG080LW9b05<0J6QX05]KF`0g=cL0;bl_030`<012@T80?clo03hn?P12
@T80BDU905IFEP1<C4`0@D5104E5A@1KFe/0NWYj079bLP1WIfL0G5aL05EEE@1CDe<0MgMg08N7Q`2?
Shl0Rh^;08:2PP21PH40R8R80861P@1oOgl0L71`06QXJ02=SHd0RXZ:08b<S01QHF40Cdm?06][J`1m
OGd0GemO051@D01iNGT0[:b/0820P00b<S80;Rh^03De=@2<S8`0aLG507IfMP0f=SH0;Rh^02/[:`0]
;Bd0:BTY02`/;00X:2P09bLW02`/;00o?cl0HV9R04E5A@0o?cl0>CTi0410@00l?3`0?clo030`<00d
=3@0;Bd]030`<00g=cL0<S8b034a<@0[:b/0<S8b03/k>`0f=SH0?Shn03Xj>P0l?3`0De=C03hn?P03
03Ph>00903Ti>@0_;bl0<30`030`<00^;Rh0=3@d03Ph>012@T80ATI60080@d=300@0?clo04];B`1L
G5`0JFUY0P1fMWH09P1WIfL0I6AT051@D00f=SH0:RXZ030`<00[:b/0=SHf055AD@1<C4`0EeMG071`
L01jNWX0MWIf07inOP1dM7@0LW9b075aL@1/K6`0KFe]07]kN`20P800Ph>30820P023Ph<0P82008V9
R@26QXH0R8R808b<S02>SXh0SHf=08Z:RP2<S8`0R8R808V9R@2CTi<0RXZ:0P2;Rh/05@28R8P0TY:B
08R8R028R8P0SXj>09:BTP2<S8`0RHV9092@T02>SXh0Rh^;092@T02=SHd0UYJF09>CT`2EUID0UiNG
09^KV`2HV9P0Vi^K09nOW`020:6QX@0409nOW`2NWYh0Xj>S0:BTY080YJFU00X0Xj>S0:NWY`2VYZH0
YjNW0:f][@2`/;00[jn_0;2`/02^[Zh0[jn_0P2a/K402`2_[jl0^;Rh0;Fe]@2c/k<0]kNg0;Zj^P2f
][H0]kNg0;Rh^02k^k/0_Kfm0080`/;200@0a/K60<C4a034a<@0alO70P3:b/X02P3;bl/0bLW90<g=
c@3>c/h0cLg=0=3@d03Bd]80d=3@0=7Ad@3EeMD20=?Cd`80e]KF0P3GemL04P3IfMT0f=SH0=_Kf`3H
f=P0bLW9096AT@17AdL0<C4a03Xj>P0`<300:RXZ02LW9`0];Bd0<c<c038b<P0o?cl0C4a<0492@P80
?3`l0180@d=303Ti>@15ADD0<30`02HV9P0`<300@41007alO02][Jd0WYjN08b<S02;Rh/0SHf=08Z:
RP2@T900UIFE09JFUP2DU9@209VIV@0S09RHV02DU9@0Ti>C092@T02<S8`0TI6A08f=S@2ATI40Shn?
09:BTP2:RXX0T92@08j>SP29RHT0Shn?08b<S02=SHd0SXj>092@T02<S8`0SXj>08f=S@2@T900RXZ:
08b<S02:RXX0SHf=08^;R`2:RXX0QhN708>3P`26QXH0QHF508J6QP28R8P00P25QHD00`26QXH0Ogmo
07inOP020861P@0;08:2PP1hN7P0O7al07inOP1jNWX0OWin07emO@1oOgl0Q8B408N7Q`2;Rh/00P24
Q8@207moO`0;07YjNP1iNGT0Ph>30::RXP2h^;P0aLG50<_;b`3@d=00e=CD0=SHf03EeMD00P3De=@0
1P3Fe]H0emOG0=CDe03GemL0f=SH0=GEe@80e]KF00H0dM7A0<g=c@38b<P0`/;20;Rh^02_[jl20:>S
X`0908n?S`1kNg/0I6AT055AD@10@400?3`l03lo?`1<C4`0DE5A0080GemO00l0H61P05aLG01NGUh0
F5QH05UIF@1KFe/0GEeM05YJFP1LG5`0GEeM069RHP1UIFD0KFe]06YZJP1aLG400P1_Kfl01P1/K6`0
J6QX06MWI`1OGel0G5aL06=SH`80G5aL00H0H61P05eMG@1UIFD0JVYZ06MWI`1VIVH>0<SPf0003038
h=P206MWI`0X06][J`1`L700Ng]k08>3P`28R8P0S8b<08f=S@2@T900U9BD09^KV`2HV9P0WIfM09VI
V@2CTi<0TI6A09FEU@2BTY80R8R80820P01`L700IFEU051@D012@T80=3@d02XZ:P0_;bl0=SHf04Q8
B01HF5P0IFEU071`L01mOGd0QXJ609>CT`2HV9P0WYjN0:BTY02/[:`0/;2`0;6a/@80[jn_0P2a/K40
;02][Jd0/[:b0:j^[P2`/;00[jn_0:f][@2_[jl0]KFe0;6a/@2^[Zh0[:b/0:RXZ02RXZ80X:2P09bL
W02DU9@0S8b<08j>SP2^[Zh0d=3@0;no_`1WIfL0CTi>04e=C@2=SHd0aLG504m?C`0T92@0:BTY02@T
900];Bd0:BTY02h^;P0];Bd0;2`/03@d=00c<c<0=SHf034a<@0/;2`0=3@d034a<@11@D40CDe=0P17
AdL05`11@D40@T920451@@0d=3@0<C4a03De=@0f=SH0=cLg03/k>`0d=3@0;2`/034a<@0d=3@0AdM7
05EEE@1MGEd0BDU904I6AP11@D40>CTi03Lg=`0b<S8092@T00<0:b/[00@0;Bd]03lo?`1<C4`0=CDe
0P0/;2`203@d=00304M7A`1BDU80IfMW0080MGEe00/0Fe]K03De=@0_;bl0<c<c03/k>`17AdL0A4A4
03lo?`18B4P0AdM705EEE@0204U9B@0W04];B`1_Kfl0MWIf06IVIP1PH600EUIF04m?C`1MGEd0MWIf
08R8R02?Shl0SHf=08>3P`29RHT0QHF50820P01nOWh0I6AT06UYJ@2=SHd0PX:208Z:RP1eMGD0KVi^
06=SH`1iNGT0NWYj07alO02GUiL0S8b<05aLG00`<300<S8b0410@02YZJT0[jn_05MGE`0^;Rh0<30`
0080<S8b01P0<30`02d];@0c<c<0;2`/038b<P0j>SX0GUiN04M7A`0o?cl0@T9203dm?@0h>3P0AdM7
03@d=00f=SH0=cLg034a<@0f=SH0<S8b02d];@0^;Rh0;bl_03<c<`0e=CD203`l?0040451@@18B4P0
@410038b<P80>CTi00@0>SXj03Ti>@0d=3@0=cLg0P0c<c<07@0h>3P0BDU904E5A@15ADD0A4A403dm
?@1;Bd/0H61P06QXJ01[Jf/0Kfm_06QXJ01NGUh0Bd];03dm?@0_;bl0:RXZ02`/;00m?Cd0CDe=04Q8
B01TI6@0M7Ad07QhN01gMgL0Ogmo07UiN@1fMWH0MGEe0080LG5a00<0Kfm_07alO01oOgl00P22PX82
08F5Q@0708>3P`28R8P0R8R808N7Q`2:RXX0S8b<08V9R@0208^;R`0808f=S@2<S8`0SHf=08f=S@2>
SXh0TY:B08n?S`28R8P208f=S@0308b<S02?Shl0Rh^;0080SHf=00l0Shn?09:BTP2GUiL0U9BD09FE
U@2HV9P0UiNG09^KV`2PX:00WYjN0::RXP2TY:@0X:2P0::RXP2TY:@00`2UYJD07@2TY:@0Z:RX0:VY
Z@2YZJT0[jn_0;2`/02^[Zh0Zj^[0:f][@2_[jl0/[:b0;6a/@2^[Zh0/k>c0;Fe]@2b/[80]KFe0;Rh
^02f][H0]kNg0;Vi^@2m_Kd0_kno0<30`033`l<0_kno0<G5a@36a/H0alO70080b/[:03H0c<c<0<W9
b@3=cLd0dM7A0<g=c@3@d=00clo?0=7Ad@3Cdm<0eMGE0=KFeP3De=@0e]KF0=SHf03GemL0e]KF0=[J
fP3Hf=P0fMWI0<o?c`2SXj<0Fe]K030`<00a<C40>c/k02LW9`0Z:RX0;Bd]038b<P0^;Rh0>3Ph0451
@@1>CTh0Bd];03dm?@12@T80AdM704I6AP1:BTX0=SHf02d];@0b<S80@d=306e]K@2/[:`0X:2P08j>
SP2;Rh/0RHV908N7Q`2=SHd0T92@09RHV02CTi<209BDU00709FEU@2FUYH0Ti>C09JFUP2EUID0U9BD
08n?S`02096AT@0408j>SP2=SHd0Shn?096AT@80SXj>00T0TI6A08f=S@2?Shl0T92@08b<S02=SHd0
SXj>08b<S02;Rh/00P2<S8`208Z:RP80QhN70P25QHD01`28R8P0QXJ608F5Q@1nOWh0PX:208>3P`24
Q8@00P1lO7`207inOP0F07]kN`1lO7`0OGem07UiN@1hN7P0O7al07emO@21PH40QXJ608N7Q`26QXH0
QHF507emO@1iNGT0Lg=c07IfMP1nOWh0V9RH0;2`/031`L40b/[:0<o?c`<0eMGE00H0e=CD0=GEe@3C
dm<0eMGE0=KFeP3GemL20=KFeP080=GEe@3Fe]H0d];B0=3@d03<c<`0aLG50;jn_P2c/k<20:VYZ@0;
09FEU@23Ph<0LG5a05MGE`16ATH0=CDe03dm?@19BDT0Cdm?05IFEP1QHF400P1PH6001@1IFET0EUIF
05IFEP1MGEd0Fe]K0080G5aL00D0FEUI05eMG@1OGel0J6QX06e]K@0207EeM@0;079bLP1_Kfl0Jf][
06QXJ01SHf<0H61P05iNGP1KFe/0E5AD05QHF01MGEd00P1SHf<00`1WIfL0IFEU0<SPf00=0<SPf000
3038h=P207UiN@0907EeM@1nOWh0OWin08B4Q02=SHd0TY:B09BDU02FUYH0V9RH0080VIVI01d0UYJF
09FEU@2?Shl0RHV908f=S@28R8P0QXJ607UiN@1]KFd0Fe]K05UIF@16ATH0<S8b02d];@0/;2`0?Shn
04U9B@1ADE40GUiN06i^KP1nOWh0RHV909JFUP2KVi/0XJ6Q0:JVYP2XZ:P0[jn_0;:b/P020;>c/`09
0;2`/02][Jd0[Jf]0:b/[02^[Zh0[Jf]0:b/[02^[Zh0/;2`0080/K6a01X0Zj^[0:ZZZP2VYZH0YJFU
09nOW`2GUiL0UIFE08j>SP2EUID0alO70=cLg037alL0MGEe05aLG01dM7@0SXj>0<K6aP1YJFT092@T
02DU9@0R8R809bLW02<S8`0U9BD0<30`034a<@80>3Ph0`0l?3`04@0k>c/0>CTi0451@@19BDT0?clo
04m?C`1;Bd/0AdM703Lg=`0_;bl09bLW03Xj>P1BDU80B4Q80410@00l?3`0>3Ph0080<c<c00T0>SXj
04=3@`13@d<0@41004A4A010@400=SHf03dm?@0];Bd00P0[:b/03@0_;bl0<S8b030`<00n?Sh0@d=3
03Lg=`0_;bl0;Rh^03Ph>01>CTh0L71`06][J`1`L7000P1XJ6P0400m?Cd0:BTY02d];@0h>3P0AdM7
059BDP1:BTX0C4a<05ADE019BDT0D51@04];B`1>CTh0H61P07UiN@1WIfL206EUI@0R05=CD`1EEED0
IfMW07IfMP25QHD0TY:B08b<S024Q8@0RXZ:07alO02;Rh/0RHV905mOG`1eMGD0QhN708F5Q@1^KVh0
GEeM05ADE015ADD0RHV908N7Q`2b/[80[jn_07AdM01PH600@T9203Ti>@1KFe/0^;Rh08b<S010@400
<c<c02h^;P80;2`/01P0;Bd]034a<@0f=SH0=3@d03<c<`0m?Cd0HV9R04];B`15ADD0>c/k03dm?@0i
>CT0ATI603De=@0n?Sh0=SHf03dm?@0l?3`0>3Ph03De=@0i>CT0=3@d03Lg=`0h>3P203`l?0040451
@@14A4@0BDU903Ti>@80>c/k00P0@T9203dm?@0n?Sh0?clo03De=@0k>c/0@T9205iNGP80BDU900X0
@d=30410@01>CTh0FUYJ06ATI01XJ6P0JFUY06MWI`1LG5`0@4100P0h>3P0800e=CD0;2`/03lo?`1B
DU80D51@061PH01gMgL0Ng]k07EeM@23Ph<0Ng]k07IfMP1cLg<0MWIf07UiN@1dM7@0K6a/07AdM01h
N7P0PH6108N7Q`29RHT0R8R808F5Q@28R8P0QXJ608f=S@2@T900RHV908R8R029RHT0S8b<0`2>SXh0
4P2?Shl0T92@08n?S`2:RXX0RHV908N7Q`2<S8`0SHf=08V9R@2>SXh0RXZ:08n?S`2@T900U9BD09RH
V02EUID0V9RH09VIV@80W9bL00L0WinO0:6QX@2QXJ40WinO0::RXP2UYJD0YjNW0080ZJVY00/0YZJV
0:VYZ@2YZJT0Xj>S0:ZZZP2a/K40Zj^[0:j^[P2a/K40/[:b0;Jf]P030;:b/P030;Fe]@2g]kL0^[Zj
0080_;bl00H0^k^k0;Zj^P2o_kl0`L710;no_`31`L420<?3``090<K6aP38b<P0alO70<_;b`3<c<`0
b/[:0<k>cP3?cll0c/k>00<0d=3@00L0dm?C0=;BdP3De=@0dm?C0=KFeP3Jf]X0emOG0080fMWI02D0
e]KF0<o?c`2_[jl0IVIV03Ti>@0/;2`0?clo04=3@`0^;Rh0<c<c02l_;`0k>c/0;Rh^03Hf=P18B4P0
ATI604Y:BP10@400?Shn04Q8B01>CTh0Cdm?03`l?00Y:BT0<C4a03/k>`1YJFT0Zj^[0:>SX`2?Shl0
SHf=092@T027QhL0Rh^;08b<S02CTi<0T92@0080UIFE00@0Vi^K09JFUP2ATI40Ti>C0P2BTY804P2E
UID0Ti>C096AT@2>SXh0S8b<096AT@2@T900SHf=09:BTP2?Shl0SHf=092@T02BTY80Shn?08f=S@2:
RXX0SXj>092@T080R8R800L0QXJ608V9R@28R8P0Rh^;08J6QP2;Rh/0QhN700<0PX:200D0Ogmo08:2
PP1oOgl0Ogmo07alO00207moO`0607UiN@1fMWH0NGUi07QhN01eMGD0MWIf0P1jNWX01`22PX80PH61
08J6QP1nOWh0Ph>307YjNP1eMGD00P1`L7001@29RHT0Z:RX0;bl_039bLT0c/k>00<0dm?C0100e=CD
0=GEe@3De=@0e]KF0=GEe@3De=@0eMGE0=KFeP3De=@0eMGE0=CDe03@d=00c<c<0<G5a@30`<00^[Zj
0P2_[jl03P2PX:00SXj>07alO01NGUh0@D51038b<P0a<C40>3Ph04A4A01?Cdl0G5aL065QH@1OGel0
G5aL0P1KFe/305mOG`80Fe]K01D0FEUI05YJFP1VIVH0Jf][06m_K`1/K6`0Lg=c0820P01^KVh0JVYZ
06EUI@1PH600Hf=S05eMG@1DE5@0DE5A05ADE01MGEd0H61P065QH@1PH6003P38h=P000`0b>3H0P21
PH40201jNWX0O7al0820P028R8P0SXj>09BDU02IVIT0V9RH0P2IVIT01@2HV9P0UYJF09>CT`28R8P0
QHF50080QXJ601L0OGem075aL@1RHV80EeMG04e=C@11@D40=SHf02TY:@0Z:RX0>CTi0451@@1CDe<0
HV9R075aL@21PH40QhN708n?S`2IVIT0X:2P0:>SX`2WYjL0[:b/0:j^[P020;6a/@0Z0;:b/P2`/;00
[Jf]0:f][@2_[jl0[:b/0:j^[P2`/;00[:b/0;Bd]02_[jl0Zj^[0:j^[P2VYZH0X:2P0::RXP2GUiL0
UYJF08n?S`2MWId0clo?0=_Kf`3AdM40QhN707UiN@2ATI40Rh^;0:6QX@1OGel09BDU02@T900Y:BT0
>3Ph02HV9P0[:b/0<C4a03@d=00j>SX0?Cdm03/k>`0l?3`0=SHf0P0e=CD07`14A4@0?Cdm0451@@1<
C4`0ATI603lo?`0d=3@0;Bd]02/[:`0i>CT0F5QH061PH01ADE40@d=303hn?P0h>3P0>CTi03lo?`0j
>SX0@4100451@@12@T80=3@d03Hf=P0h>3P0>c/k034a<@0d=3@0;2`/02l_;`0n?Sh00P0b<S80200_
;bl0:BTY02`/;00j>SX0EUIF08V9R@2>SXh0LW9b0P1@D500A@0c<c<0:BTY03Ph>00j>SX0A4A4059B
DP1ADE40CDe=04U9B@1:BTX0@D5104A4A01EEED0Kfm_06e]K@1JFUX0Fe]K051@D01EEED0G5aL06UY
J@1oOgl0S8b<09:BTP28R8P0P82007moO`2<S8`0VYZJ08Z:RP1MGEd0Ti>C08N7Q`1cLg<0AdM703De
=@0h>3P0BDU909^KV`2SXj<0b<S809RHV01HF5P0NGUi05EEE@0n?Sh0Ph>30;Rh^01[Jf/0>3Ph03Xj
>P0e=CD0>3Ph02l_;`0b<S80=3@d03De=@0a<C40=cLg03/k>`1HF5P0BDU904=3@`0h>3P0?Shn03Lg
=`0l?3`0=SHf03/k>`0203`l?00403dm?@0i>CT0=CDe03Ti>@80>c/k00L0?3`l0410@00o?cl0ADE5
04=3@`19BDT0>3Ph0080=SHf00@0=cLg03<c<`0h>3P0<c<c0P0i>CT06`10@400Fe]K04Q8B017AdL0
@41003Ti>@1;Bd/0EEEE069RHP1XJ6P0JFUY06EUI@1IFET0@41003Lg=`0b<S80;Rh^02d];@0o?cl0
E5AD04i>CP1KFe/0LW9b07YjNP1dM7@0NWYj07MgM`0207IfMP0@07inOP1iNGT0NGUi07=cL`1WIfL0
Kfm_07UiN@25QHD0RXZ:08>3P`24Q8@0QhN708F5Q@2:RXX0RHV908^;R`80RXZ:0P29RHT00`2:RXX0
Rh^;092@T00208f=S@0;08j>SP2:RXX0Rh^;08Z:RP2<S8`0RHV908^;R`2>SXh0T92@096AT@2CTi<0
0P2DU9@02`2FUYH0VIVI09ZJVP2LW9`0XJ6Q0:>SX`2TY:@0XZ:R09nOW`2SXj<0ZJVY0080Zj^[0180
YjNW0:RXZ02/[:`0YjNW0:b/[02`/;00[jn_0;2`/02b/[80];Bd0;Rh^02a/K40/[:b0;Fe]@2h^;P0
^k^k0;no_`2l_;`30;fm_@040<30`031`L40`L710<;2`P80`l?300<0b<S80<K6aP3=cLd00P3:b/X0
1@3<c<`0clo?0<o?c`3AdM40d=3@0080d];B00H0e=CD0=GEe@3De=@0d];B0=GEe@3GemL20=WIf@0V
0=SHf03?cll0/k>c071`L00k>c/0>3Ph03Lg=`18B4P0@D5102l_;`0a<C40=3@d03hn?P0g=cL0=CDe
0410@014A4@0D51@04I6AP0k>c/0CDe=04Y:BP1>CTh0AdM702TY:@0`<300>3Ph065QH@2TY:@0YjNW
08f=S@2?Shl0U9BD08N7Q`29RHT0Ti>C09JFUP2CTi<209:BTP80U9BD00d0VIVI09>CT`2BTY80Ti>C
096AT@2BTY80S8b<08n?S`29RHT0TI6A09>CT`2>SXh0T92@00<0SXj>00<0Rh^;08b<S02>SXh00`2;
Rh/02029RHT0S8b<08V9R@2<S8`0R8R808N7Q`2:RXX0Ph>30P24Q8@00`20P800Q8B40861P@020820
P080Ogmo01X0P82007emO@1hN7P0NGUi07YjNP1dM7@0N7Qh07MgM`1mOGd0O7al0861P@24Q8@0QHF5
08:2PP1oOgl0OWin071`L01_Kfl0KVi^08F5Q@2OWil0][Jf0<C4a03;bl/0dM7A0=GEe@80dm?C00l0
eMGE0=CDe03EeMD0eMGE0=CDe03EeMD0dm?C0=OGe`3Fe]H0eMGE0=3@d03>c/h0b/[:0<?3``2m_Kd0
0P2d];@01@2WYjL0VYZJ08>3P`1WIfL0B4Q80080=CDe02<0<30`03Ti>@16ATH0EUIF05YJFP1IFET0
Fe]K05MGE`1MGEd0G5aL05mOG`1RHV80G5aL05]KF`1HF5P0EEEE05QHF01TI6@0JFUY06YZJP1eMGD0
KVi^06YZJP1YJFT0J6QX05iNGP1OGel0GEeM05IFEP1EEED0De=C05MGE`1OGel0H61P05mOG`0>0<SP
f0003038h=P207moO`0308>3P`22PX80QXJ60080T92@00<0TI6A09NGU`2IVIT00`2GUiL06`2EUID0
TY:B08R8R021PH40Q8B407alO01gMgL0JFUY05iNGP1EEED0B4Q80410@00g=cL0;Rh^02/[:`0g=cL0
Bd];05ADE01RHV80KVi^07alO026QXH0Ti>C09ZJVP2PX:00Y:BT0:JVYP020:j^[P80[Jf]00@0[jn_
0:j^[P2_[jl0[:b/0P2^[Zh00`2_[jl0[Zj^0;2`/0020;6a/@0R0;2`/02][Jd0YjNW0:BTY02MWId0
UiNG09FEU@2?Shl0V9RH0<O7a`3Fe]H0fMWI09JFUP1aLG40N7Qh0820P01YJFT0EUIF02d];@0b<S80
;2`/03Lg=`0f=SH0<S8b034a<@0d=3@0=CDe0410@00f=SH0<c<c03Lg=`0j>SX0;bl_03/k>`80@410
00/0BDU904e=C@0g=cL0;Bd]02`/;00];Bd0>3Ph04a<C01IFET0C4a<04M7A`020492@P0403Xj>P0l
?3`0=CDe03@d=080<30`01<0?Cdm03lo?`12@T80ATI604U9B@13@d<0@41003/k>`10@400>SXj03@d
=00S8b<092@T02DU9@0m?Cd0HV9R08R8R02OWil0Lg=c0080@4100280;bl_030`<016ATH0?clo0410
@01HF5P0BDU904E5A@14A4@0?Cdm0492@P1<C4`0IfMW07=cL`1XJ6P0EUIF05QHF01BDU80G5aL06MW
I`1`L700Q8B408j>SP2:RXX0Q8B407UiN@28R8P0W9bL09fMW@20P800S8b<0:FUY@1mOGd0BTY:0P0X
:2P0:00/;2`0GUiN0:FUY@30`<00];Bd06=SH`0n?Sh0LG5a05EEE@1<C4`0YJFU09nOW`17AdL0;bl_
038b<P0^;Rh0:BTY02XZ:P0[:b/0<30`02`/;00Z:RX0<C4a03De=@1FEUH0B4Q804A4A00c<c<0=3@d
03<c<`0i>CT0=SHf02l_;`0g=cL0=3@d03Ti>@0h>3P0=CDe02l_;`0d=3@203Lg=`0603`l?00n?Sh0
ADE50492@P14A4@0<c<c0P0g=cL0300c<c<0<C4a03De=@0g=cL0=3@d03Ti>@0k>c/0De=C03/k>`15
ADD0@d=303Ti>@80Cdm?01<0GUiN06=SH`1WIfL0IVIV04e=C@0f=SH0<c<c02`/;00];Bd0:b/[04=3
@`1<C4`0CTi>05=CD`1`L700MWIf075aL@1hN7P0M7Ad0080MgMg0`1nOWh03@1jNWX0LG5a071`L01b
LW80N7Qh0820P026QXH0Ph>308V9R@28R8P0RXZ:09:BTP2<S8`00`29RHT208Z:RP0508^;R`2>SXh0
Shn?08V9R@2=SHd00P2?Shl00`2;Rh/0T92@08f=S@0208^;R`03092@T02BTY80TY:B0080U9BD00@0
V9RH09JFUP2KVi/0VYZJ0`2PX:00102TY:@0Xj>S0:NWY`2VYZH20:ZZZP040:JVYP2/[:`0ZZZZ0:n_
[`80/[:b00H0[jn_0;Bd]02b/[80/[:b0;Rh^02e]KD20;Jf]P080;^k^`2i^KT0_Kfm0;jn_P2m_Kd0
`L710;jn_P33`l<30<71`@070<;2`P35aLD0alO70<W9b@3:b/X0bl_;0<[:bP020<g=c@030<k>cP3A
dM40d];B0080dM7A0P3EeMD0:`3Cdm<0e=CD0=KFeP3GemL0e]KF0=SHf03AdM40]KFe07IfMP14A4@0
;Bd]03Ti>@11@D40D51@03lo?`0`<300>c/k03@d=00l?3`0=CDe03Ph>019BDT0D51@05ADE01BDU80
ADE504Y:BP14A4@0ADE504M7A`0X:2P0<c<c03Ph>01MGEd0WYjN0:VYZ@2CTi<0U9BD09>CT`24Q8@0
R8R808f=S@2EUID00`2DU9@0102FUYH0VYZJ09FEU@2@T90308n?S`0C096AT@2CTi<0TI6A08j>SP2E
UID0Ti>C08b<S02=SHd0SXj>08n?S`2=SHd0S8b<08f=S@2;Rh/0T92@08b<S02:RXX0Shn?08Z:RP02
08N7Q`0508j>SP28R8P0R8R808J6QP23Ph<00P21PH4208:2PP0508B4Q01mOGd0OGem08B4Q027QhL0
0P1gMgL0:01eMGD0MWIf079bLP1dM7@0N7Qh07alO01nOWh0OGem0820P024Q8@0PH6107]kN`1dM7@0
L71`06EUI@1XJ6P0NWYj09VIV@2a/K40`L710<_;b`3?cll0d];B0=CDe03Cdm<0e=CD0=;BdP3De=@0
eMGE0=CDe03GemL0eMGE0=?Cd`3EeMD0dm?C0=7Ad@3<c<`0bl_;0<O7a`33`l<20;Zj^P0Z0;>c/`2T
Y:@0TI6A071`L01ADE40>CTi02l_;`0/;2`0<S8b03lo?`1;Bd/0EEEE05YJFP1LG5`0EEEE05iNGP1R
HV80FUYJ05iNGP1JFUX0FEUI055AD@1GEeL0EUIF05mOG`1PH600HF5Q06][J`1/K6`0JVYZ06UYJ@1R
HV80GemO05iNGP1HF5P0FEUI05eMG@1IFET0E5AD05iNGP1UIFD0GUiN3P38h=P000`0b>3H0P1lO7`2
08F5Q@0V08Z:RP2ATI40TI6A09>CT`2IVIT0Vi^K09NGU`2CTi<0UIFE09>CT`2=SHd0QXJ608>3P`1j
NWX0M7Ad06][J`1SHf<0EUIF04M7A`12@T80>c/k03Hf=P0Z:RX09RHV03Hf=P19BDT0EEEE06IVIP1`
L700O7al08J6QP2CTi<0WIfM0::RXP2UYJD0ZJVY0:f][@2`/;020:b/[0040:j^[P2_[jl0[jn_0:^[
Z`80[Zj^01L0Zj^[0:b/[02][Jd0/;2`0;:b/P2_[jl0ZZZZ0:FUY@2VYZH0X:2P09VIV@2>SXh0S8b<
08f=S@34a<@0emOG0=kNgP2/[:`0Hf=S05YJFP1TI6@0AdM705UIF@0203/k>`0D03lo?`11@D40>3Ph
038b<P0_;bl0;2`/02d];@0a<C40:BTY02l_;`0Y:BT09RHV02XZ:P0`<300<c<c0451@@1@D500DE5A
03Ti>@0P820202DU9@0P03<c<`16ATH0CTi>04=3@`0n?Sh0@T920410@013@d<0>SXj03dm?@0c<c<0
>3Ph03`l?019BDT0EEEE05eMG@1YJFT0K6a/079bLP1[Jf/0K6a/05eMG@18B4P0>CTi02h^;P0P8200
9BDU02h^;P1EEED0P82009^KV`1fMWH203Hf=P0F02/[:`0f=SH0@41003hn?P11@D40EUIF03hn?P12
@T80?Shn03lo?`1<C4`0IFEU06YZJP1WIfL0De=C05IFEP1MGEd0F5QH06ATI01aLG40Lg=c08J6QP80
Q8B403<0S8b<08:2PP23Ph<0Xj>S09NGU`24Q8@0Y:BT09nOW`1WIfL0<C4a02<S8`0U9BD0?3`l08Z:
RP2a/K40_Kfm08F5Q@0k>c/0=CDe061PH01GEeL0HV9R0;Rh^020P800=SHf03Ph>00f=SH0;bl_034a
<@0];Bd09bLW034a<@0[:b/0;bl_02d];@0i>CT0EEEE051@D00k>c/0>SXj03@d=00f=SH0?3`l03De
=@0a<C40=SHf034a<@0k>c/0<S8b03Hf=P0e=CD00P0c<c<01`0^;Rh0?3`l03Ph>014A4@0?clo0451
@@0g=cL00P0/;2`05@0b<S80=CDe038b<P0i>CT0<C4a03De=@0k>c/0DU9B0410@01<C4`0>c/k0410
@017AdL0DU9B05UIF@1NGUh0H61P05UIF@12@T80>CTi02d];@02038b<P0=034a<@1=CDd0EUIF04Y:
BP1OGel0Kfm_07=cL`1dM7@0Lg=c079bLP1fMWH0N7Qh07YjNP0208>3P`090861P@1dM7@0LG5a075a
L@1dM7@0N7Qh08B4Q025QHD0RHV90080RXZ:00l0S8b<08V9R@2;Rh/0R8R808F5Q@26QXH0Rh^;08Z:
RP2<S8`0R8R808V9R@2=SHd0SXj>08f=S@26QXH00P2:RXX01@29RHT0SXj>08Z:RP2>SXh0SHf=0080
Ti>C00/0UYJF09ZJVP2IVIT0VIVI09jNWP2PX:00WIfM0:BTY02OWil0X:2P0:FUY@020:JVYP080:RX
Z02YZJT0[:b/0:f][@2a/K40/;2`0;>c/`2e]KD20;Bd]00:0;Fe]@2j^[X0^KVi0;Rh^02m_Kd0^KVi
0;^k^`2n_[h0_Kfm0;bl_080`<3000X0`l?30<C4a033`l<0aLG50<C4a036a/H0bl_;0<[:bP3;bl/0
cLg=0P3@d=002@3>c/h0c<c<0=7Ad@3AdM40d=3@0=;BdP3De=@0e]KF0=GEe@020=SHf0050=OGe`3B
d]80^KVi08J6QP1=CDd00P0e=CD02`16ATH0CTi>05QHF013@d<0@D5104E5A@10@400A4A403lo?`10
@400BTY:0080D51@01@0EEEE04Y:BP1<C4`0Bd];03lo?`19BDT0;Rh^03Lg=`0j>SX0EUIF09BDU02]
[Jd0TY:B09VIV@2GUiL0QhN708V9R@2@T900UYJF09:BTP80V9RH00T0Ti>C09NGU`2EUID0TI6A09BD
U02BTY80UiNG092@T02BTY800P2?Shl0102GUiL0Shn?096AT@2=SHd209:BTP0@08n?S`2>SXh0S8b<
08^;R`2>SXh0RXZ:08J6QP28R8P0QHF508Z:RP2=SHd0Rh^;08Z:RP26QXH0PX:207moO`80PH6100@0
Q8B408>3P`1oOgl0NWYj0P1kNg/0101jNWX0N7Qh07YjNP1cLg<2071`L00D07AdM01eMGD0O7al08>3
P`24Q8@0PX:208J6QP1oOgl0MWIf075aL@1^KVh0IVIV069RHP1^KVh0SHf=0:ZZZP2m_Kd0b<S80<c<
c03Bd]820=CDe0030=GEe@3Cdm<0e=CD00<0eMGE00T0e]KF0=GEe@3De=@0e]KF0=;BdP3>c/h0bl_;
0<W9b@33`l<00P2o_kl0402h^;P0[:b/09>CT`1lO7`0EeMG03/k>`0/;2`09BDU02d];@0f=SH0AdM7
04i>CP1EEED0Fe]K05iNGP1GEeL205UIF@0@05EEE@1DE5@0DU9B05QHF01CDe<0EEEE05eMG@1RHV80
J6QX06IVIP1XJ6P0IFEU06IVIP1YJFT0H61P05aLG080FEUI00H0G5aL05=CD`1FEUH0GemO06EUI@1V
IVH>0<SPf0003038h=P207inOP0X08:2PP2<S8`0S8b<08b<S02CTi<0UYJF09VIV@2FUYH0UIFE092@
T02>SXh0Shn?08B4Q021PH40NWYj07IfMP1`L700I6AT05YJFP1ADE40AdM704=3@`0l?3`0;bl_02TY
:@0V9RH0<c<c04M7A`1EEED0IfMW07MgM`1nOWh0QhN709:BTP2HV9P0XJ6Q0:NWY`2/[:`0/K6a0:n_
[`80/K6a00h0[jn_0:f][@2[Zj/0ZJVY0;:b/P2[Zj/0ZJVY0:j^[P2][Jd0/[:b0;Bd]02_[jl0[Jf]
0:ZZZP80Xj>S04D0UiNG08b<S02:RXX0S8b<0;Jf]P3Fe]H0fm_K0<30`01^KVh0A4A406IVIP15ADD0
F5QH04i>CP1<C4`0@41003dm?@0`<300;2`/02h^;P0U9BD0;bl_02XZ:P0V9RH09bLW02XZ:P0X:2P0
9bLW02l_;`0/;2`0<S8b03hn?P18B4P0?3`l02LW9`0X:2P0;Bd]03Lg=`19BDT0EEEE05YJFP1=CDd0
CTi>0410@00m?Cd0>SXj04A4A016ATH0Bd];03`l?00h>3P0?Cdm04A4A01?Cdl0EUIF06YZJP1`L700
NGUi07moO`1/K6`0C4a<02h^;P0/;2`09bLW02XZ:P0k>c/0Hf=S08^;R`20P8000P0k>c/0<`0h>3P0
>CTi03/k>`0k>c/0CDe=04I6AP0i>CT0>SXj03/k>`10@400FUYJ06EUI@1WIfL0FEUI05MGE`1LG5`0
HF5Q06a/K01bLW80OGem08J6QP23Ph<0Q8B408V9R@25QHD0Ng]k08b<S02LW9`0SHf=09BDU02SXj<0
QhN704];B`0T92@08B4Q02HV9P1[Jf/0YjNW0;:b/P2IVIT0CTi>02/[:`0e=CD0EEEE051@D02HV9P0
][Jf05aLG00f=SH0<S8b03De=@0203Ph>00402l_;`0];Bd0;Bd]02PX:080:BTY01T0=SHf05QHF01?
Cdl0@41003Xj>P0b<S80=3@d03Hf=P0c<c<0<S8b03Xj>P0m?Cd0=cLg03Ti>@0c<c<0=CDe03hn?P0e
=CD0<S8b03hn?P0o?cl0ATI603dm?@11@D40<c<c0080;bl_00<0<S8b03Ti>@0d=3@00P0e=CD01P0f
=SH0>CTi04i>CP0e=CD0?clo04=3@`80?clo00L0EEEE05IFEP1NGUh0Hf=S04U9B@0n?Sh0<S8b0080
<C4a00l0:RXZ03Lg=`1GEeL0De=C05MGE`1JFUX0L71`07=cL`1aLG40Lg=c075aL@1fMWH0NGUi0820
P024Q8@00P1nOWh02@1lO7`0OWin079bLP1^KVh0MWIf07]kN`1nOWh0QhN708R8R00308^;R`0308Z:
RP26QXH0QhN70080RXZ:0`2>SXh04`2:RXX0SHf=092@T02<S8`0RHV908J6QP27QhL0QXJ608R8R02:
RXX0Rh^;08N7Q`2>SXh0TI6A09BDU02FUYH0W9bL09fMW@2LW9`00P2PX:020::RXP080:JVYP2XZ:P0
ZJVY0:VYZ@2XZ:P0ZZZZ0:f][@2^[Zh30;>c/`060;Jf]P2g]kL0^;Rh0;Vi^@2j^[X0^KVi0P2l_;`0
1`2k^k/0^;Rh0<30`02m_Kd0_kno0<?3``35aLD00P36a/H00`37alL0`l?30<C4a0020<W9b@070<[:
bP3>c/h0clo?0<o?c`3@d=00c/k>0=3@d0020=?Cd`050=CDe03Cdm<0eMGE0=KFeP3De=@00P3GemL0
3`3AdM40^KVi08R8R01DE5@0<C4a02TY:@0f=SH0@D51051@D01DE5@0@T92038b<P0n?Sh0>CTi0492
@P0203Lg=`0B0410@01<C4`0AdM7051@D013@d<0?clo04];B`0k>c/0A4A402TY:@0^;Rh0=CDe04a<
C02?Shl0Z:RX09FEU@2MWId0U9BD0P24Q8@00`2?Shl0VYZJ09FEU@0209FEU@0=09:BTP2HV9P0U9BD
096AT@2?Shl0TY:B092@T02BTY80U9BD092@T02ATI40Shn?08j>SP0208n?S`0908b<S02?Shl0SHf=
096AT@2<S8`0Rh^;08N7Q`26QXH0RHV90080QHF50`26QXH05`25QHD0P82008B4Q01kNg/0O7al07mo
O`1nOWh0PH6107QhN01gMgL0Ogmo07MgM`1jNWX0MgMg07EeM@1dM7@0KVi^06][J`1]KFd0LG5a07Yj
NP1nOWh0PH610080Q8B40100PH6107IfMP1_Kfl0JFUY05mOG`1JFUX0Hf=S08R8R02TY:@0^[Zj0<O7
a`3<c<`0dM7A0=CDe03Bd]80eMGE0P3Fe]H01@3EeMD0e]KF0=CDe03Cdm<0eMGE0080e]KF00<0dM7A
0=;BdP3;bl/00P3:b/X20<S8b00=0;no_`2b/[80X:2P0861P@1WIfL0AdM7030`<00U9BD0:b/[034a
<@0g=cL0ATI6051@D00205]KF`0705iNGP1JFUX0EeMG05=CD`1GEeL0FUYJ05IFEP02055AD@0B05=C
D`1LG5`0HF5Q065QH@1WIfL0I6AT06m_K`1UIFD0H61P05aLG01KFe/0FEUI05aLG01JFUX0De=C05MG
E`1MGEd0H61P3P38h=P000`0b>3H0P22PX809`20P800RXZ:08b<S02?Shl0TI6A09FEU@2JVYX0U9BD
09>CT`2@T900S8b<08F5Q@1oOgl0O7al07=cL`1`L700JVYZ061PH01JFUX0DU9B04Y:BP14A4@0=CDe
034a<@0Y:BT0;Bd]03Hf=P15ADD0EUIF06=SH`1fMWH0OGem08b<S02@T900V9RH0:>SX`2TY:@0Zj^[
0:NWY`030:f][@050:j^[P2/[:`0[Jf]0:^[Z`2/[:`00P2[Zj/0602][Jd0[:b/0:j^[P2`/;00[Zj^
0:f][@2WYjL0XZ:R0:2PX02FUYH0T92@08^;R`24Q8@0UiNG0<;2`P37alL0c<c<09jNWP16ATH0M7Ad
061PH01`L700EUIF04A4A080>CTi03@0<C4a02LW9`0W9bL0:2PX02TY:@0Z:RX0:2PX02TY:@0_;bl0
;2`/02HV9P0[:b/09bLW030`<00m?Cd0@T9204A4A00l?3`0ATI605ADE01OGel0Jf][07QhN021PH40
OWin07EeM@1RHV80BDU904a<C01BDU80De=C05YJFP0m?Cd0>SXj03`l?00o?cl0ADE503Hf=P0k>c/0
BTY:06IVIP21PH40Ph>306QXJ00n?Sh0;Bd]02h^;P0b<S80@41004Y:BP1jNWX0TI6A0P1FEUH00`1=
CDd0>SXj03Ti>@0204E5A@0803Lg=`0l?3`0>c/k03hn?P1?Cdl0IVIV06=SH`1OGel204a<C00g065Q
H@1jNWX0Lg=c07inOP1oOgl0OWin08N7Q`2CTi<0QXJ608R8R021PH40UIFE08f=S@23Ph<0SHf=09NG
U`1^KVh0<c<c02XZ:P0V9RH0=cLg08^;R`2_[jl0W9bL065QH@0^;Rh0:b/[0492@P1LG5`0GUiN0:n_
[`2FUYH0@T9202l_;`0o?cl0>c/k03Ph>00a<C40;Rh^02PX:00_;bl0:RXZ02l_;`0^;Rh0=CDe05iN
GP1;Bd/0A4A40492@P0a<C40<30`0410@00f=SH0=3@d03Hf=P0203Lg=`0<03<c<`0[:b/0;Bd]034a
<@0^;Rh0=3@d0451@@0m?Cd0@41003`l?00m?Cd0>SXj0P0i>CT00`0h>3P0=3@d038b<P02038b<P0=
02h^;P0l?3`0@d=303Ti>@11@D40C4a<0410@00l?3`0CTi>05IFEP1GEeL0GUiN0492@P0203Xj>P08
02l_;`0i>CT0<C4a0410@01FEUH0DE5A059BDP1JFUX206a/K00707=cL`1dM7@0M7Ad07MgM`1fMWH0
Ng]k07alO00207]kN`080861P@20P800PH6107inOP1eMGD0Ng]k07emO@27QhL208V9R@0608Z:RP27
QhL0R8R808V9R@2;Rh/0SHf=0P2<S8`02`2?Shl0S8b<08f=S@2=SHd0S8b<096AT@2>SXh0Rh^;08Z:
RP2=SHd0Rh^;00<0S8b<00D0T92@08n?S`2CTi<0Ti>C09VIV@0209bLW00609nOW`2MWId0Xj>S0::R
XP2SXj<0YZJV0P2YZJT03`2VYZH0ZZZZ0:^[Z`2_[jl0][Jf0;Bd]02c/k<0]kNg0;fm_@2h^;P0][Jf
0;Vi^@2j^[X0_Kfm0<30`0020;fm_@80_[jn00<0_kno0<30`031`L400P34a<@30<K6aP070<_;b`3<
c<`0b/[:0<c<c03=cLd0d=3@0<o?c`020=7Ad@0K0=CDe03Cdm<0d];B0=CDe03EeMD0e]KF0=CDe03E
eMD0clo?0;Vi^@25QHD0D51@03De=@0_;bl0:BTY02l_;`13@d<0EUIF05ADE00l?3`0<S8b03/k>`0m
?Cd0B4Q803hn?P0k>c/0>CTi0080BTY:01@0E5AD04U9B@10@400DE5A03lo?`15ADD0;2`/02l_;`0f
=SH0ATI608R8R02XZ:P0UIFE09fMW@2CTi<0QhN708F5Q@2=SHd0UIFE09JFUP80TI6A02@0UIFE09JF
UP2CTi<0Ti>C096AT@2@T900UIFE09:BTP2?Shl0RXZ:092@T02ATI40S8b<096AT@2@T900TY:B08Z:
RP2@T900Shn?08V9R@28R8P0Rh^;08Z:RP29RHT0Q8B408F5Q@2:RXX0QhN708F5Q@20P800PH6108>3
P`1nOWh0P82007]kN`1mOGd207YjNP0M07UiN@1eMGD0MWIf07UiN@1^KVh0OWin06][J`1WIfL0JFUY
06i^KP1bLW80MGEe0820P024Q8@0QhN708V9R@1oOgl0MgMg06][J`1TI6@0F5QH05IFEP1NGUh0NWYj
09RHV02a/K40aLG50<g=c@3@d=000P3EeMD20=?Cd`030=CDe03Bd]80eMGE0080e=CD00@0d];B0=GE
e@3De=@0dm?C0P3@d=00303;bl/0c<c<0<W9b@39bLT0a/K60;Vi^@2SXj<0T92@07MgM`1DE5@0>SXj
02`/;080:RXZ0200>c/k03Xj>P1?Cdl0FUYJ05aLG01KFe/0GUiN05YJFP1LG5`0EeMG05EEE@1ADE40
DU9B04i>CP1ADE40Fe]K065QH@1OGel0I6AT061PH01UIFD0Hf=S069RHP1QHF40GEeM05YJFP1DE5@0
Cdm?05=CD`1@D500Fe]K05iNGPh0b>3H000<0<SPf080QXJ602P0PH6108B4Q02<S8`0RXZ:09JFUP2B
TY80V9RH09>CT`2@T900Rh^;08J6QP24Q8@0NWYj07AdM01VIVH0JVYZ06IVIP1JFUX0FEUI04];B`14
A4@0@D5103De=@0^;Rh0:b/[03De=@0f=SH0@T9205MGE`1VIVH0Lg=c0820P02<S8`0Ti>C09JFUP2S
Xj<0YZJV0:VYZ@2WYjL0[:b/0P2[Zj/02@2/[:`0Zj^[0:f][@2YZJT0[:b/0:n_[`2[Zj/0[Zj^0:^[
Z`020:n_[`080;2`/02ZZZX0YJFU0:BTY02OWil0UYJF096AT@2:RXX208:2PP0;0:NWY`2[Zj/0_[jn
0;Vi^@1DE5@0GemO06i^KP1dM7@0FEUI03Xj>P0^;Rh00P0/;2`0<`0Z:RX0:b/[02l_;`0b<S80;2`/
028R8P0W9bL0:BTY02PX:00O7al08B4Q02PX:00^;Rh0?clo05UIF@1ZJVX0L71`08B4Q02>SXh0S8b<
08>3P`20P800PX:208N7Q`2ATI40Ph>306ATI015ADD0ATI604e=C@1ADE40?Shn04E5A@12@T80B4Q8
05MGE`13@d<0:BTY02`/;00m?Cd0IfMW07emO@1oOgl0GEeM03lo?`0i>CT0>c/k03hn?P19BDT0IVIV
08j>SP0207YjNP05069RHP18B4P0?3`l04i>CP16ATH00P0l?3`04@0k>c/0AdM705YJFP1GEeL0G5aL
055AD@16ATH0EEEE075aL@1eMGD0NGUi08:2PP1jNWX0OGem08f=S@2NWYh0Ph>30080SXj>00H0TI6A
08B4Q020P800R8R808Z:RP1GEeL202l_;`0Q02h^;P0m?Cd0PH610::RXP1[Jf/0=CDe02HV9P0^;Rh0
DE5A06MWI`21PH40/[:b06i^KP0b<S80<C4a0410@00o?cl0>3Ph03Hf=P0d=3@0<c<c02/[:`0^;Rh0
;bl_038b<P0n?Sh0H61P04m?C`0n?Sh0>SXj03Hf=P0`<300?3`l0080=CDe00P0>SXj02h^;P0e=CD0
<c<c02l_;`0`<300>3Ph034a<@<0>CTi00@0@T9203Ti>@0i>CT0?Shn0P0h>3P04`0e=CD0=3@d03<c
<`0a<C40;Rh^038b<P0l?3`0@d=303Lg=`14A4@0ATI604=3@`0h>3P0BDU905IFEP1?Cdl0DU9B03De
=@0g=cL00P0h>3P03`0i>CT0<C4a0492@P1GEeL0Cdm?05MGE`1NGUh0IfMW06a/K01aLG40MWIf07Mg
M`1fMWH0MGEe07QhN00207UiN@0607moO`23Ph<0Ng]k0861P@1nOWh0Ogmo0P1iNGT02P21PH40PX:2
08>3P`24Q8@0Rh^;08R8R02;Rh/0SHf=08n?S`2DU9@208n?S`0408j>SP2<S8`0RXZ:08Z:RP80SHf=
00@0RHV908R8R025QHD0RHV90P27QhL03P2?Shl0T92@08n?S`2BTY80U9BD09JFUP2LW9`0VYZJ09nO
W`2KVi/0Xj>S0:6QX@2RXZ80YJFU0P2ZZZX00`2YZJT0YjNW0;2`/0020;Fe]@0D0;Jf]P2g]kL0^k^k
0;Zj^P2h^;P0^k^k0;Zj^P2l_;`0_[jn0<30`02o_kl0_Kfm0;no_`2m_Kd0_[jn0;no_`31`L40aLG5
0<K6aP37alL20<W9b@050<c<c03;bl/0c<c<0<k>cP3<c<`00P3?cll0103AdM40clo?0=?Cd`3AdM42
0=?Cd`80eMGE01d0e]KF0<g=c@2g]kL0PH6104i>CP0d=3@0<30`02/[:`0Z:RX0<S8b04Q8B01LG5`0
EUIF0410@00g=cL0?Cdm0451@@1:BTX0ADE50451@@0l?3`0Bd];04I6AP1FEUH0CDe=03lo?`1;Bd/0
AdM704I6AP02038b<P0<03Ti>@0n?Sh0Q8B40:^[Z`2BTY80VIVI09BDU026QXH0S8b<08j>SP2FUYH0
V9RH0P2CTi<02@2IVIT0TI6A09BDU02DU9@0T92@096AT@2DU9@0UIFE09>CT`02096AT@0508n?S`2@
T900Shn?08j>SP2:RXX00P2;Rh/0102<S8`0SHf=08R8R027QhL208V9R@0;08N7Q`29RHT0Q8B408F5
Q@20P800Ph>30861P@23Ph<0PX:207emO@1hN7P00P1gMgL0201fMWH0NGUi07EeM@1aLG40MGEe075a
L@1]KFd0Jf][0`1UIFD04P1]KFd0MgMg07QhN022PX80QXJ608Z:RP1mOGd0MgMg06m_K`1XJ6P0F5QH
05=CD`1EEED0JVYZ08j>SP2YZJT0_kno0<_;b`80d=3@0P3Bd]801P3De=@0dM7A0=GEe@3De=@0dM7A
0=?Cd`80eMGE00H0e=CD0=7Ad@3Bd]80d=3@0<k>cP3=cLd20<k>cP0D0<W9b@32`/80/[:b09RHV01o
Ogl0FUYJ04A4A00`<300:b/[03Hf=P0^;Rh0<S8b03dm?@1;Bd/0E5AD05iNGP1JFUX0F5QH05MGE`1>
CTh204m?C`0<05ADE01<C4`0Cdm?05=CD`1IFET0GEeM065QH@1MGEd0Hf=S06IVIP1QHF40H61P0P1O
Gel01P1CDe<0E5AD05=CD`1DE5@0F5QH05]KF`h0b>3H000<0<SPf080R8R802P0PH6108b<S02;Rh/0
S8b<08f=S@2;Rh/0T92@08j>SP27QhL0QXJ607emO@1dM7@0LG5a06YZJP1QHF40GemO069RHP1IFET0
De=C051@D01;Bd/0?3`l02l_;`0[:b/0:RXZ034a<@0j>SX0A4A405ADE01UIFD0Lg=c07YjNP27QhL0
Ti>C09FEU@2OWil0Xj>S0:JVYP2XZ:P0ZJVY0`2/[:`02P2ZZZX0[:b/0:RXZ02ZZZX0[:b/0:f][@2[
Zj/0/K6a0;2`/02^[Zh20:b/[00F0:VYZ@2TY:@0WIfM09VIV@2ATI40Rh^;0820P01gMgL0U9BD09JF
UP2HV9P0aLG506e]K@1PH600O7al07YjNP1KFe/0=CDe02TY:@0^;Rh0;Bd]02h^;P80;2`/0300;Bd]
02LW9`0V9RH09bLW02@T900P820092@T02DU9@0Y:BT0?3`l06ATI020P800R8R808>3P`1oOgl0Ng]k
075aL@1YJFT0GEeM05aLG01XJ6P0OWin08N7Q`24Q8@0KFe]04a<C00n?Sh0B4Q804=3@`1ADE40A4A4
04I6AP1@D500FEUI030`<00W9bL0;Bd]03Xj>P1OGel0N7Qh07EeM@1?Cdl0?3`l03Xj>P0l?3`0@d=3
055AD@1gMgL208>3P`0508:2PP1^KVh0CTi>055AD@1<C4`00P0k>c/0201ADE40DU9B04i>CP1HF5P0
De=C04E5A@1>CTh0J6QX0P1eMGD207]kN`0E07=cL`1nOWh0QXJ609^KV`28R8P0VIVI08^;R`27QhL0
OGem08J6QP2ATI40MWIf03/k>`12@T80@41003dm?@1gMgL0VIVI07inOP0i>CT0;Rh^0080=3@d01h0
JVYZ06IVIP2[Zj/0U9BD0492@P0c<c<0=SHf0451@@0o?cl0@d=303dm?@0g=cL0=CDe03<c<`0a<C40
;2`/038b<P13@d<0G5aL04];B`17AdL0>c/k03Hf=P0h>3P0@41003`l?00e=CD0>3Ph034a<@0f=SH2
02l_;`0603<c<`0j>SX0=cLg03/k>`0h>3P0>CTi0P10@4004P0n?Sh0>3Ph03Lg=`0g=cL0=SHf03Lg
=`0c<c<0<S8b03<c<`0e=CD0?Shn0410@00m?Cd0?Shn04A4A00i>CT0=cLg04Y:BP80Cdm?00d0B4Q8
03Lg=`0d=3@0=SHf03dm?@0h>3P0<S8b03dm?@1HF5P0DU9B05]KF`1SHf<0I6AT0080LG5a02@0MGEe
07=cL`1dM7@0N7Qh07IfMP1eMGD0M7Ad07QhN021PH40PX:207moO`1nOWh0Ng]k07alO01nOWh0NWYj
08B4Q022PX80QhN708J6QP28R8P0S8b<08f=S@2<S8`0SHf=08n?S`2@T900TI6A08f=S@2ATI40SXj>
08Z:RP2@T900QXJ608N7Q`28R8P208^;R`0408J6QP2<S8`0Shn?092@T080TY:B00D0TI6A09RHV02J
VYX0WYjN09fMW@020::RXP0=0:JVYP2XZ:P0Z:RX0:RXZ02[Zj/0[Jf]0:j^[P2c/k<0]KFe0;Jf]P2k
^k/0_Kfm0;Zj^P020;^k^`030;bl_02k^k/0_[jn00<0_[jn00T0`<300<;2`P33`l<0`L710<?3``37
alL0a/K60<S8b03<c<`00P3:b/X0203;bl/0c<c<0<g=c@3>c/h0d=3@0<o?c`3@d=00c/k>0P3Bd]80
7P3De=@0eMGE0=CDe03De=@0b/[:0;6a/@20P800C4a<030`<00^;Rh0=cLg02l_;`0[:b/0;Rh^04i>
CP1LG5`0F5QH0451@@0m?Cd0ATI604A4A015ADD0ATI603`l?011@D40ATI603lo?`1>CTh0DU9B04Q8
B080ADE500l0B4Q8038b<P0d=3@0B4Q803`l?023Ph<0[jn_09BDU02JVYX0TI6A08^;R`2:RXX0QhN7
09JFUP2OWil00P2BTY801@2GUiL0U9BD08n?S`2EUID0SHf=00<0TY:B00<0SXj>08f=S@2BTY800P2;
Rh/0>02@T900RXZ:08j>SP2<S8`0RHV908f=S@2;Rh/0R8R808V9R@23Ph<0R8R808V9R@24Q8@0PX:2
08J6QP22PX80PH6107inOP20P800NGUi07MgM`1kNg/0MgMg07IfMP1gMgL0MGEe07=cL`1^KVh0JVYZ
06][J`1XJ6P0IfMW061PH01KFe/0GemO079bLP1^KVh0OWin07moO`25QHD0R8R807moO`1dM7@0KVi^
061PH01GEeL0DE5A04i>CP1QHF40QHF509nOW`2m_Kd0b<S80<g=c@3@d=00e=CD0P3Bd]800`3AdM40
e=CD0=GEe@020=?Cd`050=CDe03EeMD0eMGE0=CDe03@d=000P3AdM406P3@d=00c/k>0<k>cP3>c/h0
alO70;Vi^@2RXZ80SHf=071`L01CDe<0>c/k0410@00W9bL09RHV02PX:00d=3@0>c/k04e=C@1JFUX0
De=C05ADE01HF5P0De=C04m?C`1<C4`0CTi>0P1=CDd02P1>CTh0DU9B05YJFP1JFUX0G5aL05]KF`1O
Gel0I6AT05eMG@1GEeL305IFEP0404i>CP1ADE40E5AD05IFEPh0b>3H000<0<SPf080QhN702P0Ph>3
08J6QP2<S8`0Shn?08b<S028R8P0QhN708>3P`24Q8@0Ng]k07MgM`1_Kfl0Lg=c06=SH`1RHV80GUiN
061PH01KFe/0De=C04m?C`16ATH0?Shn02l_;`0/;2`0:b/[034a<@10@400Bd];05EEE@1UIFD0LG5a
07UiN@28R8P0Shn?09RHV02NWYh0Xj>S0:BTY02YZJT0ZZZZ0P2WYjL01P2/[:`0Zj^[0:VYZ@2YZJT0
ZZZZ0:b/[080[Jf]0400[:b/0:^[Z`2[Zj/0[Zj^0:f][@2WYjL0Xj>S09nOW`2KVi/0UIFE08^;R`1m
OGd0NGUi08N7Q`2BTY80OWin0;>c/`2>SXh0H61P07AdM02KVi/0M7Ad02h^;P0`<300;2`/02/[:`0Y
:BT0<30`02TY:@0X:2P09RHV02@T900W9bL0:BTY024Q8@0T92@0;2`/03De=@1ZJVX0OGem07]kN`1e
MGD0O7al06e]K@1HF5P0A4A402h^;P0];Bd0:b/[03<c<`1;Bd/0L71`08R8R02@T900MWIf04Q8B00m
?Cd0B4Q805YJFP1IFET0BTY:03dm?@10@400=SHf0P0];Bd02`0Z:RX0?3`l06IVIP1`L700HF5Q04e=
C@11@D40=SHf03Xj>P15ADD0IfMW0080K6a/00D0QHF508N7Q`1nOWh0EeMG0410@00203Ti>@0_04M7
A`19BDT0DU9B059BDP10@400ADE5061PH022PX80O7al07]kN`1fMWH0LG5a06YZJP1VIVH0MWIf08R8
R02OWil0UIFE07moO`1iNGT0Ogmo08F5Q@27QhL0I6AT04i>CP1]KFd0Hf=S075aL@2RXZ80Shn?04];
B`0U9BD0;Rh^034a<@1>CTh0LW9b07emO@2ZZZX0IFEU03Ph>00d=3@0=CDe03lo?`0m?Cd0?Shn03De
=@0c<c<00P0];Bd05P0/;2`0:b/[02l_;`0m?Cd0FUYJ04m?C`18B4P0>SXj038b<P0c<c<0>c/k03@d
=00c<c<0>3Ph038b<P0g=cL0<S8b03<c<`0b<S80=CDe034a<@0m?Cd203Lg=`040410@01;Bd/0A4A4
03De=@80<c<c00h0=cLg03@d=00i>CT0=3@d03<c<`0j>SX0?Shn03dm?@0d=3@0@T920451@@0h>3P0
?clo04e=C@80DE5A00l0ADE503`l?00i>CT0=3@d03Ti>@0e=CD0=cLg03Xj>P1ADE40Cdm?061PH01K
Fe/0IVIV06UYJ@1^KVh00P1dM7@01P1cLg<0N7Qh07MgM`1gMgL0NWYj07]kN`80Ogmo00D0PH6107in
OP1nOWh0PH6107moO`0207YjNP0408:2PP24Q8@0QhN708V9R@80Rh^;01@0SHf=08Z:RP2=SHd0Shn?
08b<S02=SHd0U9BD08^;R`2?Shl0S8b<08f=S@26QXH0Rh^;08Z:RP28R8P0QHF508b<S02CTi<0TY:B
096AT@80Ti>C00P0UIFE09NGU`2KVi/0WYjN09nOW`2TY:@0YJFU0:VYZ@80[Jf]00L0/K6a0:n_[`2a
/K40]KFe0;Rh^02f][H0_;bl0080_kno0P2l_;`04P2o_kl0_;bl0;jn_P2n_[h0`L710<C4a032`/80
a<C40<?3``31`L40b<S80<G5a@39bLT0b/[:0<S8b03<c<`0c/k>0<_;b`80c/k>00H0cLg=0=3@d03@
d=00d=3@0=;BdP3AdM420=?Cd`0:0=KFeP3De=@0b<S80:^[Z`1jNWX0BDU902d];@0/;2`0=CDe03Ph
>080<30`00L0>CTi05MGE`1VIVH0HF5Q04M7A`0n?Sh0CTi>0080AdM701T0D51@04=3@`12@T80DU9B
04I6AP1@D500De=C04=3@`14A4@0ADE504I6AP0e=CD0=SHf04I6AP0k>c/0Ng]k0:ZZZP2HV9P0WIfM
09BDU029RHT0RXZ:08j>SP2CTi<0Vi^K0080Shn?00/0W9bL09BDU02BTY80T92@096AT@2CTi<0TY:B
08n?S`2ATI40Rh^;092@T00208b<S00I08f=S@27QhL0S8b<08V9R@2<S8`0Rh^;08V9R@27QhL0Rh^;
08F5Q@27QhL0Q8B408>3P`1lO7`0PX:207alO01kNg/0NGUi07]kN`1iNGT0N7Qh07]kN`1cLg<0MGEe
06i^KP0206m_K`0K071`L01cLg<0IfMW06ATI01VIVH0FUYJ069RHP1SHf<0K6a/07AdM01hN7P0P820
08N7Q`22PX80OGem075aL@1^KVh0HV9R05=CD`1>CTh0ADE505IFEP1eMGD0Vi^K0;Rh^035aLD0b/[:
0080dM7A0`3Bd]80103?cll0dM7A0=;BdP3Cdm<20=KFeP050=CDe03Cdm<0d];B0=;BdP3AdM400`3?
cll0403=cLd0bLW90;no_`2/[:`0VYZJ08J6QP1/K6`0EUIF03`l?00`<3009bLW02`/;00Y:BT0<c<c
03dm?@1=CDd2051@D00605EEE@1GEeL0E5AD04a<C01?Cdl0BTY:0P1?Cdl00`1HF5P0FEUI05UIF@02
05]KF`0;05mOG`1KFe/0GUiN05eMG@1LG5`0De=C05EEE@1>CTh0DU9B05MGE`1KFe/03P38h=P000`0
b>3H0P2<S8`00`28R8P0RXZ:08b<S00208N7Q`0N08F5Q@24Q8@0PX:207YjNP1hN7P0KVi^06MWI`1P
H600FUYJ05EEE@1BDU80E5AD05=CD`1?Cdl0ATI604M7A`0h>3P0<S8b02l_;`0Z:RX0;bl_0410@018
B4P0E5AD06QXJ01_Kfl0OGem08N7Q`2ATI40VYZJ0P2SXj<30:NWY`80Zj^[00D0ZJVY0:b/[02VYZH0
[:b/0:^[Z`020:ZZZP80[:b/01H0[jn_0:^[Z`2^[Zh0[:b/0:VYZ@2VYZH0XZ:R09fMW@2FUYH0SHf=
0861P@1dM7@0Kfm_07YjNP1`L700Shn?0:6QX@1EEED0K6a/0<30`02NWYh0>c/k0P0^;Rh0200W9bL0
9RHV02`/;00[:b/0:2PX02h^;P0/;2`09bLW0P0Z:RX0:P0];Bd09BDU0410@01YJFT0Hf=S05aLG01H
F5P0MWIf06UYJ@10@4009bLW01dM7@0Q8B407QhN02<S8`0Z:RX0@D51075aL@2:RXX0SHf=06=SH`13
@d<0BDU905EEE@1^KVh0IFEU04A4A00^;Rh0<S8b03Xj>P0_;bl08b<S02/[:`14A4@0Hf=S05UIF@1M
GEd0@D5103Ti>@16ATH0EeMG07EeM@80KFe]00H0JVYZ07UiN@2JVYX0Q8B4065QH@1=CDd20492@P0W
05ADE01FEUH0AdM703hn?P1MGEd0PX:207YjNP1bLW80MWIf071`L01eMGD0HV9R05IFEP1^KVh0Ti>C
0::RXP27QhL0MGEe07inOP23Ph<0R8R807]kN`1OGel0IFEU075aL@1nOWh0XJ6Q09JFUP1RHV80<c<c
02TY:@0d=3@0Cdm?06EUI@1^KVh0Xj>S08F5Q@13@d<0<S8b0080>CTi00h0ADE504];B`0o?cl0<c<c
03Lg=`0/;2`0;Rh^02PX:00/;2`0;Rh^03Ti>@1OGel0BDU904A4A080<C4a00<0<c<c03Ph>00h>3P0
0P0f=SH03P0c<c<0>SXj02l_;`0a<C40;Rh^034a<@0e=CD0>CTi03Hf=P0j>SX0ATI604E5A@0d=3@0
<c<c0P0g=cL02@0c<c<0=CDe02/[:`0b<S80=CDe03@d=00f=SH0<S8b03Hf=P0203hn?P0F03/k>`16
ATH0C4a<05=CD`1<C4`0>SXj03Ph>00i>CT0>SXj03@d=00a<C40=cLg04A4A01DE5@0DE5A05QHF01S
Hf<0IFEU06YZJP1gMgL0MWIf07MgM`80LW9b0P1dM7@05P1jNWX0N7Qh07emO@1jNWX0P82007alO01o
Ogl0Ph>30820P01lO7`0NWYj07]kN`24Q8@0QhN708F5Q@29RHT0S8b<08V9R@2?Shl0SXj>096AT@2;
Rh/208n?S`0908V9R@2@T900QXJ608b<S026QXH0RXZ:08j>SP25QHD0R8R80080Rh^;00H0T92@09:B
TP2?Shl0TY:B09>CT`2GUiL209^KV`0409bLW02PX:00YjNW0:j^[P80[Jf]00L0[jn_0;6a/@2f][H0
][Jf0;Rh^02i^KT0^k^k0080_kno00<0_Kfm0<30`02m_Kd00P2l_;`01`32`/80`<300<C4a034a<@0
`L710<?3``31`L400P37alL20<W9b@80b/[:0P3<c<`04`3=cLd0d=3@0=3@d03?cll0d=3@0=;BdP3A
dM40d];B0=GEe@3De=@0d=3@0<?3``2OWil0Lg=c0492@P0a<C40;Rh^034a<@0^;Rh00P0j>SX08`0d
=3@0>CTi05eMG@1SHf<0GemO04M7A`10@400C4a<04e=C@1>CTh0D51@04Q8B015ADD0DE5A04U9B@1K
Fe/0E5AD04Y:BP10@400B4Q804a<C00o?cl0=3@d04I6AP0m?Cd0M7Ad0:RXZ02PX:00Vi^K09BDU02:
RXX0QhN708B4Q02=SHd0UiNG0080TI6A00<0TY:B096AT@2>SXh00P2CTi<00`2ATI40Shn?08j>SP02
08n?S`0?08^;R`26QXH0S8b<08f=S@28R8P0QXJ608V9R@26QXH0RHV908J6QP2;Rh/0QXJ608V9R@23
Ph<0Q8B40080P82000L0PH6107QhN01jNWX0NGUi07YjNP1nOWh0MGEe0080L71`00@0LW9b06UYJ@1X
J6P0IfMW0P1/K6`03P1VIVH0GEeM05YJFP1FEUH0FEUI06QXJ01ZJVX0JFUY079bLP22PX80Ph>307in
OP1mOGd0Lg=c0P1ZJVX04`1EEED0BDU904I6AP1ADE40JFUY09NGU`2a/K40a<C40<[:bP3@d=00d];B
0=3@d03Bd]80c/k>0=3@d03>c/h0dM7A0=?Cd`3Fe]H00P3EeMD00`3Cdm<0d];B0=7Ad@020=3@d080
c/k>00X0c<c<0<[:bP32`/80/;2`0:RXZ02JVYX0RHV907UiN@1IFET0@4100P0_;bl03P0Z:RX0<S8b
03Hf=P0n?Sh0ADE504];B`1?Cdl0DE5A059BDP1;Bd/0D51@04m?C`1DE5@0CTi>0P1BDU803P1FEUH0
EeMG05UIF@1OGel0EeMG069RHP1MGEd0FEUI05EEE@1BDU80De=C05MGE`1ADE40EUIF3P38h=P000`0
b>3H0P2:RXX03@25QHD0Q8B408b<S026QXH0QHF508:2PP1nOWh0NGUi07MgM`1[Jf/0GemO05eMG@1E
EED00P1ADE405P1BDU80De=C04e=C@19BDT0A4A403dm?@0k>c/0;bl_03Hf=P0b<S80=3@d03lo?`1<
C4`0F5QH06MWI`1^KVh0O7al08N7Q`2BTY80VYZJ0:2PX02RXZ820:NWY`040:VYZ@2[Zj/0Zj^[0:RX
Z0<0ZJVY0180[jn_0:f][@2[Zj/0ZZZZ0:VYZ@2][Jd0[jn_0:b/[02XZ:P0ZZZZ0:NWY`2TY:@0VYZJ
09>CT`2?Shl0QXJ607YjNP1^KVh205iNGP0C06a/K02PX:00IFEU065QH@30`<00`/;205iNGP0X:2P0
;2`/03<c<`0Y:BT09bLW02PX:00_;bl0:BTY02h^;P0Z:RX0;2`/02/[:`0202PX:00X03De=@0n?Sh0
?Cdm04Q8B017AdL0OWin07AdM012@T809RHV020P800T92@08b<S02@T900b<S80>SXj04];B`23Ph<0
S8b<07AdM017AdL0BDU904i>CP1QHF40MWIf06=SH`0g=cL0;Bd]03Lg=`0[:b/09bLW02PX:00d=3@0
BDU9055AD@1HF5P0EEEE04e=C@1[Jf/0SHf=08J6QP80NGUi0P1SHf<08`21PH40UIFE08j>SP1oOgl0
ADE504A4A01@D500@D5103dm?@1BDU80OWin07moO`1[Jf/0L71`06i^KP1iNGT0K6a/04a<C01BDU80
QhN709jNWP2@T900N7Qh07IfMP22PX80QhN708R8R01hN7P0K6a/06UYJ@1/K6`0VYZJ09^KV`1WIfL0
=CDe0080;bl_01`0FUYJ08B4Q01TI6@0W9bL0:6QX@1GEeL0<c<c02l_;`0g=cL0>SXj04M7A`18B4P0
CTi>03@d=00c<c<0:b/[02h^;P0X:2P092@T02PX:00m?Cd0Hf=S05MGE`0o?cl0>3Ph03<c<`0^;Rh0
=cLg0P0l?3`00`0b<S80<C4a03Hf=P0202h^;P0:02d];@0e=CD0?Shn03Ph>00c<c<0>SXj04m?C`17
AdL0<S8b03<c<`<0<S8b00L0<30`03@d=00b<S80=3@d02l_;`0j>SX0=CDe0080>SXj01L0?Cdm03/k
>`11@D40ATI604a<C013@d<0>3Ph0451@@0j>SX0>CTi03De=@0a<C40>3Ph03hn?P1?Cdl0D51@05UI
F@1OGel0Hf=S06e]K@1_Kfl0KVi^071`L00207IfMP0K07AdM01jNWX0NGUi07UiN@20P800O7al07in
OP1lO7`0Ogmo08B4Q022PX80PH6107inOP1hN7P0Ogmo0861P@24Q8@0RHV908^;R`25QHD0SXj>08f=
S@2;Rh/0S8b<08f=S@2ATI40SHf=0080S8b<00P0SHf=08b<S02;Rh/0SHf=08b<S029RHT0S8b<096A
T@80Ti>C00<0RXZ:09:BTP2CTi<00P2FUYH209bLW00309jNWP2SXj<0YZJV00<0[Jf]00H0[jn_0;:b
/P2f][H0][Jf0;Zj^P2k^k/20;bl_0090;no_`2n_[h0_Kfm0;fm_@2n_[h0`L710<30`034a<@0`/;2
0080a<C400D0`L710<[:bP37alL0bl_;0<S8b0020<_;b`050<k>cP3:b/X0bl_;0<k>cP3AdM40103B
d]820=CDe00_0<c<c02j^[X0TI6A06=SH`0j>SX0;Rh^028R8P0U9BD0:RXZ02`/;00m?Cd0?3`l030`
<011@D40G5aL06EUI@1SHf<0@D5103lo?`1:BTX0Bd];04a<C01ADE40@T9204U9B@1>CTh0ADE504e=
C@1DE5@0Bd];04M7A`16ATH0Bd];03hn?P0j>SX0@d=303Xj>P1bLW80X:2P0:>SX`2IVIT0UIFE08f=
S@29RHT0Ph>308V9R@2EUID00`2CTi<03@2DU9@0T92@092@T02=SHd0Shn?08j>SP2ATI40S8b<09:B
TP29RHT0Rh^;08J6QP2:RXX00P28R8P208V9R@0Z08R8R025QHD0QXJ608J6QP29RHT0QXJ607moO`1k
Ng/0P82007]kN`1hN7P0OWin07UiN@1bLW80MGEe079bLP1dM7@0KVi^06YZJP1^KVh0J6QX06MWI`1L
G5`0IVIV06=SH`1LG5`0EUIF05UIF@1FEUH0H61P05mOG`1ZJVX0MWIf07UiN@21PH40NWYj07MgM`1f
MWH0LG5a06IVIP1IFET0Cdm?0P1<C4`02P1SHf<0T92@0;2`/031`L40c<c<0<o?c`3Bd]80d=3@0<k>
cP3?cll20<k>cP050=7Ad@3Bd]80e=CD0=CDe03Cdm<00`3@d=007`3?cll0d=3@0=3@d03@d=00clo?
0<_;b`36a/H0^[Zj0;6a/@2ZZZX0Xj>S096AT@23Ph<0H61P051@D00k>c/0;Rh^02d];@0c<c<0<C4a
0410@016ATH0B4Q804e=C@1?Cdl0EUIF051@D01:BTX0D51@04e=C@1BDU800P1CDe<205EEE@0505QH
F01IFET0FUYJ05]KF`1IFET00P1ADE40101IFET0F5QH05ADE01EEED>0<SPf0003038h=P208^;R`0W
08F5Q@27QhL0PX:208B4Q027QhL0Ogmo07=cL`1_Kfl0KFe]06=SH`1KFe/0FEUI059BDP1?Cdl0B4Q8
04I6AP1>CTh0DE5A04Q8B010@400>SXj03Ti>@0e=CD0<C4a02h^;P0`<300@41004a<C01KFe/0H61P
071`L020P800RHV909:BTP2JVYX0X:2P0:6QX@2UYJD0YjNW00<0ZJVY00@0[:b/0:RXZ02[Zj/0[:b/
0P2[Zj/00`2YZJT0YjNW0:ZZZP020;2`/00>0;:b/P2[Zj/0[:b/0:JVYP2RXZ80X:2P09FEU@2ATI40
PH61079bLP1YJFT0Fe]K05ADE01TI6@20861P@0805YJFP2d];@0dm?C07moO`0g=cL0;bl_02h^;P0]
;Bd202/[:`0C02PX:00[:b/0;bl_02PX:00Z:RX0<c<c02`/;00Y:BT0:2PX02XZ:P0e=CD0A4A4051@
D021PH40Ogmo04I6AP0Q8B407alO02@T900202HV9P0K02l_;`0e=CD0@D5107UiN@23Ph<0LG5a055A
D@1;Bd/0CDe=04m?C`1fMWH0NGUi04=3@`0a<C40;Bd]02h^;P0T92@09bLW03Hf=P0m?Cd0EEEE07em
O@2>SXh0Q8B4092@T02<S8`0O7al0080JFUY02d0IFEU05]KF`1IFET0MGEe08^;R`2ATI40AdM704=3
@`15ADD0>CTi05QHF01jNWX0PH6106e]K@1SHf<0IfMW079bLP1kNg/0GEeM04M7A`1_Kfl0UiNG08n?
S`1fMWH0Kfm_07UiN@1eMGD0PX:208^;R`1oOgl0PH6108Z:RP2@T900YJFU07]kN`1?Cdl0=3@d02h^
;P0o?cl0J6QX06ATI01SHf<0/k>c08:2PP0i>CT00P0f=SH0800d=3@0=SHf0451@@1:BTX0Cdm?03/k
>`0g=cL0;bl_02PX:00V9RH09BDU02PX:00k>c/0EeMG04e=C@0g=cL0=SHf03<c<`0b<S80>CTi03/k
>`0b<S80;Rh^02d];@0g=cL0=3@d02`/;00];Bd0=cLg03hn?P0i>CT0?3`l0P0i>CT00`0j>SX0<C4a
03Xj>P0203De=@80<S8b01h0=CDe03<c<`0f=SH0>CTi03Lg=`0c<c<0>3Ph03hn?P15ADD0@d=304Q8
B01=CDd0@d=303dm?@0f=SH0?clo03dm?@0b<S80=3@d03Hf=P0j>SX0@D5104];B`1DE5@0IFEU06IV
IP1YJFT0Jf][06m_K`1dM7@206i^KP0507AdM01bLW80NGUi07]kN`1iNGT00P1nOWh07`1oOgl0PH61
0861P@20P800QHF508J6QP1nOWh0Q8B407moO`22PX80R8R808V9R@27QhL0QXJ608V9R@2;Rh/0SHf=
08R8R02;Rh/0Shn?08j>SP2<S8`0Rh^;08Z:RP2>SXh0Rh^;08n?S`2<S8`0QXJ608Z:RP2;Rh/00P2?
Shl02P2=SHd0UIFE09BDU02DU9@0UiNG09bLW02QXJ40Vi^K0:>SX`2XZ:P20:VYZ@80[Jf]00@0/K6a
0;Jf]P2f][H0^k^k0P2n_[h00`2m_Kd0`L710;fm_@020;fm_@80_[jn00P0`<300<C4a038b<P0`l?3
0<G5a@36a/H0bLW90<S8b080b/[:00@0bl_;0<W9b@3:b/X0c<c<0P3>c/h03@3@d=00dM7A0=?Cd`3E
eMD0d];B0=7Ad@36a/H0[:b/08R8R01DE5@0<c<c02`/;00W9bL00P0T92@01@0d=3@0>CTi04];B`16
ATH0>3Ph0080EeMG0P1VIVH07P14A4@0@D5104U9B@1ADE40ATI605=CD`19BDT0A4A404Y:BP11@D40
BTY:059BDP11@D40B4Q804a<C01ADE40ADE503Ph>018B4P0=SHf06IVIP2FUYH0YJFU0:2PX02DU9@0
Shn?08Z:RP27QhL0R8R809ZJVP80T92@00X0TI6A09>CT`2@T900RXZ:08b<S02?Shl0SHf=08j>SP2A
TI40Shn?0P28R8P208J6QP0A08N7Q`23Ph<0QhN708F5Q@26QXH0Q8B408:2PP24Q8@0Ogmo07emO@1l
O7`0Ng]k07alO01kNg/0MgMg07=cL`1aLG400P1`L700101]KFd0KVi^06EUI@1XJ6P2069RHP0306AT
I01LG5`0GUiN0080H61P01T0FEUI05YJFP1JFUX0FUYJ061PH01SHf<0L71`07IfMP1kNg/0M7Ad07Ui
N@1aLG40JFUY05mOG`1CDe<0C4a<04M7A`1BDU80I6AT08n?S`2][Jd0`l?30<[:bP3?cll0d=3@00<0
c/k>00P0c<c<0<_;b`3?cll0clo?0=;BdP3Cdm<0e=CD0=;BdP80clo?00@0c/k>0=3@d03?cll0clo?
0P3=cLd06`39bLT0`L710;no_`2g]kL0/[:b0:ZZZP2KVi/0QHF5079bLP1DE5@0@T9203<c<`0];Bd0
;Rh^03Ph>010@400ADE504];B`1?Cdl0CTi>04m?C`1@D500BTY:04M7A`1=CDd0CTi>04U9B@0205=C
D`0;05ADE01IFET0EEEE05=CD`1LG5`0De=C05]KF`1JFUX0Fe]K05UIF@1GEeL03P38h=P000`0b>3H
0P25QHD208B4Q00U08>3P`1oOgl0OGem07QhN01/K6`0HV9R05aLG01FEUH0EeMG04m?C`17AdL0@T92
04=3@`0o?cl0CTi>04];B`0k>c/0?clo03Ph>00i>CT0<30`03De=@0_;bl0=cLg0492@P16ATH0EUIF
06MWI`1bLW80OWin08V9R@2BTY80UiNG09fMW@2RXZ80YjNW0:VYZ@030:b/[00:0:RXZ02YZJT0[:b/
0:n_[`2/[:`0Zj^[0:f][@2YZJT0[:b/0;Jf]P<0];Bd00X0/K6a0:FUY@2QXJ40WinO09NGU`2;Rh/0
QHF507UiN@1ZJVX0Fe]K0P1ADE403@1QHF40RHV906QXJ02@T900cLg=0::RXP0l?3`0<c<c02h^;P0U
9BD09bLW02h^;P0V9RH00`0X:2P02@0V9RH0:RXZ030`<00Y:BT0:RXZ02TY:@0c<c<0CDe=05mOG`02
07MgM`0Q04M7A`0O7al07AdM024Q8@0V9RH0:RXZ038b<P0i>CT0A4A407MgM`1hN7P0JVYZ05EEE@19
BDT0Cdm?04a<C01RHV80LW9b0451@@0U9BD08R8R02<S8`0T92@0:RXZ03Ti>@1ADE40MGEe09>CT`2=
SHd0Q8B408J6QP1gMgL0IFEU0080FEUI00`0Jf][05eMG@10@400FUYJ07alO02>SXh0JFUY0410@00c
<c<0EUIF07UiN@1oOgl206MWI`0`06ATI01YJFT0M7Ad06a/K01DE5@0FUYJ08J6QP21PH40OGem06e]
K@1cLg<0KVi^071`L01gMgL0PX:206][J`26QXH0Y:BT0::RXP1nOWh0FUYJ06UYJ@14A4@0=CDe05=C
D`1OGel0D51@09>CT`2NWYh0EeMG03<c<`0g=cL0=SHf03@d=00h>3P0A4A404I6AP1CDe<0@T9203<c
<`0a<C40<30`02`/;00W9bL0:RXZ03Ph>01BDU80Cdm?0P0e=CD0500];Bd0:b/[03De=@0d=3@0;bl_
030`<00^;Rh0<C4a02l_;`0Y:BT0;2`/03@d=00h>3P0=cLg03dm?@0f=SH0<S8b03<c<`0d=3@0<c<c
0`0^;Rh0100b<S80<30`03@d=00i>CT203Xj>P0E03Hf=P0n?Sh0?Cdm03hn?P0o?cl0C4a<04Y:BP11
@D40>3Ph03Lg=`0h>3P0=SHf038b<P0a<C40<S8b03Lg=`0n?Sh0ATI6055AD@1OGel0HV9R0080IfMW
02/0Lg=c07AdM01bLW80MgMg07YjNP1hN7P0O7al07]kN`1jNWX0Ng]k07YjNP1hN7P0OWin0820P01m
OGd0P82008>3P`20P800OGem07moO`27QhL0RXZ:08B4Q027QhL0QHF508^;R`29RHT0QhN708^;R`29
RHT0RXZ:08j>SP2;Rh/0Shn?08V9R@2:RXX0SHf=08R8R02=SHd0RHV908Z:RP2=SHd0Shn?00<0T92@
00H0U9BD09JFUP2FUYH0V9RH09ZJVP2PX:020:>SX`80YjNW00L0ZJVY0:b/[02b/[80^KVi0;Ng]`2j
^[X0_kno0080_[jn0P2o_kl05@31`L40`l?30;no_`31`L40`l?30<C4a037alL0a/K60<O7a`3:b/X0
b<S80<_;b`3<c<`0c/k>0<c<c03:b/X0c<c<0=3@d03;bl/0d=3@0<o?c`020=CDe00c0=?Cd`3?cll0
_kno09VIV@1_Kfl0BTY:02`/;00[:b/0:BTY024Q8@0T92@09BDU03Lg=`0e=CD0CTi>04M7A`18B4P0
EeMG059BDP1XJ6P0H61P04I6AP18B4P0BTY:05IFEP17AdL0Cdm?04M7A`18B4P0Bd];03`l?01BDU80
Cdm?04I6AP1;Bd/0B4Q804m?C`1<C4`0?3`l04];B`0c<c<0H61P08j>SP2ZZZX0VIVI09:BTP2?Shl0
T92@08V9R@26QXH0V9RH0080T92@00h0Shn?08j>SP2<S8`0Rh^;08b<S02>SXh0Q8B408j>SP2FUYH0
Rh^;08J6QP28R8P0QXJ608F5Q@80Q8B400<0QXJ608F5Q@22PX800P20P8003`1nOWh0PH6107inOP1j
NWX0M7Ad07EeM@1aLG40Lg=c075aL@1bLW80KFe]06QXJ01WIfL0K6a/06ATI00206=SH`0605mOG`1R
HV80GEeM06=SH`1RHV80HF5Q0P1IFET0201JFUX0HV9R05YJFP1QHF40J6QX06m_K`1eMGD0LG5a0P1^
KVh02`1XJ6P0GEeM04m?C`1<C4`0BDU9051@D01YJFT0S8b<0:f][@2o_kl0bLW90080clo?00T0d=3@
0<k>cP3<c<`0c/k>0<c<c03>c/h0cLg=0=7Ad@3Cdm<00P3Bd]80103@d=00c/k>0=3@d03>c/h20<g=
c@040<c<c03=cLd0b/[:0<O7a`80`l?30240_;bl0;Jf]P2YZJT0WIfM08j>SP1cLg<0De=C03Ph>00_
;bl0:2PX030`<00c<c<0@41004U9B@1ADE40C4a<04e=C@1;Bd/0BTY:04a<C019BDT0C4a<04Q8B01@
D500EEEE055AD@1HF5P0DU9B04m?C`1IFET0DU9B05]KF`1LG5`00`1FEUH>0<SPf0003038h=P30820
P00708>3P`20P800NWYj075aL@1ZJVX0H61P05UIF@0205IFEP0N055AD@11@D40ADE503Xj>P0m?Cd0
@41004M7A`15ADD0@41003Xj>P0e=CD0>3Ph03@d=00_;bl0<c<c03Xj>P12@T80C4a<05IFEP1YJFT0
L71`07emO@28R8P0T92@09NGU`2MWId0XJ6Q0:ZZZP2[Zj/0ZJVY0P2ZZZX01P2[Zj/0[Zj^0:b/[02]
[Jd0[:b/0:j^[P80Zj^[0P2][Jd0702f][H0_Kfm0<?3``2l_;`0ZJVY0:>SX`2OWil0VYZJ08Z:RP22
PX80N7Qh06e]K@1KFe/0Cdm?0492@P1?Cdl0Kfm_07EeM@1bLW80]kNg0:b/[01PH600@41002h^;P0Z
:RX092@T02DU9@0W9bL202TY:@0=02LW9`0V9RH09RHV02d];@0_;bl0:RXZ02d];@11@D40F5QH069R
HP1QHF40LG5a04e=C@02020P800302<S8`0a<C40<C4a0080>CTi00/0CDe=07EeM@1/K6`0HV9R05EE
E@1=CDd0Bd];0492@P1ADE40Jf][04=3@`0202DU9@0<024Q8@0X:2P0>3Ph04a<C023Ph<0Q8B408>3
P`1kNg/0N7Qh06QXJ01FEUH0BTY:0P1<C4`0A@1DE5@0HV9R04];B`1ADE40O7al08b<S01hN7P0>CTi
0451@@1UIFD0LG5a065QH@1PH600Hf=S05YJFP1SHf<0IfMW06IVIP1SHf<0O7al07moO`1`L700MGEe
06m_K`1cLg<0L71`06a/K01`L700Lg=c05mOG`2FUYH0Zj^[08R8R01BDU80@T9205MGE`1:BTX0DE5A
04i>CP1;Bd/0Jf][09JFUP1TI6@0<c<c02l_;`0d=3@0>SXj03De=@0a<C40?clo04a<C01KFe/0@410
03De=@0_;bl0;Bd]02LW9`0T92@0;2`/03Xj>P1@D500GemO03Xj>P0a<C40;Bd]02h^;P0h>3P0<S8b
034a<@0202d];@0703De=@0b<S80;bl_034a<@0f=SH0?Cdm03Lg=`0203Ph>00403Xj>P0b<S80=3@d
034a<@80<30`00@0;Rh^02d];@0a<C40?3`l0P0h>3P203Hf=P0B03hn?P0m?Cd0=cLg03Xj>P15ADD0
BDU90410@00g=cL0=3@d03`l?00i>CT0<S8b030`<00c<c<0=CDe04M7A`1=CDd0DE5A0P1LG5`01`1[
Jf/0K6a/071`L01cLg<0M7Ad07EeM@1jNWX00P1nOWh207UiN@0C07inOP1mOGd0N7Qh07alO01nOWh0
P82007alO022PX80Ph>30861P@24Q8@0QhN708V9R@25QHD0Rh^;08F5Q@2:RXX0QhN708J6QP0208V9
R@0:08f=S@29RHT0SXj>08b<S029RHT0SXj>09>CT`2@T900S8b<08Z:RP80Rh^;00D0S8b<08f=S@2B
TY80SHf=08n?S`0209BDU00509:BTP2JVYX0WIfM09nOW`2SXj<00P2YZJT0102_[jl0/;2`0;Fe]@2h
^;P20;^k^`030;no_`30`<00_[jn0080`L7100<0`/;20<?3``33`l<00P34a<@20<[:bP070<_;b`39
bLT0b<S80<_;b`3:b/X0c<c<0<W9b@020<[:bP030<k>cP3;bl/0c/k>0080dM7A00T0e=CD0=7Ad@34
a<@0ZJVY08V9R@1MGEd0=cLg034a<@0[:b/00P0U9BD202HV9P0402DU9@0a<C40<c<c04Q8B080BTY:
00/0G5aL059BDP1/K6`0IVIV04=3@`1?Cdl0Bd];05UIF@1:BTX0EEEE04Y:BP0204a<C0030492@P1B
DU80EEEE0080BDU900T0ADE504Q8B01:BTX0@D51055AD@0a<C40GEeM096AT@2_[jl00`2EUID0102C
Ti<0RHV908:2PP2BTY8208j>SP80S8b<0`29RHT01P2;Rh/0SXj>08Z:RP2?Shl0RHV908B4Q080R8R8
0180QHF508B4Q024Q8@0PH6107inOP1oOgl0Q8B407UiN@1mOGd0NGUi07MgM`1jNWX0Kfm_06i^KP1a
LG40Jf][06UYJ@1_Kfl206YZJP05069RHP1UIFD0Hf=S065QH@1RHV800P1QHF40701NGUh0Hf=S061P
H01NGUh0Hf=S05UIF@1MGEd0H61P06ATI01NGUh0J6QX06i^KP1[Jf/0LW9b06i^KP1VIVH0I6AT05aL
G01FEUH0CTi>04e=C@1IFET0Jf][092@T02][Jd0`<300<W9b@3?cll20=7Ad@<0c/k>00D0c<c<0<_;
b`3>c/h0clo?0=7Ad@020=;BdP030=7Ad@3@d=00clo?00<0d=3@0280c/k>0<o?c`3=cLd0b/[:0<W9
b@37alL0a<C40<30`02f][H0YjNW09bLW029RHT0JFUY04a<C00];Bd09bLW02d];@0[:b/0;bl_03De
=@11@D40?Shn0451@@12@T80AdM704E5A@14A4@0AdM704];B`1>CTh0D51@04m?C`1FEUH0E5AD0P1C
De<00`1ADE40F5QH05EEE@0205=CD`0305ADE038h=P0b>3H00`0b>3H000<0<SPf080PH6101<0OWin
07UiN@1bLW80Kfm_06QXJ01IFET0EeMG051@D01?Cdl0CDe=04Y:BP0o?cl0>c/k03Ph>00e=CD0?3`l
04I6AP12@T80@4100080>3Ph01<0?Shn03Lg=`0`<300=cLg03Ti>@14A4@0Cdm?05aLG01WIfL0Lg=c
07inOP2:RXX0UIFE09bLW02PX:00YJFU0:RXZ02ZZZX0Zj^[00<0[:b/0P2][Jd0102ZZZX0Zj^[0:ZZ
ZP2ZZZX20:f][@1<0:b/[02a/K40^KVi0;fm_@39bLT0`L710;Bd]02MWId0V9RH08f=S@22PX80MWIf
06QXJ01KFe/0Bd];04A4A018B4P0EEEE07]kN`1MGEd0Shn?0:RXZ02@T900GUiN03hn?P0_;bl0:BTY
02PX:00Z:RX08b<S02TY:@0W9bL0:BTY02/[:`0_;bl0;Bd]03De=@0l?3`0AdM705eMG@1@D500BTY:
05UIF@1CDe<092@T01lO7`0V9RH0:b/[03@d=00a<C40?3`l05=CD`1bLW80IVIV069RHP1ADE40C4a<
04];B`16ATH0?3`l05YJFP1CDe<0:2PX024Q8@0N7Qh0<S8b04M7A`1oOgl0TY:B07]kN`24Q8@0N7Qh
065QH@18B4P0=3@d03dm?@80@d=300L0CDe=05QHF018B4P0EEEE08b<S02BTY80S8b<0080BDU902`0
GUiN05QHF01KFe/0GemO06a/K01SHf<0FEUI05mOG`1RHV80Q8B408:2PP1_Kfl0LW9b06QXJ01iNGT0
KFe]06MWI`1]KFd0N7Qh07alO01`L700/;2`0;Vi^@1kNg/0GUiN055AD@1MGEd0CDe=0451@@16ATH0
OGem0:RXZ01nOWh0<c<c02/[:`0^;Rh0<C4a03`l?00n?Sh0?3`l04E5A@16ATH0F5QH04M7A`80<30`
01d0<C4a02`/;00X:2P0;Rh^03Ti>@1CDe<0G5aL03lo?`0_;bl0<C4a02d];@0e=CD0=cLg02h^;P0_
;bl0:RXZ03Hf=P0d=3@0;Bd]034a<@0m?Cd0?Shn03Hf=P0e=CD0<C4a03<c<`0`<300=SHf034a<@02
02l_;`0502d];@0a<C40;Rh^03<c<`0h>3P00P0j>SX02@0o?cl0?3`l03dm?@0f=SH0?Shn03`l?00m
?Cd0?Shn0451@@0203Ti>@0[03Xj>P0^;Rh0;bl_038b<P0i>CT0CTi>055AD@1DE5@0Fe]K05iNGP1Z
JVX0Kfm_07IfMP1mOGd0NGUi07AdM01lO7`0Ng]k07YjNP1mOGd0Ng]k07inOP21PH40OGem07moO`1m
OGd0PH610820P01iNGT0QHF50861P@23Ph<0Rh^;08R8R02<S8`0QXJ608R8R029RHT0QXJ608N7Q`2;
Rh/0RXZ:08j>SP0208b<S00<096AT@2<S8`0RXZ:08b<S02>SXh0Rh^;08f=S@2<S8`0Rh^;08f=S@2;
Rh/0T92@0P2>SXh00`2?Shl0UIFE09>CT`0209VIV@0309nOW`2RXZ80ZZZZ0080ZZZZ00@0[:b/0:f]
[@2d];@0^;Rh0P2n_[h02`2o_kl0`L710<71`@34a<@0`L710<K6aP37alL0a<C40<G5a@38b<P0b/[:
00<0bLW900P0cLg=0<_;b`3:b/X0bLW90<_;b`3<c<`0cLg=0<c<c0<0dM7A00L0bLW90;Bd]02CTi<0
JVYZ04Q8B00b<S80:BTY00809RHV02`0:RXZ02@T900S8b<092@T02PX:00b<S80<30`0492@P1?Cdl0
BDU905eMG@1EEED0K6a/05mOG`11@D40AdM704m?C`1HF5P0Cdm?05UIF@1@D500CDe=051@D014A4@0
D51@05EEE@16ATH0BDU90451@@1?Cdl0@d=303Ti>@1@D500<C4a05]KF`2;Rh/0/k>c09ZJVP2HV9P0
S8b<09>CT`29RHT0OWin08f=S@80RHV900l0Rh^;08b<S028R8P0QXJ608^;R`29RHT0RXZ:092@T02=
SHd0QHF508>3P`26QXH0PH6107inOP23Ph<00P1oOgl04@22PX80OWin07]kN`1iNGT0M7Ad07EeM@1j
NWX0Lg=c075aL@1/K6`0Jf][069RHP1XJ6P0JFUY06IVIP1UIFD0Hf=S0080I6AT00l0IfMW065QH@1P
H600H61P069RHP1VIVH0Hf=S065QH@1OGel0IFEU05eMG@1SHf<0I6AT065QH@1TI6@00P1^KVh03`1/
K6`0KVi^06m_K`1SHf<0GEeM05YJFP1HF5P0E5AD05UIF@1gMgL0UiNG0:b/[030`<00bLW90=3@d002
0=7Ad@050<o?c`3;bl/0c/k>0<c<c03;bl/00P3>c/h01`3?cll0dM7A0<o?c`3@d=00cLg=0=?Cd`3@
d=000P3?cll01@3>c/h0dM7A0<k>cP3=cLd0c<c<0080b/[:00/0aLG50;^k^`2b/[80ZJVY09RHV024
Q8@0H61P04E5A@0d=3@0;Rh^02`/;00203<c<`07038b<P0g=cL0?Cdm03/k>`15ADD0@T9204I6AP02
04=3@`0904U9B@1<C4`0BDU905IFEP1GEeL0EEEE051@D01ADE40E5AD0080EeMG0P1IFET>0<SPf000
3038h=P207UiN@0=07AdM01aLG40Hf=S06=SH`1MGEd0DU9B055AD@1<C4`0BDU903lo?`11@D40>CTi
03Ph>00203@d=00I03Ph>00g=cL0@41003`l?00d=3@0>3Ph03`l?00f=SH0;bl_038b<P0k>c/0@D51
04Y:BP1LG5`0KFe]07IfMP1oOgl0R8R8096AT@2IVIT0WYjN0:>SX`2XZ:P0ZJVY0:^[Z`020:VYZ@08
0:ZZZP2[Zj/0[Jf]0:NWY`2ZZZX0[Jf]0:VYZ@2/[:`20:ZZZP0Q0;6a/@2b/[80/K6a0;Rh^02o_kl0
^[Zj0;:b/P2[Zj/0V9RH0861P@1cLg<0IfMW05IFEP1>CTh0@T9204M7A`12@T80H61P069RHP1EEED0
RHV909NGU`24Q8@0EUIF034a<@0[:b/092@T030`<00^;Rh0<C4a02PX:00W9bL0:2PX0080;Bd]00X0
>c/k04a<C01EEED0E5AD0410@00`<300AdM705ADE00[:b/09BDU0P0];Bd0700f=SH0;Rh^03/k>`1I
FET0K6a/06IVIP1EEED0?Cdm04U9B@1:BTX0?clo03Ph>01=CDd0DE5A02`/;00R8R8092@T03`l?01^
KVh0V9RH08N7Q`1iNGT0M7Ad05]KF`1GEeL0?Cdm03`l?01>CTh205]KF`0f06UYJ@1jNWX0LW9b07]k
N`2@T900WYjN0:6QX@20P800E5AD0410@017AdL0Cdm?06IVIP1YJFT0GEeM04];B`1FEUH0LW9b07Mg
M`1]KFd0IFEU06YZJP1^KVh0MGEe06=SH`1TI6@0HF5Q07EeM@1nOWh0Ti>C0;>c/`35aLD0Vi^K07]k
N`1oOgl0GemO03/k>`10@400Rh^;0;:b/P2NWYh0EeMG03<c<`0Y:BT0<30`02h^;P0i>CT0<c<c03Hf
=P12@T80Bd];05QHF01<C4`0=cLg0P0^;Rh06P0X:2P0<C4a03<c<`0h>3P0EEEE05]KF`0j>SX0;Rh^
030`<00_;bl0>3Ph03De=@0a<C40;Bd]038b<P0e=CD0;Rh^02/[:`0`<300<c<c03Lg=`0f=SH0=3@d
03<c<`0a<C40;Bd]0P0c<c<203De=@03034a<@0`<300=3@d0080<c<c00T0=cLg03dm?@12@T80?Shn
04I6AP0h>3P0>c/k03Xj>P10@4000P0d=3@03`0g=cL0>CTi03`l?00a<C40<S8b03@d=00n?Sh0Cdm?
04U9B@1IFET0EeMG069RHP1]KFd0MWIf07UiN@0307YjNP04079bLP1iNGT0OWin0820P080OGem00<0
Ogmo07]kN`1nOWh00P1mOGd01P1lO7`0OWin07alO021PH40Q8B408b<S080RXZ:00/0QHF508N7Q`25
QHD0QhN708f=S@2;Rh/0QhN708^;R`2=SHd0S8b<08f=S@0208j>SP0308f=S@27QhL0S8b<0080S8b<
00@0SHf=08^;R`2BTY80SHf=0`2?Shl2092@T00409BDU02IVIT0Vi^K0::RXP80YJFU00h0Z:RX0:b/
[02/[:`0]KFe0;Vi^@2j^[X0_;bl0;jn_P2o_kl0a<C40<G5a@33`l<0alO70<W9b@<0alO700@0bLW9
0<O7a`3:b/X0c<c<0P3;bl/0503:b/X0b<S80<c<c03=cLd0clo?0=7Ad@3@d=00bLW90;Bd]02HV9P0
NGUi05MGE`0i>CT0<S8b02l_;`0Y:BT09bLW02@T900X:2P09BDU0P0T92@0:00Z:RX0=SHf034a<@11
@D40DE5A04i>CP1;Bd/0DU9B07=cL`1QHF40A4A404Y:BP1?Cdl0FUYJ04e=C@1FEUH0B4Q8055AD@1@
D500@D51055AD@1LG5`0CDe=04U9B@10@400BTY:04];B`10@400BDU903De=@1CDe<0RXZ:0;Fe]@2E
UID0V9RH09BDU02CTi<0Q8B407emO@25QHD208>3P`0308V9R@2;Rh/0QhN70080Q8B400H0QHF508b<
S02ATI40R8R808:2PP21PH4208:2PP060820P01mOGd0OWin07MgM`1fMWH0OWin0P1dM7@06`1_Kfl0
LW9b06m_K`1ZJVX0JFUY06YZJP1XJ6P0JFUY069RHP1VIVH0Hf=S06EUI@1VIVH0J6QX069RHP1TI6@0
FUYJ065QH@1TI6@0K6a/06IVIP1^KVh0IFEU06ATI01UIFD0IVIV06EUI@0206UYJ@0706EUI@1XJ6P0
KFe]06][J`1aLG40JFUY06ATI002061PH00906EUI@1OGel0HF5Q08:2PP2PX:00]KFe0<30`039bLT0
c/k>00<0dM7A00D0cLg=0<k>cP3<c<`0bLW90<_;b`020<o?c`80d=3@00@0cLg=0=3@d03@d=00clo?
0P3AdM400`3@d=00dM7A0=;BdP020=7Ad@0?0<k>cP3<c<`0a<C40<30`02f][H0/[:b0:RXZ02IVIT0
NGUi065QH@16ATH0<c<c02l_;`0];Bd0:b/[0080<30`00/0<S8b03Lg=`0n?Sh0@d=303dm?@10@400
@D5104E5A@14A4@0BTY:05ADE002059BDP80DE5A00D0DU9B05EEE@1FEUH0EEEE05]KF`0>0<SPf000
3038h=P206m_K`0906=SH`1WIfL0F5QH05MGE`1:BTX0@T9204M7A`12@T80?clo0080=SHf01d0=3@d
034a<@0^;Rh0<C4a03De=@0d=3@0@T9204A4A010@400@T9203/k>`0e=CD0>SXj03dm?@11@D40Bd];
05IFEP1YJFT0Lg=c07inOP23Ph<0Shn?09BDU02IVIT0Xj>S0:FUY@2XZ:P0Zj^[0:f][@020:VYZ@06
0:ZZZP2][Jd0ZZZZ0:ZZZP2/[:`0Zj^[0P2YZJT04@2XZ:P0/;2`0;2`/02^[Zh0Zj^[0:VYZ@2ZZZX0
Zj^[0;2`/032`/80_kno09ZJVP1kNg/0IVIV05QHF016ATH0?Shn0080@D5102X0C4a<05QHF00o?cl0
H61P08f=S@2XZ:P0PH6103Hf=P0W9bL08B4Q02LW9`0T92@0:RXZ02d];@0V9RH08R8R02/[:`0a<C40
AdM705MGE`1?Cdl0BTY:02l_;`0[:b/0>CTi03hn?P0k>c/0;Bd]030`<00d=3@0<30`03Ph>018B4P0
Jf][075aL@1ZJVX0DE5A03Xj>P0k>c/0ADE504=3@`0l?3`203hn?P0>02TY:@0Z:RX0<30`04i>CP28
R8P0SHf=08B4Q01cLg<0FUYJ05UIF@1ZJVX0M7Ad06m_K`1fMWH308V9R@05092@T02>SXh0SXj>09JF
UP2NWYh00P2MWId0AP1/K6`0@4100492@P1CDe<0Hf=S05eMG@1<C4`0Fe]K07=cL`1/K6`0H61P065Q
H@1TI6@0M7Ad07]kN`1hN7P0Hf=S051@D01;Bd/0I6AT09BDU02HV9P0U9BD0;Ng]`2OWil0QHF507em
O@1CDe<0=CDe07UiN@2g]kL0ZZZZ075aL@0m?Cd0:BTY02/[:`0Z:RX0<30`03Xj>P0f=SH0=3@d0451
@@19BDT0EeMG04Q8B00k>c/0;Rh^038b<P0[:b/0<c<c02h^;P0g=cL0E5AD05EEE@0m?Cd0=SHf038b
<P0_;bl0>SXj03Ph>00a<C40;2`/038b<P0/;2`0<30`02h^;P0f=SH0>c/k03Hf=P0g=cL203De=@04
02d];@0`<300<c<c02h^;P80=3@d00L0;bl_03Lg=`0c<c<0;bl_02XZ:P0_;bl0=SHf0080?Shn01L0
?clo03Ti>@0l?3`0>CTi0410@00m?Cd0=cLg03<c<`0m?Cd0>CTi02d];@0e=CD0=cLg04I6AP1;Bd/0
EEEE05IFEP1LG5`0GUiN06UYJ@1gMgL0MGEe079bLP0207YjNP0407alO01fMWH0Ng]k07moO`80P820
00D0OWin07]kN`1mOGd0OGem07]kN`0207emO@<0Q8B400T0RXZ:08>3P`2<S8`0Rh^;08Z:RP28R8P0
RHV908Z:RP2>SXh00P2:RXX01@2?Shl0SXj>092@T02@T900SXj>0080Shn?00`0RXZ:08b<S02@T900
SXj>08V9R@2:RXX0SHf=08j>SP2@T900TI6A08n?S`2ATI4309RHV0040:6QX@2TY:@0Y:BT0:f][@80
Zj^[0P2d];@0102h^;P0^k^k0;no_`31`L440<G5a@030<W9b@3:b/X0a/K60080b/[:00L0alO70<S8
b03:b/X0bl_;0<S8b03<c<`0bl_;0080c<c<03X0c/k>0<_;b`2g]kL0VYZJ07QhN01RHV80@D51030`
<00^;Rh0<C4a038b<P0];Bd0:RXZ02HV9P0T92@09RHV02PX:00T92@0:RXZ03De=@0j>SX0@d=305EE
E@1KFe/0BDU905QHF01eMGD0FUYJ04M7A`1ADE40CDe=05eMG@1<C4`0EeMG04];B`1>CTh0EUIF04A4
A01FEUH0G5aL055AD@1BDU80A4A404=3@`15ADD0ATI604A4A00f=SH0CDe=08Z:RP2f][H0XJ6Q09FE
U@2DU9@0UYJF08>3P`1nOWh0PH610P1nOWh09026QXH0Shn?08>3P`21PH40Q8B408F5Q@2<S8`0RXZ:
08R8R022PX80O7al07inOP1mOGd0PH6107MgM`1hN7P0MgMg07UiN@1jNWX0MGEe07=cL`1eMGD0LG5a
06a/K01YJFT0J6QX06YZJP1/K6`0JFUY06IVIP1WIfL0HV9R065QH@1WIfL0GUiN06MWI`80JVYZ00H0
JFUY06][J`1_Kfl0M7Ad06QXJ01/K6`306UYJ@80KVi^00H0L71`06][J`1_Kfl0L71`06YZJP1]KFd2
06m_K`0>06e]K@1WIfL0IfMW06MWI`1[Jf/0PH610:>SX`2i^KT0a<C40<k>cP3?cll0e=CD0=7Ad@3B
d]820<k>cP040<S8b03>c/h0c<c<0<c<c0@0d=3@00<0d];B0=7Ad@3Bd]800P3AdM420=3@d00H0=7A
d@3?cll0dM7A0=3@d03<c<`0b<S80<71`@2k^k/0]kNg0;2`/02[Zj/0U9BD07alO01TI6@0DE5A0451
@@0e=CD0>3Ph02l_;`0[:b/0:RXZ02/[:`0a<C40>SXj0P0i>CT01`0l?3`0@41004I6AP1<C4`0D51@
05=CD`1EEED00P1GEeL00`1CDe<0DE5A05=CD`0205UIF@h0b>3H000<0<SPf080GemO02L0DU9B055A
D@17AdL0ADE504];B`11@D40?Cdm03hn?P0b<S80>3Ph03De=@0h>3P0=SHf02l_;`0a<C40;bl_03@d
=013@d<0ADE503dm?@18B4P0?clo03Ti>@10@400>SXj04M7A`1BDU80G5aL06a/K01gMgL0OWin08F5
Q@2>SXh0U9BD09bLW02PX:00YJFU0:NWY`2_[jl0102[Zj/00`2YZJT0YjNW0:RXZ0020:^[Z`060:f]
[@2[Zj/0[:b/0:j^[P2_[jl0[Jf]0P2YZJT0:@2TY:@0X:2P09^KV`2e]KD0clo?0<c<c02PX:00MWIf
05EEE@16ATH0@41003Ph>01=CDd0B4Q804U9B@0g=cL0@D5106IVIP2WYjL0Y:BT05EEE@0c<c<0:2PX
02DU9@0Y:BT0:2PX02@T900R8R8092@T03@d=018B4P0Fe]K05QHF01>CTh0?Shn02`/;00[:b/0=CDe
04E5A@0m?Cd0;Rh^0080=CDe01`0>CTi03Hf=P13@d<0N7Qh06a/K01EEED0BDU90451@@0n?Sh0C4a<
0410@00h>3P0=cLg03hn?P0e=CD0>CTi04M7A`1aLG40Q8B408J6QP1nOWh0IFEU059BDP1JFUX0Ph>3
08n?S`24Q8@0N7Qh0P1kNg/0301hN7P0NWYj07inOP1hN7P0PH6109ZJVP2LW9`0YZJV09:BTP1MGEd0
BDU9059BDP80Cdm?01`0EEEE07MgM`1_Kfl0F5QH065QH@1KFe/0JVYZ0820P02BTY80P82005MGE`12
@T80?Shn05iNGP2ATI40MGEe07IfMP2QXJ40T92@07MgM`1fMWH0EeMG05QHF02VYZH0[:b/08:2PP19
BDT0?3`l0P0/;2`0300b<S80=SHf03Hf=P0l?3`0>SXj0410@01:BTX0De=C04E5A@0c<c<0:b/[02LW
9`<0:RXZ01L0>SXj04a<C01LG5`0?Shn03De=@0_;bl0;Rh^03<c<`0j>SX0=3@d038b<P0c<c<0<S8b
03@d=00/;2`0=3@d03Ti>@0l?3`0=3@d038b<P0_;bl0=CDe03Ph>00203Hf=P80<c<c00H0;Rh^03@d
=00i>CT0=3@d034a<@0f=SH203`l?00503/k>`0j>SX0>CTi03/k>`0i>CT00P0k>c/04@0e=CD0=3@d
03Ti>@0i>CT0;bl_03<c<`0d=3@0ADE504Q8B01BDU80FEUI05aLG01TI6@0JFUY07EeM@1_Kfl0MgMg
0080O7al00/0Ogmo07YjNP1nOWh0OGem07]kN`1mOGd0Ogmo07UiN@1kNg/0O7al07emO@0207moO`04
08>3P`24Q8@0QHF508B4Q080QhN700D0RXZ:08N7Q`2<S8`0Rh^;08V9R@0208^;R`0508b<S02>SXh0
SXj>09>CT`2DU9@00P2ATI400`2CTi<0RHV908^;R`02092@T00308b<S02=SHd0Shn?0080TI6A00L0
Shn?08j>SP2BTY80UYJF09RHV02GUiL0X:2P0080YJFU00<0Zj^[0:b/[02[Zj/00P2a/K401@2j^[X0
^k^k0;jn_P33`l<0`/;20080aLG501D0alO70<W9b@37alL0aLG50<[:bP39bLT0b<S80<c<c03:b/X0
bl_;0<[:bP3;bl/0c<c<0<[:bP33`l<0/[:b09bLW01jNWX0GUiN03lo?`0d=3@00P0a<C401`0Z:RX0
<30`03De=@0[:b/09RHV02XZ:P0b<S800P0Z:RX0300W9bL0<c<c03<c<`0f=SH0?Shn055AD@1IFET0
Bd];05mOG`1gMgL0Fe]K04I6AP80C4a<00<0F5QH051@D01DE5@00P1:BTX05P1BDU80ADE5059BDP1N
GUh0De=C051@D017AdL0@T9204m?C`1JFUX0Bd];03Lg=`1:BTX0QXJ60;Jf]P2SXj<0UIFE09NGU`2C
Ti<0QHF507moO`1jNWX208:2PP0B0820P02;Rh/0QHF508B4Q023Ph<0QXJ608^;R`25QHD0PH6107mo
O`1jNWX0Ogmo07inOP1kNg/0N7Qh07]kN`1dM7@0LG5a0P1bLW802@1WIfL0JFUY06i^KP1/K6`0IfMW
06UYJ@1[Jf/0KFe]06ATI00206][J`0906MWI`1ZJVX0JFUY06IVIP1]KFd0Jf][079bLP1aLG40L71`
0080MgMg00`0Lg=c079bLP1`L700M7Ad06i^KP1dM7@0LW9b07=cL`1hN7P0MWIf07AdM01cLg<207Qh
N080Kfm_01@0K6a/06e]K@1`L700Lg=c07]kN`2TY:@0^k^k0<S8b03=cLd0clo?0=GEe@3Bd]80dM7A
0<o?c`3;bl/0c/k>0<g=c@3>c/h0bl_;0<k>cP80clo?00@0d];B0=7Ad@3Bd]80dm?C0P3@d=001@3?
cll0dM7A0=;BdP3Bd]80dM7A0080cLg=02<0aLG50<C4a02n_[h0^KVi0;Fe]@2_[jl0YJFU09JFUP25
QHD0LG5a061PH019BDT0=CDe02HV9P0[:b/09RHV02`/;00^;Rh0<30`03Lg=`0o?cl0?Cdm03lo?`11
@D40B4Q804U9B@1=CDd0DU9B05MGE`1EEED0CTi>05QHF01@D500Fe]K05aLG00>0<SPf0003038h=P2
04];B`0X04=3@`18B4P0?Shn03hn?P13@d<0?Cdm03`l?00g=cL0>c/k03De=@0f=SH0=cLg03De=@0]
;Bd0<S8b02l_;`0a<C40=cLg04=3@`14A4@0@d=30492@P13@d<0@41004=3@`1<C4`0GEeM06ATI01`
L700OWin0861P@29RHT0SXj>09FEU@2KVi/0XZ:R0:FUY@2XZ:P0ZZZZ0:j^[P80[:b/02D0Z:RX0:^[
Z`2/[:`0[Jf]0:BTY02[Zj/0[:b/0:n_[`2ZZZX0[Zj^0;2`/02[Zj/0ZJVY0:>SX`2QXJ40X:2P09RH
V02LW9`0[:b/0<_;b`39bLT0Xj>S06YZJP1>CTh0@d=303dm?@1BDU80GEeM04Y:BP0o?cl0=CDe04=3
@`25QHD0ZJVY06m_K`0b<S80:BTY0080;Rh^00d0;Bd]02PX:00X:2P0;2`/03@d=01;Bd/0IVIV05QH
F01=CDd0>3Ph03<c<`0b<S80=SHf0080BDU901l0<c<c03Ph>00h>3P0>CTi03Xj>P10@400KVi^06YZ
JP1?Cdl0?Shn03/k>`0e=CD0>CTi03Lg=`0`<300=SHf04U9B@14A4@0Bd];06UYJ@20P800PH6108Z:
RP1dM7@0F5QH065QH@20P800SHf=08j>SP1eMGD0E5AD0080De=C01D0E5AD05IFEP1EEED0HF5Q071`
L026QXH0TI6A09nOW`2MWId0Q8B405IFEP1=CDd0@d=304Q8B01XJ6P0KVi^05IFEP1CDe<0G5aL06EU
I@1kNg/00P29RHT02P1]KFd0AdM704U9B@16ATH0Hf=S061PH01BDU80Lg=c09RHV02IVIT207MgM`0F
07UiN@2MWId0/[:b08n?S`1@D500;Rh^02d];@0_;bl0=cLg034a<@0f=SH0?clo03hn?P14A4@0@d=3
04];B`1HF5P0CTi>03`l?00i>CT0<c<c02XZ:P80;Bd]00h0>3Ph04I6AP1GEeL0@41003lo?`0d=3@0
;Rh^03Ph>00l?3`0=SHf030`<00];Bd0<C4a02`/;080=SHf00P0>SXj03lo?`0b<S80<C4a02h^;P0b
<S80>CTi03@d=0<0=CDe00l0=cLg03@d=00c<c<0;bl_034a<@0h>3P0>CTi0410@00l?3`0>SXj03Lg
=`0i>CT0?3`l03lo?`0j>SX00P0f=SH06@0k>c/0=CDe034a<@0i>CT0?Cdm04U9B@1@D500E5AD05YJ
FP1GEeL0H61P06UYJ@1dM7@0LW9b07IfMP1kNg/0NWYj07moO`20P800OGem0820P021PH40Ng]k07al
O020P8000P1oOgl01022PX80P82008>3P`25QHD208>3P`0608Z:RP23Ph<0Rh^;08R8R02;Rh/0SHf=
0P2;Rh/208N7Q`0408b<S02ATI40T92@09BDU080Ti>C0P2DU9@0302@T900SHf=08n?S`2CTi<0S8b<
092@T02?Shl0T92@08f=S@2?Shl0T92@09>CT`80U9BD00T0VYZJ09bLW02RXZ80XZ:R0:RXZ02][Jd0
[Zj^0;2`/02b/[800P2i^KT00`2m_Kd0`<300<C4a0020<G5a@060<K6aP37alL0alO70<[:bP37alL0
bl_;0P39bLT20<c<c00a0<W9b@3:b/X0`/;20:j^[P2DU9@0MgMg05mOG`17AdL0?Shn03Hf=P0c<c<0
=3@d03<c<`0a<C40=CDe03`l?00a<C40:b/[030`<00c<c<09RHV030`<00/;2`0<S8b03/k>`0m?Cd0
@D5105YJFP1FEUH0EeMG06ATI01aLG40FEUI04Y:BP1IFET0Cdm?05iNGP1?Cdl0EEEE04M7A`1<C4`0
Cdm?04U9B@1EEED0GemO05ADE01=CDd0ADE504A4A00205EEE@0<04i>CP0k>c/0BDU907moO`2e]KD0
YjNW09>CT`2HV9P0U9BD08N7Q`20P800Lg=c0P1lO7`0301jNWX0Rh^;08:2PP21PH40Ph>308J6QP21
PH40N7Qh07MgM`1mOGd0NGUi07YjNP<0M7Ad0180Lg=c06m_K`1]KFd0LW9b071`L01YJFT0KVi^06][
J`1YJFT0J6QX06a/K01ZJVX0K6a/06YZJP1[Jf/0KVi^06QXJ01]KFd206UYJ@0@06e]K@1bLW80L71`
07=cL`1bLW80Lg=c07EeM@1aLG40NGUi07AdM01jNWX0Ng]k07emO@1eMGD0N7Qh07alO080Ng]k00l0
N7Qh07alO01eMGD0M7Ad07QhN01dM7@0LW9b06i^KP1cLg<0PH610::RXP2i^KT0b<S80<g=c@3Bd]80
0P3De=@03P3Cdm<0d=3@0<g=c@3?cll0c/k>0<_;b`3<c<`0c/k>0=7Ad@3@d=00dM7A0<o?c`3De=@0
dM7A0P3@d=007@3AdM40d];B0=7Ad@3@d=00dM7A0<k>cP3;bl/0a/K60<C4a02o_kl0_Kfm0;Rh^02c
/k<0/;2`0:JVYP2NWYh0SXj>0820P01VIVH0EEEE03Lg=`0_;bl0:RXZ02TY:@0W9bL0;bl_02d];@0e
=CD0?3`l0080>c/k00D0@T9204a<C01@D500Cdm?05EEE@0205UIF@0405YJFP1=CDd0DU9B05ADE0h0
b>3H000<0<SPf080@41000X0?clo04I6AP19BDT0@T920451@@0j>SX0>CTi03De=@0c<c<0=CDe0P0b
<S80200^;Rh09RHV02XZ:P0W9bL0;Bd]03Lg=`0k>c/0@4100P1:BTX04P16ATH0@D5104];B`1;Bd/0
FEUI06YZJP1fMWH0O7al08>3P`2;Rh/0SXj>09FEU@2KVi/0X:2P0:>SX`2XZ:P0Zj^[0:ZZZP80[:b/
00T0[jn_0:f][@2ZZZX0ZZZZ0:^[Z`2ZZZX0[Zj^0:VYZ@2_[jl00P2^[Zh20:VYZ@0[0:JVYP2PX:00
WinO09JFUP2ATI40TY:B0:2PX02k^k/0cLg=0:j^[P1[Jf/0AdM703Hf=P10@400D51@05IFEP1:BTX0
<S8b030`<01GEeL0Vi^K07MgM`0e=CD0:2PX02DU9@0W9bL0:BTY02DU9@0Q8B409bLW03Ti>@1DE5@0
G5aL05UIF@19BDT0A4A404E5A@0h>3P0?Cdm03lo?`15ADD0?Shn02l_;`0203Ph>00K03Xj>P13@d<0
MWIf05eMG@10@400?Cdm03`l?00/;2`0>SXj03De=@0a<C40?3`l04E5A@1EEED0IfMW08>3P`1oOgl0
Ph>30820P01VIVH0Jf][08F5Q@2=SHd0QXJ607MgM`1=CDd0:BTY0080;2`/0140<c<c03/k>`1KFe/0
F5QH06i^KP1oOgl0PX:2096AT@2QXJ40X:2P075aL@11@D40CTi>065QH@1WIfL0EEEE05QHF00206=S
H`0G07EeM@22PX80Ph>3075aL@1ADE40Hf=S06a/K01NGUh0CDe=03De=@1;Bd/0JFUY08J6QP2OWil0
QHF508>3P`2PX:00Y:BT09VIV@1WIfL0<C4a02/[:`0];Bd00P0/;2`0600^;Rh0=SHf03Ti>@1;Bd/0
@T9204I6AP1<C4`0HF5Q051@D00l?3`0=CDe034a<@0Y:BT0;2`/03De=@0h>3P0@41005ADE00g=cL0
>3Ph03Lg=`0_;bl0?3`l03Lg=`80=CDe00H0;bl_030`<00a<C40=CDe038b<P0j>SX203Ti>@0603De
=@0`<300<30`03Ph>00b<S80=cLg0P0k>c/01P0m?Cd0=cLg03Ph>00_;bl0<c<c03Xj>P80?Shn01L0
@D5104A4A00i>CT0>3Ph03Lg=`0h>3P0<S8b03De=@0n?Sh0=SHf030`<00b<S80=CDe03`l?01=CDd0
De=C05IFEP1CDe<0EEEE05mOG`1WIfL0Kfm_07MgM`0207YjNP0408>3P`22PX80Ng]k08:2PP80P820
01H0N7Qh07]kN`1oOgl0Ogmo07alO022PX80P82008R8R027QhL0Q8B408>3P`28R8P0PX:208R8R027
QhL0Rh^;08N7Q`29RHT0Rh^;08R8R02>SXh0SHf=0`2@T9004`2CTi<0UIFE09RHV02ATI40U9BD09:B
TP2ATI40TY:B096AT@2=SHd0TI6A09:BTP2@T900U9BD08n?S`2@T900TI6A09>CT`2IVIT00`2PX:00
802VYZH0[Jf]0:j^[P2][Jd0];Bd0;Rh^02i^KT0`L710<?3``34a<@0alO70<K6aP35aLD0a<C40<O7
a`35aLD0b/[:0<g=c@3;bl/0c/k>0=3@d03<c<`0_Kfm0:b/[02BTY80Lg=c05MGE`15ADD0?Cdm03`l
?00i>CT0=CDe0P0f=SH203Ti>@0303Lg=`0j>SX0>3Ph0080<c<c0P0e=CD0:P0k>c/0<S8b03De=@0h
>3P0?Cdm04I6AP1JFUX0F5QH05YJFP1_Kfl0Lg=c05mOG`1;Bd/0E5AD051@D01KFe/0E5AD05iNGP15
ADD0DE5A05ADE01=CDd0CTi>061PH01KFe/0C4a<04];B`1>CTh0DE5A04m?C`1CDe<0@T9204U9B@1d
M7@0/K6a0:VYZ@2CTi<0Vi^K09JFUP2:RXX0PH6107QhN080OWin00L0MGEe08J6QP1nOWh0OGem0820
P021PH40Ng]k0080MGEe00<0Ng]k07QhN01aLG40101cLg<01P1/K6`0L71`071`L01`L700Kfm_079b
LP80KVi^00d0JFUY06e]K@1[Jf/0KFe]06UYJ@1_Kfl0K6a/06i^KP1eMGD0Kfm_079bLP1gMgL0Ng]k
0080N7Qh00@0NGUi07QhN01mOGd0Ng]k0P1iNGT0101mOGd0PX:20861P@21PH4208>3P`0H07moO`21
PH40OWin07alO01kNg/0O7al07]kN`1gMgL0LW9b07EeM@1cLg<0Ogmo0:>SX`2i^KT0a/K60<k>cP3A
dM40f=SH0=OGe`3EeMD0dm?C0=3@d03>c/h0c<c<0P3=cLd01P3>c/h0clo?0<o?c`3AdM40d];B0=?C
d`<0d=3@00<0clo?0=;BdP3AdM400P3AdM40503@d=00b/[:0<W9b@36a/H0`/;20;no_`2m_Kd0_;bl
0;Rh^02a/K40[Jf]09jNWP2CTi<0MgMg06MWI`1;Bd/0>c/k02h^;P0];Bd09bLW0P0_;bl03`0^;Rh0
<S8b03Lg=`0i>CT0?3`l03hn?P12@T80Bd];04e=C@1EEED0C4a<05=CD`1>CTh0BTY:04U9B@0>0<SP
f0003038h=P203Ti>@0=03lo?`11@D40?Cdm0492@P0f=SH0>3Ph03De=@0b<S80;bl_030`<00c<c<0
<S8b02l_;`0202LW9`0602HV9P0^;Rh0>CTi03Ph>013@d<0BDU90P1@D5004@15ADD0BDU905=CD`1P
H600LW9b07moO`25QHD0RHV908b<S02ATI40UiNG09jNWP2RXZ80YJFU0:NWY`2/[:`0Zj^[0080/;2`
00@0ZZZZ0:^[Z`2/[:`0ZZZZ0P2_[jl0<P2][Jd0[Zj^0;2`/02a/K40/k>c0:n_[`2`/;00YZJV09jN
WP2JVYX0UiNG09>CT`25QHD0RHV909bLW02m_Kd0dm?C0;jn_P1lO7`0BTY:03/k>`16ATH0De=C0451
@@0f=SH0<C4a03Lg=`1^KVh0Q8B404Y:BP0c<c<0:2PX02XZ:P0^;Rh09bLW02l_;`0X:2P0?clo061P
H01KFe/0E5AD04I6AP18B4P0?Cdm03@d=00j>SX0@41004M7A`0b<S80>3Ph0P0j>SX06`0i>CT0C4a<
06e]K@1>CTh0<C4a03Ti>@14A4@0=SHf03Lg=`0^;Rh0<C4a03Hf=P1?Cdl0IVIV0861P@23Ph<0OWin
08:2PP1[Jf/0KVi^08^;R`2?Shl0S8b<07EeM@1FEUH0>SXj03@d=00202XZ:P1D02d];@0h>3P0C4a<
061PH021PH40RXZ:07IfMP20P800VYZJ09jNWP2;Rh/0EeMG05eMG@1YJFT0F5QH05ADE01_Kfl0K6a/
06m_K`1nOWh0QXJ6071`L01MGEd0GemO0820P01hN7P0FEUI03Ph>00e=CD0BDU907moO`2;Rh/0XJ6Q
09NGU`2RXZ80YZJV096AT@1[Jf/0?3`l02h^;P0a<C40=3@d03<c<`0d=3@0<30`03Hf=P0l?3`0?Cdm
0492@P16ATH0CTi>05YJFP1BDU80?Shn03<c<`0_;bl0;Rh^03<c<`0];Bd0@41004M7A`1BDU80>3Ph
03@d=00c<c<0;Rh^038b<P0e=CD0>SXj02`/;00`<300<C4a038b<P0e=CD0>3Ph03Lg=`0];Bd0;bl_
030`<00d=3@0<c<c034a<@0[:b/0;bl_0P0b<S8203@d=00803Hf=P0e=CD0=SHf03Xj>P0n?Sh0@D51
0410@00j>SX203/k>`0F0410@00h>3P0<C4a03Ph>00d=3@0=SHf03Ti>@0c<c<0=SHf03hn?P1:BTX0
DE5A05EEE@1ADE40EeMG05aLG01PH600LG5a07AdM01fMWH0N7Qh07YjNP80P82002P0PX:208>3P`1m
OGd0PX:207inOP1lO7`0OWin0820P01oOgl0PH610820P024Q8@0QHF508J6QP27QhL0QXJ608B4Q028
R8P0RHV908F5Q@27QhL0Rh^;08b<S02>SXh0SHf=092@T02ATI40UIFE09BDU02BTY80UYJF09:BTP2D
U9@0UYJF08n?S`2CTi<0UYJF09:BTP2ATI40Ti>C0`2ATI401@2FUYH0UIFE09FEU@2GUiL0Y:BT0080
XJ6Q00P0X:2P0:VYZ@2ZZZX0[jn_0;:b/P2e]KD0_;bl0<30`080`l?300L0a/K60<?3``38b<P0b<S8
0<[:bP38b<P0b/[:0080cLg=02D0a/K60;no_`2VYZH0S8b<07IfMP1FEUH0BTY:03hn?P10@400>c/k
03De=@0h>3P0>c/k03Hf=P0g=cL0=SHf03dm?@0j>SX0=SHf02l_;`0b<S80;Bd]03@d=00a<C40?Cdm
03De=@0k>c/0=cLg03hn?P1DE5@0D51@05=CD`1JFUX0IfMW079bLP1GEeL0B4Q80080DE5A01H0F5QH
05EEE@1SHf<0Cdm?05EEE@1BDU80CDe=055AD@1OGel0GEeM04Y:BP1@D500DU9B05ADE018B4P0CDe=
03hn?P15ADD0Kfm_0:ZZZP2][Jd0TY:B0P2IVIT00`2@T900OWin07YjNP0207YjNP0;07EeM@1oOgl0
M7Ad07YjNP22PX80Ogmo07UiN@1bLW80LG5a07AdM01bLW800P1_Kfl03`1gMgL0MGEe075aL@1cLg<0
Kfm_071`L01dM7@0L71`06m_K`1bLW80KVi^06e]K@1`L700LG5a07=cL`0207AdM080MWIf00@0NGUi
07moO`1iNGT0Ng]k0P20P800301nOWh0P82008>3P`1nOWh0QHF508R8R022PX80QhN708B4Q022PX80
QHF508J6QP@0Q8B400h0P82007alO01kNg/0NGUi07MgM`1cLg<0MWIf07AdM021PH40Xj>S0;bl_03:
b/X0dM7A0=?Cd`<0e]KF00D0e=CD0=7Ad@3>c/h0c/k>0<o?c`020<k>cP030=3@d03>c/h0c<c<00X0
dM7A02D0c/k>0<W9b@3=cLd0b/[:0<G5a@33`l<0a<C40;no_`2n_[h0]kNg0;6a/@2YZJT0WinO08n?
S`1jNWX0HF5Q04Y:BP10@400<C4a02`/;00^;Rh0:RXZ02/[:`0_;bl0;Bd]03<c<`0e=CD0?Cdm03hn
?P15ADD0CDe=05EEE@1BDU80EEEE055AD@1?Cdl0BDU900h0b>3H000<0<SPf080=cLg02H0=SHf03Lg
=`0g=cL0@41004E5A@0c<c<0?3`l034a<@0e=CD0;2`/02h^;P0V9RH0:b/[02HV9P0Y:BT0:2PX03Ph
>00k>c/0?Cdm0492@P18B4P0C4a<04Y:BP1=CDd0AdM7051@D01QHF40Lg=c0820P026QXH0R8R808j>
SP2EUID0Vi^K09bLW02UYJD0Z:RX0:VYZ@80Zj^[0`2/[:`0<02^[Zh0ZZZZ0:f][@2^[Zh0Zj^[0:b/
[02b/[80[Zj^0;:b/P2^[Zh0[jn_0:VYZ@2WYjL0XZ:R09VIV@2BTY80RXZ:08V9R@22PX80OGem09ZJ
VP2l_;`0f][J0=3@d02IVIT0CTi>0410@01DE5@0DE5A04I6AP13@d<0>CTi055AD@1eMGD0EeMG038b
<P0X:2P0:RXZ02d];@0S8b<0:2PX030`<00k>c/0Hf=S061PH01GEeL0BDU903dm?@80>CTi0280?clo
04e=C@1CDe<0?Shn03Lg=`0i>CT0?3`l03<c<`1JFUX0EUIF03Xj>P0c<c<0<30`03De=@0_;bl0=cLg
03De=@0_;bl0?Shn06a/K022PX80R8R807UiN@22PX80LG5a069RHP28R8P0U9BD08f=S@21PH40Fe]K
04Q8B016ATH0?clo0P0[:b/04`0Y:BT0;2`/03/k>`1@D500MgMg07inOP1UIFD0KVi^096AT@2KVi/0
VIVI075aL@1[Jf/0EEEE055AD@1OGel0LG5a07inOP1oOgl00P2HV9P06`1hN7P0JFUY08>3P`22PX80
GEeM04Y:BP0k>c/0@D5105IFEP2YZJT0[:b/0;>c/`2_[jl0WYjN09NGU`1eMGD0?clo02`/;00`<300
;bl_038b<P0^;Rh0=3@d02h^;P0g=cL0=3@d03Xj>P0204A4A00J04m?C`1FEUH0DU9B0410@00g=cL0
=SHf02TY:@0b<S80:RXZ03/k>`1FEUH0GemO038b<P0^;Rh0<30`034a<@0d=3@0=CDe038b<P0g=cL0
<C4a03<c<`0i>CT0>SXj03Ti>@0b<S8202h^;P06030`<00^;Rh0<S8b034a<@0b<S80=SHf0P0`<300
0`0c<c<0<C4a03De=@0203Ti>@0>03Ph>00i>CT0?Cdm03De=@0b<S80<c<c03Ti>@15ADD0>c/k03De
=@0i>CT0;Bd]030`<00e=CD202h^;P0Q0451@@16ATH0BTY:059BDP1ADE40EEEE061PH01VIVH0JVYZ
071`L01bLW80MgMg07emO@22PX80Ph>30820P01nOWh0PH6108F5Q@1kNg/0NGUi0820P021PH40PX:2
08B4Q025QHD0Ph>308J6QP27QhL0QXJ608F5Q@2:RXX0Q8B400<0R8R80P2>SXh00`2=SHd0SXj>09>C
T`0209FEU@0A09RHV02DU9@0UIFE09VIV@2KVi/0V9RH09^KV`2FUYH0UIFE09VIV@2FUYH0Ti>C09JF
UP2CTi<0UIFE09BDU02FUYH00P2HV9P02P2MWId0WinO09nOW`2QXJ40Z:RX0:ZZZP2^[Zh0];Bd0;>c
/`2i^KT30<71`@040<G5a@37alL0alO70<S8b080a/K603T0b<S80<C4a02g]kL0XJ6Q08R8R01ZJVX0
Bd];03dm?@0j>SX0<c<c03Xj>P0f=SH0>SXj03@d=00e=CD0;Rh^03Hf=P0c<c<0>CTi03Lg=`0d=3@0
;Rh^03<c<`0_;bl0:2PX02XZ:P0^;Rh0<C4a02`/;00d=3@0;bl_03@d=01CDe<0@41004m?C`1HF5P0
JFUY079bLP1BDU80C4a<05ADE01EEED0EeMG04i>CP1TI6@0AdM705ADE01=CDd0AdM704m?C`1JFUX0
GEeM04U9B@1:BTX0CDe=051@D011@D400P18B4P02P10@400Kfm_0::RXP2a/K40UiNG09VIV@2PX:00
TY:B07inOP1jNWX207=cL`0B06UYJ@1jNWX0KVi^07]kN`1iNGT0Kfm_06IVIP1aLG40KVi^079bLP1d
M7@0Kfm_06e]K@1fMWH0LW9b06m_K`1bLW80LG5a0`1cLg<01P1eMGD0N7Qh071`L01cLg<0MWIf07Ee
M@80M7Ad00/0MWIf07]kN`1kNg/0Ng]k08:2PP1nOWh0PH6107inOP24Q8@0Ph>308F5Q@0308R8R004
08V9R@27QhL0RHV908Z:RP80QHF501`0S8b<08J6QP24Q8@0Q8B407inOP20P800Ogmo07emO@1jNWX0
MGEe07AdM01`L700M7Ad07inOP2LW9`0]KFe0<O7a`3?cll0dm?C0=GEe@3Hf=P0fMWI0=OGe`3EeMD0
dM7A0<g=c@3?cll0d=3@0P3?cll20=3@d0030=;BdP3Cdm<0d=3@0080dM7A00@0d=3@0=7Ad@3AdM40
d=3@0P3?cll01P3;bl/0c<c<0<c<c03;bl/0b<S80<W9b@80`L7100l0^KVi0;:b/P2/[:`0XZ:R09BD
U026QXH0Lg=c05aLG015ADD0=cLg030`<00a<C409bLW02@T900V9RH00P0Y:BT02`0^;Rh0<S8b03Xj
>P0l?3`0ADE504Q8B01<C4`0D51@04];B`1@D500BDU900h0b>3H000<0<SPf080>CTi00X0=3@d03Hf
=P0g=cL0>SXj03/k>`0e=CD0;Rh^02l_;`0`<300:BTY0P0[:b/06@0X:2P0:RXZ02/[:`0Y:BT0<c<c
03dm?@14A4@0ATI604];B`1BDU80Cdm?04a<C01:BTX0DU9B069RHP1eMGD0Ogmo08N7Q`2:RXX0T92@
09BDU02IVIT0WIfM0:6QX@2WYjL00P2[Zj/01@2_[jl0[Zj^0:j^[P2^[Zh0[Jf]00@0[Zj^03X0ZZZZ
0:j^[P2[Zj/0[Zj^0;2`/02^[Zh0[:b/0:RXZ02RXZ80Vi^K092@T02:RXX0QHF507IfMP1dM7@0LG5a
096AT@2a/K40fMWI0=GEe@2GUiL0CDe=04A4A01fMWH0IVIV04Y:BP0l?3`0C4a<08J6QP1VIVH0BTY:
03De=@0[:b/0=cLg02TY:@0[:b/09RHV04=3@`1WIfL0EeMG04E5A@1:BTX0?Cdm03Xj>P0o?cl0>c/k
04Y:BP1BDU80AdM703Ph>00b<S80=CDe03@d=01BDU80CTi>03<c<`0`<300:BTY0P0a<C404`0`<300
;bl_02l_;`12@T80L71`08f=S@20P800MgMg07moO`1XJ6P0OWin09RHV02?Shl0OWin06QXJ01;Bd/0
Cdm?059BDP0l?3`00P0`<300:@0_;bl0=cLg03Ti>@15ADD0JFUY06IVIP1FEUH0JVYZ08b<S02ATI40
WYjN08>3P`1RHV80EUIF05UIF@1=CDd0MWIf08>3P`2GUiL0ZJVY09RHV02@T900RXZ:07IfMP1QHF40
B4Q802`/;00_;bl0E5AD07YjNP2^[Zh0]KFe0;bl_02_[jl0Ti>C06e]K@0m?Cd0:b/[02PX:00[:b/0
;bl_00@0<30`01`0=cLg038b<P0e=CD0>SXj04Y:BP18B4P0C4a<05MGE`17AdL0<c<c030`<00X:2P0
:BTY02HV9P0h>3P0De=C05ADE00e=CD0;Bd]030`<00b<S80<C4a03<c<`0e=CD0;2`/030`<00d=3@0
?3`l0P0f=SH01`0_;bl0<C4a03Hf=P0d=3@0<C4a03Lg=`0/;2`00P0b<S8203Lg=`0B030`<00b<S80
>c/k03Ti>@0j>SX0=SHf03Xj>P13@d<0>c/k038b<P0h>3P0B4Q803`l?00f=SH0=cLg03@d=00c<c<0
<30`0P0a<C403P0e=CD0BTY:04U9B@1ADE40CDe=04i>CP1@D500EeMG05eMG@1WIfL0Jf][079bLP1a
LG40MWIf0`1nOWh08@20P800Ph>308B4Q01oOgl0P8200861P@22PX80Ph>308F5Q@28R8P0QHF508N7
Q`26QXH0R8R808N7Q`26QXH0R8R808B4Q02<S8`0Rh^;08n?S`2<S8`0RXZ:08j>SP2?Shl0T92@09^K
V`2HV9P0UIFE09NGU`2IVIT0Vi^K09VIV@0209ZJVP0809VIV@2GUiL0Vi^K09fMW@2IVIT0V9RH09bL
W02GUiL309^KV`0309ZJVP2KVi/0Vi^K0080YjNW00X0Z:RX0:^[Z`2`/;00]KFe0;^k^`2m_Kd0`l?3
0<C4a032`/80a/K60P39bLT02`32`/80_;bl0:n_[`2FUYH0Ogmo06][J`1=CDd0=cLg034a<@0l?3`0
=CDe0080=3@d00@0=cLg03De=@0f=SH0<S8b0P0c<c<0=00`<300>3Ph03@d=00d=3@0;bl_03Xj>P0a
<C40:BTY03@d=00e=CD0ATI603Ti>@0_;bl0<30`03Ph>016ATH0?clo04];B`1IFET0Jf][06e]K@1D
E5@0DU9B05ADE01PH600HF5Q055AD@1LG5`0Cdm?04a<C01BDU80CDe=04a<C01MGEd0GemO04Q8B015
ADD0DU9B051@D00o?cl0BTY:03dm?@0o?cl0Jf][09^KV`2a/K40V9RH09JFUP2OWil0UYJF07YjNP1o
Ogl206i^KP0@06YZJP1dM7@0MWIf07emO@1aLG40IFEU079bLP1]KFd0Kfm_06e]K@1bLW80Lg=c079b
LP1`L700LW9b07EeM@80MWIf00/0Lg=c075aL@1fMWH0MGEe07MgM`1cLg<0M7Ad07MgM`1nOWh0Ng]k
07moO`0207]kN`0J0861P@1oOgl0QhN708B4Q029RHT0Rh^;08V9R@2;Rh/0RHV908^;R`2:RXX0SHf=
08V9R@2;Rh/0RXZ:08V9R@28R8P0RHV908Z:RP28R8P0QhN708:2PP26QXH0Ogmo07emO@1kNg/307Ui
N@0806m_K`1fMWH0OGem09jNWP2e]KD0aLG50=7Ad@3EeMD20=SHf00>0=[JfP3GemL0eMGE0=7Ad@3@
d=00c/k>0=7Ad@3@d=00dM7A0=;BdP3@d=00d];B0=7Ad@3Fe]H30=7Ad@0;0=;BdP3@d=00dM7A0<g=
c@3>c/h0d=3@0<k>cP3=cLd0c/k>0<_;b`37alL00P35aLD04P2k^k/0][Jf0:j^[P2UYJD0WinO09>C
T`21PH40Kfm_05IFEP12@T80=3@d02d];@0_;bl09bLW02HV9P0X:2P09RHV02TY:@80<C4a00P0<S8b
03Hf=P10@400AdM704i>CP1@D500Bd];04U9B@h0b>3H000<0<SPf080<S8b02P0>c/k03hn?P0g=cL0
<c<c03@d=00i>CT0;bl_02d];@0Z:RX0:2PX02/[:`0V9RH0:2PX02d];@0/;2`0:BTY03@d=00o?cl0
A4A404U9B@1>CTh0EUIF051@D01<C4`0CDe=05MGE`1XJ6P0NGUi0820P026QXH0Rh^;092@T02JVYX0
VIVI09nOW`2QXJ40YZJV0:f][@2ZZZX0/;2`0P2][Jd01@2_[jl0[Zj^0:f][@2/[:`0[Zj^0080Zj^[
00<0[Jf]0:j^[P2_[jl00P2a/K409@2`/;00YJFU0:BTY02LW9`0Ti>C08f=S@23Ph<0MWIf06i^KP1T
I6@0K6a/08N7Q`2][Jd0d];B0=_Kf`2LW9`0BDU905UIF@1HF5P0@T9203lo?`1MGEd0/[:b08^;R`1;
Bd/0@41003Lg=`11@D40<S8b02LW9`0`<300ATI605eMG@1JFUX0Bd];04I6AP0o?cl00P12@T808P13
@d<0>SXj04=3@`1?Cdl0=cLg038b<P0d=3@0>SXj0410@015ADD0=3@d02XZ:P0a<C40=cLg02h^;P0d
=3@0<c<c02TY:@0i>CT0J6QX096AT@1jNWX0MgMg07UiN@1`L700T92@09RHV01iNGT0H61P04Y:BP1<
C4`0FEUI04m?C`0m?Cd203Ti>@0h03<c<`0n?Sh0AdM705EEE@1UIFD0Fe]K04];B`1BDU80Kfm_08Z:
RP2TY:@0VYZJ0820P01QHF40BTY:05EEE@1lO7`0V9RH09fMW@2TY:@0T92@08V9R@1fMWH0ATI60410
@00n?Sh0=CDe03lo?`1dM7@0Xj>S0;Bd]02PX:00YJFU09>CT`1bLW80A4A402/[:`0X:2P0:BTY02`/
;00a<C40;Bd]02l_;`0];Bd0<C4a03<c<`0b<S80=cLg03hn?P1;Bd/0B4Q804m?C`1GEeL0ATI6034a
<@0];Bd202HV9P0B02h^;P0c<c<0BTY:051@D00c<c<0<S8b03<c<`0];Bd0<C4a02h^;P0];Bd0;bl_
03Hf=P0d=3@0>3Ph03De=@0h>3P0;Bd]0P0a<C42030`<004034a<@0];Bd0;2`/038b<P80=CDe0140
<c<c038b<P0c<c<0>CTi03Lg=`0j>SX0?3`l03Ti>@0g=cL0=CDe0410@012@T80>3Ph03Ti>@0d=3@0
<c<c038b<P03034a<@0:03@d=01:BTX0ADE504M7A`1BDU80FUYJ05MGE`1BDU80F5QH06IVIP80Jf][
00P0KVi^06m_K`1hN7P0MWIf07YjNP1mOGd0Ph>30820P080Ph>300H0PX:208F5Q@27QhL0QHF5096A
T@2>SXh208^;R`0608Z:RP27QhL0S8b<08Z:RP28R8P0RXZ:0P2=SHd01@2:RXX0Rh^;08f=S@2<S8`0
SHf=0080UiNG00P0V9RH09VIV@2KVi/0WinO09RHV02KVi/0UYJF09VIV@80UYJF00T0WIfM09bLW02M
WId0W9bL0:6QX@2NWYh0WIfM0::RXP2VYZH00P2PX:005`2TY:@0ZJVY0:b/[02][Jd0]kNg0;Jf]P2k
^k/0_Kfm0<71`@34a<@0a/K60<71`@2f][H0[jn_09bLW02;Rh/0LG5a05YJFP14A4@0@41003Lg=`0i
>CT0=3@d0080=cLg02`0<S8b03Lg=`0m?Cd0=cLg03De=@0f=SH0<c<c03@d=00l?3`0=cLg03dm?@0n
?Sh0<S8b03@d=00e=CD0:RXZ02LW9`0c<c<0>3Ph03<c<`0_;bl0<c<c04U9B@0m?Cd0>c/k04i>CP1H
F5P0LG5a06e]K@1BDU80De=C051@D01GEeL0Hf=S055AD@1IFET0CDe=055AD@1CDe<0EEEE059BDP1N
GUh0HV9R04e=C@80BTY:00h0DE5A04Q8B017AdL0?Cdm04A4A01UIFD0WYjN0;:b/P2LW9`0Shn?0:BT
Y02IVIT0PH6107moO`80Lg=c00@0IFEU07UiN@1fMWH0Lg=c0P1YJFT0101]KFd0L71`06e]K@1]KFd2
075aL@0907YjNP1iNGT0Lg=c07UiN@1gMgL0NGUi07YjNP1aLG40MgMg0080Ng]k0100NWYj07alO01o
Ogl0Ng]k08:2PP21PH40Q8B408N7Q`24Q8@0S8b<08Z:RP29RHT0SXj>092@T02<S8`0TY:B0P2=SHd0
3@2<S8`0SXj>08b<S02=SHd0Shn?08Z:RP28R8P0SHf=08R8R02>SXh0QhN708B4Q01oOgl00P1nOWh2
07]kN`0;07MgM`1hN7P0KVi^079bLP1kNg/0Ti>C0;>c/`31`L40c<c<0=CDe03GemL00P3IfMT01@3J
f]X0f=SH0=7Ad@3AdM40d=3@0080dM7A00H0e=CD0=7Ad@3@d=00clo?0=7Ad@3Fe]H30=7Ad@80clo?
00<0c/k>0<o?c`3?cll00P3?cll06P3>c/h0c<c<0<g=c@3:b/X0alO70<?3``2o_kl0^k^k0;2`/02/
[:`0Z:RX09^KV`2<S8`0MgMg069RHP1@D500>SXj02l_;`0];Bd0:b/[034a<@0^;Rh0;2`/02TY:@0j
>SX09BDU0P0[:b/01P0b<S80?Cdm04I6AP15ADD0@T9204E5A@h0b>3H000<0<SPf080;bl_02@0=SHf
034a<@0d=3@0=CDe03<c<`0b<S80=3@d034a<@0Y:BT0:b/[02XZ:P0/;2`0:RXZ02/[:`0Z:RX0;Bd]
03@d=00m?Cd0AdM704i>CP1JFUX0EUIF05YJFP1DE5@0Cdm?05MGE`1SHf<0LW9b07alO024Q8@0SXj>
092@T02FUYH0W9bL09jNWP2SXj<20:NWY`080:n_[`2ZZZX0[:b/0:b/[02_[jl0[Zj^0:^[Z`2ZZZX2
0;2`/00I0:b/[02[Zj/0[Zj^0;6a/@2][Jd0[jn_0:j^[P2VYZH0Y:BT09bLW02HV9P0TY:B08B4Q01i
NGT0KFe]065QH@1HF5P0GUiN0820P02][Jd0e=CD0=gMg@2IVIT0DE5A04M7A`0203hn?P0504i>CP2B
TY80WinO04I6AP0b<S800P0[:b/0;@0V9RH0:RXZ03<c<`1;Bd/0HF5Q059BDP12@T80@41003Ti>@0k
>c/0@D5104E5A@10@400>CTi04E5A@19BDT0>CTi03<c<`0b<S80>CTi03Ph>00e=CD0:b/[02XZ:P0_
;bl0:RXZ038b<P0[:b/0:BTY02h^;P1MGEd0TY:B07]kN`27QhL0MGEe08:2PP2PX:00T92@06QXJ01:
BTX0B4Q805ADE01@D500BTY:03/k>`0203Ph>00@03Ti>@18B4P0GUiN07UiN@1jNWX0IfMW04A4A013
@d<0GEeM07AdM02JVYX0UiNG08:2PP1IFET0B4Q806MWI`80TI6A01T0WinO09bLW026QXH0OGem061P
H00e=CD0A4A404e=C@1CDe<0KVi^09^KV`2XZ:P0XZ:R08f=S@22PX80I6AT0410@00Y:BT0:2PX02/[
:`0U9BD0;Bd]02l_;`0X:2P0;Rh^0080=CDe01L0:b/[02h^;P0a<C40?3`l055AD@17AdL0ADE505MG
E`1>CTh0=cLg02/[:`0U9BD0:BTY02XZ:P0c<c<0?Cdm04E5A@0j>SX0;bl_030`<00];Bd0=SHf030`
<002038b<P0>03<c<`0d=3@0=3@d034a<@0_;bl0:BTY03<c<`0a<C40=SHf038b<P0`<300;Bd]03<c
<`0h>3P203Hf=P0R02l_;`0`<300<c<c03Ti>@0m?Cd0>c/k03dm?@0e=CD0=SHf03<c<`0k>c/0=cLg
03Xj>P0m?Cd0?3`l03Xj>P0f=SH0;Rh^030`<00a<C40?Cdm04A4A011@D40A4A404i>CP1?Cdl0E5AD
05UIF@1@D500GEeM06ATI01UIFD0KVi^06e]K@80Lg=c00P0NGUi07MgM`22PX80Ph>308F5Q@24Q8@0
Ph>308V9R@80QXJ602H0S8b<09>CT`2ATI40T92@08V9R@2<S8`0RXZ:08N7Q`2:RXX0Rh^;09:BTP2A
TI40RXZ:08n?S`2@T900U9BD08n?S`2HV9P0W9bL09ZJVP2NWYh0Vi^K09nOW`2PX:00Vi^K09jNWP2O
Wil0W9bL09fMW@2RXZ80X:2P0:JVYP2RXZ80Y:BT0:JVYP2UYJD0YjNW0:b/[080Zj^[00D0YZJV0:RX
Z02^[Zh0/;2`0;>c/`020;Ng]`0D0;bl_02i^KT0][Jf0;2`/02MWId0QXJ6079bLP1SHf<0D51@04E5
A@0k>c/0=3@d03Ti>@0n?Sh0?clo03De=@0b<S80>3Ph03/k>`0f=SH203De=@80>SXj00L0=CDe03Lg
=`0k>c/0?Cdm0451@@0f=SH0=cLg0080=CDe02d0<30`034a<@0i>CT0>3Ph03De=@0_;bl0=cLg04Y:
BP0i>CT0>SXj05=CD`1LG5`0K6a/06e]K@1BDU80De=C051@D01GEeL0JVYZ05IFEP1DE5@0C4a<04];
B`1=CDd0Fe]K05IFEP1LG5`0FUYJ04Q8B00m?Cd0ATI604U9B@16ATH0Bd];04I6AP0j>SX0I6AT09VI
V@2e]KD0ZJVY08^;R`2QXJ40WIfM08J6QP20P8000P1cLg<04@1VIVH0Ng]k07IfMP1/K6`0J6QX06e]
K@1aLG40Lg=c075aL@1dM7@0N7Qh07EeM@1lO7`0NWYj07EeM@1lO7`0N7Qh0080PH6100T0Ng]k07in
OP22PX80Ph>308F5Q@23Ph<0PX:208>3P`29RHT00`27QhL0102:RXX0UIFE09:BTP2FUYH209:BTP04
08n?S`2EUID0Shn?092@T080Shn?00P0SXj>08f=S@2:RXX0RXZ:08V9R@28R8P0QhN708Z:RP80QXJ6
00l0PH610820P01nOWh0Ogmo07]kN`1jNWX0MWIf079bLP1eMGD0MWIf08n?S`2^[Zh0`/;20<_;b`3D
e=@00P3GemL20=[JfP030=WIf@3De=@0dm?C0080dM7A00<0d];B0=3@d03Cdm<00`3@d=00103De=@0
dM7A0=7Ad@3Bd]850=3@d00G0<o?c`3=cLd0clo?0<k>cP3@d=00c<c<0<[:bP37alL0`l?30;fm_@2i
^KT0/[:b0;6a/@2SXj<0VYZJ08R8R01`L700GUiN04Q8B00i>CT0<30`02`/;00T92@00P0Y:BT0100[
:b/0:RXZ02XZ:P0W9bL2034a<@05030`<00l?3`0>c/k03`l?00n?Sh03P38h=P000`0b>3H0P0_;bl0
1`0^;Rh0;bl_034a<@0`<300;2`/030`<00X:2P00`0Y:BT02`0/;2`0:RXZ02XZ:P0V9RH09bLW02l_
;`0c<c<0@41004U9B@1;Bd/0EeMG0080GEeM00L0EeMG05iNGP1NGUh0J6QX07EeM@1nOWh0QHF50080
SXj>00P0UiNG09^KV`2QXJ40Y:BT0:JVYP2XZ:P0[Zj^0:f][@80/;2`05@0/[:b0:^[Z`2YZJT0Zj^[
0;6a/@2][Jd0[Zj^0;2`/02c/k<0/;2`0:f][@2/[:`0[jn_0:NWY`2MWId0WinO09^KV`2@T900QhN7
07UiN@1]KFd0G5aL05ADE019BDT0EUIF07UiN@2TY:@0b/[:0=GEe@2OWil0DU9B04e=C@1;Bd/0AdM7
08>3P`2IVIT0Hf=S03De=@0];Bd0:2PX02HV9P0W9bL0>SXj04];B`1OGel0F5QH04=3@`0b<S80<C4a
03Hf=P16ATH0A4A403Ph>00g=cL0?3`l04U9B@10@400?3`l02TY:@0d=3@0=SHf02l_;`0Z:RX0;Bd]
030`<00[:b/0;bl_02PX:00V9RH0;Bd]05UIF@2FUYH0Q8B408J6QP1mOGd0U9BD09^KV`2:RXX0L71`
051@D01HF5P0EEEE04i>CP15ADD303Hf=P0:04=3@`1IFET0MGEe08^;R`2DU9@0NGUi04=3@`12@T80
EEEE06QXJ080PH610380IVIV04m?C`1QHF40SHf=09jNWP2DU9@0WYjN09:BTP1nOWh0MgMg059BDP16
ATH0HV9R075aL@26QXH0U9BD0:f][@2RXZ80Rh^;075aL@1DE5@0?Cdm03De=@0_;bl0:b/[02TY:@0/
;2`0;Bd]02h^;P0c<c<0=3@d034a<@0b<S80<C4a03Hf=P0b<S80@D51055AD@1=CDd0ATI605MGE`1=
CDd0>3Ph034a<@0W9bL0:RXZ02LW9`0`<300ATI604Y:BP80=SHf00h0<c<c03@d=00a<C40=3@d030`
<00];Bd0<c<c03Ph>00i>CT0?3`l03@d=00/;2`0=SHf03<c<`80=SHf00@0;bl_02/[:`0e=CD0=3@d
0P0c<c<03@0b<S80=SHf03Lg=`0j>SX0>c/k0451@@0l?3`0@D5103hn?P0i>CT0@41003lo?`0h>3P0
0P0l?3`04`0k>c/0>CTi03Hf=P0f=SH0@41004M7A`1;Bd/0DE5A05=CD`1ADE40AdM704A4A01;Bd/0
BTY:059BDP1FEUH0G5aL06i^KP1]KFd00P1[Jf/206e]K@0607AdM01iNGT0PH6107emO@1nOWh0R8R8
0`26QXH02P2BTY80SHf=08R8R026QXH0R8R808F5Q@2:RXX0QXJ608N7Q`2<S8`208J6QP0509:BTP2C
Ti<0UIFE092@T02FUYH00P2TY:@02P2KVi/0W9bL0::RXP2RXZ80WinO0:2PX02SXj<0WYjN0:>SX`2V
YZH30:RXZ080ZJVY00<0/K6a0:f][@2`/;000P2][Jd20:ZZZP0@0::RXP2NWYh0Xj>S0:6QX@2TY:@0
YJFU0:2PX02EUID0Ph>3071`L01:BTX0@41003hn?P0k>c/0=cLg03De=@80=cLg00<0?3`l0492@P0j
>SX00P0l?3`01`0i>CT0=cLg03Hf=P0k>c/0>CTi03Lg=`0e=CD00P0i>CT04P11@D40@41003@d=00g
=cL0@41003De=@0^;Rh0;Bd]03Xj>P0_;bl0=SHf02`/;00e=CD0AdM703De=@0k>c/0CTi>05eMG@80
LG5a00h0EUIF059BDP1LG5`0EeMG069RHP1ADE40FEUI051@D01DE5@0CDe=05UIF@1EEED0E5AD05MG
E`80@D5100l0CDe=04Y:BP1:BTX0@41004a<C00l?3`0H61P09BDU02g]kL0[Zj^08j>SP2OWil0WIfM
08b<S026QXH00P1hN7P02`1^KVh0OWin07=cL`1`L700K6a/06i^KP1aLG40Lg=c07IfMP1lO7`0OWin
0080O7al0200Ng]k07alO01lO7`0P82008^;R`22PX80PH6107moO`23Ph<0QHF508V9R@2:RXX0R8R8
08n?S`2;Rh/0RXZ:08^;R`2?Shl0SXj>09BDU02CTi<0UYJF09NGU`2BTY80Ti>C09BDU02@T900Shn?
096AT@2?Shl0T92@08n?S`80Rh^;00`0SXj>08N7Q`27QhL0QhN708B4Q023Ph<0Q8B408:2PP21PH40
O7al07YjNP1gMgL207=cL`0>07AdM01bLW80QHF50:FUY@2l_;`0bLW90=3@d03GemL0f][J0=_Kf`3L
g=`0f][J0=OGe`3EeMD30=;BdP050=?Cd`3De=@0d=3@0=;BdP3?cll00`3Cdm<01P3AdM40d=3@0=7A
d@3Bd]80dM7A0=3@d080dM7A0280c/k>0=3@d03Bd]80c/k>0<g=c@3;bl/0b<S80<?3``2o_kl0^k^k
0;Ng]`2`/;00YjNW09nOW`2;Rh/0N7Qh069RHP1?Cdl0?Cdm038b<P0e=CD0;Bd]02/[:`0X:2P09RHV
02@T900X:2P08b<S02XZ:P0d=3@0<S8b03Hf=P0g=cL0=CDe3P38h=P000`0b>3H0P0`<3001@0];Bd0
;2`/02l_;`0n?Sh0<c<c0080<30`0200:BTY02`/;00/;2`0<C4a02PX:00Y:BT09bLW02XZ:P0^;Rh0
<C4a03lo?`16ATH0C4a<05QHF01SHf<0H61P05QHF01KFe/0I6AT06a/K01kNg/0P82008J6QP29RHT0
TY:B09RHV02NWYh0WIfM0:>SX`2VYZH0[:b/0:f][@<0/;2`00P0[Zj^0:f][@2[Zj/0[Jf]0:n_[`2^
[Zh0[jn_0:f][@80/[:b02T0]KFe0;:b/P2][Jd0ZJVY0:2PX02OWil0VIVI08n?S`27QhL0NWYj079b
LP1QHF40E5AD04E5A@0m?Cd0C4a<07IfMP2LW9`0^k^k0=CDe02QXJ40Fe]K06IVIP1KFe/0RHV90:JV
YP1VIVH0<S8b02LW9`0[:b/0;Rh^02l_;`0o?cl0De=C04i>CP1JFUX0@D5103@d=00e=CD0?3`l04U9
B@0203lo?`0P03Ti>@10@400AdM704Q8B00`<300<c<c034a<@0f=SH0=3@d02XZ:P0_;bl0=CDe02XZ
:P0d=3@0:b/[02h^;P0e=CD0G5aL09^KV`2?Shl0Q8B408f=S@2IVIT0SXj>07YjNP1TI6@0HF5Q06m_
K`1OGel0C4a<04=3@`0i>CT203/k>`0Z05mOG`1XJ6P0QhN708B4Q02BTY80Lg=c055AD@0n?Sh0EeMG
06a/K01aLG40JFUY06a/K01`L700Ph>309BDU02FUYH0Xj>S09ZJVP2;Rh/0Ph>308Z:RP1iNGT0NWYj
09JFUP2][Jd0X:2P09bLW02VYZH0WIfM071`L017AdL0?3`l03De=@0g=cL0=3@d03Hf=P0c<c<0=3@d
03<c<`0e=CD0<S8b0P0c<c<03P0b<S80<C4a03Hf=P0f=SH0@d=3059BDP1DE5@0A4A405ADE01BDU80
=cLg034a<@0c<c<0;2`/0P0];Bd0200o?cl0C4a<03`l?00b<S80<C4a02h^;P0g=cL0=3@d0P0^;Rh0
300c<c<0>SXj03Lg=`0f=SH0;2`/034a<@0_;bl0<C4a03Ph>00e=CD0:b/[02h^;P80=3@d0P0i>CT0
1@0b<S80>SXj03`l?00n?Sh0?Cdm0080?Shn00@0>CTi03Ph>00i>CT0?Shn0P0k>c/01010@400@D51
03De=@0^;Rh203Hf=P0403`l?017AdL0@d=304i>CP80F5QH01/0BTY:0451@@10@400@T9203hn?P16
ATH0BDU905MGE`1NGUh0H61P05aLG01PH600IVIV06ATI01RHV80Jf][06e]K@1^KVh0LW9b07=cL`1i
NGT0MGEe07QhN01iNGT0MGEe07MgM`1hN7P00P1iNGT03`23Ph<0QXJ608>3P`1jNWX0OGem08Z:RP2=
SHd0S8b<08^;R`2:RXX0VYZJ09^KV`2IVIT0UiNG0:2PX00209fMW@0909jNWP2RXZ80WinO0:FUY@2Y
ZJT0Z:RX0:JVYP2TY:@0XZ:R0080Xj>S00/0X:2P0:NWY`2TY:@0Y:BT09bLW02FUYH0SHf=08b<S025
QHD0RHV908J6QP0208V9R@0L07inOP1[Jf/0H61P0451@@0b<S80;bl_030`<00f=SH0<c<c03Ti>@0k
>c/0>3Ph0492@P0h>3P0?clo04=3@`0c<c<0>SXj03Lg=`11@D40>c/k03Ph>00];Bd0=cLg03/k>`1@
D500BTY:03Ti>@80>SXj02X0>c/k030`<00d=3@0?Shn03Ph>00b<S80;Bd]03Hf=P14A4@0=cLg0451
@@1?Cdl0GUiN07=cL`1WIfL0CDe=05MGE`1NGUh0FUYJ061PH01FEUH0EEEE04Q8B01DE5@0Cdm?055A
D@1BDU80FEUI05MGE`1;Bd/0>c/k04a<C019BDT0De=C03dm?@17AdL0=CDe05UIF@2=SHd0/k>c0;2`
/02BTY8209nOW`0>09>CT`26QXH0Ng]k07]kN`1aLG40OWin079bLP1^KVh0Lg=c071`L01aLG40M7Ad
07emO@21PH4207moO`050861P@23Ph<0Ph>308F5Q@2;Rh/00P25QHD03027QhL0PX:208N7Q`2:RXX0
R8R808j>SP2=SHd0Ti>C08n?S`2<S8`0Ti>C08f=S@80TY:B00<0V9RH09FEU@2GUiL00P2@T9003@2<
S8`0TY:B08j>SP2CTi<0Shn?08b<S02>SXh0S8b<08^;R`2:RXX0R8R808J6QP2:RXX00P27QhL04`25
QHD0Ph>30820P020P800OGem07]kN`1fMWH0Lg=c07EeM@1dM7@0Ogmo0:2PX02e]KD0a/K60<o?c`3C
dm<0fMWI0=gMg@3Kfm/00P3Jf]X0103Hf=P0e=CD0=CDe03Cdm<20=;BdP040=?Cd`3De=@0dM7A0=CD
e0<0d];B02T0e=CD0=7Ad@3Bd]80d=3@0=7Ad@3@d=00d];B0=3@d03Bd]80d=3@0=7Ad@3=cLd0c/k>
0<c<c038b<P0a<C40<;2`P31`L40_;bl0;Jf]P2^[Zh0XJ6Q09VIV@27QhL0MGEe05mOG`19BDT0@410
03Lg=`0];Bd0;Rh^03De=@0_;bl08b<S02LW9`0V9RH0;bl_02h^;P0a<C40;bl_03<c<`0>0<SPf000
3038h=P202l_;`0E030`<00/;2`0;Bd]02d];@0a<C40<30`02`/;00_;bl0:RXZ02d];@0_;bl0:RXZ
03De=@0Z:RX0:BTY038b<P0o?cl0@4100492@P1DE5@0GUiN0080GemO00X0G5aL05YJFP1TI6@0M7Ad
07YjNP23Ph<0RHV908^;R`2DU9@0UYJF0`2OWil0102UYJD0[:b/0:b/[02[Zj/20:j^[P060:b/[02]
[Jd0[:b/0:b/[02_[jl0[Jf]0P2`/;00C@2a/K40][Jf0;Bd]02a/K40[Zj^0:JVYP2RXZ80WinO09ZJ
VP2BTY80Rh^;07moO`1`L700IFEU05UIF@13@d<0>CTi0451@@1:BTX0K6a/096AT@2^[Zh0b<S808f=
S@1NGUh0IFEU07=cL`2PX:00MgMg030`<00];Bd0:RXZ02TY:@0a<C40ATI6055AD@1EEED0AdM703`l
?00j>SX0?3`l0492@P0j>SX0?3`l03Ti>@0c<c<0>3Ph04I6AP19BDT0?3`l02d];@0^;Rh0?clo03Hf
=P0[:b/0;Rh^038b<P0^;Rh0<c<c02TY:@0T92@0:BTY06=SH`2OWil0Ti>C08^;R`2DU9@0V9RH07em
O@1IFET0Cdm?055AD@1RHV80H61P055AD@11@D40>3Ph0080@D5101P0GEeM07AdM026QXH0LG5a08Z:
RP1/K6`0DE5A04i>CP1UIFD0Q8B4071`L01KFe/0K6a/0820P026QXH0SXj>08f=S@2UYJD0VYZJ092@
T02;Rh/0S8b<08F5Q@2HV9P20:^[Z`0@09^KV`2HV9P0VYZJ08N7Q`1<C4`0=CDe03Hf=P0^;Rh0;bl_
02h^;P0`<300<C4a03Hf=P0h>3P0<30`03De=@80>CTi0200<S8b03Lg=`0d=3@0<c<c0492@P19BDT0
BTY:04E5A@1@D500CTi>03Ti>@0a<C40:RXZ02PX:00Z:RX0;Rh^03lo?`1HF5P0?3`l034a<@0c<c<0
<30`03`l?00c<c<0<C4a030`<00g=cL0>SXj03Ti>@0f=SH0;Bd]038b<P<0=3@d00D0;bl_03De=@0c
<c<0;bl_03De=@0203<c<`0C034a<@0g=cL0>3Ph03`l?00o?cl0@d=30451@@0i>CT0@T9204M7A`0m
?Cd0AdM703lo?`14A4@0@41003Ti>@0e=CD0?3`l03De=@0204Y:BP0704E5A@1ADE40FEUI04Y:BP12
@T80ATI603Xj>P0203`l?00503Ph>00n?Sh0?clo0451@@0j>SX00P10@4002015ADD0A4A404Q8B01>
CTh0DU9B05iNGP1LG5`0FUYJ0P1PH6002P1RHV80IfMW05eMG@1VIVH0KFe]079bLP1hN7P0NGUi07Ad
M01gMgL207moO`80PX:20P25QHD01P26QXH0RXZ:09>CT`2DU9@0SXj>09:BTP80UYJF00D0U9BD09bL
W02NWYh0XZ:R0:JVYP030:6QX@0509NGU`2FUYH0UYJF09:BTP2HV9P00P2IVIT01P2ATI40TY:B08^;
R`27QhL0PH6108J6QP80PX:200T0RXZ:07moO`1YJFT0G5aL0410@00i>CT0<c<c03@d=00h>3P00P0e
=CD02`0f=SH0>c/k03Lg=`0h>3P0=cLg03De=@0i>CT0<S8b03lo?`0g=cL0=CDe0080>SXj00X0=SHf
03Ph>01=CDd0?Shn03<c<`0g=cL0>SXj03Lg=`0^;Rh0;Bd]0P0d=3@0:@0^;Rh0;bl_03Ph>011@D40
?clo03hn?P1CDe<0G5aL075aL@1]KFd0DE5A05ADE01GEeL0E5AD069RHP1CDe<0F5QH04e=C@1FEUH0
BTY:05UIF@1@D500F5QH05iNGP17AdL0@D5104E5A@1;Bd/0DU9B04=3@`1=CDd0=3@d05EEE@2>SXh0
/[:b0;2`/02DU9@0W9bL0:>SX`2DU9@0Ti>C0080QhN702H0O7al07moO`1aLG40L71`07MgM`1hN7P0
NGUi07YjNP23Ph<0QhN707emO@24Q8@0R8R808B4Q026QXH0RXZ:08N7Q`29RHT0SXj>08n?S`2:RXX0
SHf=08b<S02CTi<0UIFE09:BTP2ATI40T92@09>CT`2BTY80UIFE09:BTP2HV9P0UYJF09BDU02BTY80
Ti>C09FEU@80TY:B00X0UIFE09:BTP2BTY80T92@08^;R`2:RXX0SHf=08j>SP29RHT0QXJ60P25QHD0
5`21PH40Q8B408V9R@21PH40NGUi07YjNP1kNg/0MgMg07EeM@1cLg<0MWIf07UiN@2EUID0/k>c0<?3
``3=cLd0d];B0=KFeP3Lg=`0gMgM0=cLg03Jf]X0emOG0080eMGE00@0dm?C0=CDe03Cdm<0d];B0P3D
e=@00`3EeMD0d];B0=;BdP050=?Cd`030=CDe03AdM40d];B0080dm?C00H0dM7A0=;BdP3?cll0d=3@
0<o?c`3;bl/20<W9b@0B0<O7a`35aLD0_[jn0;Rh^02a/K40Z:RX0:2PX02IVIT0QhN707=cL`1OGel0
Bd];03`l?00d=3@0:b/[02TY:@0T92@09bLW0P0Y:BT302XZ:P0302d];@38h=P0b>3H00`0b>3H000<
0<SPf080:BTY00P0;2`/02TY:@0`<300=3@d02h^;P0a<C40;Bd]02h^;P80:b/[01h0;2`/02PX:00Z
:RX0<c<c02`/;00c<c<0=3@d03`l?015ADD0EeMG061PH01SHf<0GemO06=SH`1NGUh0Jf][07AdM020
P800PH6108Z:RP2?Shl0UYJF09ZJVP2OWil0XZ:R0:>SX`2VYZH0ZJVY0:b/[02`/;020:b/[080Zj^[
0P2/[:`20;:b/P0H0;6a/@2c/k<0/k>c0;6a/@2d];@0/K6a0:b/[02WYjL0YJFU0:>SX`2JVYX0Ti>C
08Z:RP20P800N7Qh06][J`1MGEd0BDU903Ti>@0f=SH0=CDe04M7A`1QHF40Q8B40P2NWYh205mOG`0/
05UIF@22PX80Lg=c034a<@0b<S80:RXZ02l_;`0i>CT0C4a<05mOG`1NGUh0Bd];03dm?@11@D40AdM7
0451@@0l?3`0?Cdm0410@00n?Sh0=cLg03Ti>@1;Bd/0@T9203`l?00h>3P0>CTi03@d=00Y:BT0;2`/
03Hf=P0];Bd0>3Ph02`/;00^;Rh0;Bd]07inOP2UYJD0SXj>08>3P`2BTY80S8b<061PH019BDT20410
@00505YJFP1HF5P0CDe=04A4A011@D400P1@D5005@1LG5`0NWYj07=cL`1hN7P0OGem06EUI@1EEED0
Fe]K07QhN02DU9@0MWIf05=CD`1^KVh0Ng]k08N7Q`26QXH0RXZ:09nOW`2PX:00TY:B09BDU00208F5
Q@0>08f=S@2HV9P0SXj>0820P02=SHd0Rh^;06EUI@0o?cl0;Rh^02TY:@0[:b/0:BTY02/[:`0/;2`2
02l_;`03034a<@0d=3@0<S8b0080>CTi01@0=3@d03<c<`0c<c<0=CDe0492@P14A4@0BTY:04I6AP1>
CTh0DE5A03<c<`0[:b/09bLW02XZ:P0X:2P0=CDe03lo?`1CDe<0>c/k03<c<`80;Rh^0P0_;bl01P0a
<C40=SHf03Xj>P0l?3`0=cLg030`<0<0;Rh^00H0=CDe034a<@0[:b/0:b/[030`<00d=3@303Hf=P0<
03@d=00h>3P0>3Ph03hn?P0m?Cd0>c/k03hn?P0i>CT0@41004Q8B015ADD0@D510P12@T800`11@D40
=3@d03`l?00203hn?P0604e=C@19BDT0AdM704i>CP1=CDd0AdM70P0m?Cd01@0j>SX0?Shn04A4A00l
?3`0>CTi0080@41000P0?Cdm03Ph>012@T80>CTi03Xj>P0n?Sh0?3`l04=3@`80BTY:00T0DE5A04m?
C`1KFe/0FEUI061PH01NGUh0Hf=S06IVIP1ZJVX00P1jNWX06@1fMWH0NGUi0861P@23Ph<0R8R808^;
R`2:RXX0SXj>08b<S02?Shl0VYZJ09RHV02@T900Ti>C09:BTP2FUYH0W9bL0:2PX02SXj<0XZ:R0:>S
X`2RXZ80YJFU0:2PX02KVi/00P2HV9P04@2EUID0V9RH09NGU`2GUiL0VYZJ09VIV@2DU9@0SXj>08^;
R`2>SXh0S8b<08:2PP2:RXX0QhN706m_K`1IFET0AdM70080<c<c00L0;Bd]03Lg=`0a<C40;Rh^03De
=@0g=cL0?3`l0080=3@d00D0=cLg03/k>`0k>c/0>c/k03Xj>P0203/k>`0703Hf=P0i>CT0>c/k055A
D@14A4@0=CDe03Lg=`0303Ti>@0503@d=00j>SX0=SHf02d];@0b<S800P0k>c/09@12@T80A4A405AD
E01PH600LW9b06m_K`1BDU80GEeM05iNGP1?Cdl0HF5Q055AD@1DE5@0ATI6059BDP1?Cdl0Fe]K04m?
C`1MGEd0GemO04Y:BP12@T80BTY:05IFEP1>CTh0?Shn03dm?@0a<C40FEUI08j>SP2`/;00[jn_09FE
U@2JVYX0YJFU09FEU@2BTY800P28R8P06020P800OGem07QhN01gMgL0N7Qh07emO@22PX80Q8B408F5
Q@23Ph<0R8R808N7Q`2:RXX0S8b<08f=S@2?Shl0U9BD09:BTP2?Shl0T92@09FEU@2BTY80UIFE09NG
U`80Ti>C00P0UYJF09FEU@2GUiL0U9BD09ZJVP2EUID0U9BD09>CT`<0U9BD00l0Shn?092@T02CTi<0
TI6A08j>SP2@T900SXj>08n?S`2<S8`0TY:B092@T02?Shl0RHV908Z:RP27QhL00P23Ph<04@29RHT0
QhN707moO`22PX80Ng]k07QhN01gMgL0LG5a07EeM@1lO7`0Shn?0:n_[`30`<00bl_;0=?Cd`3GemL0
g=cL0080gMgM00P0fm_K0=[JfP3Hf=P0emOG0=KFeP3EeMD0dM7A0=?Cd`80eMGE00@0e]KF0=7Ad@3A
dM40e=CD1@3Cdm<20=CDe0040=3@d03Bd]80dM7A0=7Ad@80clo?01D0dM7A0<o?c`3?cll0c<c<0<_;
b`38b<P0aLG50<71`@2n_[h0^k^k0;Fe]@2a/K40YZJV09^KV`28R8P0Ogmo06IVIP1:BTX0>SXj03@d
=00/;2`00`0[:b/202h^;P80:b/[3P38h=P000`0b>3H0P0];Bd03P0/;2`0=SHf02l_;`0_;bl0<C4a
038b<P0f=SH0<c<c030`<00/;2`0:RXZ02/[:`0d=3@0=cLg0P0a<C403@0i>CT0?Cdm04a<C01EEED0
GemO065QH@1SHf<0JFUY06][J`1`L700NWYj08:2PP20P8000P2<S8`02@2FUYH0VYZJ09bLW02OWil0
YJFU0:JVYP2ZZZX0[:b/0:n_[`030:f][@80[Zj^00T0Zj^[0;2`/02b/[80[jn_0;2`/02a/K40/;2`
0;>c/`2`/;000P2][Jd06@2XZ:P0YJFU09ZJVP2BTY80Shn?08:2PP1hN7P0JFUY05YJFP1ADE40A4A4
03Hf=P0g=cL0@D5104U9B@1UIFD0MWIf08:2PP1RHV80EeMG04I6AP1HF5P0IFEU038b<P0];Bd00P0[
:b/0;013@d<0D51@061PH01/K6`0C4a<03dm?@1<C4`0CTi>03hn?P0b<S80>CTi0451@@16ATH0>c/k
03hn?P11@D40EEEE03hn?P0i>CT0ADE5038b<P0Y:BT0:b/[03Ph>00f=SH0>c/k02@T900Q8B40<30`
07UiN@2TY:@0RHV907QhN02:RXX0Ph>305MGE`10@400>3Ph0410@01ADE40CDe=04M7A`15ADD0@D51
0P1FEUH07P1[Jf/0NGUi06QXJ01oOgl0LG5a05]KF`1MGEd0IFEU08F5Q@2IVIT0QHF5079bLP1`L700
Ng]k07moO`1jNWX0S8b<09NGU`2KVi/0Xj>S0:FUY@1fMWH0Lg=c07YjNP28R8P0MgMg075aL@21PH40
Kfm_0492@P80<S8b00H0<30`02h^;P0`<300<S8b03Hf=P0l?3`203@d=00403De=@0c<c<0<c<c03Ph
>080<C4a00H0=SHf03Lg=`0h>3P0>3Ph04E5A@12@T8204i>CP0E03Ph>00_;bl0<C4a034a<@0^;Rh0
<c<c03lo?`1;Bd/0?Shn03@d=00h>3P0<S8b03Hf=P0c<c<0<C4a03Xj>P0d=3@0>3Ph03Ti>@0d=3@0
<30`0080<c<c00L0=cLg02l_;`0Z:RX0;bl_038b<P0/;2`0>3Ph0080<c<c00H0=SHf03Ph>00m?Cd0
>SXj03/k>`0h>3P203Hf=P0803dm?@0o?cl0@D5103Xj>P14A4@0?clo03Ti>@0d=3@203Ti>@060451
@@1CDe<0BTY:04Q8B019BDT0ATI60P0m?Cd05@0e=CD0?3`l02d];@0d=3@0:b/[03@d=00h>3P0>SXj
03dm?@0j>SX0@D5104E5A@16ATH0AdM704E5A@14A4@0@D5104I6AP1=CDd0E5AD05YJFP0205iNGP0H
06IVIP1`L700Lg=c07QhN01aLG40NGUi07]kN`1iNGT0Ph>308F5Q@23Ph<0QhN708b<S02=SHd0T92@
09>CT`2HV9P0UYJF09VIV@2GUiL0T92@09bLW02OWil0XZ:R0P2VYZH20:BTY0040:NWY`2RXZ80WinO
09NGU`80Vi^K01@0VYZJ09^KV`2KVi/0Vi^K09jNWP2FUYH0Ti>C092@T02<S8`0SHf=08V9R@28R8P0
QhN707IfMP1QHF40@D5102/[:`0/;2`0;Rh^02l_;`80>CTi00T0<S8b03Hf=P0h>3P0>CTi03Hf=P0c
<c<0=cLg03<c<`0k>c/00P0h>3P0:`0g=cL0<C4a03Xj>P0f=SH0Bd];0410@00d=3@0<c<c03@d=00g
=cL0>SXj03@d=00f=SH0;bl_03<c<`0h>3P0=CDe0410@00m?Cd0@41005EEE@1QHF40LW9b06IVIP1?
Cdl0EeMG05EEE@1<C4`0HV9R04e=C@1KFe/0BTY:04i>CP1EEED0H61P059BDP1LG5`0FUYJ04U9B@0h
>3P0CDe=05aLG018B4P00P0l?3`01@0^;Rh0EeMG092@T02`/;00[:b/0080VYZJ00<0WinO09bLW02K
Vi/00P2=SHd05@26QXH0QhN70820P020P800Ph>308B4Q027QhL0Rh^;08Z:RP2=SHd0Ti>C08b<S02;
Rh/0SXj>09:BTP2?Shl0U9BD096AT@2>SXh0U9BD08n?S`0209NGU`0709BDU02EUID0UiNG09>CT`2L
W9`0VYZJ096AT@0309NGU`0409BDU02EUID0Ti>C09:BTP80U9BD00@0UIFE09:BTP2BTY80TY:B0P2?
Shl09`2>SXh0S8b<08Z:RP2<S8`0Rh^;08R8R02<S8`0QhN708J6QP2;Rh/0QhN708B4Q01nOWh0Ogmo
07]kN`1eMGD0MWIf07EeM@1gMgL0QXJ60:FUY@2k^k/0bLW90=7Ad@3Fe]H0fMWI0=kNgP3MgMd0g]kN
0=[JfP3GemL0fMWI0=KFeP3EeMD0d];B0=?Cd`3De=@0dm?C0=GEe@020=?Cd`80eMGE00L0e]KF0=CD
e03EeMD0e=CD0=GEe@3De=@0eMGE0080dm?C00<0e=CD0=3@d03@d=000P3@d=040<k>cP0?0<_;b`38
b<P0aLG50<?3``31`L40_Kfm0;Vi^@2c/k<0ZJVY0:>SX`2@T900P82006][J`1FEUH0@D510080<c<c
00<0<C4a030`<00^;Rh00P0[:b/>0<SPf0003038h=P202d];@0>02`/;00f=SH0;bl_02l_;`0a<C40
<S8b03Hf=P0c<c<0<30`02`/;00Z:RX0:b/[03@d=00g=cL2034a<@0=03Ti>@0m?Cd0C4a<05EEE@1O
Gel0HF5Q06=SH`1YJFT0Jf][071`L01jNWX0PX:20820P00208b<S00909JFUP2JVYX0W9bL09nOW`2U
YJD0YZJV0:ZZZP2/[:`0[jn_00<0[Jf]0P2^[Zh02@2[Zj/0/;2`0;:b/P2_[jl0/;2`0;6a/@2`/;00
/k>c0;2`/0020:f][@0I0:RXZ02UYJD0VYZJ09:BTP2?Shl0PX:207QhN01YJFT0FUYJ055AD@14A4@0
=SHf03Lg=`11@D40BDU906EUI@1fMWH0PX:2069RHP1GEeL0ATI605QHF01UIFD0<S8b02d];@0202/[
:`0/04=3@`1@D500H61P06a/K01<C4`0?Cdm04a<C01>CTh0?Shn038b<P0i>CT0@D5104I6AP0k>c/0
?Shn0451@@1EEED0?Shn03Ti>@15ADD0<S8b02TY:@0[:b/0>3Ph03Hf=P0k>c/092@T024Q8@0`<300
NGUi0:BTY029RHT0N7Qh08Z:RP23Ph<0EeMG0410@00h>3P0@410055AD@1=CDd0AdM704E5A@11@D42
05IFEP0N06][J`1iNGT0J6QX07moO`1aLG40Fe]K05eMG@1UIFD0QHF509VIV@25QHD0LW9b071`L01k
Ng/0Ogmo07YjNP2<S8`0UiNG09^KV`2SXj<0YJFU07IfMP1cLg<0NWYj08R8R01gMgL0LG5a0861P@1_
Kfl0@T920P0b<S801P0`<300;Rh^030`<00b<S80=SHf03`l?080=3@d00@0=CDe03<c<`0c<c<0>3Ph
0P0a<C401P0f=SH0=cLg03Ph>00h>3P0ADE50492@P80CTi>01D0>3Ph02l_;`0a<C40<C4a02h^;P0c
<c<0?clo04];B`0n?Sh0=3@d03Ph>00b<S80=SHf03<c<`0a<C40>SXj03@d=00h>3P0>CTi03@d=00`
<3000P0c<c<01`0g=cL0;bl_02XZ:P0_;bl0<S8b02`/;00h>3P00P0c<c<01P0f=SH0>3Ph03dm?@0j
>SX0>c/k03Ph>080=SHf00P0?Cdm03lo?`11@D40>SXj04A4A00o?cl0>CTi03@d=080>CTi00H0@D51
05=CD`1:BTX0B4Q804U9B@16ATH203dm?@0E03De=@0l?3`0;Bd]03@d=00[:b/0=3@d03Ph>00j>SX0
?Cdm03Xj>P11@D40ADE504I6AP17AdL0ADE504A4A011@D40ATI604e=C@1DE5@0FUYJ0080GUiN01P0
IVIV071`L01cLg<0N7Qh075aL@1iNGT0Ng]k07UiN@23Ph<0QHF508>3P`27QhL0S8b<08f=S@2@T900
Ti>C09RHV02FUYH0VIVI09NGU`2@T900W9bL09nOW`2RXZ820:JVYP80Y:BT00@0YjNW0::RXP2OWil0
UiNG0P2KVi/0502JVYX0Vi^K09^KV`2KVi/0WYjN09JFUP2CTi<0T92@08b<S02=SHd0RHV908R8R027
QhL0MWIf065QH@11@D40:b/[02`/;00^;Rh0;bl_0P0i>CT02@0b<S80=SHf03Ph>00i>CT0=SHf03<c
<`0g=cL0<c<c03/k>`0203Ph>00[03Lg=`0a<C40>SXj03Hf=P1;Bd/0@41003@d=00c<c<0=3@d03Lg
=`0j>SX0=3@d03Hf=P0_;bl0<c<c03Ph>00e=CD0@41003dm?@10@400EEEE065QH@1bLW80IVIV04m?
C`1GEeL0EEEE04a<C01RHV80CDe=05]KF`1:BTX0CTi>05EEE@1PH600DU9B05aLG01JFUX0BDU903Ph
>01=CDd0G5aL04Q8B00203`l?00502h^;P1GEeL0T92@0;2`/02/[:`00P2JVYX00`2OWil0W9bL09^K
V`0208f=S@0E08J6QP27QhL0P8200820P023Ph<0Q8B408N7Q`2;Rh/0RXZ:08f=S@2CTi<0S8b<08^;
R`2>SXh0TY:B08n?S`2DU9@0TI6A08j>SP2DU9@0Shn?0080UiNG00L0U9BD09FEU@2GUiL0Ti>C09bL
W02JVYX0TI6A00<0UiNG00@0U9BD09FEU@2CTi<0TY:B0P2DU9@0102EUID0TY:B09:BTP2BTY8208n?
S`0W08j>SP2<S8`0RXZ:08b<S02;Rh/0R8R808b<S027QhL0QXJ608^;R`27QhL0Q8B407inOP1oOgl0
Ng]k07EeM@1fMWH0MGEe07MgM`26QXH0YJFU0;^k^`39bLT0dM7A0=KFeP3IfMT0g]kN0=gMg@3Ng]h0
f][J0=OGe`3IfMT0e]KF0=GEe@3Bd]80dm?C0=CDe03Cdm<0eMGE0080dm?C0P3EeMD01`3Fe]H0e=CD
0=GEe@3De=@0eMGE0=CDe03EeMD00P3Cdm<00`3De=@0d=3@0=3@d0020=3@d0@0c/k>00l0bl_;0<S8
b035aLD0`l?30<71`@2m_Kd0^KVi0;>c/`2YZJT0Xj>S092@T020P800Jf][05IFEP11@D400P0c<c<0
0`0a<C40<30`02h^;P0202/[:`h0b>3H000<0<SPf00503Ph>00`<300;Rh^02d];@0/;2`00P0];Bd0
200^;Rh0;bl_02h^;P0];Bd09RHV02`/;00[:b/0<30`0P0e=CD06@0g=cL0>CTi04=3@`1;Bd/0FEUI
05mOG`1PH600IVIV06QXJ01_Kfl0M7Ad0861P@22PX80Ogmo08Z:RP2=SHd0U9BD09NGU`2IVIT0WYjN
0:>SX`2XZ:P0YjNW0;2`/02^[Zh00P2][Jd0202/[:`0ZZZZ0;2`/02_[jl0/K6a0:n_[`2b/[80]KFe
0P2c/k<0B`2`/;00/[:b0:f][@2/[:`0Y:BT0:JVYP2LW9`0UYJF096AT@23Ph<0Ng]k06a/K01IFET0
CTi>04A4A00o?cl0@d=30410@014A4@0C4a<06=SH`1lO7`0LW9b05=CD`11@D40>3Ph03Ti>@0h>3P0
;2`/02d];@0e=CD0@d=304U9B@18B4P0J6QX059BDP12@T80EeMG04I6AP0e=CD0<30`03Ti>@12@T80
>SXj0410@013@d<0@41004M7A`13@d<0ATI60492@P0c<c<0:RXZ02TY:@0h>3P0=CDe038b<P0W9bL0
;Bd]03lo?`22PX80XZ:R08J6QP1gMgL0RXZ:07inOP1KFe/0?Cdm03Ph>014A4@0GEeM04i>CP1:BTX0
DU9B05MGE`0205aLG00N07QhN01]KFd0GEeM07moO`1^KVh0G5aL06a/K025QHD0VYZJ09FEU@2JVYX0
VIVI07YjNP1iNGT0LW9b07UiN@2;Rh/0UYJF09nOW`2e]KD0XZ:R05eMG@16ATH0CDe=06][J`1^KVh0
Jf][07UiN@1JFUX0>CTi0P0c<c<0:@0`<300=cLg030`<00b<S80<c<c038b<P0f=SH0<S8b034a<@0f
=SH0<S8b03Ph>00f=SH0<c<c03Ti>@0h>3P0>CTi03dm?@12@T80@d=304Q8B01ADE40@D5103Lg=`0h
>3P0<30`034a<@0h>3P0>SXj04U9B@0o?cl0=cLg02l_;`0c<c<0=CDe03hn?P0c<c<0>SXj03Ti>@0l
?3`0>c/k0080<c<c00T0=CDe038b<P0g=cL0>3Ph03Lg=`0e=CD0<S8b03De=@0j>SX00`0k>c/0300n
?Sh0?3`l0492@P11@D40>3Ph03Ti>@0e=CD0>3Ph03Ti>@0m?Cd0>SXj03lo?`80>CTi00D0>3Ph03<c
<`0l?3`0BTY:04I6AP0204M7A`0404];B`0f=SH0<c<c03<c<`80;bl_00P0<c<c02l_;`0/;2`0=3@d
03Hf=P0n?Sh0?clo04i>CP80BDU901<0C4a<05aLG01FEUH0GEeM05QHF01KFe/0H61P06][J`1`L700
MWIf071`L01dM7@0Ng]k07IfMP1cLg<0P82007moO`20P800Ph>30080QHF500@0Rh^;096AT@2;Rh/0
TI6A0P2DU9@03`2FUYH0W9bL09RHV02GUiL0V9RH09bLW02XZ:P0Y:BT0:RXZ02VYZH0YjNW0:ZZZP2X
Z:P0Xj>S0:6QX@0309nOW`1H0:2PX02SXj<0Xj>S09^KV`2OWil0XJ6Q09RHV02CTi<0T92@08j>SP2=
SHd0S8b<08Z:RP1lO7`0JVYZ05EEE@0_;bl0;2`/02XZ:P0d=3@0@41003/k>`0m?Cd0@41003Xj>P0f
=SH0?3`l03dm?@0e=CD0>CTi03`l?00e=CD0>CTi0410@00k>c/0=SHf0410@01DE5@0BDU903Ti>@0j
>SX0=3@d03/k>`18B4P0<c<c03Lg=`0l?3`0<c<c03De=@0];Bd0<C4a03`l?00n?Sh0E5AD069RHP1_
Kfl0IfMW04Y:BP1HF5P0EEEE059BDP1RHV80CTi>05YJFP1<C4`0BTY:055AD@1QHF40DE5A05IFEP1D
E5@0BTY:03lo?`1CDe<0G5aL04M7A`0o?cl0>c/k034a<@1@D500R8R80:b/[02ZZZX0WYjN09^KV`2I
VIT0WYjN09^KV`80TY:B00T0RXZ:08N7Q`23Ph<0PX:208V9R@28R8P0S8b<096AT@2<S8`00P2ATI40
2P2?Shl0TI6A08n?S`2BTY80T92@09BDU02KVi/0Ti>C09JFUP2BTY8209RHV00:09FEU@2FUYH0UYJF
09>CT`2HV9P0Ti>C09FEU@2DU9@0UYJF09BDU080UIFE00<0V9RH096AT@2EUID00P2ATI40202?Shl0
T92@096AT@2=SHd0SXj>08b<S02:RXX0R8R80P29RHT0102<S8`0R8R808B4Q02;Rh/308N7Q`0@07mo
O`1nOWh0OGem07YjNP1gMgL0Lg=c07AdM020P800WYjN0;Rh^035aLD0clo?0=OGe`3Jf]X0gMgM0=kN
gP80fm_K00@0fMWI0=SHf03Hf=P0eMGE0P3De=@00`3Bd]80eMGE0=GEe@030=GEe@050=?Cd`3Bd]80
e=CD0=KFeP3Cdm<0103Fe]H40=?Cd`0L0=7Ad@3>c/h0d=3@0<k>cP3?cll0c/k>0<g=c@3>c/h0bl_;
0<[:bP37alL0a/K60<C4a02o_kl0^[Zj0;Bd]02WYjL0XJ6Q09BDU022PX80Lg=c061PH01<C4`0@T92
03Ti>@0c<c<0<C4a030`<0h0b>3H000<0<SPf080=3@d00<0<c<c038b<P0_;bl00P0a<C40100^;Rh0
;2`/02`/;00/;2`202d];@0L03Hf=P0g=cL0<30`03@d=00b<S80?3`l04];B`1ADE40EeMG05eMG@1T
I6@0Hf=S06ATI01]KFd0NGUi0820P026QXH0PH6108N7Q`2<S8`0TI6A09NGU`2JVYX0WYjN0:BTY02Y
ZJT0ZZZZ0:^[Z`<0[jn_02X0[Zj^0:b/[02][Jd0[:b/0;:b/P2`/;00[jn_0;6a/@2f][H0/k>c0;Bd
]02c/k<0/[:b0:n_[`2VYZH0Xj>S09fMW@2GUiL0SHf=08V9R@1iNGT0K6a/05YJFP1ADE40@41003/k
>`0l?3`0ADE504=3@`14A4@0EEEE06UYJ@1mOGd0H61P04A4A00l?3`0=3@d030`<00];Bd0<S8b034a
<@13@d<203Ph>00B06MWI`1YJFT0DU9B05iNGP12@T80<30`038b<P0n?Sh0?Cdm04E5A@19BDT0>SXj
034a<@1:BTX0B4Q80492@P13@d<0<S8b0P0_;bl05@0h>3P0=3@d02h^;P0Y:BT0:2PX04];B`28R8P0
V9RH08B4Q01hN7P0Rh^;07AdM01=CDd0>CTi02h^;P1>CTh0De=C04];B`1ADE40IVIV05aLG002065Q
H@0o07YjNP1IFET0Hf=S07alO01hN7P0Ng]k08Z:RP2EUID0UiNG08N7Q`26QXH0T92@08V9R@1_Kfl0
LW9b08F5Q@2>SXh0S8b<09VIV@2UYJD0Ph>3055AD@12@T80AdM705IFEP1LG5`0E5AD05eMG@1?Cdl0
?clo03De=@0f=SH0=3@d03`l?00c<c<0=CDe030`<00f=SH0>3Ph03/k>`0g=cL0>CTi03Hf=P0g=cL0
<C4a038b<P0c<c<0>c/k03Ph>00n?Sh0A4A404=3@`16ATH0CDe=0410@00b<S80<c<c02`/;00Z:RX0
;Bd]03Lg=`15ADD0?Shn0080;bl_00<0<S8b03@d=00j>SX00P0e=CD01`0c<c<0>CTi03<c<`0_;bl0
<30`02l_;`0g=cL00P0c<c<01@0`<300;Rh^038b<P0g=cL0?3`l0080>c/k00X0=SHf03Ph>00l?3`0
?Cdm04=3@`0j>SX0=3@d03Ti>@0l?3`0?Cdm0P0l?3`09P15ADD0>CTi03Ph>00b<S80?3`l04U9B@1B
DU80ATI604a<C01=CDd0?clo03hn?P0h>3P0=3@d03De=@0d=3@0;Rh^02l_;`0c<c<0?Cdm03Lg=`0o
?cl0CTi>051@D01GEeL0FEUI069RHP1TI6@0IVIV06=SH`1[Jf/0L71`079bLP1iNGT0O7al07inOP1l
O7`0PH610P24Q8@08022PX80QXJ608^;R`2:RXX0RHV908n?S`2=SHd0TI6A09>CT`2BTY80Ti>C09:B
TP2HV9P0UYJF09^KV`2LW9`0WIfM09ZJVP2UYJD0YjNW0:JVYP2XZ:P0Y:BT0:RXZ02[Zj/0[Jf]0:FU
Y@2QXJ40Y:BT0:>SX`2UYJD0YjNW0P2UYJD0702NWYh0WinO09fMW@2IVIT0VYZJ09:BTP2CTi<0TI6A
08n?S`2:RXX0OGem06i^KP1HF5P0;Bd]02`/;00`<300=3@d0492@P0i>CT0=CDe03@d=00i>CT0>c/k
03`l?00f=SH0>SXj03Ti>@0l?3`203Ph>00?03Ti>@0j>SX0<C4a03Hf=P16ATH0CTi>03`l?00h>3P0
=CDe03Ti>@11@D40<30`02l_;`0b<S80>SXj0080>CTi02H0=cLg03De=@15ADD0EEEE06ATI01aLG40
IfMW051@D01HF5P0EeMG04a<C01VIVH0BDU905=CD`1;Bd/0CTi>04m?C`1KFe/0DU9B05EEE@1GEeL0
CTi>03lo?`1?Cdl0H61P04U9B@0l?3`0>3Ph02h^;P16ATH0Ph>30;2`/02[Zj/0WinO09jNWP2IVIT0
X:2P09bLW0<0SXj>00D0T92@08b<S02;Rh/0S8b<092@T00309:BTP0@09FEU@2DU9@0Ti>C09FEU@2C
Ti<0UiNG09RHV02DU9@0UiNG09VIV@2CTi<0T92@09FEU@2GUiL0UIFE09BDU080UiNG0180UYJF09>C
T`2CTi<0UIFE096AT@2BTY80UYJF09NGU`2CTi<0UIFE09BDU02@T900U9BD09>CT`2?Shl0S8b<096A
T@2?Shl208^;R`0408V9R@2<S8`0S8b<08^;R`<0RHV901T0R8R808N7Q`24Q8@0P8200861P@1mOGd0
NGUi07QhN01eMGD0MWIf07]kN`2BTY80/[:b0<K6aP3@d=00e=CD0=[JfP3MgMd0g=cL0=kNgP3MgMd0
f][J0=WIf@3GemL0eMGE00<0d];B00P0dm?C0=KFeP3EeMD0eMGE0=KFeP3De=@0eMGE0=?Cd`80eMGE
00T0e]KF0=OGe`3GemL0e]KF0=CDe03Fe]H0e=CD0=?Cd`3Bd]800P3AdM400`3>c/h0cLg=0<o?c`02
0<k>cP80cLg=0180c<c<0<_;b`3:b/X0alO70<?3``2o_kl0][Jf0;>c/`2_[jl0YZJV09RHV02=SHd0
PX:207=cL`1SHf<0DU9B03dm?@0k>c/>0<SPf0003038h=P203<c<`0402d];@0_;bl0=SHf03@d=080
=CDe00@0<S8b030`<00a<C40;bl_0P0a<C406P0^;Rh0;2`/038b<P0f=SH0@d=304a<C01EEED0FUYJ
065QH@1PH600Hf=S06QXJ01bLW80MWIf0861P@24Q8@0QXJ608N7Q`29RHT0TI6A09JFUP2MWId0WYjN
0:>SX`2WYjL0ZZZZ0P2^[Zh30:n_[`80[Zj^0P2`/;00102a/K40/[:b0;:b/P2b/[820;>c/`0/0:f]
[@2b/[80Zj^[0:RXZ02OWil0WYjN09JFUP2<S8`0QHF507]kN`1^KVh0FUYJ04m?C`17AdL0?3`l0410
@012@T80CDe=04i>CP1HF5P0GEeM079bLP1hN7P0Cdm?03/k>`0b<S80<C4a03@d=00h>3P0<c<c03`l
?00];Bd0<C4a05YJFP1mOGd0GUiN06ATI019BDT0<30`03<c<`0i>CT0?3`l04M7A`12@T82034a<@0L
04A4A01BDU80@D5104E5A@0b<S809RHV030`<00g=cL0;bl_02`/;00Q8B40?3`l05eMG@20P800T92@
07YjNP1oOgl0QHF506YZJP0i>CT0<C4a03Hf=P16ATH0AdM70451@@1NGUh0Jf][05MGE`80L71`0100
KFe]06YZJP1`L700N7Qh08>3P`28R8P0Shn?08V9R@2;Rh/0LW9b06YZJP1bLW80NWYj07=cL`1mOGd0
QXJ60P2;Rh/05`2JVYX0QXJ605aLG01DE5@0EeMG04a<C01OGel0Jf][05YJFP11@D40?3`l04I6AP0l
?3`0=CDe03lo?`0h>3P0=CDe03<c<`0b<S80<30`02l_;`0d=3@0=CDe0080<S8b0100<30`02`/;00`
<300<30`02h^;P0h>3P0>c/k0451@@0j>SX0@41004=3@`0l?3`0=CDe02l_;`0];Bd0;2`/0P0d=3@0
5`17AdL0@410030`<00];Bd0<S8b03<c<`0g=cL0;Bd]03<c<`0k>c/0>CTi02l_;`0/;2`0<C4a038b
<P0h>3P0;Bd]02h^;P0c<c<0<C4a03Lg=`0o?cl0?Cdm0080>3Ph00@0<S8b03Lg=`0k>c/0>CTi0P0c
<c<0100`<300=cLg03dm?@14A4@203`l?00?04I6AP0n?Sh0>CTi03@d=00h>3P0@41004a<C015ADD0
D51@04];B`0k>c/0<c<c030`<00];Bd0:RXZ0080:BTY01D0<30`03Lg=`0o?cl0@41004I6AP1ADE40
Cdm?05]KF`1SHf<0JVYZ06m_K`1eMGD0LG5a07EeM@1fMWH0M7Ad07IfMP1mOGd0OWin07emO@25QHD0
0P24Q8@04@22PX80Rh^;08Z:RP2?Shl0SXj>09>CT`2BTY80U9BD09>CT`2GUiL0Ti>C09NGU`2DU9@0
VYZJ09bLW02MWId0WinO0080Y:BT00<0ZJVY0:JVYP2YZJT00P2/[:`0102a/K40Z:RX0:^[Z`2XZ:P2
0:FUY@80Z:RX0`2VYZH04P2QXJ40Y:BT09^KV`2MWId0TY:B096AT@2CTi<0UYJF08b<S022PX80KVi^
059BDP0];Bd0:2PX02/[:`0_;bl0?clo03Ti>@80<c<c0180>3Ph03`l?00m?Cd0=cLg03Xj>P0g=cL0
>CTi03Hf=P0e=CD0>SXj03Lg=`0h>3P0?Cdm0410@01BDU80@D51034a<@0^;Rh203Ph>00D03@d=00`
<300>3Ph03Ti>@0`<300=CDe030`<00l?3`0B4Q804m?C`1XJ6P0M7Ad06EUI@1@D500CTi>055AD@1>
CTh0JVYZ04U9B@1@D50204Y:BP0F04a<C01IFET0CTi>04i>CP1HF5P0BDU903<c<`1;Bd/0FUYJ04A4
A00d=3@0=SHf02d];@12@T80Q8B40:^[Z`2/[:`0X:2P09fMW@2LW9`0Xj>S0:BTY080U9BD00/0Ti>C
09JFUP2CTi<0TY:B09BDU02EUID0UiNG09RHV02JVYX0V9RH09FEU@0209RHV00<09VIV@2DU9@0UYJF
09BDU02GUiL0Vi^K09>CT`2GUiL0VIVI09FEU@2JVYX0Ti>C0P2FUYH03@2GUiL0U9BD09BDU02EUID0
V9RH09VIV@2HV9P0UiNG09>CT`2BTY80UYJF092@T02ATI400P2?Shl02`2CTi<0TY:B08f=S@2>SXh0
S8b<08f=S@2:RXX0SHf=08R8R02<S8`0RXZ:0080RHV900@0Q8B408>3P`22PX80OWin0P1mOGd05`1f
MWH0MGEe07EeM@1kNg/0T92@0:j^[P32`/80cLg=0=GEe@3Hf=P0gMgM0=kNgP3MgMd0g]kN0=[JfP3I
fMT0emOG0=GEe@3Cdm<0d];B0=7Ad@3Bd]80eMGE0080dm?C00<0e=CD0=GEe@3Cdm<0103Fe]H20=SH
f0090=KFeP3De=@0eMGE0=CDe03EeMD0dM7A0=3@d03AdM40d=3@00D0c/k>01<0d=3@0<[:bP3<c<`0
bl_;0<[:bP38b<P0a<C40<;2`P2o_kl0_[jn0;Rh^02f][H0[Jf]0:RXZ02MWId0TI6A0861P@1aLG40
HF5Q00h0b>3H000<0<SPf080<C4a0P0/;2`00`0_;bl0=cLg03De=@02038b<P0303@d=00`<300<S8b
0080;Rh^0180;Bd]034a<@0o?cl0>SXj04Y:BP1>CTh0DU9B05mOG`1MGEd0HF5Q06=SH`1TI6@0IVIV
075aL@1kNg/0Q8B408N7Q`2<S8`208j>SP0809>CT`2KVi/0WYjN0::RXP2YZJT0Zj^[0:b/[02^[Zh2
0;>c/`030:j^[P2`/;00/K6a0080/K6a00<0/[:b0;2`/02b/[800P2b/[803`2f][H0/[:b0:n_[`2Y
ZJT0YZJV0:6QX@2OWil0UiNG08^;R`23Ph<0Ng]k06][J`1LG5`0Cdm?04a<C00204A4A00V04I6AP1<
C4`0DE5A05UIF@1PH600IFEU07UiN@1[Jf/0>CTi03De=@0f=SH0=CDe03Ti>@0k>c/0=SHf02`/;00d
=3@0CTi>0820P01^KVh0I6AT0451@@0Z:RX0=CDe03Xj>P11@D40A4A403Xj>P0a<C40;Bd]03Ti>@1E
EED0AdM70492@P0c<c<0:RXZ034a<@0n?Sh202h^;P0=02TY:@0l?3`0IVIV08>3P`2GUiL0M7Ad07]k
N`26QXH0F5QH03Hf=P0b<S80>CTi04I6AP0203lo?`0305YJFP1MGEd0Fe]K0080Jf][01/0K6a/0820
P01nOWh0NGUi07moO`20P800S8b<08N7Q`22PX80LW9b06a/K01`L700LW9b0820P01fMWH0RXZ:09JF
UP2?Shl0TY:B06UYJ@1=CDd0KVi^06][J`1GEeL0Lg=c07YjNP1ADE400P0g=cL06013@d<0B4Q803Ph
>00e=CD0=3@d03Ti>@0_;bl0;2`/03Hf=P0h>3P0>SXj03Ti>@0k>c/0=CDe03<c<`0_;bl0<c<c030`
<00_;bl0=3@d03De=@10@400>c/k03`l?080@41000h0;bl_034a<@0Z:RX0;Rh^03Xj>P0h>3P0B4Q8
03dm?@0e=CD0<S8b03<c<`0d=3@0=CDe034a<@80@T9200d0>3Ph03Ti>@0_;bl0;Bd]038b<P0a<C40
;Rh^02l_;`0d=3@0<30`03Ti>@0k>c/0?Shn0080?3`l00@0<30`03Xj>P13@d<0=3@d0P0c<c<04@0k
>c/0?clo03/k>`0h>3P0=CDe0410@016ATH0?3`l03Ti>@0`<300=CDe04Y:BP13@d<0B4Q804E5A@12
@T80;bl_0080<C4a0100;Bd]02/[:`0e=CD0=CDe03dm?@0n?Sh0ADE5055AD@1CDe<0EEEE05MGE`1M
GEd0Jf][06e]K@1aLG40N7Qh0P1jNWX0801kNg/0O7al07inOP22PX80P82008J6QP27QhL0QXJ608^;
R`29RHT0R8R808Z:RP2?Shl0UIFE096AT@2=SHd0TY:B092@T02GUiL0UYJF09RHV02FUYH0UiNG09^K
V`2WYjL0YJFU0:BTY02QXJ40YJFU0:RXZ02VYZH0Z:RX0P2/[:`20:ZZZP050:FUY@2VYZH0Z:RX0:^[
Z`2YZJT00P2[Zj/01P2ZZZX0ZJVY0:FUY@2LW9`0WIfM096AT@80TY:B04d0UiNG08Z:RP24Q8@0L71`
059BDP0/;2`09BDU02/[:`0b<S80ADE50410@00a<C40=CDe03Hf=P0b<S80>CTi03/k>`0j>SX0=SHf
03De=@0d=3@0=SHf03Ph>00i>CT0>SXj03/k>`12@T80C4a<03Ph>00d=3@0<S8b034a<@0g=cL0>3Ph
034a<@0g=cL0<S8b03@d=00i>CT0;Rh^03/k>`0o?cl0CDe=06QXJ01eMGD0J6QX04M7A`1:BTX0D51@
04e=C@1_Kfl0A4A404e=C@16ATH0@D51055AD@1GEeL0Cdm?04I6AP1=CDd0Bd];03Lg=`16ATH0F5QH
04M7A`0d=3@0?3`l02`/;015ADD0RHV90:f][@2^[Zh0Xj>S0::RXP2LW9`0WinO0:NWY`02096AT@0G
08j>SP2BTY80UiNG09NGU`2IVIT0VYZJ09JFUP2KVi/0WinO09bLW02JVYX0W9bL09RHV02GUiL0UYJF
09>CT`2EUID0UYJF09NGU`2JVYX0V9RH09NGU`2HV9P00P2GUiL00`2IVIT0U9BD09JFUP0209>CT`04
09RHV02IVIT0Ti>C09>CT`80UYJF00D0UiNG09>CT`2EUID0TI6A092@T00208n?S`0408j>SP2:RXX0
SXj>08b<S0@0R8R800H0S8b<08R8R028R8P0QhN708J6QP23Ph<207moO`80O7al00/0MgMg07AdM01e
MGD0N7Qh08N7Q`2UYJD0`<300<g=c@3Cdm<0fMWI0>3Ph0020=kNgP070>3Ph03Jf]X0fMWI0=OGe`3F
e]H0e=CD0=?Cd`020=;BdP030=GEe@3Cdm<0dm?C0080e=CD0P3EeMD01`3Fe]H0emOG0=SHf03GemL0
f=SH0=WIf@3Fe]H00P3EeMD02P3De=@0eMGE0=7Ad@3@d=00clo?0=3@d03>c/h0c<c<0<k>cP3=cLd2
0<o?c`040<[:bP3<c<`0b/[:0<W9b@80alO70P35aLD02@33`l<0`<300;fm_@2j^[X0];Bd0;>c/`2X
Z:P0WinO08j>SP0>0<SPf0003038h=P2030`<00>02h^;P0b<S80=CDe03Hf=P0i>CT0=SHf030`<00Z
:RX0:b/[02h^;P0b<S80>CTi034a<@0g=cL20451@@80DE5A01H0FEUI05eMG@1PH600GemO061PH01R
HV80Hf=S06m_K`1iNGT0PH6108V9R@27QhL0R8R8096AT@2CTi<0VYZJ09^KV`2TY:@0Z:RX0:ZZZP2/
[:`0/K6a0P2][Jd20:n_[`80[Zj^00H0/K6a0;Fe]@2`/;00[jn_0;>c/`2d];@20;>c/`0=0:b/[02X
Z:P0XJ6Q0:>SX`2OWil0UYJF08f=S@23Ph<0N7Qh075aL@1LG5`0Cdm?04E5A@020451@@0K04Q8B01>
CTh0DE5A05UIF@1ZJVX0Hf=S07AdM01fMWH0F5QH03Hf=P0h>3P0=cLg03Hf=P0k>c/0>CTi03Ph>00a
<C40CTi>08:2PP1cLg<0EeMG038b<P0_;bl0>c/k030`<00n?Sh0>3Ph0080<C4a01d0<30`03`l?01>
CTh0CTi>04=3@`0_;bl0;Bd]034a<@11@D40<c<c02/[:`0m?Cd0CTi>061PH02<S8`0Vi^K06EUI@1_
Kfl0N7Qh051@D00`<300;bl_0492@P0o?cl0=SHf0410@01BDU80E5AD06e]K@0207AdM00U08Z:RP24
Q8@0MWIf06m_K`1/K6`0Ogmo08Z:RP2>SXh0Q8B407EeM@1_Kfl0K6a/0861P@2<S8`0MgMg08R8R02F
UYH0T92@08f=S@1JFUX0FEUI075aL@1VIVH0C4a<06QXJ01cLg<0Bd];03Lg=`0i>CT0>SXj04];B`18
B4P0?3`l03@d=00e=CD0<c<c034a<@0203De=@080492@P0k>c/0=3@d034a<@0];Bd0=SHf034a<@0f
=SH203@d=00?03/k>`13@d<0@4100410@012@T80?clo03@d=00^;Rh0<30`02h^;P0d=3@0=SHf04U9
B@0m?Cd0;Bd]0080<S8b00L0=3@d03Lg=`0a<C40>CTi03/k>`0b<S80;2`/0080;Rh^0P0`<3001`0^
;Rh0<S8b03/k>`0i>CT0=SHf03Xj>P0l?3`00P0d=3@07P0a<C40>3Ph03Ph>00d=3@0>CTi03De=@0i
>CT0B4Q803/k>`0c<c<0=SHf04A4A010@400A4A403Ti>@0c<c<0>c/k04Y:BP12@T80Bd];03dm?@0c
<c<0;Rh^02`/;00`<300;Bd]030`<00h>3P0?clo0451@@80Bd];01T0E5AD059BDP1JFUX0HF5Q06EU
I@1ZJVX0M7Ad079bLP1hN7P0O7al07UiN@1mOGd0Ogmo08:2PP21PH40Ph>308V9R@26QXH0QhN708b<
S02;Rh/0TI6A08j>SP2=SHd0U9BD0080TI6A00d0Shn?09>CT`2GUiL0TY:B09^KV`2IVIT0VYZJ09jN
WP2[Zj/0ZJVY0:NWY`2UYJD0YZJV0080YjNW00X0YZJV0:j^[P2VYZH0Y:BT0:RXZ02VYZH0Y:BT0:VY
Z@2XZ:P0/;2`0P2XZ:P04@2c/k<0[Jf]0:RXZ02PX:00W9bL09JFUP2@T900UiNG09^KV`2CTi<0TI6A
07QhN01DE5@0;bl_02d];@0Y:BT0=CDe0080@D5100T0=CDe03<c<`0h>3P0=SHf03Xj>P0h>3P0=SHf
03<c<`0i>CT00P0e=CD203Hf=P0e03Ph>012@T80=cLg051@D00f=SH0=3@d038b<P0_;bl0<C4a03Xj
>P0i>CT0>c/k02/[:`0a<C40=3@d02d];@0k>c/0>CTi04];B`1VIVH0M7Ad06QXJ013@d<0DU9B05AD
E01?Cdl0Kfm_04Y:BP1CDe<0DU9B04A4A01DE5@0DU9B04a<C01:BTX0CTi>04A4A00c<c<0EeMG05QH
F016ATH0>SXj04E5A@0/;2`0AdM70861P@2_[jl0/K6a0:JVYP2NWYh0WinO09fMW@2XZ:P00P2DU9@0
0`2<S8`0U9BD09FEU@0209RHV00A09bLW02IVIT0VYZJ09nOW`2MWId0W9bL09jNWP2FUYH0Vi^K09VI
V@2ATI40TY:B096AT@2GUiL0V9RH09JFUP2IVIT00P2GUiL0102BTY80UIFE09JFUP2EUID209BDU007
09:BTP2CTi<0UiNG09BDU02BTY80VIVI09BDU00209FEU@0709RHV02DU9@0TY:B09:BTP2?Shl0SHf=
092@T00208n?S`0T08b<S02:RXX0SXj>08V9R@28R8P0SHf=08Z:RP27QhL0R8R808F5Q@21PH40OGem
07YjNP1iNGT0LW9b07AdM01lO7`0QXJ60:>SX`2k^k/0bl_;0=CDe03IfMT0gmoO0=gMg@3QhN40g]kN
0=[JfP3IfMT0f=SH0=KFeP3Cdm<0dM7A0=CDe03@d=00dm?C0P3EeMD01`3Bd]80e=CD0=KFeP3GemL0
e=CD0=GEe@3Fe]H00P3GemL00`3Hf=P0e]KF0=GEe@020=KFeP070=CDe03Bd]80d=3@0=3@d03Cdm<0
dM7A0<k>cP020<g=c@80c/k>00L0cLg=0<c<c03<c<`0b/[:0<c<c03;bl/0b/[:0080bl_;00@0b/[:
0<O7a`36a/H0_kno0P2m_Kd00`2e]KD0[Jf]0<SPf00=0<SPf0003038h=P202l_;`0@02h^;P0];Bd0
<C4a03Ti>@0b<S80<c<c02d];@0^;Rh0;Bd]02h^;P0/;2`0<c<c03De=@0/;2`0=SHf04A4A080EEEE
00<0EeMG05aLG01PH6000P1OGel02P1PH600IVIV06m_K`1jNWX0OGem08B4Q028R8P0RHV908b<S02E
UID209^KV`050:>SX`2ZZZX0ZJVY0:n_[`2c/k<00P2b/[830;2`/0030:n_[`2/[:`0/;2`0080/;2`
01h0/k>c0;Fe]@2d];@0/K6a0;:b/P2[Zj/0YjNW0:>SX`2KVi/0Ti>C08j>SP25QHD0PH61071`L01O
Gel0E5AD04U9B@17AdL0ADE504Q8B01ADE40E5AD05YJFP1QHF40Hf=S061PH01UIFD0EUIF04];B`19
BDT203`l?00]04I6AP15ADD0=3@d02l_;`18B4P0N7Qh0820P01ADE40;bl_03<c<`0o?cl0?Cdm03hn
?P0e=CD0;Bd]030`<00c<c<0@41005YJFP1EEED0A4A402`/;00c<c<0=SHf03lo?`0g=cL0;Bd]03/k
>`1ADE40Fe]K07moO`2IVIT0EUIF069RHP1UIFD0ATI603Ti>@0b<S80>3Ph03Lg=`0c<c<0BTY:05EE
E@1/K6`0QHF50080Rh^;00H0RHV908b<S028R8P0JVYZ071`L020P80208:2PP0J07QhN01YJFT0I6AT
06ATI02JVYX0U9BD07emO@1gMgL0O7al092@T02HV9P0Ph>306i^KP1NGUh0CDe=04Q8B01iNGT0GEeM
0492@P1FEUH0DE5A03Xj>P10@400Jf][04I6AP0b<S8203<c<`0`03Ph>00e=CD0<c<c0451@@0j>SX0
<c<c038b<P0`<300<C4a03Lg=`0f=SH0=cLg02l_;`0i>CT0@D5103dm?@0l?3`0?Cdm03Xj>P0m?Cd0
;2`/02h^;P0/;2`0<C4a03Ph>00n?Sh0>SXj030`<00c<c<0>3Ph03De=@0^;Rh0<S8b03hn?P0g=cL0
<c<c02h^;P0b<S80;Rh^03Hf=P0b<S80=3@d03De=@0k>c/0>SXj03@d=013@d<0>c/k0`0g=cL01@0h
>3P0=cLg03Ph>00i>CT0=SHf00<0>c/k02H0=SHf03Xj>P13@d<0@4100492@P0f=SH0=CDe03`l?01=
CDd0BTY:04a<C011@D40<C4a03De=@0^;Rh0;Bd]02l_;`0b<S80=cLg0492@P19BDT0DE5A05QHF01G
EeL0F5QH05]KF`1MGEd0J6QX06m_K`1fMWH0MGEe07MgM`1kNg/0OWin08F5Q@21PH40Ph>308B4Q0<0
QhN701<0Rh^;08b<S028R8P0SHf=092@T02ATI40T92@096AT@2@T900UIFE09>CT`2HV9P0W9bL09VI
V@2MWId0XJ6Q0:NWY`2[Zj/0[Zj^0080YjNW00H0Zj^[0:JVYP2VYZH0Z:RX0:ZZZP2VYZH20:NWY`05
0:JVYP2UYJD0YJFU0:RXZ02_[jl00P2][Jd0>`2c/k<0/;2`0:VYZ@2SXj<0WYjN09bLW02>SXh0TY:B
09JFUP2IVIT0TY:B08B4Q01IFET0<c<c02TY:@0];Bd0:b/[03Lg=`1;Bd/0=cLg03<c<`0d=3@0<S8b
03Ti>@0d=3@0=SHf03<c<`0b<S80<30`03Hf=P0n?Sh0<c<c03Ph>00o?cl0?Shn04U9B@0h>3P0=3@d
038b<P0Z:RX0<C4a03De=@0o?cl0>3Ph02/[:`0`<300<S8b03De=@0g=cL0=SHf04A4A01KFe/0NWYj
06UYJ@1BDU80Cdm?05=CD`1=CDd0Lg=c00<0CDe=01L0@D51059BDP1HF5P0BDU9059BDP1FEUH0ATI6
02l_;`1:BTX0EeMG03`l?00h>3P0@41002XZ:P11@D40Ph>30:b/[02a/K40ZZZZ0::RXP2KVi/0Xj>S
0:BTY00208n?S`0E08j>SP2EUID0TY:B09bLW02NWYh0X:2P09^KV`2OWil0WIfM09jNWP2MWId0WYjN
09ZJVP2KVi/0UYJF09VIV@2GUiL0U9BD09JFUP2HV9P0UiNG0080V9RH0100Vi^K09BDU02IVIT0UIFE
09VIV@2FUYH0UIFE09JFUP2EUID0UiNG09VIV@2DU9@0V9RH09>CT`2EUID0V9RH0P2DU9@01@2EUID0
Ti>C08n?S`2@T900SXj>00<0S8b<00@0Rh^;08V9R@2=SHd0S8b<0P2;Rh/06023Ph<0RHV908B4Q01k
Ng/0QXJ607moO`1kNg/0MGEe07IfMP1cLg<0Ogmo09bLW02j^[X0bLW90=;BdP3IfMT0fm_K0=gMg@3N
g]h0gMgM0=_Kf`3Jf]X0emOG0=SHf0<0e=CD103Bd]830=?Cd`040=CDe03EeMD0eMGE0=GEe@<0emOG
0P3Fe]H00`3GemL0f=SH0=GEe@020=?Cd`090=;BdP3AdM40d=3@0<o?c`3>c/h0bl_;0<k>cP3AdM40
clo?0080cLg=00H0bl_;0<c<c03;bl/0c/k>0<_;b`3<c<`20<[:bP060<_;b`39bLT0alO70<?3``32
`/80_[jn3P38h=P000`0b>3H0P0_;bl01`0b<S80<c<c02h^;P0e=CD0=cLg02l_;`0c<c<00P0^;Rh2
038b<P80<30`00<0;bl_03@d=01;Bd/00P1IFET0301LG5`0I6AT06QXJ01VIVH0IFEU065QH@1TI6@0
Jf][07YjNP21PH40QXJ608V9R@80SHf=00P0Ti>C09RHV02LW9`0Xj>S0:JVYP2[Zj/0/;2`0;6a/@80
/k>c01T0/;2`0;6a/@2b/[80/;2`0;6a/@2b/[80/K6a0;2`/02_[jl0/;2`0;6a/@2c/k<0Zj^[0:RX
Z02TY:@0XZ:R09nOW`2BTY80SHf=0861P@1lO7`0LG5a05aLG01DE5@0BTY:0080@41000L0BDU904m?
C`1@D500FUYJ06ATI01ZJVX0IFEU0080G5aL0100JFUY04U9B@0h>3P0>3Ph055AD@19BDT0>CTi030`
<014A4@0KFe]07inOP1@D500=3@d02l_;`0g=cL0>SXj0P0l?3`02`0/;2`0<S8b02TY:@0m?Cd0Hf=S
05MGE`13@d<0<S8b02`/;00k>c/0@T920080=3@d0180A4A405ADE01GEeL0NGUi09:BTP1CDe<0JFUY
06IVIP11@D40;bl_03Ph>00k>c/0?3`l04=3@`1DE5@0MgMg08J6QP1oOgl208F5Q@0d09FEU@2DU9@0
QHF5079bLP21PH40O7al07UiN@1fMWH0J6QX05eMG@1?Cdl0JVYZ0:FUY@2CTi<0KVi^06QXJ01gMgL0
UYJF09nOW`1oOgl0De=C04E5A@1<C4`0D51@08J6QP1[Jf/0DE5A0:FUY@2WYjL0A4A403Ti>@1@D500
G5aL03Ph>00c<c<0<30`03Hf=P0`<300=SHf03Lg=`0f=SH0=CDe03Hf=P0d=3@0<S8b034a<@0e=CD0
;bl_02d];@0l?3`0?clo0410@080>SXj01H0>CTi03Ph>00d=3@0;Rh^02/[:`0c<c<0>CTi03Xj>P12
@T80<30`02h^;P0Y:BT0;Rh^038b<P0h>3P0?Cdm03De=@0];Bd0;bl_02h^;P0];Bd0=3@d0`0`<300
1@0e=CD0>3Ph03Ph>00l?3`0<S8b0080=SHf00L0>SXj03Ph>00d=3@0>3Ph03Lg=`0i>CT0>c/k0080
>3Ph01h0>SXj03/k>`0o?cl0@4100451@@0a<C40>CTi04E5A@17AdL0Cdm?04M7A`0i>CT0<S8b02d]
;@0a<C40=3@d03Xj>P14A4@0BDU904a<C01@D500F5QH05aLG01KFe/0I6AT05mOG`1[Jf/0KFe]07Ad
M01gMgL207alO00=0820P01mOGd0OGem07inOP25QHD0QhN708B4Q029RHT0QhN708J6QP27QhL0TY:B
08f=S@0309>CT`0B09BDU02BTY80UIFE09^KV`2JVYX0Vi^K09jNWP2MWId0XZ:R0:ZZZP2WYjL0ZZZZ
0:VYZ@2XZ:P0YJFU0:BTY02RXZ80YZJV0`2YZJT01P2XZ:P0Y:BT0:FUY@2VYZH0Zj^[0:b/[080Z:RX
0P2/[:`06@2ZZZX0Y:BT09bLW02MWId0SXj>09BDU02GUiL0V9RH09BDU02;Rh/0K6a/03Lg=`0V9RH0
9bLW02l_;`0c<c<0Cdm?03lo?`0^;Rh0;Bd]02`/;00c<c<0<30`03<c<`0d=3@00P0`<300>00b<S80
>CTi03De=@0i>CT0?clo0451@@0n?Sh0?Cdm0410@00d=3@0;Bd]030`<00e=CD0Bd];03Lg=`0_;bl0
>CTi02h^;P0`<300=SHf03Lg=`1=CDd0HV9R07emO@1[Jf/0Cdm?04i>CP1;Bd/0BTY:075aL@1:BTX0
EUIF04m?C`10@400DE5A04m?C`1>CTh0CDe=05=CD`11@D40<c<c04U9B@1IFET0?Shn034a<@0g=cL0
;2`/03hn?P28R8P0ZJVY0:f][@2WYjL0WYjN09ZJVP2NWYh0XJ6Q0P2ATI404`2@T900UIFE09NGU`2H
V9P0WIfM0:>SX`2JVYX0XZ:R09^KV`2LW9`0VIVI09ZJVP2IVIT0Vi^K09:BTP2GUiL0W9bL09NGU`2J
VYX00P2HV9P01P2FUYH0Ti>C09JFUP2CTi<0U9BD09RHV080UIFE00<0U9BD09JFUP2GUiL00`2IVIT0
1P2DU9@0TI6A09FEU@2BTY80Ti>C096AT@80U9BD02P0Shn?08^;R`2>SXh0TY:B092@T02:RXX0SXj>
08f=S@2<S8`0Rh^;08N7Q`2:RXX0Rh^;08:2PP25QHD0OWin0820P01nOWh0Ng]k07AdM01cLg<0MGEe
0820P02JVYX0^;Rh0<[:bP3@d=00emOG0=_Kf`3MgMd0g]kN0=cLg03Jf]X0g=cL0=WIf@3Hf=P0eMGE
0=;BdP3EeMD0dm?C0`3De=@03`3Cdm<0e=CD0=?Cd`3EeMD0e]KF0=GEe@3Fe]H0emOG0=GEe@3GemL0
e]KF0=OGe`3Fe]H0emOG0=GEe@020=CDe0060=;BdP3De=@0d=3@0=;BdP3>c/h0clo?103=cLd20<k>
cP040<g=c@3?cll0c/k>0<c<c080clo?00L0c<c<0<g=c@3=cLd0cLg=0<W9b@37alL0b<S800h0b>3H
000<0<SPf080<30`0P0_;bl09P0/;2`0;Rh^02`/;00a<C40<30`038b<P0];Bd0;bl_03De=@0^;Rh0
<C4a02h^;P0c<c<0@D5105IFEP1JFUX0IFEU075aL@1/K6`0JVYZ06QXJ01UIFD0HF5Q06YZJP1eMGD0
Ogmo08N7Q`25QHD0Rh^;08f=S@2DU9@0VIVI09fMW@2WYjL0YJFU0:VYZ@2`/;00[jn_0P2^[Zh0702a
/K40[jn_0:f][@2b/[80/;2`0:j^[P2f][H0[jn_0;>c/`2d];@0]KFe0;>c/`2/[:`0ZZZZ0:RXZ02O
Wil0WYjN09NGU`2;Rh/0PX:207UiN@1^KVh0GEeM051@D019BDT0@T920410@015ADD205ADE00805YJ
FP1WIfL0M7Ad06YZJP1OGel0JFUY06m_K`1EEED203Lg=`0<04A4A01BDU80?Shn03Lg=`1:BTX0H61P
079bLP1MGEd0>3Ph02h^;P11@D40=cLg0P0e=CD202HV9P0M02h^;P10@400I6AT05ADE010@400;Bd]
02LW9`0`<300>SXj03Lg=`0o?cl0C4a<051@D01?Cdl0KVi^09^KV`1GEeL0KFe]06i^KP17AdL0=SHf
0451@@13@d<0ATI605eMG@1kNg/0Q8B407]kN`1^KVh00P25QHD0:027QhL0Ogmo07alO01hN7P0PH61
07MgM`1eMGD0Jf][05IFEP18B4P0DU9B07EeM@2RXZ80RHV906=SH`1PH600P82008f=S@2QXJ40KFe]
02h^;P0k>c/0H61P05]KF`1mOGd0O7al08J6QP34a<@0_[jn05EEE@0b<S80=SHf05]KF`11@D40<C4a
02`/;00b<S80=CDe03@d=00h>3P203De=@0303Xj>P0a<C40;Rh^0080>3Ph00H0<30`03Lg=`0g=cL0
H61P0451@@0n?Sh203/k>`0M03Lg=`0_;bl0:2PX02DU9@0a<C40=cLg03Ph>00m?Cd0<c<c038b<P0_
;bl0<30`03<c<`0o?cl0=CDe03<c<`0a<C40;Rh^030`<00e=CD0<c<c030`<00b<S80>c/k03De=@0k
>c/0?clo03Lg=`0l?3`00P0k>c/0B011@D40<c<c03<c<`0k>c/0=3@d038b<P13@d<0?Cdm03Xj>P0f
=SH0@d=30451@@10@400=cLg02h^;P0g=cL0ATI604m?C`1<C4`0@41003De=@0^;Rh0=3@d03Lg=`0j
>SX0A4A404E5A@1=CDd0EUIF05YJFP1QHF40GUiN05mOG`1TI6@0IfMW06][J`1`L700LW9b07EeM@1m
OGd0OWin0820P01lO7`0Q8B40820P026QXH0Ph>308J6QP24Q8@0Rh^;08b<S02:RXX0Shn?08b<S02B
TY80UIFE096AT@2CTi<0Shn?096AT@2HV9P0UiNG09JFUP2NWYh0XJ6Q0:BTY02XZ:P0YZJV0:NWY`2T
Y:@0Xj>S0:BTY080XZ:R00P0YJFU0:JVYP2YZJT0YjNW0:>SX`2VYZH0XJ6Q0::RXP80ZZZZ0P2UYJD0
1P2XZ:P0YZJV0:>SX`2VYZH0WIfM09jNWP80T92@00L0UYJF09^KV`2FUYH0TI6A08B4Q010@400:2PX
0080:b/[0180<S8b059BDP14A4@0;Bd]030`<00_;bl0<C4a03Xj>P0f=SH0=3@d030`<00];Bd0=CDe
03Xj>P0d=3@0?3`l04M7A`0i>CT203Xj>P0C0451@@0g=cL0:RXZ034a<@0f=SH0EUIF03dm?@0[:b/0
=3@d02l_;`0e=CD0>c/k03Lg=`1;Bd/0GEeM07UiN@1[Jf/0ATI605]KF`0204a<C00@06i^KP1>CTh0
EEEE04Y:BP12@T80CDe=04U9B@15ADD0BTY:04m?C`12@T80=CDe04i>CP1HF5P0?Cdm02l_;`80<C4a
00L0ATI608f=S@2VYZH0/;2`0:BTY02PX:00W9bL0080XJ6Q0P2<S8`02`2ATI40VYZJ09JFUP2EUID0
Vi^K09jNWP2OWil0WYjN09ZJVP2OWil0WYjN00<0W9bL00<0UYJF09>CT`2CTi<00P2HV9P0202FUYH0
V9RH09RHV02GUiL0UIFE09ZJVP2BTY80UYJF0P2EUID0102FUYH0VIVI09NGU`2DU9@409NGU`0609VI
V@2DU9@0U9BD09NGU`2BTY80U9BD0P2@T9009`2>SXh0S8b<08f=S@2:RXX0S8b<08V9R@2=SHd0RXZ:
08J6QP28R8P0PH6108N7Q`28R8P0Ph>307moO`22PX80O7al07QhN01cLg<0M7Ad07inOP2BTY80][Jf
0<G5a@3>c/h0e=CD0=[JfP3Kfm/0h>3P0=gMg@3Hf=P0g=cL0=[JfP3Hf=P0e]KF0=CDe03Cdm<0d];B
0=CDe0020=;BdP0=0=CDe03Cdm<0e]KF0=?Cd`3De=@0dm?C0=KFeP3GemL0e]KF0=SHf03EeMD0e]KF
0=SHf0020=KFeP0:0=GEe@3De=@0dm?C0=7Ad@3Cdm<0dM7A0=3@d03Bd]80clo?0=3@d0<0clo?00<0
c/k>0<o?c`3?cll00P3?cll20<k>cP070<g=c@3?cll0c/k>0<k>cP3<c<`0cLg=0<[:bP0>0<SPf000
3038h=P202d];@0802h^;P0b<S80;Rh^034a<@0`<300<c<c03De=@0_;bl3030`<00M034a<@0j>SX0
=3@d03Hf=P11@D40D51@05]KF`1WIfL0KFe]06][J`1ZJVX0JFUY061PH01WIfL0LG5a07QhN024Q8@0
Ph>308F5Q@2<S8`0SXj>09NGU`2IVIT0W9bL0:6QX@2SXj<0ZJVY0:j^[P2b/[800`2_[jl20:j^[P03
0;6a/@2`/;00/K6a0080/K6a04d0[jn_0;Bd]02b/[80/k>c0:j^[P2WYjL0Xj>S0::RXP2JVYX0UIFE
08^;R`22PX80MgMg06YZJP1QHF40EEEE04a<C012@T80@d=304a<C01>CTh0EUIF05UIF@1QHF40KVi^
06][J`1KFe/0Hf=S06a/K01NGUh0BTY:04E5A@17AdL0Bd];04e=C@18B4P0C4a<05]KF`1OGel0EUIF
0410@00d=3@0@D5103Xj>P0a<C40<S8b02LW9`0S8b<0;Bd]0492@P1TI6@0Fe]K04E5A@0b<S80<30`
03Hf=P0d=3@0=cLg03lo?`17AdL0BTY:04m?C`1hN7P0XJ6Q05]KF`1WIfL0KVi^05YJFP1<C4`0GEeM
06QXJ01bLW80PH6107alO01^KVh0N7Qh07UiN@0208Z:RP0b07MgM`1nOWh0PX:207moO`1fMWH0L71`
06][J`1LG5`0C4a<04Y:BP1=CDd0MWIf09RHV01nOWh0HF5Q06EUI@28R8P0QHF509BDU01/K6`0;Rh^
04A4A01^KVh0GUiN07=cL`25QHD0VYZJ0;^k^`33`l<0Fe]K02l_;`0^;Rh0?clo04=3@`0a<C40;Rh^
02/[:`0/;2`0;Rh^034a<@0_;bl0<30`03De=@0d=3@0<30`03De=@0^;Rh0<C4a02l_;`0e=CD204Q8
B0050410@00d=3@0=cLg03Hf=P0/;2`00P0[:b/02P0_;bl0=SHf03Ti>@0k>c/0=3@d02d];@0a<C40
=CDe030`<00k>c/2038b<P0=02d];@0c<c<0<c<c038b<P0c<c<0<C4a03Xj>P0i>CT0=cLg038b<P0i
>CT0=3@d03Hf=P0203/k>`090410@00h>3P0=CDe03Ph>00a<C40=CDe03lo?`0m?Cd0>3Ph00<0?3`l
0180>c/k03Lg=`0e=CD0@T9204M7A`1>CTh0C4a<03Xj>P0d=3@0<c<c03Ph>00n?Sh0ATI605EEE@1;
Bd/0DU9B05EEE@1QHF42069RHP0905iNGP1XJ6P0KFe]06e]K@1`L700M7Ad07IfMP1kNg/0PX:20080
QXJ600@0QhN708>3P`28R8P0PH610P25QHD02`2=SHd0RXZ:08V9R@2:RXX0S8b<08n?S`2BTY80T92@
08n?S`2;Rh/0Ti>C0080UIFE00L0Ti>C09fMW@2MWId0WinO0:BTY02SXj<0XJ6Q0080W9bL00d0WinO
0:2PX02QXJ40YjNW0:ZZZP2^[Zh0/K6a0:ZZZP2XZ:P0XJ6Q0:RXZ02YZJT0/;2`0080YJFU00H0YjNW
0:FUY@2SXj<0Xj>S0::RXP2MWId209FEU@0<09:BTP2JVYX0UiNG09:BTP2;Rh/0H61P03<c<`0a<C40
;2`/02d];@1<C4`0D51@0P0a<C403`0Y:BT0<30`02h^;P0^;Rh0<C4a03@d=00[:b/0=3@d03dm?@0e
=CD0?Cdm04E5A@0i>CT0<S8b03De=@020451@@0J02h^;P0_;bl0>3Ph04I6AP14A4@09bLW034a<@0]
;Bd0;bl_03Ti>@0h>3P0BTY:05mOG`1hN7P0JFUY04I6AP1>CTh0Cdm?04Y:BP1/K6`0DE5A05MGE`19
BDT0@41004M7A`13@d<204a<C00B05=CD`15ADD0<C4a051@D01?Cdl0?clo03<c<`0d=3@0<c<c04e=
C@2;Rh/0XJ6Q0:b/[02PX:00XJ6Q09RHV02UYJD0X:2P0P26QXH04@2?Shl0TI6A09JFUP2FUYH0VYZJ
0:2PX02QXJ40VYZJ09fMW@2OWil0W9bL09ZJVP2GUiL0W9bL09jNWP2EUID0V9RH0080VIVI0`2FUYH0
1`2DU9@0UYJF09JFUP2EUID0UYJF09:BTP2GUiL00P2JVYX01`2HV9P0UiNG09RHV02KVi/0UYJF09bL
W02JVYX00P2EUID02`2FUYH0TY:B09>CT`2@T900U9BD08j>SP2=SHd0Rh^;08f=S@2<S8`0Shn?0080
S8b<01<0QHF508V9R@28R8P0QXJ608N7Q`22PX80PH6107emO@21PH40N7Qh07=cL`1dM7@0NWYj09:B
TP2b/[80a<C40<o?c`3Fe]H0f][J0080g]kN00H0g=cL0=[JfP3Lg=`0fm_K0=SHf03GemL20=KFePD0
e=CD00H0d];B0=?Cd`3Cdm<0dm?C0=;BdP3De=@20=GEe@030=OGe`3Fe]H0f=SH0080emOG00<0eMGE
0=KFeP3EeMD00P3Cdm<0103De=@0dm?C0=CDe03?cll30=3@d080d];B0P3@d=000`3?cll0c/k>0<o?
c`020=3@d0070<g=c@3@d=00c/k>0<o?c`3<c<`0cLg=0<c<c00>0<SPf0003038h=P202d];@80<C4a
00T0<S8b02h^;P0];Bd0=CDe03Xj>P0c<c<0>3Ph02l_;`0a<C400P0c<c<06`0`<300=SHf03`l?01>
CTh0FUYJ06IVIP1TI6@0J6QX06IVIP1TI6@0GUiN06EUI@1bLW80NWYj08:2PP24Q8@0QHF508b<S02=
SHd0V9RH09ZJVP2LW9`0X:2P0:JVYP2/[:`0[jn_0;6a/@020:n_[`060:f][@2a/K40[Zj^0:n_[`2c
/k<0/[:b0P2a/K420;>c/`0R0;Fe]@2d];@0[Jf]0:RXZ02WYjL0YZJV09VIV@2EUID0SXj>08B4Q01i
NGT0L71`05iNGP1EEED0C4a<0492@P0n?Sh0AdM704e=C@1DE5@0GEeM06QXJ01^KVh0K6a/06EUI@1S
Hf<0K6a/06ATI018B4P0BDU904m?C`15ADD0F5QH05eMG@80GemO00l0H61P05IFEP0k>c/0=CDe03hn
?P0d=3@0;Rh^02TY:@0W9bL0:2PX02l_;`19BDT0I6AT05]KF`11@D400P0[:b/00`0^;Rh0=3@d03`l
?0020451@@0A03dm?@11@D40P8200:ZZZP1PH600GemO06ATI01DE5@0IVIV06m_K`1jNWX0NGUi071`
L01ZJVX0Kfm_08n?S`2;Rh/00P1nOWh07P1]KFd0NGUi07inOP1^KVh0JVYZ06e]K@1NGUh0CTi>04Y:
BP1=CDd0DU9B08V9R@2@T900OWin071`L01XJ6P0QhN707inOP29RHT0IVIV03De=@1@D500OWin06MW
I`1]KFd0Ng]k08n?S`2j^[X0alO707YjNP80=3@d00@0<S8b03dm?@0d=3@0<30`0P0c<c<0800d=3@0
>CTi03@d=00b<S80;Bd]038b<P0c<c<0;Rh^03Hf=P0];Bd0:RXZ03Lg=`0l?3`0@T9203Lg=`0e=CD0
@T9203Hf=P0`<300;bl_02XZ:P0a<C40=cLg03`l?00o?cl0;Rh^030`<00c<c<0<30`03Ph>00n?Sh0
<30`0P0/;2`02@0b<S80<C4a034a<@0`<300>3Ph03Lg=`0i>CT0>3Ph03Lg=`0203Xj>P0L04E5A@0l
?3`0?3`l03Lg=`0c<c<0<30`034a<@0_;bl0>CTi03dm?@0o?cl0=SHf0451@@0i>CT0ADE503Lg=`0b
<S80<30`03Xj>P17AdL0Cdm?04E5A@0i>CT0<c<c03Lg=`12@T80ATI604m?C`80FEUI00H0G5aL05iN
GP1RHV80IFEU06MWI`1ZJVX206a/K080Lg=c00P0Ogmo07alO021PH40PX:208N7Q`23Ph<0PH6108:2
PP80QXJ600X0QhN708Z:RP28R8P0SHf=08Z:RP2<S8`0SHf=08b<S02BTY80Shn?0P2<S8`06@2ATI40
UIFE09:BTP2CTi<0VIVI09^KV`2MWId0WinO09jNWP2JVYX0WYjN09bLW02NWYh0WinO0:FUY@2XZ:P0
YjNW0:ZZZP2YZJT0ZZZZ0:f][@2WYjL0[:b/0:VYZ@2UYJD00P2PX:020:BTY00]0:RXZ02SXj<0WinO
09nOW`2HV9P0UYJF09NGU`2FUYH0VIVI09:BTP2=SHd0LG5a02h^;P0V9RH0:RXZ02TY:@0n?Sh0CDe=
03@d=00];Bd0:BTY030`<00Y:BT0;Bd]03@d=00/;2`0;bl_034a<@0l?3`0=cLg03/k>`10@400>c/k
03`l?00n?Sh0?Cdm03/k>`0a<C40<30`03/k>`11@D40AdM703hn?P0^;Rh0;Bd]0080<c<c02@0;bl_
04E5A@1LG5`0LG5a06EUI@15ADD0D51@059BDP1>CTh0JFUY05ADE01IFET0CDe=0410@015ADD0A4A4
04a<C01;Bd/0Fe]K04e=C@0c<c<0CDe=0492@P0o?cl0=cLg03`l?00^;Rh0DU9B08Z:RP2WYjL0[:b/
0:6QX@2SXj<0UiNG0:BTY02SXj<208n?S`0608f=S@2CTi<0VIVI09RHV02IVIT0XZ:R0P2OWil0102M
WId0WinO09fMW@2FUYH309bLW00609VIV@2JVYX0WIfM09bLW02MWId0V9RH0P2IVIT209RHV00E09^K
V`2HV9P0VIVI09JFUP2HV9P0Vi^K09VIV@2EUID0UYJF09NGU`2BTY80UIFE09NGU`2HV9P0Ti>C09VI
V@2FUYH0U9BD09:BTP2@T900SXj>0080SHf=00P0TI6A08f=S@2;Rh/0Rh^;08j>SP2=SHd0Rh^;08B4
Q080RXZ:00l0PX:207moO`1nOWh0NGUi07YjNP1gMgL0LG5a07YjNP2:RXX0ZZZZ0<30`03>c/h0dm?C
0=SHf03Jf]X00P3Kfm/02@3Jf]X0g=cL0=_Kf`3Jf]X0fMWI0=KFeP3GemL0e]KF0=WIf@020=?Cd`80
e=CD00D0eMGE0=CDe03Cdm<0d];B0=?Cd`030=GEe@050=KFeP3Hf=P0eMGE0=GEe@3Fe]H00P3EeMD3
0=CDe00=0=GEe@3Cdm<0d];B0=;BdP3Cdm<0d];B0=3@d03Bd]80dM7A0<k>cP3AdM40clo?0<g=c@02
0=3@d0070<o?c`3>c/h0c/k>0=;BdP3<c<`0bl_;0<c<c00>0<SPf0003038h=P3030`<00703@d=00/
;2`0<30`02h^;P0a<C40<c<c034a<@0303@d=00:03De=@0c<c<0<C4a03@d=013@d<0DU9B065QH@1U
IFD0IVIV06QXJ080IfMW00@0HF5Q06MWI`1^KVh0NGUi0P22PX802P2:RXX0S8b<092@T02DU9@0UiNG
09bLW02OWil0Z:RX0:ZZZP2/[:`30;2`/0030;:b/P2d];@0/K6a0080/;2`02h0[Zj^0;:b/P2b/[80
]KFe0;>c/`2d];@0[jn_0:f][@2YZJT0Y:BT0:6QX@2HV9P0UIFE08^;R`29RHT0NWYj06][J`1QHF40
F5QH04a<C015ADD0@41004=3@`1;Bd/0D51@05eMG@1_Kfl0N7Qh079bLP1XJ6P0IfMW06UYJ@1FEUH0
ATI60451@@1>CTh0A4A404i>CP1TI6@0HF5Q05UIF@1HF5P0Hf=S03hn?P0l?3`0=3@d0P0];Bd03P0Z
:RX0:2PX02`/;00];Bd0ADE506=SH`1QHF40ATI603<c<`0Y:BT0<30`03dm?@10@400?Shn0P0g=cL0
2@11@D40RXZ:0:NWY`1XJ6P0I6AT06QXJ01FEUH0LW9b07QhN002075aL@05065QH@1YJFT0QHF509VI
V@24Q8@00P1eMGD05`1`L700NGUi06a/K01SHf<0IFEU05]KF`1GEeL0D51@04U9B@1<C4`0EUIF08^;
R`1nOWh0PH6107=cL`1`L700P8200861P@25QHD0IfMW03`l?01EEED0OGem0080Hf=S00`0O7al0:NW
Y`35aLD0clo?0:2PX018B4P0=cLg03<c<`0i>CT0<S8b03@d=00^;Rh203<c<`0V03@d=00f=SH0=SHf
03Lg=`0j>SX0<S8b03De=@0f=SH0=3@d03Xj>P0`<300=cLg03lo?`0f=SH0=cLg0451@@0i>CT0=3@d
03De=@0Y:BT0<30`03Hf=P0g=cL0?Shn02l_;`0f=SH0<C4a03Hf=P0i>CT0>3Ph02l_;`0/;2`0;Rh^
030`<00^;Rh0<C4a03Lg=`0m?Cd203Ti>@0503De=@0h>3P0>3Ph04A4A013@d<00P0k>c/01P0g=cL0
<C4a034a<@0`<300=cLg03Xj>P80@T920P0k>c/05@11@D40ATI603Hf=P0b<S80<c<c03dm?@19BDT0
CTi>04=3@`0m?Cd0?3`l0451@@1:BTX0DE5A05MGE`1IFET0FUYJ05iNGP1RHV80IVIV06][J`0206YZ
JP80LW9b0100MWIf07YjNP1jNWX0OWin08F5Q@1oOgl0QHF508:2PP24Q8@0QhN708B4Q029RHT0RXZ:
08b<S028R8P0RXZ:0P29RHT0202=SHd0RXZ:08j>SP2?Shl0SXj>08n?S`2@T900TY:B0P2DU9@03`2H
V9P0W9bL09fMW@2LW9`0VYZJ09JFUP2EUID0UiNG09RHV02NWYh0ZJVY0:BTY02UYJD0YZJV0:ZZZP02
0:b/[0040:j^[P2[Zj/0[Zj^0::RXP80WYjN01h0XZ:R09jNWP2LW9`0XZ:R09^KV`2JVYX0V9RH09FE
U@2CTi<0TY:B09NGU`2EUID0TI6A08B4Q013@d<09BDU02HV9P0];Bd0=cLg04U9B@0e=CD0;Rh^02/[
:`0a<C40:b/[02l_;`0c<c<0<S8b034a<@0_;bl203Hf=P80>SXj03<0AdM703dm?@0k>c/0@41004];
B`0d=3@0<S8b03@d=00c<c<0?clo030`<00g=cL0<C4a03Hf=P0e=CD0<C4a03lo?`1QHF40Lg=c065Q
H@19BDT0Cdm?051@D01=CDd0JFUY04i>CP1EEED0CTi>04Q8B014A4@0ATI6051@D01<C4`0FEUI04e=
C@0n?Sh0Bd];03Xj>P0k>c/0>SXj03Lg=`0];Bd0BDU908b<S02YZJT0[jn_0:BTY02PX:00UiNG0:FU
Y@2RXZ800P2ATI400`29RHT0Vi^K09^KV`0209NGU`040:6QX@2NWYh0X:2P09ZJVP80WIfM00L0VIVI
09ZJVP2LW9`0WYjN09^KV`2IVIT0UYJF0080W9bL00P0VYZJ09NGU`2FUYH0UiNG09VIV@2KVi/0U9BD
09NGU`<0UYJF00l0VIVI09ZJVP2HV9P0VIVI09>CT`2ATI40U9BD09>CT`2HV9P0UiNG09JFUP2DU9@0
Shn?096AT@2EUID00P2@T9000`2?Shl0T92@08N7Q`0208j>SP0C08^;R`2<S8`0Rh^;08Z:RP29RHT0
P82008:2PP1nOWh0Ng]k07UiN@1fMWH0L71`07IfMP28R8P0YjNW0;jn_P37alL0d];B0=SHf0020=_K
f`050=[JfP3GemL0fMWI0=[JfP3Kfm/00P3Hf=P00`3Fe]H0eMGE0=CDe0050=GEe@080=?Cd`3De=@0
d];B0=CDe03EeMD0e=CD0=GEe@3Fe]H40=CDe0040=?Cd`3Fe]H0e=CD0=CDe080eMGE00L0e=CD0=KF
eP3Cdm<0d];B0=?Cd`3AdM40c/k>0080clo?0P3@d=001@3>c/h0clo?0=3@d03=cLd0d=3@0080clo?
00<0c<c<0<k>cP3=cLd03P38h=P000`0b>3H0P0a<C404P0b<S80;Rh^02d];@0d=3@0<c<c03Lg=`0e
=CD0<30`03<c<`0a<C40;bl_030`<00c<c<0<S8b03De=@10@400D51@05mOG`<0IVIV0100Hf=S06MW
I`1SHf<0J6QX06][J`1iNGT0PX:207moO`26QXH0S8b<09:BTP2>SXh0U9BD09^KV`2SXj<0YjNW0`2]
[Jd20:n_[`060;2`/02b/[80/K6a0;2`/02^[Zh0/K6a0P2c/k<0202a/K40]KFe0;>c/`2_[jl0[:b/
0:FUY@2WYjL0XZ:R0P2GUiL0?02?Shl0Ph>307UiN@1^KVh0I6AT05UIF@1>CTh0B4Q804I6AP13@d<0
CDe=05ADE01VIVH0N7Qh0820P01iNGT0KFe]06UYJ@1_Kfl0FUYJ04e=C@1>CTh0ATI60492@P1:BTX0
GUiN06YZJP1HF5P0Cdm?05iNGP0n?Sh0=CDe03Hf=P0d=3@0:RXZ02TY:@0V9RH0:BTY02XZ:P10@400
F5QH05aLG017AdL0:b/[02h^;P0b<S80A4A403hn?P0h>3P0<S8b03<c<`17AdL0RXZ:0:FUY@1/K6`0
KFe]07EeM@1SHf<0M7Ad06IVIP80N7Qh00D0G5aL07EeM@2JVYX0TY:B08:2PP0206YZJP0?071`L01i
NGT0JFUY06IVIP1OGel0CTi>04m?C`1HF5P0E5AD05IFEP1QHF40Q8B407YjNP23Ph<0H61P0080Hf=S
01D0M7Ad08J6QP1YJFT0<c<c06MWI`23Ph<0HV9R07IfMP2UYJD0clo?0=[JfP3?cll0dM7A0:6QX@1B
DU80=CDe034a<@0c<c<0;Rh^034a<@0c<c<00`0e=CD02P0k>c/0?Cdm03dm?@0b<S80=SHf030`<00/
;2`0=CDe03@d=00i>CT203/k>`0F03Ti>@0m?Cd0=SHf034a<@0^;Rh0:RXZ030`<00c<c<0?clo03Ph
>00b<S80=CDe03Hf=P0g=cL0?Cdm03@d=00`<300<c<c034a<@0^;Rh0;Bd]038b<P80>c/k00L0>3Ph
03Hf=P0d=3@0@41003Ti>@0o?cl0B4Q80080>SXj00l0=SHf03@d=00`<300<30`038b<P0k>c/0?clo
03dm?@0l?3`0>c/k04Y:BP18B4P0>3Ph03<c<`0b<S800P13@d<02`17AdL0?3`l04A4A015ADD0DU9B
05IFEP1CDe<0GUiN06ATI01RHV80Hf=S0080JFUY0100KFe]06a/K01aLG40Kfm_071`L01hN7P0Ng]k
07moO`1mOGd0P82007moO`24Q8@0PX:208N7Q`29RHT0Q8B40P29RHT01`27QhL0RXZ:08^;R`2:RXX0
S8b<08^;R`2=SHd00`2>SXh0202;Rh/0T92@08^;R`2BTY80TI6A09:BTP2GUiL0VYZJ0P2EUID0202@
T900V9RH09:BTP2IVIT0VYZJ09nOW`2QXJ40[Jf]0P2UYJD0102WYjL0Zj^[0:ZZZP2ZZZX40:6QX@0F
0:2PX02KVi/0VIVI09nOW`2JVYX0VIVI09ZJVP2HV9P0Ti>C096AT@2BTY80UYJF096AT@2<S8`0IFEU
02/[:`0W9bL0:2PX03<c<`17AdL0=cLg03@d=080;2`/00D0;Rh^02d];@0];Bd0<C4a02l_;`0202d]
;@0P038b<P0l?3`0=cLg03dm?@13@d<0=3@d0451@@18B4P0>c/k03Ti>@0`<300<S8b03Ph>00b<S80
;bl_02h^;P0f=SH0;Rh^02l_;`10@400HF5Q07UiN@1QHF40ATI604U9B@1@D500BDU906IVIP1<C4`0
BTY:04];B`1:BTX204A4A00D04e=C@14A4@0EeMG05IFEP12@T80AdM703Ph>00d=3@0>c/k03lo?`0b
<S80Bd];08>3P`2PX:00/K6a0:BTY02VYZH0UiNG0:JVYP2SXj<209JFUP0908N7Q`2CTi<0VYZJ09fM
W@2JVYX0X:2P09fMW@2OWil0WIfM00<0W9bL00@0WIfM09jNWP2KVi/0Vi^K0P2IVIT209fMW@80VIVI
00d0UYJF09NGU`2GUiL0VIVI09JFUP2DU9@0VIVI09RHV02IVIT0VYZJ09^KV`2IVIT0Vi^K0080UYJF
00H0U9BD09RHV02HV9P0UIFE09>CT`2BTY8208n?S`80T92@0P2<S8`06@2?Shl0SXj>08b<S02>SXh0
RXZ:08f=S@2:RXX0QhN708J6QP21PH40P82007emO@1hN7P0MGEe07UiN@1fMWH0LW9b08R8R02SXj<0
^;Rh0<S8b03?cll0emOG0=_Kf`3MgMd00P3Kfm/40=[JfP<0e]KF00@0eMGE0=OGe`3GemL0eMGE0`3F
e]H40=?Cd`80e=CD0P3Cdm<01@3De=@0dm?C0=OGe`3Bd]80dm?C00<0e=CD00<0e]KF0=CDe03Fe]H0
0P3De=@01@3Cdm<0dM7A0=;BdP3Bd]80clo?00<0dM7A0P3@d=000`3?cll0c/k>0<o?c`020<g=c@03
0=7Ad@3@d=00b>3H00d0b>3H000<0<SPf080=3@d00P0<30`03Lg=`0c<c<0=cLg034a<@0b<S80<30`
034a<@80;bl_01h0;Rh^02TY:@0];Bd0;bl_038b<P0g=cL0CTi>05YJFP1VIVH0JFUY06MWI`1YJFT0
IFEU06ATI01WIfL0JVYZ07alO01mOGd0Ph>308V9R@2<S8`0TI6A092@T02HV9P0VIVI0::RXP2VYZH0
[:b/0;2`/02/[:`20;6a/@040;:b/P2`/;00/K6a0;2`/0<0/[:b02d0/K6a0;>c/`2h^;P0/k>c0;:b
/P2^[Zh0ZJVY0:FUY@2PX:00W9bL09FEU@2<S8`0QHF507inOP1aLG40H61P05EEE@1:BTX0?Shn0492
@P18B4P0ATI605IFEP1`L700PH6107moO`1bLW80JFUY075aL@1RHV80FUYJ05mOG`1FEUH0AdM70451
@@14A4@0EeMG05YJFP1>CTh0A4A406ATI013@d<0=CDe03lo?`0j>SX00P0^;Rh302TY:@0L03hn?P1J
FUX0FUYJ04a<C00_;bl0<C4a03hn?P16ATH0?Cdm03Ph>00/;2`0<c<c04i>CP2DU9@0/k>c08:2PP1j
NWX0Ogmo05eMG@1QHF40MWIf08J6QP1ZJVX0FUYJ096AT@2RXZ80R8R807]kN`80KFe]02P0Kfm_07Ad
M01cLg<0LG5a05YJFP18B4P0CDe=06=SH`1JFUX0GEeM071`L01fMWH0TI6A08>3P`1FEUH0D51@04Q8
B01ZJVX0Q8B4075aL@19BDT0MWIf08:2PP1eMGD0RXZ:0<;2`P3Jf]X0h>3P0<S8b03;bl/0d=3@09^K
V`19BDT0>3Ph03Hf=P0b<S80;Rh^034a<@0_;bl0=CDe0P0d=3@00`0f=SH0;Bd]038b<P02030`<005
038b<P0f=SH0=CDe03Lg=`0n?Sh00P0j>SX04P10@400>3Ph03Ti>@0];Bd09RHV02h^;P0`<300>3Ph
03Ti>@0b<S80;bl_03Hf=P0h>3P0>c/k038b<P0];Bd0<30`03Lg=`80<c<c00X0?Cdm03hn?P0k>c/0
>c/k03Hf=P0k>c/0?Shn03Xj>P14A4@0?clo0P10@4006P0j>SX0;2`/02d];@0b<S80=cLg03`l?00o
?cl0=cLg03dm?@0l?3`0CDe=03hn?P0j>SX0=CDe03Ti>@17AdL0ATI604A4A00l?3`0C4a<05EEE@1K
Fe/0EeMG05UIF@1NGUh0I6AT0P1XJ6P00`1WIfL0JVYZ06e]K@0206i^KP06071`L01cLg<0Ng]k07em
O@20P800OWin0P1lO7`03`24Q8@0PX:208B4Q028R8P0QHF508Z:RP28R8P0RXZ:08N7Q`2<S8`0RXZ:
08b<S02;Rh/0R8R8092@T00208f=S@0B08Z:RP2;Rh/0SXj>096AT@2>SXh0Shn?096AT@2EUID0TY:B
08n?S`2CTi<0TI6A09FEU@2GUiL0VIVI09jNWP2OWil0Y:BT0P2UYJD01P2YZJT0ZZZZ0:NWY`2TY:@0
X:2P09jNWP80X:2P00@0WIfM09^KV`2MWId0WinO0P2KVi/00`2GUiL0V9RH09:BTP0209>CT`0N09BD
U02ATI40Rh^;07moO`0k>c/0;2`/02/[:`0c<c<0CTi>04A4A00_;bl0;Bd]02h^;P0[:b/0<C4a02`/
;00^;Rh0<c<c038b<P0a<C40=CDe038b<P0a<C40=SHf04a<C00f=SH0>3Ph03Xj>P0o?cl0@D510P0a
<C40:P0o?cl0>3Ph02XZ:P0c<c<0=SHf02XZ:P0b<S80>c/k05QHF01gMgL0H61P04A4A01<C4`0D51@
04Q8B01RHV80DE5A04e=C@1;Bd/0CTi>04U9B@17AdL0Bd];05ADE01CDe<0Cdm?04I6AP11@D40<30`
034a<@10@400?3`l02h^;P1ADE40RHV90::RXP2][Jd0ZJVY0:>SX`2FUYH0YJFU0::RXP80UYJF00<0
RHV908n?S`2IVIT00P2JVYX0102IVIT0X:2P09fMW@2KVi/309jNWP0409bLW02MWId0VIVI09^KV`80
UYJF00P0WYjN09ZJVP2JVYX0UYJF09VIV@2EUID0UiNG09JFUP80U9BD00D0V9RH09VIV@2IVIT0Ti>C
09fMW@0309VIV@0709BDU02FUYH0UiNG09BDU02CTi<0UIFE09^KV`0208n?S`0@09:BTP2ATI40SHf=
09>CT`2@T900Shn?08j>SP2<S8`0Q8B408f=S@27QhL0RHV908N7Q`20P800OWin07alO080NWYj00X0
M7Ad07MgM`1dM7@0P8200::RXP2h^;P0b<S80=3@d03EeMD0f=SH103Kfm/01@3Ng]h0f][J0=WIf@3G
emL0f=SH0080e]KF0P3GemL0103IfMT0f=SH0=KFeP3Fe]H20=GEe@080=?Cd`3De=@0e=CD0=GEe@3J
f]X0dm?C0=CDe03Cdm<20=CDe0030=;BdP3De=@0e=CD0080e=CD00d0e]KF0=CDe03De=@0eMGE0=CD
e03AdM40dm?C0=7Ad@3EeMD0dm?C0=7Ad@3Bd]80dM7A0080d=3@00H0dM7A0=3@d03?cll0clo?0=3@
d03?cll>0<SPf0003038h=P203De=@0903@d=00b<S80;bl_038b<P0g=cL0<C4a02l_;`0a<C40<c<c
0080<30`0P0a<C406@0`<300:b/[03<c<`17AdL0EeMG06ATI01YJFT0K6a/06QXJ01UIFD0HF5Q06QX
J01^KVh0LW9b0861P@26QXH0QhN708R8R02BTY80T92@09NGU`2KVi/0XJ6Q0:>SX`2/[:`00P2][Jd2
0:j^[P0:0;6a/@2c/k<0[Zj^0;Bd]02^[Zh0/[:b0;6a/@2b/[80][Jf0;6a/@80];Bd0P2[Zj/0902V
YZH0Xj>S0::RXP2GUiL0T92@08N7Q`1iNGT0KVi^05iNGP1?Cdl0AdM70410@01:BTX0A4A404];B`1J
FUX0N7Qh08j>SP23Ph<0KFe]05aLG01TI6@0HF5Q05UIF@1PH600FEUI04Y:BP12@T80>c/k04M7A`1@
D500BTY:04e=C@1TI6@0EeMG02d];@80=cLg0P0];Bd07`0^;Rh09bLW02XZ:P0e=CD0EUIF069RHP1:
BTX0=3@d03Lg=`11@D40BDU903De=@0i>CT0@d=30492@P1YJFT0WIfM0;bl_027QhL0PH6108V9R@1N
GUh0MWIf08^;R`1eMGD0DU9B06][J`2QXJ40VYZJ08B4Q01oOgl00P1WIfL0901]KFd0IVIV07inOP22
PX80K6a/0492@P17AdL0EeMG05IFEP1lO7`0Ph>307EeM@2CTi<0NWYj0451@@0g=cL0>3Ph05iNGP25
QHD0OGem06IVIP1bLW80S8b<07alO022PX80[Jf]0=KFeP3Lg=`0cLg=0;Jf]P3Fe]H0`/;207inOP1@
D500>3Ph02`/;080:BTY01T0;Bd]02h^;P0d=3@0>SXj03Lg=`0`<300<C4a03De=@0`<300;2`/02h^
;P0`<300?Shn03Ti>@0e=CD0;bl_03/k>`0i>CT0<C4a038b<P0V9RH0<S8b03<c<`12@T80<c<c0080
;bl_01<0<c<c038b<P0g=cL0<S8b034a<@0b<S80<30`03@d=00h>3P0>SXj03`l?00n?Sh0>CTi03`l
?00g=cL0?3`l03/k>`12@T80>c/k0080?clo01X0>3Ph02l_;`0/;2`0=SHf03De=@0n?Sh0?clo03Ti
>@13@d<0@T9204];B`0n?Sh0>SXj03@d=00k>c/0A4A404Y:BP17AdL0ATI604i>CP1DE5@0FUYJ05aL
G01HF5P0HF5Q06YZJP80IfMW00l0K6a/06e]K@1aLG40Kfm_07AdM01cLg<0MgMg07emO@1kNg/0PH61
0820P01iNGT0PX:208B4Q029RHT00P27QhL00`24Q8@0Rh^;08j>SP0208N7Q`0;08R8R026QXH0S8b<
08Z:RP2;Rh/0SHf=08V9R@2:RXX0T92@08f=S@2;Rh/00P2:RXX05@28R8P0SHf=08n?S`2?Shl0SXj>
08f=S@2?Shl0U9BD09VIV@2HV9P0UiNG09RHV02JVYX0XJ6Q09nOW`2QXJ40YZJV0:6QX@2RXZ80WinO
09bLW00209fMW@0909bLW02NWYh0WIfM09fMW@2NWYh0W9bL09RHV02EUID0Ti>C0080T92@00h0TI6A
08j>SP2<S8`0R8R805QHF00a<C40;2`/03<c<`1DE5@0A4A403@d=00b<S808R8R02PX:080:b/[00D0
<30`03@d=00^;Rh0;bl_03<c<`0203Hf=P07034a<@13@d<0>CTi03Lg=`0i>CT0?Shn0410@002038b
<P0E03De=@0g=cL0:b/[03@d=00m?Cd0:b/[034a<@0k>c/0DU9B07AdM01QHF40ADE504a<C013@d<0
@T9205mOG`1HF5P0E5AD04a<C01=CDd0@T920080ATI60140@T92051@D01EEED0CDe=03Ti>@0d=3@0
<30`03/k>`0h>3P0:2PX059BDP29RHT0Xj>S0:b/[02WYjL0XZ:R09JFUP020:6QX@80UiNG00/0SHf=
08j>SP2HV9P0W9bL09fMW@2IVIT0Vi^K09jNWP2JVYX0Vi^K09jNWP0209fMW@0F09bLW02MWId0VIVI
09ZJVP2EUID0UiNG09bLW02JVYX0V9RH09VIV@2JVYX0W9bL09RHV02DU9@0VIVI09FEU@2JVYX0UiNG
09VIV@2JVYX0V9RH09ZJVP80Ti>C00X0UiNG09JFUP2FUYH0TI6A09>CT`2GUiL0UIFE09:BTP2?Shl0
UIFE0P2ATI40202@T900S8b<08j>SP2?Shl0TI6A08V9R@2>SXh0Ph>30P24Q8@01@1oOgl0O7al07in
OP1lO7`0Lg=c0080MWIf00L0Ogmo09jNWP2h^;P0a<C40<k>cP3De=@0emOG0080fm_K00@0f][J0=_K
f`3Jf]X0fMWI0`3Hf=P01`3GemL0f=SH0=GEe@3EeMD0emOG0=WIf@3GemL00`3Fe]H00`3EeMD0e]KF
0=[JfP030=CDe0040=?Cd`3De=@0dM7A0=;BdP<0dM7A00D0d];B0=CDe03Fe]H0e=CD0=?Cd`030=CD
e0040=?Cd`3Bd]80dm?C0=?Cd`@0d];B00@0dm?C0=;BdP3Bd]80dm?C0`3AdM4>0<SPf0003038h=P2
03hn?P0S03<c<`0_;bl0=SHf03De=@0b<S80=CDe034a<@0d=3@0<S8b030`<00e=CD0=3@d030`<00c
<c<0;Rh^03De=@10@400E5AD06IVIP1RHV80JFUY069RHP1YJFT0GemO06MWI`1]KFd0MWIf07emO@23
Ph<0QhN708j>SP2?Shl0Ti>C09NGU`2LW9`00P2SXj<00`2[Zj/0[Zj^0;6a/@020;:b/P030:n_[`2d
];@0/[:b0080/[:b0500/K6a0;:b/P2c/k<0]KFe0;Ng]`2e]KD0/[:b0;2`/02/[:`0YjNW0:BTY02J
VYX0U9BD092@T022PX80OWin06m_K`1JFUX0EUIF04M7A`0m?Cd0@d=30410@01:BTX0HV9R08F5Q@2F
UYH0NGUi06EUI@1GEeL0HF5Q06=SH`1GEeL0F5QH05EEE@1=CDd0BDU903Xj>P0k>c/0@d=304A4A01:
BTX0LW9b06IVIP0f=SH0>c/k038b<P0e=CD0<S8b02/[:`0S8b<0:RXZ03Lg=`1ADE40H61P05=CD`0g
=cL0=3@d04=3@`15ADD0=SHf02l_;`0a<C40@D5107inOP2RXZ80^KVi08J6QP21PH40Rh^;07MgM`2A
TI40LW9b04a<C018B4P0RHV909bLW027QhL0QHF507YjNP80Jf][02<0JFUY065QH@1fMWH0QXJ60820
P01LG5`0D51@05ADE01ADE40PH6107inOP1eMGD0RXZ:079bLP17AdL0=cLg03`l?01`L700RHV908F5
Q@1`L700JFUY08^;R`1hN7P0NWYj09JFUP39bLT0f=SH0<?3``34a<@0^k^k0=GEe@2k^k/0Ng]k03Lg
=`02038b<P0A02l_;`0d=3@0<30`030`<00e=CD0;2`/02h^;P0b<S80;Bd]038b<P0^;Rh0<30`03Ph
>00j>SX0>3Ph03@d=00a<C400P0k>c/0200d=3@0<30`02/[:`0`<300<C4a03`l?00k>c/0=3@d0P0c
<c<02@0f=SH0<C4a03@d=00h>3P0<S8b03@d=00j>SX0>CTi03De=@0303Ti>@0603<c<`0i>CT0>c/k
03Xj>P10@400?Cdm0P0o?cl0300m?Cd0;2`/02l_;`0a<C40?Cdm0410@00l?3`0>CTi04a<C014A4@0
AdM703Ti>@80=cLg00@0?Cdm04Q8B019BDT0ADE50P1CDe<01@1IFET0EeMG05]KF`1JFUX0IVIV0080
IFEU00H0IVIV06UYJ@1_Kfl0LG5a06m_K`1cLg<207QhN00D07]kN`1nOWh0PX:20861P@1lO7`0Ogmo
08>3P`27QhL0Ph>30861P@22PX80RHV908N7Q`2;Rh/0RHV908N7Q`2;Rh/0S8b<08Z:RP2;Rh/208V9
R@0408R8R029RHT0RXZ:08^;R`80QhN70P28R8P04`2;Rh/0QXJ608R8R028R8P0S8b<09BDU02ATI40
UIFE09BDU02FUYH0U9BD09NGU`2LW9`0VIVI0:2PX02LW9`0Vi^K09VIV@2KVi/00P2OWil0602GUiL0
VYZJ09fMW@2NWYh0UiNG09VIV@2LW9`0U9BD09FEU@2>SXh0RHV908n?S`2CTi<0SHf=08N7Q`1jNWX0
?clo02PX:00];Bd0CDe=04A4A00`<300?Shn034a<@80:RXZ0140:b/[02LW9`0a<C40<c<c02d];@0d
=3@0>SXj03@d=00c<c<0?Cdm03Hf=P0g=cL0>3Ph03dm?@0g=cL0<C4a03@d=00203Ph>00?030`<00c
<c<0=cLg02`/;00[:b/0>SXj04m?C`1cLg<0GUiN04M7A`1CDe<0D51@04Y:BP1NGUh0FEUI0080B4Q8
01L0AdM70492@P12@T80@T9204A4A01>CTh0EeMG04m?C`0d=3@0<S8b03<c<`0i>CT0=SHf02h^;P1I
FET0QHF50::RXP2YZJT0WYjN09bLW02BTY80XZ:R09bLW00209NGU`80T92@00<0Ti>C0:2PX02KVi/0
0P2HV9P0102LW9`0VYZJ09nOW`2LW9`209^KV`0709ZJVP2IVIT0UiNG09^KV`2HV9P0VYZJ09^KV`02
09ZJVP0G09RHV02KVi/0VIVI09FEU@2KVi/0WIfM09FEU@2IVIT0UiNG09RHV02FUYH0UiNG09RHV02F
UYH0TI6A09FEU@2DU9@0UiNG09>CT`2DU9@0UiNG09:BTP2DU9@00P2@T9001P2EUID0TI6A08^;R`2=
SHd0Shn?092@T0<0Rh^;00l0R8R808F5Q@25QHD0P82007inOP1lO7`0N7Qh07YjNP1cLg<0MGEe08:2
PP2MWId0]KFe0<K6aP3=cLd00P3IfMT00`3Jf]X0fm_K0=cLg0030=[JfP050=WIf@3EeMD0eMGE0=KF
eP3GemL00P3EeMD30=WIf@030=OGe`3Fe]H0e]KF0080f=SH00<0fMWI0=GEe@3Bd]800P3De=@00`3B
d]80dM7A0=3@d0020=;BdP040=3@d03?cll0dM7A0=;BdP80dm?C00L0e=CD0=?Cd`3Bd]80d=3@0=?C
d`3De=@0dM7A0080d];B00T0dm?C0=;BdP3Cdm<0e=CD0=?Cd`3De=@0dM7A0=?Cd`3AdM403P38h=P0
00`0b>3H0P0];Bd02`0_;bl0<C4a038b<P0f=SH0=CDe03<c<`0d=3@0<S8b03De=@0d=3@0<c<c0080
<C4a00H0<S8b02h^;P0a<C40?Cdm05EEE@1^KVh206=SH`0C06EUI@1QHF40GemO06ATI01/K6`0Lg=c
07YjNP21PH40R8R808Z:RP2BTY80UIFE09RHV02LW9`0XJ6Q0:ZZZP2YZJT0/K6a0:j^[P020;2`/080
/[:b00L0/;2`0;6a/@2b/[80/K6a0;Bd]02f][H0/k>c0080]KFe04X0/;2`0:j^[P2ZZZX0Z:RX09nO
W`2LW9`0UYJF092@T025QHD0O7al06e]K@1PH600BTY:04=3@`10@400@D5104E5A@1?Cdl0H61P08b<
S02QXJ40MWIf061PH01OGel0H61P06UYJ@1NGUh0Cdm?04Y:BP12@T80BTY:03Hf=P0d=3@0<c<c04M7
A`1HF5P0NWYj07emO@12@T80>3Ph03@d=00e=CD0<C4a02`/;00T92@09bLW030`<01?Cdl0F5QH04e=
C@0h>3P0=3@d04=3@`0m?Cd0>CTi02/[:`0U9BD0=CDe06a/K02RXZ80_Kfm08Z:RP1lO7`0VIVI08F5
Q@1mOGd0E5AD03`l?01UIFD0UiNG08Z:RP1mOGd0RXZ:07QhN080MGEe0P1QHF409`1XJ6P0LG5a07]k
N`1eMGD0IVIV05EEE@1RHV80N7Qh07emO@1gMgL0Q8B406YZJP1DE5@0BTY:05EEE@1gMgL0S8b<08J6
QP1[Jf/0IfMW0820P01ZJVX0KVi^09RHV03:b/X0c/k>0:FUY@2WYjL0][Jf0;^k^`3Hf=P0XJ6Q059B
DP0e=CD0=SHf03<c<`0h>3P0<c<c03@d=00303De=@0X034a<@0f=SH0=CDe038b<P0e=CD0>SXj03dm
?@0i>CT0>SXj03/k>`11@D40?Cdm03Hf=P0d=3@0<S8b03De=@0f=SH0>3Ph03`l?00h>3P0=3@d03Ti
>@0m?Cd0=3@d03Lg=`0c<c<0=cLg03`l?010@400?clo03dm?@0l?3`0>SXj03hn?P10@400@T9203Xj
>P0n?Sh0@d=304E5A@80@T9200@0>c/k034a<@0f=SH0=CDe0P12@T807`0f=SH0@D5104m?C`1CDe<0
AdM703hn?P0g=cL0?Shn04M7A`1EEED0EUIF04i>CP1HF5P0Fe]K05eMG@1IFET0Hf=S06EUI@1YJFT0
IfMW06a/K01^KVh0K6a/06m_K`1aLG40LW9b07UiN@1gMgL0Ng]k07alO01oOgl00P21PH401`1mOGd0
P82008>3P`25QHD0RHV908R8R026QXH00P28R8P01`2<S8`0SXj>08N7Q`2<S8`0Rh^;08J6QP2<S8`0
0P2;Rh/00`27QhL0QXJ608f=S@0208J6QP0F08b<S028R8P0R8R808^;R`29RHT0PX:208B4Q027QhL0
R8R808f=S@2>SXh0Shn?08b<S02ATI40Shn?092@T02ATI40TY:B09NGU`2>SXh0UIFE092@T080U9BD
00T0UiNG09FEU@2JVYX0VYZJ09VIV@2FUYH0WYjN09fMW@2EUID00P2;Rh/03P2=SHd0TI6A08b<S02=
SHd0QXJ605eMG@0];Bd0;bl_03lo?`1@D500=SHf02d];@0`<300;Bd]0P0[:b/0400/;2`0<c<c02l_
;`0[:b/0;Rh^03hn?P0h>3P0<C4a03Xj>P0d=3@0=CDe0410@015ADD0=SHf03@d=00e=CD2034a<@0B
02/[:`0a<C40>c/k02TY:@0];Bd0=SHf04U9B@1aLG40Fe]K04E5A@1=CDd0Bd];04I6AP1MGEd0H61P
04Y:BP13@d<0B4Q80P0m?Cd0500n?Sh0>CTi04e=C@1OGel0DE5A02l_;`0b<S80;bl_03De=@0b<S80
<C4a05aLG027QhL0ZJVY0:JVYP2SXj<0VYZJ09:BTP2UYJD0W9bL0P2IVIT00`2DU9@0Ti>C09:BTP02
09ZJVP0309NGU`2HV9P0WIfM0080WIfM0P2IVIT01@2JVYX0W9bL09VIV@2GUiL0VIVI0080V9RH00P0
W9bL09ZJVP2MWId0VIVI09RHV02LW9`0V9RH09NGU`<0W9bL0`2JVYX0402FUYH0V9RH09RHV02EUID0
UYJF09NGU`2CTi<0U9BD09:BTP2FUYH0T92@09>CT`2ATI40T92@08n?S`2<S8`308n?S`0708b<S02=
SHd0SXj>092@T029RHT0Rh^;08B4Q00207moO`0?07emO@1lO7`0Ng]k07EeM@1hN7P0QXJ609fMW@2`
/;00`/;20<k>cP3EeMD0emOG0=[JfP3Kfm/0g=cL0080f][J00H0fm_K0=OGe`3Fe]H0e]KF0=SHf03G
emL20=GEe@030=OGe`3Hf=P0f][J0080e]KF00L0eMGE0=OGe`3Hf=P0fMWI0=OGe`3Fe]H0emOG0080
eMGE0P3Cdm<20=3@d00@0=?Cd`3?cll0d=3@0=;BdP3@d=00dM7A0=;BdP3@d=00dM7A0<o?c`3AdM40
d];B0=7Ad@3Cdm<0d];B0=CDe0<0dm?C00D0e=CD0=?Cd`3Cdm<0dm?C0=CDe00>0<SPf0003038h=P2
03Hf=P0<03<c<`0b<S80<C4a03De=@0h>3P0>SXj03De=@0^;Rh0<c<c03De=@0d=3@0<C4a0P0_;bl0
2@0a<C40=3@d03Hf=P1;Bd/0EeMG061PH01OGel0HF5Q05aLG00205eMG@0806=SH`1bLW80O7al08>3
P`2:RXX0SHf=096AT@2CTi<209^KV`0509nOW`2VYZH0[:b/0:n_[`2d];@00P2`/;00@02b/[80];Bd
0;>c/`2a/K40][Jf0;>c/`2d];@0/[:b0;Zj^P2f][H0];Bd0;:b/P2][Jd0Zj^[0:>SX`2QXJ40WIfM
09FEU@2>SXh0PX:207UiN@1^KVh0FUYJ05ADE015ADD0@4100451@@1:BTX0CDe=061PH02:RXX0XJ6Q
07=cL`1QHF40GemO06=SH`1YJFT0LW9b06QXJ01GEeL0?Shn03Ph>00e=CD0<c<c03Ph>012@T80Fe]K
07alO02;Rh/0Fe]K04E5A@0^;Rh0;2`/030`<00Y:BT0;2`/02HV9P0d=3@0Cdm?06=SH`1IFET0@410
0492@P0n?Sh203<c<`0C02/[:`0`<300?Cdm06ATI02HV9P0^k^k09JFUP1mOGd0W9bL07]kN`1LG5`0
>CTi05MGE`22PX80V9RH07emO@1bLW80P8200861P@02071`L00`05EEE@1JFUX0F5QH05eMG@1DE5@0
Jf][08:2PP1`L700MgMg08:2PP29RHT0P82007inOP1UIFD0HV9R05QHF01>CTh0KFe]08F5Q@1lO7`0
DU9B06IVIP28R8P0KFe]07EeM@2UYJD0b/[:0=7Ad@2LW9`0Ph>30;Jf]P2KVi/0c/k>0<O7a`2:RXX0
@d=303@d=00/;2`0<c<c03De=@0a<C40>CTi03`l?00k>c/0>3Ph03<c<`0e=CD0;bl_0P0g=cL08P0i
>CT0>3Ph03Ph>00f=SH0?Shn03Ph>00`<300:b/[038b<P0/;2`0=SHf03Ph>00g=cL0;bl_02TY:@0b
<S80<30`03Hf=P0`<300<S8b03Lg=`0j>SX0>3Ph03`l?00f=SH0=3@d03Ti>@0f=SH0>c/k03dm?@0f
=SH0>CTi0410@00m?Cd203Hf=P0403Xj>P0_;bl0=CDe03Hf=P80A4A402`0=cLg04=3@`1?Cdl0EEEE
0492@P11@D40<c<c04Q8B015ADD0Cdm?05=CD`1>CTh0EEEE05]KF`1JFUX0Fe]K061PH01UIFD0Hf=S
06IVIP1_Kfl0IfMW06a/K01YJFT0LG5a079bLP1cLg<0MGEe07YjNP1hN7P0OWin07emO@20P800Ogmo
0820P023Ph<0QhN708:2PP25QHD0QhN708^;R`29RHT0Rh^;08R8R080RXZ:0P2=SHd01026QXH0S8b<
08n?S`29RHT208N7Q`0408b<S024Q8@0R8R808J6QP80QHF500/0RHV908:2PP1oOgl0QHF508J6QP25
QHD0R8R808f=S@24Q8@0RHV908N7Q`020861P@050820P026QXH0QHF508>3P`2:RXX00`2<S8`0B02D
U9@0TI6A09VIV@2DU9@0VIVI09FEU@2FUYH0VYZJ09>CT`27QhL0Rh^;08b<S02BTY80SXj>08R8R01o
Ogl0@D5102h^;P0l?3`0EeMG03Hf=P0`<300;bl_02/[:`0`<300:b/[02`/;00_;bl0;2`/038b<P0c
<c<0?clo03Ti>@0j>SX0>3Ph034a<@0i>CT0CTi>0451@@0j>SX0<S8b03Xj>P0d=3@0=cLg03@d=00h
>3P0@41002/[:`0`<300>CTi04i>CP1dM7@0GemO04Y:BP1?Cdl0D51@04I6AP1SHf<0GEeM04];B`10
@400Bd];03Ph>00m?Cd0B4Q80451@@1>CTh0HV9R04I6AP0e=CD0@41002l_;`80=3@d00<0<S8b065Q
H@24Q8@00P2ZZZX01@2SXj<0UYJF09JFUP2SXj<0UYJF0080Vi^K00L0TI6A09>CT`2?Shl0UiNG09^K
V`2LW9`0VIVI0080W9bL00D0X:2P09bLW02GUiL0Vi^K09bLW00209^KV`0909ZJVP2MWId0WIfM09fM
W@2IVIT0UYJF09fMW@2KVi/0VIVI0080W9bL00H0WIfM09RHV02KVi/0WIfM09ZJVP2LW9`209RHV003
09ZJVP2GUiL0UiNG0080UiNG00D0U9BD09NGU`2CTi<0TI6A092@T00209>CT`<0Shn?01T0T92@08^;
R`2@T900TI6A08^;R`2@T900RHV908F5Q@23Ph<0OGem08N7Q`1nOWh0NWYj07IfMP1eMGD0NGUi08J6
QP2KVi/0/[:b0<?3``3=cLd0eMGE0=SHf03Jf]X0fm_K00<0fMWI00H0f=SH0=GEe@3Fe]H0e=CD0=OG
e`3EeMD20=KFeP050=GEe@3Fe]H0e]KF0=KFeP3Hf=P00P3GemL30=SHf0<0emOG00@0e=CD0=GEe@3A
dM40d=3@0P3AdM400`3@d=00clo?0<o?c`020<o?c`030=7Ad@3@d=00d];B00<0dM7A00P0e=CD0=;B
dP3Bd]80d=3@0=;BdP3@d=00dm?C0=;BdP80e=CD00<0d];B0=GEe@38h=P03@38h=P000`0b>3H0P0b
<S802P0`<300<C4a038b<P0h>3P0=CDe03Ti>@0`<300=cLg03Ph>00^;Rh203<c<`80;bl_01X0<c<c
03De=@0h>3P0ADE5055AD@1JFUX0H61P05eMG@1JFUX0EEEE05QHF01QHF40Kfm_07alO022PX80S8b<
09JFUP2@T900UIFE09^KV`2MWId0XJ6Q0:VYZ@2ZZZX0[Zj^0;>c/`80/[:b00H0/k>c0;:b/P2`/;00
/k>c0;6a/@2d];@20;Ng]`060;Bd]02g]kL0^KVi0;6a/@2_[jl0Zj^[0P2PX:00@@2LW9`0U9BD08b<
S023Ph<0MWIf06i^KP1JFUX0D51@04=3@`0o?cl0?Shn04E5A@1;Bd/0IFEU08R8R02TY:@0OGem06EU
I@1KFe/0I6AT06e]K@1^KVh0Jf][06IVIP15ADD0<S8b02XZ:P0e=CD0?Shn03dm?@1HF5P0LG5a09FE
U@1eMGD0@D5102l_;`0^;Rh0;bl_03De=@0_;bl0;Rh^02LW9`18B4P0I6AT05iNGP10@400>c/k03Lg
=`0b<S80:BTY02d];@0o?cl0D51@065QH@26QXH0^k^k0:j^[P29RHT0U9BD06MWI`13@d<0?Cdm05YJ
FP2@T900SXj>0080M7Ad00D0MgMg0820P01_Kfl0Kfm_04M7A`0204a<C00U05ADE00h>3P0C4a<07Ui
N@2;Rh/0QHF508n?S`25QHD0NWYj06][J`1PH600MGEe06IVIP0j>SX0KVi^08Z:RP1kNg/0EUIF07Yj
NP2>SXh0MGEe07]kN`2SXj<0`l?30<o?c`2^[Zh0QhN709ZJVP2c/k<0W9bL0<_;b`38b<P0S8b<03dm
?@0`<300;bl_02h^;P02034a<@04038b<P0/;2`0<30`03De=@80<30`02@0=CDe03<c<`0f=SH0>SXj
03`l?00g=cL0@D5103Xj>P0h>3P0;2`/02XZ:P0Y:BT0<S8b03Ti>@0g=cL0<c<c03Hf=P0g=cL0<c<c
04I6AP0e=CD0>SXj03Lg=`0j>SX0A4A404Y:BP0g=cL0<S8b04A4A00l?3`0>c/k03hn?P0h>3P0@D51
03lo?`0h>3P203<c<`0E03De=@0c<c<0=CDe03lo?`1<C4`0BDU903dm?@19BDT0FEUI059BDP10@400
>CTi03/k>`17AdL0Bd];04i>CP1@D500DE5A05EEE@1MGEd0HV9R0080JFUY00@0J6QX06UYJ@1YJFT0
KVi^0`1ZJVX00`1dM7@0MWIf07MgM`0207IfMP0<07inOP1kNg/0OWin0861P@24Q8@0PX:20861P@23
Ph<0Q8B408J6QP24Q8@0SHf=0P2:RXX02P2>SXh0S8b<09:BTP2?Shl0TI6A08f=S@2<S8`0R8R808V9
R@24Q8@208N7Q`0E08R8R025QHD0PH610861P@24Q8@0QHF50861P@20P800PX:208J6QP25QHD0PH61
08F5Q@20P800OWin07UiN@1hN7P0MGEe07IfMP1jNWX0MGEe0080OGem0`1nOWh05@1oOgl0R8R808n?
S`2EUID0VIVI09bLW02JVYX0Vi^K09RHV02@T900S8b<08V9R@2<S8`0SHf=08R8R027QhL0HF5Q034a
<@0i>CT0EUIF03/k>`0202/[:`80;Bd]02l0<c<c02PX:00_;bl0;Rh^02`/;00^;Rh0=cLg034a<@0d
=3@0>3Ph03@d=00c<c<0C4a<04=3@`0g=cL0=3@d03lo?`0g=cL0<c<c03Ph>00f=SH0@D5102TY:@0^
;Rh0>SXj04Y:BP1dM7@0Fe]K03hn?P18B4P0CDe=04=3@`1NGUh0IVIV04];B`18B4P0AdM70492@P0m
?Cd0@41003lo?`1>CTh0Fe]K04=3@`0^;Rh0?Cdm04Q8B00203Lg=`0603`l?01UIFD0QhN70:FUY@2_
[jl0XJ6Q0P2EUID0102TY:@0UiNG09ZJVP2JVYX209NGU`0?09:BTP2DU9@0WinO09fMW@2FUYH0Vi^K
09nOW`2NWYh0W9bL09RHV02LW9`0X:2P09fMW@2KVi/0UYJF00<0VYZJ01@0VIVI09ZJVP2LW9`0VIVI
09ZJVP2GUiL0VYZJ09bLW02OWil0Vi^K09fMW@2NWYh0Vi^K09VIV@2JVYX0U9BD09NGU`2HV9P0UYJF
09NGU`80UIFE00P0Ti>C09BDU02?Shl0TI6A08j>SP2CTi<0Shn?096AT@80Shn?01D0SXj>08^;R`2>
SXh0SXj>08Z:RP29RHT0PX:208F5Q@20P800OGem07]kN`1fMWH0Kfm_07EeM@24Q8@0WIfM0;2`/036
a/H0b/[:0=CDe03IfMT00`3Kfm/0103Jf]X0fMWI0=KFeP3EeMD20=KFeP080=WIf@3GemL0emOG0=OG
e`3EeMD0emOG0=KFeP3De=@20=KFeP060=WIf@3Hf=P0fMWI0=[JfP3IfMT0f=SH0P3Fe]H01`3EeMD0
dm?C0=7Ad@3Bd]80dm?C0=7Ad@3?cll00P3=cLd01@3>c/h0clo?0<k>cP3@d=00clo?00<0dM7A00/0
d=3@0=7Ad@3@d=00d=3@0<o?c`3Bd]80e=CD0=7Ad@3Cdm<0dM7A0=;BdP0>0<SPf0003038h=P203Ti
>@80<c<c00d0=3@d03De=@0f=SH0<S8b030`<00c<c<0?3`l03@d=00h>3P0=CDe03Xj>P0b<S80?3`l
0080=cLg00<0?clo04m?C`1HF5P00P1MGEd0201HF5P0EeMG05IFEP1RHV80LG5a07alO024Q8@0RXZ:
0P2BTY80202HV9P0WIfM09nOW`2PX:00ZZZZ0:f][@2_[jl0/K6a0`2e]KD00`2b/[80];Bd0;Bd]002
0;:b/P0C0;2`/02e]KD0]KFe0;Fe]@2c/k<0];Bd0:j^[P2XZ:P0YZJV09fMW@2JVYX0UIFE08R8R022
PX80MgMg06a/K01GEeL0De=C04=3@`020451@@0K04I6AP1;Bd/0HF5Q08N7Q`2WYjL0Q8B406UYJ@1N
GUh0H61P06YZJP1XJ6P0Kfm_06i^KP1HF5P0?clo034a<@0b<S80?Cdm03Ph>01;Bd/0LW9b09fMW@26
QXH0AdM702/[:`0V9RH0<S8b0080<c<c01d0:RXZ02DU9@0m?Cd0IfMW05]KF`15ADD0>3Ph034a<@0]
;Bd0:BTY03Hf=P1?Cdl0GemO05QHF01dM7@0]kNg0;Rh^02;Rh/0RXZ:05MGE`0h>3P0Bd];06][J`2A
TI40OGem069RHP1_Kfl0Ng]k08J6QP0206IVIP0Z04=3@`0n?Sh0A4A404];B`0b<S80A4A4061PH02>
SXh0VYZJ08R8R01mOGd0GemO05QHF01iNGT0Shn?07=cL`0e=CD0N7Qh096AT@24Q8@0JFUY08j>SP2C
Ti<0N7Qh07]kN`2BTY80][Jf0=;BdP31`L40YjNW092@T02c/k<0WYjN0:VYZ@3Lg=`0`/;207IfMP0j
>SX0=3@d038b<P0d=3@0=cLg0P0_;bl03@0c<c<0=CDe03Ti>@0k>c/0>3Ph03Hf=P0d=3@0<S8b03Lg
=`0d=3@0>3Ph02l_;`0[:b/00P0^;Rh0100X:2P0<c<c03De=@0k>c/2030`<00503@d=00`<300;2`/
03Ph>00m?Cd00P0l?3`03013@d<0>c/k03Lg=`0h>3P0@T9204=3@`0k>c/0A4A403hn?P0o?cl0A4A4
03Lg=`80=CDe00h0<30`03De=@0h>3P0?Shn059BDP1=CDd0>CTi04a<C01BDU80BTY:03dm?@0j>SX0
@4100451@@80AdM700P0E5AD05=CD`1IFET0I6AT06IVIP1]KFd0K6a/06QXJ080IVIV01L0KVi^06e]
K@1^KVh0L71`07QhN01eMGD0MWIf07YjNP1fMWH0NWYj07]kN`20P800PH610820P022PX80PH6108N7
Q`25QHD0Ph>308N7Q`2<S8`0RHV908N7Q`0208^;R`0308f=S@2ATI40SHf=0080Rh^;00P0Shn?08b<
S02;Rh/0R8R808J6QP27QhL0Q8B408F5Q@80PX:200T0P82008>3P`1nOWh0Ogmo07inOP1mOGd0Ogmo
07emO@1oOgl00P1eMGD00`1dM7@0MGEe07=cL`0207MgM`0506m_K`1dM7@0Lg=c07=cL`1dM7@00P1g
MgL06`1lO7`0QHF508Z:RP2DU9@0X:2P09NGU`2FUYH0UIFE092@T02=SHd0TI6A09BDU02@T900R8R8
07alO015ADD0=SHf05UIF@0m?Cd0:BTY02`/;00a<C40;Bd]02PX:00V9RH0:b/[02h^;P02034a<@0O
030`<00/;2`0<30`03Lg=`0l?3`0=SHf03Xj>P15ADD0>3Ph02h^;P0e=CD0>3Ph034a<@0c<c<0=3@d
03Ti>@0^;Rh0;2`/03dm?@1HF5P0KFe]05]KF`14A4@0ATI605=CD`15ADD0Hf=S05iNGP17AdL0Cdm?
04A4A0020410@00D04=3@`0m?Cd0EEEE05QHF00o?cl0<30`03Hf=P0d=3@0=CDe03@d=00k>c/0IVIV
08b<S02NWYh0ZZZZ09jNWP2ATI40UYJF0::RXP2EUID209fMW@0;09NGU`2DU9@0U9BD09:BTP2LW9`0
Vi^K09RHV02LW9`0Vi^K09ZJVP2KVi/00P2IVIT209bLW00309RHV02JVYX0VIVI0080WIfM00X0UYJF
09NGU`2HV9P0VIVI09bLW02FUYH0Vi^K09VIV@2JVYX0WIfM0P2KVi/00`2JVYX0V9RH09FEU@0409FE
U@0=09BDU02GUiL0VYZJ092@T02EUID0TI6A092@T02BTY80S8b<09>CT`2>SXh0TI6A08j>SP0208n?
S`08092@T02<S8`0Rh^;08^;R`28R8P0QHF508B4Q01mOGd207YjNP0907AdM01hN7P0QHF509bLW02`
/;00`l?30<S8b03Bd]80f=SH0080fm_K00<0f][J0=WIf@3Hf=P00P3GemL30=GEe@060=CDe03Fe]H0
e]KF0=GEe@3Cdm<0eMGE0`3GemL0103Hf=P0fMWI0=WIf@3Jf]X30=WIf@0;0=GEe@3Hf=P0eMGE0=?C
d`3Bd]80e=CD0=;BdP3@d=00c<c<0<g=c@3<c<`00P3=cLd01@3>c/h0cLg=0<c<c03?cll0cLg=00D0
d=3@00H0clo?0=3@d03Bd]80d];B0<o?c`3Bd]8>0<SPf0003038h=P20451@@80<c<c00H0;Bd]030`
<00c<c<0<C4a03Hf=P0g=cL203lo?`0:03Ph>00j>SX0?3`l03@d=00e=CD0>3Ph03@d=010@400B4Q8
059BDP80GemO0100EeMG05=CD`1EEED0J6QX075aL@1mOGd0Ph>3092@T02BTY80UYJF09^KV`2NWYh0
XJ6Q0:>SX`2XZ:P0Zj^[0P2a/K420;>c/`1E0;Fe]@2c/k<0/K6a0;6a/@2d];@0/k>c0;:b/P2f][H0
/k>c0;Ng]`2d];@0/k>c0;6a/@2/[:`0ZZZZ0:2PX02FUYH0U9BD08j>SP21PH40N7Qh06][J`1KFe/0
DU9B04I6AP14A4@0@d=30451@@17AdL0Fe]K08:2PP2LW9`0UiNG06i^KP1UIFD0Hf=S06ATI01VIVH0
Lg=c07UiN@1VIVH0BTY:03`l?00e=CD0>c/k03Hf=P1;Bd/0MgMg0:6QX@2<S8`0Bd];02HV9P0U9BD0
<C4a03<c<`0^;Rh08b<S028R8P0h>3P0GemO06m_K`1MGEd0A4A403Lg=`0e=CD0<30`05ADE01CDe<0
F5QH05ADE01EEED0ZJVY0;Jf]P25QHD0PH61069RHP0i>CT0FEUI07moO`2<S8`0KVi^06a/K01aLG40
Ng]k07MgM`0206ATI00704E5A@1;Bd/0@D510492@P0g=cL0HV9R08:2PP0208F5Q@0Z08^;R`1gMgL0
Jf][071`L025QHD0PH6106IVIP1;Bd/0QXJ60:2PX02BTY80KVi^08n?S`2EUID0MGEe07MgM`2<S8`0
[Zj^0<c<c03:b/X0UYJF09jNWP2PX:00`/;2096AT@38b<P0emOG0;2`/01UIFD0?Shn03Ti>@0g=cL0
=CDe03Lg=`0h>3P0=SHf03Xj>P0c<c<0=CDe03Ph>00k>c/0=cLg0P0l?3`02@13@d<0>c/k03hn?P0g
=cL0<S8b02d];@0g=cL0>c/k03lo?`0203Lg=`0A03@d=00e=CD0;bl_03De=@0n?Sh0?Cdm03hn?P14
A4@0=cLg03Hf=P0o?cl0AdM704A4A00k>c/0=cLg03dm?@16ATH00P13@d<303Xj>P0D038b<P0e=CD0
>c/k04=3@`1?Cdl0ADE503Xj>P1IFET0EEEE059BDP13@d<0=cLg04M7A`19BDT0BTY:04Q8B01DE5@0
EeMG069RHP1VIVH206a/K00806UYJ@1ZJVX0J6QX06a/K01`L700Lg=c071`L01gMgL307EeM@0K07Mg
M`1iNGT0NWYj07inOP22PX80Ph>307moO`20P800PX:208R8R029RHT0Q8B408N7Q`26QXH0Rh^;08n?
S`26QXH0SXj>09:BTP2@T900SXj>08b<S02;Rh/0S8b<08Z:RP25QHD0QhN70080QHF500H0PH6108N7
Q`23Ph<0PH6108N7Q`25QHD207moO`0>08>3P`1jNWX0M7Ad07EeM@1gMgL0Lg=c07EeM@1gMgL0NGUi
07IfMP1gMgL0OGem07alO021PH4207QhN00=07MgM`1eMGD0Ng]k079bLP1jNWX0P82008N7Q`2GUiL0
W9bL09JFUP2KVi/0U9BD096AT@0208j>SP0E08b<S02;Rh/0PH6106m_K`0j>SX0EEEE0492@P0f=SH0
;Bd]02TY:@0/;2`0;Rh^02/[:`0W9bL0:2PX02/[:`0`<300=3@d02h^;P0Z:RX0<C4a0080>CTi00<0
=cLg03/k>`0j>SX00P0b<S806`0e=CD0=cLg03Ti>@0j>SX0<C4a02l_;`0`<300?clo055AD@1PH600
FEUI04I6AP19BDT0EEEE0410@01LG5`0E5AD03lo?`1BDU80ATI603lo?`0f=SH0>3Ph04E5A@1@D500
GemO03hn?P02030`<080;bl_00/0=CDe03dm?@1YJFT0RHV909jNWP2VYZH0W9bL08^;R`2JVYX0WYjN
096AT@0209bLW00709^KV`2DU9@0UYJF09RHV02GUiL0WYjN09NGU`0209bLW080V9RH00<0Vi^K09RH
V02MWId00`2HV9P01`2IVIT0VYZJ09VIV@2KVi/0UiNG09bLW02KVi/00P2JVYX00`2HV9P0UYJF09VI
V@0209^KV`0<09RHV02IVIT0UiNG09FEU@2FUYH0U9BD09RHV02EUID0U9BD09FEU@2DU9@0UiNG0P2A
TI40102BTY80U9BD092@T02>SXh208n?S`0E08f=S@2>SXh0SHf=08^;R`29RHT0Rh^;08N7Q`28R8P0
Ph>307moO`22PX80NGUi07IfMP1eMGD0OGem08j>SP2LW9`0/[:b0<C4a03;bl/0dM7A0080f=SH00@0
f][J0=SHf03Kfm/0f=SH0`3Fe]H00`3EeMD0e=CD0=GEe@020=CDe0<0eMGE0`3Fe]H01`3GemL0f][J
0=WIf@3Jf]X0f=SH0=OGe`3IfMT00P3GemL30=?Cd`080=CDe03AdM40d=3@0<o?c`3>c/h0clo?0<g=
c@3>c/h40<g=c@050<k>cP3=cLd0c<c<0<g=c@3?cll00`3>c/h20=3@d0030<o?c`3@d=00b>3H00d0
b>3H000<0<SPf080<30`02P0=3@d02l_;`0c<c<0<c<c03Lg=`0b<S80=cLg03Hf=P0i>CT0=CDe03Xj
>P0f=SH0>CTi03Hf=P0g=cL0=CDe03Hf=P0j>SX0ADE5059BDP1HF5P0Fe]K05YJFP1KFe/0FEUI06IV
IP1aLG40PH6108R8R02?Shl0Ti>C09JFUP2IVIT0WinO0:2PX02RXZ80Z:RX0:f][@2`/;00/k>c0P2a
/K401P2d];@0/k>c0;:b/P2e]KD0];Bd0;Fe]@80/[:b02d0/k>c0;Ng]`2e]KD0/[:b0:j^[P2/[:`0
YZJV0:>SX`2MWId0V9RH08^;R`1nOWh0Lg=c06][J`1HF5P0C4a<04];B`12@T80A4A404U9B@1;Bd/0
DE5A071`L02=SHd0X:2P08>3P`1_Kfl0HV9R06MWI`1UIFD0LG5a07emO@1`L700F5QH04Q8B00`<300
=CDe034a<@0n?Sh0Kfm_09jNWP2;Rh/0DE5A02d];@0[:b/00P0d=3@07P0f=SH0;Rh^02`/;00`<300
DU9B06i^KP1YJFT0ATI602d];@0h>3P0>c/k05YJFP1@D500F5QH05MGE`1BDU80W9bL0;>c/`1oOgl0
LW9b06QXJ013@d<0LG5a09>CT`1iNGT0Fe]K05YJFP1VIVH0NGUi07]kN`80GEeM02d0ADE503lo?`0n
?Sh0>SXj05QHF025QHD0R8R806i^KP1QHF40RXZ:08B4Q021PH40OGem08:2PP1VIVH0HF5Q07]kN`2H
V9P0/[:b0:b/[01mOGd0Shn?08j>SP1dM7@0LG5a0820P02XZ:P0a<C40<S8b02?Shl0QhN709FEU@2X
Z:P0/K6a09^KV`3AdM40alO7092@T01IFET0?Shn03Lg=`0e=CD0>CTi03Ph>00i>CT00`0f=SH00`0b
<S80=cLg03`l?00203hn?P80=cLg00<0C4a<03Xj>P0f=SH00P0d=3@02`0f=SH0>CTi03De=@0j>SX0
>CTi03<c<`0`<300?3`l03dm?@0o?cl0?3`l0080?Cdm00L0=cLg0410@012@T80@D5103Hf=P0o?cl0
ADE50080Bd];00T0BTY:03lo?`0m?Cd0?Cdm03@d=00a<C40@41004A4A01FEUH00P10@4001`1IFET0
Cdm?051@D016ATH0?Cdm04I6AP1ADE400P1>CTh01@1HF5P0HF5Q06=SH`1WIfL0IFEU0080J6QX00/0
JFUY06i^KP1cLg<0Kfm_07QhN01`L700Ng]k07YjNP1eMGD0O7al07UiN@0207emO@80Q8B400h0PX:2
08>3P`24Q8@0QHF508R8R027QhL0RXZ:08b<S02:RXX0Rh^;08f=S@2<S8`0RXZ:092@T0<0SXj>00X0
T92@08Z:RP27QhL0QHF508J6QP23Ph<0Q8B408J6QP22PX80PH610P22PX804@1oOgl0Ng]k07inOP1k
Ng/0NWYj07MgM`1fMWH0N7Qh07]kN`1lO7`0P82008B4Q01oOgl0PH6108N7Q`2;Rh/0S8b<0080Ph>3
00X0P8200861P@1mOGd0OGem07moO`1kNg/0PH6108N7Q`2EUID0VIVI0P2FUYH0<`2CTi<0SXj>09JF
UP2@T900S8b<08R8R023Ph<0GEeM04];B`1>CTh0=3@d02HV9P0W9bL0<S8b02h^;P0/;2`0:RXZ034a
<@0_;bl0;Bd]03Xj>P0b<S809bLW02d];@0h>3P0@410030`<00^;Rh0>c/k03Lg=`0b<S80=SHf03lo
?`0i>CT0>c/k038b<P0a<C40;2`/03`l?01;Bd/0EUIF05aLG017AdL0@41004m?C`16ATH0GUiN05MG
E`0l?3`0Cdm?055AD@0203`l?00D03Ph>00n?Sh0EUIF06UYJ@10@400;bl_03@d=00/;2`0<c<c02/[
:`0j>SX0IFEU08V9R@2VYZH0Xj>S0:2PX02@T900UYJF0:>SX`2@T9020:2PX00<09ZJVP2EUID0UiNG
09^KV`2EUID0Vi^K09NGU`2NWYh0W9bL09^KV`2JVYX0WIfM0`2JVYX02P2KVi/0VYZJ09NGU`2HV9P0
WIfM09ZJVP2OWil0W9bL09RHV02KVi/209NGU`0509JFUP2GUiL0UYJF09RHV02EUID00`2HV9P00`2E
UID0Ti>C09>CT`0209FEU@0609NGU`2DU9@0T92@09:BTP2?Shl0U9BD0P2@T9001@2>SXh0SHf=092@
T029RHT0Shn?0080RXZ:00@0S8b<08R8R028R8P0PH610P23Ph<03026QXH0Ng]k07YjNP1cLg<0O7al
08b<S02QXJ40/K6a0<;2`P37alL0d=3@0=KFeP80f=SH0P3Jf]X0103Hf=P0emOG0=KFeP3Fe]H20=?C
d`030=GEe@3De=@0e=CD0080eMGE01@0dm?C0=KFeP3Cdm<0eMGE0=KFeP3Hf=P0emOG0=[JfP3Hf=P0
fMWI0=SHf03Fe]H0emOG0=KFeP3De=@0eMGE0=?Cd`3De=@0d];B0=?Cd`80clo?00@0cLg=0<k>cP3<
c<`0c/k>0P3=cLd0203;bl/0c/k>0<[:bP3<c<`0c/k>0<c<c03?cll0b/[:0P3=cLd20<k>cPh0b>3H
000<0<SPf080=3@d00D0;Rh^034a<@0c<c<0>SXj03Ph>00303Lg=`0L03/k>`0i>CT0?3`l03Ph>00i
>CT0=SHf03Lg=`0i>CT0>3Ph0451@@1:BTX0De=C055AD@1HF5P0GemO06YZJP1LG5`0IFEU07=cL`21
PH40R8R808j>SP2DU9@0Vi^K09bLW02OWil0XJ6Q0:FUY@80Z:RX00L0/;2`0;6a/@2d];@0];Bd0;:b
/P2c/k<0/K6a0080/k>c00D0][Jf0;Fe]@2c/k<0]kNg0;Vi^@020;Fe]@040:j^[P2XZ:P0ZJVY09fM
W@80VYZJ01D0S8b<08>3P`1jNWX0J6QX05eMG@1:BTX0ATI604Y:BP15ADD0C4a<04e=C@1@D500HV9R
08J6QP2JVYX0WinO07moO`1XJ6P0HF5Q06ATI01/K6`00P1dM7@0;01WIfL0BTY:03Lg=`11@D40<S8b
034a<@1SHf<0UYJF08b<S01MGEd0<S8b02LW9`0T92@0;Rh^03De=@0b<S80:b/[03Xj>P14A4@0IfMW
06m_K`19BDT0;bl_03Ti>@1IFET0Fe]K04];B`1GEeL0G5aL04Q8B02<S8`0/[:b08n?S`1]KFd0K6a/
05IFEP27QhL0T92@05QHF01:BTX0CTi>05mOG`1]KFd0Lg=c0P1>CTh08P0m?Cd0>SXj05=CD`1DE5@0
OGem08:2PP1fMWH0N7Qh05ADE026QXH0QHF508R8R01mOGd0Ng]k055AD@1^KVh0VYZJ09jNWP2/[:`0
Y:BT08R8R02GUiL0QXJ6075aL@1]KFd0Ogmo0:n_[`2n_[h0aLG508j>SP1VIVH0P82008R8R02QXJ42
0:b/[00:0<c<c02k^k/0TI6A06MWI`0d=3@0<30`038b<P0j>SX0=cLg02d];@80=CDe00@0=3@d034a
<@0d=3@0?Cdm0P0e=CD04@0g=cL0@41003@d=00i>CT0;Rh^03@d=00e=CD0>SXj03De=@0c<c<0=3@d
030`<00a<C40=3@d03Lg=`0d=3@0=CDe0080=cLg00X0=CDe0451@@14A4@0?Shn03Ti>@17AdL0ATI6
0410@016ATH0?3`l0`0e=CD05P0^;Rh0=CDe0451@@1ADE40EUIF03hn?P14A4@0EUIF04A4A01<C4`0
?Cdm03lo?`11@D40CDe=04m?C`1ADE40G5aL06EUI@1VIVH0JVYZ06UYJ@1^KVh206a/K00G06i^KP1c
Lg<0Lg=c07IfMP1dM7@0Ng]k07QhN01iNGT0P82007alO01kNg/0NWYj08B4Q022PX80QhN708J6QP25
QHD0RHV908J6QP2:RXX0R8R808V9R@25QHD00`2;Rh/0102=SHd0Shn?096AT@2=SHd208n?S`0408R8
R025QHD0Rh^;08B4Q080QHF50P23Ph<02020P800Ng]k0861P@1lO7`0OWin07alO01jNWX0NGUi0`1n
OWh01`1mOGd0PH6108R8R027QhL0Q8B408N7Q`29RHT00P2?Shl2096AT@1E08^;R`2=SHd0S8b<08R8
R024Q8@0Ph>30820P021PH40QhN708V9R@2CTi<0UYJF09FEU@2@T900Ti>C096AT@2DU9@0RXZ:08N7
Q`1nOWh0Hf=S04i>CP0b<S809bLW02/[:`0_;bl0<C4a02d];@0e=CD0<S8b030`<00c<c<0?Cdm03Xj
>P0c<c<0=CDe03Hf=P0o?cl0=CDe02l_;`0e=CD0>c/k03@d=00`<300>CTi0451@@0h>3P0=cLg02h^
;P0_;bl0>SXj04I6AP1FEUH0IFEU04A4A00k>c/0CDe=04Q8B01RHV80F5QH04E5A@1>CTh0@d=304I6
AP0m?Cd0>SXj03`l?01KFe/0HV9R03Ti>@0[:b/0=cLg03Ph>00e=CD0<S8b0492@P1aLG40SXj>0:FU
Y@2OWil0XJ6Q09>CT`2FUYH0X:2P08j>SP0209fMW@0<09^KV`2EUID0UYJF09ZJVP2DU9@0WinO09RH
V02IVIT0VYZJ09nOW`2JVYX0V9RH0P2KVi/01P2OWil0UiNG09RHV02IVIT0VYZJ09bLW080VIVI01H0
Vi^K09ZJVP2JVYX0VYZJ09FEU@2KVi/0UYJF09ZJVP2CTi<0V9RH09>CT`2EUID0UYJF09NGU`2EUID0
TY:B09JFUP2GUiL0TY:B09>CT`2BTY80Ti>C0P2ATI40102>SXh0TI6A09:BTP2?Shl208b<S00408n?
S`29RHT0SHf=096AT@80S8b<00H0R8R808B4Q026QXH0Q8B407inOP1jNWX207emO@0908b<S02MWId0
[jn_0<30`038b<P0c/k>0=;BdP3GemL0f=SH0080emOG00L0f=SH0=GEe@3EeMD0e]KF0=GEe@3De=@0
emOG00<0e=CD00D0dm?C0=GEe@3EeMD0eMGE0=;BdP050=OGe`80e]KF00D0emOG0=SHf03EeMD0e]KF
0=OGe`020=KFeP030=GEe@3Cdm<0dM7A00<0clo?0P3>c/h20<c<c0030<k>cP3<c<`0bl_;00<0c<c<
00H0bl_;0<k>cP3;bl/0cLg=0<c<c03=cLd>0<SPf0003038h=P203`l?00G03Lg=`0b<S80>CTi03Hf
=P0h>3P0>c/k03`l?00k>c/0<c<c03/k>`0l?3`0>c/k03Lg=`0h>3P0>SXj03Hf=P0g=cL0@41004=3
@`1>CTh0EEEE05UIF@1HF5P00P1JFUX01`1XJ6P0LW9b0861P@29RHT0Shn?09NGU`2JVYX00P2RXZ80
102UYJD0YjNW0:VYZ@2[Zj/20:n_[`80/k>c00<0];Bd0;6a/@2c/k<00P2b/[801`2e]KD0];Bd0;Jf
]P2c/k<0]KFe0;Jf]P2c/k<00P2][Jd0A`2VYZH0YJFU0:2PX02SXj<0WIfM08^;R`20P800L71`05mO
G`1@D500@T920451@@14A4@0AdM704a<C01?Cdl0FEUI06i^KP2:RXX0X:2P09FEU@1/K6`0IVIV06=S
H`1VIVH0L71`07AdM01SHf<0ATI603<c<`0g=cL0>3Ph03Lg=`1@D500S8b<096AT@1IFET0=SHf02`/
;00[:b/0<30`03Lg=`0[:b/0<30`02/[:`0h>3P0F5QH06i^KP1CDe<0<S8b0492@P1ZJVX0F5QH03Ti
>@1QHF40GEeM04=3@`1mOGd0];Bd09fMW@1dM7@0Kfm_06UYJ@2;Rh/0LW9b03hn?P0k>c/0Cdm?055A
D@1MGEd0IFEU0080@D5100<0<c<c04Y:BP1PH6000P21PH403P1ZJVX0N7Qh09FEU@1>CTh0M7Ad06][
J`1mOGd0M7Ad06i^KP1PH600Ogmo0:BTY02PX:00WinO0P2@T9005`2MWId0RHV9079bLP1/K6`0Q8B4
0;:b/P3=cLd0c<c<09nOW`1MGEd0KVi^07inOP25QHD0[Jf]0:VYZ@2`/;00e]KF0;6a/@2DU9@0DE5A
03De=@0j>SX0=SHf0080>SXj00L0>3Ph03Xj>P0e=CD0>c/k03Ti>@0g=cL0@4100080>CTi00`0=SHf
03Ti>@0^;Rh0<S8b02d];@0b<S80>3Ph03Lg=`0e=CD0<c<c038b<P0];Bd203Lg=`<0=3@d00`0<C4a
03Xj>P14A4@0=cLg03Ph>00g=cL0@T9204Q8B017AdL0CDe=03/k>`0b<S8202h^;P0H03@d=00j>SX0
BDU9059BDP1FEUH0@D5105EEE@1GEeL0Cdm?04=3@`0k>c/0A4A404I6AP18B4P0CTi>05YJFP1PH600
JFUY06i^KP1YJFT0Kfm_075aL@1^KVh0L71`0P1bLW8207=cL`0K07MgM`1eMGD0MgMg07QhN020P800
Ng]k07YjNP1nOWh0PH610820P01oOgl0PH6108:2PP24Q8@0SHf=08^;R`28R8P0S8b<08Z:RP2?Shl0
Rh^;08n?S`2CTi<0TI6A09BDU02?Shl0SXj>0080Rh^;00@0Q8B408N7Q`25QHD0QXJ60P20P800501m
OGd0Ogmo07YjNP1nOWh0N7Qh07]kN`1nOWh0PX:207inOP23Ph<0OWin08J6QP1mOGd0Q8B408V9R@2:
RXX0Rh^;08j>SP29RHT0TI6A0`2CTi<03@2=SHd0SXj>08n?S`2=SHd0RHV908b<S028R8P0QXJ608:2
PP29RHT0T92@09FEU@2FUYH00P2CTi<00`2FUYH0UIFE08^;R`0208J6QP0607]kN`1RHV80?Cdm02/[
:`0b<S80;bl_0`0`<300200[:b/0;Bd]02l_;`0j>SX0?clo02h^;P0a<C40;Rh^0P0c<c<05`0];Bd0
;Rh^03hn?P0b<S80;Rh^03Xj>P15ADD0=cLg034a<@0g=cL0;Bd]03Ti>@15ADD0EEEE06IVIP12@T80
?Shn04Y:BP15ADD0HF5Q05=CD`1:BTX0Cdm?0080ADE500P0@41003/k>`0h>3P0GemO05iNGP0b<S80
;Bd]03Ti>@80;Rh^00/0;bl_04I6AP1[Jf/0TY:B0:FUY@2MWId0WinO09>CT`2JVYX0XJ6Q08j>SP02
09nOW`0509bLW02CTi<0UIFE09ZJVP2EUID00`2JVYX05P2MWId0WYjN09ZJVP2LW9`0VYZJ09^KV`2H
V9P0U9BD09VIV@2KVi/0UYJF09bLW02KVi/0UYJF09VIV@2JVYX0UIFE09^KV`2EUID0W9bL09RHV02J
VYX209BDU00909ZJVP2FUYH0TY:B09JFUP2DU9@0UiNG09VIV@2DU9@0UIFE00<0TY:B00l0Shn?09>C
T`2EUID0TI6A09:BTP2@T900TY:B09>CT`2ATI40T92@08b<S02ATI40SHf=08b<S026QXH00P23Ph<0
3@25QHD0Ogmo07]kN`1iNGT0Ng]k08j>SP2PX:00Zj^[0;no_`39bLT0d=3@0=GEe@3GemL00P3Hf=P2
0=OGe`050=KFeP3EeMD0e=CD0=GEe@3Cdm<00`3De=@0103AdM40dm?C0=CDe03Bd]820=KFeP030=OG
e`3Hf=P0e]KF00D0e]KF00/0emOG0=KFeP3Fe]H0f=SH0=OGe`3Hf=P0emOG0=KFeP3De=@0d];B0=7A
d@020=;BdP030=3@d03?cll0clo?00@0cLg=00P0c<c<0<_;b`3;bl/0bl_;0<g=c@3;bl/0c/k>0<g=
c@h0b>3H000<0<SPf080>SXj00H0>3Ph038b<P0d=3@0>SXj03<c<`0k>c/203Ti>@0703@d=00n?Sh0
>c/k03Hf=P0o?cl0>SXj03Lg=`0203Hf=P0503dm?@16ATH0D51@055AD@1IFET00P1NGUh02`1PH600
JFUY07QhN021PH40Rh^;09:BTP2GUiL0VYZJ09bLW02PX:00WinO0080ZJVY00<0[Jf]0:^[Z`2_[jl0
0P2b/[803P2d];@0/K6a0;:b/P2c/k<0]kNg0;Bd]02f][H0];Bd0;Jf]P2g]kL0^;Rh0;:b/P2`/;00
[Zj^0P2WYjL02`2/[:`0]KFe0;Bd]02JVYX0Rh^;07UiN@1YJFT0DU9B0451@@0n?Sh0@4100080ADE5
0P1@D5002@1JFUX0M7Ad08j>SP2RXZ80R8R806m_K`1YJFT0IVIV06YZJP0206e]K@0<04m?C`0h>3P0
?Cdm0410@01DE5@0ATI607]kN`2EUID0HV9R04M7A`0m?Cd0<c<c0P0d=3@07@0_;bl0<30`02TY:@0]
;Bd0De=C06YZJP1PH600>SXj04M7A`1SHf<0BTY:03<c<`1YJFT0H61P03lo?`1RHV80Z:RX0:ZZZP28
R8P0L71`07]kN`24Q8@0EeMG03De=@0g=cL0Bd];05EEE@1JFUX0EeMG00<0@4100340EeMG07emO@23
Ph<0LW9b05UIF@1ZJVX0MGEe05=CD`1PH600CDe=06MWI`1TI6@0Hf=S06][J`2;Rh/0VYZJ09NGU`2C
Ti<0Q8B409VIV@2MWId0RHV907MgM`1^KVh0Ng]k0;2`/03Fe]H0e=CD0;jn_P1LG5`0GemO07EeM@1n
OWh0RXZ:0:f][@2DU9@0b/[:0;^k^`2GUiL0NGUi03Hf=P0d=3@0;Bd]03De=@0a<C40;bl_02h^;P0]
;Bd0<C4a0080=CDe0200>3Ph03Lg=`0l?3`0>3Ph038b<P0^;Rh0;Bd]02`/;00b<S80<c<c03De=@0i
>CT0=CDe03dm?@0f=SH0=cLg03@d=00`<300<C4a038b<P0j>SX0BTY:04A4A00k>c/0>CTi03/k>`0n
?Sh0A4A40410@019BDT0>c/k034a<@80<30`01d0;Rh^03Lg=`19BDT0E5AD05QHF00k>c/0CTi>05EE
E@1DE5@0BDU903Ti>@13@d<0B4Q804i>CP1KFe/0GUiN06=SH`1XJ6P0KVi^06][J`1_Kfl0L71`07If
MP1aLG40Lg=c079bLP1fMWH0LG5a07UiN@0207QhN00>07]kN`1oOgl0OWin07inOP1lO7`0Ph>308B4
Q022PX80OWin08B4Q027QhL0Ph>308Z:RP2<S8`208j>SP0708^;R`2ATI40TY:B09BDU02CTi<0T92@
08j>SP0208b<S00508V9R@25QHD0QHF508F5Q@26QXH00P1nOWh05@1jNWX0Ng]k07YjNP1iNGT0Ogmo
07inOP23Ph<0PX:208B4Q021PH40OGem07inOP21PH40S8b<08^;R`2=SHd0TI6A08n?S`2>SXh0UiNG
09RHV00209JFUP80Ti>C00T0SHf=096AT@2>SXh0Shn?092@T02DU9@0RHV908N7Q`28R8P00P2>SXh0
402DU9@0Ti>C09RHV02IVIT0T92@08Z:RP29RHT0Ph>306UYJ@0m?Cd0;bl_02TY:@0`<300<S8b02l_
;`0`<30302d];@0703<c<`0m?Cd0<30`02l_;`0d=3@0<C4a03<c<`0202l_;`0603De=@0f=SH0:b/[
03Ph>014A4@0=3@d0`0^;Rh08`0i>CT0@d=3055AD@1]KFd0ATI603dm?@18B4P0AdM7065QH@1EEED0
AdM704A4A00o?cl0A4A404U9B@0m?Cd0>3Ph05ADE01NGUh0>SXj02d];@0a<C40;Bd]03Hf=P0c<c<0
Bd];061PH02CTi<0Y:BT09fMW@2IVIT0UiNG09VIV@2MWId0T92@0080WinO01T0Vi^K09:BTP2FUYH0
UiNG09BDU02FUYH0Vi^K09VIV@2NWYh0W9bL09^KV`2LW9`0WIfM09^KV`2JVYX0Vi^K09NGU`2JVYX0
UiNG09bLW02HV9P0VYZJ09^KV`2GUiL0Vi^K0080V9RH00l0VYZJ09RHV02EUID0UYJF09VIV@2FUYH0
U9BD09FEU@2GUiL0Ti>C09RHV02EUID0UYJF09>CT`2EUID00P2BTY801@2ATI40UIFE09:BTP2ATI40
TY:B00@0T92@01H0TY:B08n?S`2ATI40Ti>C08b<S02:RXX0R8R808V9R@23Ph<0PH6107inOP1jNWX0
OWin08^;R`2MWId0ZZZZ0;bl_038b<P0c/k>0=?Cd`3EeMD0e]KF103GemL20=GEe@030=KFeP3De=@0
eMGE00@0dm?C00<0d=3@0=;BdP3Cdm<00P3Fe]H0103De=@0eMGE0=KFeP3Fe]H30=GEe@80e]KF00<0
emOG0=SHf03GemL00P3GemL04@3Fe]H0e=CD0=?Cd`3Bd]80dM7A0=;BdP3AdM40d=3@0=7Ad@3?cll0
c/k>0<g=c@3?cll0c/k>0<c<c03=cLd0c<c<00<0cLg=00<0c/k>0<SPf038h=P03038h=P000`0b>3H
0P0j>SX0100h>3P0=SHf03@d=00e=CD203Hf=P0=03/k>`0l?3`0>SXj0451@@0o?cl0@D510492@P0k
>c/0>SXj03@d=00l?3`0?Shn04E5A@0205ADE00C05QHF01KFe/0GEeM061PH01]KFd0O7al08:2PP2:
RXX0TY:B09FEU@2IVIT0WYjN0:BTY02OWil0YjNW0:RXZ02^[Zh0/[:b0:j^[P020;6a/@1E0;Fe]@2d
];@0/K6a0;6a/@2f][H0/[:b0;>c/`2d];@0]KFe0;Jf]P2b/[80/;2`0:n_[`2YZJT0YjNW0:^[Z`2a
/K40YZJV09nOW`2DU9@0R8R8096AT@1mOGd0Hf=S04U9B@15ADD0@D5104=3@`17AdL0C4a<055AD@1E
EED0JVYZ0861P@29RHT0WYjN0861P@1/K6`0J6QX06i^KP1ZJVX0HF5Q05QHF014A4@0@D5104a<C01F
EUH0?clo06IVIP2HV9P0MgMg051@D00h>3P09bLW02TY:@0U9BD0;Bd]02`/;00X:2P0<S8b059BDP1X
J6P0Hf=S03Ph>01?Cdl0ATI603De=@11@D40KVi^051@D00l?3`0EeMG09bLW02ZZZX0UiNG07]kN`1m
OGd0IVIV0492@P0h>3P0?3`l05YJFP1@D500DU9B04];B`0204E5A@0L05QHF020P800Ogmo07IfMP1Y
JFT0Fe]K05MGE`1BDU80E5AD04i>CP18B4P0D51@05YJFP1BDU80IfMW08j>SP2:RXX0SHf=08J6QP2:
RXX0XZ:R09JFUP25QHD0P820079bLP1gMgL0X:2P0;no_`80c/k>00T0RHV904i>CP1TI6@0M7Ad07Mg
M`2:RXX0UiNG0:b/[02k^k/00P2NWYh09P1`L700?3`l02/[:`0^;Rh0<c<c03Lg=`0a<C40;2`/02l_
;`0e=CD0=cLg03`l?00j>SX0=CDe03<c<`0a<C40:b/[02`/;00Y:BT0;Rh^02TY:@0`<300=cLg030`
<00g=cL0=CDe038b<P0c<c<0<C4a02h^;P0a<C40>SXj04=3@`0i>CT0=cLg03Ti>@0m?Cd0?clo0P15
ADD00`16ATH0A4A403Ph>00202d];@08030`<00g=cL0?3`l04I6AP1;Bd/0=CDe05ADE01?Cdl204i>
CP0@03Xj>P1;Bd/0D51@059BDP1KFe/0Hf=S061PH01ZJVX0Kfm_06UYJ@1cLg<0L71`07QhN01cLg<0
M7Ad07EeM@80MWIf00H0O7al07MgM`1kNg/0NWYj07QhN01lO7`207inOP0:08>3P`1mOGd0O7al07mo
O`25QHD0Q8B408^;R`2@T900RXZ:096AT@80Shn?00X0UIFE09JFUP2BTY80TI6A08n?S`2=SHd0RXZ:
08f=S@28R8P0QHF50P21PH400`25QHD0OGem07]kN`0207alO00;07YjNP1iNGT0PX:208:2PP25QHD0
PH610820P01mOGd0P8200861P@2>SXh00P2?Shl01P2@T900UIFE09VIV@2EUID0VIVI09fMW@80WYjN
00d0VIVI09FEU@2@T900TY:B08j>SP2HV9P0UiNG09ZJVP2?Shl0QhN70861P@2<S8`0Shn?0080T92@
0P2EUID0=02FUYH0Shn?08f=S@28R8P0P82005ADE00^;Rh0<S8b02/[:`0Y:BT0:2PX030`<00Z:RX0
<30`02l_;`0`<300>SXj02l_;`0^;Rh0<S8b02XZ:P0`<300;Rh^02HV9P0_;bl0=CDe02d];@0g=cL0
Bd];03Ti>@0a<C40;Rh^02XZ:P0k>c/0@410059BDP1]KFd0CTi>03hn?P1ADE40C4a<05eMG@1OGel0
ATI60410@00l?3`0@41004Q8B00j>SX0@D5105aLG01EEED2034a<@0>03@d=00_;bl0=SHf038b<P1B
DU80GUiN09:BTP2VYZH0WinO09FEU@2ATI40UiNG09nOW`2@T90209nOW`0709ZJVP2CTi<0TY:B09JF
UP2GUiL0TY:B09VIV@0309bLW00509^KV`2MWId0W9bL09fMW@2NWYh00P2LW9`01`2QXJ40WIfM09^K
V`2HV9P0VIVI09NGU`2HV9P00P2GUiL0402EUID0V9RH09RHV02HV9P0VIVI09NGU`2DU9@0UIFE09JF
UP2GUiL0V9RH09bLW02DU9@0UIFE09BDU02?Shl209:BTP0708n?S`2EUID0SXj>09FEU@2CTi<0Shn?
096AT@02092@T00H096AT@2BTY80SHf=08f=S@29RHT0R8R808B4Q028R8P0PX:207emO@1nOWh0NGUi
07inOP2<S8`0WIfM0:b/[02h^;P0a<C40<g=c@3?cll0eMGE0=?Cd`3Hf=P0emOG0`3Fe]H0103EeMD0
dm?C0=?Cd`3De=@30=;BdP090=?Cd`3Bd]80eMGE0=KFeP3Cdm<0e]KF0=?Cd`3EeMD0e]KF0080eMGE
00<0e]KF0=GEe@3De=@00P3De=@0203EeMD0e]KF0=OGe`3Fe]H0emOG0=CDe03Fe]H0dm?C0P3De=@0
3`3Bd]80dM7A0=3@d03Bd]80c/k>0=3@d03Cdm<0c/k>0<c<c03=cLd0c/k>0<o?c`3=cLd0clo?0<g=
c@0>0<SPf0003038h=P203De=@0=03Ti>@0j>SX0=cLg03Hf=P0k>c/0?Cdm03/k>`0n?Sh0>CTi0410
@00j>SX0>c/k03hn?P020410@00603Lg=`0e=CD0?Cdm04E5A@1DE5@0EeMG0P1KFe/0301RHV80Hf=S
06e]K@1hN7P0OWin08^;R`2BTY80W9bL09ZJVP2MWId0WinO0::RXP80Z:RX00<0ZJVY0:n_[`2`/;00
0P2`/;002`2_[jl0/k>c0;:b/P2[Zj/0/K6a0;Fe]@2f][H0/[:b0;Ng]`2d];@0/K6a0080[Zj^00D0
ZJVY0:JVYP2SXj<0YJFU09bLW00208:2PP0608N7Q`2ATI40T92@07alO01LG5`0Bd];0P17AdL02P19
BDT0C4a<04e=C@1DE5@0Fe]K06a/K022PX80UiNG092@T01[Jf/206QXJ00506a/K01RHV80J6QX05EE
E@11@D400P1:BTX01`0f=SH0Cdm?08b<S023Ph<0ATI604=3@`0];Bd00P0W9bL07@0^;Rh0<c<c02DU
9@0Z:RX0@T9206IVIP1SHf<0ADE504I6AP0k>c/0>CTi055AD@1/K6`0?clo02h^;P12@T80UiNG0;6a
/@2KVi/0PH6106i^KP1?Cdl0<C4a02`/;012@T80DE5A05MGE`1IFET0FUYJ0080K6a/0P1iNGT02P1[
Jf/0GEeM05aLG01RHV80B4Q803`l?01DE5@0>SXj04=3@`1JFUX2061PH00O06UYJ@2<S8`0P82008F5
Q@22PX80TY:B09^KV`2EUID0R8R808F5Q@1gMgL0M7Ad08j>SP2LW9`0`L710=7Ad@2i^KT0JFUY05EE
E@1/K6`0Lg=c079bLP22PX80XZ:R0:JVYP2d];@0[Jf]0::RXP1`L700<S8b02l_;`0203<c<`0602/[
:`0a<C40=CDe03De=@0a<C40<c<c0P0e=CD03@0b<S80;bl_02`/;00`<300:2PX02l_;`0[:b/0<c<c
03`l?00f=SH0=CDe03Ti>@0a<C400P0/;2`01P0_;bl0=SHf03`l?00j>SX0>CTi0492@P<0?clo00D0
ATI604a<C013@d<0?clo02d];@0202TY:@0I02XZ:P0h>3P0@D51055AD@18B4P0=CDe05]KF`1ADE40
EeMG059BDP0k>c/0ADE504i>CP1GEeL0FUYJ06EUI@1YJFT0JVYZ071`L01cLg<0MWIf075aL@1gMgL0
N7Qh07IfMP0207MgM`0H07IfMP1iNGT0OWin07IfMP1kNg/0NGUi0820P01kNg/0PH6108J6QP1nOWh0
P82008>3P`28R8P0QHF508R8R02@T900R8R8096AT@2@T900Shn?09:BTP2GUiL0UYJF0P2CTi<0402@
T900RXZ:08^;R`2:RXX0QXJ607inOP1lO7`0Ng]k07YjNP1gMgL0O7al0820P023Ph<0PX:207moO`26
QXH207inOP80P82000/0OWin08>3P`2@T900U9BD09RHV02FUYH0VIVI09fMW@2OWil0XZ:R0:RXZ002
0:>SX`0D09ZJVP2LW9`0V9RH0:2PX02NWYh0YjNW0:BTY02SXj<0X:2P09:BTP24Q8@0RXZ:096AT@2@
T900SXj>09NGU`2FUYH0UiNG09:BTP2@T90208Z:RP0?07EeM@0l?3`0:RXZ02XZ:P0`<3009bLW02l_
;`0/;2`0;bl_02`/;00_;bl0@d=3038b<P0_;bl0=3@d0080;2`/00P0:b/[02XZ:P0X:2P0<C4a02h^
;P0k>c/0AdM703`l?080;2`/00/0:RXZ03Hf=P0i>CT0DE5A071`L01<C4`0@T9205EEE@1ADE40F5QH
05EEE@0204U9B@0D0410@00i>CT0@d=303`l?01:BTX0F5QH05UIF@0h>3P0;bl_030`<00];Bd0;2`/
03<c<`1@D500H61P09JFUP2XZ:P0W9bL09>CT`2=SHd209RHV00;09BDU02NWYh0WYjN09ZJVP2@T900
UYJF09VIV@2FUYH0U9BD09NGU`2MWId00P2OWil209^KV`0=09nOW`2JVYX0VYZJ09ZJVP2KVi/0W9bL
09VIV@2MWId0UiNG09VIV@2KVi/0UIFE09ZJVP0209JFUP0409VIV@2HV9P0V9RH09fMW@80U9BD00d0
VIVI09FEU@2CTi<0UIFE09NGU`2FUYH0Ti>C09NGU`2?Shl0Ti>C09:BTP2>SXh0T92@0080TY:B01d0
U9BD092@T02ATI40S8b<092@T02?Shl0U9BD08f=S@2;Rh/0SXj>08R8R02:RXX0QHF508:2PP21PH40
Ph>307UiN@1lO7`0SXj>09jNWP2/[:`0^;Rh0<C4a03;bl/0c/k>0=;BdP3EeMD0emOG0=SHf0030=GE
e@030=CDe03Cdm<0d];B00<0eMGE0P3AdM430=?Cd`80d];B00<0dm?C0=CDe03Fe]H00P3De=@0103C
dm<0e=CD0=?Cd`3Fe]H20=GEe@80f=SH00<0eMGE0=KFeP3EeMD0103EeMD0203De=@0d];B0=7Ad@3A
dM40d];B0=7Ad@3Cdm<0clo?0P3@d=040<o?c`030=3@d038h=P0b>3H00`0b>3H000<0<SPf080=CDe
00T0>3Ph03Lg=`0k>c/0=cLg03Ph>011@D40>CTi03lo?`10@4000P14A4@06P0j>SX0@D5103lo?`11
@D40=3@d03/k>`0o?cl0BDU904e=C@1CDe<0E5AD05eMG@1LG5`0HV9R071`L01jNWX0Q8B408Z:RP2C
Ti<0UYJF09^KV`2MWId0XJ6Q0:2PX02TY:@0[Zj^0`2_[jl20;6a/@060;Bd]02c/k<0[jn_0;2`/02g
]kL0/K6a0P2e]KD05P2f][H0];Bd0;>c/`2c/k<0[Zj^0:FUY@2XZ:P0X:2P09ZJVP2HV9P0RHV907em
O@1kNg/0RHV909>CT`2FUYH0QHF506ATI01:BTX0BDU904Q8B01<C4`205=CD`0=05EEE@1SHf<0PH61
08j>SP2KVi/0MGEe06IVIP1WIfL0M7Ad06][J`1VIVH0I6AT03lo?`020410@008038b<P10@400L71`
07inOP11@D40?Shn03`l?00^;Rh202HV9P0J038b<P0Y:BT09bLW03<c<`1ADE40IfMW055AD@0m?Cd0
>3Ph03Xj>P1NGUh0J6QX03@d=00];Bd0ATI608n?S`2f][H0U9BD08F5Q@1]KFd0ATI603`l?00d=3@0
BDU9055AD@1LG5`206a/K080MgMg02`0MGEe06a/K01KFe/0EEEE05aLG01NGUh0Bd];03dm?@0n?Sh0
=cLg04i>CP1OGel0L71`06=SH`1]KFd0Ph>307alO024Q8@0Ogmo08n?S`2KVi/0U9BD08j>SP27QhL0
PH6107AdM01gMgL0PX:20:b/[03AdM40b/[:09VIV@1]KFd0Fe]K06YZJP1bLW80JVYZ08f=S@2EUID0
[Zj^0;jn_P2l_;`0ZZZZ05IFEP80;Rh^02D0=cLg03Ti>@0f=SH0>SXj03Lg=`0e=CD0<c<c03Hf=P0b
<S80=SHf02LW9`0[:b/0<C4a02d];@0_;bl0;Bd]03Hf=P0n?Sh0<30`03`l?00f=SH0:b/[02`/;00^
;Rh0<S8b03Hf=P0k>c/0=CDe03dm?@12@T80=SHf03lo?`13@d<0A4A404i>CP18B4P0>SXj00<0;Rh^
02T0<C4a03Ph>017AdL0EeMG04A4A00h>3P0EUIF051@D01CDe<0D51@04=3@`12@T80B4Q805=CD`1G
EeL0H61P06MWI`1^KVh0L71`075aL@1eMGD0Kfm_07AdM01lO7`0MWIf07QhN01lO7`0NWYj07alO01i
NGT0OWin07]kN`1nOWh0PH6107moO`20P800Ph>307moO`21PH40QXJ608^;R`0208Z:RP0509BDU02?
Shl0Shn?096AT@2@T9000P2BTY8209BDU00P096AT@29RHT0RHV908F5Q@23Ph<0PX:207alO01nOWh0
P82007inOP1gMgL0PH6108:2PP23Ph<0OWin07IfMP1hN7P0NWYj07inOP1mOGd0QHF50861P@26QXH0
Ti>C09fMW@2LW9`0X:2P09nOW`2VYZH0/k>c0:f][@2d];@20;>c/`0N0:>SX`2VYZH0[jn_0;Vi^@2a
/K40^[Zj0;^k^`2e]KD0[jn_09FEU@29RHT0Ph>308f=S@2;Rh/0SXj>08n?S`2GUiL0VYZJ09JFUP2=
SHd0Rh^;08V9R@26QXH0Fe]K03De=@0/;2`0<30`02l_;`0^;Rh0:RXZ0P0^;Rh01P0_;bl0=SHf038b
<P0e=CD0=cLg02l_;`80:RXZ0100:BTY02`/;00h>3P0=CDe03`l?00i>CT0?Shn030`<00d=3@0<c<c
03Hf=P15ADD0CTi>06a/K01=CDd0?Cdm0P1>CTh03P1?Cdl0DU9B04Y:BP0n?Sh0>CTi03De=@12@T80
C4a<03`l?01JFUX0EEEE03Ph>00/;2`0:b/[0P0^;Rh02`0_;bl0CTi>06QXJ02NWYh0Xj>S09nOW`2>
SXh0R8R809jNWP2CTi<0T92@0080Vi^K00<0VIVI08n?S`2CTi<00`2GUiL03P2HV9P0WIfM09nOW`2L
W9`0WIfM09bLW02IVIT0W9bL09fMW@2KVi/0UiNG09bLW02KVi/0UiNG0P2FUYH01`2JVYX0UYJF09ZJ
VP2LW9`0U9BD09>CT`2KVi/00`2GUiL0102HV9P0UIFE09:BTP2BTY8209NGU`0308j>SP2DU9@0U9BD
0080U9BD00d0Ti>C09:BTP2>SXh0Shn?092@T02GUiL0UIFE08j>SP2@T900S8b<08n?S`2BTY80RXZ:
0080Shn?0140SXj>08J6QP28R8P0Ph>307moO`1kNg/0NWYj07alO02?Shl0WIfM0:^[Z`2f][H0`<30
0<W9b@3=cLd0dm?C0=CDe0040=GEe@050=7Ad@3De=@0e=CD0=?Cd`3De=@00P3EeMD03@3@d=00dm?C
0=;BdP3Cdm<0eMGE0=;BdP3Cdm<0e=CD0=GEe@3De=@0dm?C0=CDe03EeMD00`3De=@20=GEe@@0emOG
00@0e=CD0=OGe`3De=@0e]KF0P3EeMD0103De=@0dm?C0=CDe03De=@20=7Ad@050=?Cd`3Bd]80dm?C
0=;BdP3AdM400P3Bd]800`3?cll0b>3H0<SPf00<0<SPf0003038h=P203Ti>@0303/k>`0h>3P0?clo
0080>CTi02<0?3`l03/k>`0o?cl0?Cdm03`l?013@d<0AdM703lo?`16ATH0?Cdm03Xj>P0h>3P0ADE5
04=3@`1>CTh0EEEE059BDP1OGel0GUiN06=SH`1]KFd0NGUi08F5Q@2<S8`0Ti>C09RHV02LW9`0WIfM
0:6QX@2SXj<0YZJV0:^[Z`2^[Zh0[:b/0;6a/@020:n_[`80/K6a00<0/[:b0;>c/`2d];@00P2d];@0
:02f][H0^;Rh0;Ng]`2d];@0/k>c0:j^[P2/[:`0Y:BT09nOW`2NWYh0UiNG08Z:RP1nOWh0NGUi07Qh
N025QHD0U9BD0:6QX@22PX80GemO04e=C@1<C4`0Bd];05ADE01BDU80EUIF05aLG01`L700QHF509RH
V02=SHd0L71`075aL@1eMGD0LW9b069RHP1SHf<0E5AD04A4A015ADD203hn?P0T05ADE01TI6@0Bd];
03`l?013@d<0<c<c02XZ:P0W9bL0=3@d02`/;00Z:RX0;bl_04E5A@1SHf<0C4a<03`l?00m?Cd0>SXj
065QH@1MGEd0;bl_03De=@0m?Cd0R8R80;Bd]02FUYH0QHF506QXJ01:BTX0>CTi03/k>`1;Bd/0GemO
06e]K@1^KVh0JFUY0P1/K6`02`1[Jf/0G5aL055AD@1=CDd0EEEE06ATI01FEUH0?3`l03/k>`0m?Cd0
DU9B0080Lg=c03<0E5AD07AdM01`L700N7Qh0861P@1kNg/0Ti>C09fMW@2GUiL0Rh^;08F5Q@26QXH0
Ng]k075aL@1iNGT0YJFU0=SHf03Cdm<0^KVi09BDU01/K6`0GUiN06YZJP1WIfL0KVi^07YjNP22PX80
^k^k0;Zj^P2n_[h0WinO0451@@0d=3@0;2`/03Hf=P0b<S80;Bd]03@d=00g=cL0=3@d03Ph>00`<300
;Rh^02`/;00W9bL0:RXZ02HV9P0^;Rh0<S8b03Xj>P0f=SH00P0h>3P04P0Z:RX0:b/[02`/;00c<c<0
<S8b0451@@10@400<S8b03Hf=P12@T80?3`l03Ph>00k>c/0@T9204U9B@0n?Sh0<C4a02XZ:P80;Bd]
0140<S8b03Xj>P1=CDd0GEeM04Y:BP0n?Sh0EUIF05ADE01>CTh0De=C04a<C018B4P0CDe=05QHF01P
H600HF5Q06][J`0207=cL`0507IfMP1eMGD0LG5a07IfMP1oOgl00P1fMWH0301iNGT0MgMg08:2PP1j
NWX0P82007]kN`1lO7`0Q8B40820P01oOgl0Ph>30861P@80QhN70P2;Rh/2096AT@0309JFUP2CTi<0
TI6A0080TI6A00D0T92@09RHV02EUID0Shn?08b<S00208B4Q00A08F5Q@20P800OGem07inOP21PH40
Ogmo07inOP22PX80OWin07alO01hN7P0MgMg07YjNP20P800OWin0820P029RHT00P28R8P02@2FUYH0
VIVI09jNWP2[Zj/0][Jf0;Vi^@2l_;`0/K6a0;jn_P020<71`@0;0;Bd]02i^KT0b/[:0<K6aP35aLD0
bl_;0<[:bP34a<@0/[:b0:>SX`2>SXh00`27QhL03026QXH0SXj>09BDU02?Shl0V9RH08j>SP2<S8`0
R8R808>3P`1hN7P0@d=302h^;P80:b/[00/0:BTY02`/;00_;bl0<C4a03De=@0b<S80<c<c03De=@0f
=SH0;2`/02TY:@0202XZ:P0/02PX:00g=cL0<c<c03Ti>@0a<C40=3@d03Hf=P0^;Rh0<c<c03Ph>010
@400Bd];06IVIP1;Bd/0@d=304Y:BP1>CTh0C4a<05=CD`1;Bd/0>3Ph03Hf=P0`<300=cLg04E5A@17
AdL0FUYJ04a<C00d=3@09RHV02TY:@0b<S80:b/[038b<P1?Cdl0I6AT09bLW02VYZH0WinO08>3P`2<
S8`0WinO09:BTP2>SXh309RHV007092@T02EUID0UYJF09JFUP2EUID0V9RH09ZJVP0309bLW00@09nO
W`2LW9`0W9bL09^KV`2EUID0UYJF09^KV`2IVIT0Vi^K09VIV@2EUID0VYZJ09JFUP2KVi/0V9RH09^K
V`80UiNG00H0UYJF09BDU02EUID0UIFE09^KV`2CTi<209FEU@0C09>CT`2DU9@0VYZJ09JFUP2CTi<0
Shn?09>CT`2BTY80Ti>C092@T02CTi<0UYJF09BDU02CTi<0TI6A09:BTP2CTi<0T92@08n?S`0208j>
SP0H08R8R024Q8@0Q8B408J6QP25QHD0PX:207]kN`21PH40S8b<09RHV02UYJD0][Jf0;jn_P38b<P0
bl_;0<o?c`3EeMD0e=CD0=?Cd`3EeMD0e]KF0=;BdP3De=@0dm?C0P3Bd]820=?Cd`D0d];B00L0dM7A
0=?Cd`3Cdm<0d];B0=3@d03Bd]80dm?C0080e=CD0`3Cdm<00`3EeMD0dm?C0=OGe`020=CDe0050=GE
e@3GemL0eMGE0=OGe`3EeMD00P3De=@0203EeMD0e=CD0=CDe03Cdm<0eMGE0=?Cd`3Bd]80dm?C0P3B
d]800`3De=@0d=3@0=3@d00>0<SPf0003038h=P203Ph>00803De=@0l?3`0?clo03Xj>P0m?Cd0=3@d
03hn?P0i>CT203dm?@070410@00n?Sh0?clo03/k>`0m?Cd0?3`l03/k>`0204U9B@0E04m?C`1GEeL0
De=C05mOG`1NGUh0IfMW07=cL`1oOgl0QhN708b<S02BTY80UiNG09ZJVP2MWId0YjNW0:FUY@2VYZH0
Zj^[0;6a/@2`/;00/K6a0080[Zj^02L0/;2`0;Bd]02a/K40/;2`0;>c/`2g]kL0^KVi0;Fe]@2f][H0
^;Rh0;Fe]@2a/K40[:b/0:VYZ@2UYJD0W9bL09fMW@2EUID0SXj>0820P01fMWH0Kfm_06][J`22PX80
YJFU09bLW020P800IFEU051@D01=CDd0D51@055AD@1EEED0EeMG06e]K@1oOgl0S8b<09RHV01kNg/0
0P1fMWH0;01eMGD0I6AT05eMG@1;Bd/0?clo04E5A@12@T80=SHf04];B`1ADE40?3`l02h^;P0h>3P0
>CTi02d];@0S8b<0=3@d02l_;`0^;Rh0<C4a0410@01QHF40CDe=03Lg=`0d=3@0ATI6069RHP12@T80
>3Ph034a<@0o?cl0RHV90;2`/02EUID0QhN706m_K`1?Cdl0>CTi05ADE01EEED0HF5Q06IVIP1YJFT0
IVIV0P1]KFd2069RHP0>05mOG`1EEED0F5QH065QH@1FEUH0?Shn03/k>`10@400JFUY07UiN@1DE5@0
>SXj06ATI01MGEd207YjNP0S08B4Q02KVi/0W9bL09FEU@29RHT0QXJ608N7Q`20P800MGEe07alO02b
/[80gMgM0=[JfP3<c<`0[:b/096AT@1OGel0GEeM06i^KP1VIVH0IFEU06m_K`2?Shl0[jn_0;Jf]P2m
_Kd0OGem03Ti>@0a<C40;Bd]03<c<`0`<300=cLg03Ti>@0f=SH00`0e=CD0700];Bd0<C4a02LW9`0W
9bL0=3@d0492@P0h>3P0?3`l03Ph>00b<S80:b/[02d];@0`<300<c<c03`l?010@400?3`l0410@00j
>SX0@T9203Hf=P0j>SX0?3`l04I6AP1>CTh0ADE5030`<00b<S83034a<@0803Lg=`1FEUH0GUiN0451
@@13@d<0BTY:05=CD`1DE5@2051@D00>05=CD`1?Cdl0HV9R06=SH`1VIVH0L71`07AdM01cLg<0MWIf
07=cL`1hN7P0O7al07inOP1jNWX307]kN`0507moO`1jNWX0Ogmo07moO`22PX800P1oOgl01@25QHD0
PX:208R8R02:RXX0RHV90080S8b<00l0TY:B092@T02DU9@0TI6A09:BTP2?Shl0U9BD096AT@2DU9@0
Ti>C08j>SP2<S8`0PH6108J6QP1nOWh00P1lO7`0201nOWh0OGem08:2PP23Ph<0OWin07alO01kNg/0
MWIf0P1jNWX03`24Q8@0QhN708>3P`2<S8`0R8R808N7Q`2:RXX0Ti>C09nOW`2TY:@0Z:RX0:VYZ@2b
/[80[Jf]0;>c/`020;Ng]`040:^[Z`2a/K40alO70<71`@80b<S802/0`/;20<G5a@2d];@0YJFU09>C
T`2=SHd0QHF508V9R@2>SXh0Shn?08f=S@2BTY80UIFE08n?S`2>SXh0T92@08R8R025QHD0IFEU03/k
>`0];Bd0;Rh^02`/;00b<S80;Rh^03@d=00[:b/0=SHf03<c<`0`<300<S8b03Hf=P0_;bl0<30`02h^
;P0[:b/0;Bd]03<c<`0m?Cd0<c<c03Ph>012@T80=3@d0080>3Ph0280?3`l04];B`1KFe/0Bd];04=3
@`1?Cdl0AdM704];B`1HF5P0C4a<0451@@13@d<0>c/k03Lg=`0i>CT0DE5A05mOG`15ADD0=3@d02DU
9@0X:2P0<30`02h^;P0b<S80De=C06YZJP2HV9P0YZJV09jNWP21PH40Rh^;0:6QX@2=SHd0Shn?0`2I
VIT08`2@T900U9BD09BDU02IVIT0UIFE09BDU02OWil0WIfM09^KV`2LW9`0Vi^K09RHV02IVIT0UiNG
09RHV02FUYH0UIFE09fMW@2LW9`0UYJF09NGU`2LW9`0VYZJ09NGU`2DU9@0V9RH09^KV`2FUYH0UiNG
09>CT`2DU9@0TY:B09JFUP2DU9@0Ti>C0080TI6A00<0UIFE092@T02DU9@00P2CTi<0202BTY80TI6A
08j>SP2>SXh0U9BD09FEU@2CTi<0T92@0P2>SXh00`2EUID0TY:B08j>SP0208Z:RP0608V9R@2:RXX0
QXJ60861P@23Ph<0O7al0P1mOGd01P29RHT0UYJF0:RXZ02c/k<0_kno0<G5a@80bl_;00@0dM7A0=SH
f03Cdm<0d];B0P3De=@00`3Fe]H0e=CD0=?Cd`050=;BdP030=?Cd`3Bd]80d];B00<0dm?C0`3Bd]80
203Cdm<0d];B0=CDe03Cdm<0eMGE0=KFeP3EeMD0emOG0P3Fe]H01@3Hf=P0eMGE0=GEe@3Fe]H0emOG
0080e]KF00D0e=CD0=GEe@3De=@0eMGE0=;BdP040=?Cd`<0e=CD00<0d];B0=?Cd`38h=P03@38h=P0
00`0b>3H0`0f=SH00`0j>SX0=cLg03Ph>00303/k>`0I0410@00j>SX0>c/k0492@P0n?Sh0@T9203hn
?P0l?3`0?Cdm03Ti>@12@T80A4A404Y:BP1LG5`0Fe]K05mOG`1EEED0JVYZ07IfMP1lO7`0QXJ608j>
SP2CTi<0VIVI09ZJVP020:6QX@050:NWY`2YZJT0Zj^[0:n_[`2c/k<00`2_[jl01`2c/k<0[Zj^0;2`
/02b/[80/k>c0;2`/02e]KD00P2f][H0402a/K40]KFe0;:b/P2^[Zh0ZJVY0::RXP2MWId0Vi^K09BD
U02:RXX0PH6107AdM01YJFT0G5aL06ATI01mOGd209^KV`0<07]kN`1LG5`0DE5A04e=C@1?Cdl0EUIF
05]KF`1OGel0LW9b08N7Q`2DU9@0T92@0P1jNWX0;01kNg/0IfMW05eMG@15ADD0=SHf04U9B@17AdL0
>c/k0451@@15ADD0=cLg02XZ:P0/;2`0>SXj03Ph>00_;bl0>3Ph03/k>`0^;Rh0=CDe0410@01FEUH0
ADE503Ph>00k>c/0BTY:06IVIP0j>SX0>CTi038b<P0j>SX0Q8B40:FUY@2CTi<0S8b<06a/K01<C4`0
Cdm?06=SH`1OGel0I6AT05eMG@1QHF40F5QH0P1UIFD0DP1RHV80Jf][06m_K`1YJFT0HF5Q05mOG`1U
IFD0E5AD05aLG01CDe<0K6a/06IVIP0l?3`0?Cdm06=SH`18B4P0IVIV06QXJ020P800UYJF09VIV@2A
TI40SHf=08>3P`26QXH0Ogmo07]kN`2ATI40dM7A0>?Sh`3Ogml0e=CD0<71`@2UYJD0O7al05UIF@1Y
JFT0Kfm_05]KF`1OGel0Lg=c092@T02QXJ40alO70;Ng]`1EEED0:2PX02XZ:P0_;bl0<C4a03Xj>P0c
<c<0=3@d03Lg=`0b<S80;bl_02d];@0/;2`09BDU02XZ:P0k>c/0>CTi0492@P0k>c/0?Shn02h^;P0Y
:BT0<30`034a<@0c<c<0?Cdm03Ti>@10@400>3Ph0451@@10@400<S8b03/k>`15ADD0BTY:051@D012
@T8202`/;080:2PX00d0;2`/03@d=01=CDd0IfMW0492@P1:BTX0DE5A05UIF@1FEUH0C4a<04m?C`1@
D500EUIF0080HV9R00@0IFEU075aL@1cLg<0MGEe0P1hN7P00`1nOWh0Ng]k0861P@0207YjNP0607]k
N`1lO7`0OWin07inOP20P800OWin0P1oOgl01@25QHD0QhN708F5Q@26QXH0Rh^;0080RHV900@0RXZ:
09:BTP2ATI40UIFE102CTi<01@2<S8`0T92@08b<S02:RXX0QhN700<0P82000H0OGem07moO`1oOgl0
O7al0820P01kNg/207QhN00C07]kN`1hN7P0NWYj07emO@20P800QhN708>3P`29RHT0QHF508:2PP25
QHD0S8b<09BDU02ATI40Shn?08f=S@2ATI40V9RH09VIV@0209ZJVP1E09VIV@2OWil0ZJVY0:RXZ02d
];@0/;2`0;>c/`2f][H0[Jf]0:>SX`2BTY80RXZ:08J6QP22PX80QhN708j>SP2@T900Ti>C09:BTP2@
T900Shn?09BDU02>SXh0S8b<07emO@1<C4`0<S8b02`/;00Z:RX0;Rh^038b<P0];Bd0<30`034a<@0]
;Bd0>3Ph03`l?00];Bd0;Rh^034a<@0^;Rh0<S8b02l_;`0c<c<0?3`l03dm?@0n?Sh0CTi>03lo?`0c
<c<0>SXj03Ti>@16ATH0H61P04Y:BP15ADD0Bd];059BDP19BDT0De=C05EEE@1>CTh0ADE5030`<00b
<S80>c/k04e=C@1QHF40?Cdm038b<P0a<C40<S8b02h^;P0Y:BT0<30`04e=C@1[Jf/0UIFE0:>SX`2I
VIT0O7al08N7Q`2SXj<0SHf=092@T00209^KV`0409NGU`2@T900U9BD09BDU080UiNG00H0UIFE09fM
W@2MWId0W9bL09^KV`2LW9`209VIV@0=09NGU`2DU9@0VIVI09fMW@2FUYH0Vi^K09VIV@2GUiL0TY:B
09NGU`2HV9P0UYJF09RHV00209VIV@0809FEU@2ATI40U9BD09:BTP2DU9@0TY:B096AT@2>SXh2092@
T004096AT@2EUID0Ti>C09:BTP80U9BD00@0Ti>C092@T02BTY80SXj>0P2CTi<01P2ATI40Shn?08j>
SP2@T900UYJF092@T080Rh^;01@0SXj>08R8R025QHD0Ph>307moO`1kNg/0O7al08b<S02IVIT0YJFU
0;6a/@2k^k/0a<C40<S8b03;bl/0c/k>0=7Ad@3De=@0dm?C0=KFeP80e=CD00<0eMGE0=?Cd`3De=@0
0P3Bd]80103@d=00dm?C0=3@d03Cdm<20=;BdP090=7Ad@3Bd]80d=3@0=3@d03AdM40e]KF0=?Cd`3>
c/h0e=CD0080dm?C00@0d=3@0=?Cd`3Fe]H0e]KF0P3De=@20=GEe@040=KFeP3EeMD0eMGE0=KFeP80
e=CD00<0eMGE0=CDe03De=@01@3Cdm<00`3De=@0dm?C0=?Cd`0>0<SPf0003038h=P203<c<`0703Xj
>P0i>CT0=SHf03hn?P0j>SX0>c/k03lo?`0203dm?@0;0492@P15ADD0AdM70492@P0o?cl0@D5103hn
?P10@400@d=30451@@1:BTX00P1IFET02`1GEeL0FUYJ06IVIP1_Kfl0NWYj08J6QP2>SXh0UYJF09FE
U@2JVYX0WYjN0080YJFU00<0ZJVY0:^[Z`2^[Zh00P2_[jl20:b/[00h0;>c/`2_[jl0[jn_0;6a/@2_
[jl0/k>c0;Fe]@2f][H0];Bd0;Ng]`2f][H0];Bd0:ZZZP2YZJT0XJ6Q0:2PX02JVYX0T92@08f=S@25
QHD0N7Qh075aL@1IFET0EEEE05YJFP1eMGD0X:2P09RHV01aLG40HV9R05IFEP1>CTh0De=C059BDP1L
G5`0IFEU08B4Q02<S8`0Ti>C08V9R@1kNg/0Ogmo06m_K`1DE5@0?Cdm02l_;`0n?Sh0E5AD03Xj>P0h
>3P0?clo03Ph>00b<S809RHV02/[:`13@d<203`l?00D03Ti>@0j>SX0>c/k04M7A`1HF5P0AdM703@d
=00g=cL0FEUI05EEE@0o?cl0?Cdm03`l?00m?Cd0O7al09RHV020P800T92@06i^KP1SHf<206ATI080
Hf=S00<0GUiN05UIF@1XJ6P00P1fMWH05`1]KFd0JVYZ06=SH`1LG5`0EEEE05iNGP1]KFd0OGem08N7
Q`1gMgL0EUIF04Y:BP16ATH0@T92059BDP0h>3P0BDU905=CD`1_Kfl0PX:208j>SP2ATI40T92@0080
QXJ603T0Q8B407alO02`/;00f][J0>7Qh@3Ph>00eMGE0<k>cP2l_;`0VYZJ06a/K01MGEd0JVYZ05mO
G`1EEED0Hf=S07EeM@2EUID0^[Zj0<O7a`2OWil0?3`l02`/;00Y:BT0<30`02/[:`0b<S80<30`02h^
;P0d=3@0<30`02`/;00b<S80:2PX02TY:@0a<C40=CDe04=3@`0n?Sh0?3`l02d];@0[:b/0<30`02XZ
:P0d=3@0?Cdm03Hf=P0j>SX0>3Ph03`l?00o?cl0>3Ph03lo?`12@T80AdM7051@D00n?Sh00P0[:b/2
03<c<`0702l_;`0b<S80DU9B071`L00i>CT0DE5A05MGE`0205IFEP0F04U9B@1=CDd0CTi>05]KF`1P
H600IFEU06IVIP1`L700LG5a07IfMP1iNGT0N7Qh07alO01iNGT0Q8B407YjNP1iNGT0NWYj07inOP20
P800OWin0820P080Ph>30P22PX802P2<S8`0R8R808J6QP26QXH0QhN708F5Q@2;Rh/0Ti>C09JFUP2A
TI4209BDU00@092@T02BTY80Shn?08Z:RP23Ph<0PH610820P021PH40OGem0861P@1nOWh0O7al07=c
L`1dM7@0Kfm_06a/K080KVi^00H0LW9b07EeM@1bLW80MGEe07YjNP1nOWh207alO00;0861P@1nOWh0
P8200861P@22PX80OWin07emO@1kNg/0PH6107moO`20P8000P1nOWh03`22PX80QhN708^;R`2@T900
U9BD09>CT`2EUID0Vi^K09jNWP2KVi/0R8R808J6QP22PX80PH6108N7Q`0308Z:RP0;08f=S@2;Rh/0
Shn?096AT@2BTY80SHf=08V9R@1eMGD0>3Ph030`<00];Bd00P0_;bl0=P0d=3@0;Rh^038b<P0`<300
=cLg03/k>`0d=3@0;bl_02h^;P0_;bl0<C4a038b<P0c<c<0?3`l03Xj>P0i>CT0AdM704Q8B00h>3P0
=cLg03Ph>014A4@0Fe]K04Q8B01<C4`0BDU904a<C01;Bd/0De=C05EEE@19BDT0>CTi034a<@0h>3P0
?Shn05eMG@1QHF40?clo02l_;`0Z:RX0;2`/02l_;`0[:b/0=3@d055AD@1iNGT0UiNG0:>SX`2@T900
NGUi08b<S02RXZ80R8R8092@T080V9RH00X0UIFE08j>SP2FUYH0TY:B09JFUP2GUiL0Ti>C09fMW@2N
WYh0WIfM0P2JVYX01`2LW9`0V9RH09jNWP2GUiL0UIFE09RHV02IVIT00P2HV9P03`2EUID0VYZJ09FE
U@2HV9P0UYJF09NGU`2JVYX0W9bL09FEU@2CTi<0U9BD096AT@2CTi<0U9BD092@T00209:BTP0509BD
U02FUYH0U9BD09FEU@2FUYH00P2ATI40702BTY80U9BD09:BTP2?Shl0TY:B096AT@2@T900TY:B09>C
T`2@T900RXZ:096AT@2<S8`0QhN708J6QP2;Rh/0QHF508:2PP23Ph<0Ng]k08B4Q029RHT0V9RH0:JV
YP2b/[80_[jn0<71`@37alL20<k>cP030=3@d03Bd]80dm?C0080dm?C00<0d];B0=?Cd`3Cdm<0103A
dM402@3De=@0d];B0=3@d03?cll0d];B0=CDe03Cdm<0dM7A0=3@d0020=;BdP030=?Cd`3Bd]80e=CD
00<0d];B00H0e=CD0=?Cd`3Cdm<0e=CD0=GEe@3De=@40=GEe@@0e]KF0P3EeMD01P3De=@0dm?C0=GE
e@3De=@0dm?C0=KFeP80e=CD3P38h=P000`0b>3H0P0j>SX01@0g=cL0=SHf03De=@0i>CT0=CDe0080
?3`l00D0>SXj0410@00o?cl0ADE503hn?P030410@00I03`l?00o?cl0@D5103hn?P17AdL0DE5A051@
D01DE5@0Fe]K06ATI01aLG40Ng]k08:2PP2>SXh0TY:B09NGU`2LW9`0WinO0:>SX`2TY:@0ZZZZ0:f]
[@2a/K40[jn_0:j^[P030;:b/P090;Jf]P2a/K40/[:b0;6a/@2b/[80/;2`0;>c/`2f][H0]KFe0080
];Bd01H0/;2`0:f][@2UYJD0WinO09VIV@2CTi<0RHV908>3P`1gMgL0L71`05mOG`1ADE40C4a<05EE
E@1lO7`0WYjN08b<S01dM7@0GUiN05QHF01ADE40E5AD0P1JFUX0<@1dM7@0S8b<09JFUP2NWYh0RXZ:
08F5Q@1dM7@0F5QH0410@00^;Rh0=cLg055AD@1?Cdl0?3`l0410@00_;bl0<30`02PX:00[:b/0>CTi
03hn?P1<C4`0CTi>05UIF@0f=SH0A4A404m?C`18B4P0=SHf03@d=01HF5P0?clo03`l?00h>3P0=cLg
04=3@`1eMGD0SXj>079bLP2:RXX0Kfm_061PH01TI6@0FUYJ05iNGP1XJ6P0I6AT06IVIP1`L7000P1Z
JVX07@1RHV80F5QH04e=C@1ADE40CDe=05QHF01XJ6P0Shn?09VIV@1jNWX0@D5103Lg=`0f=SH0CTi>
04I6AP0^;Rh0>CTi04A4A01KFe/0MGEe0861P@24Q8@0PX:208>3P`26QXH0Rh^;08n?S`2o_kl0e=CD
0080fMWI01<0e=CD0=?Cd`38b<P0^KVi08B4Q01=CDd0GEeM06UYJ@1FEUH0F5QH05mOG`1gMgL0U9BD
0;Jf]P35aLD0Q8B4038b<P0];Bd0<C4a0080;2`/0180=cLg03<c<`0^;Rh0<S8b02/[:`0Y:BT0:RXZ
02/[:`0`<300>CTi04U9B@14A4@0=3@d02d];@0f=SH0>3Ph02d];@0`<30203De=@0303Ph>00j>SX0
@4100080=CDe00L0?Shn04Y:BP1@D500De=C03Ti>@0Z:RX0:b/[0080;bl_01<0:2PX03@d=01EEED0
IfMW0492@P1BDU80De=C069RHP1IFET0De=C04e=C@1CDe<0GEeM05UIF@1UIFD0JFUY07=cL`1jNWX0
NGUi0080OWin0140OGem07moO`23Ph<0P82007moO`1mOGd0O7al07inOP1mOGd0Ph>30820P025QHD0
Q8B408R8R027QhL0RHV908J6QP0208V9R@0L08j>SP2;Rh/0Shn?09NGU`2CTi<0TI6A09>CT`2ATI40
T92@08f=S@25QHD0NGUi07]kN`1hN7P0OGem07alO01dM7@0KVi^06][J`1RHV80GUiN05mOG`1NGUh0
HF5Q061PH01ZJVX0Jf][06QXJ080LG5a0P1cLg<0301^KVh0L71`075aL@1^KVh0K6a/071`L01ZJVX0
K6a/06][J`1/K6`0L71`06e]K@80Jf][00`0L71`07=cL`1jNWX0OWin07moO`23Ph<0P82008:2PP23
Ph<0PX:207moO`1mOGd207QhN00808:2PP24Q8@0Shn?08>3P`20P800Ph>308n?S`2BTY82096AT@0m
08^;R`27QhL0E5AD03@d=00Z:RX0;Rh^038b<P0/;2`0:b/[02d];@0a<C40<S8b03<c<`0k>c/0;Rh^
02/[:`0];Bd0:b/[02`/;00_;bl0>3Ph034a<@0d=3@0AdM704Y:BP11@D40>CTi03Hf=P0m?Cd0EeMG
04e=C@18B4P0D51@03lo?`1:BTX0De=C059BDP14A4@0>c/k02`/;00b<S80=cLg04m?C`1@D500?Shn
038b<P0T92@09RHV034a<@0Z:RX0<S8b055AD@1lO7`0VYZJ0:6QX@2=SHd0O7al08b<S02IVIT0RXZ:
096AT@0209VIV@0709BDU02ATI40U9BD09NGU`2EUID0Ti>C09:BTP0209jNWP<0WIfM00<0W9bL09ZJ
VP2JVYX00P2HV9P01P2IVIT0V9RH09ZJVP2EUID0UiNG09VIV@80UYJF00<0TY:B09JFUP2HV9P00P2E
UID01`2@T900TI6A09NGU`2EUID0UYJF09FEU@2ATI400P2DU9@0102FUYH0UIFE09FEU@2FUYH209>C
T`07092@T02ATI40Shn?08n?S`2DU9@0Shn?09:BTP02096AT@80T92@00<0TI6A08Z:RP29RHT00P29
RHT03P25QHD0Ph>30861P@21PH40Ogmo08J6QP2EUID0Y:BT0:f][@2h^;P0`L710<O7a`3:b/X0c<c<
0P3@d=020=?Cd`030=GEe@3De=@0eMGE00@0dm?C0P3Bd]802`3Cdm<0d];B0<o?c`3@d=00dM7A0=3@
d03AdM40c/k>0=;BdP3AdM40dm?C0080eMGE0P3Bd]801P3AdM40e=CD0=CDe03AdM40e=CD0=?Cd`D0
eMGE00@0e]KF0=CDe03GemL0f=SH103EeMD0103Cdm<0e]KF0=GEe@3EeMD20=CDe0h0b>3H000<0<SP
f080>c/k00L0=SHf03dm?@0f=SH0=cLg03De=@11@D40?clo0080@T9200D0ATI60492@P14A4@0?clo
03hn?P020410@0040451@@10@400?Shn04];B`80Cdm?0100DE5A065QH@1RHV80LW9b07alO023Ph<0
Shn?09FEU@2IVIT0Vi^K09fMW@2SXj<0Y:BT0:RXZ02[Zj/0[Jf]0P2_[jl30;:b/P1D0;Bd]02a/K40
/[:b0;>c/`2f][H0/K6a0;Bd]02c/k<0]KFe0;Bd]02a/K40[Jf]0:b/[02VYZH0X:2P09^KV`2CTi<0
R8R80861P@1dM7@0KVi^05eMG@1FEUH0C4a<04=3@`1IFET0PX:209jNWP29RHT0K6a/05eMG@1@D500
EUIF05ADE01MGEd0IfMW07emO@2GUiL0Ti>C09jNWP2;Rh/0MgMg05YJFP0l?3`0=CDe03@d=010@400
FEUI05IFEP14A4@0;Rh^02@T900Y:BT0<C4a02l_;`0f=SH0@41004i>CP1=CDd0=3@d04=3@`1<C4`0
EEEE034a<@0f=SH0B4Q803Ph>00k>c/0>CTi03De=@18B4P0MGEe096AT@1oOgl0QhN706a/K01ZJVX0
IVIV05UIF@1WIfL0Kfm_07=cL`1VIVH0EeMG0P1NGUh03`1EEED0@d=303Xj>P10@400CDe=05eMG@1k
Ng/0Q8B408F5Q@1mOGd0BDU904I6AP0n?Sh0GEeM04a<C0020451@@0>0410@01CDe<0Kfm_07]kN`1j
NWX0N7Qh07MgM`1jNWX0T92@0:j^[P30`<00b<S80<O7a`3@d=020=GEe@030<k>cP30`<00Y:BT0080
EeMG00X0J6QX079bLP1JFUX0HV9R06EUI@1fMWH0U9BD0<G5a@2k^k/0H61P0P0V9RH0500X:2P0<30`
02`/;00`<300<S8b034a<@0^;Rh0;2`/02XZ:P0^;Rh0<c<c03hn?P19BDT0AdM7030`<00W9bL0:RXZ
02/[:`0a<C40;2`/0P0e=CD0300h>3P0>SXj03lo?`0g=cL0@T9203lo?`1<C4`0DU9B04i>CP0_;bl0
9BDU02HV9P80:RXZ0180:2PX038b<P1BDU80KFe]03hn?P1ADE40DU9B06=SH`1HF5P0Bd];04U9B@1A
DE40GUiN06IVIP1[Jf/0JFUY07MgM`1hN7P207UiN@0>07moO`22PX80PX:207moO`22PX80Ng]k07mo
O`24Q8@0Ng]k07emO@23Ph<0PX:208B4Q023Ph<208N7Q`0708f=S@29RHT0RXZ:08n?S`2:RXX0TI6A
08b<S00209BDU080T92@0240Ti>C08n?S`2=SHd0PX:207EeM@1/K6`0I6AT06i^KP1TI6@0HV9R05UI
F@1JFUX0De=C059BDP1GEeL0E5AD059BDP1FEUH0GEeM05YJFP1MGEd0I6AT069RHP1/K6`0L71`06YZ
JP1XJ6P0IfMW06IVIP1PH600Hf=S061PH01GEeL00P1IFET0201QHF40GemO06IVIP1VIVH0Kfm_071`
L01cLg<0MgMg0P1eMGD03P1kNg/0M7Ad06a/K01_Kfl0KVi^06QXJ01TI6@0K6a/07AdM022PX80PH61
07inOP1hN7P0O7al0P2:RXX04P2?Shl0Ti>C096AT@2;Rh/0MgMg0410@00];Bd0:b/[02d];@0`<300
;Bd]034a<@0^;Rh0<S8b03@d=00g=cL0<S8b02`/;080:RXZ00<0;bl_03@d=00k>c/00P0b<S808P10
@400Bd];0492@P0m?Cd0<C4a03/k>`1CDe<0EeMG0410@01@D500B4Q804m?C`1ADE40Cdm?03dm?@0j
>SX0;2`/02/[:`0j>SX0F5QH04i>CP10@400<C4a02LW9`0^;Rh0<C4a02`/;00e=CD0FEUI08B4Q02O
Wil0XZ:R08R8R01nOWh2096AT@0708B4Q02ATI40V9RH09RHV02EUID0Ti>C09FEU@0209BDU00409FE
U@2ATI40XJ6Q09jNWP80W9bL00/0Y:BT09bLW02KVi/0V9RH09bLW02EUID0VYZJ09RHV02IVIT0UiNG
09VIV@0309RHV00409JFUP2EUID0UYJF09>CT`80U9BD00d0Shn?09RHV02FUYH0TY:B09FEU@2ATI40
Shn?096AT@2BTY80VIVI09FEU@2ATI40TY:B0080SXj>00D0TI6A08b<S02?Shl0Ti>C09:BTP03092@
T00J08n?S`2=SHd0SXj>08b<S02:RXX0SHf=08J6QP24Q8@0Ph>30820P01oOgl0NWYj08R8R02BTY80
WIfM0;6a/@2g]kL0^k^k0<C4a038b<P0b/[:0<g=c@3@d=00d];B0=?Cd`3GemL20=?Cd`030=;BdP3C
dm<0d];B00D0d];B0`3@d=00103AdM40d];B0<k>cP3?cll20=7Ad@080=;BdP3Cdm<0d];B0=7Ad@3@
d=00dm?C0=CDe03EeMD40=CDe0040=GEe@3De=@0e]KF0=KFeP80emOG00T0f][J0=KFeP3EeMD0e=CD
0=KFeP3GemL0dm?C0=CDe03EeMD00P3De=@>0<SPf0003038h=P303Ti>@0403Lg=`0j>SX0@41003`l
?080?clo00@0>c/k0451@@10@400BTY:0P11@D400`10@400?3`l03`l?00203/k>`0<04E5A@17AdL0
CDe=04];B`1CDe<0FEUI061PH01[Jf/0OWin08>3P`2>SXh0UIFE0P2IVIT01@2MWId0XJ6Q0::RXP2Y
ZJT0[Jf]0080/;2`00@0[jn_0:^[Z`2[Zj/0/[:b0P2_[jl07P2b/[80/k>c0;:b/P2a/K40/k>c0;Bd
]02a/K40/[:b0;Bd]02^[Zh0[:b/0:VYZ@2QXJ40WinO09FEU@2;Rh/0PH6107YjNP1^KVh0H61P059B
DP18B4P0ATI604Q8B01/K6`0T92@09ZJVP22PX80JFUY05]KF`80EUIF01h0F5QH05mOG`1aLG40RXZ:
092@T02DU9@0XJ6Q07alO01OGel0ADE503`l?00_;bl0>CTi03`l?01RHV80EEEE03Lg=`0X:2P0=SHf
04A4A013@d<0?3`l03/k>`10@400@d=303Lg=`18B4P0CTi>059BDP10@40203hn?P0B034a<@0b<S80
?Cdm03Hf=P1=CDd0KVi^08n?S`21PH40Ng]k06MWI`1^KVh0K6a/05aLG01WIfL0JFUY06IVIP1KFe/0
C4a<0P1=CDd0801>CTh0?clo03hn?P1=CDd0F5QH07YjNP1hN7P0Hf=S07UiN@1kNg/0Cdm?03Xj>P17
AdL0HF5Q07=cL`1PH600BTY:03Xj>P1OGel0RHV909RHV02JVYX0T92@07emO@1cLg<0RXZ:0:ZZZP2g
]kL0`L710;Zj^P35aLD0d=3@0P3AdM404`30`<00];Bd07YjNP1=CDd0H61P06m_K`1/K6`0HV9R05eM
G@1TI6@0PH610:FUY@3:b/X0[Zj^03`l?00T92@09bLW030`<00a<C400P0b<S80700i>CT0<S8b02HV
9P0T92@0;2`/03Hf=P1:BTX0CTi>03dm?@0`<300:BTY02`/;00e=CD0;2`/02XZ:P0b<S80;Rh^03Xj
>P0i>CT0@D51034a<@14A4@0@T9204a<C01?Cdl0Bd];02`/;00Z:RX302LW9`0@02d];@0f=SH0E5AD
071`L00n?Sh0Bd];05QHF01/K6`0EeMG04e=C@15ADD0De=C05UIF@1VIVH0Jf][071`L080MWIf00L0
NGUi07QhN020P800PX:208F5Q@26QXH0Ph>30080OWin00<0PH6107inOP23Ph<00P22PX801@20P800
R8R808V9R@28R8P0RXZ:00<0Rh^;01L0S8b<08j>SP2=SHd0T92@08n?S`2BTY80SXj>096AT@2@T900
TI6A08:2PP1bLW80G5aL05MGE`1DE5@0EUIF04e=C@19BDT0B4Q804e=C@1EEED0G5aL065QH@0206QX
J0<0Jf][0100JVYZ075aL@1_Kfl0Lg=c06MWI`1QHF40GemO05eMG@1OGel0FUYJ05]KF`1DE5@0DE5A
05QHF01KFe/0G5aL0P1TI6@04@1WIfL0L71`07IfMP1fMWH0N7Qh07emO@1jNWX0M7Ad06=SH`1MGEd0
FUYJ05ADE01KFe/0HV9R06=SH`1^KVh0M7Ad0080L71`0440Lg=c07emO@2<S8`0Rh^;096AT@2CTi<0
Rh^;08V9R@1QHF40=CDe02XZ:P0f=SH0<30`02d];@0U9BD0<C4a02h^;P0e=CD0?Cdm03<c<`0^;Rh0
=CDe03<c<`0a<C40;Rh^03Hf=P0l?3`0=SHf03Xj>P16ATH0Bd];04i>CP0g=cL0B4Q804m?C`1CDe<0
?Shn04a<C015ADD0DE5A05ADE01BDU80AdM70410@00];Bd0;bl_03lo?`1EEED0AdM703`l?00a<C40
92@T02TY:@0/;2`0:b/[03Hf=P1RHV80RHV909ZJVP2LW9`0PX:207MgM`2BTY80QHF508:2PP0309:B
TP03096AT@2?Shl0Ti>C00<0UIFE00d0Ti>C09bLW02MWId0VYZJ09VIV@2TY:@0XJ6Q09ZJVP2GUiL0
V9RH09NGU`2FUYH0VIVI0080VYZJ0P2GUiL02@2FUYH0TY:B09JFUP2GUiL0Ti>C09:BTP2FUYH0TY:B
096AT@0209>CT`0=09NGU`2EUID0TI6A092@T02ATI40Ti>C096AT@2CTi<0UiNG09FEU@2CTi<0TY:B
09>CT`02092@T00M08f=S@2>SXh0T92@09>CT`2@T900TY:B096AT@2BTY80Rh^;08b<S027QhL0R8R8
08B4Q022PX80P82007alO01oOgl0QHF509:BTP2TY:@0[Jf]0;Ng]`2n_[h0`l?30<K6aP3:b/X0cLg=
0<c<c03@d=000P3Bd]820=?Cd`080=CDe03Cdm<0e=CD0=CDe03Cdm<0dM7A0=3@d03Bd]840=3@d0@0
clo?00H0d];B0=7Ad@3AdM40d=3@0=;BdP3Cdm<20=CDe080dm?C00P0e=CD0=?Cd`3Bd]80dm?C0=;B
dP3EeMD0f=SH0=OGe`80eMGE0P3De=@20=GEe@060=KFeP3GemL0eMGE0=OGe`3De=@0eMGE3P38h=P0
00`0b>3H0`0e=CD02@0g=cL0?Cdm03/k>`0g=cL0>c/k03`l?00g=cL0?Cdm0451@@020492@P0304A4
A011@D40?Cdm00@0?clo01D0ATI604Q8B01;Bd/0CDe=05ADE01KFe/0J6QX07EeM@23Ph<0R8R809>C
T`2GUiL0W9bL0:2PX02RXZ80YZJV0:VYZ@2^[Zh0[:b/0:j^[P2_[jl00P2][Jd01P2_[jl0/;2`0;6a
/@2_[jl0/k>c0;:b/P80/k>c0140/[:b0;>c/`2d];@0/K6a0;Bd]02[Zj/0YZJV0:>SX`2JVYX0UYJF
08^;R`20P800NGUi06i^KP1RHV80CTi>0410@00204A4A00605IFEP1YJFT0RHV908f=S@1hN7P0IFEU
0P1GEeL0;`1NGUh0GEeM06EUI@1bLW80Ph>308n?S`2KVi/0PX:2061PH012@T80=CDe02/[:`0];Bd0
<c<c04Q8B01MGEd0=CDe02TY:@13@d<0EeMG04U9B@11@D40?Cdm03hn?P0i>CT0>c/k0451@@1ADE40
Cdm?04=3@`0i>CT0=SHf038b<P0a<C40=cLg03lo?`19BDT0JFUY08B4Q01mOGd0IFEU065QH@1TI6@0
JFUY06ATI01ZJVX0Hf=S00<0D51@0P19BDT06010@400?Shn04Q8B01MGEd0Ng]k06m_K`1GEeL0B4Q8
069RHP1`L700F5QH055AD@1LG5`0MgMg07UiN@1QHF40EEEE05MGE`1dM7@0RHV909BDU02_[jl0Zj^[
09fMW@80MWIf03X0Rh^;0:NWY`2n_[h0_Kfm0<G5a@3Fe]H0cLg=0<o?c`3:b/X0`L710:VYZ@1UIFD0
EUIF06YZJP1eMGD0IfMW05YJFP1QHF40Jf][08B4Q02`/;00a/K607alO00];Bd0:BTY02l_;`0`<300
:b/[02d];@0d=3@0;bl_02d];@0V9RH09BDU03dm?@1ADE40CTi>030`<00V9RH0:RXZ034a<@0b<S80
;bl_02h^;P0a<C40<S8b03`l?00n?Sh0A4A403@d=017AdL0@T9204Y:BP1CDe<0ATI602`/;00[:b/0
;2`/0P0Z:RX08@0_;bl0<S8b05IFEP1jNWX0ADE5059BDP1GEeL0Jf][04i>CP1=CDd0BTY:05UIF@1Q
HF40Hf=S06a/K01_Kfl0MgMg07EeM@1hN7P0NGUi08:2PP26QXH0PX:208V9R@25QHD0Ng]k07emO@23
Ph<0O7al08B4Q022PX80Ogmo08>3P`0208F5Q@0/08B4Q027QhL0RXZ:08Z:RP2?Shl0S8b<09>CT`2A
TI40Shn?08f=S@2?Shl0S8b<09:BTP2DU9@0Shn?08N7Q`1eMGD0GUiN04I6AP17AdL0Cdm?05UIF@1U
IFD0KFe]06m_K`1bLW80NWYj07UiN@1oOgl0O7al07emO@21PH40N7Qh07UiN@1gMgL0MGEe07]kN`1e
MGD0L71`07=cL`1^KVh0LG5a079bLP1_Kfl206][J`0306YZJP1aLG40Kfm_0080Kfm_0340L71`07Ad
M01nOWh0O7al07emO@2:RXX0Ph>308V9R@1bLW80F5QH04e=C@13@d<0EeMG05iNGP1QHF40JFUY06i^
KP1YJFT0I6AT06a/K01cLg<0P82008V9R@2BTY80U9BD08j>SP2:RXX0O7al04A4A00];Bd0;Rh^034a
<@0];Bd0:b/[02l_;`0^;Rh0=CDe03Lg=`0f=SH0;Bd]034a<@0_;bl0<S8b02d];@0c<c<0>SXj034a
<@0i>CT0?Shn0080BDU901X0<c<c03dm?@17AdL0EEEE03dm?@1?Cdl0?clo04U9B@1CDe<0DU9B0410
@018B4P0=3@d03<c<`0i>CT0ADE504=3@`0c<c<0;Rh^024Q8@0W9bL0:2PX02TY:@0g=cL0IVIV09>C
T`80X:2P00H0Ogmo06a/K02EUID0O7al08>3P`2>SXh209FEU@0908j>SP2ATI40TI6A09RHV02EUID0
T92@096AT@2IVIT0VYZJ0080W9bL00L0Vi^K09bLW02JVYX0W9bL09BDU02FUYH0W9bL0080V9RH01T0
VIVI09FEU@2KVi/0V9RH092@T02EUID0UYJF09>CT`2HV9P0U9BD092@T02CTi<0Vi^K09:BTP2DU9@0
UYJF09FEU@2BTY80TI6A09JFUP2DU9@0UIFE09JFUP2CTi<0U9BD0080SXj>0P2BTY800`2@T900TI6A
08j>SP0209:BTP0608b<S02?Shl0TI6A096AT@2<S8`0SHf=0P28R8P03P25QHD0Ogmo0820P01oOgl0
Q8B4096AT@2MWId0ZZZZ0;Fe]@2n_[h0_kno0<O7a`3:b/X0c<c<0P3>c/h20=7Ad@80e=CD0P3Cdm<2
0=;BdP060=CDe03AdM40d=3@0=;BdP3@d=00dm?C0P3Bd]80203AdM40clo?0<k>cP3?cll0d=3@0=CD
e03?cll0d];B0P3AdM420=?Cd`80e=CD00T0dm?C0=CDe03De=@0e=CD0=GEe@3De=@0e]KF0=GEe@3F
e]H00P3EeMD00`3Cdm<0e]KF0=?Cd`020=?Cd`80eMGE00<0fMWI0=GEe@38h=P03@38h=P000`0b>3H
0P0o?cl01@10@400?3`l03`l?00f=SH0>c/k0080?clo00L0>c/k03hn?P0n?Sh0A4A404Q8B012@T80
B4Q80080@41001P0>SXj03`l?00k>c/0@T9204Q8B01;Bd/0Cdm?05EEE@1KFe/0J6QX07YjNP24Q8@0
SHf=096AT@2JVYX0Vi^K0::RXP2WYjL0Y:BT0:NWY`2[Zj/0ZJVY0:^[Z`2_[jl20:j^[P0=0:ZZZP2`
/;00/K6a0:n_[`2`/;00/[:b0;Bd]02e]KD0]kNg0;Jf]P2`/;00/k>c0;:b/P020:ZZZP0]09nOW`2J
VYX0UYJF08n?S`25QHD0NWYj06i^KP1NGUh0E5AD04U9B@17AdL0@T92051@D01CDe<0K6a/08j>SP2=
SHd0Kfm_05]KF`1JFUX0FEUI05iNGP1WIfL0JVYZ079bLP22PX80TI6A08R8R01UIFD0@d=303<c<`0d
=3@0;Rh^02TY:@0b<S80GUiN05=CD`0b<S80JVYZ06][J`1=CDd0=3@d03De=@18B4P0?Shn0080@D51
00<0@T9204=3@`0c<c<00P0k>c/04P0d=3@0>CTi03Ti>@0l?3`0@D51069RHP1nOWh0MGEe05ADE01K
Fe/0K6a/06ATI01SHf<0HF5Q05EEE@1@D500AdM704U9B@80ADE50100@T9204A4A01GEeL0NWYj06e]
K@1ADE40?clo03`l?01=CDd0KVi^061PH01TI6@0Lg=c08:2PP1dM7@0HF5Q0P1lO7`01P1XJ6P0FUYJ
069RHP2ATI40W9bL08B4Q080MGEe0100P82009bLW02o_kl0_;bl0<W9b@3Cdm<0clo?0<[:bP3AdM40
bLW90;fm_@2QXJ40F5QH05mOG`1ZJVX0KVi^0P1IFET06@1TI6@0MgMg08n?S`2m_Kd0]KFe0492@P0X
:2P08R8R02HV9P0P8200:RXZ02`/;00Y:BT0;Bd]02PX:00_;bl0@d=305ADE019BDT0;Rh^034a<@0/
;2`0;Rh^030`<00X:2P00P0e=CD02P0_;bl0?3`l03`l?016ATH0?3`l04e=C@0m?Cd0B4Q804i>CP0l
?3`202TY:@0F02/[:`0^;Rh0;Rh^02h^;P0`<300GemO07MgM`1>CTh0Fe]K05eMG@1RHV80DU9B04M7
A`1CDe<0G5aL06=SH`1VIVH0Kfm_06a/K01cLg<0M7Ad07UiN@80P82000d0PH610820P022PX80Ogmo
07emO@1nOWh0Ogmo07inOP22PX80QXJ60820P024Q8@0R8R80080Q8B40140Ph>308Z:RP2;Rh/0Shn?
092@T02?Shl0TI6A08Z:RP2<S8`0Shn?08Z:RP2ATI40UYJF08f=S@2:RXX0O7al07=cL`0206UYJ@0;
06a/K01gMgL0N7Qh07emO@1oOgl0PX:208>3P`24Q8@0QXJ608V9R@28R8P00P23Ph<00`26QXH0Q8B4
08B4Q0020820P00;07alO01mOGd0NWYj07YjNP1oOgl0Ph>307alO020P800N7Qh07IfMP1lO7`00P1g
MgL0<@1bLW80NGUi08B4Q027QhL0Ogmo096AT@27QhL0T92@08Z:RP1oOgl0LW9b06EUI@1]KFd0LG5a
07UiN@1jNWX0M7Ad06=SH`1LG5`0HF5Q06QXJ01fMWH0R8R808b<S02BTY80TI6A08Z:RP22PX80Fe]K
03@d=00e=CD0<C4a02l_;`0[:b/0;bl_02d];@0`<300>CTi03Hf=P0_;bl0<30`02d];@0f=SH0<30`
02d];@0h>3P0=cLg034a<@0f=SH00P1ADE40300i>CT0>3Ph0492@P1IFET0@D5105EEE@13@d<0CTi>
055AD@1IFET0?Cdm04=3@`80=3@d01@0A4A404E5A@13@d<0;Rh^02PX:00R8R80;2`/02PX:00[:b/0
?clo071`L02EUID0X:2P09nOW`1gMgL0Jf][08Z:RP1aLG40Ph>309:BTP80UIFE00l0TI6A092@T02C
Ti<0UIFE08n?S`2<S8`0SHf=09fMW@2LW9`0WYjN09VIV@2KVi/0W9bL09ZJVP2MWId00P2GUiL0102E
UID0UiNG09ZJVP2GUiL209>CT`0309JFUP2HV9P0UYJF0080Ti>C0P2DU9@02@2ATI40TY:B09NGU`2D
U9@0Ti>C096AT@2IVIT0Ti>C09FEU@0209JFUP0?09FEU@2>SXh0TI6A09>CT`2BTY80T92@09:BTP2@
T900Shn?092@T02ATI40SXj>08n?S`2BTY80T92@0080SXj>01<0RXZ:08b<S029RHT0R8R808>3P`22
PX80Ogmo07]kN`1nOWh0T92@09jNWP2ZZZX0/K6a0;^k^`31`L40aLG50<O7a`3;bl/0c/k>0080clo?
00D0d=3@0=?Cd`3Cdm<0eMGE0=7Ad@020=;BdP050=7Ad@3Bd]80dm?C0=;BdP3@d=000P3Bd]830=3@
d0090<o?c`3@d=00dM7A0=;BdP3@d=00clo?0=3@d03AdM40dm?C0080e=CD00@0dm?C0=GEe@3EeMD0
e=CD0P3EeMD00`3De=@0eMGE0=OGe`040=GEe@050=?Cd`3Bd]80e]KF0=?Cd`3De=@00P3Fe]H00`3E
eMD0b>3H0<SPf00<0<SPf0003038h=P204I6AP0V03dm?@0n?Sh0?3`l03/k>`0i>CT0@d=30451@@0m
?Cd0ADE50492@P10@400ATI604=3@`14A4@0ATI604=3@`0j>SX0>CTi03lo?`11@D40CDe=04m?C`19
BDT0DU9B05UIF@1^KVh0OGem0820P02:RXX0TY:B09NGU`2LW9`0WYjN0:FUY@2TY:@0YJFU0:RXZ02Y
ZJT20:b/[080[Jf]00T0[:b/0:f][@2`/;00[:b/0;2`/02][Jd0/K6a0;Bd]02g]kL00P2f][H03P2b
/[80/K6a0:b/[02YZJT0XJ6Q09bLW02FUYH0SHf=07inOP1iNGT0KVi^061PH01?Cdl0D51@0P15ADD0
>P19BDT0D51@05]KF`1fMWH0Ti>C08R8R01/K6`0GemO05]KF`1LG5`0HF5Q06=SH`1YJFT0M7Ad08j>
SP27QhL0KFe]04E5A@0e=CD0;bl_02XZ:P0X:2P0<30`05MGE`1/K6`0GUiN0861P@1ZJVX0?3`l030`
<00a<C40@T9203Ph>00j>SX0?clo04A4A013@d<0>3Ph03Ti>@0c<c<0=cLg0410@016ATH0@d=30410
@01OGel0Ogmo061PH01CDe<0HF5Q06QXJ01WIfL0GemO05IFEP1EEED0F5QH04Y:BP1@D50204A4A01A
0492@P1KFe/0MgMg06e]K@1;Bd/0=3@d038b<P0i>CT0BTY:061PH01KFe/0IVIV08>3P`22PX80OGem
08R8R01nOWh0EEEE03@d=00Z:RX0>SXj071`L026QXH0IfMW05eMG@1_Kfl0Q8B40:>SX`2a/K40aLG5
0<[:bP3?cll0c/k>0<c<c03Bd]80b<S80<C4a02k^k/0S8b<05ADE01LG5`0JFUY06MWI`1JFUX0Fe]K
06ATI01lO7`0VIVI0<O7a`2ATI40;bl_01lO7`0U9BD09RHV02PX:00V9RH0:RXZ02d];@0W9bL0=cLg
04];B`1RHV80BDU902`/;00[:b/0;2`/03De=@0/;2`09bLW03@d=00h>3P0=CDe03Ph>00e=CD0A4A4
04Y:BP1ADE40ATI604Q8B01<C4`0=cLg0080;bl_01@0;Bd]02XZ:P0Z:RX0;2`/03dm?@1PH600L71`
04m?C`1HF5P0I6AT05eMG@1DE5@0B4Q805ADE01HF5P0GUiN06YZJP1aLG40L71`07=cL`80Ng]k00L0
OWin0820P024Q8@0PX:208B4Q023Ph<0PH610080P82000D0Q8B408>3P`25QHD0R8R808F5Q@0208N7
Q`0D08R8R02;Rh/0QhN708j>SP2=SHd0T92@08n?S`2;Rh/0RXZ:08b<S02;Rh/0RHV908^;R`2?Shl0
SXj>08^;R`23Ph<0QHF50820P01oOgl207inOP0D08:2PP23Ph<0Ogmo08B4Q025QHD0Ph>308V9R@2>
SXh0Shn?08R8R027QhL0Rh^;08b<S02:RXX0R8R808^;R`2:RXX0QhN708:2PP26QXH208N7Q`050820
P026QXH0Ogmo08:2PP1oOgl00P1lO7`0A`21PH40Rh^;08f=S@2:RXX0RHV9092@T02FUYH0Vi^K09:B
TP2>SXh0Rh^;08N7Q`28R8P0QhN708R8R02?Shl0S8b<08:2PP1aLG40IVIV06QXJ01fMWH0Ph>308V9
R@2@T900SXj>08^;R`28R8P0N7Qh03Xj>P0`<300;Bd]03<c<`0Z:RX0;Rh^038b<P0[:b/0<C4a03<c
<`0a<C40;bl_03Ph>00`<300=3@d03Hf=P0a<C40>3Ph02h^;P0i>CT0AdM704];B`14A4@0?Shn04I6
AP1EEED0AdM705QHF01<C4`0BDU9051@D01JFUX0@T920451@@0n?Sh0=cLg03`l?018B4P0<c<c02d]
;@0T92@09RHV0080;2`/00`0<C4a0410@01kNg/0V9RH0:>SX`2NWYh0LW9b06m_K`24Q8@0IVIV0861
P@2=SHd3096AT@80Ti>C00D0TI6A092@T02CTi<0T92@09ZJVP0209jNWP0?09bLW02KVi/0W9bL09fM
W@2LW9`0VYZJ09bLW02CTi<0VIVI09FEU@2FUYH0UiNG09:BTP2CTi<0UYJF0080T92@0`2DU9@00`2?
Shl0TY:B09FEU@0209JFUP80Ti>C00<0U9BD09>CT`2EUID00P2EUID0102?Shl0Ti>C092@T02ATI43
092@T00408f=S@2BTY80Shn?08b<S080T92@00H0SXj>08^;R`2=SHd0SHf=08b<S027QhL208J6QP0=
0861P@22PX80OWin07inOP2;Rh/0Vi^K0:RXZ02d];@0^KVi0<71`@34a<@0aLG50<S8b0020<g=c@80
c/k>00@0dM7A0=;BdP3Cdm<0dm?C103Bd]820=3@d0080<o?c`3@d=00dM7A0<o?c`3Cdm<0dM7A0<o?
c`3@d=020=;BdP0<0=?Cd`3AdM40d=3@0=7Ad@3Cdm<0e=CD0=GEe@3Cdm<0eMGE0=CDe03Cdm<0e]KF
0`3EeMD01P3De=@0eMGE0=GEe@3De=@0eMGE0=?Cd`80eMGE00D0e]KF0=?Cd`3De=@0e=CD0=GEe@0>
0<SPf0003038h=P204I6AP0<03dm?@0k>c/0>c/k03lo?`0n?Sh0?3`l04A4A015ADD0?clo04I6AP14
A4@0Bd];0P13@d<06014A4@0@T920410@012@T80@D5104I6AP14A4@0CDe=05=CD`1EEED0GemO06YZ
JP1nOWh0PH6108V9R@2>SXh0UIFE09bLW02OWil0Y:BT0::RXP2SXj<0Zj^[0:VYZ@80Zj^[0P2ZZZX0
6@2][Jd0YZJV0;2`/02^[Zh0[Jf]0;:b/P2a/K40];Bd0;Jf]P2e]KD0/[:b0;>c/`2b/[80[Zj^0:RX
Z02RXZ80WYjN09RHV02BTY80QHF507]kN`1]KFd0I6AT059BDP1;Bd/00P1:BTX02`1;Bd/0Cdm?05IF
EP1WIfL0QHF509RHV01fMWH0HV9R05iNGP1OGel0GUiN0080IFEU00P0LG5a08:2PP23Ph<0JFUY051@
D011@D40?Cdm03Ti>@80:2PX01l0?3`l079bLP1gMgL0OGem06i^KP16ATH0>SXj03Ti>@14A4@0<c<c
03`l?00n?Sh0AdM704=3@`0l?3`0>3Ph03Lg=`1=CDd0ADE50410@00o?cl0@D51069RHP1fMWH0EUIF
05=CD`1PH600GemO05EEE@1FEUH0CDe=00<0D51@01D0ATI60410@010@400B4Q806e]K@1dM7@0De=C
0451@@0k>c/0>SXj0492@P1EEED0F5QH05MGE`1]KFd0Q8B40861P@2;Rh/0Ph>305iNGP0[:b/00P0O
7al0800W9bL0De=C07=cL`1RHV80IFEU06a/K024Q8@0Y:BT0;2`/036a/H0b/[:0<G5a@2m_Kd0_kno
0<o?c`3:b/X0_kno0<K6aP2c/k<0Ogmo05MGE`1OGel0KFe]05]KF`1BDU80GEeM079bLP20P800ZZZZ
0<G5a@1eMGD0:RXZ0P0X:2P00`0];Bd09BDU02HV9P0202XZ:P080410@01OGel0LG5a059BDP0e=CD0
:b/[02d];@0c<c<202XZ:P0503/k>`0e=CD0=CDe03Ph>00f=SH00P0n?Sh02017AdL0B4Q804M7A`14
A4@0=3@d02h^;P0e=CD0;2`/0P0W9bL09P0[:b/0>CTi05ADE01WIfL0Cdm?05QHF01YJFT0HV9R05]K
F`18B4P0EUIF05mOG`1TI6@0K6a/075aL@1cLg<0NWYj07moO`1mOGd0O7al07]kN`24Q8@0PH6108>3
P`24Q8@0PH6107inOP1oOgl0QXJ608B4Q023Ph<0QHF508R8R024Q8@0RHV908N7Q`2:RXX0S8b<0P2?
Shl02@2;Rh/0SXj>08f=S@26QXH0RXZ:08V9R@28R8P0S8b<08j>SP0208^;R`80QhN700<0R8R808N7
Q`22PX800P22PX806P25QHD0QhN708V9R@2=SHd0RHV908j>SP2=SHd0TY:B08f=S@2;Rh/0T92@096A
T@2BTY80SHf=09>CT`2EUID0TY:B09>CT`2?Shl0Ti>C096AT@2>SXh0RHV908R8R02<S8`0QXJ60`29
RHT0202?Shl0U9BD096AT@2BTY80V9RH09nOW`2RXZ80W9bL0P2IVIT0102CTi<0TI6A092@T02EUID2
09ZJVP0d09fMW@2ATI40OWin07EeM@1kNg/0OWin08N7Q`2>SXh0S8b<08n?S`2;Rh/0Ph>305UIF@0`
<300<C4a038b<P0[:b/0<c<c034a<@0`<300=CDe03Xj>P0c<c<0=SHf034a<@0b<S80=3@d03<c<`0e
=CD0>SXj03<c<`0n?Sh0@41004Y:BP15ADD0>c/k03lo?`1DE5@0C4a<05YJFP18B4P0A4A404I6AP1A
DE40D51@04=3@`11@D40>c/k04I6AP18B4P0=cLg02d];@809RHV0P0U9BD0300^;Rh0@T9207inOP2L
W9`0Xj>S0:2PX01cLg<0MgMg08J6QP1SHf<0OWin08V9R@<0SHf=00h0UYJF096AT@2ATI40Shn?09>C
T`2ATI40UYJF09jNWP2LW9`0WIfM09ZJVP2IVIT0WIfM09VIV@<0V9RH00/0Vi^K09JFUP2FUYH0VYZJ
09>CT`2GUiL0UIFE09BDU02@T900U9BD09FEU@02096AT@0:09>CT`2DU9@0UiNG09VIV@2CTi<0T92@
09>CT`2BTY80UIFE09RHV080UIFE00D0T92@096AT@2BTY80Ti>C09FEU@02092@T00509:BTP2ATI40
Shn?08f=S@2?Shl00`2<S8`04`2:RXX0Rh^;08N7Q`27QhL0R8R808B4Q01oOgl0OGem0861P@2<S8`0
W9bL0:BTY02^[Zh0_[jn0<30`032`/80aLG50<K6aP3:b/X00P3<c<`00`3=cLd0d=3@0=7Ad@020=?C
d`80d];B00L0dM7A0<o?c`3Bd]80clo?0=3@d03=cLd0clo?0080dM7A1@3Bd]801@3AdM40d];B0<o?
c`3@d=00dM7A0080d];B00P0dm?C0=CDe03Bd]80dm?C0=CDe03EeMD0dm?C0=CDe080e]KF00/0dm?C
0=GEe@3EeMD0d];B0=?Cd`3EeMD0dm?C0=GEe@3De=@0dm?C0=GEe@0>0<SPf0003038h=P204M7A`08
0492@P0l?3`0?clo0451@@0l?3`0@4100451@@16ATH204];B`0G04U9B@12@T80@T920451@@0n?Sh0
@T9203hn?P10@400?clo04A4A019BDT0ATI605=CD`1FEUH0GUiN06QXJ01fMWH0PH6108R8R02CTi<0
VIVI09^KV`2LW9`00P2PX:020:RXZ0030:^[Z`2^[Zh0[:b/0080[Jf]00T0[jn_0:ZZZP2_[jl0/K6a
0;2`/02][Jd0][Jf0;Fe]@2b/[800P2e]KD06P2b/[80/;2`0:f][@2YZJT0X:2P09VIV@2FUYH0Rh^;
08>3P`1lO7`0KVi^06EUI@1CDe<0ADE504M7A`1:BTX0ATI604a<C01>CTh0F5QH07AdM02@T900V9RH
06m_K`1NGUh0H61P0P1TI6@0:@1YJFT0L71`07]kN`1gMgL0Jf][04Y:BP0i>CT0AdM704=3@`0e=CD0
9bLW03@d=01[Jf/0N7Qh06QXJ01HF5P0>SXj038b<P0g=cL0@d=3038b<P0o?cl0CDe=04Q8B012@T80
?Shn03Ti>@0l?3`0G5aL04Y:BP0o?cl0E5AD055AD@1[Jf/0IfMW04Y:BP1NGUh0GEeM05=CD`1BDU80
B4Q80080Bd];00<0DU9B04i>CP18B4P00P1<C4`00`1LG5`0LG5a05ADE00203Ph>00d03<c<`1;Bd/0
H61P07MgM`1iNGT0Lg=c07MgM`27QhL0U9BD08b<S01[Jf/0<c<c02XZ:P0[:b/0:RXZ02PX:013@d<0
HV9R07QhN028R8P0QXJ609ZJVP2RXZ80]kNg0;fm_@2d];@0[Zj^09NGU`2[Zj/0_kno0<S8b02o_kl0
`/;20<C4a02g]kL0MgMg051@D01NGUh0LG5a05MGE`1LG5`0K6a/07AdM02:RXX0][Jf0;Bd]015ADD0
;Bd]030`<00^;Rh0:2PX02HV9P80:RXZ0100@T9205mOG`1[Jf/0C4a<038b<P0`<300<c<c030`<00W
9bL0:RXZ03Xj>P0e=CD0=cLg03Hf=P0e=CD0@D510P14A4@01`1FEUH0Cdm?04e=C@0_;bl0:RXZ02`/
;00^;Rh00`0Z:RX00`0k>c/0Fe]K06YZJP0205MGE`0C06IVIP1WIfL0E5AD04i>CP1LG5`0GUiN065Q
H@1_Kfl0LW9b07=cL`1iNGT0MWIf07emO@1lO7`0OGem08>3P`22PX80P82007moO`0308:2PP0708>3
P`21PH40R8R8096AT@27QhL0QXJ608Z:RP0208V9R@0G08b<S02>SXh0SHf=08f=S@2;Rh/0Shn?08R8
R026QXH0RXZ:08N7Q`2:RXX0SHf=08V9R@2;Rh/0TY:B08n?S`2<S8`0R8R808B4Q028R8P0S8b<08Z:
RP2BTY800P2<S8`01P2:RXX0S8b<08n?S`2ATI40Ti>C08n?S`80T92@00H0SXj>08n?S`2ATI40TI6A
09VIV@2JVYX209fMW@0509nOW`2MWId0VIVI09bLW02KVi/0102FUYH20:2PX00V09jNWP2SXj<0[Jf]
0;Vi^@30`<00];Bd0:VYZ@2UYJD0X:2P09bLW02IVIT0WYjN0:BTY02[Zj/0[:b/09fMW@2;Rh/0OGem
07inOP20P800QHF508J6QP2?Shl0Rh^;08V9R@24Q8@0NWYj03hn?P0`<300;Rh^02/[:`0`<300;bl_
02/[:`0b<S80=CDe03Hf=P0i>CT202l_;`0H030`<00a<C40;bl_03Ph>00b<S80=SHf04E5A@16ATH0
?Shn04Q8B019BDT0EEEE051@D01JFUX0B4Q80492@P17AdL0F5QH059BDP13@d<0@D5103/k>`1:BTX0
ADE50P0_;bl0400T92@0:2PX02HV9P0U9BD0:BTY05ADE01oOgl0Vi^K0:NWY`2QXJ40MGEe07emO@24
Q8@0GEeM07emO@28R8P208f=S@0708^;R`2@T900SHf=09:BTP2?Shl0U9BD08n?S`0209RHV00809ZJ
VP2PX:00W9bL09bLW02JVYX0Vi^K09VIV@2JVYX209^KV`0;09FEU@2FUYH0Vi^K09RHV02GUiL0Vi^K
09FEU@2CTi<0U9BD096AT@2DU9@00P2EUID00`2IVIT0V9RH09VIV@0409BDU00A09RHV02FUYH0U9BD
09:BTP2<S8`0TI6A09:BTP2@T900Ti>C09:BTP2CTi<0TI6A08j>SP2BTY80T92@08n?S`2=SHd00`2;
Rh/01P2:RXX0SXj>08V9R@2;Rh/0P82008:2PP80Ph>300L0Rh^;09VIV@2VYZH0/;2`0;Rh^02k^k/0
`l?30080a/K600<0b<S80<[:bP3:b/X00P3=cLd00`3AdM40d];B0=?Cd`030=?Cd`030=3@d03Bd]80
d=3@00@0d=3@00<0dm?C0=7Ad@3AdM400P3@d=001P3Cdm<0dM7A0=;BdP3@d=00clo?0=3@d080dm?C
0P3AdM401@3Cdm<0dM7A0=GEe@3IfMT0e]KF0080eMGE00`0emOG0=CDe03Cdm<0e=CD0=7Ad@3EeMD0
dm?C0=GEe@3De=@0d];B0=7Ad@3De=@>0<SPf0003038h=P204Y:BP030451@@0l?3`0>c/k0080?clo
00T0ATI603lo?`15ADD0@D5104Q8B015ADD0BDU904Y:BP12@T800P13@d<03`10@400?clo04E5A@16
ATH0@d=304M7A`1?Cdl0E5AD05aLG01YJFT0Ng]k08>3P`27QhL0SHf=09FEU@0209bLW00709jNWP2T
Y:@0YjNW0:NWY`2XZ:P0YjNW0:j^[P020:VYZ@0<0:n_[`2^[Zh0[Jf]0:f][@2b/[80/K6a0;:b/P2c
/k<0]kNg0;Jf]P2d];@0/k>c0P2^[Zh0A`2XZ:P0Xj>S09VIV@2EUID0T92@08F5Q@1mOGd0Lg=c06QX
J01ADE40BTY:04M7A`18B4P0BTY:04m?C`1BDU80EEEE061PH01nOWh0TY:B08^;R`1]KFd0HF5Q06AT
I01WIfL0IFEU071`L024Q8@0MgMg06][J`1DE5@0>c/k04Y:BP1HF5P0A4A403@d=00i>CT0E5AD07al
O01XJ6P0EUIF04A4A00Z:RX0=cLg03`l?00e=CD0=3@d04U9B@1ADE40@T9203Ti>@0o?cl0?Shn05=C
D`15ADD0?3`l0410@01ADE40HF5Q04i>CP1:BTX0G5aL04];B`1>CTh0@T9203/k>`17AdL0BDU904e=
C@1CDe<0DE5A0080EEEE01/0LG5a05iNGP0o?cl0;Bd]03<c<`0k>c/0F5QH08:2PP2KVi/0QXJ606i^
KP1jNWX0SXj>09bLW026QXH0Fe]K02LW9`0N7Qh07alO02DU9@0S8b<0<S8b05IFEP1/K6`0PX:208N7
Q`2ATI400P2SXj<01P2DU9@0S8b<08R8R01nOWh0RXZ:0:BTY080]kNg02H0][Jf0<;2`P34a<@0];Bd
06UYJ@1JFUX0K6a/06IVIP1JFUX0Hf=S06][J`1hN7P0SXj>0;jn_P2KVi/0>CTi02PX:00a<C40:b/[
02`/;00V9RH0:RXZ0410@01EEED0Hf=S04I6AP0g=cL0>SXj03<c<`0d=3@0:b/[02`/;00o?cl0;bl_
03<c<`0[:b/0=CDe03@d=080@T9200L0De=C055AD@18B4P0<C4a038b<P0Y:BT0;2`/0080:RXZ00T0
:2PX03Ph>01PH600FUYJ069RHP1NGUh0Kfm_06ATI01LG5`00P1JFUX04@1TI6@0IfMW07MgM`1`L700
LG5a07MgM`1iNGT0PH6107emO@23Ph<0Ogmo0861P@1oOgl0QHF508:2PP21PH40PX:20080QHF500X0
R8R808V9R@2:RXX0S8b<08R8R029RHT0QhN708f=S@2<S8`0RXZ:0P2;Rh/01P28R8P0RXZ:08V9R@27
QhL0Rh^;08V9R@80SXj>00@0T92@096AT@2=SHd0Shn?0P2<S8`0702?Shl0SXj>08f=S@2CTi<0RXZ:
08b<S02:RXX0RHV908b<S02CTi<0T92@08n?S`2ATI40SXj>08n?S`2<S8`0SHf=092@T02DU9@0UYJF
09^KV`2IVIT0WinO0:6QX@2RXZ80XJ6Q0:FUY@2WYjL20:VYZ@0@0:j^[P2c/k<0^KVi0;fm_@2l_;`0
b/[:0=CDe03@d=00bl_;0;jn_P2j^[X0[jn_0;2`/02^[Zh0[Jf]0;Rh^080][Jf01T0YZJV08f=S@29
RHT0QXJ608B4Q027QhL0R8R808V9R@2?Shl0SXj>08R8R01kNg/0F5QH03hn?P0_;bl0:RXZ030`<00X
:2P0;2`/02h^;P0e=CD0=SHf04];B`0d=3@0<C4a0080;bl_00D0<S8b03Ti>@0g=cL0<c<c03hn?P02
04E5A@0A04Q8B01;Bd/0De=C04m?C`1BDU80ADE50451@@1:BTX0C4a<04E5A@1;Bd/0ATI603/k>`17
AdL0?Shn030`<00];Bd00P0T92@03P0W9bL09RHV02XZ:P1NGUh0Ng]k09ZJVP2^[Zh0Vi^K07QhN026
QXH0OWin04i>CP1mOGd0Q8B40P2=SHd02026QXH0T92@08f=S@2=SHd0TY:B09>CT`2<S8`0V9RH0P2M
WId209bLW00;09RHV02KVi/0WIfM09ZJVP2KVi/0V9RH09NGU`2IVIT0U9BD09VIV@2DU9@00`2GUiL0
3@2DU9@0TI6A09BDU02EUID0TI6A09FEU@2FUYH0VYZJ09>CT`2FUYH0U9BD09:BTP2DU9@00P2CTi<0
1`2EUID0Ti>C08b<S02?Shl0Ti>C09BDU02@T9000P2?Shl01`2EUID0T92@096AT@2ATI40Rh^;08n?
S`2@T9000P2=SHd208Z:RP0B08R8R027QhL0PX:208F5Q@1mOGd0P82008N7Q`2FUYH0YjNW0;6a/@2j
^[X0_[jn0<;2`P37alL0a<C40<S8b03:b/X0bl_;0P3<c<`20=3@d0060=7Ad@3GemL0emOG0=CDe03?
cll0dM7A0P3@d=00103=cLd0c/k>0=3@d03@d=020=7Ad@080=?Cd`3AdM40d];B0=3@d03AdM40d=3@
0=7Ad@3@d=020=7Ad@030=?Cd`3Bd]80dm?C0080dm?C00@0emOG0=?Cd`3EeMD0eMGE0P3De=@20=?C
d`080=GEe@3?cll0dm?C0=KFeP3Cdm<0e=CD0=?Cd`3EeMD>0<SPf0003038h=P204=3@`0T04I6AP11
@D40A4A40492@P0o?cl0Bd];0492@P18B4P0AdM704I6AP13@d<0B4Q804E5A@11@D40?Cdm03lo?`11
@D40?Cdm04M7A`18B4P0A4A404Y:BP1>CTh0Fe]K05iNGP1XJ6P0O7al0820P028R8P0TY:B09BDU02L
W9`0WIfM09jNWP2RXZ80YJFU0P2XZ:P00`2[Zj/0[:b/0:b/[0020:b/[0030;2`/02][Jd0[Zj^00<0
/;2`00<0/K6a0;Vi^@2f][H00P2c/k<0302a/K40[jn_0:JVYP2VYZH0VYZJ09FEU@2?Shl0Ph>307in
OP1]KFd0HV9R05=CD`80ADE502@0AdM704e=C@1:BTX0De=C055AD@1HF5P0Jf][0861P@2FUYH0R8R8
06a/K01[Jf/0J6QX06IVIP1_Kfl0PH6107alO01eMGD0EUIF03@d=01<C4`0EUIF05YJFP1:BTX0ATI6
04m?C`1hN7P0J6QX069RHP15ADD0;Bd]03Lg=`0f=SH0?3`l030`<00h>3P204I6AP0E03lo?`0k>c/0
ADE5051@D016ATH0?3`l04A4A01?Cdl0CDe=04I6AP1EEED0F5QH04a<C013@d<0>SXj03hn?P14A4@0
AdM704I6AP1DE5@0GemO0080GUiN00L0Hf=S03Xj>P0^;Rh0<30`03hn?P1BDU80MGEe0080U9BD04<0
MgMg075aL@1lO7`0Ti>C092@T02?Shl0PH6103/k>`0O7al06a/K01dM7@0W9bL0:BTY034a<@17AdL0
J6QX07alO024Q8@0Rh^;07inOP1aLG40KFe]06UYJ@1dM7@0Ph>308^;R`2WYjL0YZJV0:RXZ02h^;P0
aLG50<71`@2YZJT0EUIF05YJFP1bLW80EUIF05QHF01SHf<0IVIV07IfMP2WYjL0_[jn079bLP0Z:RX0
9RHV02PX:00T92@09RHV02PX:00g=cL0CDe=055AD@11@D40=3@d034a<@0`<300;bl_02PX:00[:b/0
>3Ph030`<00g=cL0<S8b03@d=00j>SX0AdM70080B4Q800H0AdM70451@@0`<300;Rh^038b<P0V9RH2
02`/;00@02PX:00e=CD0IFEU06MWI`1OGel0GEeM06m_K`1OGel0C4a<055AD@1KFe/0HF5Q06MWI`1h
N7P0L71`07AdM0<0NGUi00D0OGem08F5Q@1kNg/0Ogmo0861P@0308:2PP0808V9R@23Ph<0QhN708F5
Q@2<S8`0RXZ:08f=S@2@T90208b<S00708n?S`29RHT0SHf=08^;R`2?Shl0RXZ:08V9R@0308R8R00;
08^;R`2=SHd0S8b<096AT@2=SHd0SXj>08^;R`2>SXh0SHf=096AT@2?Shl00`2ATI40302DU9@0TY:B
08b<S02BTY80UIFE08n?S`2>SXh0SHf=096AT@2BTY80SXj>08f=S@80TI6A00T0Ti>C09FEU@2KVi/0
VIVI09^KV`2NWYh0Y:BT0:FUY@2c/k<00P2f][H03030`<00b/[:0<g=c@3EeMD0dM7A0<_;b`34a<@0
`/;20<G5a@3=cLd0e=CD0<[:bP80`L7100P0`<300;no_`2o_kl0]KFe0:RXZ02EUID0SXj>08V9R@80
RXZ:02<0Rh^;08V9R@2:RXX0Rh^;08R8R021PH40Ng]k03dm?@0/;2`0:BTY02l_;`0[:b/0;Rh^03@d
=00];Bd0>CTi04A4A00d=3@0<S8b03@d=00/;2`0;Rh^030`<00g=cL0=3@d03dm?@10@400ATI604a<
C01:BTX0DE5A04a<C01FEUH0@d=30451@@0204a<C0060451@@12@T80@T9203lo?`17AdL0>CTi0P0`
<300400/;2`09RHV02LW9`0V9RH0;bl_06][J`1kNg/0W9bL0:^[Z`2@T900MGEe08j>SP1mOGd0Bd];
07AdM022PX8308R8R080SXj>00L0Ti>C092@T02GUiL0TY:B09FEU@2MWId0Vi^K0080W9bL00L0UiNG
09ZJVP2HV9P0W9bL09ZJVP2LW9`0UiNG0080V9RH00@0UiNG09ZJVP2CTi<0U9BD0P2ATI402`2CTi<0
TI6A09>CT`2CTi<0U9BD09:BTP2DU9@0T92@09JFUP2GUiL0T92@0080Ti>C0P2DU9@00`2JVYX0Ti>C
09BDU00309:BTP08096AT@2DU9@0Shn?08n?S`2ATI40TY:B092@T02>SXh208^;R`0508j>SP29RHT0
R8R808b<S029RHT00P24Q8@02021PH40OGem08^;R`2GUiL0Xj>S0:n_[`2g]kL0_[jn0P34a<@00`35
aLD0a/K60<S8b0020<_;b`030<o?c`3>c/h0dM7A00@0dM7A00<0d=3@0=;BdP3@d=000`3?cll0303@
d=00clo?0=;BdP3AdM40d];B0=7Ad@3?cll0d];B0<o?c`3>c/h0clo?0<g=c@<0d=3@00<0d];B0=CD
e03De=@01@3De=@00`3EeMD0e=CD0=GEe@020=?Cd`070=CDe03Cdm<0e=CD0=KFeP3De=@0dm?C0=CD
e00>0<SPf0003038h=P204e=C@0;04Y:BP14A4@0ATI604Y:BP10@400B4Q804I6AP14A4@0B4Q804I6
AP14A4@00P13@d<00`15ADD0@D5103`l?00203hn?P0F0492@P13@d<0CTi>04i>CP1ADE40De=C05eM
G@1`L700MgMg07emO@24Q8@0SHf=09FEU@2HV9P0WIfM09nOW`2SXj<0YJFU0:JVYP2YZJT0Zj^[0:VY
Z@80YjNW00<0ZZZZ0:f][@2[Zj/00P2^[Zh0502c/k<0/;2`0;2`/02a/K40][Jf0;:b/P2c/k<0];Bd
0:^[Z`2UYJD0X:2P09bLW02DU9@0Ti>C08B4Q01kNg/0Lg=c069RHP1DE5@0B4Q80P15ADD0:P1>CTh0
De=C05MGE`1EEED0FEUI05eMG@1^KVh0R8R809^KV`21PH40IVIV06MWI`1VIVH0KVi^08J6QP20P800
MgMg05QHF00d=3@0?3`l04A4A01CDe<0IFEU06QXJ01OGel0KFe]07YjNP1hN7P0F5QH03Xj>P0/;2`0
=cLg03/k>`0d=3@0<S8b03lo?`1IFET0CTi>03hn?P15ADD0C4a<04M7A`80ATI600h0?Cdm03`l?011
@D40HF5Q04a<C01>CTh0ATI60451@@1;Bd/0A4A40492@P18B4P0GUiN06QXJ080IFEU02h0@d=303Ti
>@0c<c<0=CDe051@D01cLg<0QhN708V9R@1eMGD0Jf][06m_K`1jNWX0RHV907inOP2BTY80WYjN07em
O@0_;bl08B4Q02/[:`10@400:b/[020P800V9RH0DU9B07AdM01bLW80Jf][06UYJ@1NGUh0H61P05mO
G`1_Kfl0PX:208Z:RP2DU9@0X:2P09^KV`2_[jl0_[jn0<K6aP30`<00T92@05=CD`1RHV80H61P0P1G
EeL01P1MGEd0IVIV08F5Q@2k^k/0]KFe0410@080:BTY00/092@T02PX:00V9RH0;Bd]0492@P1BDU80
>3Ph03<c<`0i>CT0<S8b03Ti>@0202l_;`0?03Ph>00e=CD0>CTi02l_;`0j>SX0=cLg04=3@`1;Bd/0
DE5A03lo?`0k>c/0>3Ph02l_;`0];Bd09RHV0080:b/[00<0:2PX03hn?P1ZJVX00P1VIVH03P1JFUX0
LG5a06EUI@1CDe<0G5aL069RHP1WIfL0JVYZ07=cL`1_Kfl0MWIf08:2PP1mOGd0O7al0P23Ph<02@1k
Ng/0Ph>307emO@21PH40PX:207inOP23Ph<0QHF508R8R00208V9R@80R8R800h0QhN708b<S02>SXh0
TY:B08^;R`2>SXh0S8b<092@T02<S8`0R8R808V9R@2:RXX0Rh^;08j>SP80RXZ:00H0SHf=08j>SP2:
RXX0TY:B08j>SP2?Shl409:BTP0809>CT`2@T900SHf=096AT@2EUID0Ti>C08n?S`2>SXh209:BTP09
09FEU@2@T900T92@09VIV@2DU9@0Ti>C09JFUP2KVi/0UiNG0080Vi^K00<0WYjN0:2PX02/[:`00P2a
/K401P34a<@0clo?0<_;b`3AdM40clo?0;jn_P80/K6a0180^;Rh0<W9b@3Cdm<0dm?C0=3@d03<c<`0
bLW90<30`02n_[h0];Bd0:BTY02IVIT0SXj>08V9R@2ATI40Shn?08^;R`2<S8`208^;R`0@08f=S@22
PX80PH6104e=C@0e=CD0:BTY02d];@0^;Rh0;bl_02h^;P0/;2`0>SXj03Ph>00c<c<0<S8b034a<@80
;Bd]00l0<S8b04=3@`0g=cL0?clo03`l?00k>c/0@d=304Q8B01@D500C4a<04i>CP16ATH0@T9204U9
B@14A4@00P0i>CT01`13@d<0>CTi03/k>`0j>SX0;2`/030`<00Z:RX00`0W9bL0300g=cL0KVi^0820
P02MWId0[Jf]08f=S@1`L700TY:B07EeM@15ADD0LG5a08B4Q080PH6101T0S8b<08^;R`2>SXh0SHf=
08n?S`2CTi<0TY:B09bLW02KVi/0W9bL0::RXP2JVYX0W9bL09fMW@2IVIT0X:2P09JFUP2KVi/0WinO
09JFUP2EUID0VIVI09ZJVP2GUiL0Ti>C0080UIFE00L0U9BD09JFUP2FUYH0TY:B09FEU@2CTi<0U9BD
0080UIFE00@0U9BD09NGU`2@T900Ti>C0P2ATI402P2EUID0TI6A096AT@2?Shl0Ti>C092@T02DU9@0
TI6A08f=S@2@T902096AT@0N08j>SP2ATI40TI6A08^;R`2>SXh0RHV908^;R`26QXH0PX:208>3P`24
Q8@0Ph>30861P@25QHD0VIVI0:>SX`2^[Zh0^KVi0;jn_P33`l<0a/K60<C4a035aLD0a<C40<O7a`3:
b/X0c<c<0<g=c@3>c/h0d];B103AdM420=3@d0040<o?c`3@d=00d=3@0=3@d080clo?0P3AdM40103C
dm<0dM7A0<o?c`3AdM420<k>cP0=0=3@d03AdM40d=3@0=3@d03AdM40eMGE0=;BdP3Cdm<0e=CD0=KF
eP3De=@0dm?C0=GEe@020=CDe080d];B0`3Cdm<40=CDe0h0b>3H000<0<SPf080BTY:0140ADE504Y:
BP17AdL0AdM704Q8B01;Bd/0@41004Y:BP14A4@0ATI604M7A`18B4P0BDU904E5A@19BDT0@D510492
@P0203hn?P0<04Q8B01=CDd0D51@04];B`1EEED0GemO071`L01hN7P0O7al08R8R02>SXh0UIFE0P2K
Vi/01`2OWil0Xj>S0:FUY@2VYZH0YjNW0:VYZ@2[Zj/00P2][Jd0202/[:`0ZZZZ0:b/[02_[jl0/;2`
0:n_[`2^[Zh0[Jf]0P2c/k<04@2a/K40]KFe0;6a/@2/[:`0YZJV0:>SX`2MWId0UiNG09BDU023Ph<0
NWYj06m_K`1PH600EUIF04Y:BP18B4P0A4A40080D51@0`1BDU8205eMG@0M07QhN02:RXX0Ti>C075a
L@1`L700K6a/06][J`1kNg/0QXJ607IfMP1OGel0=3@d03dm?@12@T80@41005MGE`1_Kfl0KFe]071`
L01lO7`0OWin06QXJ00f=SH0:BTY030`<00j>SX0>c/k03De=@0l?3`00P1DE5@05018B4P0@d=304A4
A010@400D51@0451@@0e=CD0<C4a05ADE01PH600Bd];04Y:BP0h>3P0BDU904m?C`14A4@0?clo051@
D01WIfL0MGEe0P1DE5@01P0d=3@0BDU904=3@`1ADE40Ng]k0820P080Ng]k03T0JFUY07EeM@1]KFd0
Ph>307YjNP1EEED0Q8B40:NWY`2BTY80>SXj02@T900a<C40?3`l02PX:00Q8B40:b/[0451@@1IFET0
GEeM06=SH`1UIFD0H61P06a/K01QHF40IfMW07QhN027QhL0UIFE09nOW`2KVi/0Z:RX0;Jf]P31`L40
a/K60;^k^`1fMWH0EeMG06EUI@1SHf<0Fe]K05YJFP1IFET0L71`09>CT`31`L40W9bL03hn?P0X:2P0
;2`/02TY:@0T92@0:RXZ03Lg=`0f=SH0<30`03@d=00h>3P00P0g=cL04@0[:b/0<S8b03/k>`0`<300
<S8b02l_;`11@D40=CDe04A4A01<C4`0CDe=0492@P0f=SH0=cLg02l_;`0^;Rh0<30`0080:b/[00d0
9bLW0492@P1YJFT0HF5Q06ATI01PH600NWYj06ATI01:BTX0G5aL069RHP1YJFT0KFe]00<0MGEe0P1l
O7`0101nOWh0NWYj08:2PP24Q8@207moO`0407inOP20P800Ogmo08F5Q@80QXJ600@0RXZ:08^;R`28
R8P0RHV90P2;Rh/2092@T00>08R8R02<S8`0RXZ:08n?S`2;Rh/0Shn?08N7Q`28R8P0Rh^;08f=S@2;
Rh/0Shn?08j>SP2=SHd2096AT@0609>CT`2EUID0UIFE09:BTP2?Shl0TI6A0P2BTY801P2@T900UYJF
09RHV02IVIT0TI6A09FEU@80U9BD0P2BTY801P2CTi<0UiNG09NGU`2HV9P0UYJF09ZJVP80Vi^K00@0
X:2P0:6QX@2WYjL0ZZZZ0P2^[Zh05P34a<@0clo?0=7Ad@3=cLd0c<c<0<30`02][Jd0ZZZZ0;6a/@2j
^[X0bLW90<k>cP3;bl/0cLg=0<C4a02k^k/0_Kfm0;:b/P2UYJD0W9bL08n?S`2<S8`208f=S@0O096A
T@2>SXh0RXZ:08V9R@2>SXh0Q8B408>3P`1`L700?Shn03@d=00];Bd0;Rh^02/[:`0b<S80;Rh^030`
<00b<S80<C4a030`<00^;Rh0:b/[03De=@0h>3P0=3@d03<c<`0n?Sh0@D5103hn?P17AdL0Bd];051@
D002055AD@0L04e=C@14A4@0Bd];04Y:BP0h>3P0;bl_04E5A@0i>CT0=SHf03lo?`0b<S80<c<c02XZ
:P0[:b/0:2PX02TY:@0o?cl0L71`08Z:RP2MWId0[Jf]08b<S01dM7@0TY:B06QXJ019BDT0M7Ad08B4
Q080Ph>300l0RHV9092@T02?Shl0SXj>09:BTP2EUID0T92@09>CT`2JVYX0W9bL09ZJVP2HV9P0VYZJ
09nOW`2NWYh00P2JVYX01`2HV9P0UIFE09VIV@2HV9P0W9bL09RHV02LW9`0102EUID01`2FUYH0W9bL
09BDU02DU9@0Ti>C09BDU02CTi<0102DU9@01`2BTY80Ti>C096AT@2DU9@0Ti>C09:BTP2ATI400P2@
T900902?Shl0TY:B09BDU02=SHd0Ti>C096AT@2BTY80SXj>08Z:RP2?Shl0SXj>08Z:RP26QXH0QhN7
08:2PP23Ph<0Ogmo0861P@24Q8@0QXJ609JFUP2RXZ80[Zj^0;Ng]`2o_kl0`L710<G5a@33`l<0a<C4
0<K6aP37alL0b<S80<[:bP3>c/h0cLg=0=;BdP80c/k>00D0dM7A0=;BdP3@d=00c<c<0=;BdP020<o?
c`040=3@d03>c/h0d=3@0<o?c`80dM7A00<0d=3@0=7Ad@3?cll00P3?cll01P3Bd]80clo?0<o?c`3@
d=00c/k>0=7Ad@80d];B00@0e=CD0=GEe@3De=@0d];B0`3Cdm<01P3AdM40d];B0=?Cd`3Cdm<0eMGE
0=CDe080dm?C00<0e=CD0<SPf038h=P03038h=P000`0b>3H0P19BDT01P16ATH0BDU904Q8B019BDT0
AdM704=3@`80AdM701X0@d=30410@013@d<0A4A404E5A@13@d<0@T9203dm?@16ATH0?Cdm04=3@`12
@T80AdM704i>CP1?Cdl0F5QH069RHP1aLG40OGem08>3P`2<S8`0TI6A09JFUP2HV9P0W9bL09nOW`80
Xj>S00@0Y:BT0:RXZ02[Zj/0ZJVY0P2[Zj/0202ZZZX0[Zj^0:b/[02_[jl0[Zj^0:b/[02_[jl0/K6a
0P2c/k<05P2d];@0/[:b0;2`/02YZJT0Y:BT0::RXP2IVIT0UYJF08Z:RP23Ph<0NGUi071`L01OGel0
E5AD04m?C`16ATH0B4Q804i>CP1=CDd0EEEE05mOG`1EEED205MGE`0<06IVIP1hN7P0T92@09:BTP1d
M7@0Kfm_06MWI`1gMgL0Q8B407IfMP1UIFD0>c/k0P13@d<09@0l?3`0ADE505iNGP1^KVh0Jf][07]k
N`22PX80LG5a03dm?@0X:2P0<30`03<c<`0e=CD0>c/k05iNGP0l?3`0DU9B04E5A@0m?Cd0>CTi03hn
?P19BDT0@T9203/k>`0g=cL0GEeM05=CD`11@D40?Shn04E5A@1=CDd0ATI604Q8B011@D40DU9B07Ui
N@1aLG400P0k>c/02@0b<S80C4a<05QHF01dM7@0Ogmo08J6QP20P800Kfm_08:2PP0207alO01908V9
R@1UIFD0=cLg06YZJP2MWId0VIVI05=CD`0_;bl0>3Ph02`/;00X:2P0;2`/03lo?`1;Bd/0<S8b03@d
=014A4@0EeMG06IVIP1]KFd0IFEU06YZJP1dM7@0OWin092@T02GUiL0XZ:R0:JVYP2_[jl0^;Rh0<?3
``30`<00/K6a06EUI@1MGEd0Fe]K05IFEP1IFET0FUYJ05mOG`1bLW80VYZJ0<;2`P2EUID0>SXj02XZ
:P0V9RH0:RXZ02d];@0h>3P0=3@d02l_;`0f=SH0A4A403Ph>00b<S80;Rh^03<c<`0e=CD0<c<c02`/
;00d=3@0?Cdm03Ph>01:BTX0@D5103dm?@12@T80;Bd]02h^;P0d=3@0<30`02`/;00202TY:@0>02XZ
:P11@D40Hf=S06ATI01WIfL0GemO07]kN`1IFET0DE5A05iNGP1YJFT0MWIf06i^KP1]KFd207MgM`05
07QhN01mOGd0OWin0861P@22PX800P21PH405@20P800QhN708>3P`1oOgl0PX:208B4Q023Ph<0Rh^;
08N7Q`26QXH0RHV908^;R`2?Shl0S8b<092@T02<S8`0Rh^;08R8R029RHT0Rh^;09:BTP0208Z:RP04
08j>SP2@T900SHf=08^;R`80SXj>00<0UYJF09BDU02CTi<00P2EUID0102DU9@0UIFE09FEU@2GUiL2
09:BTP0=09NGU`2LW9`0W9bL09>CT`2DU9@0UiNG09JFUP2@T900U9BD096AT@2FUYH0U9BD09FEU@02
09^KV`0609VIV@2KVi/0VYZJ09fMW@2TY:@0Zj^[0P2`/;00E@34a<@0e=CD0=?Cd`3>c/h0cLg=0<G5
a@2a/K40YjNW0:j^[P2g]kL0alO70<c<c03=cLd0`l?30<30`02o_kl0_;bl0:n_[`2UYJD0W9bL09BD
U02?Shl0T92@09:BTP2CTi<0S8b<08^;R`26QXH0S8b<08V9R@24Q8@0OWin04i>CP0_;bl0;Rh^03Lg
=`0];Bd0<C4a02h^;P0/;2`0>3Ph02l_;`0];Bd0=cLg038b<P0_;bl0;2`/03<c<`0l?3`0ADE504=3
@`0h>3P0=cLg05=CD`1BDU80Fe]K04];B`17AdL0@d=304E5A@1@D500?clo03Hf=P17AdL0@d=3038b
<P11@D40<C4a03@d=00W9bL0;2`/02LW9`0V9RH0ATI606i^KP29RHT0XJ6Q0:ZZZP24Q8@0L71`08b<
S01VIVH0Cdm?07IfMP23Ph<00P21PH405P28R8P0T92@08j>SP2>SXh0TI6A09:BTP2ATI40U9BD09^K
V`2OWil0WIfM09RHV02GUiL0VYZJ09^KV`2GUiL0W9bL09^KV`2EUID0Vi^K09ZJVP2HV9P209JFUP0:
09ZJVP2CTi<0Ti>C09>CT`2EUID0UiNG09RHV02FUYH0Shn?09BDU080UiNG00@0TY:B09JFUP2CTi<0
Ti>C0`2BTY80102@T900Ti>C096AT@2EUID209>CT`0808f=S@2FUYH0UYJF096AT@2@T900TY:B08Z:
RP2@T90208j>SP0708N7Q`2:RXX0Q8B408B4Q022PX80Q8B408J6QP020861P@0509JFUP2SXj<0Zj^[
0;Ng]`2n_[h00P34a<@01`36a/H0a<C40<;2`P34a<@0a/K60<W9b@3<c<`0103=cLd30=;BdP040=3@
d03?cll0c/k>0=3@d080clo?00<0d=3@0<o?c`3@d=000`3AdM400`3?cll0c/k>0<o?c`020=7Ad@07
0<g=c@3@d=00c/k>0<o?c`3@d=00d];B0=?Cd`020=KFeP070=CDe03EeMD0dm?C0=?Cd`3Bd]80d=3@
0=?Cd`020=;BdP040=7Ad@3Cdm<0e=CD0=GEe@h0b>3H000<0<SPf080B4Q800X0C4a<04];B`16ATH0
B4Q804Y:BP1<C4`0Bd];04I6AP13@d<0BDU90P1:BTX07014A4@0?clo03dm?@11@D40A4A403hn?P12
@T80@41004E5A@1<C4`0E5AD05]KF`1TI6@0Lg=c07emO@25QHD0S8b<08j>SP2KVi/0VYZJ09fMW@2R
XZ80YjNW0:BTY02VYZH0YJFU0:^[Z`2/[:`20:VYZ@050:ZZZP2YZJT0ZZZZ0:f][@2a/K400P2_[jl0
7P2d];@0]KFe0;>c/`2d];@0][Jf0:n_[`2/[:`0Z:RX0:2PX02KVi/0U9BD08^;R`2:RXX0NWYj06m_
K`1SHf<0G5aL04Q8B013@d<0CDe=04];B`1=CDd0De=C05IFEP1BDU80G5aL05YJFP1OGel0JFUY08B4
Q080UiNG01<0LW9b06][J`1`L700O7al07QhN01PH600?Shn03Hf=P14A4@0@T9203Ph>01BDU80E5AD
06MWI`1iNGT0QXJ607alO01=CDd09BDU0080:b/[01T0;Bd]05]KF`1TI6@0=CDe03`l?015ADD0>3Ph
030`<00h>3P0BDU904I6AP0e=CD0ATI605mOG`11@D40?Cdm0492@P1>CTh0De=C0492@P1<C4`0EeMG
04e=C@1lO7`0L71`0080=cLg00X0@41004];B`1OGel0IVIV08J6QP2<S8`0LW9b07UiN@2JVYX0NGUi
0P1oOgl0>019BDT0<S8b04Y:BP2:RXX0T92@069RHP12@T80?3`l02`/;00_;bl0<S8b03`l?00];Bd0
:2PX02LW9`0f=SH0ATI605]KF`1JFUX0IfMW07UiN@1nOWh0RXZ:08n?S`2GUiL0V9RH0:JVYP2][Jd0
/;2`0<71`@33`l<0_[jn09nOW`1KFe/0GEeM06e]K@1PH600FEUI05eMG@1VIVH0O7al0:b/[030`<00
KVi^02l_;`0Z:RX092@T02PX:00[:b/0:RXZ02/[:`0m?Cd0@410030`<00c<c<0<30`0P0a<C403P0Z
:RX0;Rh^03Hf=P0n?Sh0;bl_04i>CP14A4@0?Shn03`l?00a<C40;Bd]03Hf=P0_;bl09bLW0P0V9RH0
6@0Z:RX0ATI606a/K01UIFD0J6QX05aLG01gMgL0F5QH05]KF`1SHf<0IFEU06m_K`1`L700LG5a079b
LP1fMWH0NGUi07emO@1kNg/0OWin0861P@20P800PX:208B4Q01oOgl00P22PX801@20P800R8R808N7
Q`2;Rh/0R8R80080RHV901<0SXj>08f=S@28R8P0SHf=08j>SP2<S8`0R8R808b<S02@T900TY:B08f=
S@2<S8`0T92@08j>SP2CTi<0SHf=09BDU02ATI40UYJF0080U9BD00<0VIVI09NGU`2EUID00P2CTi<0
202IVIT0V9RH09VIV@2HV9P0VIVI0:2PX02JVYX0VIVI0P2CTi<00`2BTY80UYJF092@T00209NGU`07
09BDU02FUYH0VIVI09JFUP2JVYX0VIVI09fMW@020:FUY@80/;2`0280`/;20=;BdP3?cll0c/k>0<c<
c031`L40]KFe0:b/[02`/;00_kno0<g=c@3<c<`0b/[:0<G5a@32`/80_[jn0;Vi^@2^[Zh0ZJVY0:6Q
X@2IVIT0T92@08n?S`2BTY80U9BD092@T02>SXh0RHV908Z:RP2=SHd0QHF507emO@1XJ6P0=cLg0`0^
;Rh01`0_;bl0;Bd]02h^;P0`<300<S8b02l_;`0d=3@00P0];Bd05@0Z:RX0<30`03Hf=P11@D40B4Q8
0492@P0i>CT0BTY:051@D01JFUX0DE5A04Q8B012@T80@410051@D013@d<0>CTi0492@P15ADD0>CTi
03De=@02034a<@0@02XZ:P0/;2`092@T02l_;`0n?Sh0L71`08f=S@2RXZ80Xj>S07emO@1gMgL0Rh^;
06IVIP1>CTh0Kfm_07]kN`80MgMg01@0QXJ6092@T02BTY80TY:B09BDU02@T900Shn?09>CT`2GUiL0
Vi^K0:2PX02JVYX0V9RH09VIV@2GUiL0V9RH09jNWP2JVYX0Vi^K09NGU`80UYJF00d0VIVI09BDU02F
UYH0TI6A09FEU@2FUYH0UIFE09JFUP2BTY80Ti>C09NGU`2DU9@0UIFE0080UYJF00`0U9BD09NGU`2C
Ti<0Ti>C09:BTP2>SXh0Shn?096AT@2GUiL0T92@08f=S@2;Rh/2092@T080Shn?01P0TY:B092@T02F
UYH0SHf=08n?S`2:RXX0S8b<08f=S@2<S8`0R8R808N7Q`28R8P0OGem08F5Q@24Q8@0TI6A09jNWP2Y
ZJT0][Jf0;fm_@32`/80a<C40<?3``36a/H30<C4a0040<S8b03:b/X0bl_;0=3@d080clo?00@0dM7A
0=CDe03Cdm<0clo?0`3@d=00103AdM40c/k>0<k>cP3@d=020=7Ad@<0d=3@00`0clo?0=3@d03Bd]80
dM7A0<k>cP3@d=00c/k>0=;BdP3?cll0dM7A0=;BdP3EeMD20=?Cd`030=CDe03Cdm<0d];B0080dM7A
00@0e=CD0=3@d03Bd]80e=CD0P3Cdm<00`3De=@0b>3H0<SPf00<0<SPf0003038h=P204i>CP0>04m?
C`14A4@0ATI604M7A`1=CDd0B4Q804I6AP18B4P0AdM704e=C@1>CTh0BTY:04U9B@16ATH204=3@`0A
03dm?@0l?3`0>CTi0410@015ADD0Bd];05UIF@1PH600IVIV071`L021PH40Ph>308V9R@2DU9@0UYJF
09NGU`2NWYh00P2QXJ430:NWY`0:0:^[Z`2XZ:P0Zj^[0:^[Z`2ZZZX0Z:RX0:^[Z`2/[:`0[Jf]0:b/
[080/[:b0140^;Rh0;Jf]P2e]KD0/[:b0:f][@2/[:`0YJFU09nOW`2MWId0UYJF08b<S027QhL0NGUi
06a/K01VIVH0FUYJ04];B`0204I6AP0K04Y:BP1;Bd/0De=C05iNGP1GEeL0H61P05eMG@1TI6@0IfMW
07AdM02:RXX0VIVI08b<S01cLg<0JVYZ07MgM`1jNWX0JFUY04i>CP0c<c<0>3Ph0451@@10@400DU9B
04Y:BP1HF5P0MWIf0080RHV901d0IfMW030`<00^;Rh0<c<c03Lg=`16ATH0A4A4038b<P0e=CD0?3`l
038b<P0e=CD0=cLg04m?C`15ADD0>3Ph04];B`1BDU80?clo03dm?@19BDT0FUYJ04i>CP17AdL0Bd];
05aLG01PH600MgMg06a/K00204i>CP1D04E5A@1ADE40D51@05UIF@24Q8@0PX:206UYJ@28R8P0WinO
07QhN021PH40IfMW03Xj>P0f=SH0BTY:07AdM01nOWh0K6a/04i>CP17AdL0>CTi03lo?`15ADD09BDU
01lO7`0L71`09RHV03dm?@0g=cL0A4A404a<C01HF5P0L71`09FEU@2LW9`0VYZJ09FEU@2BTY80XJ6Q
0:VYZ@2e]KD0^;Rh0<G5a@2n_[h0_;bl08J6QP1DE5@0K6a/05mOG`1JFUX0Fe]K05UIF@1`L700SHf=
0;no_`2c/k<0Fe]K02`/;00W9bL092@T02/[:`0];Bd0<S8b03@d=00^;Rh0<30`02TY:@0/;2`0<S8b
03<c<`0[:b/0;Bd]034a<@0c<c<0<S8b04];B`13@d<0>CTi03Hf=P0`<300<C4a03@d=00b<S80:2PX
0P0W9bL0400`<300C4a<07AdM01PH600JVYZ06MWI`1_Kfl0EUIF05iNGP1SHf<0JVYZ06i^KP1`L700
Lg=c07QhN01jNWX207MgM`060861P@1oOgl0OWin07inOP25QHD0Ph>30P22PX801@1lO7`0Ogmo08F5
Q@28R8P0Rh^;00<0QhN700D0SXj>08^;R`28R8P0RHV9092@T00208^;R`0D096AT@2;Rh/0Shn?08b<
S02?Shl0SXj>08f=S@2?Shl0SXj>09FEU@2DU9@0UiNG09JFUP2DU9@0UIFE09RHV02FUYH0UiNG09BD
U02IVIT209RHV00:09VIV@2OWil0Vi^K09NGU`2EUID0Ti>C09:BTP2?Shl0U9BD09NGU`80VYZJ00<0
UiNG092@T02HV9P00P2GUiL0102LW9`0UYJF0:>SX`2UYJD20:ZZZP0:0;jn_P3>c/h0dM7A0<k>cP38
b<P0_;bl0;:b/P2][Jd0/[:b0<G5a@80c/k>01P0bLW90<K6aP31`L40`l?30;Ng]`2a/K40YJFU0:6Q
X@2LW9`0U9BD08n?S`2@T900Shn?09:BTP2>SXh0RXZ:08V9R@28R8P0QhN708>3P`1gMgL0AdM702d]
;@0`<302034a<@0_02h^;P0g=cL0<C4a038b<P0a<C40=CDe034a<@0];Bd0;bl_03@d=00j>SX0@410
04=3@`16ATH0?3`l03hn?P1EEED0Cdm?05QHF018B4P0?3`l0410@01HF5P0B4Q803De=@17AdL0@d=3
03/k>`0_;bl0<c<c02l_;`0R8R80:2PX02<S8`0/;2`0>c/k07=cL`2BTY80Z:RX0::RXP1nOWh0PH61
08f=S@1RHV80BTY:06][J`1^KVh00P1eMGD03023Ph<0T92@08n?S`2CTi<0U9BD096AT@2?Shl0UIFE
09>CT`2HV9P0WinO09jNWP80Vi^K02`0VYZJ09^KV`2KVi/0VYZJ09NGU`2JVYX0VIVI09JFUP2CTi<0
UiNG09>CT`2GUiL0U9BD09FEU@2BTY80U9BD09>CT`2>SXh0Ti>C09VIV@2@T900UiNG09FEU@2FUYH0
Ti>C09:BTP2DU9@0S8b<09:BTP2?Shl0U9BD08j>SP2CTi<0TY:B08b<S02BTY80UIFE09:BTP2EUID0
Shn?096AT@2>SXh0T92@08f=S@80SXj>0P2<S8`0302;Rh/0QhN708N7Q`23Ph<0QHF508:2PP2ATI40
WinO0:NWY`2c/k<0_Kfm0<30`080`l?30P34a<@01033`l<0aLG50<O7a`38b<P20<c<c080d=3@00/0
dM7A0=3@d03@d=00d=3@0<o?c`3@d=00dM7A0<g=c@3>c/h0cLg=0<k>cP030<o?c`040=7Ad@3@d=00
clo?0<k>cP80dM7A00D0d=3@0<o?c`3>c/h0d=3@0=7Ad@020=;BdP070=?Cd`3De=@0dm?C0=CDe03?
cll0dm?C0=;BdP020=?Cd`060=;BdP3De=@0d];B0=;BdP3De=@0eMGE3P38h=P000`0b>3H0P16ATH0
1`1<C4`0Bd];04Y:BP16ATH0BDU904e=C@1:BTX00P16ATH07`1>CTh0CDe=04M7A`1:BTX0Bd];03lo
?`12@T80?Shn03/k>`0l?3`0@T9204Q8B01>CTh0DE5A05aLG01WIfL0M7Ad0820P024Q8@0SHf=09:B
TP2GUiL0Vi^K09fMW@2SXj<0YZJV0::RXP2YZJT0ZZZZ0:b/[02[Zj/00P2ZZZX01@2XZ:P0[:b/0:RX
Z02[Zj/0[Zj^0080/K6a0180/k>c0;Ng]`2c/k<0/;2`0:n_[`2][Jd0ZZZZ0:RXZ02PX:00VIVI09:B
TP2<S8`0Ph>307QhN01aLG40GemO05MGE`1ADE4204U9B@0605=CD`1@D500CDe=05ADE01FEUH0GEeM
0P1PH600<P1LG5`0J6QX07=cL`2?Shl0V9RH08b<S01eMGD0L71`07alO01WIfL0DE5A04=3@`1ADE40
@d=303Ti>@1?Cdl0De=C04Q8B01QHF40O7al08V9R@24Q8@0FEUI04I6AP0o?cl0=3@d04A4A017AdL0
<30`034a<@10@400<S8b030`<00a<C40BTY:04];B`0j>SX0FEUI04];B`12@T80@D5104];B`1CDe<0
ATI6059BDP13@d<0GemO07alO01VIVH0J6QX0P1KFe/205MGE`0F04M7A`1UIFD0RXZ:06m_K`1OGel0
UYJF09RHV01jNWX0N7Qh065QH@0n?Sh0?clo05MGE`1YJFT0L71`065QH@1FEUH0Cdm?04];B`1CDe<0
BTY:02/[:`8092@T00`0=cLg04M7A`0c<c<0:2PX02l_;`10@400E5AD09FEU@2f][H0ZZZZ09:BTP2A
TI420:JVYP0C0:j^[P2e]KD0];Bd0<30`02l_;`0[:b/05mOG`1HF5P0HV9R05YJFP1HF5P0GemO065Q
H@1fMWH0X:2P0<S8b02ZZZX0?clo02PX:00202@T900402TY:@0d=3@0<C4a02d];@80;2`/0100<C4a
03De=@0d=3@0<30`038b<P0h>3P0?3`l03dm?@1<C4`0@41003dm?@13@d<0>SXj03<c<`0b<S80;2`/
0`0`<300500];Bd0Bd];07MgM`1YJFT0KVi^065QH@1YJFT0DE5A05iNGP1QHF40JFUY07=cL`1bLW80
Lg=c07AdM01mOGd0NWYj07alO022PX80OGem0P20P8003023Ph<0Ogmo0861P@22PX80Q8B408:2PP28
R8P0QHF508^;R`29RHT0SHf=08V9R@80SHf=00@0Shn?08f=S@2=SHd0RXZ:0P2<S8`02P2:RXX0SHf=
08^;R`2<S8`0TI6A08b<S02BTY80U9BD09RHV02JVYX209NGU`0709VIV@2GUiL0UiNG09ZJVP2DU9@0
UiNG09bLW00209JFUP0509NGU`2MWId0VIVI09RHV02IVIT00`2DU9@01`2CTi<0UIFE09RHV02EUID0
TY:B09BDU02CTi<00P2GUiL0102HV9P0VYZJ09jNWP2TY:@20:^[Z`0Z0;Rh^03:b/X0c/k>0<g=c@37
alL0^k^k0;6a/@2[Zj/0/K6a0<C4a03<c<`0bl_;0<W9b@35aLD0a/K60<;2`P2j^[X0Zj^[0:RXZ02Q
XJ40VIVI09RHV02CTi<0T92@08Z:RP2DU9@0Rh^;08V9R@28R8P0QHF508N7Q`28R8P0N7Qh06MWI`0e
=CD0;Rh^02XZ:P0b<S80<C4a03@d=00b<S80;Bd]0P0a<C408`0`<300:b/[030`<00];Bd0<C4a03lo
?`15ADD0@d=303Lg=`0i>CT0F5QH05UIF@1EEED0ATI603`l?01:BTX0D51@04a<C00f=SH0@4100492
@P13@d<0=3@d02d];@0[:b/0:BTY02@T900P8200;2`/03dm?@1hN7P0V9RH0:VYZ@2UYJD0Ogmo0080
RHV900@0FEUI051@D01bLW80IfMW0P1dM7@03@22PX80Shn?09>CT`2EUID0Ti>C08n?S`29RHT0UYJF
09FEU@2JVYX0XJ6Q09jNWP2MWId01@2JVYX07@2KVi/0VIVI09RHV02JVYX0UiNG09:BTP2KVi/0U9BD
09JFUP2JVYX0UYJF09NGU`2CTi<0UYJF09RHV02EUID0U9BD09:BTP2DU9@0TI6A09RHV02DU9@0Shn?
08f=S@2EUID0T92@09>CT`2@T900Ti>C0080TY:B00d0TI6A09BDU02BTY80SHf=09>CT`2@T900RHV9
096AT@2=SHd0Rh^;08f=S@2@T900Shn?0080RHV900T0QhN708B4Q027QhL0QHF5092@T02LW9`0Zj^[
0;Fe]@2j^[X00P33`l<02@32`/80a/K60<G5a@36a/H0a<C40<K6aP39bLT0b<S80<g=c@020<_;b`03
0<k>cP3AdM40clo?00<0d];B00<0d=3@0<o?c`3@d=000P3>c/h40<o?c`80c/k>00L0clo?0=7Ad@3C
dm<0d=3@0<o?c`3>c/h0clo?0080d];B00H0dm?C0=7Ad@3De=@0eMGE0=CDe03Bd]820=3@d0060=;B
dP3Cdm<0dm?C0=?Cd`3De=@0dm?C0P3De=@>0<SPf0003038h=P304a<C00:04Y:BP15ADD0ATI604Q8
B01;Bd/0BTY:04];B`17AdL0BTY:04i>CP80Bd];00D0BTY:04E5A@11@D40?clo03/k>`0203dm?@0>
0492@P19BDT0De=C05EEE@1UIFD0Lg=c0820P027QhL0RXZ:09FEU@2GUiL0Vi^K0:2PX02QXJ420:>S
X`030:VYZ@2XZ:P0Z:RX00<0ZZZZ00L0[Zj^0:b/[02/[:`0Zj^[0:b/[02_[jl0/K6a00<0/k>c00h0
]KFe0;2`/02_[jl0ZJVY0:RXZ02NWYh0Vi^K09>CT`2>SXh0PX:207alO01]KFd0HF5Q05QHF080CTi>
03/0CDe=04a<C01BDU80F5QH05MGE`1IFET0G5aL05iNGP1RHV80GemO065QH@1ZJVX0PX:2096AT@2K
Vi/0SXj>079bLP1/K6`0IVIV05IFEP10@400<S8b03/k>`0m?Cd0C4a<05QHF010@400@T92069RHP1e
MGD0Ph>307inOP1bLW80HV9R03@d=00g=cL0>CTi02`/;00];Bd0<C4a02l_;`0`<300>3Ph04];B`16
ATH0@T9204];B`1<C4`0AdM703`l?01BDU80GemO05=CD`18B4P0@d=305MGE`1gMgL0G5aL06i^KP02
07=cL`0D05IFEP1ADE40C4a<08F5Q@21PH40Fe]K06i^KP2IVIT0QXJ607YjNP1eMGD0EEEE04A4A013
@d<0EUIF061PH01NGUh0EeMG061PH01RHV8205iNGP0n04i>CP0n?Sh0<S8b02h^;P0n?Sh0@T9202/[
:`0U9BD092@T03@d=01:BTX0Ng]k0:JVYP2[Zj/0RHV908b<S02OWil0Y:BT0:2PX02/[:`0YjNW0:n_
[`2l_;`0/;2`08R8R01CDe<0G5aL06YZJP1IFET0FUYJ069RHP1UIFD0RXZ:0<?3``37alL0TI6A03Lg
=`0/;2`0<C4a02HV9P0/;2`0<S8b02PX:00d=3@0<C4a02h^;P0a<C40<c<c02h^;P0];Bd0<C4a03Lg
=`0a<C40@D5103dm?@0l?3`0>c/k02h^;P0b<S80;bl_02`/;00[:b/202PX:00502HV9P1:BTX0L71`
06m_K`1^KVh00P1VIVH0101DE5@0HF5Q06a/K01/K6`2075aL@0C071`L01fMWH0Ogmo07YjNP1iNGT0
PX:207YjNP1mOGd0OWin07emO@1nOWh0NGUi07inOP23Ph<0Q8B408F5Q@22PX80QHF508b<S00208V9
R@0C096AT@29RHT0SHf=08j>SP2?Shl0Rh^;08R8R02:RXX0S8b<08j>SP2<S8`0Shn?096AT@2?Shl0
U9BD09JFUP2GUiL0VIVI09RHV00209NGU`0;09^KV`2JVYX0UYJF09BDU02HV9P0WIfM09VIV@2LW9`0
Vi^K09bLW02KVi/00P2GUiL01`2DU9@0TY:B09ZJVP2HV9P0UIFE09>CT`2BTY800`2DU9@01P2ATI40
T92@09BDU02GUiL0UYJF09bLW080ZJVY00H0][Jf0<K6aP3=cLd0b/[:0<71`@2g]kL20:VYZ@060;>c
/`31`L40bLW90<O7a`35aLD0`l?30P35aLD0302o_kl0[Zj^0:NWY`2SXj<0VYZJ09NGU`2EUID0TI6A
092@T02GUiL0TY:B08f=S@80RHV902L0RXZ:08V9R@1nOWh0MGEe0492@P0f=SH0;Rh^03Hf=P0b<S80
<C4a03<c<`0];Bd0;2`/030`<00[:b/0;Bd]030`<00^;Rh0<S8b03Ph>01<C4`0A4A403/k>`0h>3P0
DU9B05]KF`1DE5@0B4Q803`l?019BDT0D51@04A4A010@400>CTi03lo?`14A4@0=CDe02l_;`0b<S80
0P0W9bL01`0R8R80<30`04=3@`1gMgL0V9RH0:n_[`2SXj<00P28R8P01@2>SXh0EeMG05MGE`1`L700
EeMG0080JVYZ01D0OGem08b<S02CTi<0U9BD09:BTP2>SXh0SHf=09JFUP2DU9@0V9RH0:6QX@2MWId0
W9bL09^KV`2LW9`0V9RH09ZJVP2IVIT0V9RH09NGU`2KVi/00P2FUYH01@2DU9@0UYJF09^KV`2CTi<0
TY:B0080UYJF00P0Ti>C096AT@2FUYH0TY:B09BDU02CTi<0U9BD096AT@80T92@00X0TY:B08n?S`2E
UID0T92@08j>SP2DU9@0TI6A09>CT`2@T900Shn?0`2ATI4209BDU00308f=S@2BTY80SHf=0080SXj>
0140Shn?08^;R`2>SXh0Rh^;08B4Q022PX80Q8B408J6QP2=SHd0W9bL0:JVYP2_[jl0^;Rh0<30`034
a<@0`/;20<C4a0040<?3``030<O7a`38b<P0b/[:0080bl_;00D0c/k>0=3@d03?cll0clo?0=7Ad@02
0=3@d0050<o?c`3>c/h0clo?0<o?c`3@d=000`3=cLd0203?cll0c/k>0<o?c`3AdM40e=CD0=7Ad@3@
d=00clo?0`3AdM40303Bd]80dM7A0=?Cd`3Cdm<0d];B0=?Cd`3GemL0d];B0=3@d03Bd]80dm?C0=GE
e@<0dm?C00<0dM7A0<SPf038h=P03038h=P000`0b>3H0P1>CTh0301BDU80CDe=04A4A017AdL0B4Q8
04m?C`1=CDd0BDU904i>CP1ADE40Bd];04Y:BP80BDU900@0ATI604A4A013@d<0>CTi0P0l?3`05015
ADD0Bd];05MGE`1RHV80IfMW071`L01mOGd0QhN708R8R02BTY80UYJF09^KV`2NWYh0WinO0:FUY@2S
Xj<0YjNW0:>SX`2WYjL0ZJVY0P2/[:`01P2][Jd0Zj^[0:ZZZP2^[Zh0[jn_0:j^[P80/[:b0180]kNg
0;Fe]@2e]KD0/[:b0:n_[`2ZZZX0Xj>S09jNWP2MWId0UIFE092@T023Ph<0OGem06][J`1WIfL0DU9B
04i>CP1<C4`204Q8B004059BDP1IFET0De=C05UIF@80GemO01P0HF5Q069RHP1WIfL0J6QX07=cL`27
QhL0TY:B09VIV@2ATI40L71`069RHP1FEUH0>3Ph02`/;00k>c/0>CTi04=3@`1NGUh0C4a<03Xj>P16
ATH0Fe]K075aL@1eMGD20820P009065QH@12@T80>c/k0492@P0^;Rh0;Bd]034a<@0`<300<c<c0080
@41000h0@d=304Q8B00o?cl0A4A404=3@`1CDe<0H61P05eMG@1@D500ADE506EUI@1aLG40KFe]07Mg
M`80LW9b04<0C4a<04M7A`1cLg<0WIfM07UiN@1FEUH0O7al09NGU`1nOWh0O7al06IVIP1ADE40?clo
04Q8B01<C4`0GEeM051@D016ATH0EUIF05]KF`1DE5@0IVIV04U9B@1:BTX0@D5103Ti>@11@D40ATI6
02/[:`0S8b<0820P02h^;P0d=3@0BDU907MgM`2ATI40QhN708Z:RP2=SHd0UiNG09^KV`2VYZH0Zj^[
0:VYZ@2h^;P0]KFe0:b/[01LG5`0CTi>06UYJ@1EEED0DE5A05YJFP1YJFT0U9BD0;>c/`37alL0aLG5
07inOP0i>CT09bLW02DU9@0/;2`0:b/[02XZ:P0a<C40<S8b0080>3Ph00P0>c/k03Ti>@10@400?Shn
04=3@`12@T80C4a<0451@@80@T9200D0?3`l03Xj>P0j>SX0;bl_03Ti>@0303Xj>P0805aLG01bLW80
M7Ad06MWI`1`L700HV9R05eMG@1SHf<206][J`0506m_K`1bLW80N7Qh07]kN`20P8000P1oOgl01@1m
OGd0Ogmo08:2PP25QHD0Q8B40080Ph>300<0QXJ60861P@25QHD00P28R8P0202:RXX0Shn?08Z:RP2?
Shl0TI6A08Z:RP2;Rh/0RXZ:0P2<S8`0102;Rh/0SXj>08f=S@2<S8`2092@T00409FEU@2@T900VIVI
09VIV@<0VYZJ00@0W9bL09VIV@2IVIT0Vi^K0P2HV9P01P2KVi/0WinO09jNWP2LW9`0WinO09fMW@80
Vi^K00`0V9RH09NGU`2GUiL0VYZJ09RHV02EUID0UiNG09FEU@2BTY80U9BD09>CT`2ATI4208j>SP03
09FEU@2HV9P0WinO0080Xj>S00h0/K6a0;no_`39bLT0b<S80<30`02`/;00YJFU0:b/[02b/[80_[jn
0<S8b036a/H0a<C40<30`080aLG500`0`<300;2`/02XZ:P0X:2P09fMW@2JVYX0TI6A08n?S`2CTi<0
TY:B09BDU02?Shl208R8R00>08^;R`2:RXX0Q8B407]kN`1LG5`0=cLg02l_;`0`<300<C4a030`<00b
<S80<30`038b<P0c<c<302l_;`0?02h^;P0d=3@0>CTi05=CD`17AdL0>c/k03De=@1BDU80H61P05IF
EP10@400>c/k04I6AP1<C4`0B4Q80080>SXj00H0?Shn0451@@0g=cL0<c<c03Xj>P0/;2`202h^;P0=
030`<01>CTh0QHF509nOW`2^[Zh0W9bL08:2PP2<S8`0T92@05UIF@1LG5`0I6AT04e=C@02071`L00:
07]kN`2;Rh/0TI6A09VIV@2ATI40S8b<08f=S@2FUYH0Ti>C09FEU@80WYjN00/0Xj>S09^KV`2IVIT0
VIVI09nOW`2KVi/0VIVI09^KV`2NWYh0VIVI09BDU00209NGU`0609RHV02BTY80UIFE09VIV@2GUiL0
UYJF0P2DU9@04@2FUYH0UiNG09JFUP2CTi<0UYJF09RHV02ATI40UYJF09>CT`2@T900TI6A09>CT`2D
U9@0TI6A09:BTP2GUiL0TI6A0080Ti>C00<0TY:B09BDU02BTY800P2ATI401@2<S8`0RXZ:08^;R`2;
Rh/0SHf=0080Rh^;00X0QHF508:2PP21PH40QXJ608b<S02GUiL0Xj>S0;2`/02g]kL0_[jn0P33`l<0
2034a<@0`l?30<;2`P32`/80aLG50<K6aP38b<P0bLW90P3;bl/02@3=cLd0c/k>0=3@d03Cdm<0d=3@
0<o?c`3AdM40d=3@0<o?c`030<k>cP80cLg=0P3>c/h01`3=cLd0clo?0=3@d03AdM40d];B0=7Ad@3@
d=000`3AdM40103@d=00dM7A0=?Cd`3Cdm<30=;BdP060=KFeP3De=@0dM7A0=?Cd`3Fe]H0d];B0P3C
dm<00`3De=@0b>3H0<SPf00<0<SPf0003038h=P2059BDP0704i>CP1=CDd0Bd];04M7A`16ATH0C4a<
055AD@0205=CD`0F04];B`1>CTh0A4A404Q8B01;Bd/0ADE504Q8B012@T80>c/k03hn?P10@400ATI6
04e=C@1GEeL0HV9R06=SH`1^KVh0Ng]k0820P02:RXX0UIFE09:BTP80W9bL00L0X:2P0::RXP2SXj<0
YZJV0:NWY`2YZJT0ZZZZ0080Zj^[00P0ZZZZ0:VYZ@2/[:`0[Zj^0;6a/@2`/;00]KFe0;:b/P80]KFe
01P0][Jf0;2`/02^[Zh0[Zj^0:JVYP2PX:00VYZJ09BDU02:RXX0RHV907emO@1/K6`0Hf=S05EEE@1@
D500BTY:04i>CP1<C4`0EEEE05MGE`1MGEd0HV9R061PH01RHV82065QH@0N06][J`1XJ6P0KVi^07If
MP27QhL0Shn?09nOW`2CTi<0LW9b05IFEP0o?cl0<C4a03De=@0j>SX0C4a<06=SH`1LG5`0CDe=04I6
AP1CDe<0D51@065QH@1^KVh0Ti>C07inOP1LG5`0?Cdm03`l?00e=CD0<S8b0P0e=CD04@11@D40BTY:
04Y:BP1FEUH0CTi>04E5A@16ATH0CDe=05aLG01WIfL0Kfm_06QXJ01JFUX0LW9b06i^KP1nOWh0MWIf
0080JFUY0P1:BTX01P2=SHd0X:2P06][J`1MGEd0PX:209JFUP80Ogmo03D0FEUI04];B`0n?Sh0@410
03lo?`1=CDd0C4a<04M7A`1/K6`0JVYZ06m_K`1`L700A4A403Ph>013@d<0?3`l04U9B@1>CTh0>SXj
02/[:`0Z:RX0:2PX034a<@0h>3P0De=C0820P02<S8`0QHF507inOP25QHD0U9BD09nOW`2ZZZX0[:b/
0;:b/P2f][H0_Kfm08n?S`1ADE40H61P06=SH`1IFET0HV9R07IfMP2CTi<0W9bL0<71`@3;bl/0`l?3
07AdM00h>3P0=CDe03Lg=`0203Hf=P030451@@10@400?Shn0080=cLg00h0<c<c03Ph>00j>SX0=3@d
03dm?@0o?cl0>3Ph03Hf=P0d=3@0;2`/02h^;P0b<S809bLW02d];@80;2`/00H0<S8b05YJFP1_Kfl0
L71`05eMG@1^KVh205IFEP0<061PH01TI6@0JVYZ071`L01dM7@0MWIf07QhN01kNg/0N7Qh07emO@22
PX80NWYj0P20P8005@1nOWh0Ogmo08:2PP20P800Q8B408>3P`24Q8@0R8R808f=S@2;Rh/0RHV908f=
S@2?Shl0RXZ:08j>SP2=SHd0RXZ:08b<S02?Shl0Ti>C08n?S`02096AT@0709>CT`2GUiL0UYJF09^K
V`2GUiL0WIfM09NGU`0309VIV@80VYZJ00D0W9bL09^KV`2OWil0W9bL0:2PX00209fMW@0=09bLW02M
WId0VYZJ09JFUP2DU9@0VYZJ09RHV02IVIT0UiNG09JFUP2DU9@0UYJF09NGU`0209:BTP80TI6A00<0
Shn?09FEU@2NWYh00P2QXJ403P2/[:`0^[Zj0<;2`P35aLD0^k^k0:RXZ02QXJ40YjNW0;Fe]@2l_;`0
bl_;0<O7a`31`L40`/;20P30`<003@2h^;P0/[:b0:RXZ02RXZ80WYjN09VIV@2BTY80T92@09>CT`2?
Shl0Ti>C08n?S`29RHT00P27QhL04@2:RXX0PH6108:2PP1eMGD0@T92034a<@0b<S80<30`03@d=00e
=CD0<c<c02l_;`0f=SH0<C4a03De=@0_;bl0<c<c0080=3@d00`0A4A404Q8B00m?Cd0=CDe04E5A@1O
Gel0GEeM04U9B@11@D40ATI605QHF015ADD203lo?`0E03Ti>@16ATH0?clo03De=@0l?3`0;2`/02PX
:00S8b<0;bl_05QHF02<S8`0X:2P0;Bd]02JVYX0O7al08j>SP2:RXX0DE5A05UIF@1LG5`0A4A40080
IfMW00X0M7Ad08^;R`2BTY80Ti>C09:BTP2ATI40T92@09BDU02@T900TY:B0P2MWId0102OWil0W9bL
09^KV`2OWil209^KV`0909bLW02IVIT0UYJF09ZJVP2EUID0UiNG09BDU02CTi<0V9RH0080UiNG00D0
VIVI09FEU@2DU9@0Ti>C09BDU00209FEU@80UYJF00D0Ti>C09JFUP2IVIT0T92@08n?S`0209>CT`0C
09JFUP2ATI40Ti>C09>CT`2BTY80UYJF09FEU@2CTi<0TI6A08n?S`2ATI40SXj>08f=S@2<S8`0Shn?
08Z:RP2=SHd0Rh^;08J6QP0208B4Q00?08F5Q@21PH40RHV909ZJVP2QXJ40[Jf]0;Jf]P2n_[h0`/;2
0<?3``37alL0`l?30<C4a032`/80aLG50080a<C400L0b<S80<[:bP3:b/X0c<c<0<_;b`3?cll0d];B
0080clo?00d0d];B0<o?c`3?cll0clo?0<g=c@3@d=00cLg=0<k>cP3=cLd0c/k>0<o?c`3>c/h0clo?
0080dM7A00<0d=3@0<o?c`3AdM40103AdM403P3Cdm<0d];B0=;BdP3AdM40d];B0=CDe03AdM40d=3@
0=?Cd`3EeMD0dm?C0=7Ad@3Bd]80e=CD3P38h=P000`0b>3H0P1BDU800`1CDe<0EUIF051@D002051@
D080De=C00/0D51@059BDP1DE5@0D51@04i>CP1=CDd0BDU904M7A`16ATH0B4Q804=3@`020451@@0;
04I6AP1=CDd0E5AD05iNGP1SHf<0Jf][07]kN`20P800Rh^;09NGU`2HV9P00P2NWYh01`2QXJ40Xj>S
0:BTY02[Zj/0Z:RX0:JVYP2YZJT00P2XZ:P01@2ZZZX0[Jf]0:f][@2/[:`0/K6a0080/;2`03l0/[:b
0;>c/`2b/[80/k>c0;Fe]@2`/;00[Zj^0:FUY@2PX:00VYZJ09RHV02:RXX0R8R80820P01`L700HV9R
05IFEP1>CTh0BTY:04m?C`1@D500DU9B05ADE01GEeL0G5aL05YJFP1LG5`0GemO069RHP1VIVH0JFUY
06MWI`1`L700N7Qh08F5Q@2EUID0VYZJ08N7Q`1ADE40=cLg02XZ:P0/;2`0<30`04U9B@1GEeL0De=C
04M7A`0n?Sh0Cdm?04Q8B01:BTX0ATI607QhN02CTi<0L71`05QHF014A4@0>3Ph03De=@0/;2`0;Rh^
03hn?P17AdL00P1=CDd03@1<C4`0?clo059BDP1KFe/0G5aL06][J`1aLG40Hf=S06MWI`1cLg<0K6a/
07emO@1^KVh00P1GEeL0?`12@T80D51@09JFUP2JVYX0Jf][071`L02CTi<0SHf=08F5Q@1aLG40B4Q8
02h^;P0Y:BT0;bl_0410@00d=3@0=SHf04];B`1ZJVX0QhN707]kN`1TI6@0BDU902d];@0k>c/09BDU
02l_;`14A4@0AdM703@d=00S8b<08B4Q02/[:`0f=SH0EeMG07alO01nOWh0MWIf071`L01iNGT0PH61
08N7Q`2?Shl0X:2P09nOW`2_[jl0_[jn0;:b/P1UIFD0F5QH06m_K`1ZJVX0Hf=S07AdM027QhL0RHV9
0:BTY032`/80d=3@0;Zj^P1;Bd/0;bl_02h^;P03030`<080=3@d0P0a<C401`0];Bd0=CDe03@d=00c
<c<0@D5103Hf=P0h>3P00P0f=SH2038b<P0302l_;`0/;2`0;2`/0080<30`01d0=3@d05aLG01cLg<0
Lg=c05mOG`1YJFT0EEEE05ADE01TI6@0HF5Q06UYJ@1aLG40L71`07IfMP1gMgL0Ng]k07emO@1oOgl0
P82007YjNP1oOgl0P82007moO`1lO7`0PH6107moO`24Q8@0PX:208B4Q00208^;R`0708V9R@2;Rh/0
RHV908f=S@2?Shl0SHf=092@T00208n?S`0@096AT@2>SXh0Ti>C09BDU02=SHd0Shn?096AT@2CTi<0
V9RH09VIV@2KVi/0UiNG09jNWP2IVIT0W9bL09fMW@80WYjN00<0XJ6Q0:BTY02OWil00`2MWId01P2L
W9`0WYjN09^KV`2JVYX0V9RH09ZJVP80VIVI00@0UYJF09>CT`2ATI40UYJF0P2ATI4208n?S`80SHf=
0P2DU9@209VIV@0G0:FUY@2c/k<0^[Zj0;no_`2a/K40XJ6Q09RHV02TY:@0/K6a0;bl_038b<P0bLW9
0<71`@32`/80_Kfm0<;2`P2g]kL0/K6a0:b/[02RXZ80WYjN09fMW@2FUYH00P2CTi<03@2@T900TI6A
08j>SP29RHT0QHF508B4Q021PH40PX:207emO@1hN7P0H61P03/k>`0a<C400P0d=3@0;@0e=CD0<C4a
02l_;`0a<C40;Rh^02XZ:P0[:b/0;Bd]034a<@0d=3@0@T9204U9B@0k>c/0=cLg03lo?`1SHf<0GUiN
04Y:BP0k>c/0AdM705UIF@14A4@0>CTi0451@@0f=SH0@D510492@P0];Bd0=SHf02TY:@0X:2P08R8R
034a<@1XJ6P0TI6A0:6QX@2c/k<0V9RH06m_K`2;Rh/0QXJ6055AD@1NGUh0E5AD03lo?`0205aLG003
06][J`23Ph<0Shn?0080Ti>C0P2ATI401`2DU9@0TI6A09JFUP2OWil0X:2P09fMW@2LW9`00P2NWYh0
?@2HV9P0WIfM09ZJVP2IVIT0Vi^K09fMW@2LW9`0U9BD09FEU@2GUiL0Vi^K09NGU`2IVIT0WIfM09>C
T`2ATI40UIFE096AT@2FUYH0U9BD09RHV02DU9@0UIFE09:BTP2IVIT0UiNG08n?S`2ATI40UYJF09:B
TP2@T900U9BD09FEU@2CTi<0TI6A09>CT`2DU9@0TY:B08f=S@2>SXh0RXZ:08f=S@2;Rh/0SHf=08j>
SP2=SHd0S8b<08F5Q@24Q8@0QhN708:2PP27QhL0Q8B409RHV02SXj<0ZJVY0;>c/`2l_;`0`<300<?3
``35aLD00P33`l<01@32`/80a<C40<C4a035aLD0b<S80080a/K600P0b<S80<c<c03=cLd0cLg=0=3@
d03?cll0dM7A0<o?c`80dM7A00X0d=3@0<o?c`3>c/h0c<c<0<g=c@3?cll0cLg=0=3@d03?cll0dm?C
0P3AdM401P3?cll0dM7A0=?Cd`3Bd]80dM7A0=;BdP80dm?C0P3Bd]80203Cdm<0d];B0=3@d03Cdm<0
d];B0=3@d03Cdm<0e]KF0P3De=@>0<SPf0003038h=P204a<C00904e=C@1@D500Bd];04Y:BP19BDT0
A4A405EEE@1BDU80Cdm?0080DE5A00H0D51@04e=C@19BDT0ADE504a<C018B4P204A4A00C04M7A`1:
BTX0DE5A05IFEP1LG5`0HV9R06a/K01kNg/0PX:208R8R02FUYH0Vi^K09VIV@2LW9`0WYjN0:>SX`2W
YjL0YJFU0:VYZ@020:RXZ080[:b/00@0[Zj^0:VYZ@2_[jl0[Jf]0P2/[:`00`2_[jl0/K6a0;6a/@02
0;:b/P0H0;2`/02_[jl0ZZZZ0:JVYP2PX:00VIVI09BDU02:RXX0QXJ607UiN@1`L700GUiN05YJFP1:
BTX0Bd];051@D01<C4`0F5QH05MGE`1JFUX0Hf=S05IFEP1OGel0GEeM0P1TI6@01@1UIFD0IfMW06YZ
JP1aLG40NGUi0080T92@02T0PX:205YJFP0Z:RX09RHV02PX:00c<c<0CDe=05]KF`1GEeL0@4100492
@P16ATH0@D5103lo?`0/;2`0CTi>08>3P`2>SXh0Kfm_051@D00c<c<0;2`/02/[:`0a<C40?Cdm055A
D@1=CDd0E5AD0410@00o?cl0D51@07IfMP1FEUH0L71`07emO@1WIfL0JFUY06][J`1`L700NWYj06QX
J00205ADE01C04U9B@1EEED0W9bL09>CT`1`L700PH6109RHV02:RXX0QXJ605UIF@0b<S80;Rh^02TY
:@0d=3@0@41002h^;P0f=SH0Cdm?079bLP2:RXX0Ng]k079bLP1WIfL0B4Q803Lg=`0T92@0:2PX02l_
;`13@d<0EeMG03hn?P0_;bl0=CDe04e=C@1:BTX0HV9R06][J`1TI6@0L71`079bLP1]KFd0Kfm_07Mg
M`2<S8`0VIVI0;2`/02a/K40^[Zj09jNWP1KFe/0Hf=S071`L01OGel0JVYZ07MgM`1mOGd0RXZ:0:^[
Z`3?cll0e=CD0:6QX@0j>SX0<S8b02h^;P0];Bd0=3@d03Ph>00f=SH0=CDe038b<P0j>SX0>CTi03hn
?P10@400?Shn03Xj>P0h>3P0<c<c03Ti>@0d=3@0=CDe034a<@0_;bl00`0a<C402P0h>3P0H61P07Mg
M`21PH40GUiN06MWI`1ADE40E5AD05aLG01UIFD206e]K@03079bLP1eMGD0N7Qh00<0NGUi00T0Ng]k
07emO@1lO7`0OGem07]kN`1hN7P0OGem08:2PP26QXH00P22PX805`26QXH0QHF508J6QP2>SXh0RXZ:
08b<S02:RXX0SHf=09>CT`2>SXh0T92@08j>SP2?Shl0SXj>096AT@2?Shl0TI6A09FEU@2>SXh0U9BD
09RHV02JVYX0Vi^K0080VYZJ00d0W9bL09ZJVP2OWil0WYjN09fMW@2NWYh0XZ:R09^KV`2MWId0WYjN
09fMW@2NWYh0W9bL0080Vi^K00@0X:2P09JFUP2FUYH0V9RH0`2FUYH0202@T900UIFE08n?S`2:RXX0
SHf=08Z:RP2;Rh/0SHf=0P2ATI40:`2MWId0Y:BT0;:b/P2f][H0YJFU09ZJVP2FUYH0Xj>S0;2`/02m
_Kd0b<S80<G5a@32`/80`l?30<;2`P2o_kl0^KVi0;Bd]02][Jd0Y:BT09jNWP2LW9`0V9RH09JFUP2E
UID0T92@08j>SP2<S8`0RXZ:08F5Q@24Q8@0Ph>308J6QP20P800PH6107AdM019BDT0=SHf038b<P0e
=CD0<30`03<c<`0Z:RX00P0_;bl0:00[:b/0<S8b034a<@0f=SH0:b/[03Ph>011@D40?clo03Ph>012
@T80GEeM069RHP14A4@0?Shn051@D01LG5`0CDe=03`l?00g=cL0<30`03hn?P1<C4`0:BTY02l_;`0^
;Rh09RHV028R8P0f=SH0L71`096AT@2VYZH0[:b/09JFUP1]KFd0Shn?08J6QP1DE5@0H61P04Y:BP0j
>SX204Y:BP0406ATI023Ph<0Ti>C09>CT`80T92@0P2BTY80302?Shl0TY:B09bLW02PX:00WIfM09^K
V`2JVYX0UiNG09ZJVP2FUYH0VIVI09^KV`80VYZJ00L0UiNG09JFUP2KVi/0UYJF09VIV@2KVi/0V9RH
0080U9BD00<0UYJF09NGU`2FUYH00P2EUID00`2?Shl0Ti>C092@T00209>CT`0A09RHV02FUYH0TY:B
09>CT`2ATI40TY:B092@T02ATI40TY:B096AT@2DU9@0UIFE096AT@2?Shl0TY:B09BDU02?Shl00P2A
TI403`2=SHd0Shn?08^;R`26QXH0Q8B408V9R@22PX80Q8B408N7Q`2?Shl0Vi^K0:ZZZP2e]KD0^k^k
0;no_`020<?3``050<C4a035aLD0`/;20<?3``32`/800P34a<@20<K6aP0:0<W9b@3;bl/0cLg=0<g=
c@3?cll0d=3@0=;BdP3?cll0d=3@0<o?c`80d=3@00L0clo?0<g=c@3>c/h0cLg=0<k>cP3AdM40clo?
0080d=3@00D0d];B0=7Ad@3Bd]80dm?C0=;BdP030=7Ad@80d];B00<0dM7A0=3@d03?cll01`3Bd]80
0`3De=@0b>3H0<SPf00<0<SPf0003038h=P4055AD@0R04i>CP18B4P0B4Q804i>CP19BDT0AdM704e=
C@1ADE40Cdm?04e=C@1;Bd/0BTY:04=3@`17AdL0ATI604U9B@13@d<0AdM704Q8B01=CDd0E5AD05EE
E@1MGEd0K6a/07QhN021PH40Rh^;096AT@2EUID0Vi^K09ZJVP2PX:00YJFU0::RXP80ZJVY00D0YZJV
0:ZZZP2YZJT0ZJVY0:ZZZP020:RXZ080[Jf]00H0[Zj^0;6a/@2`/;00/;2`0;:b/P2e]KD20;:b/P0>
0:b/[02SXj<0WIfM09ZJVP2DU9@0RXZ:08B4Q01hN7P0K6a/05iNGP1FEUH0De=C04];B`18B4P2059B
DP80EeMG0P1KFe/01`1TI6@0GUiN05mOG`1UIFD0Jf][06m_K`1dM7@00P1bLW80301kNg/0PH6107Ad
M017AdL0:BTY02d];@0T92@0:b/[051@D01FEUH0DE5A04e=C@80ADE501/0?Cdm03Ti>@0];Bd0;Rh^
05UIF@25QHD0Ph>306=SH`10@400>CTi02l_;`0b<S80?Shn04M7A`1DE5@0EUIF03hn?P0m?Cd0G5aL
07UiN@1@D500Fe]K07inOP1cLg<0I6AT05eMG@1SHf<00P1jNWX206IVIP0Q04Y:BP1WIfL0W9bL08Z:
RP1UIFD0QXJ608n?S`28R8P0NGUi03Hf=P0Y:BT092@T02HV9P0b<S80>3Ph02`/;00`<300EeMG0820
P02LW9`0Ti>C09fMW@23Ph<0>CTi02TY:@0Q8B407alO02<S8`0Y:BT0F5QH069RHP0f=SH0:2PX0080
>c/k02<0BTY:05=CD`1CDe<0I6AT06=SH`1RHV80IVIV06i^KP1dM7@0PH6109^KV`2VYZH0][Jf0;Bd
]02:RXX0H61P06ATI01ZJVX0GUiN06EUI@1eMGD0OGem08j>SP30`<00e=CD0<_;b`1gMgL0<30`02TY
:@0Z:RX0:BTY02h^;P0[:b/0;bl_02XZ:P02038b<P0403<c<`0];Bd0ATI60451@@80=3@d00H0=SHf
034a<@0c<c<0<S8b02TY:@0Z:RX202d];@0<034a<@1TI6@0MgMg07UiN@1GEeL0IVIV04i>CP1GEeL0
Fe]K061PH01^KVh0KFe]0P1cLg<02@1jNWX0NGUi07UiN@1oOgl0O7al07emO@1lO7`0OWin07YjNP02
0861P@0408B4Q01nOWh0OGem08>3P`80PH6100`0RXZ:08V9R@25QHD0R8R8092@T02;Rh/0TI6A09FE
U@2ATI40T92@08n?S`2BTY82092@T00809FEU@2DU9@0U9BD09FEU@2FUYH0WinO09ZJVP2IVIT209bL
W00M09VIV@2KVi/0Vi^K09jNWP2PX:00WinO09^KV`2MWId0XJ6Q09bLW02NWYh0VYZJ09bLW02NWYh0
VYZJ09RHV02FUYH0Ti>C09JFUP2@T900Shn?096AT@2?Shl0RXZ:08J6QP27QhL0QHF508R8R02=SHd0
0P2?Shl05P2GUiL0V9RH0:JVYP2TY:@0UYJF09>CT`2DU9@0WIfM0:f][@31`L40a/K60<O7a`34a<@0
`l?30<;2`P2o_kl0]KFe0;Bd]02/[:`0ZJVY0::RXP2IVIT209NGU`80UYJF0P2>SXh0:P2@T900Rh^;
08N7Q`26QXH0Ph>30861P@1oOgl0MWIf05IFEP0a<C40<S8b034a<@0`<300;Rh^02TY:@0`<300=3@d
030`<00c<c<0:RXZ030`<00c<c<0?3`l03/k>`0n?Sh0?3`l04E5A@1OGel0GEeM04E5A@12@T80ADE5
059BDP13@d<0@D5103Xj>P0e=CD0?Cdm04e=C@0];Bd0;Rh^034a<@80:BTY00<0@41007MgM`2FUYH0
0P2ZZZX0202BTY80Lg=c096AT@22PX80EeMG06EUI@16ATH0;Rh^0P0m?Cd04P1SHf<0PX:208j>SP2@
T900VIVI096AT@2@T900VYZJ09JFUP2ATI40VIVI09bLW02PX:00W9bL09^KV`2IVIT0VYZJ09VIV@80
VYZJ00<0WIfM09RHV02HV9P00P2FUYH02@2IVIT0UIFE09FEU@2IVIT0UYJF09BDU02FUYH0V9RH09BD
U00209JFUP0709BDU02EUID0TI6A09RHV02GUiL0TY:B09JFUP0309FEU@0908n?S`2BTY80U9BD09RH
V02ATI40Ti>C08n?S`2@T900TI6A0080TY:B00H0S8b<08f=S@2;Rh/0Rh^;08f=S@2;Rh/208J6QP09
08V9R@22PX80QHF508^;R`2=SHd0VYZJ0:VYZ@2d];@0_Kfm0080`L7100P0a/K60<?3``30`<00`<30
0<K6aP33`l<0a<C40<G5a@80alO700H0b/[:0<_;b`3<c<`0cLg=0=3@d03=cLd20=7Ad@80clo?00h0
c/k>0<g=c@3@d=00d=3@0<k>cP3?cll0c/k>0<g=c@3AdM40d=3@0=?Cd`3AdM40dm?C0=3@d0<0d];B
00X0d=3@0<o?c`3Cdm<0dm?C0=;BdP3AdM40d=3@0<k>cP3AdM40clo?0P3@d=000`3Bd]80dM7A0=CD
e00>0<SPf0003038h=P204Y:BP80Cdm?00<0DU9B04i>CP1CDe<00P1;Bd/03017AdL0E5AD04i>CP1D
E5@0C4a<04Y:BP1=CDd0ADE504=3@`10@400ADE504Q8B080C4a<01<0Bd];05=CD`1BDU80FEUI06QX
J01jNWX0OGem08^;R`2>SXh0UIFE09ZJVP2KVi/0YJFU0::RXP2SXj<0ZJVY0:ZZZP2XZ:P0ZZZZ0080
Zj^[0P2YZJT00`2ZZZX0Zj^[0:f][@020;6a/@0K0;2`/02a/K40];Bd0;Bd]02`/;00[Zj^0:VYZ@2U
YJD0W9bL09JFUP2?Shl0SXj>08B4Q01hN7P0L71`061PH01BDU80Cdm?04a<C019BDT0CDe=05ADE01F
EUH0FUYJ05iNGP1KFe/0HV9R0080H61P01@0IFEU06UYJ@1eMGD0MgMg071`L01cLg<0MWIf06a/K01Q
HF40A4A402/[:`0Y:BT09bLW038b<P1>CTh0HF5Q05QHF01JFUX0B4Q804e=C@80?3`l01L0<30`02DU
9@0d=3@0G5aL07moO`1iNGT0GemO04Q8B00b<S80<30`0410@018B4P0Hf=S05eMG@13@d<0AdM7055A
D@1ZJVX0@d=304Q8B01^KVh0Kfm_065QH@0205IFEP0O07MgM`24Q8@0JVYZ06YZJP1DE5@0QHF50:NW
Y`1jNWX0HV9R08F5Q@23Ph<0S8b<06=SH`0a<C408b<S02@T900/;2`0?Shn02h^;P0Z:RX0<30`06UY
J@2BTY80YJFU0:ZZZP2PX:00OGem03Lg=`0M7Ad06a/K01`L700201lO7`0g03Ti>@1hN7P0HF5Q03De
=@0f=SH0EEEE04I6AP0`<300<c<c04E5A@1JFUX0GEeM06a/K01]KFd0J6QX07MgM`1nOWh0TI6A09fM
W@2][Jd0[:b/079bLP1TI6@0MGEe06IVIP1SHf<0K6a/079bLP23Ph<0XZ:R0=?Cd`3GemL0`<30059B
DP0U9BD09RHV02XZ:P0W9bL092@T02HV9P0Y:BT0;Bd]034a<@0h>3P0?Cdm0451@@0d=3@0<30`034a
<@0`<300;bl_034a<@0W9bL09BDU02TY:@0202HV9P0O02h^;P1WIfL0MWIf07UiN@1NGUh0I6AT04];
B`1EEED0Fe]K06MWI`1ZJVX0Lg=c07AdM01cLg<0MGEe07IfMP1dM7@0Ng]k07UiN@1mOGd0OWin07em
O@20P800PH6108:2PP1lO7`0Ogmo08>3P`26QXH0RHV908J6QP0208V9R@0B08N7Q`29RHT0SXj>08f=
S@2CTi<0SXj>08n?S`2ATI40SHf=096AT@2BTY80Ti>C09BDU02GUiL0V9RH09>CT`2DU9@0Vi^K0P2I
VIT209ZJVP0409jNWP2JVYX0UYJF09VIV@80WYjN01L0WinO0::RXP2LW9`0V9RH09bLW02IVIT0WIfM
09ZJVP2GUiL0W9bL09FEU@2BTY80U9BD08n?S`2CTi<0SHf=08b<S026QXH0Ph>308^;R`22PX80Ph>3
08F5Q@0208N7Q`0Y08f=S@2?Shl0UYJF08n?S`24Q8@0QXJ6096AT@2PX:00Zj^[0;bl_035aLD0alO7
0<?3``30`<00`/;20;fm_@2i^KT0[Zj^0:ZZZP2UYJD0Xj>S09fMW@2DU9@0UiNG09JFUP2CTi<0TY:B
096AT@2>SXh0S8b<08F5Q@27QhL0QXJ60861P@1nOWh0N7Qh06a/K00n?Sh0=3@d02l_;`0a<C400P0_
;bl0:P0d=3@0<C4a02/[:`0^;Rh0;2`/038b<P0d=3@0?Shn03Lg=`0j>SX0?clo03/k>`1CDe<0F5QH
04e=C@1?Cdl0Bd];05=CD`14A4@0AdM703Xj>P0f=SH0<C4a0492@P0Z:RX0<C4a02/[:`0R8R809BDU
03lo?`25QHD0WYjN0:^[Z`2WYjL0SHf=07QhN02=SHd0Ph>305EEE@1SHf<0?Cdm02l_;`80<30`00d0
EeMG07emO@2;Rh/0Shn?09>CT`2ATI40Ti>C09BDU02CTi<0TI6A09VIV@2MWId0X:2P0080WYjN00T0
VYZJ09fMW@2OWil0VYZJ09fMW@2JVYX0V9RH09VIV@2DU9@00P2IVIT01@2FUYH0V9RH09^KV`2KVi/0
UIFE00<0U9BD00/0UiNG09:BTP2CTi<0TY:B09JFUP2CTi<0U9BD09JFUP2KVi/0U9BD092@T00209BD
U080Ti>C00D0UIFE08j>SP2ATI40SXj>09>CT`02096AT@0K092@T02>SXh0TI6A08f=S@2>SXh0RXZ:
08b<S028R8P0RHV908F5Q@28R8P0PX:207emO@2:RXX0V9RH0:>SX`2^[Zh0^[Zj0<30`032`/80aLG5
0<C4a032`/80aLG50<O7a`34a<@0a/K600<0aLG500<0alO70<[:bP3<c<`00P3<c<`02P3?cll0d=3@
0=7Ad@3AdM40cLg=0<k>cP3?cll0c/k>0=3@d03AdM420<g=c@060<o?c`3@d=00d=3@0=7Ad@3@d=00
dm?C0P3AdM400`3@d=00d];B0=;BdP020=7Ad@0<0=SHf03?cll0d=3@0=3@d03?cll0cLg=0=3@d03A
dM40d=3@0=7Ad@3Bd]80dm?C3P38h=P000`0b>3H0P1?Cdl0701DE5@0DU9B05ADE01<C4`0DU9B04e=
C@1ADE40B4Q804];B`1>CTh0Cdm?04i>CP1<C4`0AdM70451@@10@400?clo04I6AP17AdL0Bd];04M7
A`1:BTX0CTi>059BDP1JFUX0IVIV07EeM@1oOgl208f=S@0709:BTP2HV9P0Vi^K0:2PX02SXj<0Y:BT
0:FUY@020:RXZ0<0Zj^[00D0ZJVY0:JVYP2[Zj/0Zj^[0:b/[0030:n_[`0A0;Ng]`2e]KD0]KFe0;Fe
]@2_[jl0ZZZZ0:JVYP2OWil0UYJF09:BTP2@T900QHF507]kN`1]KFd0GUiN05ADE01<C4`00P17AdL0
501BDU80De=C05MGE`1KFe/0GEeM05iNGP1SHf<0GEeM06=SH`1UIFD0Jf][07IfMP1jNWX0NGUi07Ee
M@1gMgL0IfMW05YJFP1ADE40;Rh^0P0e=CD05@0n?Sh0EEEE065QH@1HF5P0EUIF0492@P1<C4`0ATI6
0492@P0a<C409BDU02@T900g=cL0J6QX08N7Q`1jNWX0JFUY04Q8B00o?cl0?Shn05aLG00205EEE@0=
04A4A01?Cdl0AdM705QHF00m?Cd0?Shn06YZJP1lO7`0H61P05QHF01DE5@0Hf=S08B4Q002075aL@0l
06=SH`2QXJ40WIfM06m_K`1SHf<0OWin08F5Q@26QXH0Cdm?02<S8`0O7al0820P02XZ:P0m?Cd0=SHf
02XZ:P0_;bl0LW9b08f=S@2e]KD0VYZJ07MgM`1aLG40;bl_01dM7@0K6a/06QXJ01`L700O7al09RHV
05MGE`1iNGT0GUiN04I6AP1NGUh0Cdm?02PX:00S8b<0:2PX04Y:BP1RHV80H61P06ATI01YJFT0MGEe
06m_K`1cLg<0MWIf08N7Q`2GUiL0U9BD065QH@1ZJVX0M7Ad06][J`1/K6`0Kfm_07=cL`24Q8@0^k^k
0P3?cll05P2MWId0;Bd]02TY:@0U9BD0;2`/02<S8`0Y:BT0:RXZ038b<P0j>SX0@d=304i>CP1JFUX0
=3@d03De=@0a<C40:RXZ02LW9`0`<3008b<S02XZ:P0[:b/202l_;`0403De=@1SHf<0OGem07EeM@80
Hf=S00T0Cdm?059BDP1IFET0JFUY071`L01aLG40Kfm_075aL@1eMGD00P1hN7P0101jNWX0OGem07Yj
NP1oOgl20861P@0B07moO`22PX80Q8B407moO`22PX80QXJ608F5Q@27QhL0Rh^;08b<S026QXH0S8b<
09:BTP2ATI40SHf=096AT@2>SXh0U9BD0P2CTi<04P2@T900U9BD09>CT`2EUID0VYZJ09BDU02FUYH0
WYjN09fMW@2HV9P0VYZJ09NGU`2MWId0X:2P09fMW@2LW9`0WinO09jNWP80WinO01D0WYjN09nOW`2L
W9`0WIfM09RHV02GUiL0TI6A09FEU@2DU9@0UIFE08n?S`2=SHd0RHV908j>SP28R8P0Ogmo07emO@20
P800Ogmo0820P022PX800P20P8003025QHD0QhN708R8R021PH40MWIf07UiN@1oOgl0SXj>09bLW02]
[Jd0][Jf0;jn_P80`<3000L0_[jn0;bl_02g]kL0/[:b0:RXZ02VYZH0XJ6Q0080VYZJ00H0Vi^K09JF
UP2BTY80TY:B096AT@2=SHd208Z:RP0F08J6QP27QhL0P82008B4Q01hN7P0MWIf05EEE@0f=SH0;2`/
02l_;`0];Bd0:b/[038b<P0`<300:RXZ038b<P0];Bd0;bl_034a<@0k>c/0<c<c03Lg=`80?3`l00T0
BDU905aLG01PH600B4Q803hn?P1:BTX0ADE50410@00f=SH00P0];Bd03@0l?3`0;Bd]02/[:`0^;Rh0
8R8R02`/;019BDT0QhN70:>SX`2a/K40XZ:R08b<S01lO7`00P2<S8`2069RHP0<03Lg=`0[:b/0:2PX
02PX:01CDe<0NGUi08:2PP2?Shl0Ti>C09BDU02ATI40T92@0P2?Shl0402GUiL0W9bL0:2PX02OWil0
WYjN09ZJVP2NWYh0W9bL09VIV@2MWId0VIVI09JFUP2JVYX0VIVI09NGU`2KVi/209JFUP0409ZJVP2F
UYH0UYJF09BDU080UIFE00@0V9RH09FEU@2GUiL0U9BD0P2FUYH0602CTi<0TI6A09BDU02DU9@0Ti>C
09NGU`2@T900Shn?09>CT`2DU9@0TI6A09BDU02@T900TI6A08f=S@2>SXh0Rh^;08b<S02>SXh0S8b<
08n?S`2=SHd0Shn?08V9R@80QHF50P24Q8@02028R8P0QHF509VIV@2SXj<0[Zj^0;Rh^02o_kl0`/;2
0P34a<@01P35aLD0`l?30<?3``32`/80a<C40<G5a@80a<C400<0aLG50<[:bP3:b/X00P3<c<`00`3=
cLd0clo?0=7Ad@020=3@d0<0c/k>0`3@d=020<k>cP<0d=3@00T0dM7A0=3@d03Cdm<0dM7A0=?Cd`3D
e=@0d];B0=7Ad@3Bd]800P3AdM402P3?cll0d=3@0<o?c`3<c<`0d=3@0<o?c`3<c<`0d=3@0=7Ad@3C
dm<>0<SPf0003038h=P204i>CP0X055AD@1?Cdl0BTY:04Q8B01BDU80D51@04i>CP18B4P0BTY:04E5
A@1:BTX0B4Q804a<C017AdL0A4A40492@P11@D40@T9204=3@`1:BTX0@d=304e=C@1<C4`0Bd];05IF
EP1VIVH0L71`07emO@24Q8@0SXj>096AT@2HV9P0VYZJ0:2PX02SXj<0YJFU0:JVYP2XZ:P0Zj^[0:ZZ
ZP80Z:RX00<0[Jf]0:b/[02^[Zh00P2][Jd20:j^[P0:0;2`/02b/[80][Jf0;Jf]P2d];@0[Zj^0:VY
Z@2SXj<0WYjN09FEU@80T92@00l0Q8B407YjNP1_Kfl0I6AT05MGE`1?Cdl0BDU904];B`1@D500Cdm?
05ADE01MGEd0EUIF05eMG@1RHV800P1TI6@0<@1XJ6P0IFEU06i^KP1jNWX0OWin079bLP1aLG40IFEU
05QHF01RHV80De=C03Xj>P0i>CT0?Shn05EEE@1MGEd0EeMG05IFEP0n?Sh0CTi>05IFEP15ADD0=3@d
02/[:`0S8b<0:b/[04];B`1aLG40RHV907EeM@1ZJVX0CTi>04A4A01MGEd0B4Q805UIF@1GEeL0DU9B
04Y:BP13@d<0=CDe04A4A01eMGD0Q8B406UYJ@1;Bd/0ATI606EUI@1kNg/00P1aLG40<`20P800ZZZZ
08n?S`1IFET0F5QH07]kN`2EUID0Ogmo038b<P0Q8B407AdM02LW9`0/;2`0=cLg03Hf=P0W9bL0<30`
06m_K`2IVIT0YjNW08b<S01<C4`0D51@03De=@0N7Qh07AdM02@T900V9RH08b<S02@T900b<S80L71`
07alO01]KFd0CDe=02`/;00_;bl08b<S028R8P1:BTX0Fe]K04A4A01=CDd0IFEU06UYJ@1NGUh0IFEU
06e]K@1PH600Kfm_07inOP0206e]K@0=07YjNP1oOgl0Q8B408B4Q01jNWX0QhN709^KV`2e]KD0];Bd
0;Ng]`1SHf<0<C4a02LW9`0202<S8`0502@T900V9RH0:RXZ03/k>`1BDU800P1;Bd/01016ATH0ADE5
02`/;00/;2`202d];@0302LW9`0c<c<0>c/k0080=3@d0140;2`/05MGE`1aLG40NGUi06QXJ01MGEd0
De=C055AD@1LG5`0HF5Q06UYJ@1[Jf/0L71`07MgM`1fMWH0M7Ad07IfMP0207inOP0907moO`1nOWh0
Ng]k07inOP1oOgl0R8R80861P@25QHD0P8200080QXJ600P0QhN708J6QP2<S8`0QhN708f=S@2DU9@0
TY:B08n?S`80TI6A01L0V9RH09:BTP2DU9@0T92@09BDU02ATI40UIFE09BDU02CTi<0V9RH09bLW02J
VYX0Ti>C09NGU`2HV9P0WIfM09bLW02MWId0WYjN09nOW`2SXj<0V9RH09^KV`0209jNWP0509ZJVP2G
UiL0U9BD09JFUP2HV9P00P2CTi<01P2=SHd0QXJ608J6QP26QXH0PX:207emO@80NWYj00@0P82008:2
PP22PX80QhN70P24Q8@208J6QP0D08:2PP1lO7`0M7Ad07MgM`1fMWH0NWYj0820P029RHT0TI6A09fM
W@2YZJT0];Bd0;Zj^P2o_kl0^k^k0;Bd]02/[:`0Z:RX0::RXP2PX:0209bLW080U9BD00L0UiNG08f=
S@2<S8`0Rh^;08V9R@28R8P0Q8B40080QXJ60340Ogmo07QhN01YJFT0?clo02l_;`0/;2`0;bl_03@d
=00^;Rh0>CTi03@d=00/;2`0;bl_03<c<`0];Bd0?Cdm03<c<`0k>c/0>CTi03Ph>01>CTh0GUiN04i>
CP11@D40>CTi051@D01BDU80A4A4038b<P0];Bd0;2`/03/k>`0a<C40:2PX02LW9`0T92@0:b/[04m?
C`2>SXh0YZJV0:n_[`2OWil0SXj>07]kN`2ATI40U9BD06EUI@1IFET0>c/k00<09bLW00D0D51@071`
L021PH40Shn?09BDU00309FEU@05096AT@2=SHd0U9BD09^KV`2PX:000P2NWYh04P2MWId0WYjN09bL
W02HV9P0VIVI09ZJVP2LW9`0WIfM09VIV@2FUYH0U9BD09:BTP2FUYH0UIFE09RHV02EUID0U9BD09FE
U@80U9BD00l0UYJF09BDU02FUYH0UIFE09JFUP2JVYX0Vi^K09JFUP2GUiL0Ti>C092@T02DU9@0TI6A
08j>SP2@T9000P2CTi<06`2DU9@0SHf=096AT@2>SXh0SHf=092@T02?Shl0S8b<09>CT`2@T900Shn?
08b<S02:RXX0R8R808J6QP23Ph<0Q8B408Z:RP2CTi<0WYjN0:ZZZP2f][H0_Kfm0<30`032`/80aLG5
0<?3``020<C4a0030<?3``35aLD0a<C40080a/K600H0a<C40<O7a`39bLT0bLW90<_;b`3<c<`20=3@
d0070=;BdP3@d=00c/k>0=3@d03>c/h0clo?0=7Ad@020<k>cP060<o?c`3>c/h0d=3@0=;BdP3@d=00
dM7A0`3De=@02`3Bd]80dM7A0=7Ad@3?cll0d];B0=?Cd`3?cll0eMGE0=3@d03?cll0d=3@0080clo?
0P3@d=000`3AdM40b>3H0<SPf00<0<SPf0003038h=P204i>CP0805MGE`1@D500Cdm?04e=C@1>CTh0
D51@04m?C`1=CDd204m?C`0L04];B`16ATH0ATI604U9B@1:BTX0ADE504A4A016ATH0B4Q804=3@`14
A4@0AdM70492@P14A4@0De=C061PH01_Kfl0OGem08>3P`2<S8`0UIFE09RHV02LW9`0WIfM0:6QX@2V
YZH0Z:RX0:VYZ@@0[Jf]00D0[Zj^0:^[Z`2ZZZX0/K6a0;:b/P020;6a/@0R0;Fe]@2a/K40/k>c0;Fe
]@2`/;00[Jf]0:NWY`2SXj<0WIfM09ZJVP2BTY80QXJ60861P@1iNGT0K6a/05eMG@1FEUH0Bd];04Q8
B016ATH0D51@05ADE01IFET0G5aL065QH@1PH600IfMW065QH@1UIFD0JFUY06][J`1^KVh0Kfm_07Qh
N080NGUi02X0LG5a05=CD`1GEeL0H61P05EEE@12@T80?Cdm06=SH`1JFUX0DU9B04m?C`12@T80D51@
069RHP1@D500>c/k03dm?@0a<C40;Bd]02LW9`16ATH0PX:208b<S01fMWH0HV9R05EEE@1=CDd0>c/k
05IFEP1QHF40Hf=S051@D00m?Cd0<S8b03dm?@1hN7P0P82006i^KP1RHV80DU9B071`L01eMGD207=c
L`0c09bLW02XZ:P0N7Qh04I6AP1?Cdl0L71`0:FUY@1[Jf/08R8R01hN7P0M7Ad08B4Q02LW9`0Z:RX0
<S8b02TY:@0_;bl0KFe]09:BTP2JVYX0Ng]k04=3@`0`<300;2`/02PX:00U9BD08B4Q02@T900P8200
8R8R02/[:`1GEeL0RHV907YjNP1EEED0<S8b02TY:@0V9RH0820P038b<P12@T80<c<c034a<@1>CTh0
?Cdm03/k>`1EEED0De=C04a<C01NGUh0I6AT0080L71`01d0Ng]k08^;R`2DU9@0UYJF09BDU02IVIT0
WinO0:RXZ02TY:@0[Zj^09jNWP1OGel0=cLg02LW9`0V9RH0820P02<S8`0X:2P0;Rh^03Ph>00l?3`0
;2`/034a<@0_;bl0:b/[02XZ:P0[:b/0<C4a02HV9P0202l_;`80:RXZ01@0<C4a06=SH`1dM7@0Lg=c
06QXJ01BDU80BTY:051@D01NGUh0IVIV06a/K01XJ6P0M7Ad06m_K`1aLG40MGEe07MgM`20P800OWin
0861P@80Ng]k00<0O7al0820P01oOgl00P22PX803P21PH40R8R808R8R02:RXX0RHV908Z:RP2;Rh/0
T92@08j>SP2EUID0Ti>C09:BTP2DU9@0Ti>C0P2EUID00`2CTi<0TI6A08N7Q`0209JFUP0C09>CT`2F
UYH0VYZJ09NGU`2FUYH0W9bL09RHV02KVi/0WYjN09bLW02QXJ40WinO09jNWP2JVYX0X:2P09jNWP2J
VYX0W9bL09FEU@0209BDU00?09FEU@2BTY80T92@08V9R@22PX80OWin07]kN`1jNWX0OWin07alO020
P800PX:208B4Q027QhL0Q8B400<0QXJ600<0QHF508B4Q01nOWh00P1gMgL06P1fMWH0M7Ad071`L01h
N7P0MWIf07inOP28R8P0VYZJ0:b/[02n_[h0_;bl0;>c/`2^[Zh0Z:RX0:BTY02OWil0VYZJ09^KV`2G
UiL0V9RH09:BTP2ATI40S8b<08R8R029RHT0R8R80P24Q8@0<`21PH40QhN707IfMP1]KFd0FUYJ03@d
=00`<300<c<c02d];@0`<300>3Ph03<c<`0a<C40:b/[02XZ:P0`<300@41003Lg=`0e=CD0@41003Ti
>@1:BTX0CDe=05EEE@12@T80@41004U9B@1=CDd0@d=3038b<P0[:b/0;2`/03Lg=`0h>3P0:b/[02DU
9@0S8b<0;Bd]05iNGP2@T900YZJV0:n_[`2OWil0TY:B07YjNP2ATI40SHf=05]KF`1CDe<0:b/[02HV
9P0202h^;P0?04m?C`1TI6@0Ng]k08j>SP2BTY80TI6A09FEU@2CTi<0T92@08j>SP2DU9@0UiNG09fM
W@2PX:00WinO0080WYjN0P2LW9`209ZJVP0409VIV@2LW9`0UYJF09:BTP80VIVI00@0UiNG09VIV@2I
VIT0U9BD0P2GUiL06@2HV9P0UIFE09fMW@2EUID0VIVI09JFUP2EUID0U9BD09^KV`2EUID0TY:B09JF
UP2GUiL0Ti>C09JFUP2BTY80Ti>C092@T02FUYH0Shn?092@T02CTi<0TI6A09>CT`2@T9000P2ATI40
602=SHd0TI6A08V9R@2?Shl0QhN708J6QP2>SXh0RHV90820P025QHD0TI6A09nOW`2YZJT0/K6a0;Rh
^030`<00`L710<G5a@34a<@0a/K60<?3``35aLD0a<C40<?3``80aLG500/0`/;20<S8b039bLT0b<S8
0<W9b@3<c<`0d=3@0=7Ad@3?cll0c/k>0<g=c@020=7Ad@80d=3@0P3?cll30=3@d0090<k>cP3@d=00
dm?C0=7Ad@3Bd]80e=CD0=;BdP3AdM40d];B0080dM7A00@0d];B0=7Ad@3AdM40d=3@0`3?cll20<k>
cP80d=3@3P38h=P000`0b>3H0P1?Cdl00`1EEED0DU9B055AD@0404i>CP0;04e=C@1@D500Cdm?04e=
C@1>CTh0BTY:04M7A`11@D40ADE504];B`18B4P00P15ADD0300o?cl0@T920492@P15ADD0DU9B05]K
F`1]KFd0NGUi0861P@2;Rh/0Ti>C09RHV080Vi^K00H0YJFU0:BTY02YZJT0Z:RX0:VYZ@2^[Zh30:n_
[`080:ZZZP2/[:`0[Jf]0:b/[02_[jl0/k>c0;2`/02e]KD20;:b/P150;6a/@2`/;00Zj^[0:JVYP2R
XZ80VIVI08j>SP2<S8`0Q8B407]kN`1/K6`0FEUI05MGE`1>CTh0Bd];04e=C@1CDe<0EEEE05ADE01P
H600G5aL05YJFP1QHF40IFEU06MWI`1VIVH0Kfm_06a/K01_Kfl0KVi^07=cL`1dM7@0KFe]04i>CP1:
BTX0IVIV06ATI019BDT0@D5105mOG`1LG5`0EEEE059BDP1>CTh0Cdm?06e]K@1JFUX0B4Q8051@D018
B4P09RHV02<S8`0h>3P0EeMG08f=S@29RHT0LG5a06e]K@11@D40=3@d04Q8B01ZJVX0KVi^05=CD`0b
<S80<30`04];B`1dM7@0N7Qh0080I6AT00<0F5QH07UiN@1iNGT00P1fMWH02`2UYJD0Vi^K06MWI`0m
?Cd0A4A408^;R`2PX:00GemO024Q8@0P8200;2`/00808b<S00P0;Bd]038b<P0a<C40=cLg05QHF01T
I6@0MWIf05mOG`80<C4a0140:2PX02XZ:P0X:2P08b<S020P800R8R80:2PX034a<@1IFET0IfMW0861
P@1oOgl0E5AD03Hf=P0/;2`0:BTY03@d=00203lo?`0?03Ph>00c<c<0;Bd]02@T900];Bd0;Rh^02`/
;00k>c/0ATI606UYJ@2=SHd0RHV909>CT`2IVIT0XJ6Q0080[Jf]01T0/K6a0;Jf]P2n_[h0`<300;Vi
^@2^[Zh0PH6102TY:@0U9BD09RHV02LW9`0T92@0:RXZ02l_;`0[:b/0;2`/03@d=00^;Rh0;2`/02h^
;P0_;bl0<S8b02PX:00a<C40;2`/0080<C4a0140<30`061PH01^KVh0KFe]06ATI01=CDd0CTi>051@
D01SHf<0IFEU06IVIP1/K6`0MGEe07MgM`1aLG40MGEe07IfMP0207emO@0707QhN01nOWh0PH610820
P023Ph<0PX:208>3P`0208F5Q@0908Z:RP28R8P0QXJ608Z:RP2>SXh0TI6A092@T02CTi<0S8b<0080
Shn?01@0T92@09FEU@2GUiL0UIFE09NGU`2EUID0UYJF09fMW@2GUiL0VYZJ09bLW02MWId0VIVI09ZJ
VP2LW9`0VYZJ09^KV`2OWil0WYjN0:2PX080WIfM00L0W9bL09jNWP2RXZ80Vi^K09NGU`2HV9P0TI6A
0080U9BD0P2@T9001@21PH40Ng]k07AdM01hN7P0OGem0080Ogmo00D0Ph>307moO`20P800O7al07in
OP0208>3P`0H07moO`21PH40OGem07MgM`1_Kfl0KVi^06MWI`1RHV80KFe]07UiN@1hN7P0NWYj07in
OP26QXH0Vi^K0;6a/@2k^k/0]KFe0;6a/@2[Zj/0YZJV0::RXP2LW9`0V9RH0P2DU9@00`2@T900S8b<
08j>SP0208n?S`0;096AT@25QHD0P82008:2PP24Q8@0PH6107=cL`1RHV80@410030`<00_;bl00P0a
<C40:@0g=cL0>3Ph02/[:`0X:2P0;Bd]02XZ:P12@T80<S8b03<c<`0l?3`0>CTi04I6AP18B4P0EEEE
03`l?00i>CT0@d=304e=C@16ATH0<30`02d];@0^;Rh0=cLg0451@@0X:2P0:BTY028R8P0b<S80IFEU
09BDU02UYJD0Zj^[09jNWP2>SXh0OGem09RHV02<S8`0Jf][04Q8B00`<3008R8R0080:BTY00@0CTi>
05MGE`1dM7@0QXJ60P2DU9@02@2CTi<0UIFE09NGU`2CTi<0U9BD09>CT`2MWId0WinO09jNWP0209fM
W@0609^KV`2QXJ40Vi^K09VIV@2JVYX0VIVI0P2HV9P01`2FUYH0Ti>C09NGU`2EUID0UiNG09BDU02H
V9P00P2DU9@02@2GUiL0UIFE09JFUP2EUID0V9RH09JFUP2EUID0TY:B096AT@0209>CT`0<09FEU@2C
Ti<0Ti>C09:BTP2ATI40TY:B09>CT`2ATI40SXj>08f=S@2<S8`0Ti>C0P2;Rh/04@2:RXX0Shn?08j>
SP2ATI40SHf=08Z:RP25QHD0QXJ608B4Q021PH40Q8B408f=S@2KVi/0Xj>S0:j^[P2g]kL0`<300080
`l?300<0a/K60<C4a033`l<00P34a<@01P35aLD0a/K60<K6aP30`<00aLG50<K6aP80alO700@0c<c<
0<o?c`3>c/h0d=3@0P3?cll0103@d=00clo?0<o?c`3AdM420=3@d080c/k>00@0dM7A0=3@d03=cLd0
dM7A0P3Bd]80203Fe]H0d];B0=;BdP3AdM40d];B0=CDe03Bd]80dM7A0P3Bd]820<o?c`050=3@d03=
cLd0clo?0<k>cP3@d=003P38h=P000`0b>3H0P1>CTh08@1EEED0BTY:051@D019BDT0D51@04e=C@1<
C4`0DE5A04Y:BP1?Cdl0DE5A04i>CP19BDT0BTY:04M7A`11@D40A4A403hn?P10@400AdM704I6AP0m
?Cd0?3`l0410@01<C4`0FEUI06QXJ01hN7P0OGem08^;R`2BTY80UIFE09VIV@0209jNWP050:JVYP2X
Z:P0Z:RX0:j^[P2][Jd00P2a/K401P2`/;00[jn_0:f][@2_[jl0/K6a0:b/[080/;2`0240/[:b0;>c
/`2_[jl0/;2`0:f][@2ZZZX0YjNW09nOW`2FUYH0TI6A08^;R`24Q8@0O7al06m_K`1QHF40E5AD04a<
C018B4P0A4A404i>CP1CDe<0DE5A05ADE01JFUX0Fe]K069RHP1PH600Hf=S069RHP1WIfL0JFUY071`
L01]KFd00P1_Kfl0201[Jf/0E5AD04U9B@1RHV80H61P04i>CP0m?Cd0GEeM0P1NGUh0801DE5@0KVi^
07inOP1kNg/0IVIV05UIF@1>CTh0B4Q802/[:`0S8b<09bLW02l_;`1WIfL0U9BD0861P@1XJ6P0@D51
03De=@0l?3`0IfMW06m_K`16ATH0;Rh^04i>CP12@T80KFe]07AdM01MGEd0EEEE05YJFP1jNWX0OGem
0P2=SHd0202/[:`0Shn?05ADE00`<300@D5109BDU02BTY80D51@0P0U9BD07`0a<C4092@T02/[:`13
@d<0ADE50410@00b<S80AdM703lo?`17AdL0?3`l02HV9P0Q8B408b<S02@T900S8b<09BDU02@T900Y
:BT0;2`/04I6AP1FEUH0Cdm?07EeM@2LW9`0Ng]k05IFEP0g=cL0;2`/02h^;P0b<S800P0d=3@0300h
>3P0=CDe02LW9`0V9RH0820P028R8P0O7al08b<S055AD@2BTY80UiNG09jNWP80XZ:R0100[jn_0<;2
`P2i^KT0_[jn0<30`037alL0a/K60;bl_02RXZ80?3`l02<S8`0U9BD08b<S02LW9`0X:2P0:BTY0`0W
9bL202/[:`0302l_;`0];Bd0;Rh^0080;bl_01D0:BTY02@T900T92@0:BTY05mOG`1[Jf/0L71`06IV
IP1=CDd0CTi>05=CD`1OGel0IVIV06=SH`1ZJVX0K6a/071`L01_Kfl0N7Qh07EeM@1hN7P00P1jNWX2
07emO@0:07inOP23Ph<0PX:208>3P`24Q8@0Ph>308V9R@28R8P0RXZ:08R8R0<0T92@00P0TY:B092@
T02DU9@0TY:B096AT@2GUiL0UYJF09RHV080UYJF00l0Ti>C09FEU@2IVIT0UiNG09ZJVP2OWil0W9bL
09^KV`2OWil0WIfM09nOW`2MWId0WYjN0:2PX02MWId00P2OWil0102NWYh0W9bL09^KV`2FUYH309BD
U00?09>CT`2<S8`0Rh^;07alO01gMgL0NWYj07inOP20P800PX:207QhN01cLg<0K6a/06EUI@1PH600
IVIV0080KFe]0280N7Qh07AdM01_Kfl0JFUY061PH01TI6@0EeMG065QH@1aLG40MgMg07QhN01kNg/0
QHF508J6QP2JVYX0Z:RX0;bl_02n_[h0/;2`0:b/[02WYjL0XZ:R0:2PX02JVYX0TY:B096AT@2CTi<0
TI6A08f=S@2?Shl0S8b<08V9R@2:RXX0Q8B40`23Ph<0<01nOWh0K6a/05ADE00`<300<C4a03<c<`0[
:b/0;2`/02l_;`0a<C40:b/[02h^;P0/;2`0?3`l03<c<`0`<300=cLg03hn?P17AdL0ATI605=CD`0j
>SX0=SHf04E5A@1DE5@0?Shn034a<@0_;bl0;Bd]03Ph>00l?3`09BDU02@T900Q8B40>c/k07EeM@2G
UiL0ZZZZ0:b/[02OWil0Ph>307emO@2KVi/0Q8B405iNGP0m?Cd0:RXZ02LW9`80=cLg00T0B4Q804Y:
BP1`L700PH61096AT@2DU9@0UIFE096AT@2CTi<00P2?Shl01P2ATI40VYZJ0::RXP2KVi/0WinO09bL
W080Vi^K00l0VYZJ09NGU`2JVYX0UIFE09VIV@2FUYH0U9BD09JFUP2GUiL0V9RH09FEU@2FUYH0UIFE
09>CT`2GUiL00P2DU9@0102GUiL0VYZJ09RHV02GUiL209JFUP0509>CT`2BTY80UIFE09>CT`2EUID0
0`2ATI406`2BTY80T92@08n?S`2?Shl0T92@09FEU@2@T900TI6A09>CT`2=SHd0Shn?08b<S02=SHd0
TI6A08b<S02:RXX0QXJ608R8R026QXH0Q8B408J6QP2EUID0XZ:R0:f][@2i^KT0_Kfm0<71`@030<C4
a0040<G5a@34a<@0`l?30<?3``80a/K600T0`l?30<G5a@34a<@0alO70<K6aP3;bl/0cLg=0<k>cP3@
d=000P3>c/h03`3?cll0c/k>0=3@d03=cLd0clo?0<g=c@3?cll0dM7A0=3@d03Cdm<0dM7A0<o?c`3B
d]80dm?C0=CDe0030=;BdP070=7Ad@3Bd]80dM7A0=7Ad@3Cdm<0d];B0=7Ad@020<o?c`040<g=c@3?
cll0cLg=0=CDe0h0b>3H000<0<SPf080De=C02P0DU9B04m?C`1EEED0CTi>05=CD`17AdL0BTY:055A
D@1>CTh0E5AD051@D01DE5@0BDU904M7A`15ADD0@41004=3@`10@400@d=303hn?P0i>CT0>3Ph03Lg
=`0m?Cd0@d=305MGE`1WIfL0MGEe07moO`26QXH0SXj>09JFUP2HV9P0VYZJ0:2PX02SXj<0YJFU0:RX
Z02[Zj/0[Zj^0P2/[:`00`2][Jd0[:b/0:b/[0030:n_[`0E0;2`/02c/k<0/[:b0;Jf]P2c/k<0[Jf]
0:VYZ@2XZ:P0YZJV09nOW`2FUYH0TI6A08Z:RP21PH40Ogmo075aL@1UIFD0FEUI04Y:BP1;Bd/0BDU9
0080CTi>00H0EeMG05eMG@1MGEd0Fe]K05eMG@1QHF4206MWI`0`06YZJP1WIfL0L71`06i^KP1aLG40
Kfm_06][J`1?Cdl0?3`l059BDP1JFUX0DU9B03Xj>P1LG5`0GUiN05EEE@1DE5@0KFe]08b<S02CTi<0
MgMg05aLG01>CTh0C4a<03hn?P0W9bL0820P034a<@0k>c/0OGem09fMW@1`L700DU9B03lo?`0c<c<0
CDe=06m_K`12@T80;Bd]04U9B@17AdL0MWIf06i^KP1LG5`0Hf=S05UIF@1cLg<0QhN70P2OWil05@2_
[jl0Ng]k0451@@0e=CD0BDU909>CT`25QHD0?Shn02@T900[:b/0=cLg02LW9`0j>SX0@d=306EUI@1I
FET0<c<c04M7A`0l?3`0;Rh^02@T900202<S8`0A02DU9@0Q8B408b<S02LW9`0];Bd0<30`04Q8B01O
Gel0CDe=0492@P1SHf<0/K6a0:BTY01fMWH0?Cdm02TY:@0^;Rh00P0Z:RX0700];Bd0:b/[034a<@0b
<S80:b/[028R8P0P820071`L028R8P0_;bl0PH610:BTY02VYZH0ZZZZ0;6a/@2d];@0aLG50;Ng]`2n
_[h0_kno0<71`@2n_[h0_;bl0:j^[P1UIFD0=3@d02<S8`0Q8B4202PX:00;02XZ:P0U9BD09BDU02HV
9P0[:b/0:RXZ03@d=00b<S80=3@d02l_;`0/;2`00`0W9bL0500^;Rh0FUYJ06e]K@1`L700JFUY04M7
A`1?Cdl0EEEE05aLG01RHV80I6AT06IVIP1YJFT0KVi^07AdM01cLg<0NGUi07alO01iNGT0P8200P1m
OGd01P1oOgl0Ph>308:2PP21PH40P82008F5Q@80QhN700@0R8R808^;R`2<S8`0Rh^;0`2CTi<01@2>
SXh0U9BD09>CT`2IVIT0UiNG0080UYJF00<0UIFE09RHV02GUiL00P2DU9@03`2HV9P0WIfM09bLW02O
Wil0X:2P09jNWP2OWil0Vi^K09jNWP2LW9`0WYjN09fMW@2LW9`0WinO0::RXP0209JFUP0B09RHV02E
UID0U9BD08n?S`2;Rh/0QHF507]kN`1eMGD0NWYj08B4Q023Ph<0Q8B40861P@1YJFT0EeMG04I6AP0k
>c/0AdM70P1ADE40201QHF40GEeM05aLG01GEeL0EEEE05UIF@1MGEd0LW9b0P1fMWH05`1lO7`0OWin
08V9R@2EUID0XJ6Q0;Bd]02l_;`0a/K60;fm_@2ZZZX0XJ6Q0:FUY@2QXJ40U9BD092@T02EUID0TY:B
09>CT`2@T900RXZ:08j>SP2<S8`0Rh^;0080QhN70P21PH405@1lO7`0MgMg061PH00i>CT0;Bd]034a
<@0_;bl0<30`02`/;00^;Rh0:b/[02h^;P0];Bd0>CTi03@d=00_;bl0=3@d03/k>`13@d<0ATI604];
B`020410@00>04U9B@1BDU80>CTi03<c<`0b<S80<30`03@d=00e=CD0:RXZ02HV9P0T92@0?Shn07]k
N`2DU9@20:f][@0909jNWP1lO7`0OGem09RHV01nOWh0H61P03Hf=P0S8b<0:2PX0080@41000D0<C4a
0492@P1TI6@0NWYj08j>SP0409BDU080SXj>00<0U9BD09^KV`2NWYh00P2LW9`209fMW@0=09bLW02I
VIT0VIVI09ZJVP2EUID0Vi^K09FEU@2HV9P0UiNG09>CT`2HV9P0UiNG09JFUP0209FEU@0709>CT`2H
V9P0UYJF09:BTP2HV9P0UiNG09JFUP0209NGU`0>09JFUP2CTi<0UYJF09:BTP2FUYH0Ti>C09BDU02?
Shl0TI6A09:BTP2ATI40SHf=09:BTP2@T90209:BTP06092@T02CTi<0SHf=08n?S`2>SXh0Rh^;0P2:
RXX00`25QHD0Q8B408F5Q@0208N7Q`0=09BDU02LW9`0ZJVY0;Jf]P2l_;`0_kno0<;2`P37alL0a/K6
0<C4a036a/H0a<C40<G5a@020<C4a0070<?3``35aLD0a/K60<C4a036a/H0bLW90<[:bP030<g=c@06
0<k>cP3=cLd0clo?0<o?c`3>c/h0c<c<0P3>c/h01@3?cll0d=3@0=7Ad@3@d=00clo?0080d];B0P3A
dM401`3@d=00dM7A0=7Ad@3Bd]80dM7A0=?Cd`3AdM400P3Cdm<00`3Bd]80clo?0=3@d0020<k>cP03
0<g=c@38h=P0b>3H00`0b>3H000<0<SPf080CDe=00<0De=C051@D01ADE400P1>CTh205=CD`0N04U9
B@1ADE40B4Q804Q8B01=CDd0BTY:04I6AP14A4@0@T9204=3@`0k>c/0A4A40451@@0i>CT0>SXj02l_
;`0e=CD0@41005ADE01RHV80Kfm_07emO@23Ph<0Rh^;09:BTP2FUYH0V9RH09jNWP2TY:@0YZJV0P2Z
ZZX03@2[Zj/0[Jf]0:f][@2b/[80[jn_0:j^[P2a/K40[Jf]0;2`/02a/K40/;2`0;Bd]02c/k<00P2a
/K406P2`/;00Zj^[0:FUY@2LW9`0UYJF08b<S02@T900Ph>307emO@1aLG40JFUY065QH@1BDU80A4A4
04m?C`1<C4`0Cdm?05ADE01FEUH0GUiN05YJFP1PH600HV9R06YZJP1YJFT0J6QX0P1[Jf/0;@1_Kfl0
M7Ad079bLP1ZJVX0GEeM04e=C@1>CTh0E5AD04];B`10@400EEEE06EUI@1IFET0DE5A06IVIP1jNWX0
TY:B07emO@1SHf<0EUIF051@D01?Cdl0=CDe02HV9P0T92@0=SHf06MWI`2UYJD0QhN705eMG@1HF5P0
>c/k0410@01NGUh0?Shn02/[:`0i>CT0DU9B07UiN@1/K6`0GEeM06=SH`1HF5P0K6a/09BDU0020:b/
[00:0:VYZ@1[Jf/0=3@d02h^;P1ADE40WIfM07inOP0k>c/0:BTY02h^;P80<C4a00P0=SHf04Q8B01=
CDd0@T9203dm?@1?Cdl0?Cdm02DU9@808b<S01L0:2PX024Q8@0O7al08B4Q02TY:@0_;bl0>c/k04m?
C`12@T80<30`03De=@1WIfL0/;2`0:ZZZP1nOWh0=3@d02<S8`0U9BD08R8R02HV9P0[:b/0:RXZ02h^
;P0202`/;00J02HV9P0U9BD08R8R01lO7`0Q8B40F5QH0:f][@2a/K40[Jf]0;>c/`2j^[X0a<C40;Bd
]02g]kL0_Kfm0;bl_02n_[h0]kNg0:j^[P2RXZ80M7Ad030`<00Y:BT0:RXZ02<S8`0Q8B4202HV9P80
9BDU00H09RHV02`/;00h>3P0;Rh^02XZ:P0^;Rh302/[:`0B02d];@1GEeL0JVYZ069RHP1OGel0Bd];
04U9B@1ADE40H61P05iNGP1PH600HV9R06][J`1`L700LG5a07EeM@1iNGT0N7Qh0P1jNWX01@1kNg/0
P8200861P@22PX80P8200080PX:200<0QXJ608Z:RP29RHT00P28R8P01`2;Rh/0RXZ:092@T02?Shl0
SHf=08j>SP2JVYX00P2FUYH02P2CTi<0VIVI09VIV@2FUYH0Vi^K09bLW02HV9P0UIFE09ZJVP2LW9`2
09ZJVP0509fMW@2LW9`0X:2P09nOW`2NWYh00P2OWil0602NWYh0X:2P09nOW`2QXJ40V9RH09>CT`2D
U9@0TI6A08f=S@2?Shl0RXZ:08:2PP1gMgL0NGUi0861P@24Q8@0QXJ608R8R023Ph<0IFEU0451@@0b
<S80<C4a038b<P80@41005D0CDe=05UIF@1PH600FUYJ06=SH`1aLG40MGEe07YjNP1nOWh0NGUi07]k
N`1oOgl0SXj>09nOW`2XZ:P0^KVi0;no_`38b<P0alO70:f][@2OWil0WYjN09JFUP2EUID0UYJF09BD
U02HV9P0UIFE09>CT`2BTY80T92@08f=S@2;Rh/0QHF508:2PP21PH40P82007]kN`1fMWH0JVYZ04];
B`0a<C40:b/[02PX:00^;Rh0<S8b02h^;P0];Bd0:2PX030`<00i>CT0=SHf03De=@0d=3@0?3`l04=3
@`15ADD0D51@04I6AP0f=SH0@d=3055AD@0m?Cd0<30`038b<P0c<c<0<S8b02d];@0/;2`09RHV02PX
:01:BTX0R8R809BDU02/[:`0ZZZZ0:6QX@23Ph<0PH6108n?S`1iNGT0GemO03Hf=P0U9BD0;bl_0080
=cLg00P09bLW03Xj>P1QHF40Ng]k08:2PP2FUYH0V9RH09NGU`80U9BD00l0SXj>092@T02LW9`0XZ:R
0:6QX@2NWYh0Vi^K09fMW@2IVIT0WIfM09bLW02KVi/0V9RH09ZJVP2LW9`00P2EUID00`2DU9@0VIVI
09bLW00309FEU@0409BDU02EUID0UIFE09BDU080UIFE02/0T92@09JFUP2HV9P0UiNG09BDU02ATI40
Shn?09BDU02BTY80Ti>C09BDU02?Shl0T92@09FEU@2CTi<0Rh^;08R8R02DU9@0T92@096AT@2BTY80
SXj>08b<S02>SXh0U9BD08Z:RP28R8P0Q8B408J6QP25QHD0PH6108F5Q@2@T900Vi^K0:JVYP2a/K40
^k^k0;fm_@2n_[h0a/K60<C4a035aLD0a/K60080a<C40P32`/801034a<@0`/;20<?3``34a<@20<K6
aP050<W9b@3=cLd0c<c<0<c<c03?cll00P3>c/h20<g=c@050<c<c03;bl/0cLg=0<o?c`3>c/h00P3?
cll30=7Ad@80d=3@00<0dM7A0=3@d03AdM400`3AdM402@3?cll0dM7A0=7Ad@3Bd]80clo?0=3@d03?
cll0d=3@0<o?c`0>0<SPf0003038h=P205MGE`0@05]KF`1@D500D51@04m?C`1DE5@0C4a<055AD@1?
Cdl0CTi>04];B`1=CDd0D51@04i>CP15ADD0A4A403lo?`80@T9200`0>c/k03Ti>@0h>3P0=SHf03<c
<`0a<C40>c/k04m?C`1LG5`0JVYZ07MgM`24Q8@208j>SP0409JFUP2IVIT0XJ6Q0:NWY`80Z:RX00P0
ZJVY0:b/[02][Jd0[Jf]0:ZZZP2[Zj/0[Zj^0:b/[080/;2`01/0[jn_0;>c/`2c/k<0];Bd0;:b/P2a
/K40ZZZZ0:JVYP2SXj<0VIVI09NGU`2<S8`0T92@0861P@1iNGT0KFe]06UYJ@1XJ6P0FUYJ05=CD`1;
Bd/0Cdm?051@D01HF5P0DU9B05]KF`1JFUX00P1OGel04P1VIVH0HV9R06ATI01YJFT0KFe]07IfMP1e
MGD0OGem08f=S@1LG5`0GEeM051@D018B4P0@T9203lo?`1=CDd0EeMG06EUI@80GemO01h0KVi^0861
P@1gMgL0IFEU059BDP1<C4`0A4A40410@00R8R8092@T03Ph>01HF5P0TY:B09RHV01^KVh0HF5Q055A
D@0m?Cd0DU9B03De=@0^;Rh0<c<c05MGE`22PX80KVi^05iNGP1GEeL0EUIF07=cL`2PX:020;Fe]@0a
09ZJVP1LG5`0@41003Lg=`1]KFd0Xj>S07=cL`0h>3P0:RXZ038b<P0a<C40;Bd]03<c<`1=CDd0?3`l
03Ti>@0c<c<0G5aL04e=C@0W9bL0820P02@T900W9bL0<c<c02`/;00h>3P0?clo04Y:BP0m?Cd0<c<c
02/[:`0_;bl0<c<c05ADE021PH40RHV907=cL`14A4@0:2PX02HV9P0T92@09bLW02/[:`0U9BD0:b/[
02`/;00Z:RX09BDU020P800201dM7@0801lO7`0g=cL0XZ:R0;Bd]02/[:`0[jn_0:f][@2o_kl20;>c
/`0=0;Rh^02m_Kd0^KVi0;>c/`2_[jl0YjNW0:6QX@1KFe/0?3`l03De=@0W9bL09BDU024Q8@02028R
8P0302HV9P0Y:BT0;Bd]0080;bl_00<09BDU02LW9`0Y:BT00P0U9BD08@0^;Rh0GUiN06i^KP1HF5P0
Fe]K04M7A`1@D500C4a<05IFEP1MGEd0HV9R06EUI@1ZJVX0MgMg07=cL`1iNGT0MgMg07emO@1lO7`0
NWYj07emO@22PX80P82007moO`1nOWh0PX:208B4Q027QhL0RXZ:08f=S@2<S8`0Rh^;08Z:RP02092@
T00H096AT@2@T900T92@09FEU@2KVi/0U9BD09:BTP2JVYX0U9BD09NGU`2JVYX0W9bL09FEU@2HV9P0
VIVI09fMW@2IVIT0WinO09bLW02NWYh0W9bL09jNWP2LW9`0WYjN0P2MWId01`2IVIT0WinO09fMW@2L
W9`0UYJF09:BTP2DU9@00P2:RXX03P27QhL0P82007AdM01hN7P0QhN708B4Q025QHD0Q8B408Z:RP1h
N7P0EUIF03Xj>P0h>3P0>CTi0P19BDT02P1IFET0IVIV079bLP1cLg<0MgMg07inOP1iNGT0Ng]k07Ui
N@1nOWh208>3P`0H08f=S@2OWil0/;2`0;bl_034a<@0bLW90<c<c02o_kl0YJFU09ZJVP2DU9@0UYJF
09>CT`2ATI40Ti>C09:BTP2DU9@0SHf=092@T029RHT0Rh^;08F5Q@20P800Ogmo0P1nOWh0201kNg/0
LW9b05eMG@0j>SX0<c<c02PX:00/;2`09RHV0P0_;bl202d];@0=03Lg=`0k>c/0>3Ph03<c<`0n?Sh0
@d=30451@@1=CDd0C4a<03Lg=`10@400CTi>03`l?002030`<00<03@d=00`<30092@T02XZ:P0X:2P0
9RHV05QHF02@T900Vi^K0:^[Z`2WYjL0X:2P0P2;Rh/01P2=SHd0Ng]k061PH00a<C40:2PX03<c<`80
:2PX01/0;2`/02l_;`1EEED0KFe]08^;R`2ATI40T92@09FEU@2BTY80Shn?092@T02?Shl0UiNG09fM
W@2NWYh0XJ6Q0:2PX02NWYh0W9bL09ZJVP2HV9P0VYZJ09^KV`2JVYX0UiNG09bLW02GUiL00P2DU9@0
102CTi<0U9BD09NGU`2GUiL209JFUP80UiNG00<0UYJF09RHV02IVIT00P2FUYH0102DU9@0UIFE08j>
SP2=SHd209>CT`06092@T02CTi<0VYZJ09:BTP2CTi<0Shn?0P2ATI406P2?Shl0TI6A08^;R`2BTY80
T92@08n?S`2:RXX0Rh^;08j>SP29RHT0RXZ:08N7Q`23Ph<0PH6107emO@28R8P0VIVI0:JVYP2^[Zh0
][Jf0;jn_P31`L40`l?30<K6aP34a<@0aLG50P34a<@20<71`@030<?3``35aLD0`/;20080`l?300D0
aLG50<W9b@38b<P0cLg=0<k>cP020<g=c@050<k>cP3?cll0cLg=0<_;b`3?cll00`3=cLd01P3>c/h0
cLg=0<o?c`3AdM40clo?0<k>cP80clo?0P3AdM40303Bd]80d=3@0=7Ad@3@d=00d];B0=7Ad@3>c/h0
dM7A0<o?c`3@d=00clo?0<g=c@h0b>3H000<0<SPf080FUYJ02P0DE5A04m?C`1CDe<0CDe=051@D01L
G5`0DU9B04e=C@1CDe<0DU9B04M7A`18B4P0CDe=04U9B@12@T80A4A40451@@0l?3`0?Shn03lo?`0k
>c/0<C4a02d];@0/;2`0>SXj04];B`1HF5P0IFEU07]kN`1oOgl0QXJ608f=S@2EUID0UiNG09nOW`2T
Y:@0ZZZZ0:RXZ02][Jd0[:b/0P2_[jl02@2/[:`0[jn_0:j^[P2[Zj/0[:b/0:j^[P2][Jd0];Bd0:n_
[`020;:b/P1:0;2`/02/[:`0YjNW0:>SX`2HV9P0VYZJ08f=S@28R8P0P82007emO@1^KVh0HV9R06EU
I@1YJFT0H61P06MWI`1TI6@0G5aL05eMG@1JFUX0GEeM05mOG`1NGUh0HF5Q06EUI@1TI6@0IFEU06][
J`1_Kfl0N7Qh07emO@1fMWH0Ng]k06ATI01GEeL0De=C04Y:BP0b<S80=CDe04Y:BP1MGEd0Hf=S06UY
J@1RHV80J6QX07YjNP1[Jf/0JVYZ05QHF01<C4`0@D5104];B`0_;bl09BDU03<c<`1ADE40K6a/08n?
S`25QHD0FUYJ05=CD`0m?Cd0@T9202h^;P0Z:RX0=SHf065QH@1nOWh0KFe]059BDP19BDT0EEEE07If
MP2OWil20:f][@0F08B4Q013@d<0=cLg03De=@1nOWh0YZJV05mOG`0a<C40:BTY02h^;P0d=3@0;2`/
02h^;P0`<300;Rh^03<c<`0j>SX0GemO04Q8B00U9BD0820P02LW9`80:b/[0140>SXj04a<C011@D40
?clo03Ti>@0[:b/0:2PX02DU9@0Z:RX0<c<c04=3@`1;Bd/0LG5a069RHP1?Cdl0AdM703<c<`0202TY
:@809bLW0P0V9RH02@0/;2`0:BTY020P800Q8B407AdM02DU9@2<S8`0[Zj^0:FUY@020:NWY`80];Bd
00l0ZJVY0;2`/02`/;00];Bd0;Vi^@2d];@0][Jf0;Bd]02IVIT0Ng]k04a<C00];Bd0:BTY02HV9P0P
82000`0R8R801P0`<300;Bd]02/[:`0V9RH0:2PX02TY:@809BDU01P0=3@d061PH01_Kfl0I6AT05aL
G016ATH0CDe=04a<C01EEED0G5aL05eMG@1VIVH0KFe]07AdM01_Kfl0NGUi07YjNP1mOGd0P82007al
O01mOGd0QHF507moO`1mOGd208>3P`0608:2PP28R8P0QXJ608b<S02:RXX0TI6A0P2=SHd0102?Shl0
T92@08f=S@2BTY8209FEU@0:09JFUP2GUiL0UIFE09ZJVP2HV9P0UIFE09NGU`2EUID0UiNG09VIV@80
W9bL00<0WinO09RHV02MWId00`2NWYh02P2PX:00WinO0:2PX02MWId0Vi^K09jNWP2GUiL0UYJF08n?
S`2DU9@208Z:RP0808B4Q01aLG40K6a/075aL@21PH40Ogmo08V9R@27QhL208F5Q@0408>3P`1gMgL0
L71`07EeM@80OWin00D0Ogmo0820P022PX80Q8B407inOP0207YjNP80NGUi0140PH6108B4Q02?Shl0
UIFE0:NWY`2a/K40`L710<S8b03=cLd0c<c<0<g=c@2j^[X0VIVI09:BTP2GUiL0Shn?09:BTP0209NG
U`0B09:BTP2@T900Ti>C092@T02;Rh/0RHV908^;R`24Q8@0PX:207alO01iNGT0MWIf06QXJ019BDT0
<C4a02`/;00Z:RX0:2PX0P0/;2`202d];@0H030`<00e=CD0<S8b03<c<`0f=SH0>c/k03Xj>P18B4P0
AdM703Xj>P0m?Cd0C4a<03dm?@0X:2P0<30`03Hf=P0Z:RX08b<S034a<@0Z:RX0;2`/05MGE`2:RXX0
XZ:R0P2YZJT02@2QXJ40S8b<08^;R`24Q8@0MWIf05IFEP0Y:BT092@T02l_;`02028R8P0>024Q8@0Y
:BT0@T9206EUI@21PH40U9BD092@T02FUYH0T92@096AT@2>SXh0S8b<09FEU@2MWId20:2PX0060:6Q
X@2NWYh0WIfM09fMW@2KVi/0V9RH0`2GUiL00`2IVIT0UiNG09NGU`0209BDU00>09FEU@2JVYX0UIFE
09NGU`2KVi/0V9RH09NGU`2EUID0VYZJ09VIV@2HV9P0UiNG09VIV@2DU9@209JFUP80TY:B00@0TI6A
09BDU02GUiL0UIFE0P2CTi<01P2EUID0UiNG092@T02BTY80SXj>09:BTP80Shn?00D0S8b<08f=S@2<
S8`0SXj>08V9R@0208B4Q00:08F5Q@22PX80QHF509BDU02SXj<0[Jf]0;Fe]@2l_;`0_[jn0<;2`P80
a/K600<0aLG50<C4a032`/800P32`/800`30`<00`/;20<30`0020<?3``80aLG50P39bLT02`3<c<`0
bl_;0<_;b`3=cLd0c/k>0<g=c@3<c<`0cLg=0<k>cP3?cll0c/k>0080cLg=00l0clo?0=3@d03?cll0
clo?0<g=c@3?cll0d=3@0=7Ad@3>c/h0clo?0=3@d03Cdm<0dM7A0<o?c`3>c/h00P3?cll20<k>cP03
0<g=c@38h=P0b>3H00`0b>3H000<0<SPf080F5QH00<0EUIF05=CD`1CDe<00P1=CDd01P1GEeL0D51@
04Y:BP1;Bd/0DE5A04];B`80B4Q800T0@D5104A4A012@T80@T920410@00o?cl0?Shn02d];@0/;2`0
0P0[:b/02`0j>SX0CDe=05QHF01YJFT0MGEe0861P@24Q8@0T92@09JFUP2JVYX0XJ6Q0080YjNW00<0
Zj^[0:b/[02^[Zh00P2[Zj/02@2][Jd0[Zj^0:f][@2/[:`0[Zj^0;6a/@2_[jl0/K6a0;>c/`020;Fe
]@040:n_[`2^[Zh0/;2`0::RXP80W9bL00T0Shn?08N7Q`1oOgl0MgMg075aL@1RHV80Fe]K05UIF@1]
KFd00P1oOgl0601iNGT0Ogmo06m_K`1WIfL0GemO05iNGP1RHV80I6AT06EUI@1WIfL0K6a/075aL@1e
MGD0N7Qh07YjNP1gMgL0JVYZ05QHF015ADD0C4a<03dm?@0l?3`0@T9205]KF`80H61P01l0Kfm_06MW
I`1iNGT0KFe]05IFEP1GEeL0Cdm?04Q8B014A4@0=SHf034a<@0i>CT0C4a<0410@01TI6@0Shn?06UY
J@1>CTh0?clo03<c<`0];Bd0;bl_03Ti>@1[Jf/0PH6106EUI@1:BTX0@D51059BDP21PH40WYjN0080
XJ6Q01`0JVYZ03Ti>@0^;Rh0?Shn08^;R`2<S8`0@T92034a<@0];Bd0>CTi03lo?`0g=cL0:b/[030`
<00[:b/0<S8b03/k>`1@D500@d=302XZ:P0P82008B4Q02PX:00Z:RX0=SHf04Y:BP0g=cL0>3Ph0P0_
;bl03@0/;2`0:2PX02PX:00Z:RX0<S8b03lo?`1YJFT0PX:2079bLP1`L700AdM702d];@0W9bL00P0T
92@01@0W9bL08R8R02h^;P0Z:RX0820P00806a/K00`07AdM069RHP2XZ:P0WIfM0:ZZZP2XZ:P0YZJV
0:n_[`2YZJT0[:b/0:NWY`2a/K420;Fe]@090;Rh^02m_Kd0[Jf]08b<S01gMgL0Cdm?03Lg=`0Y:BT0
92@T00809RHV00<09bLW02`/;00Y:BT00P0a<C409@0_;bl09RHV02LW9`0W9bL0<S8b05QHF01YJFT0
Fe]K05IFEP0n?Sh0>SXj04M7A`1EEED0FUYJ061PH01UIFD0KVi^07AdM01cLg<0MWIf07emO@1lO7`0
Ogmo08>3P`1mOGd0Q8B40820P01oOgl0Ph>30820P025QHD0QXJ608>3P`2;Rh/0T92@08j>SP29RHT0
0P2=SHd02P2GUiL0SHf=08n?S`2HV9P0Shn?09JFUP2IVIT0Ti>C09NGU`2EUID209NGU`0909BDU02K
Vi/0W9bL09bLW02PX:00VYZJ09NGU`2LW9`0XJ6Q0080WinO0P2NWYh0602LW9`0Vi^K09ZJVP2KVi/0
UYJF096AT@2BTY80T92@08^;R`2DU9@0P82007AdM01/K6`0M7Ad07alO01mOGd0QhN708Z:RP27QhL0
QXJ608N7Q`26QXH0Q8B408J6QP80SHf=00D0RHV908B4Q02;Rh/0Q8B407inOP0207MgM`0L07IfMP1j
NWX0QHF5096AT@2DU9@0X:2P0:b/[02j^[X0a<C40<[:bP3>c/h0e=CD0=;BdP3;bl/0YjNW092@T02C
Ti<0U9BD096AT@2DU9@0TI6A092@T02?Shl0TI6A09:BTP2<S8`0R8R808Z:RP80P8200P1nOWh01P1h
N7P0Kfm_05UIF@14A4@0<C4a02TY:@80:RXZ02H0;2`/02TY:@0Y:BT0=SHf03Ti>@0c<c<0<S8b03De
=@10@400?Cdm04Q8B01BDU80?Cdm04I6AP1@D500?Cdm02d];@0b<S80<30`02TY:@0V9RH0=3@d02PX
:00Z:RX0IfMW092@T02UYJD0Y:BT0:RXZ02PX:00Shn?09>CT`1hN7P0LW9b051@D00b<S80;Rh^02/[
:`@09BDU0180?Shn05eMG@1oOgl0Shn?096AT@2CTi<0U9BD09>CT`2=SHd0SXj>09BDU02NWYh0XJ6Q
09jNWP2OWil0W9bL09jNWP2KVi/309ZJVP0409VIV@2JVYX0V9RH09VIV@80VYZJ00@0UiNG09BDU02I
VIT0UiNG0P2HV9P209JFUP0809BDU02FUYH0VYZJ09RHV02EUID0U9BD09JFUP2HV9P209FEU@0;096A
T@2EUID0UYJF09RHV02CTi<0U9BD09JFUP2CTi<0TI6A08j>SP2DU9@00P2?Shl0102CTi<0SHf=08Z:
RP2:RXX208^;R`0B08J6QP2:RXX0QHF50820P023Ph<0Q8B408n?S`2QXJ40ZZZZ0;6a/@2j^[X0`<30
0<?3``37alL0`l?30<;2`P34a<@0`/;20`33`l<30<30`0030;no_`32`/80`l?30080bLW900@0bl_;
0<g=c@3:b/X0cLg=0P3>c/h0103=cLd0clo?0<o?c`3AdM440<k>cP060<g=c@3?cll0cLg=0<g=c@3<
c<`0cLg=0`3?cll01P3AdM40d];B0=3@d03?cll0d];B0=7Ad@<0d=3@00<0c/k>0<SPf038h=P03038
h=P000`0b>3H0P1DE5@0:01HF5P0EUIF05EEE@1?Cdl0D51@04m?C`1ADE40BDU904];B`1=CDd0Bd];
04U9B@18B4P0Bd];04U9B@17AdL0?clo0451@@0m?Cd0>c/k02`/;00a<C40:BTY02PX:00d=3@0A4A4
05ADE01YJFT0MgMg07inOP25QHD0TI6A09>CT`2JVYX0Y:BT0:JVYP2WYjL0/;2`0;6a/@2_[jl30;2`
/080[jn_00D0/K6a0:n_[`2a/K40];Bd0;6a/@030;>c/`0H0:j^[P2YZJT0ZJVY0:2PX02KVi/0UiNG
08n?S`28R8P0Ogmo07AdM01[Jf/0FUYJ05ADE01=CDd0EUIF061PH01^KVh0Ogmo08Z:RP2@T900Q8B4
07AdM01UIFD0H61P0P1YJFT0<01[Jf/0J6QX07=cL`1fMWH0N7Qh07EeM@1cLg<0LG5a05eMG@14A4@0
Cdm?04I6AP18B4P0>c/k05]KF`1JFUX0E5AD06i^KP1iNGT0MGEe07MgM`1EEED0C4a<05YJFP1?Cdl0
A4A403dm?@18B4P0@d=3059BDP0`<300ATI608:2PP23Ph<0DE5A04];B`0^;Rh0;2`/038b<P1=CDd0
M7Ad08^;R`1SHf<0B4Q80410@01VIVH0TI6A09ZJVP80UIFE01D0H61P038b<P0e=CD0>c/k08f=S@1V
IVH0;Rh^038b<P0o?cl0BTY:04M7A`14A4@0<C4a02l_;`0X:2P0;Bd]03Xj>P19BDT0?Cdm02<S8`0U
9BD00P0Y:BT06`0`<300>SXj04M7A`10@400Jf][059BDP1?Cdl0?3`l02/[:`0Y:BT0=CDe03`l?01<
C4`0GUiN07AdM01^KVh0DE5A034a<@0^;Rh09BDU020P800R8R808B4Q01lO7`0U9BD0:2PX02HV9P02
01dM7@0301`L700k>c/0X:2P0080Xj>S01/0YJFU09nOW`2OWil0YZJV0:b/[02QXJ40WYjN09^KV`2O
Wil0ZJVY0;fm_@2j^[X0ZZZZ08n?S`1MGEd0@D5102HV9P0Q8B40820P01lO7`0V9RH0=CDe02PX:00_
;bl0:2PX02XZ:P0Y:BT00P0X:2P03`0d=3@0Fe]K06YZJP1WIfL0FUYJ04M7A`14A4@0?Cdm05=CD`1H
F5P0GemO06UYJ@1`L700LW9b07AdM00207IfMP0508>3P`1kNg/0Ogmo08B4Q021PH400P1oOgl208>3
P`<0QXJ60140QhN708f=S@2=SHd0SHf=092@T02=SHd0TY:B08f=S@2CTi<0T92@096AT@2DU9@0W9bL
09NGU`2FUYH0V9RH09^KV`0209bLW00909NGU`2LW9`0WIfM09jNWP2KVi/0WYjN09fMW@2NWYh0YJFU
0080WYjN01T0WinO09bLW02RXZ80WIfM09ZJVP2GUiL0U9BD09VIV@2?Shl0TI6A08n?S`23Ph<0MGEe
06][J`1bLW80N7Qh07emO@25QHD0Shn?08f=S@2;Rh/0RHV908R8R02:RXX0TY:B0080SHf=01/0Shn?
092@T02<S8`0Ph>307inOP1hN7P0MgMg07YjNP1nOWh0RXZ:09BDU02JVYX0YjNW0;>c/`2l_;`0alO7
0<k>cP3EeMD0fm_K0=WIf@3?cll0]kNg08f=S@2?Shl0VIVI09NGU`2BTY800P2FUYH00`2CTi<0SHf=
08j>SP0208b<S00308B4Q023Ph<0Ogmo00<0OWin00/0L71`06QXJ01?Cdl0>SXj02d];@0W9bL0:RXZ
02h^;P0/;2`0:2PX03De=@02038b<P0P02h^;P0h>3P0@4100451@@14A4@0ADE50410@01:BTX0Bd];
03hn?P0^;Rh0=CDe02h^;P0U9BD0:BTY03Ph>00`<300=3@d079bLP2BTY80YZJV0:FUY@2OWil0UiNG
09>CT`2FUYH0OWin06m_K`1@D500<c<c02/[:`0S8b<201hN7P0C02<S8`0V9RH0=3@d05ADE022PX80
R8R809>CT`2ATI40Ti>C09FEU@2=SHd0S8b<08f=S@2JVYX0XJ6Q0:2PX02OWil0W9bL09nOW`0209^K
V`0809jNWP2HV9P0UYJF09RHV02KVi/0VIVI09NGU`2EUID209JFUP0>09>CT`2FUYH0UIFE09JFUP2H
V9P0UIFE09RHV02FUYH0UIFE09JFUP2DU9@0UYJF096AT@2CTi<209:BTP0909ZJVP2DU9@0U9BD09>C
T`2EUID0UiNG09BDU02FUYH0T92@0080TI6A01D0SHf=09:BTP2>SXh0T92@096AT@2>SXh0TI6A08N7
Q`28R8P0Rh^;08V9R@24Q8@0OWin08J6QP2=SHd0VIVI0:BTY02/[:`0^;Rh0;no_`32`/800P36a/H0
0`34a<@0`/;20<C4a0020<?3``090<C4a031`L40a<C40<30`032`/80`l?30<;2`P36a/H0alO70080
bLW900D0c<c<0<o?c`3=cLd0d=3@0<o?c`020<k>cP040=3@d03?cll0clo?0=3@d080cLg=0P3<c<`0
0`3;bl/0c<c<0<_;b`040<o?c`050=7Ad@3?cll0clo?0<o?c`3AdM400P3@d=000`3=cLd0clo?0<SP
f00=0<SPf0003038h=P205IFEP80EEEE00<0DE5A05ADE01@D5000P1@D500201ADE40D51@04e=C@1;
Bd/0BTY:04M7A`10@400@D510P0o?cl05@0i>CT0=SHf03De=@0_;bl0;Rh^02/[:`0W9bL0;Rh^0410
@01@D500IVIV07UiN@1oOgl0QXJ608j>SP2FUYH0Vi^K0:2PX02UYJD0YjNW0:^[Z`020:b/[080[Jf]
00<0[Zj^0;2`/02`/;000P2`/;001@2_[jl0/[:b0;>c/`2a/K40/k>c0080/[:b01/0[:b/0:RXZ02T
Y:@0W9bL09VIV@2CTi<0Rh^;07inOP1jNWX0IFEU05QHF01?Cdl0Bd];0492@P1:BTX0De=C05mOG`1a
LG40QhN708^;R`2:RXX0Ph>306UYJ@1ZJVX0Hf=S06][J`1^KVh00P1[Jf/0501aLG40MGEe07MgM`1^
KVh0IfMW04m?C`13@d<0BTY:03dm?@0o?cl0G5aL05iNGP18B4P0DU9B07QhN01dM7@0PX:206i^KP12
@T80D51@0P1MGEd05P1:BTX0@D51059BDP19BDT0;bl_03Ph>01hN7P0SHf=05eMG@1=CDd0<S8b02HV
9P0g=cL0E5AD06i^KP2<S8`0HV9R03hn?P19BDT0Ogmo09BDU02JVYX208n?S`1:05EEE@0b<S80<30`
051@D028R8P0ATI602/[:`0b<S80<C4a03Ti>@18B4P0C4a<03Hf=P0d=3@0;Rh^02/[:`0V9RH0=cLg
03Ti>@0T92@0820P02<S8`0e=CD0>3Ph0451@@1?Cdl0J6QX0:6QX@2CTi<0WinO06UYJ@10@400=CDe
0410@01@D500FEUI06MWI`1aLG40IFEU03lo?`0c<c<0:RXZ02l_;`0Y:BT09bLW024Q8@0W9bL092@T
02HV9P0a<C409bLW020P800Q8B40:RXZ07QhN02YZJT0XJ6Q0:JVYP2TY:@0VIVI09JFUP2BTY80PH61
0820P01eMGD0MgMg08:2PP2QXJ40Zj^[0;fm_@2a/K40TI6A06EUI@0a<C4302@T900702PX:00V9RH0
<S8b02LW9`0S8b<09bLW02PX:00202DU9@0R02`/;01MGEd0LG5a06=SH`1IFET0@d=304E5A@1:BTX0
C4a<05aLG01JFUX0JFUY06e]K@1_Kfl0M7Ad07QhN01kNg/0P82007QhN01mOGd0Ogmo08:2PP20P800
PH6108F5Q@21PH40Ph>308R8R027QhL0RHV908b<S02;Rh/0TY:B08n?S`80T92@0P2?Shl03@2CTi<0
UIFE09NGU`2GUiL0UYJF09VIV@2EUID0V9RH0:6QX@2KVi/0WIfM09nOW`2LW9`01@2OWil02@2RXZ80
WinO09jNWP2OWil0WIfM0:6QX@2NWYh0VYZJ09FEU@0209:BTP09092@T02;Rh/0S8b<07inOP1hN7P0
J6QX071`L01fMWH0OGem0080QXJ60P2=SHd0102>SXh0RHV908b<S02=SHd208b<S00M092@T02>SXh0
RXZ:08:2PP1lO7`0NGUi07alO01nOWh0PX:208^;R`2CTi<0WIfM0:b/[02c/k<0_Kfm0<S8b03De=@0
g]kN0>;RhP3Lg=`0e=CD0;no_`2ATI40SXj>09>CT`2FUYH0UIFE09:BTP2CTi<00P2@T9003`2:RXX0
S8b<08R8R026QXH0PH610820P022PX80NWYj07alO01jNWX0LW9b05]KF`0o?cl0;Rh^02@T900202TY
:@809RHV0100<30`02d];@0c<c<0<30`03Ph>00o?cl0?3`l0410@01:BTX0B4Q804U9B@1=CDd0>c/k
02l_;`0i>CT0:RXZ0P0R8R803P0c<c<0:BTY03Lg=`1fMWH0U9BD0:f][@2SXj<0X:2P09JFUP2ATI40
TY:B08N7Q`1[Jf/0@D510P0b<S802`0S8b<08R8R028R8P0W9bL092@T02h^;P1KFe/0MGEe07inOP2>
SXh0TY:B0080Ti>C00T0TI6A08f=S@29RHT0TY:B0::RXP2PX:00WIfM0:2PX02LW9`00P2MWId03P2N
WYh0Vi^K09fMW@2RXZ80V9RH09NGU`2HV9P0UIFE09VIV@2FUYH0VIVI09FEU@2BTY80VIVI0P2EUID0
1P2DU9@0UIFE09JFUP2FUYH0V9RH09>CT`<0U9BD00H0UIFE09>CT`2HV9P0U9BD09:BTP2ATI4209BD
U00809FEU@2ATI40TY:B096AT@2?Shl0TI6A092@T02ATI4208j>SP05092@T028R8P0RXZ:08J6QP28
R8P00P22PX802`25QHD0QXJ6096AT@2QXJ40YZJV0;>c/`2l_;`0`/;20<?3``34a<@0a/K600@0aLG5
00d0`l?30<71`@33`l<0`l?30<;2`P33`l<0_kno0<?3``34a<@0a/K60<W9b@3<c<`0c/k>0080clo?
00L0dM7A0<o?c`3?cll0dM7A0<o?c`3=cLd0d=3@00<0cLg=00L0bl_;0<k>cP3?cll0c<c<0<k>cP3A
dM40clo?0080d=3@00@0clo?0<k>cP3?cll0d=3@0P3?cll00`3=cLd0c/k>0<SPf00=0<SPf0003038
h=P205ADE00:05MGE`1ADE40E5AD055AD@1>CTh0D51@055AD@1;Bd/0D51@04a<C080AdM70P13@d<0
6P11@D40>c/k03lo?`0k>c/0?3`l03Ti>@0_;bl0<30`02`/;00W9bL0<30`03dm?@1>CTh0HF5Q07Mg
M`1nOWh0QhN708b<S02FUYH0WYjN0:>SX`2UYJD0YjNW0:ZZZP2/[:`0Zj^[0`2a/K400`2][Jd0/;2`
0;2`/0040;2`/0030;Bd]02e]KD0/k>c0080[Jf]00/0[:b/0:2PX02LW9`0UiNG09:BTP2:RXX0OWin
07YjNP1[Jf/0Fe]K051@D00204M7A`0:04I6AP1<C4`0EeMG065QH@1gMgL0OGem08^;R`2>SXh0PX:2
071`L080J6QX02`0JVYZ06a/K01/K6`0N7Qh07AdM01fMWH0LW9b06EUI@1:BTX0ADE504i>CP1<C4`0
BDU905aLG01RHV80G5aL03dm?@1MGEd0Lg=c07]kN`1iNGT0Cdm?04E5A@1=CDd0FUYJ055AD@12@T80
CDe=04Q8B00k>c/0>CTi06ATI02@T900NWYj04a<C00_;bl0:2PX03Hf=P1HF5P0MgMg08Z:RP1OGel0
>SXj05ADE080QhN701<0Vi^K08Z:RP2:RXX0E5AD034a<@0h>3P0IfMW08:2PP0o?cl0:b/[02l_;`0Z
:RX0<30`03De=@0l?3`0BTY:04A4A00l?3`0=SHf0080:b/[03/0;bl_024Q8@0R8R809BDU04Q8B01>
CTh0?Cdm05UIF@1JFUX0K6a/08F5Q@2OWil0F5QH04I6AP1DE5@0GUiN06e]K@2FUYH0XZ:R09BDU020
P800GemO04];B`0m?Cd0ADE503<c<`0_;bl0:2PX02LW9`0R8R809BDU030`<00/;2`08B4Q028R8P0U
9BD0AdM708b<S02HV9P0VYZJ09JFUP28R8P0PH6107IfMP1[Jf/0KFe]06ATI01fMWH0Ph>308N7Q`2B
TY80XZ:R0:f][@2LW9`0KVi^03Lg=`0Y:BT09BDU02HV9P0202<S8`0502LW9`0^;Rh092@T02l_;`16
ATH00P0U9BD06@0^;Rh0EeMG075aL@1KFe/0CTi>04I6AP13@d<0A4A404i>CP1IFET0EeMG06=SH`1[
Jf/0MWIf079bLP1gMgL0NWYj07]kN`22PX80OWin07alO022PX80Ogmo0820P022PX800`26QXH0102<
S8`0R8R808n?S`2>SXh2096AT@0708f=S@2>SXh0Shn?09>CT`2LW9`0Ti>C09VIV@0209JFUP0:09FE
U@2GUiL0VYZJ09fMW@2LW9`0WinO09bLW02OWil0W9bL09fMW@80WYjN00D0X:2P0::RXP2NWYh0WinO
09fMW@0209nOW`0F09fMW@2JVYX0TY:B09>CT`2>SXh0Rh^;08f=S@2:RXX0OGem07AdM01[Jf/0KFe]
07AdM01mOGd0Ph>308N7Q`2:RXX0SHf=08^;R`28R8P0Rh^;092@T080SHf=00<0Shn?08R8R026QXH0
0P20P80207emO@0E08>3P`24Q8@0RXZ:09BDU02NWYh0[Jf]0;Ng]`2j^[X0bl_;0=OGe`3Ti>@0j>SX
0>;RhP3Cdm<0`/;209:BTP2?Shl0U9BD09JFUP2BTY80U9BD00<0Ti>C00l0SXj>08b<S029RHT0QhN7
08>3P`20P800Ph>307alO01mOGd0MGEe079bLP1WIfL0C4a<034a<@0^;Rh00P0Y:BT06P0`<300<C4a
02d];@0g=cL0=3@d02l_;`0h>3P0@d=30492@P18B4P0CTi>04a<C011@D40CDe=04=3@`0e=CD0=SHf
02@T900S8b<08B4Q034a<@0_;bl0?Shn08B4Q02CTi<0[Jf]0P2OWil02@2FUYH0WIfM09FEU@2;Rh/0
GemO03<c<`0l?3`0=cLg02DU9@03028R8P0>02LW9`0_;bl0F5QH075aL@1nOWh0S8b<092@T02GUiL0
S8b<09BDU02=SHd0RHV909BDU02LW9`20:2PX00309ZJVP2NWYh0VIVI0080VYZJ00h0V9RH09VIV@2F
UYH0Vi^K09VIV@2HV9P0U9BD096AT@2IVIT0UYJF09>CT`2IVIT0Vi^K09JFUP80UIFE02P0U9BD09RH
V02IVIT0VYZJ09NGU`2EUID0UYJF09VIV@2HV9P0UIFE09BDU02JVYX0TY:B096AT@2EUID0Ti>C09JF
UP2CTi<0UIFE096AT@2DU9@0XZ:R096AT@2DU9@0TY:B08n?S`29RHT0RXZ:08j>SP25QHD0QXJ608:2
PP20P800QHF508B4Q02;Rh/0W9bL0:JVYP2`/;00^KVi0P31`L401035aLD0b<S80<C4a035aLD40<;2
`P040;no_`33`l<0`l?30<?3``80`L7100<0a<C40<O7a`38b<P00P3;bl/01P3=cLd0clo?0=3@d03@
d=00clo?0=3@d080clo?00D0cLg=0<k>cP3=cLd0c<c<0<_;b`040<c<c0030<k>cP3?cll0clo?0080
clo?00L0dM7A0=3@d03?cll0c/k>0<g=c@3>c/h0clo?00h0b>3H000<0<SPf080DU9B00@0CTi>04a<
C01=CDd0CTi>0`1?Cdl02P1=CDd0DE5A04U9B@1;Bd/0CTi>04E5A@19BDT0@D5103Xj>P0k>c/203Hf
=P0E03De=@0`<300:b/[02XZ:P0T92@0<S8b03`l?01DE5@0HF5Q07IfMP1jNWX0Ph>308n?S`2FUYH0
VIVI0:2PX02UYJD0Z:RX0:ZZZP2`/;00[Jf]0080[Zj^00D0/K6a0:^[Z`2`/;00[jn_0:j^[P020:n_
[`0K0;6a/@2c/k<0];Bd0;Bd]02`/;00[:b/0:NWY`2TY:@0WIfM09NGU`2@T900QHF507emO@1fMWH0
JFUY05aLG01>CTh0BDU904A4A012@T80BTY:05=CD`1FEUH0Fe]K06QXJ01nOWh0OGem0080Ogmo02D0
NWYj06a/K01ZJVX0KFe]06][J`1^KVh0Lg=c07AdM01bLW80KFe]05EEE@0f=SH0@d=304M7A`1EEED0
EUIF05QHF01FEUH0<S8b04M7A`1[Jf/0Ogmo07QhN01RHV80C4a<03lo?`1HF5P0G5aL04m?C`16ATH0
A4A40410@00o?cl0AdM707inOP2@T900FEUI0080<c<c00X0?Cdm04i>CP1aLG40OWin05IFEP0k>c/0
Hf=S08J6QP2:RXX0X:2P0P26QXH0;`1=CDd0>CTi03`l?025QHD0KFe]02/[:`0T92@09bLW02XZ:P0b
<S80;Bd]02/[:`0h>3P0C4a<04e=C@10@400:RXZ02LW9`0T92@07alO02@T900V9RH0=cLg03Ti>@0f
=SH0EeMG03Ph>00g=cL0LG5a079bLP12@T80D51@08F5Q@2YZJT0XZ:R09fMW@24Q8@0LG5a06QXJ01R
HV80IfMW06e]K@1XJ6P0Fe]K04=3@`0a<C409BDU00<092@T00T0<S8b02HV9P0R8R807QhN028R8P1<
C4`0N7Qh08>3P`1hN7P00P1jNWX0501WIfL0IFEU06a/K01/K6`0T92@0;Fe]@2][Jd0Xj>S08f=S@2@
T900VYZJ08N7Q`1JFUX0ADE502d];@0S8b<08R8R02/[:`0U9BD0:b/[0P0X:2P03@0R8R808b<S02<S
8`0^;Rh0FUYJ06e]K@1JFUX0@d=30410@01;Bd/0CTi>055AD@1CDe<00P1OGel00`1ZJVX0M7Ad075a
L@0207IfMP0F07emO@1oOgl0OGem07alO022PX80OGem0861P@23Ph<0QXJ608F5Q@27QhL0Rh^;08f=
S@2:RXX0Rh^;08n?S`2DU9@0Ti>C09BDU02?Shl0Ti>C09^KV`80UiNG00<0VYZJ09RHV02FUYH00P2J
VYX03P2FUYH0VIVI09bLW02JVYX0WinO09VIV@2RXZ80WinO09bLW02QXJ40WinO0::RXP2TY:@0Xj>S
0P2QXJ405P2KVi/0VIVI09RHV02IVIT0TY:B08b<S02;Rh/0Shn?07moO`1gMgL0LW9b06i^KP1cLg<0
O7al0820P027QhL0QXJ608^;R`28R8P0RXZ:08V9R@2;Rh/208n?S`80Q8B401H0PH6107alO01mOGd0
Ogmo08B4Q027QhL0SHf=08b<S02ATI40X:2P0:b/[02a/K40^k^k0<k>cP3MgMd0i^KV0>SXj03Ogml0
e=CD0<?3``2ATI40Ti>C0P2ATI408`2CTi<0UYJF09NGU`2HV9P0UYJF08n?S`2<S8`0R8R808B4Q026
QXH0PH6108J6QP1mOGd0OWin07IfMP1cLg<0Jf][05eMG@0m?Cd0<C4a02`/;00];Bd09bLW02XZ:P0b
<S80>CTi034a<@0[:b/0;bl_04A4A00o?cl0ATI604U9B@1;Bd/0ATI60080AdM700<0<C4a03De=@0R
8R800P0S8b<04@0_;bl0<30`04M7A`20P800VIVI0:^[Z`2JVYX0W9bL09JFUP2NWYh0TY:B08J6QP1M
GEd0:2PX03dm?@0Z:RX08B4Q00808R8R00T0;Bd]02/[:`0[:b/0DE5A06QXJ01gMgL0QhN709:BTP2F
UYH00P2CTi<0202=SHd0T92@08f=S@2LW9`0WIfM0:6QX@2NWYh0Vi^K0P2MWId03`2KVi/0VIVI09VI
V@2JVYX0V9RH09FEU@2FUYH0VYZJ09FEU@2HV9P0UiNG09FEU@2JVYX0UYJF09FEU@0209BDU00309NG
U`2IVIT0UYJF0080UIFE00@0UYJF09NGU`2HV9P0Vi^K0`2FUYH0702EUID0UYJF09FEU@2CTi<0V9RH
092@T02ATI40SXj>092@T02EUID0SXj>08n?S`2>SXh0SHf=08^;R`29RHT0RXZ:08b<S028R8P0Ph>3
0820P026QXH0PX:208N7Q`2GUiL0WYjN0:^[Z`2i^KT20<71`@040<G5a@38b<P0a/K60<G5a@80a<C4
0P33`l<01@32`/80`l?30<?3``31`L40`/;200<0aLG500L0a/K60<S8b03;bl/0c<c<0<k>cP3@d=00
clo?0080d=3@0140dM7A0<o?c`3?cll0cLg=0<k>cP3<c<`0bl_;0<g=c@3>c/h0d=3@0<o?c`3<c<`0
dM7A0<g=c@3>c/h0d=3@0=?Cd`030<o?c`030<k>cP3@d=00d=3@00h0b>3H000<0<SPf080D51@0P1?
Cdl02@1@D500CDe=04m?C`1CDe<0DU9B04e=C@1ADE40D51@059BDP0204Y:BP0J04e=C@10@400?Shn
0410@00h>3P0=cLg03<c<`0^;Rh0=CDe02TY:@0W9bL0;Rh^03hn?P1>CTh0HF5Q07QhN01oOgl0Q8B4
08j>SP2CTi<0W9bL0:2PX02TY:@0ZJVY0:ZZZP2][Jd30;2`/0130:f][@2_[jl0/;2`0:n_[`2`/;00
];Bd0;6a/@2b/[80][Jf0;:b/P2d];@0/K6a0:^[Z`2ZZZX0Y:BT09^KV`2BTY80T92@08^;R`1nOWh0
MWIf06i^KP1JFUX0Cdm?04Q8B015ADD0BDU904];B`1=CDd0DE5A05QHF01OGel0HF5Q06UYJ@1eMGD0
Ogmo08B4Q01hN7P0Jf][06QXJ01]KFd0LW9b07YjNP1kNg/0O7al07MgM`1WIfL0>CTi03Xj>P1<C4`0
EUIF06=SH`1LG5`0FUYJ03dm?@14A4@0IFEU07AdM01cLg<0IFEU05aLG010@400?Cdm05=CD`1XJ6P0
GEeM04e=C@0204=3@`0@03/k>`1TI6@0TY:B06m_K`0j>SX0;bl_038b<P11@D40IfMW07AdM01GEeL0
?Cdm06IVIP28R8P0TY:B0::RXP80LW9b01d0ATI603De=@16ATH0RXZ:05=CD`0W9bL0:2PX02HV9P0a
<C40@D5102h^;P0V9RH0;bl_02XZ:P19BDT0?Shn03`l?00`<300;2`/02DU9@0X:2P08b<S02XZ:P0/
;2`0>SXj069RHP0d=3@0;Rh^05=CD`0204m?C`0A061PH01iNGT0Z:RX08f=S@1gMgL0Hf=S055AD@18
B4P0@T9204M7A`1_Kfl0QhN707=cL`1?Cdl0>SXj02l_;`0X:2P00P0S8b<03@0`<300;bl_02/[:`0N
7Qh08b<S02PX:01ADE40IFEU06MWI`1nOWh0QHF506YZJP1^KVh00P1bLW804`2@T900^KVi0<W9b@33
`l<0YZJV08:2PP2GUiL0OGem03@d=00T92@08b<S01lO7`0N7Qh08b<S02TY:@0U9BD08R8R02XZ:P0U
9BD00P0Y:BT03`0Z:RX0G5aL06a/K01LG5`0@D5103Ph>017AdL0B4Q804m?C`1FEUH0GEeM06MWI`1X
J6P0K6a/07=cL`0207EeM@0B07UiN@1mOGd0Ogmo0820P024Q8@0PX:208>3P`22PX80QhN708F5Q@28
R8P0QXJ608N7Q`2<S8`0Rh^;08f=S@2@T900TI6A0P2CTi<0102EUID0VYZJ09^KV`2IVIT209RHV00?
09NGU`2IVIT0VYZJ09JFUP2JVYX0WIfM09jNWP2MWId0XZ:R0:>SX`2OWil0XZ:R0:JVYP2NWYh0XZ:R
0080Y:BT00@0Xj>S0:6QX@2MWId0W9bL0P2HV9P04P2FUYH0TI6A092@T02>SXh0QHF507alO01iNGT0
MGEe079bLP1fMWH0O7al08B4Q025QHD0Ph>308N7Q`26QXH0Q8B408>3P`80PX:200<0Ogmo08B4Q01i
NGT00P1kNg/03021PH40QXJ608J6QP2=SHd0SXj>09JFUP2TY:@0[:b/0;>c/`2g]kL0bl_;0=kNgP80
i^KV01<0h>3P0=CDe036a/H0UYJF09>CT`2>SXh0T92@096AT@2GUiL0UYJF09RHV02EUID0Ti>C08n?
S`2>SXh0R8R808J6QP25QHD0P8200080OWin00H0NGUi075aL@1cLg<0I6AT04Y:BP0a<C4202`/;00A
02PX:00^;Rh0;Bd]03De=@0g=cL0;Rh^030`<00k>c/0A4A404=3@`1?Cdl0De=C0492@P19BDT0@T92
03Ti>@0^;Rh00P0R8R804P0T92@0<c<c03/k>`1DE5@0QHF509jNWP2YZJT0Vi^K08n?S`2HV9P0X:2P
08b<S020P800GemO03Lg=`0e=CD0:BTY02LW9`808b<S00/0:2PX02<S8`0];Bd0BTY:05UIF@1dM7@0
QXJ609BDU02>SXh0SHf=092@T00208f=S@0M08j>SP2GUiL0Y:BT0:>SX`2QXJ40WinO09jNWP2OWil0
Vi^K09bLW02KVi/0VIVI09^KV`2HV9P0W9bL09VIV@2FUYH0UiNG09RHV02GUiL0V9RH09JFUP2CTi<0
U9BD096AT@2CTi<0UIFE09JFUP2GUiL00P2EUID04P2IVIT0VYZJ09BDU02GUiL0UYJF09:BTP2CTi<0
U9BD09FEU@2CTi<0UYJF096AT@2FUYH0Ti>C09:BTP2FUYH0Rh^;08n?S`<0SHf=00D0S8b<08R8R02=
SHd0SXj>08R8R00208F5Q@0908B4Q023Ph<0TY:B09^KV`2XZ:P0]KFe0;no_`30`<00a<C400<0a/K6
0P33`l<30<;2`P050<?3``31`L40a<C40<;2`P30`<000P31`L420<K6aP060<_;b`3<c<`0c<c<0<o?
c`3AdM40d];B103@d=020<o?c`050<g=c@3<c<`0b/[:0<c<c03>c/h00P3?cll01`3=cLd0c/k>0=3@
d03?cll0d=3@0<k>cP3=cLd0103@d=0>0<SPf0003038h=P205ADE080DE5A00<0D51@04Y:BP1:BTX0
0P1=CDd07@1:BTX0CTi>04Q8B01?Cdl0BDU904i>CP13@d<0@T9203hn?P0o?cl0?3`l03Ti>@0e=CD0
<30`03<c<`0^;Rh092@T034a<@15ADD0EeMG06EUI@1cLg<0OWin08J6QP2?Shl0UIFE09^KV`2QXJ40
Y:BT0080Z:RX0200/;2`0:VYZ@2_[jl0[jn_0;2`/02a/K40/;2`0:n_[`2^[Zh0[Jf]0:n_[`2a/K40
/[:b0;Fe]@2_[jl0[Zj^0:ZZZP2SXj<0X:2P09nOW`2IVIT0TY:B08b<S01oOgl0MWIf06IVIP1NGUh0
EEEE04e=C@1;Bd/0BDU904];B`80De=C00P0EEEE05aLG01LG5`0GEeM06MWI`1/K6`0O7al08:2PP80
Jf][0240MGEe08F5Q@24Q8@0SHf=0820P01jNWX0MGEe05QHF00o?cl0>SXj03hn?P18B4P0GemO05IF
EP1CDe<0CDe=05MGE`1TI6@0K6a/061PH01OGel0IVIV0492@P0i>CT0FEUI061PH01RHV80EEEE04Y:
BP10@400Bd];07YjNP25QHD00P16ATH02P1>CTh0?Shn05aLG01aLG40De=C04I6AP1XJ6P0R8R809>C
T`2SXj<206a/K00703lo?`0b<S80HV9R08:2PP0f=SH092@T02LW9`0302l_;`0:03@d=00[:b/0:b/[
02`/;00e=CD0<C4a02l_;`0i>CT0<c<c030`<080;bl_02h0:RXZ034a<@1CDe<0IfMW04Q8B00o?cl0
ADE504m?C`17AdL0DU9B06=SH`25QHD0PH6107IfMP1QHF40Hf=S05UIF@13@d<0<S8b04A4A01IFET0
GemO04M7A`0k>c/0<S8b02XZ:P0U9BD0<C4a02`/;00g=cL0;bl_01lO7`0K6a/08B4Q02h^;P1?Cdl0
Bd];06e]K@27QhL0MWIf079bLP20P800Ng]k07inOP2NWYh0bLW90P3:b/X03@2[Zj/0X:2P0:>SX`0l
?3`0:2PX028R8P0O7al09BDU02LW9`0[:b/09bLW02HV9P0/;2`00`0U9BD0500/;2`0FEUI06YZJP1M
GEd0?Cdm0492@P17AdL0CDe=059BDP1IFET0F5QH06EUI@1ZJVX0KFe]07EeM@1dM7@0MWIf07]kN`1n
OWh0OGem0P20P8004P21PH40QHF508F5Q@25QHD0S8b<08N7Q`22PX80QHF508Z:RP29RHT0SHf=09BD
U02BTY80UiNG09JFUP2CTi<0VIVI09JFUP80UiNG00P0V9RH09JFUP2DU9@0Vi^K09ZJVP2NWYh0WinO
0::RXP<0X:2P00h0XZ:R0:FUY@2UYJD0WYjN0:>SX`2UYJD0XZ:R09fMW@2OWil0WIfM09^KV`2HV9P0
TY:B09FEU@80SXj>00T0T92@08Z:RP23Ph<0O7al07MgM`1bLW80NGUi07emO@22PX800P26QXH0102;
Rh/0QhN708>3P`21PH4207inOP0707]kN`1lO7`0NWYj07alO01kNg/0OWin08B4Q00208N7Q`0H09>C
T`2HV9P0XZ:R0:VYZ@2a/K40/k>c0<k>cP3Ph>00i^KV0>GUi@3Ogml0dm?C0<71`@2ATI40V9RH09NG
U`2HV9P0UiNG09RHV02FUYH0VIVI09^KV`2BTY80S8b<0P28R8P01@26QXH0Q8B40820P021PH40Ogmo
0080OWin02/0KVi^06MWI`1ADE40=CDe02TY:@0W9bL0:BTY02/[:`0_;bl0;2`/03<c<`0/;2`0;Bd]
03Xj>P13@d<0@D5104A4A01BDU80@D5104=3@`15ADD0ATI602h^;P0X:2P08b<S028R8P0_;bl0ADE5
05UIF@27QhL0WIfM0:>SX`2LW9`0R8R809bLW02FUYH0T92@0861P@14A4@0;2`/02TY:@0_;bl0:b/[
00809bLW01D08b<S02@T900_;bl0ADE504i>CP1XJ6P0P82008j>SP2?Shl0T92@096AT@2:RXX0R8R8
08b<S02GUiL0Vi^K0::RXP2NWYh0X:2P09^KV`2NWYh00P2LW9`08P2JVYX0UYJF09JFUP2MWId0Vi^K
09NGU`2HV9P0UIFE09NGU`2HV9P0UYJF09RHV02DU9@0UYJF09VIV@2GUiL0Vi^K09NGU`2IVIT0V9RH
09FEU@2DU9@0UYJF096AT@2DU9@0Ti>C09:BTP2EUID0UYJF09BDU02ATI40UYJF09>CT`2ATI42092@
T00309:BTP2@T900SXj>0080TI6A01<0S8b<08j>SP2<S8`0RHV908F5Q@22PX80QhN708B4Q025QHD0
Ogmo08b<S02GUiL0XJ6Q0:b/[02e]KD0_[jn0<71`@36a/H0aLG500<0a<C40P33`l<01P32`/80`l?3
0;no_`30`<00a<C40<?3``80`/;200H0a<C40<O7a`38b<P0b/[:0<c<c03>c/h20=7Ad@0@0=;BdP3A
dM40dM7A0=7Ad@3@d=00clo?0<k>cP3<c<`0c/k>0<c<c03>c/h0cLg=0<o?c`3@d=00clo?0<k>cP<0
clo?00D0d=3@0<o?c`3@d=00d=3@0<k>cP0>0<SPf0003038h=P204m?C`04051@D01>CTh0E5AD04i>
CP80CDe=00d0C4a<04i>CP16ATH0BDU904Y:BP17AdL0Bd];04=3@`14A4@0ADE50451@@0g=cL0<c<c
0080=3@d01<0<c<c02XZ:P0[:b/0;Rh^04A4A01@D500IfMW07MgM`20P800Q8B4096AT@2GUiL0Vi^K
0:6QX@2RXZ80Xj>S0:^[Z`2YZJT0[Jf]00@0/;2`00@0[jn_0;6a/@2a/K40/;2`0P2a/K40502b/[80
[jn_0:j^[P2_[jl0ZJVY0:FUY@2RXZ80WIfM09NGU`2DU9@0QhN707inOP1bLW80IFEU05IFEP1ADE40
BDU904];B`1@D500CDe=0P1@D500=`1CDe<0FUYJ05]KF`1MGEd0GemO06ATI01[Jf/0MWIf07alO01k
Ng/0QhN708Z:RP29RHT0R8R808>3P`28R8P0Ng]k05QHF017AdL0=3@d03Ph>018B4P0KVi^06QXJ01W
IfL0GEeM04U9B@1QHF40J6QX05iNGP1HF5P0JFUY05iNGP0j>SX0>3Ph04m?C`1/K6`0Hf=S05=CD`19
BDT0ATI607IfMP2=SHd0E5AD05eMG@1OGel0A4A405iNGP1lO7`0G5aL04m?C`1`L700PH6109JFUP2J
VYX00P1ZJVX05@0j>SX0=CDe07IfMP1^KVh09BDU02@T900V9RH0:RXZ030`<00];Bd0;Rh^030`<00j
>SX0<c<c034a<@0[:b/0<C4a02h^;P0];Bd0:RXZ03Ti>@02038b<P0X03<c<`1UIFD0GUiN06MWI`1<
C4`0Bd];05]KF`1:BTX0AdM705]KF`1jNWX0Xj>S08^;R`1`L700MGEe06i^KP1JFUX0@T9203/k>`0m
?Cd0FUYJ04m?C`12@T80A4A402h^;P0Z:RX092@T02TY:@0j>SX0<S8b024Q8@0S8b<0<30`024Q8@0/
;2`0:2PX05aLG029RHT0RXZ:07EeM@80N7Qh00X0NGUi09:BTP2o_kl0c<c<0<k>cP3:b/X0_kno0<G5
a@1oOgl0;bl_0P0R8R801@0W9bL0:b/[02TY:@0R8R80:2PX00809bLW0P0X:2P03`0`<300EUIF06AT
I01JFUX0@D5103Lg=`18B4P0ADE505=CD`1GEeL0G5aL061PH01VIVH0LG5a07EeM@0207MgM`0507em
O@20P800P8200820P027QhL00`24Q8@208J6QP0508Z:RP27QhL0S8b<08n?S`26QXH00P2@T900302B
TY80UYJF09VIV@2CTi<0UiNG09FEU@2HV9P0U9BD09JFUP2JVYX0WIfM09^KV`80W9bL00H0V9RH09jN
WP2SXj<0XZ:R0:2PX02UYJD20:BTY0090:2PX02TY:@0Y:BT0:>SX`2TY:@0XJ6Q09jNWP2KVi/0WIfM
0080U9BD0140TY:B08n?S`2>SXh0R8R808F5Q@1mOGd0O7al07YjNP1kNg/0O7al07]kN`22PX80Ph>3
08b<S025QHD0OGem07moO`0207]kN`0Q07emO@1nOWh0NGUi07EeM@1jNWX0OWin08>3P`25QHD0QhN7
09:BTP2IVIT0WinO0:NWY`2a/K40^;Rh0=7Ad@3Ph>00i^KV0>GUi@3Ng]h0d];B0;bl_02EUID0W9bL
09fMW@2LW9`0VYZJ09RHV02EUID0UiNG09RHV02DU9@0SXj>00<0RXZ:02h0R8R808B4Q020P800PH61
08:2PP1mOGd0KFe]06ATI01FEUH0ATI6030`<00W9bL0:b/[02TY:@0`<300;Bd]03De=@0b<S80@T92
04E5A@12@T80BDU904E5A@17AdL0B4Q804I6AP1;Bd/0=SHf03Lg=`0S8b<08B4Q020P800b<S80ATI6
05aLG02<S8`0Y:BT0:FUY@2KVi/0Q8B40:2PX02ATI40RHV9079bLP0e=CD0=cLg0P0];Bd0900^;Rh0
:2PX02PX:00V9RH0;Bd]02`/;01<C4`0A4A406=SH`1lO7`0RHV908j>SP2?Shl0S8b<08V9R@2:RXX0
R8R809>CT`2NWYh0X:2P0::RXP2NWYh0XJ6Q09VIV@2NWYh0W9bL09jNWP2HV9P0Vi^K09VIV@2EUID0
Vi^K09RHV02GUiL0V9RH09NGU`80V9RH00L0U9BD09NGU`2LW9`0W9bL0:2PX02EUID0YJFU0080UiNG
00D0Ti>C09BDU02ATI40U9BD09FEU@0209>CT`80U9BD00d0UIFE09NGU`2BTY80T92@09FEU@2CTi<0
TY:B08j>SP2?Shl0T92@08j>SP2=SHd0RHV90080RXZ:0100SHf=08Z:RP27QhL0QhN708:2PP20P800
QXJ608f=S@2NWYh0Zj^[0;>c/`2k^k/0`/;20<?3``37alL0aLG51034a<@00`32`/80`<300<;2`P02
0;no_`80`l?30P31`L420<C4a0070<[:bP3;bl/0cLg=0<k>cP3AdM40d=3@0=7Ad@020=;BdP090=7A
d@3@d=00cLg=0<g=c@3?cll0d=3@0<g=c@3?cll0c/k>00<0clo?00D0d=3@0<o?c`3?cll0d=3@0<c<
c0020<k>cP030<g=c@38h=P0b>3H00`0b>3H000<0<SPf080DE5A00P0EUIF051@D01GEeL0CTi>04];
B`16ATH0Cdm?04];B`80ADE500@0Bd];04M7A`1<C4`0BDU90`13@d<05`0e=CD0=cLg038b<P0b<S80
;bl_030`<00_;bl0<30`03`l?01CDe<0J6QX07MgM`1mOGd0QXJ6096AT@2GUiL0Vi^K09nOW`2UYJD0
YjNW0:b/[02ZZZX0[Jf]00<0[jn_01T0ZZZZ0;:b/P2b/[80[jn_0;2`/02^[Zh0/K6a0:n_[`2b/[80
/K6a0:n_[`2YZJT0Y:BT09nOW`2MWId0UYJF092@T02:RXX0OWin079bLP1XJ6P0EeMG051@D01:BTX0
Bd];0080ATI602L0Cdm?04e=C@1JFUX0G5aL06QXJ01_Kfl0LG5a07QhN01nOWh0MWIf07MgM`1jNWX0
M7Ad071`L01bLW80OGem08B4Q022PX80OWin06EUI@18B4P0=3@d03De=@0d=3@0Hf=S07IfMP1^KVh0
JFUY04m?C`1<C4`0Hf=S05ADE01GEeL0E5AD05iNGP1;Bd/0<c<c03Ti>@1FEUH00P1IFET0401HF5P0
CDe=05eMG@25QHD0N7Qh06ATI01DE5@0?Cdm05]KF`1iNGT0HF5Q05UIF@1`L700Ng]k09fMW@2JVYX2
05mOG`0f03Xj>P14A4@0Ng]k05=CD`0Q8B40:RXZ02PX:00Z:RX0;Rh^02PX:00b<S80<30`03Ti>@0_
;bl0:b/[02h^;P0X:2P0;2`/02<S8`0R8R80:BTY03Hf=P0_;bl0=CDe05YJFP19BDT0ATI6051@D01H
F5P0GemO05=CD`0l?3`0BTY:06YZJP2NWYh0Ogmo071`L01_Kfl0LW9b05IFEP11@D40DU9B08:2PP2S
Xj<0XJ6Q096AT@1]KFd0=CDe02<S8`0U9BD0<S8b03Ph>00_;bl0;2`/0P0O7al06@0R8R807QhN028R
8P14A4@0PX:209ZJVP1kNg/0LG5a07IfMP1cLg<0Ogmo0:RXZ03@d=00clo?0=3@d03<c<`0d=3@0;Vi
^@19BDT09RHV02<S8`0Z:RX09RHV02PX:00/;2`00P0T92@05P0U9BD08R8R028R8P0X:2P0De=C061P
H01DE5@0?3`l0451@@1:BTX0Bd];05ADE01MGEd0HF5Q06MWI`1ZJVX0LG5a07EeM@1gMgL0NGUi07Mg
M`1oOgl20820P00<08F5Q@21PH40PH6108N7Q`23Ph<0QXJ608N7Q`2;Rh/0S8b<09RHV02:RXX0TY:B
0P2@T9002P2FUYH0V9RH09:BTP2IVIT0V9RH09VIV@2HV9P0VYZJ09^KV`2NWYh209^KV`0609nOW`2J
VYX0WYjN0:2PX02OWil0Xj>S0P2WYjL05`2TY:@0Xj>S0:2PX02NWYh0X:2P0:6QX@2SXj<0WinO09jN
WP2MWId0VIVI09FEU@2ATI40TY:B08V9R@28R8P0QhN708:2PP1nOWh0PH6107moO`1nOWh0O7al0080
Ph>300@0QhN708>3P`1nOWh0O7al0P1kNg/207moO`0b07UiN@1eMGD0MWIf0861P@20P800RHV908Z:
RP2EUID0WYjN0:>SX`2][Jd0/K6a0<71`@3De=@0gmoO0>KViP3Shn<0gMgM0=7Ad@2k^k/0Ti>C09bL
W02NWYh0VYZJ09VIV@2HV9P0VYZJ09FEU@2HV9P0VYZJ08Z:RP2;Rh/0RHV908j>SP22PX80QXJ60861
P@22PX80Ogmo07YjNP1fMWH0I6AT05iNGP1;Bd/0>CTi02/[:`0X:2P0:b/[02d];@0[:b/303@d=00N
03dm?@19BDT0?clo03hn?P1:BTX0BDU904a<C01ADE40<c<c02LW9`0R8R808B4Q028R8P0a<C40C4a<
06i^KP2GUiL0YjNW0:ZZZP2HV9P0PH610:FUY@2>SXh0R8R806e]K@0/;2`09RHV02<S8`0_;bl0<30`
0P0W9bL0800Z:RX0:2PX02h^;P0k>c/0?3`l05mOG`1aLG40Rh^;08b<S02;Rh/0Shn?08b<S029RHT0
RXZ:09>CT`2NWYh0WIfM0:6QX@2NWYh0WinO09^KV`2MWId0WinO09^KV`2JVYX0W9bL09VIV@2DU9@0
VIVI09bLW02HV9P0U9BD0P2IVIT01`2JVYX0V9RH09VIV@2HV9P0VIVI09^KV`2EUID00P2GUiL309JF
UP0309BDU02FUYH0UIFE0080UIFE00<0UiNG09JFUP2CTi<00P2@T90208n?S`0708j>SP2=SHd0TY:B
096AT@2DU9@0T92@08n?S`0208Z:RP0A08n?S`2=SHd0QXJ608V9R@23Ph<0Q8B408F5Q@23Ph<0S8b<
09BDU02VYZH0/;2`0;Ng]`2k^k/0_[jn0<?3``35aLD00P34a<@01033`l<0a<C40<30`033`l<20<30
`00<0;no_`32`/80`l?30<;2`P31`L40`/;20<C4a037alL0aLG50<_;b`3:b/X0cLg=1@3AdM420<k>
cP80d=3@00H0clo?0<g=c@3>c/h0d=3@0<o?c`3@d=020<o?c`050<g=c@3?cll0cLg=0<g=c@3@d=00
0P3>c/h>0<SPf0003038h=P2051@D007055AD@1>CTh0Cdm?055AD@1:BTX0BDU904];B`0204a<C00O
04Y:BP16ATH0AdM704M7A`13@d<0A4A403lo?`11@D40?Shn03Hf=P0g=cL0=SHf034a<@0/;2`0:BTY
03<c<`11@D40FUYJ06EUI@1iNGT0PX:208>3P`2<S8`0U9BD09bLW02QXJ40Y:BT0:VYZ@2^[Zh0[:b/
0:j^[P020:b/[0040:f][@2`/;00[Zj^0:^[Z`80[Zj^00@0[jn_0;6a/@2a/K40/k>c0P2^[Zh00`2Y
ZJT0YJFU0::RXP0209NGU`0:08n?S`2<S8`0P820079bLP1VIVH0FEUI051@D019BDT0Bd];059BDP80
BDU900`0DE5A05QHF01MGEd0KVi^08F5Q@2@T900RXZ:08>3P`1eMGD0KVi^06EUI@1YJFT206][J`0Z
079bLP1lO7`0M7Ad07EeM@1TI6@0AdM703Lg=`13@d<0?Cdm06i^KP24Q8@0K6a/075aL@1ADE40@D51
06UYJ@1QHF40FUYJ04Y:BP1;Bd/0HF5Q05IFEP0e=CD0?clo04Q8B01PH600HV9R05]KF`1ADE40LG5a
07moO`1XJ6P0Bd];03Xj>P1SHf<0QHF506i^KP1VIVH0K6a/07UiN@2QXJ40UIFE0P1LG5`02014A4@0
GEeM08V9R@19BDT09RHV02d];@0Y:BT0:RXZ0P0i>CT08011@D40=cLg03/k>`0_;bl0;Bd]02HV9P0Y
:BT0;2`/02XZ:P0U9BD0:2PX030`<00h>3P0;bl_04A4A00k>c/0@41005ADE01[Jf/0JVYZ04m?C`0i
>CT0>c/k04e=C@1aLG40IFEU06i^KP1eMGD0NWYj06MWI`1?Cdl0Rh^;0P2m_Kd0:02h^;P0WYjN07Ui
N@0l?3`08b<S02h^;P0m?Cd0CTi>03De=@0S8b<0820P01/K6`0N7Qh071`L01lO7`0_;bl0Jf][08n?
S`26QXH0Lg=c071`L01dM7@0MWIf092@T02o_kl0cLg=0<_;b`3>c/h0c<c<0<k>cP2SXj<0>3Ph02DU
9@0T92@09RHV02TY:@0U9BD09RHV02LW9`0R8R8202@T900=02DU9@1=CDd0IVIV04i>CP0j>SX0@T92
04M7A`15ADD0Bd];05MGE`1QHF40IfMW06a/K002075aL@0507UiN@1nOWh0P82007YjNP1nOWh00P20
P8001023Ph<0PX:208N7Q`28R8P208V9R@0D08Z:RP2>SXh0SXj>08n?S`2DU9@0Ti>C092@T02ATI40
V9RH09^KV`2GUiL0UYJF09VIV@2JVYX0WYjN0::RXP2NWYh0WIfM09bLW02PX:0309nOW`0@0::RXP2V
YZH0Z:RX0::RXP2VYZH0Y:BT0:FUY@2RXZ80X:2P0:BTY02UYJD0XZ:R0:JVYP2OWil0WYjN09ZJVP80
Ti>C00@0S8b<08j>SP25QHD0QHF50P24Q8@02@20P800PH610861P@24Q8@0OGem08B4Q022PX80O7al
07moO`0207alO01807]kN`1iNGT0Ng]k07UiN@1lO7`0OGem08:2PP26QXH0S8b<09:BTP2MWId0X:2P
0:^[Z`2d];@0a<C40=CDe03Ph>00iNGU0>;RhP3Kfm/0d];B0:n_[`2DU9@0XJ6Q0:2PX02FUYH0VYZJ
09VIV@2GUiL0UIFE09:BTP2FUYH0Shn?08f=S@2:RXX0R8R808F5Q@28R8P0Ph>308:2PP1nOWh0NGUi
07AdM01[Jf/0Hf=S05EEE@13@d<0;Rh^02`/;00Z:RX0<30`03Lg=`0d=3@0<S8b02h^;P0o?cl0@D51
03lo?`0m?Cd0CTi>04A4A01BDU80E5AD02d];@0W9bL08R8R01lO7`0V9RH0=3@d04a<C01aLG40VIVI
0P2WYjL02@2JVYX0P8200:JVYP2BTY80PH6105iNGP0[:b/08R8R02@T900203Lg=`80;2`/01/0:BTY
03@d=00^;Rh0=CDe03Ti>@1HF5P0LW9b0861P@2;Rh/0S8b<08f=S@2;Rh/0QXJ608b<S02=SHd0UiNG
09^KV`2SXj<0XJ6Q0:2PX02NWYh0WinO0:2PX02JVYX0WinO09ZJVP2HV9P00P2CTi<0302LW9`0UiNG
09VIV@2JVYX0V9RH09^KV`2GUiL0U9BD09ZJVP2EUID0UiNG09BDU080UiNG00d0Vi^K09NGU`2HV9P0
UiNG09>CT`2BTY80U9BD09FEU@2FUYH0UiNG08f=S@2BTY80Shn?0080Ti>C00D0T92@08^;R`2DU9@0
T92@096AT@0208^;R`80RXZ:00l0T92@08b<S028R8P0QhN708Z:RP29RHT0PX:208J6QP25QHD0SHf=
09^KV`2XZ:P0/[:b0;Rh^02j^[X00P33`l<20<K6aP040<C4a032`/80`l?30<71`@80`/;200@0`<30
0<;2`P32`/80`l?30P31`L430<?3``040<K6aP3:b/X0c<c<0<o?c`<0dM7A0`3?cll20=3@d0050=7A
d@3>c/h0clo?0=;BdP3@d=000P3?cll0103=cLd0dM7A0<g=c@3<c<`20<g=c@030<k>cP3?cll0b>3H
00d0b>3H000<0<SPf0<0Cdm?0P1<C4`01`1?Cdl0Bd];04U9B@19BDT0DE5A04U9B@17AdL00P1:BTX0
6017AdL0ADE504M7A`11@D40?Cdm03lo?`0k>c/0>SXj03Ph>00b<S80;2`/02h^;P0e=CD0@41005EE
E@1WIfL0OGem0861P@2:RXX0TY:B09NGU`2MWId0XJ6Q0::RXP<0ZJVY00<0ZZZZ0;:b/P2b/[800`2]
[Jd00`2[Zj/0[Jf]0:RXZ0020;2`/00D0:n_[`2b/[80[Jf]0:b/[02[Zj/0Y:BT0:2PX02NWYh0U9BD
08b<S029RHT0OWin07EeM@1RHV80FEUI059BDP17AdL0ADE504M7A`1:BTX204a<C00505eMG@1/K6`0
Ti>C09bLW02@T9000P26QXH0:P2;Rh/0MgMg06i^KP1cLg<0KVi^07alO025QHD0Ogmo07YjNP1dM7@0
EeMG03`l?00j>SX0AdM704m?C`1jNWX0UIFE07MgM`1aLG40JFUY04=3@`1>CTh0Jf][05]KF`1ADE40
IfMW06ATI01lO7`0@D51038b<P0f=SH0E5AD06][J`1LG5`0Bd];04e=C@1iNGT0PX:204a<C00j>SX0
EeMG08N7Q`80MGEe00@0Hf=S07IfMP2FUYH0QXJ60P1HF5P0101KFe/0RXZ:092@T01:BTX203Ph>00;
02TY:@0^;Rh0>SXj03Ph>00e=CD0=cLg03Ti>@0`<300:2PX02DU9@0S8b<00P0Y:BT09P0U9BD0:2PX
03dm?@18B4P0=3@d03Ph>00n?Sh0GEeM079bLP21PH40Kfm_04m?C`0n?Sh0>3Ph03Xj>P11@D40ATI6
06IVIP1fMWH0Ng]k07QhN01fMWH0];Bd0;fm_@2i^KT0][Jf09VIV@1XJ6P0;2`/02HV9P0b<S80C4a<
07=cL`1=CDd09RHV020P800Q8B407QhN0P0M7Ad03P0U9BD0D51@08>3P`2EUID0NGUi06m_K`1iNGT0
MWIf07QhN02UYJD0alO70<S8b03>c/h0clo?0P3>c/h02@29RHT0<C4a02DU9@0V9RH09BDU02LW9`0Q
8B408b<S02TY:@0202LW9`0K02TY:@19BDT0G5aL04Q8B00e=CD0?3`l04E5A@19BDT0CDe=05YJFP1R
HV80IVIV06a/K01bLW80M7Ad07EeM@22PX80Ph>307emO@1kNg/0P82008>3P`26QXH0OWin08B4Q027
QhL0RHV90080RXZ:00H0QXJ608V9R@2@T900VYZJ09:BTP2@T90209JFUP0309^KV`2IVIT0UiNG00<0
XJ6Q01<0Xj>S0:2PX02NWYh0WinO0:2PX02RXZ80Xj>S0::RXP2UYJD0Z:RX0:FUY@2SXj<0Z:RX0:VY
Z@2XZ:P0Y:BT0:FUY@2XZ:P0XZ:R0080YZJV00T0WinO0:2PX02KVi/0UYJF096AT@2@T900RHV908Z:
RP28R8P00`23Ph<00`22PX80Q8B408B4Q0020861P@0307]kN`1lO7`0OGem0080NGUi0P1hN7P0701j
NWX0Ng]k07alO01mOGd0PH6108V9R@2<S8`0UIFE09nOW`2RXZ80[Zj^0;Vi^@32`/80dm?C0>3Ph03V
i^H0hn?S0=cLg03>c/h0Z:RX09VIV@2QXJ40X:2P09VIV@2KVi/0UYJF09ZJVP2EUID209:BTP0@09>C
T`2;Rh/0Rh^;08b<S028R8P0PX:208B4Q021PH40Ph>307emO@1fMWH0K6a/06MWI`1GEeL0A4A4034a
<@80:2PX02<0:b/[02`/;00i>CT0<30`02`/;00k>c/0@d=304A4A011@D40CDe=04Q8B016ATH0FUYJ
03@d=00U9BD092@T028R8P0S8b<0=CDe04Q8B01kNg/0VYZJ0:BTY02WYjL0UYJF08F5Q@2WYjL0RHV9
08N7Q`1GEeL0:b/[01dM7@0U9BD0;Bd]03/k>`0202/[:`0:02TY:@0^;Rh0<30`02XZ:P0`<300DE5A
06ATI01oOgl0SHf=092@T080Rh^;00<0RHV908R8R02>SXh00P2JVYX02P2QXJ40WinO09jNWP2NWYh0
WIfM09nOW`2MWId0X:2P09bLW02FUYH209>CT`0309VIV@2KVi/0Vi^K0080W9bL0180VIVI09^KV`2K
Vi/0VIVI09bLW02HV9P0UiNG09^KV`2JVYX0V9RH09NGU`2DU9@0Ti>C09BDU02@T900U9BD09:BTP2E
UID209BDU00309>CT`2BTY80TY:B0080TY:B00@0T92@09>CT`2;Rh/0SXj>0P2<S8`00`29RHT0Rh^;
08f=S@0208j>SP0>08^;R`25QHD0QXJ608J6QP23Ph<0Q8B408J6QP2DU9@0WinO0:j^[P2g]kL0^[Zj
0<71`@32`/830<C4a080`/;200@0`<300<;2`P30`<00`<300`32`/800`31`L40`/;20<;2`P020<?3
``040<K6aP38b<P0c<c<0<g=c@<0d=3@00<0c/k>0<o?c`3@d=001`3@d=002P3AdM40c<c<0<k>cP3;
bl/0cLg=0<k>cP3<c<`0b/[:0<c<c03@d=0>0<SPf0003038h=P204];B`0505=CD`1>CTh0Bd];04i>
CP1:BTX00P1@D5008@1EEED0B4Q8059BDP1>CTh0BTY:04Q8B012@T80@d=303lo?`13@d<0?Shn0492
@P0l?3`0=CDe03Lg=`0f=SH0<c<c03`l?016ATH0DU9B06EUI@1hN7P0OWin08Z:RP2FUYH0U9BD09RH
V02PX:00XZ:R0:JVYP2/[:`0ZZZZ0:n_[`020;2`/0090:j^[P2][Jd0ZZZZ0:f][@2[Zj/0[Jf]0:n_
[`2`/;00/[:b0080/K6a04X0Zj^[0:NWY`2RXZ80X:2P09NGU`2EUID0T92@08Z:RP20P800Lg=c06EU
I@1GEeL0D51@04I6AP1<C4`0D51@04U9B@1;Bd/0EUIF06EUI@1oOgl0Vi^K08Z:RP1_Kfl0K6a/08V9
R@2QXJ40WIfM08F5Q@1fMWH0JVYZ071`L023Ph<0Rh^;08B4Q01`L700De=C03Hf=P0c<c<0?clo04Q8
B01/K6`0S8b<07alO01mOGd0OWin05eMG@0l?3`0Hf=S07QhN01CDe<0@d=303`l?010@400@d=303@d
=00e=CD0@T9205]KF`1YJFT0HV9R04Q8B01VIVH0SXj>05ADE00k>c/0CTi>08V9R@23Ph<0MGEe06IV
IP1eMGD0Shn?07QhN080ATI60180FEUI09^KV`1iNGT0?Cdm03`l?00n?Sh0<S8b03Ti>@0n?Sh0>3Ph
03<c<`0k>c/0=cLg030`<00Y:BT08R8R02LW9`0Z:RX202DU9@0F02@T900Y:BT0=SHf02`/;00j>SX0
@d=306m_K`22PX80Ng]k06IVIP1FEUH0@d=303/k>`0c<c<0<30`04i>CP1GEeL0IVIV07]kN`23Ph<0
SHf=0;bl_080]kNg00`0]KFe09BDU01NGUh0:BTY03<c<`0m?Cd0G5aL08F5Q@1fMWH0ATI602@T900N
7Qh201/K6`0=01`L700S8b<0=cLg071`L02PX:00Rh^;06e]K@1nOWh0MWIf07EeM@2ATI40_[jn0<?3
``020<[:bP0;0<c<c03?cll0`l?306ATI00X:2P08B4Q02<S8`0U9BD09RHV024Q8@0O7al00P0W9bL0
4@0^;Rh0Bd];05EEE@14A4@0=CDe03Xj>P14A4@0BTY:055AD@1FEUH0J6QX06UYJ@1[Jf/0L71`06m_
K`1kNg/0OWin0080OGem00L0PH6108>3P`21PH40QHF50861P@1oOgl0RHV90080Rh^;0140QhN708R8
R02=SHd0TY:B09RHV02ATI40UYJF09NGU`2IVIT0VYZJ09JFUP2KVi/0XJ6Q09fMW@2SXj<0XZ:R09ZJ
VP0209jNWP0>0::RXP2TY:@0Zj^[0:ZZZP2[Zj/0ZZZZ0:RXZ02WYjL0ZJVY0:RXZ02ZZZX0YZJV0:RX
Z02VYZH20:2PX00E0:FUY@2QXJ40WYjN09^KV`2EUID0V9RH096AT@2<S8`0Rh^;08Z:RP26QXH0QHF5
0820P023Ph<0QXJ608N7Q`25QHD0PX:207emO@1nOWh0P8200080O7al01d0N7Qh07YjNP1kNg/0O7al
07]kN`1mOGd0P82008R8R02=SHd0UYJF0:2PX02XZ:P0/k>c0;no_`35aLD0dm?C0>3Ph03Shn<0hN7Q
0=WIf@3:b/X0WinO09RHV02MWId0WinO09ZJVP2KVi/0V9RH09VIV@0209FEU@80TY:B00D0Shn?08f=
S@2;Rh/0Q8B408J6QP0208>3P`0<0861P@1nOWh0NWYj06m_K`1VIVH0FUYJ04I6AP0j>SX0;2`/02PX
:00[:b/0;Bd]0P0a<C404P0];Bd0=cLg04=3@`0n?Sh0A4A404i>CP13@d<0CTi>05QHF00_;bl0:BTY
024Q8@0O7al08R8R03<c<`19BDT0PX:209bLW080YZJV00/0TI6A08b<S02WYjL0RHV907moO`1DE5@0
:BTY020P800N7Qh0:RXZ03Ph>002030`<00=02PX:00/;2`0;2`/02`/;00b<S80BDU906EUI@1hN7P0
SHf=08b<S02=SHd0RHV908^;R`0208R8R00<09VIV@2MWId0WYjN0:2PX02NWYh0X:2P09nOW`2PX:00
WIfM09bLW02JVYX0VIVI0P2HV9P01@2IVIT0VYZJ09ZJVP2IVIT0WIfM0080VYZJ00/0W9bL09JFUP2I
VIT0UiNG09JFUP2HV9P0Ti>C09RHV02DU9@0UIFE09>CT`0209BDU00<09>CT`2ATI40TY:B08n?S`2E
UID0U9BD09>CT`2BTY80T92@096AT@2@T900Ti>C0`2BTY80202=SHd0RXZ:08b<S02<S8`0SXj>08b<
S02;Rh/0QHF50P28R8P02@23Ph<0Ogmo08F5Q@2>SXh0WIfM0:NWY`2a/K40_;bl0;jn_P030<;2`P0>
0<C4a035aLD0`/;20<30`032`/80`L710;no_`30`<00`/;20<71`@32`/80`L710<;2`P31`L420<C4
a0030<O7a`39bLT0bl_;0080cLg=00H0clo?0<k>cP3>c/h0d=3@0=7Ad@3Bd]840=7Ad@060=;BdP3=
cLd0c/k>0<g=c@3<c<`0b/[:0P3;bl/00`3:b/X0c<c<0<k>cP0>0<SPf0003038h=P205=CD`0304a<
C01@D500CDe=0080CTi>02<0C4a<04m?C`1@D500Cdm?04a<C01=CDd0D51@04a<C015ADD0@D5103hn
?P15ADD0?Shn03Xj>P0h>3P0<c<c02l_;`0`<300;2`/03Xj>P1=CDd0EUIF06EUI@1hN7P0PX:208Z:
RP2=SHd0Ti>C09^KV`2NWYh0Y:BT0:RXZ02[Zj/0[:b/0:f][@020:n_[`@0[:b/00X0Zj^[0:b/[02_
[jl0/;2`0;:b/P2][Jd0/K6a0:b/[02WYjL0YJFU0P2MWId02@2BTY80SXj>08^;R`21PH40MgMg06=S
H`1HF5P0CTi>04Y:BP0204U9B@0;04Q8B01=CDd0EUIF07=cL`2DU9@0SXj>06m_K`1LG5`0IFEU07Qh
N02ATI400P2TY:@0;@2HV9P0PH6106m_K`1aLG40O7al08N7Q`20P800F5QH034a<@0Z:RX0=cLg03Hf
=P0m?Cd0H61P07inOP20P800Rh^;08>3P`1CDe<0DU9B07YjNP1iNGT0B4Q803`l?00o?cl0>3Ph03hn
?P0i>CT0<C4a03Lg=`1SHf<0L71`05eMG@1>CTh0TY:B06YZJP11@D40C4a<07QhN02?Shl0NGUi06AT
I01cLg<0SHf=079bLP020451@@0C06i^KP2GUiL0HV9R03Ph>00l?3`0@d=303lo?`0m?Cd0C4a<03De
=@0c<c<0>SXj03`l?00/;2`0:2PX02DU9@0W9bL09RHV020P8002024Q8@0/01lO7`0/;2`0=SHf04A4
A019BDT0H61P06a/K01VIVH0EUIF05ADE01<C4`0BDU9030`<00];Bd0De=C05mOG`1;Bd/0Hf=S0861
P@2BTY80Zj^[0;Jf]P2d];@0[jn_08R8R01?Cdl0:BTY03@d=01ADE40IVIV08R8R01gMgL0F5QH02@T
900L71`07AdM01/K6`0J6QX07QhN02HV9P1IFET0TY:B09jNWP1aLG4206m_K`0<075aL@25QHD0Z:RX
0<G5a@39bLT0c<c<0<_;b`3<c<`0c/k>0;Fe]@16ATH09bLW0P0Q8B400`0S8b<0:RXZ02DU9@0202<S
8`0802TY:@17AdL0EUIF03lo?`0j>SX0>3Ph03`l?015ADD205EEE@0606UYJ@1VIVH0K6a/071`L01f
MWH0MgMg0P1mOGd01@25QHD0PH6108:2PP24Q8@0P8200080PX:200D0Q8B408N7Q`29RHT0SHf=08^;
R`02092@T00L09>CT`2EUID0WIfM09NGU`2LW9`0WIfM09RHV02PX:00WIfM0:6QX@2TY:@0XZ:R0:6Q
X@2RXZ80X:2P0:ZZZP2WYjL0ZZZZ0:JVYP2SXj<0Zj^[0:b/[02XZ:P0ZZZZ0:^[Z`2YZJT0YjNW0:VY
Z@80YJFU00d0XJ6Q0:FUY@2QXJ40VIVI09^KV`2HV9P0UiNG09:BTP2>SXh0RHV908J6QP28R8P0Q8B4
00<0Ph>300H0QhN708>3P`21PH40PH6107emO@22PX8207inOP1007]kN`1hN7P0NWYj07inOP1kNg/0
OWin08:2PP2:RXX0TI6A09RHV02RXZ80Zj^[0;Ng]`30`<00bl_;0=?Cd`3Lg=`0hn?S0=gMg@3Hf=P0
a<C409fMW@2KVi/0X:2P0:6QX@2KVi/0VYZJ09VIV@2EUID0UYJF09FEU@2ATI40Shn?08b<S02BTY80
R8R808B4Q023Ph<0P82008J6QP21PH40P82007inOP1eMGD0IfMW05iNGP1:BTX0BDU903@d=00Y:BT0
=CDe02`/;00c<c<0=CDe03<c<`0g=cL0Bd];0410@014A4@0Cdm?04M7A`1FEUH0GUiN02d];@80:2PX
01<09bLW02PX:00e=CD0EEEE08R8R02PX:00ZJVY0::RXP20P800Ti>C09nOW`27QhL0Q8B405ADE00Y
:BT07AdM02<S8`0X:2P0>SXj0080>CTi01T0<C4a038b<P0^;Rh09bLW02DU9@0l?3`0GEeM079bLP25
QHD0SXj>096AT@27QhL0Shn?08b<S027QhL0T92@09fMW@2LW9`0Y:BT0:2PX02MWId0X:2P09jNWP2L
W9`0VIVI0080WIfM0P2KVi/0202IVIT0UYJF09RHV02KVi/0V9RH09bLW02JVYX0V9RH0`2FUYH00`2K
Vi/0W9bL09RHV00209FEU@80UiNG0P2BTY805@2FUYH0Ti>C09NGU`2FUYH0U9BD09>CT`2ATI40TY:B
08j>SP2@T900SHf=08n?S`2<S8`0Shn?08Z:RP2=SHd0S8b<08^;R`2:RXX0QHF508V9R@0208Z:RP0<
08J6QP1oOgl0QXJ60861P@25QHD0QhN709FEU@2PX:00ZZZZ0;Jf]P2l_;`0_[jn0P32`/801`34a<@0
`l?30<K6aP32`/80`L710<;2`P31`L400P2o_kl01@30`<00`/;20<30`030`<00a<C40080`/;200X0
a/K60<O7a`3;bl/0bl_;0<g=c@3>c/h0cLg=0<o?c`3AdM40d=3@1P3AdM402P3?cll0cLg=0<o?c`3<
c<`0bLW90<S8b039bLT0bl_;0<W9b@3<c<`>0<SPf0003038h=P2051@D00S04Y:BP17AdL0C4a<04i>
CP18B4P0DU9B051@D01ADE40CDe=04Y:BP19BDT0AdM704I6AP13@d<0ATI604A4A010@400AdM70451
@@0j>SX0=cLg034a<@0`<300<c<c0410@01:BTX0GemO06UYJ@1hN7P0P82008V9R@2?Shl0UIFE09ZJ
VP2QXJ400P2SXj<00`2ZZZX0[Zj^0:f][@020;:b/P0;0:f][@2[Zj/0[Zj^0:j^[P2/[:`0/;2`0;Rh
^02b/[80/K6a0;:b/P2`/;000P2XZ:P20::RXP0^09RHV02DU9@0SXj>08J6QP21PH40Lg=c06EUI@1I
FET0Bd];04Y:BP17AdL0Cdm?04E5A@1ADE40G5aL0820P02?Shl0Ng]k061PH01QHF40GEeM06ATI01d
M7@0QhN709^KV`2TY:@0XZ:R09BDU025QHD0MgMg0861P@1hN7P0IFEU0451@@0W9bL0;2`/03Ti>@0a
<C40@41006m_K`1lO7`0RXZ:09ZJVP25QHD0HV9R061PH080NGUi00<0B4Q803hn?P0b<S800P0l?3`0
4@0];Bd0=3@d055AD@1kNg/0I6AT04A4A01YJFT0Fe]K038b<P0j>SX0H61P09RHV02<S8`0MGEe07in
OP29RHT0H61P0080A4A400<0Ng]k08J6QP1;Bd/00P0c<c<02P0l?3`0=SHf03`l?019BDT0?Shn03<c
<`0k>c/0?Shn02h^;P0/;2`202HV9P0o02TY:@0W9bL0:2PX02DU9@0Z:RX0<30`02`/;00a<C40?Shn
055AD@1KFe/0G5aL051@D01=CDd0EEEE04m?C`0b<S80;Bd]04Q8B01RHV80EeMG051@D01SHf<0RHV9
0:BTY02XZ:P0ZJVY0:2PX01eMGD0B4Q803<c<`13@d<0HV9R07inOP2CTi<0Ogmo061PH00V9RH07AdM
01lO7`0T92@07AdM01hN7P0T92@0>c/k0861P@2LW9`0Ogmo07EeM@1^KVh0L71`07inOP2PX:00a/K6
0<O7a`3:b/X0c<c<0<g=c@3>c/h0c<c<0:FUY@0o?cl09RHV00<08b<S0`0Q8B404P0[:b/0@D5105MG
E`0l?3`0=cLg03@d=00l?3`0ADE5051@D01KFe/0I6AT06EUI@1/K6`0L71`07AdM01fMWH0O7al07Ui
N@80PH6100`0P82008>3P`25QHD0QXJ608N7Q`23Ph<0QXJ608V9R@2ATI40Shn?09:BTP2>SXh209>C
T`0E09NGU`2EUID0Vi^K09bLW02OWil0VYZJ09nOW`2TY:@0XZ:R0:2PX02TY:@0X:2P0:BTY02ZZZX0
[:b/0:f][@2VYZH0Xj>S0:^[Z`2][Jd0[:b/0080Z:RX00D0Zj^[0:ZZZP2YZJT0ZZZZ0:NWY`020:FU
Y@0A0:JVYP2NWYh0WIfM09fMW@2GUiL0U9BD08R8R027QhL0QHF508B4Q026QXH0QHF508N7Q`26QXH0
R8R808>3P`22PX800P23Ph<02021PH40O7al07alO01gMgL0N7Qh07emO@1kNg/0OWin0P23Ph<05P28
R8P0RXZ:09VIV@2RXZ80[Jf]0;^k^`39bLT0c/k>0=OGe`3Jf]X0gmoO0=cLg03Fe]H0^k^k0:6QX@2T
Y:@0Zj^[0:>SX`2LW9`0WIfM09VIV@2JVYX209BDU00f09JFUP2@T900RXZ:08j>SP27QhL0RXZ:08F5
Q@21PH40QXJ608F5Q@1nOWh0NGUi07MgM`1`L700H61P04a<C012@T80=SHf02TY:@0W9bL0:RXZ034a
<@0i>CT0<S8b03hn?P16ATH0>SXj03dm?@11@D40C4a<05IFEP1IFET0;Bd]02HV9P0Y:BT0:2PX02l_
;`0b<S80GUiN08^;R`2RXZ80[:b/09^KV`1kNg/0WYjN09ZJVP2;Rh/0MGEe051@D00^;Rh07alO020P
800/;2`0>SXj0P0g=cL02`0d=3@0<S8b02`/;00];Bd0:2PX0410@01GEeL0K6a/0820P02<S8`0TY:B
0080S8b<00P0RHV908F5Q@2<S8`0VIVI09fMW@2SXj<0XZ:R09fMW@80X:2P00T0XZ:R0:2PX02OWil0
VYZJ09bLW02MWId0VIVI09fMW@2KVi/00P2IVIT209fMW@0;09NGU`2IVIT0UiNG09NGU`2FUYH0U9BD
09VIV@2CTi<0UYJF09FEU@2HV9P00P2CTi<0202EUID0T92@09>CT`2FUYH0T92@09>CT`2ATI40U9BD
0`2>SXh00`2=SHd0TI6A096AT@0208b<S00408^;R`2:RXX0SXj>096AT@80RXZ:00d0R8R808j>SP2<
S8`0R8R80820P021PH40PX:208j>SP2LW9`0YJFU0;6a/@2i^KT0_;bl0080`<3000P0`L710<C4a033
`l<0a<C40<;2`P31`L40`/;20;no_`80`<3000<0`L710<;2`P2n_[h00P30`<000`2o_kl0`l?30<G5
a@030<W9b@080<g=c@3<c<`0c/k>0<k>cP3?cll0d=3@0=?Cd`3AdM420=;BdP050<o?c`3>c/h0clo?
0<_;b`3<c<`00P38b<P0103;bl/0b/[:0<[:bP3;bl/>0<SPf0003038h=P205ADE00604i>CP1ADE40
B4Q804m?C`1<C4`0Bd];0P1<C4`0701ADE40BDU904Q8B01;Bd/0BTY:04e=C@15ADD0@D510410@012
@T80>c/k03Ti>@0b<S80=3@d034a<@0`<300@41004U9B@1MGEd0K6a/07MgM`21PH40S8b<08j>SP2D
U9@0WIfM09jNWP2TY:@20:JVYP0M0:^[Z`2`/;00[:b/0:b/[02[Zj/0[Jf]0:b/[02ZZZX0Zj^[0:n_
[`2b/[80/k>c0;2`/02e]KD0/[:b0;2`/02TY:@0Xj>S0:2PX02IVIT0UiNG08n?S`2=SHd0Ogmo07If
MP1^KVh0GUiN051@D01;Bd/00P1=CDd03`1;Bd/0C4a<05mOG`1mOGd0QhN707AdM01MGEd0FUYJ05iN
GP1MGEd0JFUY06YZJP1gMgL0SHf=0:BTY0020:VYZ@0=09VIV@2ATI40R8R806i^KP15ADD0:RXZ02h^
;P0g=cL0>SXj03De=@1ADE40Jf][0861P@0209bLW00307IfMP19BDT0DE5A0080O7al01D0Fe]K034a
<@0h>3P0<c<c02l_;`0[:b/0>c/k07AdM01^KVh0BDU904e=C@1FEUH0=cLg03De=@1FEUH0UYJF08V9
R@23Ph<0S8b<08F5Q@1LG5`00P1JFUX0602BTY80L71`038b<P0e=CD0=3@d03Hf=P0j>SX0=cLg059B
DP0n?Sh0>3Ph04=3@`0g=cL0;2`/02/[:`0U9BD0;Rh^02HV9P0W9bL0:RXZ02DU9@0Y:BT0<30`02PX
:080:RXZ0340@D5105=CD`1=CDd0C4a<04=3@`17AdL0CDe=03Xj>P0^;Rh0>3Ph04Q8B01>CTh0Fe]K
05aLG01iNGT0W9bL0::RXP2HV9P0RHV9065QH@0m?Cd0=CDe05=CD`1dM7@0Vi^K0:f][@2HV9P0JFUY
02HV9P0N7Qh0820P02@T900S8b<07alO020P800V9RH0Fe]K08b<S02DU9@0O7al06i^KP1[Jf/0M7Ad
092@T02f][H0c/k>0<K6aP3=cLd0clo?0080cLg=00@0bLW908^;R`0a<C408R8R0P0W9bL06@0T92@0
:b/[02/[:`0V9RH0A4A405EEE@0h>3P0;bl_03De=@0i>CT0C4a<05IFEP1JFUX0IFEU06IVIP1_Kfl0
LG5a07=cL`1fMWH0OWin07QhN023Ph<0QHF50820P023Ph<00`25QHD02026QXH0QhN708^;R`2;Rh/0
T92@09>CT`2?Shl0UIFE102HV9P05@2PX:00WIfM0:2PX02TY:@0W9bL09fMW@2PX:00Xj>S0:RXZ02T
Y:@0[Jf]0;6a/@2YZJT0ZZZZ0:NWY`2/[:`0Z:RX0:j^[P2`/;00Zj^[0:ZZZP020:b/[00=0:FUY@2W
YjL0X:2P0:FUY@2VYZH0WinO09jNWP2HV9P0VIVI09BDU02ATI40RXZ:08F5Q@0308J6QP0508B4Q028
R8P0QXJ608:2PP25QHD00P20P8001`1oOgl0Ng]k07]kN`1jNWX0N7Qh07]kN`1lO7`00P22PX8208>3
P`0708b<S02KVi/0YZJV0:j^[P2i^KT0bl_;0=KFeP030=gMg@030=_Kf`3@d=00]KFe0080Xj>S00L0
YJFU0:2PX02MWId0Vi^K09fMW@2FUYH0U9BD0080Ti>C00T0Shn?08Z:RP2<S8`0Q8B408F5Q@26QXH0
Q8B40861P@22PX800P1oOgl02P1jNWX0MgMg069RHP1@D500@T9203Lg=`0`<300:BTY02PX:00];Bd2
03Lg=`0<03Hf=P14A4@0>CTi03De=@0o?cl0Bd];05MGE`1HF5P0<30`02DU9@0V9RH092@T0P0/;2`0
3`1RHV80TI6A0:6QX@2VYZH0Vi^K07emO@2FUYH0Ti>C08Z:RP1_Kfl0C4a<03De=@0Y:BT092@T02l_
;`0303Ph>00B03Ti>@0e=CD0<C4a02h^;P0W9bL0<30`04i>CP1XJ6P0O7al08N7Q`2<S8`0RXZ:08V9
R@2;Rh/0R8R808^;R`2FUYH0WIfM0P2TY:@0302NWYh0Xj>S0:2PX02QXJ40X:2P09bLW02IVIT0WYjN
09fMW@2KVi/0WYjN09fMW@80V9RH00h0VYZJ09VIV@2JVYX0VYZJ09VIV@2LW9`0VIVI09RHV02DU9@0
UYJF09FEU@2DU9@0UYJF09>CT`80TI6A00H0UYJF096AT@2@T900Ti>C096AT@2?Shl2092@T00908n?
S`2@T900T92@08n?S`2BTY80T92@08f=S@2@T900Rh^;0080SHf=00l0RHV908b<S02>SXh0R8R808F5
Q@24Q8@0Ph>308:2PP23Ph<0QHF508n?S`2QXJ40Zj^[0;Jf]P2l_;`00P31`L401032`/80`l?30<K6
aP31`L420<?3``80`/;200@0_kno0<30`02o_kl0`L710P32`/800`30`<00`L710<71`@020<C4a008
0<S8b037alL0b/[:0<[:bP3>c/h0c<c<0<g=c@3@d=020=7Ad@030=3@d03Bd]80clo?0080clo?00D0
c/k>0<_;b`38b<P0b/[:0<S8b0020<O7a`030<_;b`38h=P0b>3H00`0b>3H000<0<SPf080Cdm?00D0
C4a<04];B`17AdL0AdM704];B`0204M7A`0804Y:BP1<C4`0BTY:04m?C`19BDT0ADE504M7A`12@T82
04=3@`0F0492@P0n?Sh0?Shn03De=@0c<c<0=cLg03@d=00m?Cd0B4Q805QHF01[Jf/0N7Qh07moO`2=
SHd0TY:B09>CT`2KVi/0WIfM0::RXP2UYJD0ZJVY0:b/[0<0/K6a01H0[jn_0:j^[P2^[Zh0Zj^[0:j^
[P2`/;00/[:b0;6a/@2b/[80/K6a0;2`/02YZJT0Z:RX0::RXP2MWId0VYZJ09BDU02BTY80RXZ:0861
P@1fMWH0JFUY0P1EEED03@16ATH0B4Q804Y:BP1=CDd0D51@05aLG01iNGT0RXZ:07moO`1XJ6P0GemO
065QH@1PH6000P1YJFT08P1WIfL0LW9b07]kN`2:RXX0Vi^K0:2PX02UYJD0WYjN08n?S`1QHF40A4A4
03Xj>P0k>c/0=SHf034a<@16ATH0De=C06i^KP2>SXh0U9BD07YjNP1GEeL0?clo05eMG@1mOGd0SXj>
061PH00i>CT0;Rh^02`/;00^;Rh0=CDe061PH01eMGD204Q8B00:05MGE`0f=SH0>3Ph03Xj>P1bLW80
PH6108Z:RP2?Shl0Ogmo05=CD`80K6a/01P0TY:B05UIF@0m?Cd0>3Ph03Lg=`0h>3P0=cLg03@d=00l
?3`0>SXj030`<010@400@d=3034a<@0Z:RX0:BTY02h^;P0W9bL0:2PX03<c<`0[:b/0:RXZ03Xj>P0X
:2P202HV9P0M03lo?`17AdL0A4A40451@@17AdL0ATI603hn?P0i>CT0<S8b02XZ:P0e=CD0?3`l055A
D@1QHF40IVIV08J6QP2CTi<0Shn?079bLP1DE5@0>CTi05IFEP1OGel0P8200;Jf]P2][Jd0RXZ:055A
D@0Y:BT00P0S8b<02P0X:2P09BDU020P800X:2P092@T03/k>`1jNWX0VIVI08>3P`1]KFd206m_K`0?
0861P@2PX:00dM7A0<O7a`39bLT0bl_;0<c<c03=cLd0dM7A0<71`@1LG5`09bLW020P800V9RH08b<S
008092@T02809BDU0410@01>CTh0>CTi034a<@0h>3P0?clo04m?C`1DE5@0Fe]K069RHP1UIFD0K6a/
071`L01_Kfl0N7Qh07alO01mOGd0OWin08F5Q@1oOgl0QhN708B4Q026QXH0QHF508B4Q02=SHd0Shn?
08^;R`2<S8`0T92@09>CT`2HV9P0Vi^K0P2IVIT03@2LW9`0WYjN09^KV`2NWYh0W9bL0:BTY02QXJ40
YZJV0:>SX`2ZZZX0[:b/0;:b/P2][Jd00P2/[:`01P2_[jl0[Zj^0:^[Z`2/[:`0[Zj^0:f][@80Z:RX
0100Zj^[0:JVYP2WYjL0YjNW0:6QX@2RXZ80WinO09VIV@2EUID0UiNG09FEU@2ATI40RXZ:08R8R026
QXH0RHV90P24Q8@308N7Q`0408Z:RP1nOWh0Ng]k0820P080Ogmo00H0P82007UiN@1kNg/0OGem0861
P@25QHD208V9R@0B092@T02IVIT0YjNW0:n_[`2i^KT0a/K60=GEe@3Jf]X0g=cL0=kNgP3Hf=P0c<c<
0:j^[P2LW9`0XZ:R0:FUY@2NWYh0XZ:R0P2MWId0302JVYX0U9BD096AT@2DU9@0UYJF08f=S@2<S8`0
RXZ:08V9R@28R8P0OWin08F5Q@80Ogmo01L0PX:207QhN01iNGT0JVYZ05MGE`13@d<0?Cdm03@d=00c
<c<0:RXZ034a<@0f=SH0>SXj038b<P0n?Sh0>CTi03Lg=`0j>SX0C4a<065QH@1@D500;bl_02PX:002
02DU9@0B02HV9P0c<c<0IfMW09RHV02TY:@0YJFU09ZJVP1oOgl0UYJF08^;R`21PH40J6QX03dm?@0g
=cL0820P02<S8`0];Bd0>3Ph0P0o?cl0100e=CD0>3Ph03Lg=`0a<C4202`/;00[03dm?@1NGUh0NWYj
08>3P`2=SHd0S8b<08V9R@2<S8`0R8R808V9R@2IVIT0Vi^K0:>SX`2OWil0X:2P0::RXP2QXJ40W9bL
09^KV`2JVYX0W9bL09jNWP2KVi/0VYZJ09^KV`2LW9`0VIVI09ZJVP2MWId0VYZJ09>CT`2JVYX0Ti>C
09NGU`2FUYH0U9BD09RHV02BTY80UIFE09>CT`2BTY80U9BD09:BTP0409>CT`0908n?S`2@T900TY:B
09>CT`2>SXh0Shn?08b<S02?Shl0Ti>C0080T92@00<0SHf=092@T029RHT00P2ATI403`2:RXX0Rh^;
08f=S@28R8P0Rh^;08N7Q`22PX80PH6108:2PP20P800Rh^;09ZJVP2TY:@0[Zj^0;Rh^0020;bl_005
0<30`033`l<0aLG50<;2`P33`l<00P32`/801P33`l<0`/;20<30`031`L40`l?30<;2`PD0`L7100@0
aLG50<?3``37alL0a/K60P39bLT00`3<c<`0c/k>0<c<c0020=3@d0070=;BdP3AdM40d=3@0=3@d03<
c<`0cLg=0<c<c0020<W9b@040<_;b`39bLT0b/[:0<_;b`h0b>3H000<0<SPf080BTY:00H0C4a<051@
D01BDU80CTi>04e=C@1;Bd/204a<C00L051@D01=CDd0CTi>059BDP18B4P0ATI604Y:BP17AdL0BDU9
04=3@`0k>c/0@41003`l?00f=SH0=CDe038b<P0j>SX0AdM705QHF01XJ6P0MgMg0861P@2=SHd0TI6A
09^KV`2MWId0WinO0:>SX`80[:b/00T0[jn_0;6a/@2`/;00/;2`0:b/[02`/;00ZJVY0:ZZZP2][Jd0
0P2^[Zh0CP2][Jd0/K6a0;>c/`2a/K40ZJVY0:JVYP2TY:@0W9bL09FEU@2FUYH0TI6A08V9R@23Ph<0
M7Ad06a/K01IFET0Cdm?051@D014A4@0Cdm?05ADE01@D500Fe]K07AdM025QHD0PX:206ATI01OGel0
I6AT069RHP1ZJVX0K6a/06MWI`1[Jf/0IfMW06i^KP1jNWX0Ph>308R8R02EUID0V9RH09FEU@2<S8`0
M7Ad05ADE018B4P0;bl_0410@01:BTX0F5QH071`L026QXH0P82006YZJP1ADE40@D5105IFEP23Ph<0
R8R805QHF00l?3`0=3@d03Hf=P0g=cL0?3`l06IVIP1:BTX0?Shn05IFEP19BDT0?Shn03Lg=`1<C4`0
LW9b08f=S@22PX80M7Ad05QHF080Q8B402<0P82004E5A@0X:2P0<c<c0451@@0j>SX0@T9203`l?010
@400=CDe03<c<`19BDT0>CTi03@d=00];Bd0<S8b03Lg=`0[:b/0;2`/02TY:@0[:b/0:RXZ03<c<`0W
9bL09RHV02l_;`1<C4`0BDU905EEE@0b<S80:2PX02h^;P0c<c<0?Cdm03Ti>@0302d];@0703dm?@1P
H600Kfm_07IfMP28R8P0Ph>306QXJ00204m?C`0;08V9R@1iNGT0Ti>C0;:b/P2HV9P0KVi^038b<P0Q
8B40;Rh^028R8P0V9RH00P0[:b/05P0X:2P09bLW030`<01PH600T92@09FEU@1]KFd0I6AT071`L01i
NGT0QHF50<?3``3:b/X0aLG50<S8b03;bl/0c/k>0=7Ad@3De=@0YjNW02l_;`0R8R8202DU9@80:2PX
0180;bl_03Ti>@18B4P0=cLg03Hf=P0l?3`0AdM7055AD@1CDe<0GUiN06EUI@1^KVh0KFe]07MgM`1d
M7@0NWYj0820P01nOWh208>3P`0607inOP24Q8@0PX:208J6QP27QhL0RXZ:0`2=SHd01`2@T900UiNG
09BDU02HV9P0UYJF09NGU`2HV9P00P2LW9`01`2KVi/0WIfM09bLW02UYJD0ZJVY0:NWY`2][Jd00P2[
Zj/02`2d];@0[jn_0:f][@2_[jl0/K6a0:n_[`2b/[80[jn_0:b/[02XZ:P0YjNW0080[:b/01L0YjNW
0:VYZ@2WYjL0Y:BT0:6QX@2RXZ80WYjN09ZJVP2IVIT0Ti>C096AT@2:RXX0RHV908F5Q@28R8P0QXJ6
08F5Q@27QhL0R8R8096AT@26QXH0Ph>307moO`030861P@0E07YjNP1mOGd0O7al07alO024Q8@0RHV9
08R8R02>SXh0TI6A09JFUP2SXj<0Zj^[0;^k^`3;bl/0f=SH0=cLg03Ogml0f][J0=KFeP38b<P0ZZZZ
0080XJ6Q00@0XZ:R09jNWP2NWYh0W9bL0P2JVYX0>02EUID0TY:B09JFUP2BTY80RHV908j>SP2;Rh/0
RHV908J6QP24Q8@0QXJ60820P021PH40Ogmo07IfMP1gMgL0Jf][05YJFP16ATH0?3`l03Hf=P0`<300
<C4a030`<00g=cL0=CDe03<c<`0n?Sh0>3Ph03Ti>@11@D40Cdm?05eMG@17AdL0:RXZ024Q8@0T92@0
8R8R02@T900a<C40K6a/09jNWP2YZJT0YjNW09bLW025QHD0V9RH09>CT`2=SHd0I6AT03@d=013@d<0
92@T034a<@0X:2P0;Rh^0P0k>c/0600d=3@0?3`l02`/;00];Bd0:2PX02XZ:P0l?3`0G5aL07MgM`22
PX80Rh^;08n?S`2;Rh/0RXZ:08V9R@27QhL0T92@09fMW@2SXj<0WinO0::RXP2TY:@0XJ6Q09jNWP80
WIfM00D0Vi^K09fMW@2JVYX0Vi^K09VIV@0209NGU`0309RHV02IVIT0V9RH0080VIVI00D0UIFE09JF
UP2GUiL0UIFE09BDU00209JFUP0409FEU@2GUiL0UYJF09:BTP80T92@00l0Ti>C08n?S`2BTY80Ti>C
09:BTP2@T900TI6A08n?S`2>SXh0UIFE09JFUP2@T900TY:B08b<S02>SXh00P2?Shl0402>SXh0SHf=
08f=S@2=SHd0QhN708Z:RP27QhL0Q8B408J6QP21PH40QXJ608F5Q@2ATI40VYZJ0:VYZ@2a/K420;Zj
^P040;jn_P32`/80`/;20<C4a080`/;200<0`l?30<30`02n_[h00P30`<001P33`l<0_[jn0<71`@31
`L40`l?30<;2`P80`l?300@0aLG50<K6aP35aLD0alO70P39bLT20<_;b`040<g=c@3AdM40d=3@0=7A
d@80clo?00D0cLg=0<o?c`3<c<`0bLW90<[:bP020<c<c0030<W9b@3=cLd0b>3H00d0b>3H000<0<SP
f080CTi>00<0C4a<04];B`19BDT00P1=CDd00`18B4P0DE5A04a<C00204];B`0N04a<C01;Bd/0Bd];
04E5A@14A4@0@41004=3@`14A4@0?Cdm03Ti>@0f=SH0=CDe030`<00c<c<0?clo04U9B@1EEED0JVYZ
07UiN@24Q8@0Shn?09>CT`2EUID0WIfM09nOW`2QXJ40YJFU0:b/[02XZ:P0[:b/0P2_[jl02P2`/;00
[Zj^0:b/[02/[:`0[Zj^0:n_[`2c/k<0/[:b0:j^[P2a/K420:n_[`0=0:RXZ02WYjL0WinO09VIV@2G
UiL0SXj>08Z:RP22PX80M7Ad06EUI@1MGEd0DU9B04a<C00204U9B@0@04i>CP1IFET0FEUI06UYJ@1c
Lg<0L71`069RHP1PH600IFEU06=SH`1VIVH0JVYZ06UYJ@1_Kfl0Jf][06i^KP80Kfm_02P0L71`07If
MP1eMGD0PX:20:>SX`2LW9`0R8R8079bLP1PH600@D5104];B`16ATH0D51@071`L01mOGd0JFUY06][
J`16ATH0>c/k05iNGP1oOgl0O7al05iNGP0k>c/0>SXj03Lg=`0i>CT0BDU904i>CP0h>3P0DU9B03De
=@0a<C40<S8b0410@01MGEd0RHV907inOP1[Jf/0CDe=0P20P800:01RHV80>3Ph038b<P0h>3P0ATI6
03`l?00j>SX0=SHf03Ti>@0g=cL0<30`04E5A@0f=SH0<c<c02l_;`0];Bd0;bl_038b<P0^;Rh0:BTY
02l_;`0a<C40;bl_02PX:00[:b/0;2`/04I6AP1[Jf/0GemO034a<@0U9BD092@T02l_;`15ADD0=CDe
02XZ:P0^;Rh0:2PX038b<P1=CDd2071`L00Z07]kN`1bLW80EUIF04Y:BP1eMGD0[Jf]0:BTY02JVYX0
U9BD071`L019BDT0;Bd]02HV9P0Q8B408R8R02DU9@0X:2P092@T02XZ:P0[:b/0:RXZ04e=C@20P800
UiNG07UiN@1TI6@0L71`07]kN`1mOGd0[Jf]0<c<c02l_;`0a<C40<S8b03<c<`0d=3@0=GEe@38b<P0
MGEe03De=@0Y:BT08R8R0P0V9RH03P0W9bL0?clo04=3@`0a<C40;bl_03Hf=P0m?Cd0AdM7055AD@1T
I6@0J6QX06a/K01`L700MgMg0P1iNGT30820P00M07moO`22PX80P82008B4Q029RHT0S8b<08f=S@2;
Rh/0SHf=09>CT`2BTY80T92@09RHV02ATI40VIVI09NGU`2HV9P0VIVI09ZJVP2NWYh0WinO0::RXP2V
YZH0ZJVY0:FUY@2][Jd0Z:RX0:^[Z`2c/k<00`2^[Zh02@2a/K40/;2`0;6a/@2`/;00/[:b0:ZZZP2X
Z:P0Zj^[0:f][@030:RXZ00=0:BTY02SXj<0WinO09fMW@2KVi/0UiNG09RHV02EUID0TY:B092@T02;
Rh/0S8b<08^;R`0208V9R@80Rh^;00@0QXJ608B4Q01nOWh0PH610P1nOWh05`1mOGd0PH6107alO023
Ph<0PH6108B4Q029RHT0TI6A09>CT`2JVYX0XJ6Q0:^[Z`2h^;P0c/k>0=OGe`3MgMd0gmoO0=SHf03B
d]80`l?30:ZZZP2PX:00Y:BT0080XJ6Q00D0Y:BT0:6QX@2FUYH0VIVI09>CT`0209JFUP0J09jNWP2@
T900Shn?08V9R@2<S8`0RXZ:08>3P`22PX80Ph>30861P@1nOWh0N7Qh07MgM`1^KVh0GemO055AD@0m
?Cd0?clo02XZ:P0X:2P0<30`03<c<`0j>SX0;Rh^03De=@0i>CT203hn?P0I04a<C01HF5P0AdM7034a
<@0W9bL09RHV02PX:00U9BD0>CTi07=cL`2RXZ80[jn_0:JVYP2HV9P0S8b<09ZJVP2FUYH0SHf=05MG
E`0g=cL0?Cdm02<S8`0Q8B409RHV03@d=00203Lg=`0:03lo?`0j>SX0;bl_03Hf=P0b<S80<C4a03De
=@1<C4`0IVIV07inOP80RHV900/0R8R808Z:RP27QhL0Ph>308j>SP2DU9@0WYjN0:>SX`2QXJ40YZJV
0:6QX@0309fMW@0E09ZJVP2LW9`0Vi^K09RHV02LW9`0UiNG09^KV`2HV9P0VYZJ09RHV02JVYX0UYJF
09RHV02JVYX0W9bL09NGU`2DU9@0UYJF09BDU02GUiL0UIFE0080TY:B00X0Shn?092@T02CTi<0U9BD
09>CT`2BTY80Ti>C08n?S`2>SXh0TY:B102?Shl01`2@T900TI6A096AT@2?Shl0TY:B092@T02?Shl0
0P2<S8`01@2;Rh/0QhN708J6QP26QXH0PX:20080PH6100D0P82008R8R02HV9P0YJFU0;2`/0020;Fe
]@030;fm_@2o_kl0`/;20080`/;20`34a<@01P31`L40`<300<;2`P31`L40`<300;jn_P80_kno00T0
`<300<?3``31`L40`l?30<C4a033`l<0a<C40<S8b039bLT00P3:b/X02@3<c<`0c/k>0<c<c03=cLd0
c/k>0<g=c@3<c<`0clo?0<g=c@020<c<c080b/[:00<0bl_;0<[:bP38h=P03@38h=P000`0b>3H0P19
BDT01`1>CTh0Bd];04a<C01=CDd0AdM704a<C019BDT00P1<C4`00`1@D500Bd];04];B`0204M7A`07
04E5A@13@d<0ADE504E5A@12@T80?Shn03Xj>P0203Lg=`0A03`l?013@d<0ADE505EEE@1WIfL0MWIf
0861P@2?Shl0Ti>C09BDU02KVi/0WIfM0:FUY@2WYjL0ZJVY0:f][@2[Zj/00P2`/;001@2_[jl0/;2`
0;6a/@2][Jd0[Zj^0080/;2`01l0/k>c0;2`/02_[jl0/K6a0:j^[P2ZZZX0[:b/0:2PX02MWId0UiNG
092@T029RHT0QHF507IfMP1VIVH0G5aL051@D019BDT0CDe=05YJFP1BDU80FEUI061PH01KFe/0HV9R
061PH01MGEd0HV9R06EUI@1XJ6P0IVIV0080Jf][00<0K6a/06i^KP1cLg<00P1bLW806P1aLG40J6QX
059BDP1DE5@0Ogmo09NGU`2DU9@0Ti>C09VIV@1fMWH0FUYJ04I6AP13@d<0E5AD06e]K@1ZJVX0LG5a
06=SH`0o?cl0ATI605eMG@1cLg<0QHF506a/K01<C4`0>SXj0P0i>CT03010@400>3Ph04=3@`0b<S80
=cLg03<c<`17AdL0LG5a092@T01kNg/0GUiN055AD@80NWYj00P0C4a<038b<P0l?3`0?3`l0451@@0j
>SX0>CTi034a<@80<c<c00d0<C4a0492@P0i>CT0;Rh^02`/;00[:b/0=CDe038b<P0`<300:b/[02h^
;P0`<3009BDU0080;Rh^02@0:b/[0451@@1HF5P0JVYZ03<c<`0Z:RX092@T03Lg=`13@d<0;Rh^02XZ
:P0X:2P0:b/[02XZ:P1ADE40KFe]079bLP1`L700HF5Q04i>CP1JFUX0V9RH0:BTY02/[:`0UiNG06a/
K014A4@0;2`/02PX:00[:b/09RHV024Q8@0V9RH08R8R02<S8`0P820202PX:00E03<c<`1aLG40Shn?
08j>SP1YJFT0L71`07AdM01gMgL0Shn?0<O7a`2l_;`0_Kfm0<C4a037alL0bl_;0<o?c`3AdM40/k>c
04A4A00Z:RX08b<S008092@T00d0:2PX02l_;`0n?Sh0;bl_03@d=00l?3`0@d=304m?C`1ADE40Hf=S
06QXJ01/K6`0L71`0080NWYj0`1kNg/0101nOWh0PH6108>3P`28R8P208:2PP0>08J6QP2<S8`0RXZ:
08f=S@2?Shl0T92@09:BTP2HV9P0UIFE09ZJVP2IVIT0Vi^K09JFUP2IVIT209fMW@0F0:2PX02UYJD0
YJFU0:FUY@2][Jd0YjNW0:j^[P2a/K40/;2`0:b/[02a/K40]KFe0;6a/@2b/[80[jn_0:f][@2[Zj/0
ZJVY0:^[Z`2ZZZX0[:b/0:ZZZP80YjNW00H0YJFU0:6QX@2QXJ40WIfM09ZJVP2BTY8209>CT`0308n?
S`2<S8`0R8R80080RXZ:00L0T92@08R8R02?Shl0R8R808F5Q@23Ph<0P8200080PX:200<0Ng]k07em
O@1iNGT00P22PX802P23Ph<0RHV9092@T02JVYX0WIfM0:JVYP2a/K40^[Zj0<k>cP3Fe]H20=oOg`04
0=_Kf`3De=@0_kno0:b/[080YZJV03h0Y:BT0::RXP2OWil0W9bL09^KV`2FUYH0VIVI09FEU@2FUYH0
VYZJ08n?S`2=SHd0RXZ:08R8R026QXH0PH6108J6QP21PH40O7al07inOP1iNGT0NWYj06e]K@1QHF40
CTi>03`l?00o?cl0<C4a02`/;00Y:BT0<30`03Lg=`0_;bl0<c<c034a<@0e=CD0>CTi04];B`1OGel0
C4a<030`<00W9bL09RHV02PX:00T92@0=CDe07MgM`2XZ:P0/;2`0:b/[02CTi<0R8R809VIV@2KVi/0
SXj>04Q8B00V9RH0<30`02PX:00Y:BT092@T02d];@80@D5101P0?Cdm03Xj>P0f=SH0<30`03@d=00^
;Rh0<S8b04I6AP1RHV80N7Qh08V9R@2=SHd0R8R808^;R`29RHT0QXJ608F5Q@2=SHd0YJFU0:f][@2c
/k<0/[:b09jNWP2JVYX309bLW00609jNWP2IVIT0UiNG09nOW`2NWYh0VYZJ0P2HV9P0202JVYX0UiNG
09NGU`2IVIT0VYZJ09VIV@2FUYH0Ti>C0`2DU9@01P2FUYH0TY:B09FEU@2DU9@0UYJF09>CT`80U9BD
00D0UIFE09>CT`2CTi<0T92@096AT@0208n?S`0;08b<S02?Shl0SXj>09>CT`2ATI40TY:B096AT@2>
SXh0Shn?092@T02>SXh00P2<S8`02P26QXH0QhN708J6QP20P800QhN708:2PP23Ph<0Shn?09^KV`2X
Z:P20;6a/@080;Rh^02n_[h0_kno0<?3``32`/80`l?30<G5a@30`<030<;2`P80`L7100h0`<300<71
`@31`L40`<300<G5a@31`L40`/;20<C4a033`l<0a<C40<?3``37alL0a/K60<[:bP80bl_;0P3>c/h0
103=cLd0c/k>0<c<c03<c<`20<g=c@030<c<c03=cLd0c<c<0080b/[:3P38h=P000`0b>3H0P1@D500
1P1;Bd/0D51@04U9B@1?Cdl0ATI604Q8B080BTY:00/0DE5A04Q8B013@d<0B4Q804];B`13@d<0A4A4
04a<C014A4@0@d=303`l?0020410@00C03Ph>00d=3@0>c/k0451@@18B4P0E5AD06IVIP1dM7@0PX:2
08b<S02@T900U9BD09bLW02MWId0YjNW0:RXZ02/[:`0ZZZZ0:f][@020:n_[`060;6a/@2`/;00/[:b
0:n_[`2^[Zh0/;2`0`2a/K403`2_[jl0[Zj^0:j^[P2[Zj/0Y:BT09jNWP2JVYX0V9RH09>CT`25QHD0
PH6107YjNP1YJFT0GemO05=CD`0204m?C`0905IFEP1BDU80EEEE05MGE`1NGUh0GEeM05YJFP1OGel0
HV9R0080JFUY0280J6QX06UYJ@1ZJVX0JVYZ075aL@1_Kfl0LG5a079bLP1dM7@0KFe]05EEE@0j>SX0
D51@07YjNP26QXH0QHF508j>SP2@T900NGUi05YJFP0o?cl0@d=305iNGP1SHf<0LG5a069RHP1FEUH0
ADE504Y:BP1TI6@0LW9b0820P01/K6`0ATI60P0f=SH0300d=3@0>SXj03Ph>00i>CT0>c/k03De=@1H
F5P0RXZ:08j>SP1/K6`0G5aL05iNGP80L71`00d0?3`l03<c<`0h>3P0@D5103dm?@0e=CD0<S8b02/[
:`0f=SH0;bl_03<c<`0o?cl0;bl_0080<c<c00H0;2`/03hn?P0c<c<0;Bd]03@d=00b<S82034a<@07
03dm?@0g=cL0=CDe02`/;00j>SX0@D5102l_;`02030`<00c04Y:BP14A4@0:BTY02DU9@0R8R80>SXj
0451@@1PH600IVIV075aL@1kNg/0IfMW05YJFP1oOgl0/;2`09ZJVP2@T900NWYj04E5A@0Z:RX08R8R
02/[:`0_;bl0:BTY028R8P0Q8B408R8R02TY:@0V9RH08R8R02@T900Z:RX0De=C08F5Q@2OWil0N7Qh
07=cL`1dM7@0MgMg07]kN`2f][H0aLG50;Rh^02m_Kd0a<C40<G5a@39bLT0d=3@0<c<c02GUiL0<S8b
00@0:BTY01D0=CDe04=3@`0/;2`0<30`03`l?00m?Cd0Bd];05EEE@1OGel0IFEU06i^KP1dM7@0Ogmo
07UiN@1fMWH0N7Qh07UiN@1oOgl0Ph>308:2PP2<S8`00P24Q8@00`25QHD0RHV908V9R@0208n?S`08
096AT@2>SXh0UIFE09JFUP2HV9P0VIVI09bLW02BTY8209^KV`0@09ZJVP2RXZ80YjNW0:>SX`2WYjL0
ZJVY0:ZZZP2b/[80[jn_0;>c/`2_[jl0/K6a0:n_[`2a/K40^;Rh0;6a/@80[Zj^00`0ZJVY0:^[Z`2`
/;00[Zj^0:FUY@2VYZH0YJFU0:BTY02NWYh0WIfM09^KV`2OWil209:BTP0908b<S02>SXh0Shn?08V9
R@2;Rh/0S8b<096AT@2;Rh/0RXZ:0080RHV90240Q8B40861P@1lO7`0O7al07IfMP24Q8@0Ogmo0820
P023Ph<0R8R808f=S@2@T900UYJF09nOW`2XZ:P0^[Zj0<?3``3@d=00fm_K0=oOg`3Ng]h0fMWI0=?C
d`2k^k/0ZZZZ0:NWY`2SXj<0ZZZZ0:BTY02MWId0W9bL09jNWP2IVIT00P2HV9P02P2ATI40UIFE08j>
SP2=SHd0RHV908Z:RP27QhL0PH6108B4Q023Ph<208:2PP0>07MgM`1jNWX0LG5a06EUI@1CDe<0A4A4
03hn?P0j>SX0=3@d02TY:@0W9bL0?Cdm034a<@0b<S8202l_;`0@03<c<`15ADD0GEeM04];B`0^;Rh0
;2`/02TY:@0U9BD0:b/[0410@01iNGT0[Jf]0;Bd]02_[jl0TI6A08R8R080WYjN00P0O7al03/k>`0[
:b/0:BTY028R8P0T92@08b<S034a<@<0@d=301D0@41002d];@0a<C40>3Ph03<c<`0e=CD0?Cdm05UI
F@1eMGD0QXJ608n?S`29RHT0Shn?08b<S026QXH0RXZ:092@T02_[jl0Xj>S0<K6aP2UYJD00P2QXJ40
102KVi/0VYZJ09bLW02MWId209ZJVP0709jNWP2JVYX0Vi^K09ZJVP2NWYh0VYZJ09NGU`0209ZJVP80
UIFE00<0U9BD09NGU`2EUID00P2EUID02@2CTi<0T92@09BDU02DU9@0T92@08n?S`2BTY80Ti>C092@
T002096AT@0K08j>SP2=SHd0T92@096AT@2=SHd0T92@08j>SP2:RXX0TY:B09>CT`2:RXX0TI6A08f=
S@2;Rh/0SHf=092@T02=SHd0QhN708>3P`26QXH0PX:208B4Q01oOgl0PH6108R8R02CTi<0X:2P0080
[Zj^00L0/k>c0;no_`2l_;`0`L710<C4a033`l<0a<C400<0`l?300D0`L710<;2`P32`/80`L710<30
`0030<71`@0>0<30`033`l<0`l?30<?3``34a<@0`l?30<G5a@37alL0b<S80<[:bP38b<P0bLW90<c<
c03=cLd20<k>cP050<_;b`3=cLd0c/k>0<[:bP3;bl/00`3=cLd>0<SPf0003038h=P205=CD`0;05AD
E01BDU80C4a<04];B`17AdL0De=C04Q8B01:BTX0Bd];04Y:BP1;Bd/00P18B4P05@16ATH0BDU90410
@011@D40AdM70410@00o?cl0?Cdm03Ti>@0f=SH0=CDe04=3@`1<C4`0F5QH06MWI`1mOGd0Q8B408Z:
RP2BTY80UYJF09jNWP020::RXP040:^[Z`2^[Zh0[:b/0:j^[P80/[:b00P0/;2`0:n_[`2e]KD0/;2`
0:n_[`2d];@0[Zj^0;2`/080/K6a01<0[jn_0:j^[P2[Zj/0Xj>S0:FUY@2MWId0VIVI092@T029RHT0
Q8B407EeM@1YJFT0GUiN059BDP1;Bd/0BDU904e=C@1ADE40EUIF00<0FEUI00H0GemO06YZJP1ZJVX0
J6QX06EUI@1YJFT206e]K@0806a/K01aLG40LW9b07=cL`1aLG40MGEe079bLP1TI6@20410@00S05YJ
FP1gMgL0IfMW06QXJ01lO7`0PX:207alO01NGUh0B4Q804M7A`1OGel0P82006YZJP1PH600BTY:04M7
A`1:BTX0G5aL06a/K01gMgL0Jf][04m?C`0k>c/0;bl_02/[:`0e=CD0>c/k05EEE@1@D500IfMW09^K
V`22PX80GEeM05UIF@1]KFd00P1[Jf/02012@T80?Shn04e=C@0j>SX0@d=303/k>`0[:b/0:RXZ0P0/
;2`06@0d=3@0?Shn03<c<`0c<c<0=SHf03<c<`0g=cL0<C4a02h^;P0c<c<0<C4a038b<P0c<c<0;Bd]
02`/;018B4P0:BTY02h^;P0];Bd09bLW034a<@10@400Fe]K03`l?00X:2P00P0R8R801P0a<C40Bd];
05UIF@1UIFD0LG5a08B4Q080KFe]00h0UIFE0:JVYP2CTi<0MgMg05QHF00];Bd09BDU02<S8`0P8200
8b<S028R8P0U9BD092@T02<S8`808R8R01L07alO024Q8@0U9BD0>CTi079bLP2JVYX0Rh^;07=cL`1b
LW80L71`07AdM02KVi/0a/K60;Vi^@2k^k/0_kno0<C4a033`l<0aLG50<c<c032`/80JVYZ038b<P02
030`<00G02XZ:P0];Bd0>SXj02d];@0g=cL0=3@d03`l?01=CDd0FEUI06EUI@1/K6`0LG5a07EeM@1j
NWX0N7Qh07IfMP1hN7P0OWin08>3P`26QXH0Q8B408N7Q`22PX800P25QHD03@27QhL0S8b<092@T02D
U9@0TY:B08j>SP2BTY80TI6A09BDU02EUID0W9bL09fMW@2KVi/00`2RXZ803P2XZ:P0YZJV0:b/[02_
[jl0/;2`0;6a/@2`/;00^;Rh0:j^[P2b/[80];Bd0;Fe]@2g]kL0/;2`0`2_[jl01`2[Zj/0/[:b0:f]
[@2YZJT0Z:RX0:JVYP2WYjL00P2RXZ804@2PX:00VYZJ09JFUP2EUID0Rh^;08n?S`2ATI40S8b<08f=
S@2DU9@0Ti>C08j>SP2:RXX0Rh^;08F5Q@26QXH0PH610080Ogmo01H0OWin07emO@23Ph<0P82008J6
QP22PX80SHf=09>CT`2HV9P0X:2P0:ZZZP2e]KD0bl_;0=OGe`3Kfm/0g=cL0=gMg@3Hf=P0cLg=0;no
_`2^[Zh0ZJVY0`2XZ:P20:6QX@0U0::RXP2LW9`0VYZJ09ZJVP2BTY80UIFE092@T02>SXh0RXZ:08F5
Q@24Q8@0Ph>307moO`20P800O7al07emO@1nOWh0NGUi07EeM@1/K6`0EEEE0492@P0i>CT0ATI603Lg
=`0_;bl0;2`/03@d=00f=SH0<C4a03<c<`0a<C40>SXj04e=C@1NGUh0BDU903@d=00202TY:@0C02HV
9P0Z:RX0>c/k08Z:RP2YZJT0[Jf]0:RXZ02=SHd0U9BD0:6QX@2NWYh0KVi^03Ph>00/;2`092@T02PX
:00Z:RX09RHV03@d=0020451@@0=04A4A00g=cL0>SXj03<c<`0_;bl0;Bd]02l_;`0c<c<0EEEE06a/
K023Ph<0R8R808b<S00208^;R`0908f=S@26QXH0TI6A09^KV`2JVYX0XZ:R0:JVYP2UYJD0WinO0080
WYjN00X0VYZJ09bLW02JVYX0VYZJ09VIV@2LW9`0Vi^K09VIV@2LW9`0V9RH0`2GUiL0102HV9P0VYZJ
09RHV02JVYX209JFUP0909FEU@2DU9@0T92@09FEU@2HV9P0Ti>C09BDU02BTY80Ti>C0080UYJF00@0
UiNG09BDU02ATI40TI6A0P2BTY800`2FUYH0T92@08n?S`0208j>SP0508n?S`2=SHd0Shn?08j>SP2?
Shl00P2;Rh/02P2:RXX0Q8B408F5Q@26QXH0Q8B408>3P`21PH40OGem08f=S@2HV9P20:>SX`030;6a
/@2g]kL0^k^k0080_kno00H0`l?30<C4a034a<@0`l?30<;2`P31`L420<;2`P030<?3``30`<00a<C4
0080`l?300d0a<C40<?3``33`l<0`l?30<;2`P31`L40`l?30<G5a@34a<@0alO70<W9b@38b<P0bl_;
00<0b/[:00P0c<c<0<o?c`3<c<`0bl_;0<g=c@3;bl/0c<c<0<[:bPh0b>3H000<0<SPf080D51@00H0
DU9B04e=C@1>CTh0Cdm?04e=C@1@D50204i>CP80Cdm?00@0B4Q804U9B@17AdL0ATI60`19BDT01017
AdL0@T9203hn?P0i>CT203/k>`0@03Lg=`0m?Cd0ATI605eMG@1ZJVX0NGUi08B4Q028R8P0TY:B09FE
U@2HV9P0Xj>S0:JVYP2XZ:P0ZZZZ0:f][@<0[jn_00P0];Bd0;>c/`2c/k<0/[:b0;6a/@2e]KD0/;2`
0:n_[`80];Bd01T0/[:b0;2`/02^[Zh0YJFU09nOW`2JVYX0UiNG09JFUP24Q8@0P82006m_K`1XJ6P0
G5aL05QHF01>CTh0Bd];05ADE01?Cdl0EeMG05ADE01KFe/0HV9R06ATI01QHF40H61P0080JVYZ0300
KVi^06m_K`1/K6`0LW9b06m_K`1bLW80MGEe07AdM01mOGd0OWin06YZJP1@D500DE5A05QHF01DE5@0
FUYJ051@D01:BTX0IVIV07MgM`1aLG40G5aL0492@P1OGel0Ogmo06IVIP1IFET0A4A403`l?00k>c/0
AdM705QHF01]KFd0MGEe07YjNP1MGEd0?3`l034a<@0h>3P0?3`l04m?C`1]KFd0Ogmo09:BTP1dM7@0
Fe]K06IVIP1dM7@204i>CP0<03De=@10@400KFe]04Y:BP0l?3`0>SXj02LW9`0Y:BT0;Bd]02/[:`0e
=CD0;bl_0P0g=cL0;`0c<c<0=SHf03De=@0^;Rh0<30`03Hf=P0g=cL0;Rh^030`<00/;2`0<c<c04Q8
B00g=cL0<c<c03De=@0c<c<0<S8b04];B`1GEeL0>CTi02LW9`0Q8B407AdM02`/;00i>CT0Cdm?06IV
IP1_Kfl0QXJ608B4Q01`L700Shn?09^KV`28R8P0FEUI03hn?P0W9bL09BDU02@T900W9bL0;2`/02LW
9`0S8b<08R8R02HV9P0b<S809BDU00808R8R00H07alO02TY:@1KFe/0RHV909BDU01fMWH206m_K`07
07=cL`24Q8@0`<300<O7a`2k^k/0_Kfm0<K6aP020;fm_@040<?3``3>c/h0[:b/03Xj>P80;bl_00d0
:b/[02d];@0e=CD0;Rh^038b<P0f=SH0@41004m?C`1IFET0IFEU06a/K01bLW80LG5a0080MGEe0P1k
Ng/03P22PX80Ph>307inOP22PX80RHV908F5Q@28R8P0QXJ608B4Q02;Rh/0Shn?096AT@2@T900Ti>C
0P2@T9008P2EUID0UiNG09RHV02MWId0XZ:R0:NWY`2YZJT0YJFU0:RXZ02[Zj/0[:b/0;2`/02b/[80
];Bd0;Jf]P2c/k<0/;2`0:n_[`2d];@0]kNg0;>c/`2][Jd0[jn_0:j^[P2YZJT0[jn_0;2`/02_[jl0
Zj^[0:f][@2YZJT0XZ:R0:>SX`2NWYh209^KV`0;09NGU`2FUYH0TI6A08n?S`2CTi<0T92@08f=S@2B
TY80U9BD08b<S02ATI400P28R8P208J6QP80OWin00@0Ogmo07alO022PX80Q8B40P25QHD07P29RHT0
T92@09NGU`2WYjL0[Zj^0;Zj^P3Bd]80e]KF0=[JfP3Lg=`0fm_K0=SHf03=cLd0]kNg0;2`/02YZJT0
YJFU0:BTY02VYZH0XJ6Q0::RXP2KVi/0VIVI09RHV02FUYH0TI6A08j>SP2?Shl0SXj>08Z:RP80QHF5
02l0RHV90820P023Ph<0P8200861P@1nOWh0NWYj075aL@1XJ6P0H61P04E5A@0m?Cd0>c/k03Lg=`0a
<C40:2PX034a<@0i>CT0>3Ph03@d=00e=CD0>SXj04Q8B01QHF40Bd];038b<P0Z:RX0:BTY02LW9`0/
;2`0B4Q808b<S02VYZH0ZZZZ0:>SX`25QHD0V9RH0:FUY@2HV9P0HF5Q02`/;00];Bd08b<S02/[:`0k
>c/0:BTY03<c<`0203`l?00D03hn?P0c<c<0<c<c02l_;`0];Bd0;2`/02XZ:P0_;bl0BTY:069RHP1i
NGT0Ph>308b<S02;Rh/0RXZ:08f=S@27QhL0Rh^;09NGU`2IVIT20:6QX@0<0::RXP2PX:00Vi^K09VI
V@2LW9`0WYjN09NGU`2LW9`0UIFE09fMW@2LW9`0V9RH0P2JVYX01@2IVIT0V9RH09bLW02HV9P0Vi^K
0080UYJF00/0TY:B09BDU02FUYH0Ti>C09NGU`2EUID0TY:B09RHV02DU9@0TY:B096AT@0209BDU00?
09FEU@2>SXh0SHf=096AT@2EUID0UYJF092@T02BTY80SHf=08n?S`2ATI40TY:B09>CT`2@T900SHf=
00@0Rh^;00T0RXZ:08V9R@25QHD0Ph>308J6QP21PH40NWYj08>3P`2CTi<00P2OWil02`2XZ:P0/[:b
0;^k^`2k^k/0`/;20<G5a@36a/H0aLG50<K6aP34a<@0`/;20080`L7100X0`<300<;2`P31`L40`L71
0<?3``34a<@0aLG50<C4a032`/80`l?30`32`/801`34a<@0`/;20<K6aP37alL0bLW90<O7a`39bLT0
0P3:b/X20<c<c0050<_;b`3=cLd0c/k>0<[:bP3<c<`03P38h=P000`0b>3H0P1DE5@00`1ADE40CDe=
051@D002059BDP0804e=C@1?Cdl0CDe=04e=C@17AdL0Bd];04e=C@1@D50204Q8B00604e=C@1:BTX0
ADE504A4A012@T80Bd];0P0h>3P03@0n?Sh0ADE504M7A`1IFET0Jf][07YjNP1oOgl0QhN7092@T02G
UiL0Vi^K0:2PX02VYZH00P2YZJT03P2_[jl0/[:b0;6a/@2a/K40[jn_0;:b/P2d];@0/k>c0;Ng]`2e
]KD0/k>c0;Bd]02f][H0]KFe0P2`/;009`2[Zj/0YjNW0:2PX02GUiL0TY:B096AT@29RHT0QXJ607Mg
M`1WIfL0GUiN05MGE`1=CDd0Cdm?04e=C@1JFUX0FEUI05]KF`1PH600GEeM06ATI01SHf<0HV9R06i^
KP1YJFT0IVIV06m_K`1^KVh0K6a/06i^KP1gMgL0M7Ad07alO024Q8@0OGem06i^KP1>CTh0GEeM05]K
F`0204Q8B00P059BDP1EEED0Bd];05iNGP1VIVH0Hf=S04e=C@10@400FUYJ05eMG@1@D500CDe=03@d
=00b<S80?3`l04E5A@1EEED0GemO075aL@1fMWH0F5QH03`l?00a<C40?3`l04=3@`1[Jf/0SXj>096A
T@1^KVh0GUiN069RHP1YJFT20451@@0C04E5A@0o?cl0AdM706a/K00b<S80>SXj03Ph>00a<C40;Bd]
02XZ:P0];Bd0:RXZ02h^;P0j>SX0=SHf038b<P0a<C40<S8b034a<@02038b<P0503Ph>00];Bd0;2`/
03@d=010@4000P0a<C40=@0i>CT0>SXj030`<01DE5@0DU9B03Hf=P0Y:BT08b<S020P800O7al0:BTY
05IFEP1]KFd0Jf][08j>SP26QXH0Ph>307moO`2GUiL0Ph>304=3@`0a<C40<c<c02`/;00X:2P09bLW
02TY:@0Z:RX0:BTY02DU9@0X:2P0<C4a02DU9@0Z:RX0820P01dM7@0R8R80>SXj07IfMP2DU9@0Ti>C
071`L01dM7@0N7Qh07EeM@2OWil0c<c<0;jn_P2i^KT0`/;20<30`02l_;`0^k^k0080b/[:0200T92@
03De=@0e=CD08b<S02DU9@0/;2`0:b/[02h^;P0g=cL0ADE504e=C@1IFET0HF5Q06MWI`1eMGD0Lg=c
07UiN@1eMGD0O7al07emO@1nOWh0Ph>308:2PP1jNWX0Q8B40861P@26QXH0Q8B408F5Q@29RHT0R8R8
09:BTP80UYJF00@0UIFE09>CT`2GUiL0VYZJ0P2NWYh02`2UYJD0YjNW0:RXZ02ZZZX0[Jf]0:b/[02b
/[80[Jf]0;6a/@2`/;00/K6a0080];Bd00P0]kNg0;jn_P2i^KT0]KFe0:n_[`2][Jd0[Zj^0:RXZ080
Zj^[00`0ZJVY0:^[Z`2XZ:P0[jn_0:RXZ02QXJ40WinO0:2PX02JVYX0Vi^K09bLW02HV9P209>CT`0:
09JFUP2@T900UIFE09:BTP2<S8`0SHf=08b<S02:RXX0Q8B408J6QP80QHF503P0Ng]k0820P021PH40
QHF508B4Q029RHT0QXJ608n?S`2EUID0Y:BT0;:b/P31`L40c<c<0=[JfP3MgMd0g]kN0=_Kf`3GemL0
bl_;0;Bd]02b/[80Z:RX0:FUY@2TY:@0YJFU0:BTY02RXZ80WinO09^KV`2IVIT0V9RH09NGU`2CTi<0
S8b<08j>SP29RHT0QXJ608R8R024Q8@0Ogmo0820P021PH40PX:207moO`1mOGd0M7Ad06MWI`1PH600
C4a<03/k>`0i>CT0?3`l03Lg=`0/;2`0=3@d0410@080=3@d00H0<S8b03Xj>P16ATH0GEeM04Q8B00c
<c<202LW9`0C02<S8`0_;bl0BTY:08J6QP2PX:00[Zj^0::RXP1nOWh0SXj>0:BTY02GUiL0EeMG02TY
:@0`<300:2PX02/[:`0Z:RX0:2PX03@d=00204e=C@0D03Xj>P0c<c<0=SHf03Hf=P0c<c<0:b/[02h^
;P0[:b/0@T9205YJFP1dM7@0Q8B408J6QP2=SHd0RXZ:08^;R`26QXH0S8b<096AT@2GUiL20:6QX@0>
0::RXP2OWil0WinO09fMW@2IVIT0Vi^K09RHV02GUiL0UYJF09NGU`2KVi/0V9RH09^KV`2GUiL209VI
V@0609ZJVP2HV9P0UYJF09JFUP2CTi<0TY:B0P2GUiL04`2JVYX0UYJF09FEU@2IVIT0TY:B09BDU02B
TY80Ti>C09FEU@2CTi<0UiNG09BDU02ATI40UIFE09JFUP2DU9@0T92@09:BTP2EUID00P2?Shl209:B
TP80T92@00d0SXj>08n?S`2BTY80SHf=08V9R@2;Rh/0RHV908R8R020P800PH6107alO024Q8@0QXJ6
0080V9RH00H0Y:BT0:^[Z`2e]KD0^k^k0;fm_@30`<020<C4a0050<;2`P34a<@0`/;20<30`032`/80
0P31`L400`30`<00`L710<?3``040<?3``0>0<;2`P33`l<0a<C40<C4a035aLD0`l?30<71`@33`l<0
alO70<K6aP35aLD0alO70<c<c03;bl/20<W9b@040<_;b`39bLT0c<c<0<_;b`h0b>3H000<0<SPf080
E5AD00<0DE5A04e=C@1@D5000P1BDU80201=CDd0Cdm?04e=C@1=CDd0AdM704];B`1=CDd0D51@0P18
B4P01P1=CDd0BTY:04E5A@14A4@0@T9204];B`80>3Ph00d0?Shn04E5A@17AdL0FEUI06][J`1jNWX0
Ogmo08N7Q`2@T900UiNG09^KV`2PX:00YZJV0080ZJVY00h0[jn_0;:b/P2a/K40/K6a0:n_[`2b/[80
];Bd0;>c/`2g]kL0]KFe0;>c/`2d];@0][Jf0;Fe]@80/;2`02L0Zj^[0:NWY`2PX:00UiNG09:BTP2A
TI40RHV908J6QP1gMgL0IfMW05iNGP1GEeL0CDe=04m?C`1=CDd0FUYJ05UIF@1KFe/0H61P05eMG@1T
I6@0Hf=S069RHP1^KVh0JFUY06IVIP1_Kfl0KVi^06a/K01^KVh0MgMg07AdM01lO7`0Q8B407emO@1^
KVh0CTi>05eMG@1KFe/00P18B4P0801BDU80EEEE04];B`1NGUh0IVIV06=SH`1=CDd0@41005YJFP1M
GEd0D51@04e=C@0d=3@0<S8b03`l?015ADD0EEEE05mOG`1aLG40MWIf05QHF00l?3`0<C4a03`l?013
@d<0Jf][08j>SP2ATI40KVi^05iNGP1RHV80JFUY0P11@D404`15ADD0?clo04M7A`1/K6`0<S8b03Xj
>P0h>3P0<C4a02d];@0Z:RX0;Bd]02XZ:P0^;Rh0>SXj03Hf=P0b<S80<C4a038b<P0a<C400P0b<S80
1@0h>3P0;Bd]02`/;00d=3@0@4100080<C4a03D0>CTi03Xj>P0`<300E5AD059BDP0f=SH0:BTY02<S
8`0P82007alO02TY:@1FEUH0KFe]06][J`2>SXh0QXJ608>3P`1oOgl0UiNG08>3P`13@d<0<C4a03<c
<`0/;2`0:2PX02LW9`0Y:BT0:RXZ02TY:@0U9BD0:2PX034a<@0U9BD0:RXZ020P800M7Ad08R8R03Xj
>P1fMWH0U9BD09>CT`1`L700M7Ad07QhN01eMGD0WinO0<c<c02n_[h0^KVi0<;2`P30`<00_;bl0;^k
^`020<[:bP0P092@T00e=CD0=CDe02<S8`0U9BD0;2`/02/[:`0^;Rh0=cLg04E5A@1=CDd0FEUI065Q
H@1WIfL0MGEe07=cL`1iNGT0MGEe07alO01mOGd0OWin08>3P`22PX80NWYj08B4Q021PH40QXJ608B4
Q025QHD0RHV908R8R02BTY8209JFUP0409FEU@2CTi<0UiNG09ZJVP80WYjN00/0YJFU0:NWY`2XZ:P0
ZZZZ0:f][@2/[:`0/[:b0:f][@2a/K40/;2`0;6a/@020;Bd]0080;Ng]`2n_[h0^KVi0;Fe]@2_[jl0
[Jf]0:j^[P2XZ:P20:^[Z`0<0:VYZ@2[Zj/0Z:RX0:n_[`2XZ:P0XJ6Q09nOW`2PX:00VYZJ09^KV`2L
W9`0V9RH0P2CTi<02P2FUYH0T92@09FEU@2BTY80S8b<08f=S@2<S8`0RXZ:08B4Q026QXH208F5Q@0h
07]kN`20P800PH6108F5Q@24Q8@0RHV908J6QP2?Shl0UIFE0:BTY02b/[80`L710<c<c03Jf]X0gMgM
0=kNgP3Kfm/0emOG0<_;b`2d];@0/[:b0:RXZ02UYJD0Y:BT0:FUY@2TY:@0XZ:R09nOW`2KVi/0VIVI
09RHV02GUiL0Ti>C08b<S02>SXh0RHV908J6QP28R8P0Q8B407moO`20P800PH6108:2PP1oOgl0OGem
07AdM01WIfL0H61P04a<C00k>c/0>CTi03`l?00g=cL0;2`/03@d=010@40203@d=006038b<P0j>SX0
ATI605eMG@18B4P0<c<c0P0W9bL04`0S8b<0;bl_04Y:BP26QXH0X:2P0:j^[P2RXZ80OWin08j>SP2T
Y:@0UiNG05MGE`0Y:BT0<30`02PX:00[:b/0:RXZ02PX:00d=3@00P1=CDd0500j>SX0<c<c03Hf=P0f
=SH0<c<c02/[:`0^;Rh0:b/[0492@P1JFUX0M7Ad08B4Q026QXH0SHf=08Z:RP2;Rh/0QXJ608b<S02A
TI40UiNG0P2QXJ403P2RXZ80WinO09nOW`2MWId0VIVI09^KV`2HV9P0UiNG09JFUP2GUiL0Vi^K09RH
V02KVi/0UiNG0P2IVIT01P2JVYX0V9RH09JFUP2FUYH0Ti>C09:BTP80UiNG01<0VYZJ09JFUP2EUID0
VIVI09:BTP2DU9@0TY:B09>CT`2EUID0Ti>C09NGU`2DU9@0TI6A09FEU@2FUYH0U9BD092@T02BTY80
UIFE0080Shn?0P2BTY82092@T00=08j>SP2?Shl0TY:B08f=S@29RHT0Rh^;08V9R@28R8P0P8200861
P@1lO7`0Q8B408J6QP0209RHV0060:BTY02[Zj/0]KFe0;^k^`2m_Kd0`<300P34a<@01@32`/80a<C4
0<;2`P30`<00`/;20080`L7100<0`<300<71`@33`l<01033`l<03P32`/80`l?30<C4a034a<@0aLG5
0<?3``31`L40`l?30<O7a`36a/H0aLG50<O7a`3<c<`0bl_;0P39bLT0103;bl/0bLW90<c<c03;bl/>
0<SPf0003038h=P205MGE`0W05IFEP1?Cdl0E5AD04Y:BP1?Cdl0C4a<04i>CP1DE5@0BDU904Y:BP1=
CDd0D51@04m?C`1<C4`0BTY:04];B`1:BTX0B4Q80492@P10@400?3`l03Xj>P0k>c/0=CDe03hn?P14
A4@0F5QH06a/K01kNg/0Ph>308Z:RP2ATI40Vi^K09fMW@2RXZ80YJFU0:VYZ@2][Jd0[jn_00<0/K6a
00D0];Bd0;6a/@2c/k<0/[:b0;Bd]0020;Fe]@80/k>c01@0];Bd0;6a/@2a/K40[:b/0:NWY`2RXZ80
UYJF09BDU02BTY80RHV907emO@1_Kfl0IfMW065QH@1HF5P0BTY:04];B`1@D500DU9B05]KF`80G5aL
03H0GUiN065QH@1YJFT0JFUY06i^KP1VIVH0IFEU06a/K01]KFd0Kfm_071`L01aLG40L71`07alO020
P800Ph>307QhN01LG5`0FUYJ05eMG@1>CTh0B4Q805]KF`1RHV80FEUI05EEE@1IFET0J6QX05mOG`1:
BTX0DE5A03dm?@18B4P0Cdm?03Lg=`0d=3@0=cLg0492@P19BDT0EEEE065QH@1`L700Lg=c05UIF@0f
=SH0?3`l04M7A`1EEED0Ph>308J6QP25QHD0Ph>306e]K@1RHV8403Ti>@0704e=C@1YJFT0=cLg034a
<@0f=SH0=CDe02h^;P02030`<00402/[:`0`<300<30`030`<080;Bd]0200:BTY02d];@0i>CT0=cLg
03De=@0[:b/0=CDe02d];@18B4P0=SHf055AD@1HF5P0>c/k03Ph>01IFET0BTY:03De=@0[:b/092@T
01lO7`0W9bL0;2`/05]KF`1VIVH0KVi^09FEU@2?Shl0R8R806YZJP1kNg/0N7Qh05ADE080;bl_0240
>3Ph03<c<`0e=CD092@T02XZ:P0/;2`0:RXZ02TY:@0b<S80:b/[02LW9`0X:2P08R8R02@T900c<c<0
GemO092@T02TY:@0Ph>307=cL`1gMgL0LW9b08J6QP2o_kl0c<c<0;6a/@2n_[h0`L710;no_`2j^[X0
`L710=7Ad@31`L400P1RHV802`0X:2P09bLW02PX:00/;2`0<30`03@d=014A4@0B4Q805EEE@1OGel0
J6QX0080M7Ad0P1iNGT03P1hN7P0O7al0820P020P800Ogmo07UiN@20P800Ph>308J6QP2:RXX0S8b<
08j>SP2=SHd0TY:B0`2HV9P01`2GUiL0Vi^K09RHV02LW9`0X:2P0:6QX@2VYZH00P2][Jd02@2`/;00
[Zj^0:j^[P2c/k<0]KFe0;>c/`2^[Zh0][Jf0;>c/`020;Zj^P040;Jf]P2d];@0[Jf]0;>c/`80Zj^[
00X0[:b/0;2`/02][Jd0[:b/0:RXZ02`/;00YZJV0:BTY02UYJD0WIfM0P2OWil01`2HV9P0UYJF09>C
T`2DU9@0UIFE096AT@2DU9@00P2EUID01@2<S8`0SXj>08b<S02:RXX0QHF50080QhN700h0PH6107in
OP21PH40Ph>308B4Q023Ph<0RHV909NGU`2HV9P0XJ6Q0;2`/036a/H0clo?0=_Kf`80gmoO00P0g=cL
0=CDe039bLT0^KVi0:f][@2ZZZX0YZJV0:6QX@80XZ:R01h0WYjN09nOW`2QXJ40V9RH09JFUP2EUID0
Ti>C092@T02:RXX0QHF508N7Q`25QHD0Ph>308B4Q01oOgl0PX:20820P01hN7P0OGem075aL@1^KVh0
HV9R059BDP10@400>c/k03hn?P0j>SX0:BTY030`<00n?Sh203@d=00K03De=@0j>SX0AdM705mOG`1=
CDd0=SHf02d];@0Z:RX09bLW02h^;P1<C4`0QXJ60::RXP2/[:`0YJFU07alO02BTY80Z:RX09:BTP1C
De<0:2PX02l_;`0S8b<09RHV02`/;00Z:RX0<30`0080Bd];01L0=SHf03De=@0g=cL0<C4a02h^;P0a
<C40;Rh^02/[:`0h>3P0F5QH06i^KP22PX80RXZ:09>CT`2>SXh0S8b<08J6QP27QhL0SHf=09RHV02Q
XJ40X:2P0:6QX@020::RXP0609nOW`2HV9P0Vi^K09^KV`2HV9P0UiNG0P2IVIT01@2MWId0VYZJ09bL
W02KVi/0UYJF0080V9RH00P0UIFE09NGU`2GUiL0Ti>C09RHV02BTY80V9RH09:BTP<0UYJF00H0TY:B
09>CT`2BTY80TI6A09:BTP2EUID209BDU00E09>CT`2EUID0U9BD092@T02>SXh0U9BD092@T02EUID0
VYZJ09>CT`2ATI40T92@096AT@2?Shl0T92@08j>SP28R8P0QhN708F5Q@27QhL0RHV90080P82000h0
Q8B408:2PP2BTY80TY:B09jNWP2WYjL0/k>c0;Bd]02i^KT0_[jn0<;2`P34a<@0`<300<;2`P80`L71
1032`/801P31`L40`/;20<71`@33`l<0aLG50<;2`P80`L7100L0`/;20<C4a031`L40`L710<30`02o
_kl0`l?30080a/K600H0aLG50<S8b03:b/X0bLW90<S8b039bLT30<_;b`h0b>3H000<0<SPf080D51@
00<0EUIF051@D01>CTh00P1DE5@01P1ADE40C4a<051@D01;Bd/0C4a<04m?C`80DE5A01P0D51@04];
B`19BDT0BDU904=3@`16ATH0?clo03`l?00i>CT0?Cdm03Ti>@0n?Sh0Bd];05YJFP1[Jf/0NGUi08:2
PP2<S8`0Ti>C09FEU@2LW9`0Y:BT0:RXZ02[Zj/20;2`/0040;:b/P2_[jl0[jn_0;6a/@80/k>c00P0
/[:b0;>c/`2f][H0^k^k0;Fe]@2a/K40^;Rh0:n_[`80/;2`0180YjNW0:BTY02MWId0UIFE092@T027
QhL0OWin07AdM01/K6`0GemO05YJFP1?Cdl0BDU904i>CP1CDe<0EeMG05IFEP1GEeL2061PH00d06AT
I01/K6`0Jf][07MgM`1^KVh0KFe]06m_K`1`L700Lg=c079bLP1eMGD0P82008>3P`24Q8@0NGUi06MW
I`1YJFT0IVIV06YZJP1MGEd0JFUY061PH01OGel0EUIF05EEE@1DE5@0FUYJ05]KF`1MGEd0?clo03Xj
>P12@T80A4A403De=@0_;bl0>SXj03dm?@13@d<0C4a<069RHP1_Kfl0L71`03dm?@0g=cL0BTY:055A
D@1bLW80OGem07alO02ATI40SHf=07IfMP80CTi>00`0B4Q803`l?01HF5P0EeMG02l_;`0`<300<c<c
03lo?`0d=3@0;bl_02d];@0a<C4202l_;`1602/[:`0_;bl0;Bd]02h^;P0c<c<0<30`03De=@0i>CT0
:BTY02XZ:P0];Bd0?clo05QHF01PH600?Shn02/[:`11@D40GUiN0410@00];Bd09RHV02LW9`0R8R80
92@T02l_;`1OGel0HV9R06a/K02<S8`0SHf=07emO@1[Jf/0FUYJ06IVIP1OGel0=cLg030`<00[:b/0
8b<S02TY:@0[:b/0;bl_02`/;00W9bL09RHV038b<P0c<c<0<30`02HV9P0Q8B40:RXZ02`/;00l?3`0
N7Qh09NGU`2DU9@0MWIf06e]K@1mOGd0MWIf0:BTY03=cLd0/k>c0;Jf]P2o_kl0^k^k0;bl_02m_Kd0
b/[:0=7Ad@80[jn_01<0@T9202TY:@0W9bL0;Bd]03Ti>@0f=SH0=cLg04M7A`1GEeL0HF5Q06UYJ@1]
KFd0MGEe07QhN01jNWX0N7Qh07alO01jNWX0Ng]k0080NWYj0P23Ph<01P26QXH0RXZ:08n?S`2ATI40
Shn?096AT@80V9RH00T0VIVI09RHV02MWId0W9bL09jNWP2RXZ80YZJV0:RXZ02_[jl00P2^[Zh01@2]
[Jd0/K6a0;6a/@2d];@0/k>c0080];Bd01P0/[:b0;Bd]02b/[80/;2`0:n_[`2/[:`0][Jf0:f][@2_
[jl0/;2`0;>c/`2^[Zh0/;2`0:ZZZP2/[:`0[Zj^0:NWY`2VYZH0XZ:R09nOW`2MWId0VYZJ09RHV02B
TY8209VIV@0509:BTP2ATI40UIFE09BDU02?Shl00P2<S8`0=`2:RXX0Q8B408V9R@29RHT0Ph>30861
P@1lO7`0PH6108B4Q022PX80RXZ:09>CT`2LW9`0Xj>S0;>c/`35aLD0d];B0=kNgP3Ogml0h>3P0=[J
fP3Cdm<0b<S80;Ng]`2`/;00ZJVY0:JVYP2QXJ40XZ:R0:6QX@2RXZ80Vi^K09jNWP2LW9`0TY:B09>C
T`2=SHd0SXj>08b<S027QhL0QXJ608N7Q`24Q8@0Ph>307alO023Ph<0OWin07moO`20P800MGEe071`
L01RHV80De=C03`l?00c<c<00P0i>CT06`0^;Rh0<30`03Xj>P0k>c/0=cLg038b<P0h>3P0B4Q805IF
EP1ADE40=SHf03@d=00Z:RX0:BTY02d];@1ADE40SXj>0:JVYP2][Jd0Y:BT0861P@2CTi<0X:2P07in
OP12@T80:b/[03Hf=P02028R8P0302XZ:P0[:b/0;bl_0080?Cdm01L0<c<c02l_;`0d=3@0<c<c02h^
;P0Y:BT0<S8b02`/;00`<300CTi>06YZJP1kNg/0SXj>08n?S`2=SHd0RXZ:09>CT`24Q8@0RXZ:096A
T@2IVIT0XJ6Q09nOW`020:2PX080Vi^K00D0W9bL09ZJVP2IVIT0V9RH09bLW00209^KV`0;09bLW02K
Vi/0V9RH09FEU@2KVi/0U9BD09NGU`2HV9P0UYJF09VIV@2GUiL00`2EUID01`2IVIT0T92@09JFUP2J
VYX0UYJF09BDU02FUYH00P2EUID02@2BTY80T92@09>CT`2EUID0U9BD096AT@2@T900U9BD08n?S`02
09:BTP07096AT@2<S8`0T92@08n?S`2<S8`0T92@08Z:RP0208b<S00708J6QP27QhL0QhN708:2PP25
QHD0P82008:2PP0208N7Q`06096AT@2SXj<0Zj^[0;2`/02i^KT0_Kfm0P31`L404033`l<0a<C40<?3
``30`<00`l?30<;2`P31`L40`l?30<;2`P33`l<0a<C40<?3``31`L40`l?30<71`@2o_kl30<71`@08
0<?3``31`L40`l?30<30`033`l<0`/;20<C4a033`l<30<K6aP040<S8b03;bl/0b/[:0<W9b@h0b>3H
000<0<SPf080E5AD00T0EEEE05QHF01CDe<0FUYJ05MGE`1ADE40D51@04m?C`1BDU800P1?Cdl0101E
EED0Cdm?04e=C@1:BTX204M7A`0G04A4A013@d<0B4Q803lo?`0l?3`0=SHf03Ti>@0o?cl0CDe=05eM
G@1[Jf/0NWYj0861P@2=SHd0U9BD09NGU`2KVi/0XZ:R0:JVYP2ZZZX0[:b/0:j^[P2c/k<00P2d];@2
0;6a/@070;Fe]@2c/k<0[jn_0;Bd]02f][H0^KVi0;Rh^0020;Bd]00B0:f][@2YZJT0YZJV0:6QX@2J
VYX0VIVI092@T025QHD0Ogmo07EeM@1TI6@0FEUI05MGE`1?Cdl0DU9B051@D01BDU80EeMG0P1LG5`0
3@1NGUh0HV9R06UYJ@1[Jf/0NGUi08B4Q023Ph<0N7Qh07AdM01eMGD0LG5a06YZJP1fMWH00P1oOgl0
9`20P800Ng]k07EeM@22PX80P82007=cL`1LG5`0GemO05MGE`1<C4`0ADE504];B`1?Cdl0BTY:04i>
CP1JFUX0Bd];03Xj>P0l?3`0?Cdm0451@@0i>CT0=SHf03lo?`0j>SX0B4Q8055AD@1CDe<0KVi^05IF
EP0l?3`0ATI6061PH01XJ6P0Ph>306QXJ01hN7P0TI6A08V9R@0207IfMP0507]kN`1cLg<0J6QX0410
@00c<c<00P0];Bd05@0i>CT0=3@d02h^;P0^;Rh0<C4a030`<00a<C40:RXZ02h^;P0_;bl0;Bd]034a
<@0_;bl0<S8b03Lg=`0a<C40>3Ph03Xj>P1NGUh0HF5Q03/k>`0202`/;00D04Q8B01MGEd0D51@034a
<@0X:2P07QhN01lO7`0V9RH0=CDe05IFEP1SHf<0MgMg08n?S`2<S8`0O7al06m_K`1JFUX0ATI6051@
D00j>SX202h^;P0D02HV9P0b<S80:RXZ030`<00b<S80:RXZ02d];@0^;Rh0;bl_02TY:@0W9bL09RHV
02PX:00Z:RX0<S8b05aLG028R8P0Vi^K07moO`1YJFT207UiN@0:08>3P`2b/[80^;Rh0:b/[02k^k/0
_Kfm0<30`02n_[h0b<S80=7Ad@80cLg=0100V9RH03De=@0T92@09RHV02l_;`0b<S80>c/k0451@@1D
E5@0HF5Q06EUI@1^KVh0LW9b07YjNP1gMgL0Ng]k0P1lO7`03@1oOgl0OGem07alO026QXH0PH6108N7
Q`29RHT0Rh^;08n?S`2CTi<0SXj>09FEU@2FUYH00P2KVi/209bLW0060:FUY@2TY:@0YjNW0:RXZ02/
[:`0ZZZZ0P2/[:`0102a/K40/k>c0;Bd]02d];@20;>c/`030;2`/02][Jd0/;2`00<0[Zj^00h0/k>c
0;2`/02][Jd0[Jf]0;:b/P2c/k<0/K6a0:^[Z`2ZZZX0ZJVY0:FUY@2RXZ80XJ6Q09jNWP<0Vi^K00L0
VYZJ092@T02BTY80TI6A092@T02>SXh0TY:B0080Rh^;00<0R8R808B4Q024Q8@00P20P8007`21PH40
Q8B407moO`1oOgl0P82008:2PP2<S8`0TY:B09nOW`2UYJD0^KVi0<G5a@3Bd]80f][J0=cLg03Ng]h0
fm_K0=3@d037alL0^KVi0;:b/P2YZJT0YJFU0:>SX`2WYjL0X:2P09nOW`2SXj<0WIfM09VIV@2FUYH0
0P2@T900102=SHd0R8R808B4Q026QXH30861P@80Ogmo02/0PH6107emO@1lO7`0NGUi06][J`1ZJVX0
EUIF03`l?00d=3@0=SHf03Ph>00`<300;bl_03De=@12@T80?clo03Hf=P0d=3@0DE5A04a<C01DE5@0
=3@d02/[:`0Y:BT0:2PX02`/;01MGEd0UIFE0:JVYP2][Jd0X:2P08f=S@2PX:00XJ6Q07QhN00m?Cd0
;bl_034a<@0W9bL09RHV02@T900X:2P0;Rh^0080<c<c00D0:RXZ02l_;`0i>CT0>3Ph02l_;`0302XZ
:P0=02h^;P14A4@0Hf=S07AdM029RHT0Rh^;08b<S028R8P0Rh^;08N7Q`2:RXX0SXj>09JFUP0309nO
W`060:2PX02NWYh0VYZJ0:2PX02LW9`0WIfM0P2IVIT01@2KVi/0XJ6Q09NGU`2LW9`0VYZJ0080V9RH
00P0UiNG09RHV02KVi/0V9RH09JFUP2OWil0UYJF09BDU080UIFE0140U9BD09FEU@2IVIT0UIFE09NG
U`2DU9@0UYJF09BDU02@T900TI6A09:BTP2EUID0U9BD08n?S`2@T900U9BD09>CT`02096AT@0@09BD
U02=SHd0Shn?092@T02ATI40T92@08f=S@2>SXh0SHf=08^;R`27QhL0QXJ608N7Q`20P800PX:208N7
Q`80QXJ600L0RHV909JFUP2QXJ40[:b/0;>c/`2k^k/0_Kfm0080`L710`32`/801`35aLD0`<300<;2
`P33`l<0`/;20<G5a@36a/H01033`l<01`34a<@0`/;20<71`@30`<00`L710;no_`2n_[h00P30`<00
0`31`L40`/;20<C4a0020<C4a080a/K600<0b<S80<[:bP38b<P03P38h=P000`0b>3H0P1IFET05P1D
E5@0De=C05UIF@1OGel0F5QH05ADE01ADE40D51@04a<C01>CTh0DE5A05iNGP1=CDd0C4a<04e=C@1?
Cdl0B4Q804M7A`19BDT0@d=303lo?`0i>CT203/k>`0<04=3@`1?Cdl0G5aL06][J`1iNGT0PX:208n?
S`2DU9@0UYJF09bLW02SXj<0Z:RX0P2/[:`0202_[jl0/;2`0:f][@2][Jd0];Bd0:n_[`2e]KD0/K6a
0P2c/k<06`2b/[80]kNg0;Ng]`2i^KT0];Bd0;Fe]@2/[:`0YjNW0:>SX`2OWil0V9RH09BDU02;Rh/0
Ogmo079bLP1VIVH0FUYJ05IFEP1<C4`0Cdm?04Y:BP1DE5@0DE5A05IFEP1IFET0FUYJ05eMG@0206MW
I`0b07EeM@22PX80RHV908b<S028R8P0Q8B40820P01iNGT0MGEe07]kN`1mOGd0Ph>308:2PP1lO7`0
OWin0861P@1eMGD0H61P05ADE017AdL0>3Ph03Hf=P0b<S80@T9205aLG01KFe/0Cdm?04a<C00n?Sh0
@T9203lo?`11@D40?Cdm03Ti>@19BDT0?Cdm03@d=00o?cl0B4Q805IFEP1TI6@0F5QH04I6AP1CDe<0
GEeM07IfMP1gMgL0Hf=S06m_K`2<S8`208J6QP0407inOP2?Shl0MGEe03Xj>P80=CDe01H0<30`03Hf
=P0f=SH0=SHf034a<@0Z:RX0;bl_034a<@0c<c<0;Rh^03De=@0/;2`0:2PX030`<00];Bd0<S8b03@d
=016ATH0GUiN05MGE`11@D40=SHf0P0o?cl0101CDe<0JVYZ04e=C@0_;bl202@T900K02PX:00a<C40
<S8b04E5A@1QHF40PH61096AT@2<S8`0Ogmo07AdM01WIfL0ATI603Lg=`0h>3P0:BTY02h^;P0_;bl0
<S8b02h^;P0];Bd0:b/[02`/;00];Bd0;bl_02XZ:P0_;bl0<c<c0080:BTY00H0:RXZ030`<00j>SX0
K6a/09BDU02GUiL207=cL`0607QhN01eMGD0T92@0;bl_02XZ:P0][Jf0P31`L420<?3``0E0<g=c@3B
d]80d];B0<W9b@1lO7`0;Bd]024Q8@0X:2P0;Bd]03Ph>017AdL0EEEE061PH01RHV80K6a/06m_K`1g
MgL0O7al07]kN`1jNWX0OWin0080P82000H0Ogmo08N7Q`21PH40RXZ:08R8R02>SXh209BDU004096A
T@2CTi<0UiNG09NGU`<0WIfM0P2UYJD20:NWY`0?0:ZZZP2^[Zh0[Jf]0:b/[02`/;00/K6a0;>c/`2`
/;00]KFe0:n_[`2`/;00];Bd0;:b/P2g]kL0];Bd0080[Zj^00D0[jn_0;Bd]02c/k<0/;2`0;>c/`02
0;:b/P040:f][@2ZZZX0Z:RX0:JVYP80XJ6Q00D0VYZJ09fMW@2IVIT0VYZJ092@T00209:BTP0809BD
U02@T900U9BD08Z:RP2=SHd0RXZ:0861P@25QHD208N7Q`0J08F5Q@23Ph<0PX:208:2PP1kNg/0Ogmo
08V9R@2@T900X:2P0:JVYP2k^k/0bl_;0=7Ad@3GemL0gMgM0=_Kf`3EeMD0d=3@0<O7a`2g]kL0/K6a
0:^[Z`2WYjL0Xj>S0:FUY@2SXj<20::RXP0U09NGU`2HV9P0U9BD096AT@28R8P0RXZ:08J6QP27QhL0
QXJ608B4Q01nOWh0Ph>308:2PP1nOWh0P82007QhN01kNg/0NWYj07AdM01YJFT0FUYJ04I6AP0i>CT0
@4100451@@0a<C40;Bd]02l_;`12@T80?3`l03Hf=P0d=3@0Cdm?0492@P1GEeL0>c/k03@d=00202/[
:`0B034a<@1MGEd0UYJF0::RXP2][Jd0YJFU09BDU02UYJD0VYZJ06][J`0b<S80>SXj038b<P0[:b/0
:RXZ02h^;P0/;2`0=SHf0`0Y:BT0100b<S80<c<c030`<00c<c<202XZ:P0702`/;00[:b/0A4A405YJ
FP1eMGD0Ph>308R8R00208b<S00708^;R`27QhL0Ph>308^;R`2DU9@0VIVI09jNWP020:2PX00=09fM
W@2LW9`0WYjN09^KV`2NWYh0W9bL09fMW@2IVIT0W9bL09RHV02LW9`0WinO09VIV@0209RHV00809JF
UP2LW9`0VIVI09NGU`2IVIT0UiNG09JFUP2IVIT209JFUP0<09^KV`2DU9@0UYJF09FEU@2DU9@0Ti>C
09JFUP2KVi/0UIFE096AT@2CTi<0TY:B0P2ATI401`2?Shl0UIFE09BDU02?Shl0SXj>092@T02>SXh0
0P2CTi<02`2BTY80T92@08^;R`2<S8`0Rh^;08F5Q@27QhL0Rh^;08B4Q022PX80Ph>30080Q8B400`0
R8R808b<S02LW9`0Z:RX0;6a/@2g]kL0^[Zj0;bl_032`/80`L710<;2`P33`l<20<C4a0030<G5a@34
a<@0`l?30080a<C400D0aLG50<;2`P33`l<0`l?30<G5a@030<71`@060<30`02o_kl0`<300;no_`2n
_[h0`/;20P30`<001@33`l<0`/;20<O7a`34a<@0b/[:0080bLW93P38h=P000`0b>3H0P1GEeL04`1F
EUH0F5QH05YJFP1HF5P0EeMG05EEE@1GEeL0De=C051@D01EEED0C4a<04e=C@1CDe<0Cdm?04e=C@1>
CTh0Bd];04Q8B01:BTX00P0o?cl04P0k>c/0=CDe03Hf=P10@400CDe=065QH@1dM7@0Ng]k07inOP29
RHT0TY:B09>CT`2LW9`0Xj>S0:6QX@2/[:`0Zj^[0:j^[P<0/[:b00D0/;2`0;:b/P2e]KD0][Jf0;Bd
]0020;Jf]P0G0;>c/`2f][H0];Bd0;Bd]02c/k<0[Zj^0:BTY02RXZ80WIfM09BDU02>SXh0RHV90820
P01eMGD0J6QX05]KF`1@D500BTY:04i>CP1?Cdl0CTi>059BDP1DE5@00P1IFET0=@1KFe/0HF5Q06QX
J01[Jf/0J6QX07EeM@23Ph<0SHf=09JFUP2NWYh0VIVI08V9R@27QhL0TI6A08j>SP20P800NWYj0861
P@2:RXX0P8200861P@1nOWh0L71`04=3@`0`<300=CDe02h^;P0l?3`0DE5A05=CD`1DE5@0?Shn03Hf
=P0e=CD0?3`l03lo?`13@d<0@41004A4A00h>3P0>SXj0451@@15ADD0DU9B06QXJ01NGUh0DU9B04m?
C`1LG5`0PH6105]KF`1ADE40KFe]0080SXj>00H0OWin08>3P`20P800G5aL04M7A`0l?3`203@d=00/
03De=@0i>CT0=CDe02h^;P0];Bd0:2PX02/[:`0Y:BT0;Rh^02XZ:P0`<300;Rh^034a<@0f=SH0?3`l
051@D01?Cdl0?clo04];B`1ZJVX0MGEe07=cL`29RHT0T92@06i^KP1<C4`09bLW02@T900R8R80:2PX
02TY:@0i>CT0Hf=S08J6QP2CTi<0S8b<07emO@1eMGD0JVYZ05IFEP0n?Sh0=CDe02l_;`0];Bd302h^
;P0E02l_;`0];Bd0;Rh^030`<00^;Rh0;Bd]02h^;P0_;bl0<C4a030`<00[:b/0;2`/03Hf=P1CDe<0
RHV90:ZZZP20P800Lg=c079bLP1dM7@0OGem0080]KFe00<0/k>c0;bl_030`<000P33`l<0>036a/H0
clo?0<o?c`3?cll0_Kfm05QHF00Y:BT092@T02h^;P0d=3@0A4A404e=C@1GEeL0GemO06UYJ@1_Kfl0
MgMg07EeM@1gMgL0NGUi07alO01mOGd0OWin08J6QP22PX80Ph>308f=S@29RHT0SHf=09BDU02CTi<0
UiNG09RHV02GUiL0V9RH09ZJVP2NWYh0XJ6Q0::RXP2SXj<0YjNW0:VYZ@2[Zj/0[Zj^0:f][@2[Zj/0
[Zj^0;>c/`2b/[80];Bd0;2`/02/[:`0ZZZZ0;Bd]02c/k<0/;2`0P2a/K404P2b/[80/K6a0;2`/02]
[Jd0[Zj^0;:b/P2_[jl0/[:b0:n_[`2][Jd0ZZZZ0:VYZ@2WYjL0Y:BT09^KV`2LW9`0U9BD09>CT`80
U9BD00T0V9RH09FEU@2>SXh0TY:B08Z:RP2=SHd0QXJ608:2PP28R8P00P26QXH06@24Q8@0Ogmo08B4
Q023Ph<0PX:208F5Q@29RHT0TI6A09jNWP2WYjL0^[Zj0<[:bP3Cdm<0emOG0=oOg`3IfMT0d];B0<o?
c`34a<@0^;Rh0:n_[`2XZ:P0YZJV0:FUY@2RXZ800P2QXJ40202NWYh0VIVI09RHV02CTi<0TI6A08^;
R`28R8P0QhN70P26QXH05`20P800PX:208B4Q022PX80PH6107moO`1mOGd0MgMg07emO@1aLG40J6QX
05mOG`1;Bd/0>CTi03lo?`0l?3`0<30`02/[:`0l?3`0>c/k0492@P0n?Sh0=CDe0080@d=301<0EEEE
03Ph>00/;2`0:b/[02TY:@0_;bl0GemO09BDU02WYjL0];Bd0:NWY`2GUiL0YZJV08j>SP1SHf<0>CTi
04=3@`0f=SH0:2PX0080:RXZ01@0=3@d038b<P0/;2`0;2`/038b<P0f=SH0>3Ph03Ti>@0[:b/0<30`
02TY:@0/;2`0;bl_03Hf=P1HF5P0Kfm_0861P@2>SXh0R8R808j>SP80R8R800l0PH6108N7Q`2GUiL0
VIVI0:2PX02NWYh0XZ:R0:2PX02LW9`0WinO09^KV`2NWYh0VIVI09RHV02LW9`00`2JVYX04@2KVi/0
UiNG09JFUP2EUID0UiNG09BDU02IVIT0UiNG09VIV@2FUYH0W9bL09FEU@2BTY80UIFE09BDU02KVi/0
V9RH0080UIFE00<0U9BD09FEU@2BTY800P2BTY801@2ATI40TY:B09BDU02@T900Ti>C00<0TI6A0100
Shn?09:BTP2<S8`0Ti>C08n?S`2BTY80SXj>08^;R`2=SHd0RXZ:08R8R026QXH0QhN708B4Q025QHD0
PX:20P23Ph<02024Q8@0QhN708j>SP2RXZ80YJFU0:j^[P2h^;P0^[Zj0P30`<002P32`/80a<C40<G5
a@35aLD0a<C40<?3``34a<@0aLG50<K6aP37alL20<?3``050<;2`P33`l<0`L710<;2`P2o_kl00P30
`<001@2o_kl0^[Zj0;jn_P2o_kl0`L710080`l?300H0`/;20<C4a032`/80aLG50<K6aP35aLD>0<SP
f0003038h=P205YJFP0:05aLG01MGEd0IfMW06ATI01FEUH0F5QH05ADE01BDU80EUIF055AD@<0De=C
00T0C4a<04Y:BP1;Bd/0BDU904E5A@16ATH0@D5103lo?`0k>c/00P0i>CT04014A4@0CDe=069RHP1/
K6`0Ng]k08F5Q@2;Rh/0TY:B09NGU`2OWil0X:2P0:NWY`2YZJT0[Zj^0:n_[`2^[Zh30;:b/P040;Bd
]02b/[80/k>c0;:b/P80][Jf01L0]kNg0;Jf]P2c/k<0^;Rh0;6a/@2][Jd0Xj>S09nOW`2MWId0VIVI
08b<S029RHT0Q8B407AdM01[Jf/0GUiN05ADE01?Cdl0CTi>04m?C`1EEED0FEUI05aLG00205]KF`04
05iNGP1SHf<0HV9R06IVIP80IfMW00H0Jf][07=cL`24Q8@0U9BD0:6QX@2SXj<209fMW@0F0:6QX@2I
VIT0TY:B09JFUP2>SXh0VIVI0::RXP2@T900WIfM08F5Q@1=CDd0?3`l04A4A00d=3@0>CTi04U9B@1P
H600EeMG03dm?@0h>3P0>CTi03`l?080?Shn00l0?clo0492@P16ATH0ATI603Xj>P1ADE40KFe]06EU
I@1FEUH0C4a<05IFEP1gMgL0LW9b04m?C`1ADE400P1RHV807@1eMGD0P82007moO`1iNGT0Hf=S05IF
EP0o?cl0;bl_02`/;00Z:RX0<c<c02TY:@0/;2`09bLW02TY:@0X:2P0;Rh^02XZ:P0Y:BT0;bl_030`
<00n?Sh0E5AD051@D013@d<0ATI606i^KP1eMGD0O7al0080Ogmo01T0O7al07IfMP1ZJVX0CDe=03/k
>`0e=CD0<C4a02h^;P0b<S80GemO08J6QP28R8P0PX:2079bLP1SHf<0HF5Q05mOG`1:BTX0<30`02d]
;@0c<c<0=CDe03@d=00_;bl0>SXj0080;Bd]00H0;2`/030`<00`<300;Bd]02/[:`0`<30302TY:@0A
02HV9P0a<C40Kfm_09jNWP2DU9@0L71`06IVIP1_Kfl0MWIf0:JVYP30`<00Zj^[0;Bd]02m_Kd0_;bl
0<C4a032`/800P39bLT07@3@d=00c<c<0:RXZ00m?Cd0:RXZ02PX:00f=SH0@D5104];B`1DE5@0FUYJ
06IVIP1aLG40MGEe07AdM01eMGD0NWYj07emO@1nOWh0P82007inOP21PH40QXJ608Z:RP2<S8`0SHf=
09:BTP2@T900U9BD0080V9RH01<0UIFE09jNWP2NWYh0XZ:R09nOW`2TY:@0YjNW0:j^[P2/[:`0[Jf]
0:VYZ@2][Jd0[jn_0;Jf]P2e]KD0[Zj^0:RXZ02ZZZX0Zj^[0080/[:b00D0/K6a0:n_[`2f][H0/k>c
0;6a/@020;2`/0040:f][@2^[Zh0[jn_0;6a/@80/;2`00P0ZJVY0:ZZZP2TY:@0Xj>S09nOW`2JVYX0
Ti>C096AT@80UIFE00@0U9BD096AT@2CTi<0T92@0P2<S8`308F5Q@80QXJ601@0QhN707emO@21PH40
Ph>308:2PP25QHD0Rh^;09>CT`2NWYh0Z:RX0;^k^`38b<P0emOG0=WIf@3Ogml0gMgM0=CDe03=cLd0
`/;20;Rh^080[Jf]00D0ZJVY0:NWY`2TY:@0YZJV0::RXP0209nOW`0809NGU`2EUID0SHf=08Z:RP28
R8P0QHF508>3P`26QXH208:2PP0507emO@22PX80PH610861P@1jNWX00P1eMGD09`1^KVh0JFUY05MG
E`16ATH0>SXj03Ph>00m?Cd0=3@d02d];@0c<c<0@41004U9B@0f=SH0>SXj04E5A@0n?Sh0EUIF03Xj
>P0[:b/0<c<c02/[:`0/;2`0IfMW09fMW@2TY:@0];Bd0:^[Z`2MWId0Y:BT08b<S01ADE40;bl_04A4
A00o?cl0;bl_02h^;P0Z:RX0>c/k03Ti>@0202`/;00702PX:00];Bd0<c<c03Ti>@0c<c<0:b/[02h^
;P0202l_;`0<03@d=01CDe<0JFUY07YjNP2;Rh/0SHf=08R8R027QhL0Rh^;08:2PP25QHD0TY:B0P2J
VYX05P2NWYh0X:2P09nOW`2JVYX0WIfM09ZJVP2KVi/0W9bL09NGU`2FUYH0VIVI09ZJVP2NWYh0VYZJ
09NGU`2EUID0V9RH09^KV`2FUYH0V9RH09JFUP2EUID209NGU`0809BDU02FUYH0UIFE09FEU@2KVi/0
WIfM09RHV02GUiL209FEU@0808j>SP2ATI40TI6A09NGU`2>SXh0UIFE08n?S`2BTY82096AT@80UiNG
00l0Shn?096AT@2@T900TY:B092@T02?Shl0R8R808^;R`2:RXX0R8R808b<S028R8P0RHV908B4Q02>
SXh00P23Ph<03@24Q8@0QXJ608R8R02FUYH0Y:BT0:VYZ@2c/k<0^;Rh0;fm_@2o_kl0`<300<;2`P35
aLD00P36a/H02@34a<@0`l?30<C4a034a<@0`l?30<;2`P33`l<0`/;20<?3``040<30`0040;jn_P30
`<00_kno0;fm_@80_[jn00<0_kno0<30`02o_kl00P30`<020<71`@030<?3``38h=P0b>3H00`0b>3H
000<0<SPf0<0GUiN00P0GEeM06][J`1TI6@0GEeM05UIF@1HF5P0G5aL05EEE@80EUIF01T0E5AD05MG
E`1?Cdl0CDe=04a<C01>CTh0C4a<04];B`12@T80@d=303hn?P0k>c/0>SXj0451@@1?Cdl0Fe]K06MW
I`1hN7P0QHF508Z:RP2BTY80V9RH09nOW`2TY:@0YZJV0080Zj^[01d0[Zj^0;6a/@2`/;00/;2`0;:b
/P2d];@0/k>c0;Bd]02f][H0]KFe0;Rh^02f][H0];Bd0;Ng]`2d];@0/K6a0:j^[P2XZ:P0X:2P09jN
WP2IVIT0T92@08V9R@1nOWh0L71`06QXJ01NGUh0D51@055AD@0204m?C`0605MGE`1JFUX0FUYJ05eM
G@1JFUX0HV9R0P1QHF402`1MGEd0I6AT06ATI01/K6`0KVi^071`L01eMGD0Ph>308R8R02>SXh0TY:B
0080X:2P02@0V9RH0::RXP2RXZ80Z:RX0:^[Z`2NWYh0WIfM0:FUY@2>SXh0NWYj06=SH`1BDU80Bd];
04a<C01>CTh0F5QH05=CD`11@D40=SHf03Lg=`0h>3P0>CTi03dm?@13@d<0ATI603hn?P0c<c<0BDU9
06EUI@1ZJVX0E5AD04Q8B01KFe/0JFUY07UiN@1aLG4305=CD`1D069RHP1iNGT0LW9b0820P01fMWH0
Hf=S04E5A@0Y:BT0:2PX02DU9@0Y:BT0:RXZ02LW9`0Q8B40:b/[03Ph>00b<S80<c<c02h^;P0[:b/0
=CDe04];B`1DE5@0JVYZ06EUI@1_Kfl0MGEe07YjNP1mOGd0L71`06][J`1OGel0EUIF06QXJ02:RXX0
T92@08N7Q`1YJFT0@410038b<P1OGel0OGem0861P@1fMWH0IVIV05=CD`1FEUH0FEUI05=CD`0_;bl0
9bLW02h^;P0b<S80=SHf02d];@0/;2`0<C4a030`<00[:b/0<30`03De=@0`<300:b/[02XZ:P0/;2`0
:BTY02LW9`0X:2P0;Bd]05ADE02CTi<0XZ:R07emO@1VIVH0IfMW071`L028R8P0^k^k0;Bd]02^[Zh0
^KVi0;bl_032`/80_kno0P32`/802P3;bl/0c/k>0<S8b02@T900=3@d030`<00c<c<0?clo04a<C01C
De<205mOG`0E06m_K`1bLW80MGEe07UiN@1hN7P0NWYj07]kN`23Ph<0Ogmo08>3P`24Q8@0R8R808Z:
RP2;Rh/0T92@09:BTP2GUiL0VIVI09FEU@2JVYX0WIfM0080X:2P00D0XZ:R0:NWY`2XZ:P0Z:RX0:j^
[P020:NWY`070;6a/@2/[:`0];Bd0;2`/02][Jd0Z:RX0;6a/@020;Jf]P80/K6a0180/;2`0:n_[`2/
[:`0Zj^[0:FUY@2YZJT0[Zj^0;:b/P2^[Zh0/[:b0:^[Z`2^[Zh0ZZZZ0:RXZ02SXj<0X:2P09ZJVP2H
V9P209JFUP0;092@T02>SXh0SXj>092@T02ATI40Shn?08b<S02;Rh/0QXJ60861P@1nOWh00`27QhL0
2`1lO7`0Ogmo0820P020P800Q8B408f=S@2FUYH0W9bL0:b/[02m_Kd0a/K60080emOG00L0gmoO0=cL
g03Cdm<0c<c<0<30`02h^;P0[:b/0080[Jf]00h0[:b/0:f][@2YZJT0WYjN09VIV@2EUID0UiNG09:B
TP2<S8`0RXZ:08R8R02;Rh/0QHF508N7Q`80QHF500/0OGem08:2PP1nOWh0Ng]k07alO01fMWH0MgMg
079bLP1ZJVX0Fe]K04M7A`0203Ti>@0L03/k>`0`<300;2`/034a<@0h>3P0@D5103Lg=`0e=CD0BDU9
03/k>`1EEED0=cLg030`<00[:b/09bLW02l_;`1dM7@0X:2P09jNWP2a/K40[Zj^09jNWP2LW9`0NGUi
04Y:BP0b<S80@D5103@d=0808R8R00<0:2PX04=3@`0m?Cd00P0];Bd07@0S8b<0<30`03Ti>@0e=CD0
>3Ph03De=@0_;bl0<30`034a<@0Z:RX0ADE506EUI@1fMWH0Q8B408j>SP2<S8`0RHV908F5Q@23Ph<0
QXJ608V9R@2JVYX0WIfM0:2PX02OWil0WYjN09nOW`2KVi/0VYZJ00<0Vi^K01<0VYZJ09FEU@2JVYX0
VIVI09RHV02FUYH0V9RH09^KV`2JVYX0V9RH09ZJVP2FUYH0UIFE09JFUP2EUID0V9RH09ZJVP2GUiL0
VYZJ0080UYJF00X0V9RH09VIV@2EUID0Ti>C09BDU02BTY80U9BD09^KV`2FUYH0TY:B0P2CTi<01P2@
T900TY:B096AT@2DU9@0UIFE08j>SP80TI6A0P2>SXh01`2;Rh/0RXZ:08R8R028R8P0Rh^;08j>SP28
R8P00P26QXH308N7Q`0;08R8R025QHD0R8R809^KV`2TY:@0ZJVY0;:b/P2h^;P0_[jn0;no_`32`/80
0P36a/H01038b<P0aLG50<G5a@36a/H20<S8b0030<G5a@31`L40`L710080`L7100P0`l?30;jn_P2o
_kl0_kno0;fm_@2n_[h0_Kfm0;jn_P80_kno00@0`<300;no_`2n_[h0`<300P32`/800`33`l<0b>3H
0<SPf00<0<SPf0003038h=P205QHF00605eMG@1LG5`0G5aL05]KF`1GEeL0Fe]K0P1DE5@205IFEP0:
05EEE@1BDU80E5AD04i>CP1DE5@0BDU904i>CP18B4P0@T9203lo?`<0>c/k00d0?Cdm0492@P1@D500
F5QH06UYJ@1fMWH0Ogmo08N7Q`2ATI40V9RH09jNWP2TY:@0YJFU0080[Jf]00P0/;2`0;:b/P2_[jl0
[jn_0;Bd]02b/[80/k>c0;:b/P80]KFe01L0]kNg0;>c/`2d];@0]kNg0;:b/P2`/;00[Jf]0:VYZ@2R
XZ80WIfM09VIV@2=SHd0R8R807moO`1_Kfl0IFEU05eMG@1JFUX0DU9B051@D01>CTh0D51@05IFEP02
05eMG@80GemO00L0HF5Q06EUI@1QHF40IVIV06YZJP1VIVH0Jf][0080KFe]01d0Kfm_079bLP1bLW80
MGEe07moO`28R8P0QhN708:2PP25QHD0SHf=09FEU@2KVi/0Y:BT0:j^[P2VYZH0YJFU09fMW@2FUYH0
Rh^;08b<S01fMWH0I6AT04e=C@19BDT0AdM703dm?@0o?cl0?Shn04=3@`0204I6AP0<0492@P0i>CT0
?clo061PH01jNWX0EeMG04M7A`1BDU80KVi^07UiN@1eMGD0Ng]k0P1HF5P02`1LG5`0L71`05mOG`1X
J6P0NGUi07=cL`1MGEd0Bd];02/[:`0X:2P09BDU0080:BTY00d09BDU02TY:@0b<S80;Bd]034a<@0d
=3@0>SXj04A4A01KFe/0KFe]07EeM@1DE5@0HV9R0080K6a/0280HV9R05QHF01JFUX0CTi>05aLG02E
UID0WIfM0:2PX02OWil0V9RH07IfMP15ADD0A4A406][J`1SHf<0GemO059BDP1ADE40EEEE04e=C@12
@T809bLW02DU9@0X:2P0=3@d03<c<`0d=3@0:BTY02HV9P0_;bl0:b/[02XZ:P0Y:BT0;bl_0P0];Bd0
500^;Rh0:b/[02TY:@0X:2P0;Bd]0492@P1gMgL0W9bL09RHV01^KVh0HF5Q06YZJP1fMWH0Y:BT0;jn
_P2WYjL0/K6a0;bl_02o_kl0^k^k0P2m_Kd09@36a/H0c<c<0<g=c@31`L40NWYj03Hf=P0d=3@0?Cdm
04M7A`1;Bd/0EUIF06MWI`1]KFd0LW9b071`L01eMGD0N7Qh07alO01kNg/0Ph>30861P@20P800Q8B4
08N7Q`2<S8`0T92@08n?S`2DU9@0V9RH09bLW02FUYH0Vi^K09fMW@2OWil0X:2P0:FUY@2TY:@00P2X
Z:P02P2/[:`0YjNW0:f][@2][Jd0[:b/0;2`/02][Jd0[Zj^0:f][@2`/;020;:b/P090:f][@2_[jl0
[:b/0:ZZZP2/[:`0[Jf]0:RXZ02TY:@0[Jf]0080/K6a00H0/[:b0:j^[P2b/[80[:b/0:NWY`2RXZ82
09^KV`0>09RHV02EUID0Ti>C092@T02:RXX0SXj>08f=S@2DU9@0Shn?08^;R`28R8P0Q8B408N7Q`21
PH4208:2PP0D08N7Q`1lO7`0P82007YjNP1oOgl0Ph>308^;R`2LW9`0Xj>S0;6a/@2n_[h0b<S80=?C
d`3MgMd0h>3P0=oOg`3Bd]80b/[:0;no_`2g]kL20;2`/0050:f][@2^[Zh0Zj^[0:>SX`2KVi/00P2D
U9@0102@T900SHf=08n?S`2<S8`208R8R00b08^;R`28R8P0Q8B408>3P`1nOWh0OGem07moO`1iNGT0
O7al07IfMP1dM7@0K6a/06][J`1MGEd0CTi>04M7A`0h>3P0?3`l03Hf=P0c<c<0<S8b03De=@0k>c/0
=cLg034a<@16ATH0>SXj05UIF@10@400:BTY02<S8`0V9RH0=CDe07UiN@2OWil0XZ:R0:b/[02c/k<0
YZJV09FEU@1gMgL0ATI603@d=017AdL0?3`l02TY:@0U9BD0:b/[0492@P0c<c<202/[:`0C02XZ:P0/
;2`0<S8b03Ph>00i>CT0<C4a02/[:`0];Bd0;Rh^02/[:`0k>c/0Fe]K071`L022PX80SHf=08b<S028
R8P0QhN708F5Q@0208J6QP0A09>CT`2MWId0WYjN09nOW`2LW9`0WIfM09jNWP2MWId0Vi^K09ZJVP2M
WId0VYZJ09RHV02JVYX0W9bL09ZJVP2LW9`00P2IVIT0102KVi/0WYjN09^KV`2JVYX209FEU@0D09VI
V@2JVYX0W9bL09NGU`2EUID0V9RH09VIV@2HV9P0VYZJ09VIV@2GUiL0U9BD09NGU`2@T900TI6A09:B
TP2CTi<0UIFE09:BTP2@T90409>CT`0909:BTP2?Shl0T92@08j>SP2?Shl0TI6A08f=S@2;Rh/0Shn?
00<0RXZ:01l0QhN708V9R@27QhL0QhN708J6QP22PX80P82008Z:RP2>SXh0UiNG0::RXP2][Jd0]kNg
0;Rh^02n_[h0_kno0<;2`P37alL0b<S80<K6aP34a<@0a/K60<O7a`35aLD0a<C40<G5a@33`l<0`L71
0;no_`32`/80_[jn0080_kno00d0_;bl0;jn_P2m_Kd0_Kfm0;bl_02o_kl0`/;20;jn_P2o_kl0_Kfm
0;no_`31`L40_kno00h0b>3H000<0<SPf080Fe]K02P0FUYJ05aLG01FEUH0GUiN05MGE`1JFUX0EEEE
05=CD`1DE5@0EUIF055AD@1FEUH0D51@04a<C01ADE40BDU904i>CP1<C4`0AdM704A4A011@D40>c/k
03`l?00k>c/0ADE504];B`1HF5P0KVi^07]kN`26QXH0RHV908f=S@2IVIT0UiNG0:6QX@2VYZH0ZZZZ
0:b/[02][Jd0];Bd0P2`/;000`2g]kL0/K6a0;>c/`020;:b/P0C0;Jf]P2g]kL0][Jf0;Ng]`2d];@0
]KFe0:j^[P2`/;00YjNW0:>SX`2NWYh0U9BD09:BTP28R8P0PX:207MgM`1/K6`0GUiN05IFEP0304m?
C`0[055AD@1EEED0Fe]K05MGE`1KFe/0H61P065QH@1WIfL0I6AT06][J`1YJFT0KFe]071`L01^KVh0
KFe]06i^KP1_Kfl0L71`07AdM01cLg<0MGEe07alO01cLg<0IfMW06a/K01fMWH0Rh^;0:NWY`2[Zj/0
TI6A08n?S`2@T900TY:B09jNWP2RXZ80VIVI09>CT`1jNWX0GemO051@D014A4@0>CTi03dm?@0203Xj
>P0=0451@@10@400?3`l03Xj>P1ADE40MWIf06ATI01>CTh0AdM7079bLP20P800JFUY07]kN`02071`
L00L05]KF`1IFET0E5AD04e=C@1WIfL0QXJ607EeM@1OGel0@D5102<S8`0R8R809BDU02PX:00/;2`0
:RXZ03<c<`0[:b/0>CTi03`l?01ADE40Hf=S07]kN`1oOgl0I6AT05EEE@1GEeL0EUIF051@D080ADE5
01@0Hf=S07EeM@1kNg/0O7al07MgM`23Ph<0TI6A09fMW@2PX:00OWin03dm?@10@400B4Q804Y:BP14
A4@0@4100492@P0n?Sh0;bl_02`/;080;Bd]0200=SHf03<c<`0^;Rh0;Rh^02`/;00];Bd0:2PX030`
<00a<C40;2`/03@d=00a<C40=cLg02`/;00[:b/0<S8b02`/;00Y:BT0DU9B08^;R`2UYJD0OWin06UY
J@1WIfL0L71`08b<S030`<00/[:b0:^[Z`2e]KD0_;bl0;jn_P80_Kfm01@0`/;20<K6aP39bLT0bLW9
0;^k^`1IFET0=SHf03Lg=`15ADD0DE5A059BDP1QHF40Jf][071`L01aLG40Kfm_07UiN@1nOWh0NWYj
08B4Q080PX:200<0RXZ:08^;R`2;Rh/00P2=SHd01P2BTY80UiNG09fMW@2JVYX0XJ6Q09^KV`80WinO
00@0XZ:R0:VYZ@2YZJT0Y:BT0P2UYJD0102ZZZX0[Jf]0:VYZ@2a/K420:f][@0=0:b/[02[Zj/0[Jf]
0:^[Z`2/[:`0[Jf]0:^[Z`2ZZZX0[:b/0:f][@2XZ:P0ZJVY0:RXZ0020:VYZ@80/;2`00D0[Jf]0:RX
Z02/[:`0X:2P09bLW00209ZJVP0409FEU@2DU9@0SHf=08R8R080SXj>00L0UYJF08V9R@2;Rh/0RHV9
0820P023Ph<0PX:200<0PH6103/0NWYj08J6QP1jNWX0OWin08N7Q`2>SXh0V9RH0:FUY@2_[jl0a<C4
0<_;b`3AdM40f][J0=oOg`3Lg=`0dM7A0<K6aP2l_;`0^;Rh0;Fe]@2a/K40[jn_0:RXZ02WYjL0X:2P
09^KV`2JVYX0V9RH09FEU@2@T900SHf=08V9R@24Q8@0R8R808N7Q`23Ph<0PX:208F5Q@1nOWh0O7al
07YjNP1kNg/0NWYj079bLP1`L700KVi^06ATI01LG5`0BTY:0451@@0_;bl0>3Ph03@d=00X:2P0;Bd]
03Ph>00o?cl0@D51034a<@0203lo?`0@059BDP13@d<0<S8b02`/;00Z:RX0>SXj07alO02PX:00Z:RX
0;2`/02g]kL0YJFU08n?S`1eMGD0>CTi03Lg=`80BTY:00D0:RXZ02DU9@0a<C40@D5103Ti>@02034a
<@0B030`<00Z:RX0;2`/03@d=00c<c<0<C4a02h^;P0`<300<C4a02l_;`0m?Cd0EEEE06e]K@1jNWX0
Rh^;08b<S02:RXX0QhN70P24Q8@0;026QXH0Shn?09RHV02IVIT0Xj>S09nOW`2KVi/0WYjN09ZJVP2M
WId0UIFE09bLW02KVi/0UYJF09VIV@2HV9P0VYZJ09FEU@2IVIT0UiNG09FEU@2JVYX0VIVI09RHV02G
UiL0UYJF09RHV02FUYH0UIFE09NGU`2HV9P0UiNG09JFUP2CTi<0V9RH09JFUP2HV9P0TY:B09JFUP2D
U9@0UYJF09BDU02@T900Ti>C0`2BTY803`2FUYH0TI6A092@T02CTi<0SHf=096AT@2<S8`0Ti>C096A
T@2>SXh0T92@08f=S@27QhL0S8b<08^;R`0208R8R080Q8B400l0QhN708J6QP23Ph<0Ph>308:2PP2@
T900W9bL0:FUY@2ZZZX0/k>c0;^k^`2m_Kd0`<300<;2`P34a<@00P35aLD00`37alL0a<C40<O7a`02
0<K6aP80`L710P30`<00102o_kl0`<300;no_`2l_;`20;fm_@050;^k^`2j^[X0_Kfm0;no_`30`<00
0`2n_[h00`30`<00`L710<SPf00=0<SPf0003038h=P2065QH@0E05iNGP1OGel0GUiN05eMG@1HF5P0
Fe]K05iNGP1HF5P0EEEE05IFEP1GEeL0E5AD04m?C`1DE5@0EEEE051@D01ADE40D51@04E5A@12@T80
A4A400<0?Cdm00P0BDU905EEE@1JFUX0IfMW07UiN@26QXH0RHV909:BTP80VYZJ00H0WinO0:RXZ02W
YjL0ZJVY0:j^[P2_[jl30;:b/P040;6a/@2e]KD0][Jf0;Bd]080^;Rh03d0/k>c0;Jf]P2g]kL0][Jf
0;2`/02][Jd0Z:RX0:2PX02RXZ80UYJF08n?S`2:RXX0PH6107EeM@1YJFT0HF5Q05MGE`1?Cdl0CDe=
059BDP1CDe<0F5QH05eMG@1SHf<0HF5Q06ATI01PH600IVIV06QXJ01VIVH0JVYZ06i^KP1_Kfl0JFUY
06a/K01^KVh0L71`07=cL`1]KFd0LG5a07EeM@1iNGT0NWYj06m_K`1PH600KVi^07=cL`22PX80Shn?
07UiN@1_Kfl0IFEU075aL@25QHD0U9BD096AT@2BTY80QHF507MgM`1LG5`0?clo0080>3Ph00l0>CTi
038b<P0`<300<C4a02l_;`0g=cL0Cdm?06e]K@1PH600CDe=051@D01XJ6P0PX:207AdM01OGel00P1e
MGD0@P1ZJVX0GemO03lo?`11@D40AdM706a/K021PH40KVi^059BDP0_;bl09RHV02@T900V9RH09bLW
030`<00b<S80;Rh^03Ti>@1?Cdl0HV9R079bLP21PH40JFUY05EEE@1@D500?Cdm03/k>`18B4P0CDe=
04m?C`1]KFd0PX:206e]K@1DE5@0?3`l05aLG01YJFT0Lg=c0:JVYP2[Zj/0LW9b03/k>`0b<S80<c<c
03Hf=P0c<c<0=3@d038b<P0a<C40=3@d034a<@0c<c<0=cLg03Hf=P0^;Rh0:b/[030`<00/;2`0:2PX
02l_;`0b<S80;bl_03De=@0c<c<0;Bd]02h^;P80<C4a0P0W9bL03P0j>SX0Kfm_09JFUP2KVi/0M7Ad
06a/K01YJFT0PX:20:b/[02n_[h0X:2P0;>c/`2h^;P0_kno0P30`<003@2n_[h0a<C40<?3``37alL0
c<c<0;2`/01<C4`0>CTi04=3@`1;Bd/0EeMG05mOG`1TI6@00P1`L700101fMWH0O7al07YjNP1iNGT3
07moO`0408b<S02;Rh/0Rh^;08Z:RP80Ti>C00D0UYJF09RHV02GUiL0WYjN09fMW@0209nOW`0D0:NW
Y`2ZZZX0ZJVY0:6QX@2SXj<0XZ:R0:ZZZP2/[:`0[Zj^0;Bd]02/[:`0Zj^[0:VYZ@2SXj<0YZJV0:FU
Y@2XZ:P0YZJV0:VYZ@2/[:`20:j^[P0B0:f][@2/[:`0Z:RX0:RXZ02ZZZX0YZJV0:RXZ02/[:`0Z:RX
0:ZZZP2SXj<0XZ:R0:2PX02IVIT0U9BD08j>SP2:RXX0R8R80`2=SHd01P2:RXX0QHF508>3P`27QhL0
PX:20861P@80Ph>301<0Q8B407moO`25QHD0P82007moO`29RHT0Shn?09RHV02UYJD0]KFe0<G5a@3:
b/X0dm?C0=cLg03Ogml0f][J0<o?c`36a/H0^KVi00<0];Bd00T0/K6a0:^[Z`2QXJ40Y:BT09VIV@2H
V9P0UIFE09RHV02CTi<00P2>SXh01029RHT0QhN708Z:RP23Ph<207moO`0^07alO01mOGd0NGUi07Ui
N@1lO7`0LW9b075aL@1[Jf/0I6AT05ADE015ADD0@D5103/k>`0l?3`0=3@d02TY:@0_;bl0<S8b03@d
=00l?3`0>c/k03Hf=P0m?Cd0D51@04U9B@0];Bd08b<S02XZ:P0j>SX0MgMg09jNWP2VYZH0][Jf0;Bd
]02VYZH0Ti>C06i^KP10@400>CTi04E5A@1=CDd0:2PX02<S8`0b<S80=SHf03<c<`80;2`/00<0=CDe
02h^;P0`<3000P0g=cL02P0e=CD0<C4a02/[:`0/;2`0;Bd]03@d=014A4@0IFEU07=cL`25QHD208b<
S00A08J6QP28R8P0QHF508J6QP2<S8`0UIFE09bLW02OWil0XJ6Q09^KV`2SXj<0Vi^K09fMW@2JVYX0
Vi^K09ZJVP2KVi/00P2JVYX06@2IVIT0U9BD09BDU02HV9P0UIFE09ZJVP2EUID0VIVI09RHV02GUiL0
UYJF09FEU@2IVIT0UYJF09NGU`2FUYH0VIVI09FEU@2IVIT0Ti>C09JFUP2BTY80UIFE09BDU02KVi/0
0P2FUYH0102HV9P0UYJF09FEU@2ATI4309:BTP0608f=S@2<S8`0Ti>C08f=S@2?Shl0T92@0P2<S8`0
1P2>SXh0RHV908^;R`2=SHd0R8R808Z:RP80QhN701<0QXJ608R8R027QhL0PX:20861P@28R8P0SXj>
09fMW@2VYZH0[jn_0;Bd]02h^;P0_Kfm0<30`033`l<0aLG50<K6aP35aLD0bLW90080aLG50P33`l<0
2031`L40_kno0;no_`30`<00_kno0<71`@2m_Kd0_;bl0P2k^k/02@2l_;`0^k^k0;bl_02k^k/0_Kfm
0;jn_P30`<00_kno0;jn_P0>0<SPf0003038h=P206=SH`0<05eMG@1PH600GUiN05UIF@1KFe/0F5QH
05MGE`1KFe/0FEUI05ADE01@D500DU9B0P1@D500101BDU80De=C04i>CP1;Bd/204I6AP0D03dm?@0o
?cl0?Cdm03/k>`12@T80CTi>05aLG01/K6`0OGem08B4Q02<S8`0Ti>C09JFUP2HV9P0Y:BT0:JVYP2Y
ZJT0[:b/0:n_[`2c/k<20;6a/@050;Bd]02f][H0^;Rh0;:b/P2i^KT00P2h^;P0@02f][H0^KVi0;Ng
]`2e]KD0][Jf0:j^[P2XZ:P0Y:BT09bLW02GUiL0TY:B08V9R@21PH40MgMg06MWI`1QHF40G5aL04m?
C`1=CDd0EEEE05IFEP1EEED0G5aL05]KF`1OGel0IFEU05iNGP1XJ6P0IfMW06][J`1YJFT0Lg=c06i^
KP1`L700LG5a06m_K`1bLW80K6a/06][J`1bLW80Q8B407AdM01jNWX0PH6107QhN01`L700KFe]06a/
K01dM7@0Lg=c06MWI`1?Cdl0A4A405UIF@1RHV80N7Qh07emO@1iNGT0MgMg05eMG@1=CDd0>CTi03<c
<`0h>3P203<c<`0902XZ:P0d=3@0;bl_03`l?01MGEd0FUYJ055AD@15ADD0GUiN0080MgMg0380KVi^
06MWI`1WIfL0P82006ATI019BDT0=3@d03De=@15ADD0JVYZ07MgM`1KFe/0AdM702PX:00T92@08b<S
02HV9P0_;bl0=CDe02d];@0c<c<0CTi>05=CD`1XJ6P0LG5a059BDP12@T80=cLg02XZ:P0b<S80IfMW
08b<S02DU9@0Shn?07alO01CDe<0@T9203/k>`13@d<0IfMW05=CD`1jNWX0YZJV0:>SX`1JFUX0;Bd]
02l_;`0Y:BT0;Bd]02h^;P80<c<c0P0`<300100c<c<0=3@d034a<@0V9RH202/[:`0K02`/;00X:2P0
;2`/034a<@0e=CD0<C4a03Hf=P0e=CD0<S8b03@d=00e=CD0:RXZ02h^;P0/;2`0D51@08:2PP2SXj<0
Ogmo06MWI`1UIFD0KVi^08j>SP2i^KT0Xj>S0;6a/@2f][H0_;bl0080^k^k00@0_Kfm0<30`032`/80
b<S80P3<c<`05P2TY:@0@41003lo?`17AdL0DE5A05aLG01OGel0K6a/071`L01dM7@0N7Qh07]kN`1l
O7`0Ph>307emO@26QXH0SHf=08V9R@2<S8`0SXj>09FEU@2FUYH309RHV00;09fMW@2OWil0X:2P09jN
WP2XZ:P0ZJVY0:NWY`2SXj<0YJFU0::RXP2ZZZX00P2/[:`04@2b/[80Zj^[0:VYZ@2XZ:P0Xj>S0:JV
YP2ZZZX0Y:BT0:NWY`2XZ:P0[Zj^0;6a/@2`/;00[Zj^0:b/[02UYJD0ZJVY00<0YZJV0P2WYjL04P2V
YZH0XJ6Q0:JVYP2KVi/0WinO09FEU@2=SHd0R8R808V9R@2;Rh/0SXj>09:BTP2@T900RXZ:08J6QP27
QhL0QHF508B4Q080QXJ603`0Ogmo08:2PP21PH40PH6108B4Q028R8P0V9RH09nOW`2WYjL0^;Rh0<;2
`P3=cLd0e]KF0=WIf@3Ng]h0fMWI0<o?c`32`/80_Kfm0;Jf]P2e]KD0/[:b0:f][@2YZJT0Xj>S09nO
W`2JVYX0VIVI09JFUP2HV9P0U9BD08n?S`2=SHd0RXZ:08N7Q`24Q8@0Ph>30820P01lO7`0NWYj07]k
N`1hN7P0NWYj07=cL`1_Kfl0Jf][06MWI`1VIVH0FUYJ04=3@`0m?Cd0>c/k03Ti>@0f=SH0:b/[03De
=@0_;bl0<S8b03Ti>@13@d<203`l?00G04U9B@12@T80=3@d02<S8`0];Bd0>c/k08B4Q02OWil0ZZZZ
0;Jf]P2a/K40Y:BT09:BTP1/K6`0=SHf03/k>`1ADE40B4Q802TY:@0V9RH0<C4a03<c<`14A4@00P0[
:b/0100Z:RX09bLW02`/;00e=CD203Hf=P0C02l_;`0/;2`0;2`/02`/;00_;bl0?Shn05QHF01eMGD0
Ph>308Z:RP27QhL0QHF508B4Q026QXH0Ph>308V9R@2EUID0Vi^K09fMW@0209nOW`0=09bLW02IVIT0
WinO09^KV`2OWil0VIVI09ZJVP2LW9`0VYZJ09NGU`2EUID0UYJF09RHV00209NGU`0709BDU02GUiL0
U9BD09JFUP2HV9P0Shn?09RHV00209ZJVP0609RHV02KVi/0UYJF09VIV@2BTY80U9BD0P2ATI403@2C
Ti<0UYJF09FEU@2KVi/0UIFE09NGU`2CTi<0UiNG09:BTP2CTi<0TI6A09FEU@2BTY800P2EUID02P2?
Shl0SXj>08^;R`2<S8`0TI6A09:BTP2<S8`0SHf=08j>SP2<S8`208R8R00C08N7Q`25QHD0QHF508>3
P`21PH40Ph>308B4Q02@T900Vi^K0:RXZ02^[Zh0]KFe0;Vi^@2l_;`0_kno0<;2`P34a<@0aLG50<K6
aP030<C4a0050<G5a@30`<00`<300;no_`2m_Kd00P2o_kl00`2m_Kd0_;bl0;fm_@020;fm_@050;jn
_P2o_kl0_[jn0;no_`2k^k/00P2n_[h00`2o_kl0b>3H0<SPf00<0<SPf0003038h=P206IVIP0C05iN
GP1PH600G5aL05]KF`1IFET0GEeM05aLG01PH600E5AD05UIF@1EEED0E5AD055AD@1=CDd0D51@05=C
D`1DE5@0DE5A04U9B@0204I6AP0C0410@00m?Cd0?Shn0451@@1:BTX0F5QH06][J`1lO7`0QHF508^;
R`2FUYH0V9RH09bLW02TY:@0YZJV0:VYZ@2_[jl0/[:b0;2`/0020;:b/P080;Jf]P2c/k<0]kNg0;:b
/P2g]kL0]KFe0;Ng]`2e]KD20;Jf]P0<0;Rh^02b/[80[:b/0:JVYP2WYjL0WIfM09>CT`2ATI40Q8B4
0820P01dM7@0IfMW0P1JFUX01@1@D500Bd];04m?C`1BDU80G5aL0080GEeM00H0HF5Q06ATI01RHV80
IfMW06m_K`1YJFT2071`L00906i^KP1/K6`0K6a/06YZJP1bLW80Jf][06a/K01]KFd0KVi^0080MGEe
01<0Ph>308F5Q@24Q8@0L71`06a/K01XJ6P0LW9b06m_K`1/K6`0C4a<03lo?`0m?Cd0BTY:04M7A`1@
D500GEeM06m_K`1PH600@T920080<30`00h0?3`l038b<P0[:b/0:b/[034a<@0m?Cd0EUIF059BDP16
ATH0?3`l04i>CP1WIfL0Jf][07AdM080K6a/00/0O7al06i^KP16ATH0?3`l034a<@0d=3@0D51@06e]
K@1SHf<0EEEE03@d=00202HV9P0a02XZ:P0W9bL0<S8b0451@@0];Bd0>CTi03dm?@1PH600FUYJ04I6
AP0g=cL0<C4a03Hf=P17AdL0QhN7092@T02CTi<0T92@08>3P`1jNWX0H61P03`l?00m?Cd0Lg=c04];
B`19BDT0M7Ad09ZJVP24Q8@0;2`/02XZ:P0X:2P0:b/[034a<@0];Bd0<S8b02/[:`0_;bl0<S8b030`
<00/;2`0<30`02h^;P0W9bL0<30`02h^;P0a<C40<S8b03lo?`04030`<00B03<c<`0[:b/0:RXZ02XZ
:P0/;2`0>3Ph06][J`2BTY80UIFE06m_K`1RHV80I6AT07EeM@2RXZ80]KFe0:ZZZP2b/[80]KFe0P2j
^[X20;fm_@060<K6aP39bLT0clo?0<k>cP37alL0RXZ:0P10@400101=CDd0FEUI065QH@1ZJVX2075a
L@0M07EeM@1fMWH0MgMg07emO@25QHD0QXJ608V9R@25QHD0RXZ:08f=S@2GUiL0U9BD09NGU`2FUYH0
W9bL0:6QX@2HV9P0XJ6Q0::RXP2TY:@0YjNW0:BTY02VYZH0X:2P0:BTY02WYjL0ZZZZ0:f][@2/[:`0
0P2VYZH02P2PX:00YJFU0:NWY`2UYJD0Z:RX0:>SX`2WYjL0ZJVY0:^[Z`2][Jd20:VYZ@0?0;6a/@2^
[Zh0ZJVY0:BTY02VYZH0[:b/0;2`/02TY:@0YZJV0:j^[P2UYJD0WYjN09>CT`2<S8`0SXj>0080R8R8
00L0T92@08n?S`2>SXh0Rh^;08J6QP29RHT0QXJ600<0PH6101<0Ph>30861P@22PX80P82007moO`2;
Rh/0VYZJ0:NWY`2a/K40];Bd0<71`@3?cll0fMWI0=cLg03MgMd0emOG0<c<c032`/80^k^k0080]kNg
01<0/;2`0:NWY`2SXj<0WIfM09bLW02MWId0Vi^K09bLW02GUiL0U9BD08b<S027QhL0Q8B408N7Q`23
Ph<0Ogmo0861P@1jNWX0MgMg0080LW9b00X0Lg=c06m_K`1]KFd0KVi^06=SH`1QHF40EEEE03dm?@0n
?Sh0@4100P0h>3P01P0Z:RX0<c<c03Lg=`0c<c<0>SXj0410@080?3`l0100BTY:0492@P0d=3@0:RXZ
03Lg=`10@400PX:20:2PX02SXj<0^k^k0;2`/02GUiL0SHf=06=SH`0i>CT0?Shn0P1CDe<01@0/;2`0
;bl_03De=@0a<C40>CTi0080<S8b00P0;bl_02PX:00/;2`0<S8b03@d=00f=SH0=3@d02/[:`80;2`/
01P0:RXZ03Hf=P1@D500Jf][07alO028R8P0QXJ608N7Q`25QHD0QhN708>3P`26QXH0TY:B09FEU@2O
Wil0W9bL09ZJVP2IVIT0WIfM09ZJVP2MWId0WYjN09fMW@2GUiL309VIV@0509RHV02KVi/0VIVI09NG
U`2JVYX00P2HV9P01`2CTi<0V9RH09NGU`2EUID0U9BD09RHV02JVYX00P2FUYH00`2EUID0VIVI09VI
V@0209FEU@0909:BTP2FUYH0UiNG09NGU`2FUYH0UIFE09:BTP2ATI40Ti>C0080TI6A00d0UIFE09:B
TP2BTY80T92@09JFUP2CTi<0TY:B09JFUP2>SXh0S8b<096AT@2>SXh0Shn?00@0SHf=00<0R8R808V9
R@25QHD00P23Ph<03025QHD0Q8B408>3P`2>SXh0X:2P0:JVYP2/[:`0/[:b0;Jf]P2l_;`0`<300<?3
``80a<C400X0a/K60<C4a035aLD0`l?30<;2`P31`L40_[jn0<71`@2m_Kd0`<300`2o_kl30;bl_007
0;^k^`2n_[h0_;bl0;fm_@2l_;`0_[jn0<30`00>0<SPf0003038h=P206ATI00=065QH@1UIFD0HF5Q
05UIF@1NGUh0Fe]K05eMG@1JFUX0FEUI05ADE01ADE40EEEE055AD@0305=CD`0H059BDP1<C4`0CDe=
04E5A@14A4@0?3`l03Ti>@0h>3P0A4A404i>CP1PH600L71`07alO025QHD0S8b<09JFUP2EUID0WIfM
0:2PX02XZ:P0YjNW0:VYZ@2_[jl0/;2`0P2a/K40702d];@0]kNg0;:b/P2c/k<0^;Rh0;Vi^@2g]kL0
][Jf0;Fe]@2h^;P0]KFe0;Jf]P2][Jd0YZJV0:>SX`2IVIT0UIFE092@T02;Rh/0Ogmo07EeM@1WIfL0
Fe]K05MGE`1=CDd0DE5A051@D01JFUX205QHF00905YJFP1NGUh0HF5Q06EUI@1WIfL0JFUY069RHP1/
K6`0JVYZ0080KVi^00L0K6a/06e]K@1]KFd0K6a/06e]K@1/K6`0KVi^0080LW9b02<0RHV909ZJVP2O
Wil0TY:B0861P@1`L700KFe]071`L01hN7P0JVYZ05EEE@0n?Sh0?3`l03Ti>@10@400De=C06YZJP1W
IfL0E5AD03Ti>@0m?Cd0?clo03Lg=`0Y:BT09BDU02h^;P0_;bl0CTi>05MGE`0k>c/0>3Ph0451@@1G
EeL0G5aL05QHF00206e]K@0R06EUI@1eMGD0CDe=04=3@`1:BTX0AdM70451@@1WIfL0JFUY059BDP19
BDT0;bl_02`/;00[:b/092@T02<S8`0e=CD0>3Ph03Hf=P0o?cl0EUIF05=CD`0d=3@0;bl_038b<P1>
CTh0LG5a08:2PP1oOgl0N7Qh07emO@1iNGT0MWIf075aL@80BTY:00/0K6a/06i^KP10@400@41005mO
G`28R8P0B4Q802HV9P0[:b/0<C4a030`<00302`/;00@02d];@0_;bl0;Bd]02LW9`0/;2`0<C4a02PX
:00[:b/0:BTY030`<00f=SH0=cLg02d];@0c<c<0<S8b034a<@80<30`01009RHV02LW9`0X:2P0;Bd]
04M7A`22PX80WYjN08B4Q01YJFT0IFEU06][J`27QhL0];Bd0:f][@2a/K40];Bd0P2f][H20;^k^`80
`l?301T0b/[:0<o?c`3=cLd0`L710861P@0o?cl0ADE505ADE01PH600IVIV075aL@1`L700Kfm_079b
LP1hN7P0Ogmo08N7Q`26QXH0QhN708>3P`2>SXh0S8b<09JFUP2DU9@0UiNG00<0W9bL00<0Vi^K09nO
W`2TY:@00P2QXJ40102RXZ80Y:BT09jNWP2VYZH20:6QX@050:>SX`2OWil0VYZJ09nOW`2KVi/00P2R
XZ803P2MWId0WYjN09nOW`2VYZH0Y:BT0:^[Z`2ZZZX0Xj>S0:JVYP2a/K40[:b/0:j^[P2UYJD0XZ:R
0P2/[:`00`2PX:00XZ:R0:ZZZP020:BTY00309FEU@2<S8`0SHf=0080QHF500@0R8R808Z:RP2?Shl0
SXj>0P28R8P208:2PP80OWin02`0Q8B407moO`1oOgl0P82007emO@2<S8`0V9RH0:2PX02XZ:P0];Bd
0;no_`3AdM40fMWI0=oOg`3Ph>00e]KF0<K6aP30`<00^k^k0;Zj^P2e]KD0[jn_0:2PX02MWId0VIVI
09jNWP2LW9`0UiNG09JFUP2GUiL0T92@08Z:RP22PX80QhN708:2PP25QHD0PX:207moO`1jNWX0M7Ad
07MgM`1aLG40MWIf07EeM@80LW9b01/0JVYZ05iNGP1EEED0BDU903hn?P19BDT0>CTi03@d=00T92@0
;Bd]03Hf=P0g=cL0<30`0410@00k>c/0?clo05IFEP1<C4`0=3@d02`/;00d=3@0?clo08V9R@2OWil0
Y:BT0;Zj^P2`/;000P2=SHd02P1ZJVX0?Cdm0492@P1GEeL0GEeM02h^;P0_;bl0>CTi034a<@0l?3`2
02d];@0302XZ:P0V9RH0:2PX0080<C4a00D0>c/k02`/;00];Bd0;Rh^02TY:@02030`<00704a<C01V
IVH0O7al08N7Q`2=SHd0RHV908J6QP0208B4Q00408V9R@2<S8`0Ti>C09ZJVP<0W9bL00X0WYjN09fM
W@2JVYX0WIfM09jNWP2KVi/0WinO09ZJVP2GUiL0UYJF0P2IVIT02@2JVYX0V9RH09NGU`2GUiL0UYJF
09RHV02IVIT0VYZJ09JFUP0309RHV00809>CT`2FUYH0U9BD09JFUP2JVYX0U9BD09FEU@2DU9@209FE
U@0909BDU02CTi<0VIVI09FEU@2CTi<0V9RH09:BTP2EUID0TY:B0080UIFE00/0UYJF09BDU02ATI40
Ti>C08n?S`2@T900SXj>08b<S02?Shl0SXj>08f=S@02092@T00H08n?S`2:RXX0RHV908J6QP1oOgl0
QHF508:2PP26QXH0Ph>309:BTP2LW9`0YJFU0:f][@2a/K40][Jf0;fm_@30`<00`L710<?3``34a<@0
aLG50<C4a033`l<0`<300P31`L400`2o_kl0`<300<30`0020;no_`070<30`02n_[h0_Kfm0;bl_02n
_[h0_;bl0;fm_@020;no_`030;fm_@2n_[h0b>3H00d0b>3H000<0<SPf080J6QX0`1SHf<0301RHV80
GEeM065QH@1OGel0GEeM05]KF`1LG5`0FEUI05YJFP1GEeL0De=C055AD@80E5AD00D0Bd];04e=C@16
ATH0@D5103`l?00203Hf=P0<03hn?P1<C4`0G5aL071`L022PX80Q8B408Z:RP2CTi<0UIFE0::RXP2Q
XJ40YZJV0P2[Zj/0202][Jd0[Zj^0;6a/@2a/K40^[Zj0;Jf]P2d];@0]kNg0P2d];@20;Ng]`<0^;Rh
0140/;2`0:j^[P2WYjL0Xj>S09jNWP2HV9P0SXj>08Z:RP22PX80NGUi06QXJ01LG5`0DE5A059BDP1E
EED0Cdm?05=CD`0205aLG00705mOG`1MGEd0HF5Q069RHP1VIVH0Jf][06QXJ00206e]K@0R071`L01]
KFd0Kfm_06QXJ01]KFd0Jf][06m_K`1/K6`0KFe]07QhN02ATI40W9bL09jNWP2^[Zh0Z:RX09JFUP2=
SHd0MWIf07AdM01gMgL0Kfm_065QH@18B4P0@41003lo?`0l?3`0@d=304i>CP1ZJVX0I6AT05UIF@1>
CTh0=SHf038b<P80:2PX00X09RHV03Xj>P0m?Cd0Fe]K03/k>`0`<300>c/k04M7A`13@d<0=cLg0P1?
Cdl08`1PH600Hf=S06UYJ@1ZJVX0Lg=c06YZJP1[Jf/0GemO06EUI@16ATH0>c/k03@d=00W9bL0:RXZ
02`/;00S8b<0:2PX03dm?@0n?Sh0C4a<04U9B@16ATH0=CDe03Hf=P1>CTh0MGEe0820P01gMgL0IFEU
04];B`1HF5P0HF5Q061PH01XJ6P0HF5Q0080F5QH00X0Shn?06YZJP0l?3`0?clo05]KF`1NGUh0?3`l
04];B`0c<c<0=CDe0P0`<3000`0];Bd0:BTY02`/;00202h^;P0702d];@0/;2`0:b/[02l_;`0Y:BT0
=3@d03De=@0202l_;`0E038b<P0Z:RX0;bl_038b<P0Y:BT09BDU024Q8@0U9BD08b<S030`<01VIVH0
Shn?09nOW`1lO7`0I6AT06QXJ01kNg/0Y:BT0;^k^`2/[:`0][Jf0080/K6a01D0/k>c0;Ng]`2j^[X0
`<300<K6aP3;bl/0c<c<0<k>cP2k^k/0L71`03`l?01>CTh0EEEE05iNGP1UIFD0KVi^071`L01fMWH0
N7Qh07UiN@22PX800P27QhL02026QXH0SHf=08j>SP2HV9P0UYJF09VIV@2GUiL0VYZJ0P2GUiL02@2J
VYX0Vi^K0:2PX02SXj<0WYjN0:>SX`2OWil0X:2P09bLW00209ZJVP0:09NGU`2DU9@0UYJF09JFUP2H
V9P0Vi^K09JFUP2IVIT0WYjN09^KV`80W9bL01`0YJFU0:2PX02RXZ80Y:BT0:FUY@2WYjL0ZZZZ0:FU
Y@2WYjL0YJFU0::RXP2OWil0YZJV0:>SX`2WYjL0W9bL08j>SP2;Rh/0PX:207moO`24Q8@0QXJ608^;
R`2<S8`0QhN708V9R@20P800OWin0P20P8003@24Q8@0PX:208:2PP23Ph<0QhN708f=S@2LW9`0XJ6Q
0:ZZZP2f][H0`l?30<k>cP3IfMT00P3MgMd0203Fe]H0a/K60;jn_P2k^k/0^[Zj0;6a/@2[Zj/0WinO
0P2SXj<02P2JVYX0VIVI09RHV02DU9@0Ti>C08b<S025QHD0Q8B40861P@1mOGd207moO`0?07YjNP1f
MWH0KVi^07MgM`1`L700MWIf079bLP1]KFd0JFUY069RHP1QHF40De=C03dm?@0j>SX0@D510080=CDe
01H09BDU02d];@0g=cL0=3@d034a<@0j>SX0?clo03Ph>01;Bd/0De=C038b<P0`<300=3@d04I6AP2<
S8`0XZ:R0:JVYP2m_Kd0[jn_08R8R029RHT0I6AT0P10@4001`1NGUh0C4a<02l_;`0i>CT0:RXZ02h^
;P0i>CT00P0a<C406P0`<300:RXZ02d];@0a<C40=CDe03Xj>P0h>3P0<C4a02`/;00X:2P0<c<c02/[
:`13@d<0I6AT07MgM`24Q8@0T92@08^;R`29RHT0QXJ608Z:RP1nOWh0Rh^;08f=S@2IVIT0WIfM0`2N
WYh309ZJVP0:09VIV@2JVYX0W9bL09NGU`2FUYH0W9bL09FEU@2DU9@0UiNG09ZJVP<0UYJF0P2HV9P0
3`2GUiL0V9RH09FEU@2IVIT0V9RH09VIV@2HV9P0W9bL09JFUP2HV9P0UYJF09NGU`2EUID0UiNG09RH
V00209NGU`0A09JFUP2EUID0UYJF09JFUP2CTi<0UiNG09FEU@2DU9@0Ti>C096AT@2?Shl0T92@096A
T@2BTY80TI6A08b<S02@T9000P2?Shl05@2;Rh/0RXZ:08Z:RP2=SHd0RXZ:08F5Q@24Q8@0QHF508:2
PP1oOgl0Ph>307inOP23Ph<0Shn?09ZJVP2SXj<0YjNW0;:b/P2i^KT0_;bl0;no_`030<30`0<0`/;2
00D0`L710<;2`P31`L40_[jn0<30`0020;no_`<0_Kfm00@0_;bl0;fm_@2n_[h0^k^k0P2m_Kd00`2l
_;`0_[jn0<SPf00=0<SPf0003038h=P206ATI00306MWI`1UIFD0Hf=S0080I6AT00D0IFEU05iNGP1N
GUh0GemO05iNGP0205UIF@80De=C01P0EUIF059BDP1CDe<0DE5A04i>CP1=CDd0ATI604M7A`0m?Cd0
>c/k04];B`1DE5@0I6AT071`L01oOgl0QHF508f=S@2ATI40UiNG0:>SX`2TY:@0YJFU0:ZZZP2][Jd2
0;:b/P80];Bd00P0/;2`0;Bd]02d];@0]KFe0;:b/P2g]kL0^;Rh0;Ng]`80][Jf0P2c/k<0502^[Zh0
YZJV0:FUY@2MWId0UYJF096AT@2:RXX0QHF507AdM01WIfL0HF5Q05EEE@1=CDd0D51@059BDP1DE5@0
GEeM069RHP1NGUh0GemO0P1SHf<0101XJ6P0IfMW06m_K`1ZJVX206e]K@0I06a/K01]KFd0KFe]06][
J`1]KFd0JFUY06a/K01_Kfl0Q8B40:NWY`2CTi<0SHf=09jNWP2[Zj/0ZZZZ0:FUY@2LW9`0QXJ607Mg
M`1`L700H61P055AD@1=CDd0ADE50492@P0204=3@`0705=CD`1PH600EeMG051@D011@D40>c/k02`/
;00202@T900902PX:00c<c<0D51@034a<@0^;Rh0;Bd]03lo?`0i>CT0<c<c0080>CTi02L0De=C0820
P029RHT0Ph>307emO@1bLW80NGUi07IfMP1gMgL0H61P04e=C@0o?cl0<C4a03Ph>00^;Rh0:2PX02/[
:`0c<c<0Cdm?04e=C@1;Bd/0ATI603Hf=P10@400N7Qh07alO01^KVh0HF5Q05eMG@1;Bd/0@41004];
B`10@400HF5Q06i^KP1OGel0Hf=S08f=S@29RHT00P1EEED05`1NGUh0GemO04Q8B01JFUX0Cdm?04];
B`0/;2`0:b/[02l_;`0/;2`0;bl_038b<P0a<C40<c<c02`/;00W9bL0;Rh^034a<@0h>3P0=SHf03<c
<`0`<300;bl_0080;Bd]0180;2`/02LW9`0S8b<092@T02DU9@0S8b<092@T03lo?`1iNGT0W9bL08n?
S`1cLg<0Jf][06m_K`2FUYH0`L710;:b/P2[Zj/20:JVYP0L0:ZZZP2a/K40]KFe0;bl_02o_kl0b<S8
0<c<c03?cll0c<c<0;Jf]P1PH600AdM7055AD@1LG5`0GemO06MWI`1^KVh0LW9b07]kN`1jNWX0O7al
08>3P`2;Rh/0R8R8092@T02BTY80U9BD09VIV@80VYZJ00H0V9RH09NGU`2CTi<0UYJF09jNWP2DU9@2
09^KV`0<09nOW`2JVYX0WIfM09ZJVP2EUID0UiNG096AT@2>SXh0TY:B096AT@2CTi<0Shn?0P2@T900
2@2CTi<0TY:B09:BTP2HV9P0UYJF09bLW02MWId0X:2P0:6QX@020:RXZ00=0:NWY`2SXj<0Y:BT0:BT
Y02LW9`0XJ6Q0:>SX`2WYjL0X:2P09:BTP26QXH0Ph>308F5Q@0208B4Q00608J6QP2:RXX0Rh^;08N7
Q`24Q8@0Ogmo0P21PH403@1lO7`0Ph>307alO021PH40Q8B408j>SP2PX:00YJFU0:ZZZP2l_;`0b<S8
0=3@d03EeMD00P3MgMd04`3Fe]H0b<S80;bl_02k^k/0^;Rh0:f][@2XZ:P0XZ:R0:>SX`2LW9`0UYJF
09FEU@2DU9@0SXj>092@T028R8P0QHF50861P@1nOWh00P1lO7`05`1gMgL0Lg=c06m_K`1dM7@0K6a/
06QXJ01]KFd0KVi^06e]K@1XJ6P0IVIV05EEE@1ADE40@41003/k>`14A4@0>c/k02l_;`0Y:BT0:RXZ
03Ti>@0f=SH0;Bd]00<0?Cdm01L0B4Q805=CD`0c<c<0=SHf03De=@16ATH0SXj>09bLW02/[:`0_;bl
0:JVYP22PX80QXJ605mOG`0i>CT0>SXj05iNGP11@D40=SHf03Ti>@0/;2`0>3Ph03Xj>P0202l_;`0:
03Ph>00c<c<0;Bd]034a<@0b<S80?clo03/k>`0g=cL0;Rh^02PX:080:BTY01D0@T9205EEE@1cLg<0
PX:208^;R`2:RXX0R8R808:2PP28R8P0Ph>308V9R@2CTi<0UiNG09fMW@2KVi/0WIfM09ZJVP2KVi/0
WIfM09^KV`2JVYX00P2HV9P06P2IVIT0Vi^K09fMW@2MWId0UiNG09^KV`2FUYH0UiNG09FEU@2CTi<0
VYZJ09JFUP2IVIT0V9RH09FEU@2IVIT0UYJF09NGU`2FUYH0UiNG09BDU02FUYH0Ti>C09BDU02FUYH0
UiNG0P2IVIT209JFUP0C09FEU@2HV9P0VYZJ09FEU@2IVIT0UiNG09FEU@2ATI40T92@09>CT`2ATI40
U9BD08n?S`2ATI40SXj>08b<S02:RXX0SHf=08j>SP0208f=S@0H08j>SP2@T900RXZ:08R8R026QXH0
Q8B408J6QP25QHD0Ph>307inOP24Q8@0UYJF09VIV@2QXJ40ZZZZ0:n_[`2d];@0^KVi0;Zj^P2l_;`0
_kno0;bl_02o_kl0`/;20P31`L430<30`080_kno00H0_[jn0;fm_@2o_kl0_;bl0;no_`2m_Kd20;bl
_0030;fm_@2o_kl0_kno00h0b>3H000<0<SPf080IFEU00<0IfMW06ATI01SHf<00P1TI6@08`1PH600
GemO06=SH`1MGEd0G5aL05eMG@1FEUH0FUYJ05MGE`1EEED0DU9B05EEE@1IFET0DE5A04e=C@19BDT0
ATI603lo?`13@d<0CDe=05ADE01SHf<0Kfm_07UiN@24Q8@0SXj>09>CT`2HV9P0W9bL0:JVYP2[Zj/0
[:b/0:f][@2`/;00/k>c0080[jn_00@0];Bd0;>c/`2f][H0]kNg0P2f][H0502g]kL0^;Rh0;Rh^02d
];@0/K6a0;Jf]P2`/;00YZJV0:BTY02NWYh0UIFE092@T028R8P0PX:207IfMP1YJFT0HF5Q059BDP1>
CTh0BDU90P1ADE40301HF5P0FEUI05eMG@1PH600HV9R06=SH`1XJ6P0IfMW06YZJP1]KFd0K6a/06e]
K@80JFUY02/0KFe]06][J`1[Jf/0Hf=S06i^KP1gMgL0VIVI0:2PX027QhL0SXj>09^KV`2TY:@0XZ:R
0:FUY@2][Jd0XJ6Q096AT@20P800Kfm_05mOG`15ADD0C4a<05=CD`1<C4`0>CTi0410@01DE5@0IFEU
05EEE@1ADE40=CDe02`/;00^;Rh0<30`02DU9@0Z:RX0?Cdm03Hf=P0[:b/092@T03Lg=`0e=CD0=cLg
0080?clo00D0IfMW09JFUP2?Shl0Rh^;096AT@020861P@0V07moO`1kNg/0Ng]k07=cL`16ATH0=3@d
03Hf=P0a<C409RHV02TY:@0a<C40F5QH05IFEP1>CTh0A4A403lo?`1RHV80MWIf06][J`1FEUH0ATI6
06][J`1GEeL0CTi>04M7A`1MGEd0Lg=c07EeM@1cLg<0NWYj08N7Q`2;Rh/0NWYj07AdM01KFe/0ADE5
03@d=010@40202d];@0U02TY:@0W9bL0:b/[03@d=00^;Rh0;Bd]02/[:`0^;Rh0;bl_030`<00];Bd0
;Rh^03Hf=P0/;2`0;Rh^02l_;`0[:b/0;bl_02XZ:P0`<3009bLW02PX:00[:b/09RHV024Q8@0R8R80
:2PX061PH025QHD0XJ6Q08:2PP1[Jf/0IfMW07inOP2YZJT0`<300:RXZ0020:6QX@080:^[Z`2b/[80
][Jf0;Ng]`2e]KD0`L710<O7a`39bLT20<[:bP070:VYZ@1OGel0BTY:05IFEP1MGEd0Hf=S06e]K@02
07EeM@0707emO@1oOgl0Ph>308Z:RP28R8P0SHf=09>CT`0209BDU00309FEU@2KVi/0VIVI0080VYZJ
02T0UYJF09RHV02FUYH0U9BD09NGU`2IVIT0UIFE09BDU02CTi<0T92@09FEU@2@T900Rh^;09BDU02B
TY80Shn?092@T02=SHd0SXj>092@T02>SXh0Shn?08j>SP2FUYH0UiNG09JFUP2GUiL0VYZJ09^KV`2M
WId0XJ6Q0:>SX`2UYJD0Y:BT09ZJVP2MWId0XJ6Q0:>SX`2QXJ40V9RH08^;R`030861P@0708R8R024
Q8@0RXZ:08R8R026QXH0QhN70861P@0208>3P`0J07inOP22PX80Ogmo08:2PP23Ph<0S8b<09ZJVP2U
YJD0[jn_0;no_`39bLT0d];B0=[JfP3Ogml0gMgM0=;BdP38b<P0^;Rh0;Jf]P2a/K40YZJV0:BTY02N
WYh0WIfM09JFUP2CTi<208b<S00408N7Q`29RHT0RHV908R8R080OGem03<0Ph>307alO01cLg<0Hf=S
06YZJP1YJFT0GUiN06EUI@1XJ6P0IFEU06MWI`1MGEd0HF5Q05UIF@1>CTh0?Cdm03Lg=`10@400>SXj
02d];@0X:2P09bLW03@d=00e=CD0=SHf038b<P0i>CT0>c/k04e=C@17AdL0;bl_02h^;P0c<c<0B4Q8
08j>SP2JVYX0ZZZZ0;bl_02UYJD0SXj>08F5Q@1RHV80?clo03/k>`1LG5`0Bd];03De=@0l?3`0;2`/
03Ph>00a<C400P0b<S801@0i>CT0<S8b02`/;00`<300=3@d0080@d=300/0>3Ph02TY:@0_;bl0;2`/
02l_;`0b<S80D51@079bLP23Ph<0Rh^;08Z:RP0208N7Q`0A08>3P`21PH40Ph>308n?S`2CTi<0WYjN
09bLW02NWYh0Vi^K09nOW`2LW9`0Vi^K09bLW02EUID0UYJF09^KV`2OWil00P2IVIT02P2KVi/0U9BD
09FEU@2GUiL0UYJF09RHV02EUID0V9RH09bLW02JVYX309NGU`0?09JFUP2GUiL0UiNG09JFUP2EUID0
TY:B09RHV02GUiL0UIFE09:BTP2DU9@0UYJF09BDU02JVYX0UYJF0080UiNG00D0UYJF09VIV@2EUID0
UIFE09:BTP0209>CT`0609BDU02BTY80TI6A09>CT`2=SHd0Shn?0P2>SXh208f=S@0508n?S`2>SXh0
Rh^;08b<S027QhL00P2;Rh/01024Q8@0Ph>308R8R022PX8208N7Q`0<09>CT`2OWil0Y:BT0:b/[02^
[Zh0];Bd0;Rh^02i^KT0_;bl0;no_`2n_[h0_kno0P31`L400`2o_kl0`/;20;jn_P040;fm_@80_;bl
00<0_kno0;bl_02k^k/00P2l_;`00`2m_Kd0b>3H0<SPf00<0<SPf0003038h=P206IVIP0706YZJP1T
I6@0I6AT06EUI@1RHV80H61P065QH@02069RHP80H61P00<0GEeM05QHF01MGEd00P1CDe<0601EEED0
De=C055AD@1<C4`0CDe=04U9B@14A4@0@T9204M7A`1BDU80J6QX071`L01lO7`0R8R808n?S`2BTY80
UiNG09jNWP2VYZH0YjNW0:VYZ@2^[Zh0[jn_0;2`/080];Bd00@0/;2`0;>c/`2c/k<0][Jf0P2g]kL0
?@2h^;P0]kNg0;Fe]@2j^[X0];Bd0;2`/02a/K40ZZZZ0:FUY@2MWId0UIFE09:BTP25QHD0PH61075a
L@1XJ6P0G5aL05=CD`1?Cdl0C4a<059BDP1DE5@0EUIF05UIF@1NGUh0HF5Q06EUI@1OGel0IVIV06EU
I@1XJ6P0K6a/06e]K@1_Kfl0MGEe06][J`1/K6`0JVYZ06UYJ@1UIFD0Lg=c08V9R@2WYjL0RXZ:08R8
R02DU9@0V9RH09VIV@2>SXh0Rh^;08j>SP2BTY80WinO0:VYZ@2IVIT0Kfm_05EEE@16ATH0AdM704A4
A013@d<00P15ADD0401QHF40Jf][05=CD`0h>3P0<C4a030`<00X:2P0:RXZ02`/;00Z:RX0<c<c02LW
9`0Y:BT0=CDe03Hf=P14A4@2071`L00L08n?S`2NWYh0Ogmo07UiN@26QXH0Rh^;08N7Q`1cLg<0IfMW
071`L01fMWH0D51@02XZ:P0f=SH0>CTi02<S8`0Y:BT0>SXj06MWI`15ADD0@d=304E5A@12@T80K6a/
075aL@1LG5`0@410034a<@80JVYZ01D0DE5A059BDP1cLg<0MgMg08J6QP22PX80U9BD08J6QP25QHD0
SHf=07UiN@0f=SH0:2PX02TY:@0[:b/0;Rh^03De=@0i>CT0=3@d02XZ:P0/;2`00P0d=3@01P0b<S80
<C4a02h^;P0X:2P0;Rh^03Lg=`80<c<c00D0;Rh^03@d=00g=cL0=3@d02`/;002030`<00302LW9`0N
7Qh08B4Q0080820P00/08b<S03`l?01fMWH0VIVI09^KV`1^KVh0Hf=S071`L02<S8`0^KVi0:ZZZP02
09nOW`0[0:NWY`2`/;00/k>c0;>c/`2`/;00^k^k0<;2`P3:b/X0bLW90<_;b`38b<P0XZ:R05eMG@1?
Cdl0De=C05aLG01SHf<0LG5a07IfMP1iNGT0Q8B408>3P`26QXH0QhN708^;R`2<S8`0Shn?09>CT`2B
TY80UiNG09ZJVP2BTY80UYJF09:BTP2GUiL0VIVI096AT@2CTi<0TI6A08^;R`2?Shl0TI6A09BDU002
09FEU@0908b<S02:RXX0U9BD092@T02=SHd0RHV908R8R029RHT0Rh^;0080SHf=00<0U9BD096AT@2<
S8`00P2EUID02P2KVi/0VIVI09nOW`2OWil0Y:BT09jNWP2JVYX0U9BD09JFUP2IVIT209bLW00;08f=
S@23Ph<0NWYj07]kN`21PH40Q8B408J6QP29RHT0QXJ608:2PP25QHD00P21PH4207moO`0K07emO@23
Ph<0QHF5092@T02RXZ80YJFU0:b/[02k^k/0a/K60=;BdP3MgMd0hn?S0=kNgP3Bd]80`l?30;Fe]@2^
[Zh0ZZZZ0:6QX@2LW9`0VYZJ09FEU@2CTi<0R8R808V9R@27QhL0QHF50080R8R80300PX:207]kN`1m
OGd0Q8B407inOP1]KFd0EUIF06IVIP1WIfL0CDe=05eMG@1XJ6P0GemO069RHP1KFe/0HF5Q05]KF`1=
CDd0?clo03Hf=P0o?cl0=SHf02d];@0W9bL0:BTY03<c<`0b<S80;Rh^03<c<`0j>SX0?Shn04];B`1?
Cdl0=3@d02/[:`0g=cL0CTi>096AT@2HV9P0Zj^[0<30`02YZJT0Shn?07]kN`1RHV80?3`l0492@P1U
IFD20492@P0403De=@0Y:BT0>3Ph030`<080:RXZ0180<30`02LW9`0];Bd0:b/[03<c<`14A4@0B4Q8
03dm?@0/;2`0:BTY02DU9@0^;Rh0>3Ph04a<C01RHV80Ng]k08J6QP2;Rh/208R8R00:08>3P`20P800
PX:208b<S02DU9@0W9bL0:2PX02UYJD0WIfM0:6QX@80WIfM00T0VYZJ09BDU02KVi/0VIVI09^KV`2H
V9P0VYZJ09VIV@2KVi/00P2GUiL06`2IVIT0U9BD09JFUP2EUID0VIVI09ZJVP2FUYH0UiNG09VIV@2H
V9P0U9BD09bLW02GUiL0UIFE09NGU`2EUID0UYJF09RHV02CTi<0UIFE09JFUP2HV9P0UiNG09JFUP2C
Ti<0V9RH09>CT`0209RHV00309VIV@2EUID0Ti>C0080U9BD00@0Ti>C09BDU02BTY80SHf=0P2ATI40
8@2?Shl0Rh^;08^;R`2:RXX0Rh^;08f=S@2>SXh0QhN708Z:RP28R8P0Rh^;08F5Q@2:RXX0QXJ608F5
Q@22PX80RXZ:092@T02KVi/0W9bL0:JVYP2/[:`0[jn_0;>c/`2i^KT0^k^k0;Zj^P2l_;`0_Kfm0;no
_`2n_[h0`L710;fm_@020<30`0030;^k^`2n_[h0_kno00H0_;bl00<0_kno0<SPf038h=P03038h=P0
00`0b>3H0P1WIfL02`1XJ6P0JFUY06MWI`1[Jf/0JVYZ06ATI01OGel0HV9R06QXJ01SHf<0Fe]K0080
FEUI01/0EUIF05ADE01FEUH0EeMG05IFEP1CDe<0DU9B04];B`1:BTX0ADE504Q8B016ATH0E5AD06IV
IP1dM7@0P82008F5Q@2=SHd0U9BD09^KV`2MWId0YJFU0:JVYP2[Zj/0[Zj^0:n_[`2d];@00P2e]KD0
1P2c/k<0/K6a0;Fe]@2f][H0]KFe0;Ng]`80]KFe01D0^k^k0;bl_02d];@0/k>c0:j^[P2VYZH0YJFU
09fMW@2FUYH0T92@08N7Q`20P800MGEe06][J`1UIFD0EeMG04a<C01?Cdl0EeMG05ADE01EEED00P1L
G5`0=P1QHF40IFEU06MWI`1[Jf/0KFe]06UYJ@1]KFd0L71`075aL@1bLW80Lg=c06i^KP1]KFd0Kfm_
06i^KP1`L700S8b<08>3P`1QHF40Kfm_07EeM@1hN7P0RXZ:08V9R@21PH40LW9b07alO024Q8@0Ti>C
09NGU`2BTY80PX:207=cL`1?Cdl0@D5104Y:BP1IFET0E5AD055AD@1JFUX0FEUI04U9B@0i>CT0>3Ph
034a<@0W9bL0:BTY02`/;00_;bl0;Bd]02DU9@0W9bL0?3`l075aL@80V9RH00l0S8b<08:2PP1OGel0
CTi>06YZJP21PH40Ogmo06][J`1>CTh0D51@05ADE019BDT0;2`/03Hf=P0l?3`00P0Y:BT0@`1?Cdl0
LG5a0451@@0k>c/0Bd];05ADE01ZJVX0J6QX04i>CP0[:b/0=CDe05aLG01`L700IFEU069RHP1aLG40
NGUi08N7Q`1eMGD0NWYj07AdM01gMgL0QhN7096AT@1_Kfl0<c<c02@T900U9BD0<S8b03Xj>P0c<c<0
;Bd]02XZ:P0/;2`0<C4a02l_;`0d=3@0<c<c02TY:@0^;Rh0<c<c030`<00^;Rh0;bl_02`/;00_;bl0
=3@d03De=@0b<S80=SHf02d];@0V9RH09bLW02HV9P0L71`07QhN02<S8`0V9RH0FEUI08N7Q`2QXJ40
P82006=SH`1VIVH0Lg=c0:RXZ02h^;P00`2SXj<03@2XZ:P0/k>c0:f][@2b/[80]KFe0;fm_@35aLD0
b<S80<_;b`36a/H0a<C409jNWP1IFET00P1ADE40301PH600Jf][06i^KP1kNg/0P82007inOP23Ph<0
QHF508N7Q`2>SXh0TY:B09FEU@80SHf=0P2@T9005P2FUYH0U9BD09NGU`2BTY80U9BD08^;R`2?Shl0
S8b<08n?S`2CTi<0UYJF09NGU`2@T900Q8B408>3P`2<S8`0RHV908:2PP1lO7`0OWin08B4Q01oOgl2
08R8R080QHF500H0MgMg08b<S02EUID0SXj>092@T02PX:0209VIV@<0UYJF0P2ATI40302FUYH0UIFE
08n?S`23Ph<0MgMg07YjNP20P800PH6108R8R024Q8@0QHF507inOP<0Ph>301l0P82007emO@20P800
QXJ608V9R@2ATI40XJ6Q0::RXP2ZZZX0_kno0<[:bP3GemL0g]kN0>?Sh`3Lg=`0dm?C0;no_`2d];@0
Z:RX09nOW`2JVYX0UiNG09FEU@2>SXh0QHF508R8R021PH40OWin07alO024Q8@0PX:20080OGem0P1o
Ogl0<P1fMWH0K6a/059BDP1ZJVX0GemO04a<C01BDU80Hf=S069RHP1QHF40FEUI05aLG01BDU80ATI6
03Xj>P0`<300>SXj03Ph>00_;bl09RHV02@T900c<c<0=3@d02`/;00a<C40>CTi04m?C`19BDT0DU9B
03@d=00[:b/0=cLg04m?C`2=SHd0Vi^K0;2`/02o_kl0Xj>S096AT@1fMWH0H61P03Ph>01ADE40IVIV
0451@@0i>CT0;Rh^03Hf=P0i>CT0;Bd]0P0/;2`04`0d=3@0<30`02XZ:P0X:2P0;Rh^03`l?00m?Cd0
>CTi03De=@0f=SH0<30`02/[:`0_;bl0D51@06=SH`1jNWX0QhN708Z:RP29RHT00P25QHD04021PH40
P82008V9R@2CTi<0WYjN09VIV@2PX:00WYjN09ZJVP2LW9`0WYjN09bLW02JVYX0VIVI09ZJVP2LW9`2
09NGU`80Vi^K00L0VIVI09BDU02IVIT0VIVI09RHV02GUiL0Vi^K0080UIFE00P0VYZJ09RHV02IVIT0
VYZJ09RHV02CTi<0TY:B09NGU`80UYJF00X0UiNG09ZJVP2HV9P0V9RH09JFUP2GUiL0UYJF09NGU`2H
V9P0U9BD0P2IVIT0302FUYH0UIFE09JFUP2DU9@0Ti>C09FEU@2CTi<0S8b<096AT@2CTi<0TY:B08j>
SP80SHf=00@0RXZ:08b<S02:RXX0RXZ:0P2;Rh/02`23Ph<0R8R808R8R02;Rh/0R8R808J6QP25QHD0
QXJ608R8R02@T900VIVI0080XJ6Q00D0ZZZZ0:^[Z`2b/[80]KFe0;Jf]P030;Zj^P80_[jn00L0_Kfm
0;jn_P2n_[h0_kno0;fm_@2n_[h0_kno0080_[jn00@0^KVi0;bl_02i^KT0_Kfm3P38h=P000`0b>3H
0`1VIVH03@1PH600Hf=S06a/K01YJFT0J6QX06EUI@1TI6@0JVYZ065QH@1KFe/0H61P05eMG@1IFET0
0P1DE5@0101FEUH0E5AD04e=C@1?Cdl204I6AP0:0492@P1:BTX0C4a<05EEE@1UIFD0L71`07moO`28
R8P0T92@09:BTP80WIfM00<0XJ6Q0:NWY`2/[:`00P2`/;040;>c/`030;Fe]@2f][H0]KFe0080]kNg
02<0^k^k0;Rh^02e]KD0^k^k0;Fe]@2a/K40Zj^[0:NWY`2XZ:P0WinO09BDU02<S8`0QhN707emO@1e
MGD0IfMW069RHP1GEeL0CTi>051@D01HF5P0EeMG05]KF`1PH600Hf=S06][J`1RHV80IfMW06ATI01/
K6`0IfMW06a/K01^KVh0KFe]06YZJP0306i^KP0S06][J`1/K6`0NGUi09^KV`1TI6@0>CTi0451@@19
BDT0G5aL0861P@2;Rh/0QhN708>3P`2EUID0XJ6Q096AT@1kNg/0PX:208V9R@2;Rh/0P82007EeM@1k
Ng/0Ogmo075aL@1NGUh0DU9B04E5A@11@D40B4Q804M7A`0j>SX0:b/[02XZ:P0];Bd00P0b<S80100/
;2`0<30`055AD@2ATI4209>CT`0:075aL@1JFUX0A4A403Lg=`1;Bd/0Jf][08j>SP1iNGT0?clo03Hf
=P80;bl_01T0;2`/02d];@0b<S80<C4a02d];@1ADE40MGEe03@d=01>CTh0BTY:05aLG01QHF40GUiN
03Ph>00V9RH0<c<c05=CD`1WIfL0Kfm_07QhN01WIfL0L71`07AdM01aLG40Q8B40080I6AT0P1iNGT0
2`2EUID0J6QX02TY:@0U9BD09bLW02`/;00b<S80;Rh^034a<@0c<c<0A4A40080:BTY00L0:b/[02l_
;`0_;bl0;Rh^02d];@0^;Rh0:RXZ0080;2`/00T0<30`038b<P0f=SH0=3@d02d];@0X:2P09BDU02HV
9P0S8b<00P0R8R802P0S8b<0<S8b06][J`2=SHd0UIFE06i^KP1RHV80JFUY092@T02k^k/20;Ng]`07
0::RXP2QXJ40/;2`0:f][@2f][H0^;Rh0;bl_0020<C4a00N0<_;b`39bLT0aLG50<G5a@2JVYX0FEUI
055AD@1OGel0IVIV06i^KP1fMWH0O7al0861P@22PX80RHV908F5Q@2<S8`0SHf=09>CT`25QHD0SHf=
08^;R`2ATI40U9BD09>CT`2BTY80SXj>09:BTP2=SHd0TI6A0P2@T9001P2FUYH0UIFE09BDU02>SXh0
Ph>307MgM`80PH6100l0Ng]k075aL@1^KVh0QXJ607moO`28R8P0RXZ:08n?S`1kNg/0K6a/08J6QP2:
RXX0PH6108J6QP2VYZH00P2BTY801@2GUiL0VIVI09NGU`2IVIT0TY:B0080SXj>00D0Q8B407moO`1e
MGD0NGUi07moO`0208>3P`80Q8B403D0Ogmo0861P@23Ph<0Ph>307inOP1oOgl0PX:208R8R02:RXX0
TI6A09^KV`2VYZH0Zj^[0;Vi^@3<c<`0fMWI0=oOg`3Ph>00g=cL0<o?c`2i^KT0[Zj^0:BTY02OWil0
UIFE09>CT`2<S8`0SHf=08B4Q027QhL0QHF50820P01_Kfl0NGUi07=cL`1iNGT0MgMg079bLP1iNGT0
K6a/05EEE@11@D40GEeM04m?C`1:BTX0D51@05aLG01GEeL0EUIF055AD@1FEUH0EEEE04=3@`0203Hf
=P0Q03Lg=`0j>SX0<c<c02d];@0X:2P0<S8b03hn?P0c<c<0<S8b03/k>`1ADE40CDe=05ADE00d=3@0
;2`/03Hf=P1?Cdl0TI6A09ZJVP2e]KD0^[Zj09nOW`2?Shl0Kfm_05YJFP0j>SX0FEUI069RHP1=CDd0
?Cdm038b<P0k>c/0=3@d00<0<c<c00T0=CDe03Hf=P0a<C409bLW02l_;`0f=SH0?Shn0451@@0b<S80
0P0^;Rh05P0f=SH0=3@d04E5A@1UIFD0L71`0861P@2=SHd0SXj>08Z:RP25QHD0R8R808B4Q02:RXX0
T92@09JFUP2MWId0XJ6Q09^KV`2NWYh0WinO0:6QX@2NWYh209VIV@0J09^KV`2IVIT0Vi^K09ZJVP2G
UiL0VIVI09^KV`2JVYX0UYJF09ZJVP2KVi/0V9RH09VIV@2GUiL0UYJF09ZJVP2DU9@0UIFE09NGU`2H
V9P0VIVI09FEU@2FUYH0UiNG09VIV@2FUYH209ZJVP0609>CT`2FUYH0U9BD09RHV02FUYH0UiNG0P2H
V9P01P2GUiL0UIFE09FEU@2IVIT0V9RH09NGU`80TY:B00D0UIFE08n?S`2?Shl0TY:B096AT@0208j>
SP0608f=S@2>SXh0SHf=08V9R@28R8P0QHF50P26QXH05024Q8@0R8R808F5Q@2;Rh/0QHF508B4Q028
R8P0Rh^;08n?S`2FUYH0W9bL0::RXP2SXj<0ZJVY0:f][@2a/K40/[:b0;Ng]`2h^;P0^[Zj0P2h^;P0
1@30`<00_Kfm0;fm_@2n_[h0_kno0080_;bl00D0^[Zj0;^k^`2m_Kd0^k^k0;jn_P0>0<SPf0003038
h=P206MWI`0@06IVIP1WIfL0J6QX06i^KP1YJFT0IVIV065QH@1RHV80JFUY065QH@1LG5`0GemO05QH
F01KFe/0FUYJ05]KF`80EEEE01D0Cdm?055AD@1BDU80BTY:04A4A018B4P0BDU905UIF@1TI6@0Lg=c
07inOP2<S8`0TY:B096AT@2JVYX0X:2P0:FUY@2XZ:P0[:b/0:f][@2^[Zh00`2a/K40702c/k<0/[:b
0;Bd]02g]kL0^;Rh0;Ng]`2i^KT0]KFe0;Vi^@2f][H0]kNg0;2`/02^[Zh0ZJVY0:FUY@2PX:00UIFE
08f=S@24Q8@0PH6107IfMP1XJ6P0HV9R05ADE01=CDd0DE5A059BDP1CDe<205eMG@0:05iNGP1UIFD0
IfMW06IVIP1YJFT0IfMW06YZJP1aLG40LW9b071`L0<0Kfm_02X0KVi^06YZJP1_Kfl0Rh^;0:6QX@1E
EED0:RXZ02l_;`0d=3@0ATI606YZJP22PX80R8R809FEU@2TY:@0]KFe09bLW02;Rh/0Q8B407inOP1m
OGd0QHF507moO`25QHD0Y:BT0;>c/`2LW9`0HV9R0451@@0j>SX0@41004];B`16ATH0@41003<c<`0g
=cL0<30`03Lg=`0i>CT0C4a<07IfMP28R8P207UiN@0<055AD@0j>SX0?clo02l_;`0c<c<0AdM706MW
I`1kNg/0AdM702LW9`0T92@09BDU0P0Z:RX0:@0`<300>3Ph03Hf=P1KFe/0NGUi03Lg=`0h>3P0Cdm?
06][J`1XJ6P0FUYJ02h^;P0b<S80CDe=05UIF@1YJFT0MWIf0820P01ZJVX0LW9b075aL@25QHD0Ti>C
06=SH`1;Bd/0G5aL05iNGP21PH40PX:204];B`0Z:RX08b<S02LW9`0];Bd0:2PX02/[:`0];Bd09RHV
02d];@0Y:BT0;Bd]0080;2`/00h0<30`03@d=00d=3@0:b/[02XZ:P0_;bl0>CTi03Ph>00_;bl0<30`
02`/;00S8b<09bLW02HV9P808b<S00/08R8R024Q8@0V9RH0ATI607alO02IVIT0P820069RHP1LG5`0
Ogmo0;>c/`020<?3``040:f][@2OWil0ZJVY0:ZZZP80/k>c00h0^;Rh0<71`@32`/80b<S80<[:bP35
aLD0alO70<71`@2FUYH0FEUI05=CD`1YJFT0K6a/07AdM080OWin00@0Ph>308R8R025QHD0RXZ:0P2=
SHd0102:RXX0SXj>08j>SP2@T90208n?S`0B096AT@2>SXh0S8b<096AT@2EUID0Shn?08b<S02@T900
SHf=08j>SP25QHD0PH6106e]K@1gMgL0P82007YjNP1^KVh0G5aL0P20P8006P29RHT0QXJ608^;R`1a
LG40KVi^0820P01kNg/0IVIV07emO@2VYZH0V9RH09>CT`2LW9`0YJFU0::RXP2SXj<0VIVI09NGU`2:
RXX0Ph>307inOP1jNWX0MgMg07YjNP1lO7`0PX:20P24Q8@08`1mOGd0Ph>30820P020P800PH610820
P01nOWh0RXZ:09BDU02EUID0W9bL0:JVYP2a/K40]kNg0<g=c@3Jf]X0gmoO0>?Sh`3Lg=`0cLg=0;Jf
]P2ZZZX0Y:BT0:6QX@2HV9P0UiNG092@T02ATI40Shn?08j>SP28R8P0PH6106YZJP1`L700KVi^0080
LW9b0300HF5Q07AdM01MGEd0@d=303/k>`1=CDd0?3`l04=3@`1EEED0EUIF05=CD`1@D500EeMG05IF
EP1CDe<0@D5103/k>`0d=3@0<S8b03`l?00c<c<0:BTY02<S8`0/;2`0<c<c02l_;`0i>CT0>SXj04];
B`1GEeL0De=C030`<00d=3@0>c/k04e=C@2EUID0VYZJ0;Ng]`2o_kl0V9RH08^;R`1UIFD0EEEE0492
@P1KFe/0HV9R059BDP0h>3P203Hf=P0<02h^;P0_;bl0;Rh^02h^;P0a<C40<c<c038b<P0_;bl0:BTY
03@d=00h>3P0>CTi0`0f=SH07@0`<300=SHf04=3@`1JFUX0Jf][07]kN`22PX80S8b<08^;R`29RHT0
QhN708B4Q028R8P0SXj>092@T02LW9`0Xj>S0:6QX@2RXZ80WinO09^KV`2IVIT0WIfM09ZJVP2HV9P0
Vi^K09ZJVP2KVi/0VYZJ0080Vi^K00D0V9RH09^KV`2IVIT0V9RH09JFUP0209NGU`0709:BTP2DU9@0
U9BD09JFUP2EUID0V9RH09NGU`0209VIV@0;09>CT`2FUYH0UiNG09JFUP2KVi/0UIFE09NGU`2FUYH0
U9BD09JFUP2IVIT00P2KVi/01P2JVYX0V9RH09RHV02GUiL0UIFE09>CT`80U9BD00D0SHf=08n?S`2A
TI40Ti>C092@T00208n?S`0608j>SP2<S8`0SXj>08f=S@2<S8`0R8R80P29RHT02P28R8P0S8b<08Z:
RP23Ph<0QHF508V9R@28R8P0Q8B408V9R@28R8P209FEU@0;09VIV@2UYJD0Y:BT0:ZZZP2][Jd0/;2`
0;6a/@2e]KD0]kNg0;Vi^@2k^k/00`2l_;`0202k^k/0_Kfm0;bl_02h^;P0_;bl0;jn_P2k^k/0_Kfm
3P38h=P000`0b>3H0`1XJ6P02@1ZJVX0IVIV06YZJP1XJ6P0IFEU06a/K01]KFd0IVIV065QH@0205mO
G`80FEUI00@0Fe]K05QHF01GEeL0DE5A0P1@D500501BDU80DE5A04=3@`18B4P0C4a<05]KF`1XJ6P0
O7al0861P@29RHT0Shn?09FEU@2NWYh0WinO0:>SX`2XZ:P0ZZZZ0:^[Z`2YZJT0/K6a0P2b/[803@2d
];@0/K6a0;Fe]@2d];@0]KFe0;:b/P2f][H0^KVi0;Bd]02h^;P0/[:b0;Bd]02][Jd00P2TY:@05`2K
Vi/0Ti>C08j>SP29RHT0P820075aL@1VIVH0GEeM05IFEP1CDe<0EeMG05EEE@1IFET0FUYJ05]KF`1P
H600IFEU069RHP1WIfL0JFUY06YZJP1VIVH0LG5a0080L71`00T0KFe]07EeM@1aLG40LG5a06i^KP1/
K6`0SHf=09ZJVP10@4000P0Z:RX02P0W9bL0<S8b04a<C01RHV80Kfm_07inOP2OWil0[jn_09ZJVP2L
W9`2092@T00F08b<S02>SXh0OWin08J6QP2DU9@0Y:BT0;Zj^P2l_;`0M7Ad04=3@`0c<c<0<S8b03`l
?00j>SX0=cLg02`/;00^;Rh0>3Ph04M7A`1aLG40P82006i^KP80JVYZ00`0J6QX05]KF`1GEeL0ADE5
03De=@0k>c/0@T9206EUI@1YJFT0=3@d02PX:00R8R8202DU9@0P02XZ:P0b<S80?Cdm061PH01jNWX0
9bLW03De=@1JFUX0HV9R05YJFP18B4P0=SHf04A4A016ATH0EUIF06EUI@1aLG40U9BD07]kN`1XJ6P0
IFEU0861P@2QXJ40KFe]04i>CP1`L700ADE504I6AP1/K6`0GemO03Hf=P0V9RH202d];@0=02`/;00V
9RH0:RXZ02d];@0^;Rh0:b/[030`<00_;bl0:b/[02d];@0^;Rh0<C4a02l_;`02030`<00;03<c<`0b
<S80>CTi03<c<`0^;Rh0:b/[034a<@0T92@09RHV028R8P0S8b<00P0P8200200Z:RX0GUiN08V9R@2L
W9`0Kfm_05UIF@1WIfL0W9bL0P30`<004032`/80XZ:R0:BTY02XZ:P0[jn_0;2`/02k^k/0_Kfm0<;2
`P38b<P0c/k>0<K6aP35aLD0a/K60<;2`P2FUYH2061PH00;06UYJ@1^KVh0MWIf07QhN01oOgl0QHF5
08>3P`26QXH0Rh^;08B4Q027QhL00P29RHT01P2?Shl0SHf=09:BTP2ATI40T92@08n?S`80TY:B01d0
RHV908J6QP24Q8@0R8R808Z:RP23Ph<0NWYj06e]K@1XJ6P0MgMg07emO@1TI6@0FEUI07IfMP21PH40
PX:208B4Q01oOgl0JFUY06YZJP20P800Lg=c06EUI@1oOgl0WinO0:>SX`2XZ:P0YjNW0;>c/`020:n_
[`0:0:RXZ02NWYh0T92@08R8R01mOGd0MgMg07emO@1hN7P0OWin07alO080PH6105T0PX:208>3P`24
Q8@0Q8B408N7Q`22PX80PH6108Z:RP2?Shl0UYJF09bLW02WYjL0];Bd0;^k^`3>c/h0f][J0>7Qh@3S
hn<0fMWI0<g=c@2d];@0ZJVY0:b/[02WYjL0Y:BT09nOW`2FUYH0U9BD09>CT`2GUiL0TI6A08>3P`1l
O7`0Ng]k075aL@22PX80MGEe071`L01nOWh0F5QH03lo?`12@T80?Shn03dm?@0o?cl0@41004=3@`0o
?cl0@d=305QHF01IFET0EEEE04E5A@0g=cL0>3Ph03Lg=`0i>CT0=3@d02l_;`0];Bd0<30`03Lg=`0d
=3@0=CDe03Hf=P13@d<0De=C055AD@0e=CD0<30`038b<P1DE5@0UiNG09VIV@2d];@0^KVi09>CT`22
PX80GUiN05EEE@15ADD0E5AD06=SH`1CDe<0@41003Ti>@0l?3`0;Bd]02h^;P02038b<P0:02l_;`0g
=cL0<30`03Lg=`0_;bl0<c<c03/k>`0l?3`0@d=303@d=080<S8b0140=SHf0492@P1=CDd0GEeM07Ad
M01oOgl0QhN708V9R@2:RXX0QXJ608>3P`25QHD0RXZ:08j>SP2HV9P0WYjN09fMW@0209jNWP0609ZJ
VP2KVi/0WIfM09fMW@2LW9`0Vi^K0P2JVYX01@2GUiL0Vi^K09RHV02IVIT0Vi^K0080UiNG0`2CTi<0
2@2FUYH0VIVI09RHV02IVIT0UiNG0:2PX02LW9`0VYZJ09jNWP0209JFUP0G09VIV@2GUiL0VIVI09VI
V@2GUiL0UYJF09RHV02JVYX0V9RH09bLW02KVi/0W9bL09RHV02GUiL0UYJF09RHV02DU9@0Ti>C09:B
TP2DU9@0TI6A08f=S@2DU9@00`2@T9000`2<S8`0Rh^;08R8R00208b<S00C08Z:RP2>SXh0S8b<08N7
Q`2;Rh/0QhN708R8R025QHD0QXJ608V9R@2:RXX0R8R808N7Q`26QXH0SHf=092@T02EUID0VYZJ0:6Q
X@020:RXZ0070:b/[02b/[80];Bd0;Jf]P2i^KT0]kNg0;Rh^0020;Zj^P80_;bl00<0^;Rh0;bl_02k
^k/00P2n_[h>0<SPf0003038h=P206][J`80IfMW0P1SHf<04P1WIfL0HV9R069RHP1YJFT0Jf][06=S
H`1PH600GEeM05]KF`1LG5`0Fe]K05MGE`1EEED0DU9B05ADE01@D500CDe=04Y:BP80B4Q80100Cdm?
05YJFP1UIFD0M7Ad0820P023Ph<0SXj>09FEU@2IVIT0WYjN0:JVYP2YZJT0Zj^[0:f][@2b/[80/K6a
0`2c/k<20;Bd]0040;Ng]`2e]KD0]KFe0;Ng]`80]KFe0P2d];@03P2c/k<0Zj^[0:>SX`2RXZ80WIfM
09>CT`2=SHd0RHV907]kN`1`L700JFUY05eMG@1EEED0DU9B0P1@D500201FEUH0G5aL061PH01QHF40
HV9R05mOG`1VIVH0JFUY0P1[Jf/01@1ZJVX0L71`075aL@1]KFd0Kfm_0080L71`02T0Jf][06e]K@2=
SHd0ZJVY03hn?P0U9BD0;Rh^02@T900Z:RX0=cLg03lo?`1>CTh0Hf=S0820P02IVIT0W9bL09:BTP2@
T900UYJF09fMW@2PX:00VYZJ09fMW@2TY:@0WinO09ZJVP34a<@0/k>c08V9R@1=CDd0;bl_03@d=00_
;bl0:BTY02XZ:P0T92@0<C4a04Q8B01aLG40GemO051@D00205mOG`0J06][J`1dM7@0Q8B408F5Q@1/
K6`0De=C04U9B@18B4P0GUiN05EEE@0[:b/092@T02LW9`0T92@0:2PX02TY:@0e=CD0GEeM07UiN@0]
;Bd0=3@d065QH@1IFET0DE5A04Y:BP1?Cdl204i>CP0O05eMG@1NGUh0Ogmo09FEU@1kNg/0DU9B06EU
I@22PX80ZJVY071`L01_Kfl0Lg=c0410@00h>3P0>SXj061PH019BDT0:b/[02l_;`0^;Rh0<30`02XZ
:P0S8b<0:BTY02XZ:P0_;bl0;2`/03Hf=P0];Bd0;Rh^02l_;`02030`<00>02/[:`0Z:RX0:b/[038b
<P0/;2`0>SXj02d];@0i>CT0:2PX02@T900U9BD092@T02DU9@0S8b<2028R8P0703Ti>@1gMgL0W9bL
08N7Q`1OGel0HF5Q0861P@020;Ng]`0=0<[:bP2i^KT0YZJV0:NWY`2ZZZX0/K6a0;Jf]P2j^[X0_[jn
0<?3``3:b/X0bl_;0<W9b@020<;2`P0B0;no_`2:RXX0GUiN05mOG`1XJ6P0MGEe07MgM`21PH40PX:2
07alO022PX80RXZ:0861P@27QhL0PX:208F5Q@2BTY80SXj>0P2?Shl07`2=SHd0Shn?08n?S`2=SHd0
QXJ607QhN01fMWH0OGem07inOP1oOgl0OWin06a/K01]KFd0Jf][07alO01_Kfl0H61P07YjNP25QHD0
R8R809:BTP2FUYH0TI6A09>CT`2WYjL0X:2P08f=S@2OWil0XZ:R0:BTY02_[jl00P2/[:`0402[Zj/0
[Zj^0:f][@2OWil0U9BD08b<S023Ph<0OWin0820P01lO7`0Ogmo07AdM01kNg/0PX:207]kN`1nOWh2
0820P080Ph>301l0QXJ608f=S@2BTY80UIFE09fMW@2[Zj/0]kNg0<30`03@d=00fm_K0=oOg`3QhN40
eMGE0<W9b@2c/k<0[Jf]0:j^[P2UYJD0WinO0:2PX02?Shl0QHF508R8R02ATI40UYJF08j>SP25QHD0
PH6108j>SP2IVIT0Vi^K0080WIfM0380R8R80861P@1eMGD0HV9R05]KF`1>CTh0@D51038b<P0_;bl0
>3Ph05ADE01CDe<0Bd];04I6AP0k>c/0=cLg03De=@0n?Sh0>CTi03@d=00Y:BT0<C4a04Q8B00g=cL0
=SHf03@d=00j>SX0EEEE04a<C00];Bd0;Rh^03@d=01CDe<0UIFE09bLW02h^;P0][Jf092@T01oOgl0
Fe]K04e=C@1>CTh0F5QH06IVIP19BDT0=SHf04A4A012@T80<c<c02`/;0@0<S8b01X0<30`02l_;`0Y
:BT0:2PX038b<P0k>c/0?Cdm03Ti>@0a<C40;Rh^03Hf=P0j>SX0Ng]k05QHF01/K6`0NGUi08N7Q`2@
T900RXZ:08F5Q@28R8P0QHF508V9R@2=SHd0UIFE09fMW@80WYjN0280WIfM09^KV`2KVi/0W9bL09fM
W@2JVYX0WIfM09VIV@2MWId0V9RH09BDU02IVIT0Vi^K09ZJVP2DU9@0UYJF09>CT`2FUYH0U9BD09FE
U@2KVi/0V9RH09FEU@2HV9P0VYZJ09bLW02WYjL0/K6a0:2PX02FUYH0V9RH09NGU`2IVIT0Ti>C0P2L
W9`00`2IVIT0W9bL09JFUP0209VIV@0409fMW@2JVYX0VIVI09JFUP80V9RH00<0Ti>C09FEU@2?Shl0
0P2DU9@05P2FUYH0U9BD092@T02@T900Shn?08^;R`2:RXX0S8b<096AT@2=SHd0Shn?08b<S028R8P0
RHV908F5Q@26QXH0Rh^;08b<S025QHD0Rh^;08N7Q`28R8P308F5Q@0308f=S@2>SXh0UiNG0080X:2P
00<0YZJV0:b/[02/[:`00P2a/K402`2d];@0][Jf0;Ng]`2h^;P0^k^k0;Vi^@2g]kL0_Kfm0;^k^`2n
_[h0_kno00h0b>3H000<0<SPf080J6QX00L0IfMW06QXJ01WIfL0IfMW06ATI01PH600I6AT0080Hf=S
00<0H61P069RHP1SHf<00P1IFET06@1MGEd0FUYJ05]KF`1DE5@0GEeM051@D01<C4`0Bd];04U9B@11
@D40D51@05QHF01YJFT0MgMg08:2PP26QXH0SXj>09VIV@2HV9P0WIfM0:BTY02UYJD0ZJVY0:b/[02b
/[800`2d];@01@2c/k<0];Bd0;Jf]P2b/[80];Bd0080]kNg0P2e]KD08@2c/k<0][Jf0:n_[`2ZZZX0
YJFU0:2PX02MWId0TY:B08V9R@2:RXX0PH61075aL@1VIVH0HF5Q05UIF@1FEUH0De=C05QHF01EEED0
FEUI05aLG01MGEd0H61P06EUI@1YJFT0Hf=S06IVIP1]KFd0KVi^06a/K01_Kfl0LG5a06YZJP0206i^
KP0?079bLP1VIVH0NWYj09nOW`1DE5@0;Rh^034a<@0/;2`0:b/[02h^;P0b<S80>c/k04I6AP1QHF40
QhN70080T92@00T0W9bL0:6QX@2PX:00UIFE09nOW`2`/;00a<C40<30`02UYJD00P3=cLd03@2d];@0
Ti>C05=CD`0h>3P0<S8b02d];@0`<300;Bd]03<c<`1DE5@0I6AT0410@00^;Rh00P0c<c<0E00j>SX0
BTY:06MWI`1kNg/0QHF508R8R024Q8@0J6QX05iNGP1]KFd0<S8b02@T900Q8B40:b/[020P800S8b<0
<C4a04e=C@1^KVh0:2PX03Lg=`1IFET0Fe]K04m?C`1>CTh0B4Q804i>CP1NGUh0D51@06=SH`2;Rh/0
QXJ607QhN00g=cL0E5AD07moO`2WYjL0MGEe07AdM01`L700Bd];0451@@0c<c<0ATI6059BDP0T92@0
<S8b02/[:`0X:2P092@T02DU9@0[:b/09BDU02`/;00_;bl0=3@d038b<P0a<C40<30`034a<@0h>3P0
<S8b02h^;P0i>CT0<30`034a<@0_;bl0:RXZ03Ph>00_;bl09bLW02HV9P0];Bd08R8R024Q8@0O7al0
8b<S02`/;01BDU80Q8B409nOW`1]KFd0EUIF06a/K080Vi^K01l0`/;20<_;b`2_[jl0Xj>S0:NWY`2/
[:`0][Jf0;Vi^@2l_;`0_[jn0<S8b039bLT0b/[:0<K6aP34a<@0aLG50;jn_P2DU9@0HV9R05aLG01/
K6`0N7Qh07]kN`1lO7`0Ng]k0861P@26QXH0OWin0861P@1mOGd0Q8B40080Ti>C0100TI6A092@T02?
Shl0SHf=08N7Q`28R8P0PH61071`L01]KFd0LW9b06UYJ@1/K6`0N7Qh079bLP1_Kfl0M7Ad0P25QHD0
202?Shl0UiNG09^KV`2GUiL0WYjN0:VYZ@2WYjL0[:b/0P2b/[802P2ZZZX0/K6a0;Bd]02k^k/0_Kfm
0;6a/@2PX:00Vi^K09NGU`2DU9@208R8R00;08V9R@24Q8@0Ph>307inOP1iNGT0MgMg07UiN@1cLg<0
N7Qh0820P023Ph<00P21PH406`20P800NGUi08:2PP2=SHd0U9BD09NGU`2MWId0ZJVY0;Jf]P31`L40
clo?0=_Kf`3Ogml0gMgM0=KFeP38b<P0Z:RX09ZJVP2CTi<0Ogmo07alO01fMWH0NGUi07EeM@21PH40
S8b<09RHV00209>CT`0S09VIV@2HV9P0W9bL0:2PX02MWId0WYjN09NGU`2;Rh/0QXJ60820P01aLG40
GUiN04a<C00i>CT0;2`/030`<00n?Sh0BTY:04=3@`0n?Sh0>CTi03Ph>00k>c/0>3Ph03@d=00`<300
;bl_034a<@1:BTX0=cLg038b<P0h>3P0>CTi05]KF`1EEED00P0`<3004`0e=CD0F5QH09^KV`2PX:00
_;bl0;Fe]@2BTY80L71`05EEE@1<C4`0EeMG05QHF01/K6`0@T9203De=@14A4@0@D5104M7A`0_;bl0
0P0^;Rh0900[:b/0;bl_03Xj>P0];Bd0:b/[038b<P0d=3@0>c/k03De=@0j>SX0>c/k034a<@0[:b/0
=SHf0492@P1<C4`0HV9R07IfMP27QhL0SXj>096AT@2:RXX0S8b<08N7Q`26QXH0T92@09:BTP2GUiL0
XJ6Q09nOW`2PX:00W9bL09^KV`2IVIT0WIfM09bLW080WYjN00L0VIVI09fMW@2FUYH0UiNG09fMW@2F
UYH0VYZJ0080UiNG00@0UYJF08n?S`2HV9P0UIFE0P2GUiL0102JVYX0W9bL09VIV@2UYJD20:RXZ005
09JFUP2IVIT0VYZJ09ZJVP2EUID00P2IVIT0102JVYX0WYjN09^KV`2KVi/209NGU`0309FEU@2JVYX0
VIVI00@0UYJF00D0U9BD09>CT`2EUID0U9BD09:BTP0209>CT`0608n?S`2ATI40SXj>08b<S02>SXh0
TI6A0P2=SHd06@2BTY80Rh^;08R8R028R8P0Rh^;08Z:RP2;Rh/0Shn?08J6QP25QHD0RHV908R8R023
Ph<0OGem08N7Q`2=SHd0TI6A09VIV@2MWId0XJ6Q0:BTY02YZJT0Zj^[0:f][@2c/k<00P2e]KD20;Jf
]P050;Ng]`2i^KT0_Kfm0;fm_@2o_kl03P38h=P000`0b>3H0P1SHf<02`1PH600IFEU06IVIP1VIVH0
HV9R06=SH`1PH600Hf=S06IVIP1QHF40Hf=S0080Fe]K00P0GEeM05aLG01GEeL0FUYJ05]KF`1FEUH0
Cdm?04U9B@80BTY:0140B4Q805=CD`1IFET0Jf][07]kN`1oOgl0RHV908b<S02CTi<0VYZJ09jNWP2T
Y:@0YjNW0:b/[02][Jd0[Zj^0;2`/0020;6a/@040;>c/`2d];@0/[:b0;>c/`80][Jf01L0]KFe0;Bd
]02b/[80];Bd0;>c/`2^[Zh0[:b/0::RXP2SXj<0VYZJ09BDU028R8P0QHF507moO`1bLW80IfMW05eM
G@1FEUH0DU9B05ADE01EEED0DU9B05QHF00205eMG@0505UIF@1SHf<0IFEU065QH@1WIfL00P1ZJVX0
1P1]KFd0Kfm_06e]K@1YJFT0Kfm_06e]K@80Jf][00H0LG5a07alO01ZJVX0@41003Ph>00_;bl202XZ
:P0502/[:`0f=SH0>CTi04Y:BP1nOWh00P1hN7P06025QHD0VIVI09RHV02LW9`0Z:RX0;Jf]P2m_Kd0
Zj^[09jNWP2e]KD0f=SH0>_[j`3Jf]X0_Kfm08:2PP1CDe<0?3`l02/[:`0b<S80>CTi06i^KP1GEeL0
:RXZ02PX:0809bLW05@0;Bd]02h^;P0_;bl0@D5105]KF`1iNGT0Ph>30820P01cLg<0Jf][05IFEP0_
;bl0;2`/02l_;`0V9RH08b<S02PX:012@T80I6AT03Hf=P0n?Sh0FEUI065QH@1DE5@0C4a<0410@01G
EeL0CDe=04Y:BP1XJ6P0Shn?07IfMP1hN7P0<C4a04m?C`1dM7@0YJFU08>3P`1YJFT0G5aL04M7A`1;
Bd/0<c<c02d];@0^;Rh09BDU02h^;P0i>CT0;2`/02LW9`0T92@09bLW02TY:@0a<C40=3@d02`/;00a
<C40;Bd]030`<00l?3`0@41003Xj>P0f=SH0;Rh^02`/;00`<300<S8b04A4A00k>c/0;bl_03@d=00[
:b/08b<S02LW9`0U9BD08R8R02`/;00Y:BT0>c/k06i^KP2ATI40Ti>C05mOG`1PH60207alO00G0:b/
[03>c/h0_kno09jNWP2SXj<0YZJV0:j^[P2d];@0^[Zj0;^k^`35aLD0b<S80<[:bP38b<P0a/K60<C4
a02o_kl0_;bl08n?S`1PH600HV9R07MgM`1iNGT00P1kNg/02@1oOgl0PH610861P@20P800OWin08R8
R02@T900Ti>C092@T00208f=S@0?08b<S022PX80O7al07AdM01[Jf/0Hf=S06UYJ@1CDe<0Bd];075a
L@1mOGd0QhN708Z:RP2BTY80UIFE0080WIfM00@0WinO0:RXZ02][Jd0/;2`0P2k^k/06031`L40a<C4
0<71`@2i^KT0[jn_0:NWY`2ZZZX0Vi^K09:BTP2>SXh0QhN707alO01eMGD0MWIf08:2PP20P800QXJ6
07inOP1mOGd0N7Qh07MgM`1iNGT0Ng]k0820P0<0PX:201T0QHF50820P024Q8@0SXj>09BDU02JVYX0
YjNW0:f][@2k^k/0`l?30=3@d03MgMd0gmoO0>3Ph03EeMD0b/[:0:FUY@1nOWh0M7Ad06IVIP1PH600
G5aL06a/K01gMgL0Ogmo0080SXj>01H0RHV908Z:RP2>SXh0V9RH0:6QX@2WYjL0[Zj^0;Bd]02^[Zh0
Y:BT09jNWP2=SHd0O7al06IVIP1LG5`0CDe=03De=@0^;Rh0=3@d0492@P10@400?Shn0P0h>3P0200e
=CD0>SXj03Ph>00a<C40<30`038b<P0f=SH0<S8b0P0c<c<0100f=SH0Fe]K05MGE`0i>CT203Ph>00=
05aLG02MWId0YJFU0;fm_@2`/;00Rh^;06m_K`1CDe<0EEEE05eMG@1DE5@0IFEU04I6AP0203hn?P03
03<c<`0e=CD0;Bd]0080;Rh^01l0:BTY02l_;`0/;2`0;Bd]02`/;00a<C40;bl_03Lg=`0e=CD0>3Ph
02l_;`0[:b/0:2PX030`<00_;bl0@d=305UIF@1eMGD0Q8B408Z:RP2<S8`0RHV908Z:RP26QXH0P820
08f=S@2BTY80Vi^K09bLW02MWId0X:2P0080Vi^K00P0V9RH09ZJVP2LW9`0WinO09VIV@2GUiL0VYZJ
09FEU@80VYZJ00X0VIVI09JFUP2IVIT0VIVI09>CT`2EUID0VIVI09^KV`2JVYX0V9RH0P2JVYX05@2I
VIT0XZ:R0::RXP2KVi/0UYJF09^KV`2IVIT0Vi^K09JFUP2HV9P0VIVI09^KV`2JVYX0UiNG09^KV`2J
VYX0VIVI09RHV02FUYH0UiNG09BDU00209JFUP0609FEU@2IVIT0Ti>C09>CT`2BTY80U9BD0P2@T902
096AT@05092@T02BTY80U9BD08j>SP2BTY800P2>SXh01`28R8P0Rh^;08V9R@26QXH0SXj>08b<S02;
Rh/00P29RHT01025QHD0R8R808R8R026QXH208B4Q00508R8R02=SHd0V9RH09^KV`2OWil00P2RXZ80
1P2UYJD0[:b/0;2`/02_[jl0/;2`0;6a/@80][Jf00<0^[Zj0;^k^`2o_kl03P38h=P000`0b>3H0P1R
HV801P1UIFD0Hf=S06EUI@1XJ6P0IFEU069RHP80Hf=S00<0HV9R06=SH`1QHF400P1PH6001@1FEUH0
GEeM05eMG@1KFe/0F5QH0080De=C01@0CDe=04Y:BP19BDT0A4A4059BDP1JFUX0I6AT07AdM01lO7`0
R8R8096AT@2EUID0UiNG09jNWP2TY:@0Z:RX0:b/[02][Jd0[jn_0;6a/@80];Bd00<0/k>c0;Bd]02e
]KD00P2c/k<06P2b/[80][Jf0;:b/P2a/K40]KFe0;Jf]P2^[Zh0ZJVY0::RXP2MWId0UiNG09:BTP2=
SHd0Ogmo07UiN@1bLW80IVIV061PH01FEUH0DU9B05QHF01BDU80FEUI05aLG01IFET0GUiN0P1SHf<0
0`1TI6@0IFEU06UYJ@0206MWI`05071`L01ZJVX0KVi^06YZJP1/K6`00P1^KVh09`1]KFd0K6a/06QX
J01YJFT0Hf=S051@D014A4@0?Cdm04=3@`0_;bl0=3@d03<c<`1NGUh0IFEU05IFEP1>CTh0H61P07Ui
N@22PX80UIFE0:NWY`2h^;P0/;2`09FEU@2IVIT0[Zj^0;Zj^P3UiND0mOGe0?;blP3Shn<0`L71075a
L@0k>c/0<c<c04E5A@1UIFD0@d=302LW9`0302PX:080:BTY00/09bLW02/[:`0b<S80BDU906IVIP1_
Kfl0KVi^06ATI01JFUX0BDU904I6AP02038b<P0S02XZ:P0/;2`0=cLg05EEE@1@D500De=C05]KF`1O
Gel0F5QH05MGE`1DE5@0EeMG04M7A`11@D40IVIV08J6QP1YJFT0M7Ad03Ph>01CDe<0LG5a09^KV`23
Ph<0FUYJ04U9B@0`<300?Cdm0410@00b<S80:BTY02LW9`0_;bl0?clo038b<P0/;2`00P0W9bL02P0T
92@0:BTY030`<00i>CT0>3Ph038b<P0^;Rh0=SHf04=3@`0o?cl202h^;P0D03Hf=P0`<300;2`/02h^
;P0a<C40=cLg02LW9`0T92@0:2PX02DU9@0T92@08B4Q020P800i>CT0:RXZ04e=C@25QHD0Vi^K07al
O01SHf<206IVIP0;08R8R032`/80aLG509bLW02EUID0WinO0:f][@2a/K40^KVi0;Fe]@30`<000P37
alL00`36a/H0alO70<G5a@020<71`@0@0;bl_02BTY80IVIV06UYJ@1bLW80Ogmo07alO01kNg/0NWYj
07alO01nOWh0Ng]k08N7Q`2>SXh0Rh^;08f=S@80QXJ60300QHF5079bLP1ZJVX0GemO05]KF`1MGEd0
GemO05iNGP1^KVh0MgMg08:2PP2;Rh/0SHf=08>3P`25QHD0RXZ:09>CT`2NWYh0][Jf0;^k^`31`L40
aLG50<O7a`3;bl/0c/k>0=7Ad@3>c/h0alO70;Jf]P2NWYh0T92@08V9R@2ATI40V9RH08^;R`1cLg<0
L71`07alO023Ph<0PX:207emO@1iNGT0LW9b07EeM@1iNGT0O7al08B4Q021PH4208:2PP030861P@25
QHD0Q8B40080SHf=02h0VIVI0:BTY02YZJT0]kNg0<S8b03AdM40g=cL0>3Ph03MgMd0e]KF0<[:bP2U
YJD0OGem06IVIP1JFUX0FEUI065QH@1hN7P0P82008Z:RP28R8P0P82007UiN@1aLG40MGEe08V9R@2@
T900WinO0;>c/`2j^[X0]KFe0:f][@2/[:`0WinO092@T01hN7P0I6AT05=CD`15ADD0<C4a02l_;`0g
=cL0?Cdm03Hf=P0c<c<0<30`0P0f=SH01P0c<c<0=CDe030`<00^;Rh0=3@d03Ph>080<c<c01P0<30`
05aLG01HF5P0=cLg034a<@0i>CT0Fe]K09fMW@2[Zj/0_kno0:>SX`28R8P0IfMW04E5A@1;Bd/0I6AT
04e=C@1PH600DU9B04a<C018B4P0>3Ph034a<@0];Bd2034a<@0T038b<P0];Bd0<S8b02d];@0/;2`0
<30`03De=@0h>3P0>SXj03/k>`0`<300;Bd]038b<P0_;bl0:b/[03<c<`1=CDd0IfMW07moO`2;Rh/0
Shn?08R8R02:RXX0QHF508N7Q`2=SHd0S8b<09JFUP2JVYX0WYjN0::RXP2LW9`0WIfM09bLW02NWYh0
WinO0P2LW9`0202JVYX0W9bL09RHV02HV9P0VYZJ09VIV@2HV9P0Vi^K0P2GUiL03`2EUID0V9RH09NG
U`2FUYH0V9RH09NGU`2KVi/0XZ:R0:BTY02JVYX0VIVI09BDU02FUYH0VIVI09ZJVP0209JFUP0709^K
V`2GUiL0W9bL09ZJVP2HV9P0VYZJ09NGU`0209ZJVP0309RHV02DU9@0UIFE0080UYJF00D0UIFE09VI
V@2BTY80UYJF09BDU00309FEU@80TI6A0P2DU9@02@2<S8`0T92@08n?S`2@T900RXZ:08j>SP2:RXX0
QhN7096AT@0208b<S00808n?S`2=SHd0QhN708N7Q`26QXH0R8R808:2PP23Ph<20861P@0908N7Q`2=
SHd0Ti>C09VIV@2KVi/0X:2P0::RXP2VYZH0ZJVY0080[:b/00D0/K6a0;:b/P2e]KD0]kNg0;Zj^P0>
0<SPf0003038h=P206ATI00>06UYJ@1WIfL0HV9R05eMG@1RHV80I6AT061PH01SHf<0I6AT06=SH`1T
I6@0GEeM05iNGP1EEED305YJFP0505EEE@1CDe<0Cdm?04i>CP1;Bd/00P14A4@0401BDU80Fe]K06][
J`1fMWH0O7al08R8R02?Shl0UiNG09ZJVP2KVi/0XJ6Q0:JVYP2][Jd0[Zj^0;:b/P2d];@20;6a/@07
0;Fe]@2d];@0/K6a0;>c/`2d];@0/k>c0;Jf]P020;Bd]00D0;>c/`2`/;00[jn_0:j^[P2SXj<0XZ:R
09^KV`2@T900SHf=07moO`1hN7P0Lg=c06YZJP1JFUX0EUIF04];B`1@D500E5AD051@D01GEeL205]K
F`80HF5Q03@0IVIV06UYJ@1TI6@0J6QX065QH@1[Jf/0K6a/06QXJ01_Kfl0JFUY06QXJ01[Jf/0I6AT
06e]K@1RHV80IfMW06YZJP1[Jf/0IFEU06][J`1/K6`0>c/k03Ph>00d=3@0?clo03Lg=`0`<300=cLg
03Ti>@1;Bd/0EUIF07IfMP2=SHd0][Jf09RHV02=SHd0Z:RX0;no_`2g]kL0`/;20=kNgP3dm?@0l_;b
0>KViP3?cll0Ti>C03Lg=`0j>SX0C4a<030`<00U9BD0:2PX0P0_;bl0200X:2P08b<S02HV9P0V9RH0
;Rh^03<c<`1CDe<0IFEU0P1BDU802P18B4P0E5AD05=CD`1IFET0B4Q803<c<`0b<S80@41005IFEP1E
EED204I6AP0n05ADE01ADE40CTi>065QH@1NGUh0Fe]K04E5A@1PH600Q8B406UYJ@1XJ6P0BTY:05IF
EP1^KVh0TI6A08J6QP1>CTh0=cLg02XZ:P0[:b/0=cLg03De=@0/;2`0;Rh^02TY:@0o?cl0;2`/02/[
:`0f=SH0;2`/02l_;`0[:b/0=SHf03dm?@0j>SX0=SHf02d];@0X:2P0=cLg0410@00a<C409bLW02HV
9P0Y:BT0;2`/02l_;`0`<300=CDe02HV9P0U9BD0;Rh^02d];@0Q8B408b<S024Q8@0Z:RX0=SHf03`l
?01HF5P0R8R809JFUP1SHf<205QHF00;06IVIP2SXj<0`/;20:^[Z`2FUYH0W9bL0:b/[02e]KD0/[:b
0;Bd]02m_Kd00P33`l<06P37alL0bLW90<G5a@37alL0`L710<C4a031`L40W9bL06a/K01ZJVX0Lg=c
07MgM`1jNWX0LW9b07IfMP1nOWh0O7al08>3P`2<S8`0Ph>308n?S`28R8P0O7al07IfMP1SHf<0De=C
0P13@d<00`1BDU80Hf=S07=cL`0207MgM`0V07alO024Q8@0N7Qh06a/K01UIFD0IVIV07AdM029RHT0
Xj>S0;Zj^P35aLD0a/K60<[:bP3=cLd0clo?0=7Ad@3?cll0b/[:0<K6aP2`/;00UiNG08R8R02@T900
SXj>09BDU01aLG40KVi^07UiN@25QHD0OWin07AdM01aLG40NGUi07AdM01lO7`0Ng]k07alO01oOgl3
08:2PP0K08>3P`26QXH0QXJ6092@T02DU9@0XZ:R0:ZZZP2h^;P0alO70<o?c`3Kfm/0g=cL0=gMg@3E
eMD0cLg=0:j^[P1nOWh0I6AT065QH@1[Jf/0OGem08V9R@2FUYH0Rh^;079bLP1YJFT0F5QH0080Cdm?
00l0EUIF06ATI01kNg/0W9bL0;Ng]`2e]KD0/K6a0:b/[02WYjL0VIVI07]kN`1XJ6P0DE5A04A4A00j
>SX00P0f=SH02P0_;bl0;Rh^030`<00`<300<c<c03Ph>00e=CD0<S8b02LW9`0Y:BT203De=@0G02d]
;@0_;bl0=3@d05ADE01HF5P0<S8b03<c<`0e=CD0Fe]K09bLW02XZ:P0^KVi0:6QX@2<S8`0IFEU03dm
?@1ADE40GemO05IFEP1ADE40GemO04U9B@17AdL00P0d=3@01P0^;Rh0<c<c03<c<`0d=3@0<c<c03Lg
=`80<C4a00H0:b/[02h^;P0h>3P0>SXj03/k>`0e=CD2038b<P0702/[:`0^;Rh0<S8b05=CD`1SHf<0
O7al08R8R00308b<S00908R8R02=SHd0QhN708b<S02CTi<0WIfM0::RXP2OWil0WYjN0080WIfM00T0
W9bL09ZJVP2JVYX0W9bL09^KV`2NWYh0VYZJ09^KV`2LW9`00P2JVYX0102HV9P0UiNG09NGU`2GUiL3
09VIV@0>09RHV02FUYH0Vi^K0:6QX@2KVi/0W9bL09FEU@2IVIT0V9RH09ZJVP2KVi/0WIfM09NGU`2K
Vi/209ZJVP0309^KV`2MWId0Vi^K0080VYZJ00/0W9bL09JFUP2LW9`0WIfM09VIV@2GUiL0U9BD09NG
U`2HV9P0VYZJ09VIV@0209:BTP0B09FEU@2CTi<0UiNG09BDU02CTi<0Shn?096AT@2@T900Shn?08b<
S02=SHd0Shn?08b<S02;Rh/0SHf=08Z:RP2<S8`0RHV90P27QhL02`26QXH0Ph>308B4Q024Q8@0P820
0861P@20P800QXJ608F5Q@2@T900Shn?0080UiNG00T0WIfM0::RXP2QXJ40Xj>S0:^[Z`2ZZZX0[jn_
0;Fe]@2f][H03P38h=P000`0b>3H0P1UIFD0101TI6@0Hf=S05mOG`1TI6@2069RHP0=06=SH`1VIVH0
HF5Q061PH01OGel0H61P05YJFP1FEUH0Fe]K05iNGP1FEUH0G5aL05=CD`0204e=C@0C04U9B@15ADD0
BTY:05EEE@1IFET0JFUY07=cL`21PH40QhN708f=S@2EUID0VYZJ09^KV`2RXZ80Z:RX0:^[Z`2`/;00
/K6a0;Bd]0020;6a/@0Y0;>c/`2`/;00/K6a0;Fe]@2f][H0]KFe0;Ng]`2c/k<0][Jf0;:b/P2a/K40
[Jf]0:ZZZP2QXJ40XZ:R09JFUP2ATI40Rh^;07emO@1iNGT0LG5a06MWI`1NGUh0EeMG055AD@1@D500
CDe=05=CD`1EEED0FUYJ05eMG@1KFe/0HF5Q06UYJ@1UIFD0I6AT06EUI@1VIVH0JVYZ06UYJ@1XJ6P0
0P1YJFT206MWI`0X06IVIP1]KFd0I6AT06=SH`1WIfL0K6a/06IVIP1dM7@0PH6106][J`1>CTh0>CTi
038b<P0h>3P0>SXj038b<P0];Bd0=3@d034a<@17AdL0R8R80:^[Z`26QXH0RXZ:0;>c/`33`l<0_[jn
0;Vi^@3;bl/0gmoO0>k^kP3Rh^80dm?C0;^k^`1iNGT0@4100451@@0Z:RX0;2`/02XZ:P80;bl_0`0Y
:BT0200V9RH0:BTY034a<@0d=3@0E5AD065QH@1MGEd0?clo0P0h>3P07`15ADD0A4A403`l?00h>3P0
?3`l05EEE@18B4P0?3`l03Ti>@0n?Sh0?Cdm04M7A`1EEED0CTi>05MGE`1@D500F5QH08b<S01fMWH0
J6QX05QHF01ADE40M7Ad096AT@1mOGd0B4Q803Hf=P0V9RH0:2PX02d];@0j>SX00P0`<300500b<S80
>CTi03`l?00e=CD0:2PX02h^;P0Z:RX0;Rh^03@d=015ADD0Cdm?03dm?@0Z:RX0:BTY034a<@0j>SX0
<S8b02d];@0/;2`0:2PX0P0];Bd00`0f=SH0>3Ph02PX:00202LW9`0;02@T900Q8B409BDU02XZ:P0`
<300<S8b03De=@0o?cl0KVi^09FEU@1lO7`00P1CDe<04@1FEUH0OWin0:n_[`2i^KT0WinO09RHV02Y
ZJT0/;2`0;>c/`2d];@0_;bl0;jn_P33`l<0alO70<W9b@3:b/X0a<C400<0aLG500H0a<C40:2PX01]
KFd0J6QX075aL@1eMGD207IfMP0;07moO`22PX80Q8B408:2PP1lO7`0PX:207alO01eMGD0K6a/05IF
EP11@D400P0_;bl04P19BDT0Hf=S075aL@1`L700MGEe07QhN01aLG40GemO059BDP0o?cl0@T9204];
B`1HF5P0Ogmo09jNWP2l_;`0b/[:0<_;b`80b/[:00h0c/k>0<c<c036a/H0`l?30;bl_02SXj<0U9BD
08Z:RP24Q8@0N7Qh06YZJP1dM7@0OWin07YjNP80L71`00L0Lg=c07alO01mOGd0N7Qh07IfMP1kNg/0
NWYj0080QXJ603H0Q8B408^;R`2:RXX0Shn?09BDU02KVi/0YJFU0:^[Z`2_[jl0`L710<o?c`3GemL0
fm_K0=gMg@3Hf=P0clo?0;Fe]@1oOgl0Hf=S06m_K`1bLW80PH61092@T02DU9@0Kfm_05YJFP1=CDd0
Bd];05UIF@1HF5P0EUIF04];B`1<C4`0Lg=c09jNWP2d];@0][Jf0;6a/@2WYjL0Vi^K08:2PP1ZJVX0
D51@0451@@0e=CD0<C4a038b<P0^;Rh0;2`/030`<00c<c<0<C4a03<c<`0X:2P202h^;P@0:b/[01D0
;Bd]03@d=01@D500GemO03Xj>P0d=3@0>SXj06QXJ02ZZZX0ZJVY0;Vi^@2KVi/0QhN705aLG00n?Sh0
EUIF05eMG@1IFET0DU9B05aLG01?Cdl00P0k>c/203Ph>080=SHf00D0;Rh^030`<00^;Rh0=cLg03De
=@0203<c<`0503lo?`0j>SX0=CDe034a<@0];Bd00P0/;2`05P0[:b/0<30`03`l?01QHF40M7Ad08>3
P`2@T900Ti>C08^;R`2=SHd0Shn?08^;R`2?Shl0TY:B09VIV@2NWYh0WinO0::RXP2OWil0Vi^K09fM
W@2KVi/209bLW00A09NGU`2LW9`0Vi^K09jNWP2MWId0UiNG09FEU@2KVi/0VYZJ09RHV02GUiL0VYZJ
09NGU`2FUYH0V9RH09NGU`2LW9`00P2IVIT0302FUYH0VIVI09JFUP2GUiL0VYZJ09RHV02FUYH0VIVI
09JFUP2HV9P0Vi^K09bLW0L0V9RH00P0UiNG09JFUP2FUYH0UiNG09RHV02GUiL0Vi^K09JFUP80UIFE
00P0SXj>09JFUP2CTi<0UIFE09BDU02ATI40TY:B096AT@80Ti>C00/0Shn?08j>SP2ATI40T92@096A
T@2:RXX0RHV908N7Q`2;Rh/0R8R808V9R@0208J6QP0308R8R022PX80Ph>30080Ph>300h0Ogmo08F5
Q@26QXH0S8b<08j>SP2ATI40VIVI09ZJVP2LW9`0XZ:R0:FUY@2ZZZX0[Zj^0;6a/@h0b>3H000<0<SP
f080JFUY00@0H61P06ATI01SHf<0Hf=S0P1PH6001P1RHV80H61P06=SH`1UIFD0J6QX05mOG`@0G5aL
01P0F5QH05EEE@1ADE40D51@04i>CP1:BTX0@d=304M7A`1>CTh0EUIF06MWI`1hN7P0P82008B4Q02@
T900UIFE09ZJVP2PX:00Xj>S0:NWY`2YZJT0[jn_0;:b/P2`/;030;6a/@090:n_[`2a/K40];Bd0;Jf
]P2d];@0/k>c0;Jf]P2`/;00/[:b0080/K6a0180[:b/0::RXP2OWil0UYJF08n?S`28R8P0QhN707]k
N`1bLW80I6AT05aLG01EEED0CTi>04U9B@1DE5@0De=C05MGE`1BDU8205]KF`0<065QH@1RHV80GEeM
065QH@1UIFD0IVIV06UYJ@1/K6`0Jf][06ATI01PH600IVIV0P1[Jf/0401/K6`0GEeM06MWI`1[Jf/0
J6QX06a/K01YJFT0LW9b07YjNP1[Jf/0EEEE04M7A`18B4P0@D5103Xj>P0a<C4202/[:`0E0410@02J
VYX0[:b/075aL@1^KVh0RHV909JFUP2][Jd0`L710=GEe@3=cLd0dm?C0<K6aP2d];@0[Jf]09ZJVP1[
Jf/0>CTi02XZ:P0X:2P0:RXZ0080:BTY02d0;Bd]034a<@0S8b<092@T02LW9`0_;bl0<30`03hn?P1N
GUh0HV9R05=CD`15ADD0>3Ph03Lg=`0c<c<0<30`03dm?@13@d<0DU9B03hn?P1:BTX0>3Ph03dm?@14
A4@0EUIF03Ti>@0h>3P0?Shn04Q8B01EEED0Ph>308R8R01fMWH0HF5Q05MGE`1oOgl0VIVI07EeM@10
@400;Rh^02LW9`0c<c<0:b/[030`<00d=3@00P0_;bl04P0f=SH0@41002h^;P0/;2`0:2PX02`/;00X
:2P0>SXj059BDP1dM7@0CDe=02XZ:P0/;2`0=3@d030`<00e=CD0;2`/02d];@80:b/[0140=CDe03@d
=00`<300:RXZ030`<00/;2`09bLW02PX:00[:b/09bLW02h^;P0X:2P09BDU02`/;010@400OGem08Z:
RP0206MWI`18055AD@1VIVH0RHV90:JVYP2QXJ40T92@09NGU`2SXj<0Z:RX0:^[Z`2k^k/0^KVi0<71
`@36a/H0aLG50<S8b037alL0aLG50<C4a032`/80alO70<?3``2HV9P0K6a/06=SH`1`L700LW9b07Yj
NP1nOWh0PH6107emO@1dM7@0MGEe07UiN@1]KFd0I6AT061PH01:BTX0<S8b02/[:`0c<c<0A4A405aL
G01YJFT0LW9b07emO@1aLG40FEUI03hn?P0i>CT0=SHf03dm?@0j>SX0@D5104e=C@1[Jf/0X:2P0<K6
aP3@d=00c/k>0=3@d03?cll0dM7A0<[:bP38b<P0`<300;2`/02NWYh0Ph>3079bLP1QHF40IVIV0P1m
OGd02P1dM7@0IVIV06m_K`1bLW80MgMg07alO01eMGD0LG5a07]kN`21PH4208:2PP1E08J6QP29RHT0
RXZ:08j>SP2CTi<0Vi^K0::RXP2YZJT0/K6a0;bl_03<c<`0eMGE0=KFeP3Kfm/0fMWI0=KFeP2o_kl0
QXJ606QXJ01YJFT0K6a/0820P026QXH0MWIf055AD@11@D40EEEE06MWI`1TI6@0H61P069RHP1BDU80
ADE504M7A`1_Kfl0XJ6Q0;>c/`2][Jd0YJFU09ZJVP27QhL0KFe]059BDP15ADD0?Cdm02h^;P0e=CD0
=SHf02PX:00^;Rh0;2`/02l_;`0];Bd0:2PX02l_;`0^;Rh0:2PX02d];@0X:2P09bLW02`/;00e=CD0
DU9B06EUI@0a<C40;Bd]03De=@1ZJVX0/;2`0:NWY`2i^KT0Vi^K08B4Q01GEeL0?clo05]KF`1GEeL0
C4a<04Q8B01FEUH0CTi>03Ph>00f=SH0=CDe03Lg=`02038b<P0502h^;P0o?cl0>SXj030`<00e=CD0
0P0a<C406`0n?Sh0?3`l03De=@0c<c<0;2`/034a<@0];Bd0;bl_034a<@0e=CD0FEUI06a/K022PX80
Shn?09:BTP2=SHd0RXZ:08R8R027QhL0R8R808n?S`2GUiL0VIVI09jNWP2MWId0WYjN09nOW`0209fM
W@0809^KV`2NWYh0Vi^K09fMW@2HV9P0VYZJ09fMW@2GUiL209VIV@0;09RHV02GUiL0TI6A09NGU`2N
WYh0Vi^K09FEU@2GUiL0VIVI09ZJVP2GUiL00`2FUYH01`2IVIT0VYZJ09RHV02DU9@0UiNG09fMW@2K
Vi/00P2HV9P01`2FUYH0V9RH09NGU`2JVYX0Vi^K09FEU@2JVYX00P2LW9`01P2HV9P0UiNG09JFUP2E
UID0VIVI09JFUP80U9BD00@0T92@09>CT`2=SHd0VIVI0P2CTi<02`2?Shl0U9BD09NGU`2DU9@0T92@
08j>SP2ATI40Ti>C092@T02<S8`0R8R80080RHV900P0SHf=08N7Q`2;Rh/0QhN708J6QP25QHD0Ogmo
08>3P`80PH6100d0O7al0820P023Ph<0Q8B408N7Q`2=SHd0TY:B09BDU02JVYX0WinO0:>SX`2WYjL0
[:b/00h0b>3H000<0<SPf080I6AT00@0HF5Q06=SH`1WIfL0IFEU0P1PH6008P1TI6@0Hf=S069RHP1M
GEd0IFEU061PH01MGEd0Fe]K05aLG01HF5P0FEUI05eMG@1ADE40D51@04i>CP1=CDd0A4A404U9B@1?
Cdl0G5aL06QXJ01gMgL0PH6108>3P`2?Shl0U9BD09^KV`2NWYh0Y:BT0:NWY`2ZZZX0/;2`0:j^[P2d
];@20;6a/@0G0;Fe]@2b/[80][Jf0;Bd]02a/K40]kNg0;Fe]@2d];@0/k>c0;Fe]@2`/;00Zj^[0:ZZ
ZP2RXZ80WinO09VIV@2>SXh0Rh^;08>3P`1kNg/0LW9b069RHP1IFET00P1?Cdl01@1ADE40D51@051@
D01HF5P0DE5A0080Fe]K0P1TI6@00`1SHf<0GUiN06ATI00206YZJP80J6QX00P0Jf][069RHP1YJFT0
JVYZ06ATI01VIVH0JVYZ06UYJ@<0IVIV00@0I6AT06EUI@1/K6`0J6QX0P1SHf<06`1HF5P0Bd];03`l
?00];Bd0<C4a03/k>`1eMGD0^;Rh09bLW01FEUH0@T9205EEE@1^KVh0Z:RX0=3@d03Bd]80`/;20;:b
/P2ZZZX0WYjN0:6QX@2LW9`0RXZ:06QXJ01@D500;Rh^03Hf=P0203@d=00503De=@0b<S80:b/[02LW
9`0V9RH00P0Z:RX0C@0c<c<0@d=305UIF@1_Kfl0Hf=S04];B`0_;bl0<S8b02d];@0^;Rh0Bd];05EE
E@0i>CT0@d=303De=@0j>SX0BTY:05UIF@0e=CD0:RXZ03<c<`10@400BTY:07UiN@24Q8@0Jf][05YJ
FP1FEUH0Ng]k09fMW@1aLG40>SXj02l_;`0[:b/0;2`/02l_;`0f=SH0<S8b02l_;`0/;2`09RHV03Ph
>00X:2P09RHV02LW9`0V9RH0;Bd]0410@01UIFD0Ogmo04m?C`0e=CD0;Rh^034a<@0Y:BT0=CDe02/[
:`0Y:BT0<C4a02d];@0a<C40?Cdm02d];@0X:2P0;Bd]02HV9P0/;2`0:b/[02PX:00S8b<0;Bd]02LW
9`0T92@09RHV02l_;`1JFUX0N7Qh0080Lg=c01<0DE5A05aLG01mOGd0UiNG0;6a/@2NWYh0Ti>C09NG
U`2CTi<0VIVI0::RXP2ZZZX0];Bd0;^k^`33`l<0a/K60<W9b@3:b/X0b<S80080aLG502P0`l?30<;2
`P2HV9P0IfMW06e]K@1UIFD0Lg=c07QhN01jNWX0MGEe06i^KP1TI6@0HF5Q05mOG`1FEUH0CTi>03Lg
=`0_;bl0<c<c04E5A@1CDe<0FUYJ06a/K01oOgl0Lg=c05QHF00k>c/0?3`l04m?C`1GEeL0FUYJ051@
D01=CDd0=cLg0451@@1aLG40[Jf]0<o?c`3Cdm<0d];B0P3Cdm<03P3=cLd0c/k>0<[:bP2f][H0WYjN
07]kN`1MGEd0E5AD06=SH`1nOWh0MWIf06IVIP1RHV80Jf][0P1_Kfl0101eMGD0LW9b07IfMP1jNWX3
0820P00E08J6QP28R8P0RHV9092@T02GUiL0XZ:R0:6QX@2WYjL0]KFe0;Ng]`35aLD0clo?0=OGe`3J
f]X0e]KF0=CDe035aLD0VYZJ06i^KP1MGEd0JFUY0080N7Qh01L0GEeM03Xj>P1EEED0HF5Q06ATI01M
GEd0EUIF05QHF01IFET0EeMG04I6AP10@400Ng]k0:j^[P2][Jd0YjNW09bLW02?Shl0L71`05IFEP15
ADD0?clo02h^;P0202d];@0Q02XZ:P0Y:BT0:2PX02l_;`0`<300:BTY02`/;00f=SH0;2`/02XZ:P0^
;Rh0:b/[02`/;00a<C40ATI606QXJ00e=CD0;Bd]038b<P1bLW80[jn_0:b/[02f][H0VYZJ08F5Q@1C
De<0B4Q8065QH@1KFe/0Bd];04Y:BP1DE5@0F5QH0080>SXj00<0=CDe03hn?P0d=3@00P0d=3@07P0_
;bl0;Bd]03<c<`0c<c<0=3@d03Lg=`0l?3`0>3Ph03De=@0d=3@0;Rh^02d];@0^;Rh0<30`02d];@0f
=SH0DU9B06QXJ01oOgl0S8b<092@T02;Rh/0S8b<08Z:RP25QHD0PX:208^;R`2EUID0UiNG09VIV@80
WIfM00/0Vi^K09ZJVP2LW9`0WIfM09nOW`2LW9`0Vi^K09jNWP2OWil0WIfM09JFUP0309RHV00509fM
W@2FUYH0W9bL09VIV@2FUYH00P2IVIT209JFUP80UiNG00X0UYJF09RHV02JVYX0W9bL09fMW@2HV9P0
Vi^K09ZJVP2NWYh0VIVI0P2HV9P0302IVIT0WIfM09fMW@2KVi/0VIVI09bLW02EUID0UiNG09JFUP2G
UiL0Vi^K09RHV080UYJF0P2CTi<02`2DU9@0SXj>09:BTP2FUYH0Ti>C09JFUP2>SXh0U9BD09:BTP2E
UID0TY:B00<0TI6A0100SHf=092@T02ATI40T92@08f=S@27QhL0Shn?08j>SP2;Rh/0RHV908R8R020
P800Q8B40820P026QXH0P8200`1oOgl02@20P800PX:208Z:RP2;Rh/0TI6A09>CT`2KVi/0Xj>S0:2P
X00>0<SPf0003038h=P306=SH`80HV9R00<0JVYZ05eMG@1PH6000P1UIFD0301MGEd0IVIV05mOG`1J
FUX0GEeM05aLG01KFe/0EUIF05MGE`1IFET0EEEE05ADE080Cdm?0180B4Q804Y:BP1BDU80GEeM06a/
K01fMWH0Ph>308F5Q@2<S8`0UiNG09VIV@2QXJ40Z:RX0:FUY@2/[:`0/K6a0;2`/02^[Zh20;2`/080
/K6a01H0[jn_0;>c/`2b/[80]KFe0;Jf]P2b/[80][Jf0;>c/`2][Jd0[Zj^0:RXZ02TY:@0WIfM09JF
UP2@T900Rh^;08>3P`1kNg/0L71`06MWI`1LG5`0D51@0P18B4P0501:BTX0CTi>05IFEP1GEeL0E5AD
061PH01SHf<0GEeM06UYJ@1SHf<0IFEU06IVIP1RHV80IVIV06EUI@1WIfL0HF5Q06ATI01[Jf/0J6QX
0P1TI6@00`1WIfL0Jf][069RHP02069RHP80IVIV01h0GUiN061PH01PH600GemO05MGE`16ATH0=3@d
03<c<`1:BTX0V9RH0;Vi^@25QHD0EEEE05=CD`1/K6`0XZ:R0;jn_P34a<@0]KFe0:VYZ@2FUYH0UiNG
09>CT`2GUiL0VIVI09JFUP29RHT0Ogmo05eMG@1]KFd207=cL`1:05IFEP11@D409BDU02LW9`0X:2P0
;2`/02LW9`0S8b<0;bl_03Ti>@1eMGD0N7Qh05]KF`1<C4`0=cLg02TY:@0W9bL0>CTi04i>CP1GEeL0
BDU903De=@0g=cL0C4a<04i>CP0_;bl0;Bd]038b<P0k>c/0@d=306IVIP20P800Hf=S04i>CP1ADE40
IFEU09FEU@1`L700>CTi034a<@0_;bl0<30`02h^;P0Z:RX0;bl_030`<00a<C40;2`/03Ph>00^;Rh0
:b/[02TY:@0[:b/0<C4a04E5A@1iNGT0MgMg04I6AP0n?Sh0;2`/02TY:@0Z:RX0;2`/02XZ:P0];Bd0
;2`/02XZ:P0`<300>SXj02h^;P0Z:RX09RHV02PX:00Y:BT202/[:`0302DU9@0W9bL08b<S00809BDU
00<0;Rh^04Y:BP1YJFT00P24Q8@0401bLW80EUIF06a/K02CTi<0_;bl0;no_`2XZ:P0XJ6Q09VIV@2E
UID0VIVI0:RXZ02][Jd0/k>c0;jn_P33`l<20<[:bP040<_;b`36a/H0`L710<K6aP80alO701X0Ti>C
06UYJ@1RHV80IfMW07AdM01^KVh0JFUY05aLG01DE5@0DU9B04i>CP12@T80>c/k02h^;P0[:b/0;Bd]
04E5A@1:BTX0GEeM07EeM@1iNGT0Hf=S04=3@`0j>SX0E5AD069RHP80EUIF01P0Fe]K05=CD`18B4P0
>CTi0492@P1nOWh0aLG50=7Ad@3>c/h0d=3@0=;BdP3=cLd0c/k>0<S8b02f][H0UIFE06a/K01<C4`0
ATI606a/K01nOWh0JVYZ05aLG01PH602071`L00606e]K@1`L700MWIf07UiN@1jNWX0OGem0P21PH40
5`25QHD0RXZ:08R8R02=SHd0UIFE09bLW02QXJ40YJFU0;6a/@2i^KT0`L710<S8b03De=@0f=SH0=OG
e`3Cdm<0bl_;0:RXZ01lO7`0FUYJ05EEE@1WIfL0HF5Q0080?Cdm03`0GUiN06ATI01IFET0Bd];04=3
@`1GEeL0JFUY05EEE@1;Bd/0>SXj05MGE`2RXZ80/;2`0:JVYP2MWId0SHf=07AdM01>CTh0?Shn03/k
>`0];Bd0:b/[02XZ:P0W9bL0:b/[02d];@0_;bl0<C4a02l_;`0b<S80:BTY02d];@0a<C40:RXZ02LW
9`0[:b/0;Bd]03`l?01SHf<0>c/k02`/;00c<c<0Ng]k0:VYZ@2_[jl0];Bd09ZJVP24Q8@0Cdm?051@
D01VIVH0GEeM04e=C@11@D40F5QH05EEE@0d=3@0>SXj04E5A@0m?Cd2030`<00702`/;00];Bd0<30`
03@d=00a<C40<c<c038b<P0203@d=00>03De=@0f=SH0<c<c03De=@0`<300=cLg03@d=00h>3P0B4Q8
069RHP1dM7@0QHF508f=S@2@T90208b<S00Z08N7Q`28R8P0Rh^;09:BTP2GUiL0W9bL09nOW`2RXZ80
X:2P09fMW@2QXJ40WinO09bLW02NWYh0Vi^K09nOW`2PX:00WIfM09bLW02GUiL0VYZJ09bLW02KVi/0
U9BD09FEU@2HV9P0VYZJ09RHV02GUiL0UYJF09FEU@2DU9@0UYJF09ZJVP2FUYH0Vi^K09VIV@2GUiL0
VYZJ09VIV@2KVi/0VYZJ0P2HV9P01`2GUiL0V9RH09^KV`2JVYX0Vi^K09RHV02IVIT00P2HV9P01P2K
Vi/0UiNG09NGU`2EUID0UYJF09BDU080V9RH00P0U9BD09:BTP2CTi<0VIVI09FEU@2JVYX0Ti>C09BD
U0<0TI6A0P2DU9@03`2?Shl0SHf=08n?S`2@T900S8b<08j>SP2;Rh/0SXj>08^;R`28R8P0RXZ:08B4
Q025QHD0Q8B407moO`0208>3P`0<07inOP21PH40PX:20861P@22PX80P82008J6QP28R8P0SHf=096A
T@2EUID0VYZJ3P38h=P000`0b>3H0P1VIVH04P1TI6@0HV9R061PH01SHf<0GEeM06ATI01OGel0HF5Q
05mOG`1UIFD0GEeM06=SH`1MGEd0G5aL05eMG@1FEUH0EEEE05QHF080De=C01@0Cdm?04Y:BP16ATH0
Bd];05IFEP1NGUh0KFe]07IfMP26QXH0R8R808j>SP2DU9@0VIVI0:2PX02TY:@0Z:RX0:f][@2`/;00
/[:b0;>c/`80/;2`00P0/K6a0:f][@2a/K40];Bd0;6a/@2e]KD0/[:b0;Jf]P80/K6a02<0/[:b0;Fe
]@2XZ:P0XJ6Q09jNWP2KVi/0Shn?08^;R`21PH40Ng]k075aL@1RHV80E5AD04i>CP17AdL0BDU904Y:
BP1?Cdl0EEEE05IFEP1GEeL0G5aL05]KF`1SHf<0IFEU05aLG01TI6@0Hf=S06ATI01SHf<0IfMW06IV
IP1UIFD0I6AT065QH@0406=SH`0806a/K01VIVH0IVIV06ATI01SHf<0IFEU065QH@1MGEd205aLG00E
05]KF`1DE5@0A4A403Xj>P1>CTh0T92@0;Rh^02LW9`0UIFE0:j^[P2j^[X0`/;20;2`/02TY:@0UiNG
09JFUP2CTi<0SHf=09ZJVP2EUID0Ti>C0080UIFE00<0NGUi06UYJ@2BTY800P2IVIT0>`2>SXh0IVIV
034a<@0Y:BT0:b/[02XZ:P0T92@09bLW02TY:@0^;Rh0Bd];071`L01YJFT0GEeM04E5A@0Z:RX09BDU
02l_;`0`<300CTi>05UIF@0l?3`0=cLg04A4A00k>c/0;Bd]034a<@0[:b/0>c/k04Q8B01HF5P0R8R8
05mOG`12@T80HF5Q05]KF`27QhL0Lg=c0492@P0e=CD0=cLg038b<P0_;bl0:b/[02h^;P0a<C40:BTY
02PX:00e=CD0:RXZ030`<00V9RH09bLW02h^;P1BDU80R8R805ADE00f=SH0A4A40080<30`01L08b<S
02@T900V9RH0;bl_02HV9P0^;Rh0=cLg03Ph>00_;bl0:b/[02TY:@0W9bL0=3@d03Ti>@0b<S80:b/[
02DU9@0X:2P0;Bd]03De=@18B4P0BTY:069RHP0208V9R@0C09fMW@1eMGD0H61P07AdM02YZJT0cLg=
0;no_`2ZZZX0Y:BT0:f][@2ZZZX0/[:b0;^k^`2f][H0_Kfm0;bl_038b<P0bLW90<_;b`020<K6aP0N
0<g=c@39bLT0b<S80<;2`P2=SHd0GEeM065QH@1[Jf/0IFEU065QH@1FEUH0De=C0410@00e=CD0<c<c
030`<00a<C40;Bd]02l_;`12@T80AdM705mOG`1cLg<0Jf][04M7A`0d=3@0G5aL069RHP1JFUX0B4Q8
0P12@T801`1JFUX0K6a/04Y:BP0e=CD0EeMG0;6a/@3?cll00P3<c<`05P3>c/h0bl_;0<S8b02o_kl0
Zj^[0820P01HF5P0ATI605QHF01lO7`0N7Qh05iNGP1JFUX0K6a/07MgM`1bLW80L71`075aL@1cLg<0
N7Qh07]kN`21PH4208J6QP1D08N7Q`28R8P0Rh^;08f=S@2ATI40VIVI09fMW@2VYZH0/;2`0;Ng]`30
`<00alO70=3@d03Hf=P0f][J0=WIf@3De=@0_[jn0861P@1UIFD0CTi>04m?C`1>CTh0<c<c03`l?01D
E5@0D51@03lo?`0Z:RX0;Rh^04Q8B01EEED0AdM705=CD`1<C4`0ADE509FEU@2b/[80Z:RX0:2PX02;
Rh/0Jf][059BDP14A4@0=cLg02LW9`0_;bl0=SHf02XZ:P0[:b/0;bl_02h^;P0_;bl0=3@d02XZ:P0_
;bl0:BTY03<c<`1:BTX0@41002/[:`0b<S80?clo061PH00k>c/0:b/[03/k>`24Q8@0Zj^[0;6a/@2^
[Zh0UYJF07]kN`18B4P0EEEE06QXJ01GEeL0ADE504A4A01GEeL0EUIF03Lg=`0k>c/0@T920`0f=SH0
900b<S80<c<c030`<00b<S80<C4a030`<00^;Rh0<c<c034a<@0c<c<0<30`034a<@0[:b/0;Rh^030`
<00g=cL0>3Ph0451@@1HF5P0LW9b0820P02ATI40Shn?096AT@2=SHd0R8R808f=S@29RHT0SHf=09JF
UP2JVYX0WIfM0:6QX@2MWId0WinO09fMW@80WYjN00@0WIfM09bLW02OWil0WIfM0P2PX:002P2IVIT0
Vi^K09VIV@2FUYH0UiNG09JFUP2JVYX0UiNG09bLW02FUYH209NGU`0809VIV@2GUiL0UiNG09JFUP2H
V9P0UiNG09RHV02JVYX209VIV@0B09NGU`2IVIT0UiNG09RHV02GUiL0VIVI09FEU@2KVi/0V9RH09JF
UP2IVIT0Vi^K09RHV02KVi/0VYZJ09NGU`2HV9P0VYZJ0`2FUYH0102KVi/0TY:B09>CT`2EUID209>C
T`0509FEU@2@T900U9BD09BDU02CTi<00P2BTY80102@T900TY:B08j>SP2@T90208n?S`0408j>SP2<
S8`0RXZ:08f=S@80R8R80P25QHD01023Ph<0QXJ608N7Q`23Ph<208:2PP0807moO`1mOGd0Ph>307Yj
NP20P800QhN708^;R`2>SXh>0<SPf0003038h=P2069RHP0;06=SH`1RHV80GemO06IVIP1LG5`0H61P
06=SH`1OGel0HF5Q061PH01KFe/00P1NGUh06`1KFe/0FUYJ05MGE`1EEED0De=C055AD@1CDe<0DE5A
04Y:BP18B4P0C4a<055AD@1NGUh0L71`07QhN025QHD0QhN708^;R`2EUID0VYZJ0:2PX02SXj<0ZJVY
0:j^[P2`/;00[Jf]0;Fe]@020;Bd]00>0;:b/P2_[jl0[Zj^0:n_[`2b/[80/;2`0;Bd]02_[jl0];Bd
0;>c/`2e]KD0/[:b0:ZZZP2OWil209VIV@0@092@T02<S8`0PX:207]kN`1[Jf/0GemO05YJFP1=CDd0
BDU904a<C01>CTh0DE5A05IFEP1HF5P0E5AD061PH080HF5Q00d0H61P06=SH`1MGEd0GUiN06ATI01S
Hf<0I6AT06EUI@1PH600GEeM06EUI@1QHF40G5aL0080HF5Q00D0IVIV065QH@1VIVH0H61P065QH@02
05iNGP0G05]KF`1LG5`0FUYJ05IFEP1HF5P0DU9B04U9B@1NGUh0X:2P0<30`02d];@0_[jn0<K6aP2e
]KD0YjNW09>CT`28R8P0RHV909:BTP2CTi<0UiNG09JFUP2CTi<00`2FUYH00`21PH40IfMW08:2PP02
09RHV00809ZJVP26QXH0B4Q802d];@1<C4`0DE5A02/[:`0/;2`202HV9P0R04=3@`18B4P0EEEE06e]
K@1LG5`0?Shn02h^;P0`<3009RHV03Lg=`1=CDd0IVIV04M7A`10@400;bl_02LW9`0S8b<0:BTY038b
<P1BDU80EUIF08>3P`1gMgL0EeMG05YJFP1BDU80PX:2075aL@0e=CD0=3@d03De=@0_;bl0:b/[02h^
;P80;2`/00D09BDU02@T900X:2P0=CDe02/[:`0202`/;00;03@d=01VIVH0SHf=04U9B@0a<C40?Cdm
03De=@0Y:BT09bLW02TY:@0X:2P00P0^;Rh00`0_;bl0;2`/03Xj>P02038b<P0=02XZ:P0[:b/0:RXZ
03@d=00j>SX0=3@d02XZ:P0Y:BT0;bl_04U9B@1;Bd/0>CTi03/k>`0207AdM00<09RHV02>SXh0IfMW
05aLG02<S8`0`/;20<W9b@2d];@0Y:BT0:n_[`2f][H0/k>c0P2i^KT01`2h^;P0]kNg0<30`03<c<`0
clo?0<_;b`37alL00P39bLT02P34a<@0bLW90;fm_@1jNWX0D51@05]KF`1NGUh0EUIF055AD@14A4@2
03Ph>00H03De=@0c<c<0:RXZ02h^;P0d=3@0>3Ph04I6AP1LG5`0IfMW05YJFP0b<S80>CTi05iNGP1M
GEd0C4a<030`<00Y:BT0:b/[04E5A@1`L700CDe=03Ph>012@T80WIfM0P3<c<`30<K6aP0D0<71`@2/
[:`0T92@069RHP16ATH0A4A405eMG@23Ph<0KVi^05ADE01KFe/0M7Ad07YjNP1eMGD0M7Ad075aL@1c
Lg<0R8R808:2PP24Q8@208V9R@0N08^;R`29RHT0T92@08b<S02?Shl0VIVI09bLW02WYjL0[:b/0;Jf
]P2o_kl0alO70=?Cd`3Jf]X0fm_K0=WIf@3Fe]H0c<c<09jNWP1_Kfl0EUIF04E5A@0h>3P0<S8b0451
@@13@d<0?clo03Hf=P0];Bd0:2PX0P0l?3`06`14A4@0Hf=S06YZJP16ATH0Shn?0;>c/`2XZ:P0XJ6Q
08J6QP1PH600C4a<03`l?00e=CD0;Rh^02l_;`15ADD0;Rh^030`<00c<c<0?3`l03De=@0d=3@0;Rh^
02l_;`0e=CD0;Bd]038b<P0202LW9`0D02TY:@0e=CD0GUiN03lo?`0[:b/0=3@d08R8R02WYjL0[jn_
0:VYZ@2DU9@0LW9b05UIF@1GEeL0IVIV04m?C`0o?cl0A4A404I6AP1DE5@203lo?`0Y03/k>`0j>SX0
=SHf03Hf=P0c<c<0<C4a02`/;00_;bl0>CTi03dm?@0a<C40;Rh^034a<@0d=3@0=cLg02d];@0Z:RX0
:b/[02l_;`0b<S80=CDe0492@P1@D500KFe]07]kN`2<S8`0SHf=08n?S`28R8P0SXj>08J6QP2:RXX0
Rh^;09VIV@2KVi/0Xj>S09nOW`2LW9`0X:2P09^KV`2PX:000P2KVi/0202NWYh0X:2P09jNWP2NWYh0
VYZJ09NGU`2IVIT0UiNG0P2HV9P04P2JVYX0VIVI09RHV02GUiL0V9RH09bLW02FUYH0WYjN09ZJVP2I
VIT0V9RH09NGU`2JVYX0VIVI09RHV02GUiL0W9bL09ZJVP80UiNG00h0UYJF09RHV02KVi/0VIVI09RH
V02KVi/0U9BD09NGU`2MWId0V9RH09NGU`2HV9P0VYZJ09NGU`<0VIVI00H0V9RH09NGU`2DU9@0UIFE
09BDU02CTi<3096AT@0<09>CT`2FUYH0UIFE09BDU02CTi<0UIFE096AT@2?Shl0Ti>C08n?S`2BTY80
TI6A0P2>SXh01@2=SHd0S8b<08f=S@28R8P0QhN70080Ph>30`26QXH02@22PX80Q8B408F5Q@21PH40
OWin07moO`21PH40Ph>308:2PP0>0<SPf0003038h=P2061PH00306EUI@1YJFT0JFUY0080GEeM00D0
GUiN06=SH`1MGEd0GemO069RHP0205eMG@0L065QH@1JFUX0Fe]K05QHF01IFET0DU9B055AD@1@D500
DE5A04e=C@18B4P0BDU905=CD`1LG5`0Jf][07QhN022PX80QhN708b<S02HV9P0VIVI09fMW@2UYJD0
ZJVY0:f][@2_[jl0[Zj^0;Fe]@80[Zj^00L0[Jf]0;6a/@2d];@0/K6a0;:b/P2_[jl0/[:b0080];Bd
01d0/K6a0:j^[P2][Jd0YZJV09jNWP2LW9`0TY:B09BDU02;Rh/0PH6107UiN@1aLG40HV9R05=CD`18
B4P0BTY:04e=C@19BDT0CTi>059BDP1HF5P0FEUI05YJFP1LG5`0Fe]K069RHP1UIFD0HV9R06IVIP02
065QH@0806ATI01VIVH0GUiN05mOG`1TI6@0GUiN06ATI01VIVH2061PH00306=SH`1TI6@0Hf=S0080
GEeM0`1LG5`02@1JFUX0EeMG05UIF@1FEUH0EeMG07moO`33`l<0`/;20:n_[`020<G5a@0:09fMW@29
RHT0OWin08B4Q028R8P0SHf=096AT@2BTY80VIVI09JFUP80VIVI00@0VYZJ08>3P`1NGUh0KFe]0P29
RHT02`2<S8`0T92@06UYJ@12@T80?clo04M7A`0d=3@092@T02HV9P0/;2`0>3Ph0080<c<c00D0D51@
07EeM@1SHf<0CTi>03dm?@0202HV9P0K03<c<`1OGel0LW9b04e=C@0a<C409BDU02<S8`0[:b/0;2`/
04Q8B01NGUh0O7al07QhN01SHf<0GEeM05YJFP1fMWH0L71`03Lg=`0_;bl0:b/[02XZ:P0Y:BT0AdM7
02l_;`0^;Rh0<30`00809bLW01H0>3Ph02h^;P0W9bL0;2`/03hn?P1jNWX0OGem03lo?`0[:b/0=CDe
02/[:`0/;2`0:2PX02XZ:P0[:b/0:BTY03<c<`0`<300;bl_034a<@0^;Rh0;bl_0P0[:b/02`0];Bd0
@41004Q8B011@D40>3Ph03Xj>P0U9BD09RHV02LW9`0Q8B409BDU0080DU9B03/0SHf=0:6QX@1nOWh0
H61P06a/K02LW9`0a/K60;fm_@2TY:@0[Jf]0:n_[`2a/K40]kNg0;:b/P2a/K40]kNg0;Vi^@33`l<0
c/k>0<_;b`3:b/X0alO70<71`@38b<P0aLG50<_;b`2g]kL0Jf][055AD@1BDU80F5QH05EEE@1>CTh0
A4A403Ph>00a<C40=CDe02`/;00Z:RX0;2`/03<c<`11@D40DU9B05YJFP1ADE40<S8b03`l?01@D500
Cdm?030`<00V9RH092@T02LW9`0h>3P0FUYJ0451@@0b<S80B4Q80:>SX`020<c<c00G0<O7a`30`<00
`<300;Vi^@2;Rh/0Jf][04Q8B00l?3`0?Shn06QXJ01/K6`0E5AD04];B`1TI6@0Ng]k07alO01hN7P0
NWYj07MgM`1iNGT0P82008N7Q`22PX800P27QhL208^;R`0D09JFUP2=SHd0TI6A09ZJVP2PX:00Xj>S
0:ZZZP2c/k<0_;bl0<O7a`3@d=00d];B0=SHf03GemL0e]KF0=?Cd`31`L40Shn?05aLG013@d<2038b
<P0H03De=@0l?3`0=3@d030`<00[:b/0;Bd]03dm?@0i>CT0CDe=08n?S`29RHT0C4a<09JFUP2`/;00
WinO09:BTP1kNg/0GUiN04=3@`0h>3P0;Bd]02TY:@0];Bd0<30`0P0a<C401@0c<c<0>3Ph03<c<`0a
<C40;Rh^0080<S8b00l0;bl_02h^;P0V9RH09bLW03De=@0o?cl0D51@04U9B@0];Bd0=SHf08^;R`2T
Y:@0/[:b0:RXZ02<S8`00P1UIFD02`1FEUH0K6a/0410@00n?Sh0B4Q803Xj>P1OGel0@T9203dm?@0o
?cl0>c/k0080>3Ph00<0=SHf02d];@0^;Rh00P0_;bl0200`<300:b/[03Hf=P0m?Cd0=3@d03`l?00b
<S80;Rh^0P0`<300200_;bl0<C4a03Xj>P1:BTX0HF5Q07QhN029RHT0T92@0P2ATI405P2:RXX0S8b<
08F5Q@2=SHd0TY:B09ZJVP2NWYh0WinO09bLW02QXJ40X:2P09jNWP2JVYX0WIfM09jNWP2PX:00W9bL
09nOW`2LW9`0WIfM09FEU@2GUiL209bLW00309VIV@2JVYX0VIVI0080V9RH00X0W9bL09VIV@2JVYX0
VYZJ09NGU`2HV9P0WYjN09^KV`2LW9`0VIVI0P2HV9P01@2JVYX0Vi^K09VIV@2GUiL0VYZJ0080VIVI
00/0VYZJ09^KV`2IVIT0Vi^K09VIV@2LW9`0VYZJ09^KV`2IVIT0U9BD09FEU@0309RHV00?09VIV@2G
UiL0UYJF09JFUP2EUID0TY:B09FEU@2BTY80VIVI09FEU@2DU9@0UYJF09RHV02GUiL0TI6A0080T92@
00<0Shn?096AT@2<S8`00P2>SXh01@2<S8`0RHV908R8R029RHT0QHF50080RHV900P0QhN708F5Q@28
R8P0RHV908B4Q029RHT0P82008F5Q@80Ph>300<0Q8B408:2PP38h=P03@38h=P000`0b>3H0P1OGel0
201RHV80HF5Q065QH@1RHV80GUiN05eMG@1NGUh0Fe]K0P1PH60205]KF`0905YJFP1IFET0FUYJ05aL
G01IFET0EEEE04m?C`1FEUH0FUYJ0080Bd];00H0Cdm?055AD@1LG5`0JFUY07=cL`20P80208f=S@08
09BDU02JVYX0WIfM0::RXP2ZZZX0[:b/0;2`/02_[jl30;2`/00H0;:b/P2_[jl0/K6a0;:b/P2`/;00
[jn_0;>c/`2a/K40/;2`0;6a/@2][Jd0Zj^[0:BTY02RXZ80Vi^K09JFUP2@T900SXj>08B4Q01kNg/0
L71`06ATI01HF5P0DU9B0P19BDT204a<C003055AD@1EEED0EUIF0080FUYJ00<0GEeM05aLG01KFe/0
0P1PH6005@1TI6@0H61P069RHP1RHV80HF5Q06IVIP1SHf<0HV9R061PH01SHf<0IVIV069RHP1MGEd0
I6AT06=SH`1NGUh0H61P05iNGP1JFUX0F5QH05MGE`0205QHF00H05EEE@1GEeL0QhN70<g=c@36a/H0
/k>c0;fm_@3>c/h0][Jf08b<S01jNWX0P82008V9R@2=SHd0TI6A09FEU@2FUYH0UIFE09VIV@2MWId0
VIVI08N7Q`1UIFD0G5aL0P21PH40>`27QhL0Ph>306m_K`1@D500CDe=05IFEP0g=cL0;Bd]02DU9@0R
8R80<C4a02l_;`0/;2`0:RXZ05UIF@20P800Lg=c065QH@0e=CD09bLW02h^;P0g=cL0KFe]07IfMP14
A4@09BDU02@T900O7al0:RXZ0410@01EEED0JFUY079bLP1SHf<0GEeM06ATI01mOGd0NGUi04U9B@0j
>SX0;bl_02d];@0W9bL0;2`/02XZ:P0o?cl0?3`l02TY:@0/;2`0<30`02d];@0^;Rh0<30`04M7A`20
P800IFEU02XZ:P0_;bl0;Bd]0080<C4a00P0;Rh^02/[:`0b<S80;bl_02/[:`0];Bd0<30`038b<P80
>c/k00d0;Bd]03<c<`0o?cl0D51@05YJFP1EEED0<S8b02XZ:P0W9bL08R8R024Q8@0O7al08B4Q0080
<S8b01L0LW9b09RHV02LW9`0Jf][05mOG`1iNGT0/K6a0<S8b02`/;00Y:BT0:RXZ02/[:`0/k>c0;Fe
]@2_[jl0]KFe0;Rh^02f][H0b/[:0<k>cP39bLT0alO70<71`@030<G5a@0Y0<C4a02_[jl0JFUY04a<
C01@D500EeMG05EEE@1<C4`0A4A403`l?00b<S80:RXZ02TY:@0Z:RX0<c<c03De=@0m?Cd0CDe=04=3
@`0[:b/0;bl_03hn?P0l?3`0;Bd]02LW9`0T92@0:2PX05QHF01GEeL0@D5105IFEP1iNGT0[Zj^0<[:
bP3<c<`0_kno0;2`/02SXj<0VYZJ065QH@15ADD00P0[:b/03`0k>c/0C4a<04Y:BP0o?cl0Cdm?06e]
K@1kNg/0PX:207alO01iNGT0MWIf07UiN@20P800RXZ:08J6QP0208b<S00L08^;R`2BTY80T92@096A
T@2DU9@0VIVI09jNWP2UYJD0YZJV0:ZZZP2j^[X0`/;20<[:bP3?cll0e]KF0=OGe`3Cdm<0eMGE0<c<
c02e]KD0NWYj055AD@0f=SH0<S8b034a<@0/;2`0:b/[034a<@80;2`/00d0=cLg03Ph>01KFe/0U9BD
0820P015ADD0XJ6Q0:BTY02GUiL0QhN706][J`1@D500=SHf0080:b/[02P0:RXZ02/[:`0d=3@0=cLg
03Hf=P0h>3P0>SXj03De=@0_;bl0<c<c030`<00_;bl0<S8b02h^;P0U9BD09RHV02`/;00^;Rh0D51@
0451@@0[:b/0=cLg08^;R`2RXZ80]kNg0:VYZ@2CTi<0GemO05UIF@1SHf<0F5QH04E5A@0o?cl0@410
03hn?P1HF5P0@d=303`l?00m?Cd0ADE50P0l?3`02`0e=CD0<C4a02d];@0/;2`0=3@d034a<@0d=3@0
=CDe03Lg=`0i>CT0=CDe0080<30`00T0;bl_02h^;P0/;2`0:b/[030`<010@400GEeM075aL@21PH40
0P2@T9002P2CTi<0RXZ:08V9R@26QXH0R8R8096AT@2HV9P0W9bL0:6QX@2PX:0209nOW`0<09bLW02O
Wil0W9bL09fMW@2LW9`0WIfM09^KV`2OWil0VIVI09ZJVP2HV9P0VIVI0`2LW9`05`2GUiL0Vi^K09VI
V@2IVIT0Ti>C09RHV02IVIT0V9RH09ZJVP2GUiL0VIVI09ZJVP2HV9P0Vi^K09ZJVP2IVIT0WYjN09RH
V02DU9@0VIVI09RHV02KVi/0V9RH0080VYZJ00@0Vi^K09VIV@2IVIT0UiNG0P2IVIT0202LW9`0UiNG
09bLW02LW9`0Vi^K09ZJVP2LW9`0VIVI0`2HV9P01`2FUYH0U9BD09BDU02EUID0UiNG09VIV@2HV9P0
0P2FUYH03`2BTY80Shn?096AT@2@T900SXj>096AT@2<S8`0SXj>08f=S@2;Rh/0RXZ:08V9R@2<S8`0
R8R808F5Q@0208B4Q00908V9R@27QhL0Q8B408B4Q028R8P0QXJ608R8R026QXH0Ogmo00h0b>3H000<
0<SPf080Hf=S00@0I6AT05aLG01OGel0Hf=S0P1PH600101QHF40GUiN06=SH`1RHV8305aLG00K05mO
G`1KFe/0FUYJ05aLG01CDe<0Fe]K059BDP1@D500CDe=04Y:BP1>CTh0D51@065QH@1YJFT0O7al07mo
O`28R8P0SXj>09>CT`2EUID0WYjN0:>SX`2VYZH0[:b/0;6a/@2_[jl0/[:b0080/;2`0P2_[jl0102`
/;00/[:b0;>c/`2a/K420;:b/P0?0;2`/02a/K40[Zj^0:ZZZP2VYZH0WinO09fMW@2IVIT0T92@08^;
R`24Q8@0NGUi06i^KP1SHf<0EEEE00<0BTY:00<0@T9204U9B@1?Cdl00P1EEED0501GEeL0FUYJ05UI
F@1TI6@0GemO05]KF`1OGel0Hf=S061PH01OGel0IVIV05mOG`1TI6@0Hf=S061PH01RHV80GEeM06=S
H`1WIfL0GUiN0P1MGEd03@1SHf<0G5aL05YJFP1IFET0HF5Q05UIF@1FEUH0De=C05EEE@1FEUH0PH61
0<k>cP3<c<`00P2h^;P0203Bd]80cLg=0:j^[P1gMgL0O7al08V9R@2@T900SXj>0P2DU9@01`2FUYH0
Vi^K09fMW@2MWId0TY:B07alO01XJ6P00P26QXH0202;Rh/0Ng]k06UYJ@1KFe/0?clo05QHF01ADE40
<30`0P0Z:RX0<00Y:BT0:RXZ02@T900Q8B40<c<c069RHP2ATI40O7al061PH00e=CD0;Rh^02TY:@13
@d<0NGUi06EUI@0b<S809bLW02d];@0`<300ADE505YJFP1GEeL0IFEU05MGE`1?Cdl0H61P08j>SP2=
SHd0HV9R034a<@0X:2P092@T02<S8`0`<300<C4a04Y:BP15ADD0:RXZ034a<@0`<300>3Ph0410@00c
<c<0Cdm?08f=S@1CDe<0:2PX02h^;P80;2`/01P0;bl_02/[:`0X:2P0:BTY02PX:00U9BD0:b/[03@d
=018B4P0IfMW061PH01:BTX0FUYJ05=CD`1]KFd0GUiN02l_;`0Y:BT0:RXZ02PX:00S8b<09BDU028R
8P0P820202HV9P0405=CD`2<S8`0WinO08F5Q@80IFEU00T0TY:B0<?3``36a/H0Zj^[0:b/[02VYZH0
[jn_0;:b/P2^[Zh00P2e]KD0402d];@0a<C40<W9b@3:b/X0a<C40<O7a`35aLD0`<300;jn_P30`<00
b<S80:j^[P1QHF40A4A404Q8B01@D50204];B`0804I6AP0j>SX0:BTY02l_;`0a<C40<30`034a<@0`
<30203De=@0W02l_;`0[:b/0=SHf034a<@0b<S80:2PX02h^;P0`<300C4a<03hn?P15ADD0GUiN0820
P02RXZ80`L710<30`02_[jl0UIFE07MgM`1RHV80>c/k02XZ:P0W9bL09RHV02LW9`0Z:RX0;2`/03<c
<`1ADE40KVi^0861P@27QhL0PH6107inOP1mOGd0P82007inOP27QhL0R8R80080QHF500`0SXj>08b<
S02CTi<0UIFE09RHV02IVIT0XJ6Q0:>SX`2WYjL0[jn_0;Vi^@2o_kl20<_;b`0U0=;BdP3De=@0dM7A
0=?Cd`3?cll0aLG50:NWY`1`L700@D51034a<@0b<S80<c<c02d];@0^;Rh0:RXZ034a<@0k>c/0>SXj
055AD@1aLG40G5aL04];B`2MWId0UYJF08R8R01cLg<0GemO0410@00^;Rh09bLW02TY:@0[:b/0<30`
03Hf=P0h>3P0=SHf03Xj>P0203Lg=`0802h^;P0Y:BT0<30`03@d=00b<S80;Rh^02XZ:P0T92@202l_
;`0F051@D010@400;Bd]0492@P2CTi<0X:2P0;Ng]`2XZ:P0TY:B061PH01CDe<0IVIV04a<C012@T80
@41003/k>`0n?Sh0E5AD051@D00m?Cd0?Shn03`l?080>SXj00h0<c<c030`<00b<S80;Bd]030`<00c
<c<0<S8b03@d=00a<C40<c<c030`<00f=SH0<c<c030`<080<S8b00/0;2`/038b<P0f=SH0C4a<06YZ
JP1nOWh0Rh^;09>CT`2@T900Shn?08Z:RP0208R8R00309FEU@2IVIT0VYZJ0080X:2P00H0Y:BT09jN
WP2LW9`0WinO09jNWP2MWId209jNWP0409^KV`2NWYh0Vi^K09bLW0<0VYZJ00P0VIVI09NGU`2HV9P0
UiNG09ZJVP2KVi/0UYJF09RHV080VYZJ00H0V9RH09VIV@2JVYX0WIfM09RHV02GUiL209VIV@0:09bL
W02MWId0W9bL09bLW02JVYX0W9bL09VIV@2GUiL0VYZJ09VIV@<0VYZJ00@0Vi^K09ZJVP2JVYX0W9bL
0P2KVi/02@2JVYX0V9RH09JFUP2GUiL0UIFE09VIV@2KVi/0UYJF09NGU`0209>CT`80UiNG0P2HV9P0
202GUiL0Ti>C092@T02DU9@0Shn?09>CT`2?Shl0TY:B0`2=SHd0402<S8`0RXZ:08F5Q@28R8P0RXZ:
08N7Q`2:RXX0Rh^;08R8R02<S8`0QXJ608:2PP2<S8`0QXJ608B4Q028R8P>0<SPf0003038h=P205eM
G@0E05aLG01MGEd0HV9R065QH@1MGEd0F5QH05aLG01NGUh0G5aL065QH@1NGUh0FUYJ05]KF`1MGEd0
GUiN05]KF`1OGel0EEEE05UIF@1CDe<0D51@0080C4a<0140CTi>05ADE01MGEd0KFe]07=cL`1oOgl0
QhN7092@T02EUID0UiNG09bLW02TY:@0Zj^[0:ZZZP2^[Zh0[Jf]0;6a/@030:n_[`030:f][@2_[jl0
/;2`0080[jn_01/0/K6a0;2`/02_[jl0/;2`0:j^[P2XZ:P0YZJV09nOW`2LW9`0VIVI09>CT`2;Rh/0
PH6107]kN`1bLW80HV9R05EEE@1>CTh0ATI604a<C018B4P0Bd];04i>CP1CDe<0E5AD05MGE`1JFUX0
0P1HF5P01@1KFe/0G5aL061PH01LG5`0H61P0080GemO00H0HV9R06MWI`1SHf<0H61P05eMG@1NGUh2
065QH@05061PH01OGel0HF5Q06EUI@1QHF400P1OGel04@1IFET0EUIF05QHF01GEeL0De=C05EEE@1^
KVh0[Zj^0<k>cP31`L40[jn_0=3@d03AdM40aLG508R8R01iNGT0Rh^;0080SXj>00D0T92@08n?S`2F
UYH0UIFE09bLW00209jNWP1@09:BTP2:RXX0R8R808R8R029RHT0Rh^;07AdM01GEeL0=cLg03<c<`16
ATH0Cdm?03`l?00_;bl0:BTY024Q8@0R8R808B4Q02HV9P0d=3@0N7Qh0861P@1]KFd0Fe]K04I6AP0b
<S80;bl_05=CD`1nOWh0GUiN04I6AP0g=cL0>CTi05YJFP1HF5P0CTi>05iNGP1JFUX0ADE5055AD@24
Q8@0Ti>C071`L01=CDd0:RXZ02@T900V9RH0<S8b03`l?01ADE40?clo02XZ:P0_;bl0>SXj059BDP1F
EUH0=CDe05aLG027QhL0AdM702DU9@0];Bd0=3@d038b<P0/;2`09BDU02/[:`0Y:BT0:b/[02XZ:P0`
<300?Shn06i^KP1jNWX0L71`06e]K@1VIVH0DU9B03/k>`0[:b/202LW9`0502d];@0Y:BT08R8R028R
8P0V9RH00`0Q8B40400c<c<0JVYZ09>CT`2VYZH0LG5a05mOG`1nOWh0[:b/0<W9b@2m_Kd0YjNW0:VY
Z@2ZZZX0Zj^[0:n_[`2c/k<20;Vi^@060<C4a039bLT0cLg=0<[:bP32`/80a<C40P2n_[h03033`l<0
`L710<G5a@2VYZH0FEUI04=3@`1;Bd/0BDU903hn?P0k>c/0@T9203<c<`80<30`01X0=3@d02l_;`0`
<300<30`02l_;`0g=cL0;bl_03<c<`0`<300;Rh^02`/;00^;Rh0;bl_02`/;00b<S80>3Ph04I6AP1J
FUX0RXZ:0::RXP2FUYH0SXj>06QXJ01>CTh0>3Ph02XZ:P80:BTY0100:b/[02HV9P0Z:RX0;Rh^04=3
@`1TI6@0MGEe08B4Q028R8P0Q8B40861P@1nOWh0P82008:2PP28R8P0RXZ:0P2;Rh/0>02:RXX0Shn?
09:BTP2FUYH0U9BD09VIV@2OWil0XZ:R0:b/[02e]KD0_;bl0;jn_P35aLD0b/[:0<k>cP3=cLd0c<c<
0=7Ad@3@d=00b/[:0;fm_@2OWil0IFEU03Ph>00f=SH0>SXj03<c<`0_;bl0<S8b03Lg=`0f=SH0<S8b
03Ti>@0o?cl0<c<c05IFEP1oOgl0O7al06YZJP1KFe/0@d=3034a<@0/;2`0:b/[02d];@0c<c<0<S8b
03<c<`0j>SX0>3Ph03Ti>@0k>c/0<S8b02l_;`0^;Rh0=CDe0P0d=3@06`0[:b/0:2PX02`/;00`<300
=3@d04i>CP1<C4`0;2`/0492@P2DU9@0XZ:R0;Zj^P2/[:`0TY:B061PH01JFUX0F5QH04M7A`0b<S80
@D5103De=@0l?3`0C4a<04Y:BP0o?cl0?3`l03/k>`0203Ti>@0=03De=@0`<300;Bd]02l_;`0/;2`0
<30`02l_;`0`<300<S8b034a<@0h>3P0=cLg03Ti>@02038b<P0A03De=@0_;bl0;bl_03<c<`11@D40
GUiN07YjNP28R8P0T92@08b<S02:RXX0SXj>08V9R@22PX80RXZ:096AT@2HV9P00P2PX:003P2OWil0
WYjN09bLW02NWYh0X:2P09fMW@2PX:00Vi^K09bLW02OWil0V9RH09ZJVP2IVIT0V9RH0`2IVIT00`2F
UYH0W9bL09ZJVP0209^KV`0:09FEU@2JVYX0U9BD09RHV02JVYX0WinO0:2PX02MWId0VIVI09RHV080
VYZJ00H0W9bL09jNWP2PX:00WYjN09ZJVP2MWId209bLW00409^KV`2IVIT0VYZJ09bLW080UYJF00<0
UiNG09jNWP2KVi/00P2KVi/02P2NWYh0VYZJ09VIV@2MWId0Ti>C09RHV02FUYH0UIFE09BDU02HV9P2
09JFUP0409NGU`2HV9P0V9RH09NGU`80UIFE00<0U9BD09:BTP2BTY800P2@T9002P2ATI40S8b<092@
T02=SHd0S8b<08V9R@2<S8`0QhN708V9R@2=SHd208b<S00408N7Q`2:RXX0R8R808J6QP80Q8B43P38
h=P000`0b>3H0P1MGEd0201QHF40HV9R069RHP1SHf<0GemO05iNGP1MGEd0IFEU0P1OGel05P1PH600
GUiN05aLG01OGel0GEeM05iNGP1JFUX0Fe]K05=CD`1@D500DU9B04i>CP1=CDd0EEEE05UIF@1SHf<0
KFe]07AdM023Ph<0QhN708n?S`2FUYH209^KV`060:FUY@2SXj<0Zj^[0:ZZZP2^[Zh0[jn_0P2b/[80
=P2_[jl0/;2`0;Bd]02b/[80/;2`0;Bd]02`/;00/[:b0;2`/02a/K40[Jf]0:^[Z`2UYJD0WinO09fM
W@2FUYH0TI6A09:BTP2:RXX0NWYj06m_K`1TI6@0De=C04e=C@16ATH0ADE504I6AP1?Cdl0BDU9055A
D@1GEeL0EEEE05QHF01CDe<0FUYJ05EEE@1JFUX0Hf=S05aLG01NGUh0GemO06UYJ@1VIVH0I6AT06MW
I`1PH600IFEU05mOG`1PH600Hf=S05eMG@1OGel0I6AT069RHP80HF5Q01@0GemO06=SH`1MGEd0G5aL
05IFEP1IFET0GEeM069RHP1lO7`0XJ6Q0;:b/P2VYZH0a/K60=GEe@3;bl/0Y:BT07QhN028R8P0SHf=
092@T080UYJF00L0TI6A09NGU`2IVIT0VYZJ09^KV`2FUYH0VIVI0080U9BD01l0Rh^;08B4Q01eMGD0
JFUY04m?C`0c<c<0<30`04];B`1DE5@0BTY:03De=@0W9bL092@T02<S8`0R8R80:2PX0410@01JFUX0
MWIf07AdM01WIfL0CTi>04=3@`0m?Cd0IFEU0861P@1SHf<0<c<c0451@@1VIVH0EEEE0080CTi>01L0
IVIV04E5A@1?Cdl0KFe]092@T01eMGD0Cdm?02<S8`0Q8B40;bl_02XZ:P0f=SH0F5QH03dm?@0S8b<0
:RXZ03lo?`1EEED0?Cdm02d];@1NGUh0PX:203Ph>00202`/;00302XZ:P0X:2P09RHV008092@T00D0
:BTY02DU9@0Z:RX0@D5106UYJ@0207UiN@0>079bLP1WIfL0B4Q802PX:00T92@0:BTY02HV9P0W9bL0
;Bd]02l_;`0U9BD0:BTY02LW9`0R8R82024Q8@0502<S8`15ADD0P8200:6QX@2EUID00P1TI6@02@2@
T900^KVi0<K6aP2_[jl0YjNW0:BTY02/[:`0/K6a0;2`/0020;Rh^0080<;2`P35aLD0cLg=0<[:bP33
`l<0`/;20<30`02m_Kd20;no_`050;fm_@35aLD0YjNW05iNGP1:BTX00P11@D4204=3@`0503Ti>@0e
=CD0<S8b02l_;`0`<3000P0e=CD0800c<c<0=CDe03Lg=`0c<c<0=CDe02d];@0/;2`0:RXZ02l_;`0^
;Rh0;bl_030`<01?Cdl0@T92069RHP1gMgL0Kfm_05aLG016ATH0>CTi02h^;P0Z:RX09bLW02h^;P0Y
:BT09RHV02h^;P0l?3`0EUIF07=cL`21PH40Rh^;0P27QhL01@23Ph<0OGem08:2PP22PX80QHF500<0
SHf=0100T92@09NGU`2CTi<0U9BD09VIV@2MWId0XJ6Q0:NWY`2YZJT0];Bd0;^k^`2n_[h0aLG50<[:
bP3;bl/0c<c<0P3=cLd09@3?cll0bl_;0<O7a`2j^[X0W9bL07IfMP1;Bd/0?Cdm03Ph>00e=CD0>c/k
03De=@0c<c<0=3@d03hn?P0c<c<0=3@d04M7A`1FEUH0Fe]K04];B`0n?Sh0>c/k038b<P0_;bl0<30`
03@d=00h>3P0@D5103/k>`0i>CT0?3`l03Ti>@0k>c/0=SHf03De=@0`<3000P0];Bd00`0^;Rh0:RXZ
02DU9@0202`/;00D03<c<`16ATH0A4A402h^;P15ADD0UIFE0:RXZ02g]kL0XZ:R08B4Q01QHF40HV9R
05iNGP1:BTX0@41003dm?@0o?cl0=SHf05=CD`16ATH203/k>`0503dm?@0j>SX0>SXj03@d=00a<C40
0`0_;bl04P0c<c<0=3@d03@d=00b<S80=cLg02h^;P0a<C40<S8b03hn?P0e=CD0<C4a02h^;P0Y:BT0
:b/[03De=@1CDe<0KFe]08>3P`80SXj>01<0Rh^;08R8R024Q8@0QHF508N7Q`2BTY80VIVI09nOW`2P
X:00XJ6Q09fMW@2PX:00WYjN09nOW`2MWId0Vi^K09bLW02KVi/0VIVI0080UiNG0P2IVIT03P2KVi/0
UiNG09ZJVP2JVYX0Vi^K09NGU`2LW9`0VYZJ09fMW@2IVIT0W9bL09NGU`2NWYh0XZ:R0P2IVIT03`2K
Vi/0WYjN09ZJVP2MWId0VYZJ09^KV`2OWil0WYjN09bLW02MWId0VIVI09^KV`2JVYX0VIVI09NGU`02
09^KV`0309JFUP2KVi/0VIVI0080VYZJ00<0W9bL09ZJVP2EUID00P2GUiL209VIV@0809FEU@2FUYH0
U9BD09bLW02HV9P0Vi^K09JFUP2EUID209VIV@0309FEU@2DU9@0TI6A0080TY:B00h0T92@096AT@2>
SXh0SHf=09:BTP2;Rh/0RXZ:08j>SP2;Rh/0SHf=08Z:RP2;Rh/0RHV908N7Q`80Rh^;00@0QhN708V9
R@28R8P0QhN73P38h=P000`0b>3H0P1SHf<0201YJFT0IfMW06EUI@1RHV80GUiN069RHP1QHF40J6QX
0P1TI6@0101PH600GUiN061PH01MGEd205iNGP0C069RHP1LG5`0GEeM05UIF@1FEUH0DU9B055AD@1C
De<0D51@069RHP1^KVh0Ng]k08>3P`27QhL0SXj>09FEU@2KVi/0WinO0:FUY@020:VYZ@030:RXZ02/
[:`0/k>c0080[Zj^01H0/;2`0;>c/`2`/;00/K6a0;>c/`2b/[80/k>c0;6a/@2_[jl0[Zj^0;6a/@2Y
ZJT0Xj>S0:2PX02MWId0UiNG09BDU02>SXh0RHV907UiN@1^KVh0Hf=S0P1IFET02`1@D500BTY:04M7
A`1:BTX0EEEE05ADE01EEED0E5AD05YJFP1IFET0GUiN0080EeMG0100IFEU065QH@1NGUh0IFEU06UY
J@1ZJVX0I6AT06QXJ01PH600IFEU065QH@1VIVH0Hf=S05mOG`1SHf<0IVIV0P1PH6001P1TI6@0Hf=S
05aLG01OGel0G5aL05eMG@80FUYJ00`0GemO06EUI@1gMgL0UYJF0:2PX02RXZ80b<S80<k>cP2n_[h0
OGem08J6QP2>SXh209>CT`0309FEU@2@T900UYJF0080VIVI00<0Vi^K09VIV@2KVi/00`2MWId0902E
UID0OGem06][J`1BDU80ATI603/k>`1@D500K6a/06IVIP15ADD0:2PX02HV9P0T92@07QhN02@T900Y
:BT0?clo06EUI@1dM7@0JFUY05]KF`1>CTh0D51@05UIF@1[Jf/0RHV905eMG@1HF5P0I6AT051@D016
ATH0C4a<06a/K01@D500BDU9065QH@80O7al01H0EEEE02LW9`0V9RH0;Rh^02LW9`0`<300GemO03hn
?P0Y:BT0=cLg05IFEP0j>SX0;bl_038b<P1IFET0Lg=c02h^;P0V9RH0:BTY02LW9`0T92@09bLW0P0U
9BD02@0P8200<30`03De=@1`L700NGUi075aL@1bLW80H61P0410@00202HV9P0:02@T900W9bL0:b/[
02l_;`0c<c<0=3@d02XZ:P0P82009RHV02XZ:P806a/K00/07alO02HV9P1JFUX0T92@0:f][@1fMWH0
IfMW07]kN`2JVYX0`L710<?3``020:JVYP0O0:b/[02`/;00[Jf]0;Jf]P2d];@0^KVi0<C4a038b<P0
bl_;0<?3``31`L40`/;20;Zj^P2l_;`0_[jn0;Vi^@32`/80a/K60::RXP1HF5P0ATI60410@00o?cl0
Bd];03/k>`0f=SH0=cLg03Ti>@0e=CD0<S8b03De=@0203@d=00D03Xj>P0c<c<0;bl_038b<P0d=3@0
;Rh^030`<00^;Rh0;bl_02`/;00c<c<0=cLg03lo?`1DE5@0AdM703Lg=`0c<c<0;Rh^02PX:00^;Rh2
02LW9`0@030`<00X:2P0=cLg05QHF01_Kfl0Ph>308R8R029RHT0PH610820P023Ph<0Ng]k07inOP23
Ph<0PX:208b<S080Shn?02L0Rh^;09:BTP2DU9@0U9BD09bLW02MWId0WinO0:FUY@2[Zj/0];Bd0;^k
^`2o_kl0`/;20<O7a`3<c<`0a/K60<_;b`3:b/X0bl_;0<[:bP32`/80_;bl0;:b/P2NWYh0P82005]K
F`1>CTh0>c/k03Ph>00l?3`0<C4a03Lg=`0j>SX0=cLg034a<@0i>CT0?Shn03Xj>P0a<C400P0`<300
0`0d=3@0<S8b03<c<`0203Lg=`0M03Xj>P10@400=SHf03De=@0g=cL0@41003lo?`0c<c<0<S8b02h^
;P0d=3@0<30`02`/;00];Bd092@T02`/;00a<C40ATI604E5A@0_;bl0ATI609BDU02WYjL0]KFe09nO
W`23Ph<0Kfm_06IVIP1NGUh00P17AdL0201:BTX0<C4a038b<P1:BTX0?Shn0410@00l?3`0@4100P11
@D40400e=CD0=3@d02l_;`0/;2`0<30`02l_;`0a<C40=3@d038b<P0];Bd0>SXj03Ti>@0h>3P0<S8b
03Ph>00e=CD202/[:`0:02LW9`0/;2`0BTY:06MWI`22PX80T92@09:BTP2;Rh/0QhN708F5Q@80QhN7
00<0Shn?09FEU@2LW9`00P2RXZ803@2QXJ40XZ:R0:6QX@2LW9`0WIfM09jNWP2OWil0WYjN0:2PX02M
WId0V9RH09VIV@2NWYh00P2JVYX03P2KVi/0VYZJ09JFUP2GUiL0VYZJ09NGU`2NWYh0UIFE09JFUP2P
X:00VYZJ09^KV`2MWId0VIVI0P2HV9P03@2GUiL0Vi^K09ZJVP2HV9P0W9bL09fMW@2HV9P0W9bL09^K
V`2JVYX0W9bL09ZJVP2LW9`00P2IVIT00`2HV9P0UiNG09bLW00209NGU`0A09RHV02LW9`0V9RH09ZJ
VP2HV9P0Vi^K09ZJVP2HV9P0Vi^K09JFUP2GUiL0W9bL09VIV@2HV9P0VIVI09^KV`2EUID00P2HV9P0
1`2CTi<0U9BD09FEU@2FUYH0U9BD096AT@2CTi<00P2BTY802@2@T900TY:B08n?S`2BTY80T92@08n?
S`2>SXh0RXZ:08n?S`0208Z:RP0308b<S029RHT0Q8B400h0b>3H000<0<SPf080Hf=S00D0JFUY06QX
J01WIfL0IFEU06QXJ00206=SH`0406EUI@1TI6@0JFUY06=SH`<0I6AT01X0Fe]K05eMG@1UIFD0HV9R
05aLG01EEED0G5aL05YJFP1?Cdl0E5AD05IFEP1VIVH0LW9b07emO@22PX80RHV908n?S`2HV9P0UiNG
09fMW@2SXj<0YZJV0:^[Z`2][Jd0[Zj^0;2`/0<0/[:b00D0[Jf]0;:b/P2`/;00/k>c0;Bd]0020;6a
/@050;2`/02_[jl0[Jf]0:^[Z`2WYjL00P2OWil02`2IVIT0T92@08f=S@24Q8@0NWYj06i^KP1QHF40
F5QH05]KF`1<C4`0BDU90080Bd];00X0DU9B05EEE@1HF5P0EeMG059BDP1IFET0GUiN05aLG01OGel0
Hf=S0P1VIVH01P1ZJVX0IFEU06MWI`1WIfL0IFEU069RHP80I6AT01`0HV9R06ATI01VIVH0HV9R065Q
H@1TI6@0HF5Q06EUI@1PH600GemO06=SH`1PH600GEeM05mOG`1PH600HV9R05mOG`1ZJVX0Ph>309^K
V`2FUYH0XZ:R0;Zj^P2l_;`0QhN708R8R02ATI40U9BD0P2EUID01P2HV9P0WIfM09RHV02KVi/0VIVI
09BDU0<0W9bL01P0WYjN09VIV@2ATI40N7Qh061PH01SHf<0IVIV07UiN@22PX80GUiN04E5A@0[:b/0
:RXZ02d];@0P82008B4Q01lO7`0Z:RX0@T9205IFEP1XJ6P0GUiN04e=C@1@D50205aLG00408:2PP2<
S8`0JFUY05EEE@80?Cdm03@0A4A405iNGP1YJFT0AdM705EEE@1cLg<0NGUi05=CD`0[:b/0:BTY02LW
9`0Z:RX0<C4a06ATI00e=CD0=SHf04Y:BP17AdL0;Bd]030`<00a<C40Hf=S06MWI`0^;Rh0:b/[02HV
9P0[:b/092@T02PX:00V9RH09bLW02/[:`0`<300G5aL07]kN`1lO7`0KVi^04m?C`0b<S80;Bd]02XZ
:P0^;Rh0:2PX02/[:`0Y:BT0;bl_02h^;P0/;2`09BDU02@T900/;2`0<c<c0P0M7Ad201lO7`0]03Ti
>@1hN7P0X:2P09RHV020P800KFe]07emO@2ZZZX0bl_;0;Bd]02WYjL0[Jf]0;>c/`2_[jl0/K6a0;Ng
]`2k^k/0a<C40<S8b03;bl/0aLG50<;2`P2n_[h0^KVi0;Ng]`2j^[X0];Bd0;^k^`36a/H0b<S809fM
W@1@D500@D5104M7A`16ATH0AdM704A4A013@d<0?clo03Xj>P0e=CD0<c<c03Hf=P0d=3@0<c<c0080
=3@d01T0<C4a038b<P0_;bl0<C4a030`<00^;Rh0<S8b03/k>`0`<300>3Ph03Ti>@0f=SH0@D5102`/
;00^;Rh0:2PX02HV9P0/;2`0:BTY02XZ:P0h>3P0GUiN08>3P`2:RXX0SHf=0080PX:200P0Ogmo08B4
Q01mOGd0OWin08>3P`22PX80Shn?08b<S080SXj>0140T92@096AT@2GUiL0VIVI09bLW02NWYh0X:2P
0::RXP2YZJT0];Bd0;Ng]`2j^[X0`/;20<G5a@33`l<0aLG50<S8b0020<_;b`0A0<O7a`35aLD0_[jn
0;Vi^@2][Jd0WinO08B4Q01fMWH0EeMG03Xj>P0n?Sh0=CDe03<c<`0f=SH0<c<c038b<P0d=3@00P0c
<c<02P0a<C40<30`02l_;`0^;Rh0=3@d03Hf=P0g=cL0>SXj03De=@0h>3P303Lg=`0703`l?016ATH0
AdM703@d=00[:b/0:BTY038b<P0202TY:@809bLW01@0;Rh^04a<C01?Cdl0;bl_04U9B@2MWId0[:b/
0;6a/@2QXJ40P82006e]K@1YJFT0EUIF04e=C@12@T80=CDe02d];@0f=SH0CTi>04Q8B080>c/k01@0
>SXj04E5A@15ADD0=cLg03`l?00];Bd0;bl_02`/;00b<S80;bl_03De=@0`<300;Bd]03dm?@0j>SX0
>CTi03Ph>00g=cL0=3@d02d];@809RHV00T0;bl_03hn?P1TI6@0NGUi08j>SP2ATI40RXZ:08V9R@28
R8P00P22PX804P26QXH0Shn?09JFUP2KVi/0XJ6Q0:2PX02NWYh0WinO0:6QX@2OWil0WYjN09^KV`2Q
XJ40WinO09^KV`2MWId0VIVI09bLW080Vi^K00/0V9RH09NGU`2HV9P0WIfM09^KV`2FUYH0VYZJ0:2P
X02KVi/0VIVI0:6QX@0209fMW@0309RHV02KVi/0W9bL0080WIfM00/0W9bL09^KV`2JVYX0VYZJ09bL
W02JVYX0WYjN09bLW02NWYh0VIVI09ZJVP0209^KV`0309RHV02IVIT0WYjN0080VYZJ00P0UiNG09VI
V@2IVIT0VIVI09RHV02FUYH0UIFE09ZJVP80Vi^K0P2HV9P309VIV@0F09fMW@2IVIT0Vi^K09NGU`2I
VIT0V9RH09JFUP2EUID0TI6A092@T02DU9@0SHf=08j>SP2@T900TY:B096AT@2@T900SXj>092@T02<
S8`0RHV908R8R080RHV900<0QhN708J6QP27QhL03P38h=P000`0b>3H0P1RHV800`1WIfL0Hf=S06EU
I@0206EUI@08069RHP1UIFD0Hf=S069RHP1WIfL0HV9R065QH@1RHV8206IVIP0A06ATI01PH600GUiN
061PH01EEED0FEUI05ADE01BDU80De=C05aLG01YJFT0MWIf07inOP25QHD0S8b<092@T02FUYH00P2I
VIT0102PX:00Zj^[0:NWY`2[Zj/20:j^[P80/;2`00X0/[:b0:j^[P2b/[80]KFe0;6a/@2_[jl0[Zj^
0;6a/@2c/k<0/;2`0P2/[:`05`2XZ:P0Xj>S0:2PX02IVIT0TI6A08b<S024Q8@0O7al071`L01UIFD0
EEEE051@D01ADE40E5AD04Q8B01:BTX0CDe=04m?C`1DE5@0F5QH05UIF@1KFe/0GEeM0080G5aL01X0
HV9R06=SH`1TI6@0J6QX06=SH`1TI6@0J6QX06UYJ@1TI6@0IfMW06IVIP1TI6@0Hf=S06EUI@1PH600
HF5Q06ATI01MGEd0GemO06ATI01YJFT0IfMW06=SH`1OGel0IVIV05mOG`80HV9R00<0I6AT075aL@29
RHT00P2?Shl03`2EUID0WYjN09^KV`2>SXh0TI6A08n?S`2FUYH0UIFE09JFUP2JVYX0VIVI09RHV02F
UYH0UIFE09^KV`0209NGU`1809ZJVP2HV9P0S8b<07]kN`1YJFT0Ng]k09:BTP2KVi/0RHV907]kN`1>
CTh0;2`/034a<@0/;2`0:2PX024Q8@0X:2P09BDU02PX:00l?3`0>SXj04a<C01:BTX0D51@05MGE`1F
EUH0K6a/08R8R01gMgL0B4Q803<c<`0k>c/0@T92055AD@1[Jf/0D51@04e=C@1[Jf/0M7Ad04e=C@0[
:b/0;2`/02PX:00Z:RX0>CTi065QH@0h>3P0D51@05QHF00_;bl0;2`/02XZ:P0_;bl0GEeM06EUI@0_
;bl0:2PX02HV9P0R8R808b<S02HV9P0a<C40<30`03Xj>P19BDT0OGem07QhN01UIFD0@D5102l_;`0X
:2P09BDU0P0[:b/01`0/;2`0>CTi02l_;`0_;bl0<30`02PX:00V9RH00P0T92@07`0W9bL07alO01lO
7`0U9BD08b<S02PX:01?Cdl0TI6A0:2PX028R8P0KVi^06IVIP2=SHd0_;bl0<30`02VYZH0[:b/0:ZZ
ZP2][Jd0/;2`0;>c/`2k^k/0`l?30<K6aP3;bl/0alO70<W9b@32`/80^k^k0;Vi^@2k^k/00P2f][H0
6P2o_kl0aLG50<W9b@2OWil0FUYJ04Q8B01>CTh0EUIF04e=C@1@D500B4Q804M7A`0l?3`0=3@d03/k
>`10@400>3Ph03Hf=P0i>CT0=CDe038b<P0h>3P0<C4a038b<P0e=CD0<c<c0P0e=CD0400b<S80<C4a
02d];@0[:b/0;Bd]02/[:`0Y:BT0:2PX02`/;00e=CD0A4A404];B`1ZJVX0RXZ:08b<S028R8P20820
P00507YjNP25QHD0Ph>307emO@1jNWX00`29RHT309:BTP0>09NGU`2KVi/0WYjN09bLW02OWil0XJ6Q
0:VYZ@2/[:`0/[:b0;Zj^P2o_kl0aLG50<;2`P2o_kl30<G5a@<0a/K60P31`L403`2g]kL0ZZZZ09NG
U`2:RXX0Lg=c06ATI01QHF40A4A404I6AP0i>CT0<C4a038b<P0g=cL0=CDe03Ph>002034a<@0[03<c
<`0`<300<C4a02l_;`0j>SX0=SHf03`l?00f=SH0>3Ph03lo?`10@400BDU90451@@17AdL0>c/k02h^
;P0];Bd0<C4a02XZ:P0T92@09RHV02LW9`0];Bd0B4Q805ADE00^;Rh0C4a<09bLW02`/;00/K6a0:JV
YP1lO7`0Lg=c06m_K`1DE5@0D51@04A4A00_;bl0<S8b03Ph>01BDU80A4A403dm?@020451@@80@d=3
02L0>3Ph03dm?@0a<C40<30`02l_;`0c<c<0<C4a03Ti>@0b<S80;bl_02h^;P0a<C40;Rh^03Lg=`0i
>CT0=CDe02l_;`0Y:BT09bLW02h^;P0j>SX0GemO07IfMP23Ph<0RHV908b<S029RHT0QHF50820P026
QXH0PX:208^;R`2ATI40UiNG0:6QX@2OWil0WYjN0:2PX02NWYh00P2OWil02P2NWYh0XZ:R09bLW02N
WYh0W9bL09fMW@2KVi/0WYjN09^KV`2LW9`209VIV@0509bLW02MWId0Y:BT09fMW@2KVi/00`2JVYX2
09^KV`0E09bLW02NWYh0V9RH09^KV`2LW9`0WIfM09bLW02OWil0XJ6Q09jNWP2OWil0X:2P09jNWP2M
WId0V9RH09^KV`2DU9@0W9bL09ZJVP2HV9P0VIVI0080VYZJ01/0UYJF09^KV`2LW9`0UYJF09bLW02H
V9P0UiNG09RHV02FUYH0V9RH09^KV`2IVIT0W9bL09VIV@2JVYX0WYjN09RHV02KVi/0VYZJ09VIV@2K
Vi/0UIFE08n?S`2CTi<0U9BD09>CT`2BTY800P2ATI42092@T080SXj>00T0TY:B08f=S@2>SXh0SHf=
08Z:RP2;Rh/0QhN708Z:RP24Q8@03P38h=P000`0b>3H0P1YJFT02`1ZJVX0IVIV06YZJP1UIFD0HV9R
06e]K@1TI6@0IVIV06ATI01UIFD0I6AT0080Hf=S00<0I6AT06YZJP1RHV800P1MGEd05P1NGUh0GEeM
05ADE01HF5P0D51@05QHF01NGUh0Hf=S07AdM01oOgl0PX:208^;R`2?Shl0UiNG09VIV@2PX:00Xj>S
0:JVYP2[Zj/0[Jf]0;6a/@2b/[820;2`/0040;Bd]02a/K40[jn_0;:b/P80/K6a00X0/;2`0;>c/`2`
/;00/[:b0:n_[`2XZ:P0YZJV0::RXP2SXj<0Vi^K0P2FUYH02@26QXH0PH6106i^KP1YJFT0EEEE04e=
C@18B4P0BDU904Y:BP0204e=C@0805=CD`1GEeL0F5QH05EEE@1LG5`0H61P05mOG`1WIfL206=SH`04
06ATI01SHf<0I6AT06IVIP80JFUY00@0Hf=S06EUI@1TI6@0HF5Q0P1TI6@00`1WIfL0IFEU06ATI002
065QH@0505eMG@1OGel0GemO06=SH`1PH6000P1TI6@03@1XJ6P0HV9R06UYJ@1XJ6P0Kfm_07MgM`1o
Ogl0PX:208R8R02IVIT0U9BD08n?S`2@T9000P2EUID01`2MWId0Vi^K09bLW02MWId0WinO09^KV`2I
VIT00P2FUYH0:@2KVi/0YJFU09bLW02EUID0RXZ:09RHV02/[:`0[Jf]09VIV@1kNg/0Cdm?03<c<`13
@d<0>3Ph030`<00_;bl0;2`/02h^;P0`<300>c/k05IFEP1LG5`0>CTi04Y:BP1<C4`0D51@05eMG@1b
LW80Ng]k065QH@0a<C40;2`/0410@019BDT0FEUI05MGE`1;Bd/0J6QX07AdM01@D500:RXZ00<08R8R
00d0=CDe05eMG@10@400J6QX0410@00W9bL0:BTY02d];@0f=SH0FEUI05eMG@0[:b/09bLW00809RHV
01T092@T02TY:@0^;Rh0<30`04=3@`1LG5`0MWIf061PH00j>SX0:RXZ02TY:@0/;2`0;bl_038b<P0]
;Bd0:2PX02l_;`0];Bd0;Rh^03<c<`0Y:BT0<30`02HV9P0T92@08b<S0080:2PX00h0?Cdm024Q8@0R
8R809bLW06i^KP2?Shl0WinO07MgM`1UIFD0Kfm_0::RXP2o_kl0^KVi0:RXZ080ZZZZ01h0/;2`0:j^
[P2f][H0_kno0<C4a03;bl/0c<c<0<_;b`37alL0_;bl0;Vi^@2e]KD0[:b/0;6a/@2g]kL0_kno0<K6
aP3=cLd0YZJV05iNGP1?Cdl0DE5A04m?C`1NGUh0EeMG04e=C@15ADD0ATI605MGE`1DE5@20410@00@
04=3@`0n?Sh0>CTi03/k>`0i>CT0=SHf038b<P0/;2`0<S8b03De=@0l?3`0=cLg03Ph>00_;bl0:b/[
02l_;`80<30`0180>3Ph05=CD`1kNg/0I6AT065QH@1hN7P0R8R80861P@1lO7`0NGUi07YjNP1kNg/0
O7al07MgM`1jNWX0Q8B408V9R@2<S8`208n?S`0B09JFUP2JVYX0WinO0:6QX@2JVYX0WIfM09nOW`2S
Xj<0[Jf]0;2`/02i^KT0`L710<?3``2o_kl0_Kfm0<C4a033`l<0a<C40P32`/805@31`L40_[jn0<30
`02k^k/0];Bd0::RXP2IVIT0RXZ:08V9R@24Q8@0IfMW06i^KP1QHF40AdM703/k>`0i>CT0=cLg03<c
<`0b<S80=3@d034a<@0203@d=00Z03Ti>@0h>3P0?3`l03`l?011@D40?Cdm04I6AP17AdL0@T920410
@016ATH0CTi>03<c<`0X:2P0:b/[030`<00X:2P092@T02`/;00];Bd0BDU905ADE00[:b/0EUIF09ZJ
VP2f][H0Zj^[09^KV`1`L700MgMg079bLP1CDe<0A4A403@d=00a<C40;Rh^03`l?01LG5`0@D5103Ph
>00m?Cd0ADE50P0k>c/0200h>3P0=cLg03<c<`0d=3@0<30`034a<@0b<S80<30`0P0b<S80400c<c<0
;Rh^03<c<`0a<C40=3@d03De=@0[:b/09bLW02/[:`0e=CD0>c/k05=CD`1_Kfl0Q8B408j>SP2DU9@2
08R8R00708V9R@24Q8@0OWin08V9R@2ATI40VIVI09bLW0020::RXP0M0:FUY@2OWil0WinO0:FUY@2Q
XJ40WinO09jNWP2LW9`0WIfM09VIV@2MWId0VIVI09ZJVP2LW9`0WinO09jNWP2MWId0WinO09ZJVP2M
WId0Vi^K09RHV02KVi/0VYZJ09RHV02IVIT0W9bL09fMW@2NWYh00P2KVi/02`2JVYX0WIfM09bLW02L
W9`0WIfM09jNWP2LW9`0WIfM09nOW`2IVIT0W9bL0080V9RH00<0VIVI09ZJVP2KVi/00P2FUYH03P2I
VIT0Vi^K09nOW`2JVYX0W9bL09^KV`2GUiL0V9RH09ZJVP2MWId0Vi^K09ZJVP2LW9`0VYZJ0P2MWId0
102KVi/0VIVI09fMW@2IVIT209JFUP0709:BTP2FUYH0TY:B09>CT`2DU9@0TI6A09FEU@0209:BTP<0
T92@00P0Rh^;08f=S@2=SHd0QhN708b<S02=SHd0R8R808>3P`h0b>3H000<0<SPf080GemO00/0IFEU
069RHP1TI6@0Hf=S06MWI`1]KFd0J6QX06][J`1VIVH0KFe]069RHP0206EUI@0405mOG`1TI6@0HV9R
065QH@80GUiN0180Fe]K05EEE@1GEeL0DU9B05YJFP1OGel0IfMW07=cL`1mOGd0P82008f=S@2BTY80
VIVI09ZJVP2MWId0XZ:R0:JVYP2/[:`20:n_[`060;2`/02b/[80/[:b0:n_[`2][Jd0[jn_0P2`/;00
0`2a/K40/;2`0:f][@020;2`/080[:b/01l0YJFU0:>SX`2OWil0VYZJ09FEU@2>SXh0Rh^;07QhN01Y
JFT0Hf=S05EEE@1?Cdl0D51@04Y:BP1=CDd0CTi>05aLG01EEED0E5AD05IFEP1HF5P0G5aL06EUI@1N
GUh0G5aL065QH@1TI6@0Hf=S06EUI@1YJFT0HV9R0080IVIV0`1SHf<0101PH600HF5Q06UYJ@1QHF42
069RHP0O06QXJ01YJFT0I6AT05iNGP1QHF40Hf=S06EUI@1YJFT0I6AT069RHP1UIFD0JVYZ06MWI`1X
J6P0JFUY071`L01aLG40NGUi08F5Q@27QhL0RHV908n?S`2BTY80UYJF09fMW@2NWYh0Vi^K09VIV@2F
UYH0UIFE09JFUP0209>CT`0b0:RXZ02l_;`0];Bd0;Ng]`2/[:`0YJFU0:j^[P2WYjL0Vi^K08j>SP27
QhL0IVIV05IFEP1BDU80EEEE05aLG018B4P0>SXj02`/;00l?3`0@D5102TY:@0X:2P0<S8b0451@@1@
D500EEEE06EUI@1hN7P0PH6104Q8B00[:b/0BTY:05MGE`1BDU80EUIF03hn?P1TI6@0N7Qh065QH@0U
9BD08R8R02<S8`0R8R80<C4a05ADE01BDU80KVi^034a<@0`<30202d];@0B03`l?01DE5@0GUiN034a
<@0_;bl0;Bd]02HV9P0T92@0:BTY03<c<`0n?Sh0GemO061PH01/K6`0EeMG03@d=00U9BD0<30`0P0[
:b/01P0/;2`0;Rh^02d];@0d=3@0:RXZ02h^;P80:b/[00@0:RXZ02h^;P0W9bL09bLW0P14A4@05P0o
?cl07QhN01dM7@0R8R80?Shn0861P@2RXZ80SHf=06YZJP1YJFT0O7al0;2`/036a/H0]KFe0:BTY02Z
ZZX0Z:RX0:f][@2a/K40^k^k0<71`@35aLD20<S8b00e0<[:bP30`<00]KFe0;>c/`2YZJT0[Zj^0:f]
[@2g]kL0_Kfm0<K6aP3:b/X0[Jf]06ATI01DE5@0EEEE05mOG`1RHV80H61P06ATI01WIfL0I6AT061P
H01:BTX0Bd];04U9B@13@d<0DU9B04U9B@1ADE40>c/k03Hf=P0_;bl0>3Ph055AD@1YJFT0GUiN04];
B`0`<300;Rh^04=3@`15ADD0@41005ADE01_Kfl0NGUi0820P01GEeL0IFEU0820P01gMgL0NWYj07Ee
M@1cLg<00P1dM7@01@1gMgL0NWYj0820P026QXH0SHf=0080Ti>C00l0VIVI09bLW02MWId0XZ:R0:2P
X02MWId0WinO0:NWY`2^[Zh0/;2`0;bl_02n_[h0`l?30<71`@32`/800P36a/H06035aLD0_kno0;fm
_@2o_kl0_Kfm0;no_`2n_[h0]kNg0:VYZ@2NWYh0T92@08Z:RP28R8P0PH6107inOP28R8P0N7Qh05YJ
FP1ADE40F5QH04U9B@0g=cL0=SHf03Lg=`80>CTi00d0@D5104M7A`0o?cl0@D5104=3@`0o?cl0ADE5
04a<C016ATH0@T9204A4A019BDT0@D510080;Rh^01/0:RXZ02DU9@0W9bL0;Rh^03Hf=P19BDT0C4a<
02d];@1LG5`0W9bL0;Ng]`2a/K40Ti>C07AdM01`L700IfMW05MGE`0`<300<C4a030`<00f=SH0>c/k
05ADE00l?3`0?Cdm04=3@`11@D400P13@d<0600l?3`0>3Ph03De=@0_;bl0=3@d02h^;P0d=3@0;Rh^
03@d=00^;Rh0>3Ph030`<00c<c<0=SHf03/k>`0f=SH0<30`02/[:`0Z:RX0=3@d03lo?`1GEeL0K6a/
07emO@80R8R800T0Rh^;08V9R@22PX80OWin07moO`23Ph<0TY:B09VIV@2JVYX00P2PX:000`2LW9`0
XJ6Q09bLW00409nOW`0@09fMW@2IVIT0WIfM09ZJVP2NWYh0W9bL09^KV`2MWId0WYjN09^KV`2NWYh0
W9bL09fMW@2JVYX0Vi^K09RHV080VIVI00@0Vi^K09fMW@2IVIT0Vi^K0P2LW9`0402NWYh0WIfM09fM
W@2NWYh0VYZJ09fMW@2JVYX0Vi^K09VIV@2MWId0V9RH09bLW02HV9P0VYZJ09VIV@2KVi/209RHV003
09JFUP2JVYX0VIVI0080V9RH00T0WIfM09^KV`2JVYX0Vi^K09bLW02MWId0VYZJ09VIV@2KVi/00P2L
W9`00`2KVi/0WIfM09ZJVP0209NGU`0709RHV02BTY80Ti>C096AT@2BTY80UYJF09FEU@0209BDU008
09>CT`2?Shl0TY:B08j>SP2CTi<0T92@08Z:RP29RHT208R8R080QhN73P38h=P000`0b>3H0P1SHf<0
3P1TI6@0JFUY06MWI`1XJ6P0IVIV06UYJ@1[Jf/0JVYZ06ATI01]KFd0IVIV06QXJ01UIFD0I6AT0P1V
IVH05P1QHF40G5aL05iNGP1JFUX0EEEE05aLG01HF5P0FUYJ065QH@1WIfL0M7Ad0861P@23Ph<0SHf=
09:BTP2DU9@0W9bL09jNWP2OWil0YZJV0:n_[`2][Jd20:n_[`80/;2`01T0/K6a0:n_[`2a/K40[Zj^
0;6a/@2^[Zh0/K6a0:n_[`2a/K40/k>c0:f][@2/[:`0Z:RX0:FUY@2PX:00W9bL09>CT`2ATI40RHV9
07UiN@1`L700GemO05aLG01@D500Bd];0080C4a<0140CTi>05ADE01DE5@0De=C05QHF01KFe/0FEUI
05eMG@1VIVH0HV9R065QH@1XJ6P0I6AT06IVIP1YJFT0I6AT069RHP0206QXJ080IVIV0180HF5Q06UY
J@1XJ6P0Hf=S06EUI@1QHF40H61P06][J`1VIVH0IFEU06=SH`1TI6@0IfMW06][J`1VIVH0Jf][06QX
J01^KVh206UYJ@0>06e]K@1^KVh0Jf][06][J`1dM7@0Lg=c0861P@2EUID0UiNG09VIV@2MWId0WYjN
09ZJVP2FUYH209VIV@0c09FEU@2@T900T92@0;6a/@32`/80/k>c0:b/[02;Rh/0S8b<0:b/[02PX:00
R8R807QhN01iNGT0Ph>307YjNP1YJFT0MGEe08:2PP23Ph<0KVi^03`l?00g=cL0>c/k03hn?P0X:2P0
<S8b03Xj>P16ATH0C4a<059BDP1JFUX0Ng]k075aL@0m?Cd0ATI604=3@`1=CDd0B4Q8051@D01UIFD0
Lg=c069RHP0];Bd08b<S028R8P0S8b<0=cLg05]KF`1[Jf/0EeMG0080;2`/0280<C4a02XZ:P0`<300
Fe]K05MGE`0d=3@0;Rh^02TY:@0U9BD08b<S02@T900`<300CDe=06MWI`1/K6`0HV9R03@d=00X:2P0
:b/[02DU9@0X:2P09RHV02/[:`0d=3@0<S8b02h^;P0];Bd09RHV02`/;00Z:RX09BDU02PX:00];Bd0
>c/k0P1EEED0700V9RH071`L01hN7P0Q8B40;2`/065QH@2DU9@0XJ6Q07=cL`1XJ6P0Jf][08b<S02i
^KT0`L710;2`/02TY:@0[:b/0:NWY`2b/[80^k^k0;fm_@32`/80a<C40<_;b`38b<P0`l?30;Vi^@2a
/K420:RXZ00B0:JVYP2b/[80^[Zj0;bl_034a<@0c<c<0;:b/P1eMGD0EEEE06ATI01PH600J6QX06a/
K01[Jf/0IFEU05iNGP1OGel0HV9R0P1VIVH08P1YJFT0KFe]06][J`1GEeL0?Shn02l_;`15ADD0Kfm_
096AT@24Q8@0O7al05=CD`14A4@0IFEU071`L019BDT0IfMW06i^KP1kNg/0O7al06][J`1OGel0MGEe
07AdM01_Kfl0KFe]075aL@1`L700IVIV06e]K@1iNGT0PH6108Z:RP2CTi<209^KV`0309nOW`2JVYX0
WYjN0080Xj>S0100XZ:R0:>SX`2XZ:P0Zj^[0;:b/P2h^;P0`<300<C4a033`l<0a<C40<K6aP32`/80
`L710;jn_P2k^k/0_Kfm0P30`<001`2m_Kd0]kNg0:b/[02TY:@0VYZJ08^;R`1lO7`00P1jNWX07021
PH40NWYj06m_K`1^KVh0MWIf071`L01OGel0ATI605MGE`1;Bd/0ADE505YJFP1OGel0EEEE05aLG01=
CDd0Bd];04e=C@1ADE40BTY:04=3@`0n?Sh0@D5104e=C@0i>CT0:RXZ02TY:@0W9bL202d];@0G03Xj
>P12@T80C4a<02d];@1TI6@0W9bL0;Zj^P2^[Zh0TI6A0820P01^KVh0Hf=S05mOG`0^;Rh0;Bd]02l_
;`0a<C40=cLg05iNGP0k>c/0?Shn04A4A00o?cl00P11@D402@0o?cl0>SXj03/k>`0b<S80<c<c02`/
;00];Bd0;bl_03De=@0303Lg=`0A03De=@0h>3P0=cLg03@d=00`<300;Rh^038b<P0e=CD0?Cdm04Q8
B01NGUh0N7Qh08B4Q02:RXX0SXj>08V9R@26QXH00`20P8000`27QhL0U9BD09nOW`020:2PX00A0::R
XP2PX:00WIfM0:2PX02OWil0W9bL09^KV`2NWYh0WIfM09ZJVP2OWil0WYjN09^KV`2JVYX0W9bL09fM
W@2KVi/00P2LW9`03@2PX:00VIVI09jNWP2LW9`0Vi^K09fMW@2NWYh0VIVI09bLW02KVi/0XJ6Q09ZJ
VP2KVi/00P2NWYh01P2PX:00WYjN0:2PX02PX:00W9bL09ZJVP<0Vi^K00@0VYZJ09^KV`2MWId0VYZJ
0P2HV9P0402KVi/0UiNG09^KV`2IVIT0UiNG09^KV`2EUID0UYJF09ZJVP2KVi/0VYZJ09bLW02MWId0
X:2P09fMW@2OWil209bLW0090:2PX02JVYX0V9RH09^KV`2FUYH0U9BD09JFUP2HV9P0UIFE0080VIVI
00<0UiNG09JFUP2ATI400P2ATI40202<S8`0RHV908Z:RP28R8P0S8b<08V9R@26QXH0P8203P38h=P0
00`0b>3H0P1SHf<0:01XJ6P0Hf=S06EUI@1XJ6P0IFEU06UYJ@1[Jf/0KFe]06ATI01[Jf/0IVIV06][
J`1SHf<0HV9R06EUI@1RHV80Hf=S061PH01QHF40F5QH05YJFP1GEeL0De=C05ADE01NGUh0JVYZ079b
LP1lO7`0P82008n?S`2BTY80U9BD09ZJVP2KVi/0Y:BT0:NWY`2/[:`0Zj^[0;2`/02_[jl20:j^[P0I
0;:b/P2/[:`0[Zj^0;2`/02][Jd0/K6a0:n_[`2c/k<0];Bd0;Jf]P2e]KD0[Zj^0:VYZ@2OWil0Vi^K
09bLW02CTi<0S8b<08F5Q@1jNWX0LW9b069RHP1HF5P0DE5A04];B`0204Q8B00705EEE@1CDe<0F5QH
05YJFP1LG5`0Fe]K06IVIP0205iNGP06069RHP1WIfL0JFUY06UYJ@1UIFD0IfMW0P1SHf<0101UIFD0
IfMW06ATI01SHf<206ATI00906IVIP1SHf<0J6QX06=SH`1TI6@0IVIV06QXJ01QHF40J6QX0080Hf=S
01P0I6AT06EUI@1YJFT0IfMW06a/K01_Kfl0KFe]06EUI@1^KVh0KFe]06][J`1aLG40L71`07YjNP2@
T900UYJF09ZJVP2LW9`0Vi^K09VIV@2FUYH0U9BD09:BTP2@T90208^;R`0h0;2`/02h^;P0RHV907Ui
N@1FEUH0K6a/0:FUY@2=SHd0J6QX051@D017AdL0IfMW08B4Q01mOGd0O7al09BDU02=SHd0MWIf05MG
E`0k>c/0FEUI059BDP0g=cL0;bl_02/[:`0b<S80>CTi04Q8B01CDe<0KFe]07QhN01UIFD0AdM70451
@@0o?cl0A4A404];B`1IFET0Ng]k06ATI00h>3P08b<S02DU9@0V9RH0?clo075aL@1oOgl0A4A4030`
<00_;bl0:BTY02XZ:P0l?3`0De=C055AD@0b<S8202HV9P0:02PX:00Z:RX0<30`034a<@1EEED0IFEU
06QXJ01KFe/0;Bd]02LW9`80:2PX00D092@T02XZ:P0Z:RX0<30`02l_;`0202PX:00702XZ:P0X:2P0
<C4a02d];@0h>3P0DU9B069RHP0203dm?@0302TY:@0R8R809RHV00808B4Q0100=CDe07]kN`2FUYH0
VIVI075aL@1]KFd0MgMg09jNWP2l_;`0`/;20:NWY`2SXj<0[:b/0:j^[P2_[jl0^;Rh0P30`<003033
`l<0alO70<G5a@2k^k/0[:b/0:>SX`2QXJ40XZ:R0:JVYP2g]kL0^[Zj0<;2`P80b<S800D0][Jf08:2
PP1TI6@0HV9R06a/K002075aL@0X079bLP1hN7P0MGEe07IfMP1mOGd0N7Qh07EeM@1lO7`0PH6106i^
KP1HF5P0<c<c05YJFP21PH40UIFE09:BTP2;Rh/0M7Ad061PH01gMgL0OGem05]KF`1IFET0LG5a07=c
L`1lO7`0LG5a06UYJ@1TI6@0KVi^06=SH`1MGEd0I6AT065QH@1XJ6P0KFe]07YjNP25QHD0V9RH09bL
W080WIfM00h0W9bL09fMW@2QXJ40YZJV0:BTY02UYJD0YjNW0:^[Z`2^[Zh0^KVi0;^k^`2h^;P0_Kfm
0;no_`80`/;204D0`l?30<;2`P30`<00_[jn0;no_`2n_[h0`L710;bl_02b/[80[Jf]0:j^[P2ZZZX0
UIFE08>3P`1`L700KVi^06][J`1VIVH0Jf][075aL@1gMgL0OGem07UiN@1RHV80IFEU06m_K`1VIVH0
Lg=c07AdM01_Kfl0JVYZ05mOG`1>CTh0D51@05=CD`1BDU80AdM703`l?00m?Cd0CTi>03Ti>@0];Bd0
=SHf02l_;`0[:b/0:BTY03<c<`17AdL0BTY:02/[:`1MGEd0W9bL0;Rh^02YZJT0UIFE08>3P`1`L700
FUYJ051@D00e=CD0<30`038b<P0d=3@0>3Ph04];B`0e=CD0>CTi0492@P0l?3`00P0o?cl09P17AdL0
@41003Xj>P0c<c<0<C4a03Ph>00`<300<C4a038b<P0c<c<0<30`03<c<`0d=3@0<S8b03Ti>@0e=CD0
=SHf02d];@0c<c<0>3Ph03hn?P14A4@0DU9B075aL@1mOGd0QHF508Z:RP2<S8`0QXJ608>3P`1nOWh0
OGem08Z:RP2<S8`0VIVI09fMW@2QXJ40WinO0P2PX:00202OWil0XZ:R0:2PX02OWil0W9bL09fMW@2K
Vi/0WYjN0`2LW9`0402JVYX0WinO09^KV`2NWYh0VYZJ09VIV@2JVYX0Vi^K09VIV@2KVi/0VIVI09ZJ
VP2NWYh0VYZJ09VIV@2KVi/309fMW@80WYjN00@0XZ:R0:2PX02LW9`0WYjN0P2MWId209ZJVP0409bL
W02NWYh0VIVI09ZJVP80VIVI00h0Vi^K09ZJVP2HV9P0V9RH09VIV@2KVi/0VIVI09NGU`2IVIT0Vi^K
09bLW02MWId0W9bL09fMW@80WYjN01D0Vi^K09jNWP2NWYh0X:2P09bLW02GUiL0VIVI096AT@2FUYH0
V9RH09NGU`2KVi/0UYJF09FEU@2DU9@0SHf=08n?S`29RHT0Rh^;08N7Q`29RHT00P28R8P00`26QXH0
QHF508>3P`0>0<SPf0003038h=P206=SH`0<06IVIP1SHf<0JFUY06IVIP1XJ6P0IFEU06IVIP1]KFd0
Jf][06e]K@1VIVH0JFUY0P1XJ6P06P1VIVH0Hf=S061PH01SHf<0IFEU05iNGP1CDe<0EUIF05YJFP1G
EeL0GemO06YZJP1cLg<0Ogmo07inOP2:RXX0U9BD09JFUP2GUiL0W9bL09jNWP2UYJD0YjNW0:b/[02b
/[80/;2`0P2][Jd01@2[Zj/0[jn_0:n_[`2`/;00[jn_0080/[:b0100/;2`0;:b/P2a/K40/k>c0:j^
[P2ZZZX0XJ6Q09fMW@2IVIT0Ti>C08Z:RP23Ph<0NGUi071`L01WIfL0F5QH0P1>CTh02@1=CDd0D51@
05ADE01DE5@0FEUI05aLG01KFe/0GUiN06=SH`03061PH00406=SH`1UIFD0MGEe06][J`80IfMW00<0
IFEU069RHP1WIfL00P1TI6@0201UIFD0I6AT06IVIP1TI6@0HF5Q05YJFP1NGUh0Hf=S0P1QHF401@1R
HV80IFEU06i^KP1RHV80J6QX0080IFEU00D0JFUY06YZJP1ZJVX0J6QX06e]K@02075aL@0=079bLP1`
L700LW9b08N7Q`2ATI40VYZJ09fMW@2OWil0VYZJ09BDU02<S8`0T92@08n?S`0208f=S@0o0:RXZ02M
WId0GEeM04];B`0j>SX0GemO07AdM01bLW80@d=302XZ:P0V9RH0AdM708B4Q026QXH0Ogmo09VIV@1e
MGD0GemO04m?C`0h>3P0EUIF05UIF@0o?cl0<S8b03`l?00c<c<0=3@d04M7A`1@D500JFUY06=SH`1Y
JFT0>c/k03@d=00g=cL0=3@d03Lg=`1>CTh0NWYj06a/K01CDe<0<30`02@T900a<C40E5AD08J6QP1m
OGd0>3Ph02PX:00U9BD0;2`/02TY:@0d=3@0C4a<0410@00g=cL0:b/[02LW9`0V9RH0<30`02PX:00h
>3P0EeMG0080IVIV01<0C4a<03De=@0Z:RX08b<S028R8P0/;2`0;Bd]02`/;00Z:RX0<C4a02PX:00W
9bL0:RXZ03<c<`0e=CD0@d=306a/K01^KVh0@D510080:b/[0100<C4a02l_;`0R8R807QhN020P800Q
8B40BTY:07]kN`2NWYh0SXj>07]kN`1bLW80PH610:>SX`2o_kl0^KVi0P2XZ:P04P2YZJT0Zj^[0;:b
/P2h^;P0_Kfm0<71`@36a/H0aLG50;no_`2e]KD0ZJVY09ZJVP2QXJ40W9bL0;6a/@2e]KD0_[jn0<C4
a080alO702h0_Kfm09FEU@1/K6`0Kfm_075aL@1hN7P0OWin07emO@1kNg/0O7al08Z:RP27QhL0QXJ6
08B4Q02:RXX0Ph>307=cL`1?Cdl0Ng]k09^KV`2MWId0Vi^K09fMW@29RHT0LG5a08B4Q029RHT0MWIf
05]KF`1/K6`0IFEU06YZJP1TI6@0GUiN05MGE`1MGEd0FUYJ055AD@1JFUX0G5aL069RHP1_Kfl0MgMg
08n?S`2NWYh0YJFU0P2TY:@20:>SX`070:NWY`2ZZZX0XZ:R0:FUY@2YZJT0[Zj^0:n_[`020;Zj^P03
0;Vi^@2l_;`0`L7100@0`L7100L0_[jn0;Zj^P2l_;`0^[Zj0<30`02g]kL0^;Rh0080];Bd01h0]kNg
0:f][@2HV9P0Ogmo06m_K`1KFe/0EUIF05YJFP1OGel0IfMW07AdM01/K6`0J6QX079bLP1iNGT0NWYj
06e]K@28R8P0Rh^;07YjNP1aLG40HV9R06=SH`1RHV80Fe]K04];B`10@400=SHf03Xj>P0h>3P202XZ
:P0J02TY:@0`<300:BTY03<c<`15ADD0@d=302TY:@1TI6@0XZ:R0;Ng]`2SXj<0TY:B0820P01cLg<0
G5aL03Ph>00a<C40<c<c02h^;P0f=SH0@D5104Y:BP0b<S80>CTi0492@P0l?3`203hn?P0>04U9B@0o
?cl0ADE503<c<`0d=3@0>CTi02l_;`0^;Rh0@T9203Hf=P0d=3@0?Cdm03@d=00a<C4203@d=00E03`l
?00e=CD0=SHf03Lg=`0n?Sh0?Cdm04Y:BP1WIfL0N7Qh08J6QP2@T900S8b<08Z:RP22PX80QHF508:2
PP27QhL0TI6A09RHV02OWil0WYjN0080X:2P0P2QXJ401`2RXZ80WYjN09nOW`2RXZ80Xj>S09fMW@2Q
XJ400P2KVi/01`2LW9`0WIfM09jNWP2MWId0WinO09fMW@2LW9`00P2MWId01`2JVYX0V9RH09fMW@2L
W9`0VIVI09ZJVP2IVIT00P2LW9`0402QXJ40WYjN09jNWP2LW9`0XJ6Q09nOW`2QXJ40Vi^K09nOW`2K
Vi/0WIfM09NGU`2MWId0VIVI09^KV`2LW9`209BDU00A09JFUP2LW9`0Vi^K09bLW02HV9P0Vi^K09fM
W@2LW9`0WinO09^KV`2HV9P0WIfM09VIV@2JVYX0W9bL09fMW@2IVIT00P2JVYX04P2MWId0VYZJ09VI
V@2HV9P0UYJF09NGU`2IVIT0UYJF09RHV02CTi<0U9BD096AT@2?Shl0RHV908b<S02:RXX0Q8B408>3
P`<0QXJ600<0PH6108:2PP38h=P03@38h=P000`0b>3H0P1WIfL206=SH`0;06EUI@1ZJVX0I6AT06=S
H`1YJFT0IfMW06e]K@1XJ6P0IVIV06=SH`1RHV800P1VIVH00`1QHF40Hf=S06=SH`0206=SH`0D05aL
G01KFe/0EeMG05YJFP1PH600I6AT07=cL`1iNGT0PX:208N7Q`2DU9@0UIFE09ZJVP2FUYH0XJ6Q0:RX
Z02[Zj/0[Zj^0;2`/02a/K420:ZZZP0N0:f][@2a/K40/K6a0:n_[`2[Zj/0[Zj^0;6a/@2c/k<0/K6a
0;:b/P2][Jd0[:b/0:ZZZP2PX:00W9bL09VIV@2@T900SHf=08J6QP1kNg/0J6QX05eMG@1CDe<0CTi>
04e=C@1?Cdl0EUIF05=CD`1@D500EeMG0P1FEUH06`1PH600Fe]K06EUI@1QHF40H61P06ATI01OGel0
I6AT06EUI@1XJ6P0K6a/06YZJP1SHf<0IVIV06QXJ01RHV80IFEU06MWI`1VIVH0HV9R06IVIP1MGEd0
Hf=S06QXJ01UIFD0HV9R06EUI@0206QXJ00306][J`1WIfL0JVYZ0080K6a/01<0LG5a06YZJP1]KFd0
JFUY06m_K`1aLG40LW9b07MgM`1bLW80Ng]k08B4Q02?Shl0UIFE09^KV`2FUYH0TI6A08b<S02ATI40
RHV90080RXZ:00<0VYZJ08:2PP12@T800P0a<C40?`0m?Cd0?3`l03lo?`0/;2`08b<S02XZ:P1ADE40
Ph>30820P01lO7`0SHf=06EUI@1ADE40De=C04e=C@1aLG40J6QX04m?C`18B4P0BDU903Xj>P0k>c/0
@41004M7A`1VIVH0GUiN05mOG`0l?3`0<C4a02d];@0a<C40<S8b03De=@1LG5`0LW9b05mOG`1ADE40
:BTY02XZ:P1^KVh0RXZ:05iNGP0[:b/092@T02TY:@0a<C409RHV03@d=017AdL0>c/k03hn?P0g=cL0
;Rh^02XZ:P0/;2`0<c<c03Ti>@1KFe/0GEeM065QH@0l?3`0>3Ph030`<00302@T900=02TY:@0X:2P0
:BTY02LW9`0Z:RX0<30`034a<@1IFET0De=C061PH025QHD0DU9B02DU9@0202/[:`0/04U9B@1LG5`0
9bLW020P800M7Ad07alO038b<P1RHV80SXj>0:NWY`2FUYH0PX:2075aL@22PX80Z:RX0<?3``2g]kL0
XJ6Q0:RXZ02/[:`0/K6a0;>c/`2h^;P0^k^k0<O7a`36a/H0a<C40;^k^`2WYjL0UYJF09ZJVP2IVIT0
Z:RX0:^[Z`2j^[X0_kno0<71`@35aLD0alO70<30`02NWYh0Kfm_06i^KP1kNg/208:2PP0N08>3P`25
QHD0RHV909:BTP2CTi<0SXj>09:BTP2:RXX0MGEe07YjNP2@T900YJFU0:>SX`2PX:00Vi^K08n?S`1o
Ogl0PH6108Z:RP1nOWh0Fe]K06QXJ01JFUX0GUiN05EEE@1DE5@0Cdm?04];B`1>CTh0B4Q80P1>CTh0
1P1PH600MWIf08N7Q`2FUYH0YZJV0:ZZZP80ZJVY00T0YZJV0:RXZ02WYjL0Zj^[0:ZZZP2][Jd0[:b/
0;2`/02/[:`00P2e]KD0BP2i^KT0`L710;jn_P2m_Kd0`<300<71`@2o_kl0^[Zj0;^k^`31`L40_Kfm
0<;2`P2n_[h0`<300;Zj^P2g]kL0_;bl0;Bd]02XZ:P0VYZJ08b<S01fMWH0HV9R05ADE01HF5P0De=C
065QH@1OGel0EeMG06a/K01VIVH0LW9b06IVIP1kNg/0RHV90861P@1hN7P0KVi^075aL@1UIFD0GemO
05EEE@0m?Cd0>SXj03Lg=`0f=SH0:BTY02/[:`0W9bL0:2PX02XZ:P0^;Rh0@d=304I6AP0a<C40Jf][
0:^[Z`2e]KD0YJFU09FEU@24Q8@0Lg=c05MGE`0k>c/0=cLg03<c<`0h>3P0=CDe04M7A`1CDe<0>CTi
03`l?00m?Cd0?3`l0P0m?Cd0<015ADD0@d=303dm?@0g=cL0>c/k03<c<`0/;2`0;bl_03<c<`0`<300
<S8b03De=@0`<300>SXj03Ph>00i>CT0>3Ph03Ti>@0j>SX0>CTi038b<P0e=CD0@D5105]KF`1aLG40
Ph>308^;R`29RHT0RXZ:08:2PP21PH40OGem08>3P`2<S8`0UiNG09ZJVP2SXj<0X:2P0::RXP2VYZH0
YJFU09nOW`2SXj<0WinO09fMW@2RXZ80WinO09jNWP80WIfM00T0X:2P09fMW@2MWId0W9bL09^KV`2J
VYX0WinO09ZJVP2IVIT00`2LW9`02P2KVi/0VYZJ09nOW`2JVYX0Vi^K09ZJVP2NWYh0WIfM09bLW02Q
XJ4209fMW@0:0:2PX02MWId0W9bL09ZJVP2LW9`0WYjN09VIV@2HV9P0WIfM09jNWP80UiNG0`2IVIT0
0`2KVi/0V9RH09VIV@0209bLW00409fMW@2LW9`0VYZJ09^KV`80W9bL0P2MWId01`2IVIT0VYZJ09VI
V@2JVYX0UiNG09VIV@2JVYX00P2EUID01P2DU9@0TY:B09>CT`2>SXh0TI6A092@T080SXj>0P2=SHd0
1029RHT0QhN708J6QP26QXH208B4Q00308F5Q@38h=P0b>3H00`0b>3H000<0<SPf080J6QX00l0IVIV
06UYJ@1VIVH0I6AT06IVIP1TI6@0J6QX06YZJP1WIfL0JFUY06QXJ01RHV80Hf=S069RHP1YJFT00P1U
IFD00`1SHf<0H61P05mOG`0205iNGP0B05UIF@1KFe/0GemO06MWI`1^KVh0O7al08>3P`2:RXX0Ti>C
09RHV02EUID0VIVI0:>SX`2WYjL0ZZZZ0:n_[`2/[:`0[jn_0P2^[Zh02`2][Jd0/K6a0:n_[`2^[Zh0
/K6a0;2`/02a/K40/[:b0;Bd]02`/;00[jn_0080ZJVY01L0X:2P09fMW@2FUYH0TI6A08f=S@27QhL0
OWin06UYJ@1MGEd0De=C055AD@1>CTh0E5AD05EEE@1BDU80De=C059BDP1HF5P0EeMG05iNGP1FEUH0
G5aL069RHP0206=SH`0F06EUI@1QHF40J6QX06a/K01ZJVX0IFEU06QXJ01VIVH0IfMW06EUI@1SHf<0
HF5Q06=SH`1QHF40IFEU05eMG@1UIFD0IVIV06=SH`1/K6`0IFEU06=SH`80IVIV01D0KVi^06m_K`1]
KFd0K6a/06UYJ@1`L700Kfm_079bLP1dM7@0MGEe079bLP1iNGT0Lg=c07IfMP1eMGD0OWin08R8R02B
TY80SXj>08n?S`2:RXX00P27QhL2092@T00<0:JVYP2BTY80B4Q80451@@0h>3P0<30`02`/;00T92@0
9RHV02TY:@0V9RH0DU9B0P20P8005@21PH40QhN706QXJ01JFUX0F5QH05aLG01RHV80BDU903dm?@1;
Bd/0FUYJ059BDP0h>3P0=CDe0492@P1PH600GemO055AD@1JFUX0=CDe030`<00202XZ:P0O02LW9`15
ADD0H61P05eMG@1XJ6P0@410030`<01nOWh0Q8B403lo?`0P82009RHV02@T900_;bl0<c<c04E5A@1Q
HF40C4a<04I6AP0l?3`0=cLg03dm?@1SHf<0ATI603lo?`1KFe/0G5aL04=3@`0W9bL0=CDe03/k>`02
02TY:@0>02PX:00[:b/09bLW02DU9@0Y:BT08b<S02d];@0c<c<0Cdm?05mOG`1VIVH0MWIf05ADE00V
9RH202d];@0E05]KF`1IFET0;Rh^02XZ:P0O7al07AdM02@T900i>CT0MGEe09ZJVP2WYjL0R8R806i^
KP1XJ6P0Shn?0;Ng]`33`l<0[:b/0:NWY`2ZZZX0[Jf]0080];Bd00L0_[jn0<;2`P36a/H0alO70;no
_`2/[:`0Xj>S0080UYJF01l0XJ6Q0:VYZ@2c/k<0_;bl0;jn_P34a<@0aLG50<O7a`31`L40Zj^[07al
O01dM7@0N7Qh07YjNP26QXH0RHV908j>SP2GUiL0VIVI09ZJVP2EUID0SXj>07]kN`2FUYH0WIfM09nO
W`2SXj<0X:2P09ZJVP2;Rh/0QHF50080OWin00D0Lg=c065QH@1QHF40EUIF05=CD`0204Q8B00<04A4
A00o?cl0?clo0451@@1?Cdl0Fe]K07UiN@28R8P0UIFE0:6QX@2WYjL0Zj^[0P2WYjL00`2[Zj/0Y:BT
0:NWY`020:^[Z`0O0:f][@2_[jl0];Bd0;2`/02i^KT0^;Rh0;bl_035aLD0_;bl0;jn_P2k^k/0`L71
0;^k^`2j^[X0_;bl0<71`@33`l<0aLG50<71`@32`/80_[jn0;bl_031`L40_kno0;Vi^@2a/K40YjNW
09bLW028R8P0KVi^065QH@0205QHF00T05IFEP1>CTh0F5QH051@D01EEED0E5AD06e]K@1^KVh0MGEe
06m_K`1XJ6P0JVYZ06][J`1QHF40E5AD03lo?`0c<c<0;Rh^03De=@0Z:RX0;2`/02HV9P0W9bL0;Bd]
034a<@18B4P0@D5102l_;`1iNGT0];Bd0;Jf]P2SXj<0TI6A08J6QP1fMWH0ATI60P0n?Sh02@0d=3@0
<c<c03@d=01EEED0@T9203lo?`14A4@0@D5103dm?@0204A4A00B04=3@`0m?Cd0?Cdm03Hf=P0d=3@0
<C4a02`/;00g=cL0<S8b030`<00g=cL0=3@d02l_;`0d=3@0>3Ph03De=@13@d<0>3Ph0P0g=cL0800_
;bl0>3Ph03`l?01FEUH0KVi^0820P029RHT0TI6A08Z:RP26QXH0P8200861P@23Ph<0RHV909:BTP2G
UiL0WYjN0:>SX`2OWil0Y:BT0:>SX`2RXZ80XJ6Q0:2PX02NWYh0WinO09jNWP2RXZ80W9bL09jNWP2L
W9`0WIfM0P2NWYh209fMW@0409RHV02LW9`0VIVI09bLW080WIfM0`2LW9`04`2PX:00WinO09jNWP2M
WId0WYjN09fMW@2SXj<0VIVI0:6QX@2MWId0WinO09jNWP2MWId0Vi^K09bLW02OWil0Vi^K09VIV@2H
V9P00`2IVIT0102LW9`0WinO09RHV02KVi/309bLW00909^KV`2JVYX0Vi^K09^KV`2NWYh0Vi^K09fM
W@2LW9`0WYjN0080VYZJ00T0W9bL09ZJVP2HV9P0UYJF09BDU02HV9P0UYJF09:BTP2@T9000P2?Shl0
302ATI40Rh^;08n?S`2=SHd0RXZ:08V9R@28R8P0QXJ608V9R@28R8P0QHF50861P@h0b>3H000<0<SP
f080Jf][01@0IFEU06a/K01VIVH0Jf][06QXJ01VIVH0JFUY06QXJ01PH600I6AT06=SH`1TI6@0IfMW
06YZJP1UIFD0I6AT06IVIP1LG5`0HV9R05aLG080GUiN00h0EUIF05mOG`1PH600J6QX07AdM01nOWh0
Q8B408f=S@2?Shl0U9BD09fMW@2PX:00Z:RX0:NWY`80[:b/00d0[Zj^0:n_[`2[Zj/0Zj^[0:n_[`2`
/;00/[:b0:j^[P2_[jl0/[:b0;6a/@2`/;00/K6a00<0[Jf]00d0ZJVY09nOW`2MWId0U9BD096AT@2@
T900PX:207]kN`1]KFd0Hf=S05MGE`1=CDd0BDU90080C4a<00X0E5AD051@D01HF5P0GEeM05UIF@1K
Fe/0FEUI06=SH`1MGEd0GUiN0P1OGel0201VIVH0Hf=S06i^KP1WIfL0I6AT06a/K01UIFD0IfMW0P1R
HV802P1UIFD0HV9R05mOG`1VIVH0IFEU06QXJ01UIFD0HV9R06MWI`1VIVH206ATI00306EUI@1VIVH0
JVYZ0080Kfm_00H0KFe]071`L01`L700LW9b07EeM@1_Kfl207IfMP0;07EeM@1jNWX0MgMg07YjNP1m
OGd0P82008Z:RP28R8P0QXJ608^;R`2EUID00P2HV9P0<P2UYJD0T92@05iNGP16ATH0=SHf034a<@0]
;Bd09BDU02LW9`0];Bd0<30`051@D01kNg/0R8R809fMW@2BTY80KVi^05aLG01PH600KFe]05mOG`10
@400?clo04U9B@1PH600EeMG03hn?P0f=SH0>3Ph0492@P1KFe/0Cdm?06a/K01DE5@0;Rh^030`<00^
;Rh0=SHf02d];@17AdL0HV9R05mOG`1FEUH0>c/k08f=S@1oOgl0;Rh^028R8P0U9BD0:2PX0P0W9bL0
800c<c<0CDe=03lo?`12@T80>SXj02/[:`0m?Cd0De=C02XZ:P0c<c<0BTY:05ADE00d=3@0:BTY03Hf
=P0n?Sh0:RXZ02PX:00S8b<0;2`/02TY:@0P8200:2PX02TY:@0d=3@0D51@06IVIP1IFET0?Cdm06UY
J@1QHF409BDU0P0c<c<0<01MGEd0>SXj02d];@0n?Sh08R8R02PX:00W9bL0:RXZ051@D025QHD0XZ:R
092@T01bLW80I6AT07=cL`2JVYX0_kno0;fm_@2VYZH0WYjN0:ZZZP2`/;00/[:b0;Rh^02k^k/0`L71
0<K6aP34a<@0/k>c0:JVYP2KVi/0U9BD09bLW02UYJD0Z:RX0;:b/P2k^k/0_Kfm0<30`035aLD0`l?3
0;fm_@2a/K40R8R807IfMP1iNGT0Ph>308^;R`80TI6A0280V9RH09VIV@2IVIT0V9RH09:BTP2MWId0
XZ:R09^KV`2FUYH0UIFE08n?S`21PH40NWYj06e]K@1PH600GEeM059BDP16ATH0CDe=04=3@`11@D40
?clo03Ti>@16ATH0Cdm?05UIF@1WIfL0PH6109JFUP2PX:00ZJVY0:n_[`2[Zj/0ZZZZ0P2][Jd01P2[
Zj/0Z:RX0:^[Z`2ZZZX0Zj^[0;2`/080[jn_00@0][Jf0;Vi^@2l_;`0^[Zj0`2o_kl07@2n_[h0_kno
0;jn_P2m_Kd0^KVi0;fm_@31`L40`l?30<;2`P2n_[h0_kno0;jn_P33`l<0a<C40;no_`2n_[h0^k^k
0;>c/`2[Zj/0VYZJ096AT@1oOgl0LW9b06YZJP1HF5P0Cdm?05ADE012@T80Bd];0080EEEE00<0FEUI
05iNGP1HF5P00`1FEUH01@17AdL0=SHf02l_;`0^;Rh0<C4a0080;2`/01X0:b/[030`<00`<300>CTi
0492@P0k>c/0;Rh^07EeM@2^[Zh0]kNg0:FUY@2CTi<0RHV907EeM@10@400?Shn03@d=00h>3P0=3@d
03/k>`1?Cdl0?Cdm04=3@`1@D500ADE50451@@80@T9200`0AdM70451@@0m?Cd0=cLg03De=@0[:b/0
;Bd]03Hf=P0a<C40<c<c02l_;`0a<C4202d];@0M03<c<`0i>CT0>SXj03Ph>00b<S80<C4a03Hf=P0a
<C40>SXj04i>CP1[Jf/0PX:208^;R`2>SXh0R8R808N7Q`23Ph<0OGem08:2PP24Q8@0SHf=09FEU@2M
WId0Y:BT0::RXP2PX:00XZ:R0:FUY@2QXJ400`2PX:00102OWil0WYjN09ZJVP2MWId209bLW0090:2P
X02KVi/0XJ6Q09fMW@2OWil0WYjN09fMW@2KVi/0VIVI0080Vi^K0100VIVI09^KV`2LW9`0VYZJ09jN
WP2MWId0XJ6Q09jNWP2OWil0XJ6Q0::RXP2NWYh0X:2P09fMW@2IVIT0Vi^K0`2LW9`00`2IVIT0Vi^K
09^KV`0209^KV`0609VIV@2JVYX0VIVI09ZJVP2GUiL0WYjN0P2IVIT209bLW00509VIV@2JVYX0WYjN
09bLW02NWYh00P2JVYX209RHV00<09bLW02BTY80UIFE092@T02ATI40TY:B08n?S`2=SHd0TI6A08n?
S`2ATI40SXj>0P29RHT00`2>SXh0QhN708:2PP0208F5Q@0308N7Q`25QHD0PX:200h0b>3H000<0<SP
f080I6AT0P1YJFT0301TI6@0J6QX06MWI`1RHV80J6QX06IVIP1WIfL0HV9R06QXJ01TI6@0HF5Q06EU
I@80Hf=S00<0H61P06IVIP1QHF400P1NGUh04`1KFe/0EEEE05]KF`1MGEd0KFe]07AdM021PH40Q8B4
096AT@2DU9@0VIVI09jNWP2MWId0XZ:R0:RXZ02WYjL0[:b/0:n_[`2^[Zh00P2`/;00102b/[80/k>c
0:n_[`2][Jd20;:b/P080;Bd]02_[jl0/K6a0;:b/P2^[Zh0ZZZZ0:RXZ02UYJD209bLW00609JFUP2<
S8`0QHF507IfMP1/K6`0GUiN0P1CDe<02`1;Bd/0AdM704Y:BP1?Cdl0EEEE05ADE01FEUH0De=C05aL
G01NGUh0HF5Q0080GUiN00X0GemO05iNGP1UIFD0IFEU071`L01VIVH0HV9R06MWI`1SHf<0HV9R0P1S
Hf<206QXJ00906EUI@1WIfL0I6AT06IVIP1ZJVX0IfMW06IVIP1RHV80IVIV0080JFUY00/0JVYZ06e]
K@1WIfL0L71`06i^KP1cLg<0MWIf079bLP1cLg<0Kfm_07MgM`0207IfMP05079bLP1nOWh0PH6107Yj
NP1kNg/00P20P8000`2;Rh/0XZ:R0;Bd]00209bLW00K09ZJVP1_Kfl0BTY:04U9B@0k>c/0?Cdm02d]
;@0V9RH09bLW02TY:@0`<300EUIF07inOP2<S8`0[:b/0:6QX@28R8P0Ph>308J6QP1fMWH0K6a/05IF
EP11@D40?Cdm05IFEP1BDU80@d=30080?Cdm0180=SHf05MGE`1MGEd0Fe]K08:2PP18B4P0:b/[02PX
:00^;Rh09BDU03@d=01GEeL0Fe]K05aLG01FEUH0T92@06m_K`0Y:BT2024Q8@0D02PX:00W9bL09RHV
02XZ:P0l?3`0C4a<0492@P1>CTh0C4a<03/k>`0e=CD0:BTY03/k>`1?Cdl0B4Q803De=@0`<300:b/[
03`l?00];Bd202LW9`0=02PX:00Z:RX09bLW02XZ:P0^;Rh0BTY:06e]K@1PH600<c<c02PX:01>CTh0
Hf=S02PX:00204];B`0X05aLG00[:b/0=SHf04i>CP0X:2P08R8R01dM7@0_;bl0>SXj06i^KP2=SHd0
WYjN0861P@1UIFD0HV9R07UiN@2KVi/0_kno0;6a/@2QXJ40Zj^[0:n_[`2`/;00]kNg0;Vi^@2j^[X0
`l?30<O7a`2m_Kd0[jn_09^KV`2GUiL0VYZJ09bLW02[Zj/0[:b/0;bl_02m_Kd0^[Zj0<K6aP80`l?3
00X0`<300;Vi^@2BTY80Ng]k07emO@24Q8@0RHV908n?S`2FUYH0W9bL0P2FUYH209NGU`0<09BDU02A
TI40S8b<08B4Q01mOGd0M7Ad06QXJ01LG5`0Bd];04=3@`0k>c/0ATI60P0m?Cd03P14A4@0C4a<05QH
F01NGUh0LG5a08B4Q02=SHd0Vi^K0:NWY`2YZJT0[jn_0;2`/02][Jd0[jn_0P2e]KD00`2a/K40[Zj^
0:b/[0020:j^[P0@0;6a/@2_[jl0[jn_0;:b/P2n_[h0_Kfm0;Zj^P30`<00`l?30<71`@32`/80`L71
0;fm_@2l_;`0^k^k0<;2`P80_[jn00D0_Kfm0<30`02o_kl0`L710<G5a@020<W9b@0H0<K6aP35aLD0
`/;20<;2`P2n_[h0^[Zj0:j^[P2JVYX0T92@07moO`1aLG40IVIV06ATI01OGel0H61P05]KF`1>CTh0
AdM704E5A@0n?Sh0?Cdm04A4A00h>3P0<c<c0P0X:2P07@0/;2`0:2PX02/[:`0Z:RX0;bl_034a<@0k
>c/0ADE503Ti>@0];Bd0NGUi0:b/[02l_;`0ZJVY09:BTP2<S8`0HF5Q03De=@0l?3`0;Rh^03Ph>00f
=SH0>CTi04Q8B00o?cl0B4Q804=3@`0l?3`0>c/k0080ATI602d0@41003hn?P0k>c/0>c/k03Ph>00d
=3@0=cLg03dm?@0d=3@0<S8b02`/;00];Bd0<C4a030`<00i>CT0?Cdm03Hf=P0g=cL0=CDe03Hf=P0a
<C40;Bd]03Lg=`1<C4`0GEeM07EeM@2:RXX0SXj>08^;R`29RHT0R8R808:2PP20P800Ogmo08^;R`2B
TY80WIfM0::RXP2SXj<0YJFU0:>SX`2VYZH0XJ6Q09bLW02OWil00`2NWYh0702LW9`0WinO09fMW@2Q
XJ40WIfM09bLW02PX:00VYZJ09fMW@2LW9`0WIfM09ZJVP2LW9`0Vi^K09fMW@2LW9`0VYZJ09nOW`2J
VYX0WIfM09ZJVP2OWil0Vi^K0::RXP2LW9`0WinO0::RXP2PX:0209bLW00609ZJVP2HV9P0VYZJ09ZJ
VP2KVi/0WYjN0P2GUiL0202JVYX0W9bL09ZJVP2LW9`0Vi^K09FEU@2HV9P0UiNG0`2LW9`02`2JVYX0
WIfM09nOW`2IVIT0Vi^K09bLW02IVIT0UIFE09^KV`2JVYX0U9BD0080SXj>0180TI6A092@T02>SXh0
T92@08f=S@2@T900TY:B08n?S`2:RXX0Rh^;08Z:RP2>SXh0RHV908>3P`26QXH0QHF508J6QP25QHD>
0<SPf0003038h=P206=SH`0406IVIP1RHV80IVIV06EUI@80I6AT00P0JFUY06ATI01UIFD0IfMW06YZ
JP1TI6@0Hf=S065QH@<0I6AT0100Hf=S05iNGP1NGUh0GemO05]KF`1GEeL0FUYJ061PH01UIFD0LW9b
07emO@23Ph<0SXj>09:BTP2GUiL0VYZJ0P2PX:000`2WYjL0Z:RX0:b/[0020:b/[080[Jf]00H0/[:b
0;2`/02d];@0[jn_0;6a/@2^[Zh20;:b/P0B0;6a/@2b/[80/;2`0:ZZZP2XZ:P0XJ6Q09fMW@2JVYX0
TY:B08j>SP21PH40M7Ad06UYJ@1OGel0De=C051@D01:BTX0CTi>0P1@D5006@1?Cdl0FEUI05UIF@1F
EUH0FEUI065QH@1UIFD0HF5Q05eMG@1SHf<0IfMW06IVIP1WIfL0I6AT06QXJ01UIFD0JFUY06EUI@1S
Hf<0JFUY06EUI@1XJ6P0KFe]06a/K01ZJVX00P1WIfL0201VIVH0J6QX06QXJ01XJ6P0IFEU061PH01W
IfL0Jf][0P1YJFT02P1ZJVX0KVi^07=cL`1iNGT0Lg=c07AdM01eMGD0NGUi07EeM@1iNGT207]kN`08
07QhN01lO7`0N7Qh07UiN@1mOGd0QXJ60;:b/P3AdM420:j^[P1808N7Q`1TI6@0<c<c03Hf=P0d=3@0
;bl_02d];@0V9RH0:2PX038b<P0l?3`0EEEE07]kN`2;Rh/0UYJF0;Vi^@3;bl/0`<300;Zj^P1oOgl0
Kfm_05UIF@19BDT0A4A405=CD`1?Cdl0@D5103Lg=`0d=3@0?clo0451@@1QHF40B4Q807moO`1hN7P0
;2`/02PX:00];Bd09bLW02TY:@0m?Cd0FUYJ06EUI@1hN7P0UiNG079bLP0W9bL08B4Q02@T900[:b/0
=3@d02<S8`0Z:RX0=3@d03De=@0l?3`0EUIF0492@P0b<S80>c/k03@d=017AdL0ATI603Ti>@0_;bl0
:RXZ02`/;00j>SX0=cLg02l_;`0b<S80:b/[0P0`<3002P0/;2`0@T92061PH01XJ6P0CTi>04I6AP0b
<S80?3`l061PH00^;Rh205]KF`1005=CD`0U9BD0;Bd]05EEE@0a<C407alO02LW9`0U9BD08b<S03hn
?P1eMGD0UiNG09nOW`1^KVh0Fe]K061PH01kNg/0ZZZZ0;Vi^@2^[Zh0YZJV0:f][@2/[:`0];Bd0;:b
/P2h^;P0`<300<;2`P34a<@0]KFe0:FUY@2JVYX0W9bL09RHV02OWil0Z:RX0;Jf]P2l_;`0^k^k0;fm
_@32`/80`l?30<;2`P31`L40^[Zj09VIV@1iNGT0MWIf07YjNP22PX80RHV9092@T02<S8`0SXj>08f=
S@29RHT0Ogmo07UiN@1eMGD0KVi^06][J`1TI6@0Fe]K051@D080?clo0180A4A404M7A`19BDT0Bd];
05UIF@1ZJVX0Kfm_07YjNP2=SHd0WYjN0:FUY@2XZ:P0/;2`0;>c/`2`/;00[jn_0;6a/@2c/k<20;Bd
]0030;>c/`2d];@0/;2`00<0[:b/00<0[jn_0;:b/P2d];@00P2j^[X02031`L40a<C40<;2`P30`<00
`L710;no_`2m_Kd0^;Rh0P2l_;`20;jn_P090<71`@32`/80`/;20<G5a@38b<P0b/[:0<S8b039bLT0
b<S80080cLg=03<0c<c<0<K6aP33`l<0_;bl0:j^[P2VYZH0Vi^K08^;R`21PH40NWYj06m_K`1XJ6P0
GUiN05ADE012@T80?Shn03Ti>@0h>3P0;bl_02/[:`0W9bL0:BTY02HV9P0X:2P0:b/[02TY:@0/;2`0
<C4a03`l?01?Cdl0=cLg038b<P1mOGd0[Zj^0;^k^`2[Zj/0Shn?08>3P`1OGel0<C4a03Xj>P0_;bl0
<c<c03Xj>P15ADD0C4a<03Hf=P0j>SX0A4A40410@00j>SX00P0n?Sh03`0o?cl0?Cdm03/k>`0h>3P0
<c<c03Ph>00k>c/0<C4a03De=@0/;2`0>SXj03Ph>00d=3@0<30`03De=@0203`l?00R03@d=00a<C40
<C4a02`/;00b<S80;bl_04I6AP1PH600Jf][07moO`28R8P0SHf=08V9R@28R8P0QXJ60861P@1oOgl0
Q8B409>CT`2HV9P0Vi^K0::RXP2YZJT0YZJV0:>SX`2PX:00WinO09jNWP2OWil0XJ6Q09nOW`2MWId0
W9bL09jNWP80WIfM00L0WYjN09fMW@2MWId0WIfM09nOW`2NWYh0VYZJ0080WYjN01H0W9bL09jNWP2N
WYh0WYjN0:2PX02OWil0WIfM09nOW`2PX:00XZ:R0:2PX02RXZ80X:2P0:6QX@2NWYh0W9bL09^KV`2E
UID0WYjN09RHV02JVYX0WIfM0P2GUiL0102MWId0VYZJ09^KV`2GUiL209^KV`0509RHV02LW9`0Vi^K
09^KV`2FUYH00`2JVYX209NGU`0309JFUP2IVIT0Ti>C0080UYJF00H0V9RH09BDU02BTY80TI6A08b<
S02@T90208f=S@03096AT@2<S8`0T92@0080Rh^;00P0S8b<08V9R@26QXH0QHF508>3P`25QHD0Q8B4
08F5Q@h0b>3H000<0<SPf080Hf=S00<0IfMW06ATI01UIFD00P1TI6@02P1UIFD0I6AT06QXJ01XJ6P0
IFEU06UYJ@1QHF40Hf=S06ATI01XJ6P206EUI@03065QH@1RHV80GEeM0080G5aL0100GUiN05]KF`1S
Hf<0IfMW07IfMP1nOWh0Ph>308V9R@2ATI40UiNG09^KV`2OWil0Y:BT0:JVYP2YZJT0ZZZZ0P2`/;02
0:j^[P090;>c/`2_[jl0];Bd0;>c/`2a/K40[jn_0;2`/02a/K40[Zj^0080[:b/01H0[Jf]0:BTY02P
X:00Vi^K09RHV02BTY80Rh^;07moO`1iNGT0K6a/05iNGP1GEeL0DE5A04Y:BP1=CDd0BDU904i>CP1I
FET0De=C05UIF@1BDU80F5QH0P1LG5`02`1SHf<0GUiN065QH@1TI6@0GemO065QH@1XJ6P0IFEU06MW
I`1YJFT0IVIV00@0IfMW00L0J6QX061PH01WIfL0JFUY06=SH`1ZJVX0IFEU0080JFUY0P1WIfL00`1[
Jf/0JVYZ06i^KP0306e]K@03075aL@1eMGD0MgMg0080N7Qh00<0MGEe07AdM01gMgL00P1jNWX0201g
MgL0Ng]k07UiN@1iNGT0N7Qh0861P@2f][H0gmoO0P2g]kL00`1/K6`0GEeM03@d=00203De=@0Y02`/
;00W9bL09bLW02d];@0W9bL0:b/[03Ph>01QHF40T92@09RHV02^[Zh0e=CD0=KFeP2l_;`0Ng]k07If
MP1ZJVX0EEEE051@D01[Jf/0EeMG04I6AP0b<S80<C4a03@d=00l?3`0G5aL04E5A@1HF5P0Ph>304U9
B@0Y:BT0:2PX034a<@0[:b/0;2`/04Q8B01QHF40OWin08R8R01aLG400P0R8R8202PX:00303Hf=P0^
;Rh09bLW0080<30`01P0;bl_03Ph>00g=cL0>3Ph03@d=00o?cl0BTY:03Ti>@0c<c<0:BTY030`<00_
;bl0=SHf03Ti>@0];Bd0:b/[02LW9`0_;bl0B4Q804I6AP1?Cdl0FUYJ059BDP0b<S8203dm?@0303@d
=01GEeL0<c<c0080JFUY00H0CTi>02HV9P0_;bl0G5aL03@d=00M7Ad202LW9`0J020P800Z:RX0C4a<
08B4Q02VYZH0Ph>306a/K01LG5`0I6AT08R8R02`/;00_kno0:j^[P2YZJT0ZZZZ0:b/[02_[jl0]KFe
0;Rh^02n_[h0`/;20;^k^`2YZJT0UiNG09ZJVP2HV9P209jNWP0[0;Jf]P2j^[X0_[jn0;jn_P32`/80
a<C40<;2`P31`L40`/;20<71`@2NWYh0MWIf06IVIP1XJ6P0KVi^07IfMP1hN7P0NGUi07MgM`1eMGD0
K6a/06IVIP1PH600IfMW06EUI@1KFe/0De=C04e=C@1GEeL0EEEE05eMG@1UIFD0Jf][079bLP1mOGd0
QHF509:BTP2HV9P0WinO0:NWY`2^[Zh0/;2`0;Vi^@020;Fe]@030;2`/02][Jd0/K6a0080/k>c00`0
/[:b0;6a/@2_[jl0[jn_0:f][@2ZZZX0/k>c0;Fe]@2h^;P0^KVi0;fm_@2o_kl30<71`@0A0;no_`32
`/80_;bl0;Zj^P2l_;`0_kno0;bl_030`<00`/;20<K6aP33`l<0a/K60<W9b@3:b/X0b<S80<[:bP3;
bl/00`3>c/h0:@3=cLd0c<c<0<W9b@31`L40^;Rh0;Fe]@2XZ:P0V9RH096AT@21PH40Lg=c061PH01O
Gel0AdM703dm?@0i>CT0=CDe034a<@0d=3@0:b/[02PX:00V9RH09bLW02PX:00W9bL09RHV034a<@13
@d<0GEeM03Ph>00e=CD0OGem0;Zj^P2i^KT0Xj>S08f=S@1kNg/0FUYJ03Xj>P0k>c/0;Bd]0080?3`l
00L0BTY:04=3@`0m?Cd0>SXj03hn?P0j>SX0>CTi00<0@41000T0C4a<03hn?P12@T80=CDe03Hf=P0e
=CD0;Rh^02l_;`0];Bd00P0d=3@01@0`<300=cLg03Xj>P0a<C40=cLg0080=3@d01@0<C4a02/[:`0[
:b/0<c<c0492@P1EEED0JVYZ07UiN@25QHD0RHV908j>SP2=SHd0QhN708R8R01oOgl0P82008j>SP2I
VIT0W9bL0::RXP80Y:BT00<0Xj>S0:2PX02RXZ800P2OWil02@2PX:00W9bL0:6QX@2NWYh0WIfM09nO
W`2KVi/0X:2P09jNWP0209bLW080WYjN00H0WIfM0:6QX@2PX:00WinO09bLW02KVi/20:2PX00<0::R
XP2SXj<0XZ:R09nOW`2NWYh0X:2P0:BTY02RXZ80XJ6Q0:>SX`2KVi/0VYZJ0`2IVIT01`2KVi/0WYjN
09jNWP2NWYh0WIfM09bLW02KVi/00`2JVYX04`2LW9`0Vi^K09VIV@2JVYX0VIVI09RHV02JVYX0V9RH
09fMW@2HV9P0U9BD09FEU@2HV9P0UIFE09JFUP2BTY80Shn?08f=S@2<S8`00P2?Shl01P2=SHd0SXj>
08b<S02:RXX0SHf=08V9R@80S8b<00L0Rh^;08n?S`2<S8`0R8R808N7Q`26QXH0RHV900h0b>3H000<
0<SPf080HV9R00T0IfMW06EUI@1UIFD0HV9R06MWI`1QHF40IVIV06EUI@1VIVH00`1SHf<01@1WIfL0
IFEU06EUI@1SHf<0HF5Q0080H61P01<0G5aL061PH01KFe/0Fe]K05iNGP1SHf<0IVIV07EeM@1oOgl0
R8R808V9R@2CTi<0V9RH09ZJVP2RXZ80Y:BT0:RXZ02VYZH0ZZZZ0080[jn_0`2`/;00102a/K40[jn_
0;2`/02`/;040;6a/@0=0:f][@2[Zj/0[:b/0:ZZZP2QXJ40WYjN09JFUP2CTi<0Rh^;0820P01jNWX0
Jf][065QH@0205QHF00804Q8B01:BTX0DU9B04i>CP1EEED0F5QH05UIF@1EEED205YJFP0Y05UIF@1K
Fe/0H61P061PH01VIVH0IFEU06IVIP1ZJVX0J6QX06MWI`1ZJVX0JFUY06QXJ01[Jf/0IFEU06MWI`1T
I6@0IVIV06YZJP1WIfL0HV9R06ATI01QHF40IfMW06YZJP1UIFD0IVIV06a/K01TI6@0IfMW06YZJP1/
K6`0Lg=c06i^KP1bLW80Kfm_07QhN01iNGT0LW9b07MgM`1fMWH00`1gMgL01`1eMGD0N7Qh07IfMP1g
MgL0Ph>30:n_[`3Ti>@00P3:b/X0<`2=SHd0Kfm_07=cL`1FEUH0>3Ph02DU9@0Q8B408R8R02DU9@0V
9RH0:RXZ02DU9@19BDT0S8b<08Z:RP2GUiL0YJFU0:^[Z`2IVIT0O7al07]kN`1`L700JFUY06EUI@1c
Lg<0JFUY04i>CP0i>CT0<30`03De=@10@400FEUI06IVIP11@D40Jf][05mOG`0X:2P08R8R02PX:00/
;2`0:2PX03Xj>P1OGel0Ogmo0861P@1ZJVX0820P01lO7`0V9RH0:b/[0451@@0202`/;00O02h^;P0h
>3P0=3@d03<c<`0i>CT0:RXZ03@d=00e=CD0>SXj030`<00[:b/0;bl_02XZ:P0/;2`0=CDe03Xj>P0g
=cL0;Rh^038b<P0h>3P0>CTi03De=@0^;Rh0BTY:04I6AP0_;bl0:b/[02`/;00h>3P0H61P04U9B@02
06a/K00/03hn?P0`<300<S8b05mOG`12@T80:RXZ02DU9@0P82007AdM02<S8`0[:b/0KFe]08^;R`2I
VIT0PX:206=SH`1MGEd0K6a/08n?S`2e]KD0`L710:b/[02UYJD0[:b/0:j^[P2c/k<0/[:b0;no_`30
`<00^k^k0:f][@2JVYX0WIfM09VIV@2LW9`0WIfM0:f][@2h^;P0_Kfm0<30`033`l<0a<C40<K6aP35
aLD20<30`0030;no_`2ZZZX0N7Qh0080EEEE00X0EeMG05QHF01QHF40HF5Q061PH01VIVH0Hf=S05]K
F`1PH600J6QX0P1TI6@03@1FEUH0IVIV06i^KP1cLg<0NWYj07alO026QXH0T92@09bLW02SXj<0YZJV
0:f][@2_[jl00P2c/k<20;Jf]P040;Fe]@2a/K40/[:b0;>c/`<0/;2`00X0[jn_0;Fe]@2][Jd0ZZZZ
0:n_[`2e]KD0^KVi0;Jf]P2j^[X0^k^k0P32`/830<30`0030<;2`P2l_;`0_kno0080_kno00h0`l?3
0;no_`2o_kl0`l?30<71`@35aLD0alO70<W9b@3:b/X0c<c<0<S8b03<c<`0c/k>0=3@d0<0c/k>0180
bl_;0<K6aP37alL0/k>c0:j^[P2TY:@0T92@08F5Q@1_Kfl0I6AT04a<C00o?cl0>c/k03Hf=P0];Bd0
:b/[02HV9P0W9bL202PX:00K02LW9`0Z:RX0:RXZ02l_;`15ADD0HV9R03Ti>@0n?Sh0Vi^K0;^k^`2e
]KD0WYjN08V9R@1hN7P0DU9B03<c<`0e=CD0<c<c03/k>`17AdL0CDe=0492@P0a<C40=CDe0492@P0h
>3P0>CTi0080@T9200/0?Shn04I6AP14A4@0ADE503/k>`0i>CT0;Rh^03De=@0_;bl0<c<c02l_;`02
034a<@0J038b<P0g=cL0=CDe03Hf=P0i>CT0=SHf02l_;`0Z:RX0<C4a03@d=00k>c/0De=C06=SH`1f
MWH0Q8B408n?S`2>SXh0RHV908J6QP24Q8@0OWin08B4Q02=SHd0T92@09NGU`2QXJ420:BTY0070:6Q
X@2RXZ80WinO09jNWP2OWil0X:2P09bLW00309jNWP050::RXP2QXJ40WinO09nOW`2NWYh0102LW9`0
2P2NWYh0VYZJ09jNWP2OWil0WIfM09nOW`2PX:00Xj>S09nOW`2QXJ430:>SX`0:0:FUY@2SXj<0Y:BT
0:6QX@2OWil0Vi^K09VIV@2JVYX0WYjN09NGU`<0WIfM00D0VYZJ09^KV`2NWYh0VIVI09^KV`0309RH
V00809VIV@2GUiL0U9BD09FEU@2CTi<0TY:B09FEU@2GUiL209BDU00609NGU`2EUID0TY:B092@T02:
RXX0Shn?0P2@T900302:RXX0TI6A08b<S02ATI40SHf=08b<S02=SHd0SXj>08V9R@2?Shl0RXZ:08N7
Q`80R8R800<0RHV908N7Q`38h=P03@38h=P000`0b>3H0P1WIfL01`1TI6@0HF5Q06MWI`1SHf<0IVIV
06EUI@1VIVH00P1PH600301SHf<0I6AT06ATI01TI6@0HF5Q06ATI01RHV80IFEU06ATI01UIFD0GEeM
061PH0<0FEUI00h0GemO06YZJP1cLg<0OWin08:2PP2;Rh/0T92@09>CT`2KVi/0XJ6Q0:BTY02UYJD0
Z:RX0:VYZ@80[jn_0P2`/;020;6a/@050:n_[`2a/K40/;2`0;6a/@2`/;000P2a/K405`2][Jd0[:b/
0:RXZ02WYjL0X:2P09fMW@2GUiL0TI6A08^;R`23Ph<0MgMg06][J`1SHf<0EeMG055AD@1@D500A4A4
04];B`1CDe<0DE5A05UIF@1GEeL0Fe]K0080HF5Q01T0FUYJ061PH01PH600Hf=S06MWI`1XJ6P0JFUY
06QXJ01YJFT0IVIV06ATI01PH600IVIV061PH01HF5P0IfMW06EUI@1TI6@0IFEU06QXJ01SHf<0GemO
06EUI@1RHV80IfMW0080J6QX0100KVi^06YZJP1[Jf/0KVi^06][J`1eMGD0Lg=c07IfMP1cLg<0MWIf
07EeM@1fMWH0N7Qh07UiN@1eMGD0MWIf0P1hN7P207IfMP0307EeM@1jNWX0UYJF00<0cLg=00P0_Kfm
0:FUY@2LW9`0RXZ:04I6AP0T92@09RHV02DU9@809RHV02D09bLW02/[:`0n?Sh0KVi^08:2PP27QhL0
R8R808:2PP1mOGd0PH6108>3P`1iNGT0KFe]06UYJ@1bLW80L71`05iNGP1DE5@0ADE502l_;`0n?Sh0
?clo069RHP16ATH0FUYJ06e]K@0o?cl09BDU02<S8`0T92@0;2`/03@d=01@D500MGEe0861P@1bLW80
:b/[00808b<S00P09RHV03dm?@0b<S80<c<c03Ti>@0o?cl0>CTi03@d=0<0;bl_01<0<c<c0410@00b
<S80:2PX034a<@0Y:BT0:RXZ02/[:`0d=3@0;2`/02h^;P0e=CD0<c<c03De=@0a<C40;2`/04M7A`0g
=cL0:RXZ0080:BTY00<0<30`06EUI@1EEED00P1/K6`00`0i>CT0:BTY038b<P0205]KF`0F03Lg=`0b
<S80;Rh^02TY:@0N7Qh08b<S03/k>`1iNGT0S8b<0:2PX01hN7P0GemO06ATI01bLW80UiNG0<K6aP2j
^[X0ZJVY0:^[Z`2VYZH0YjNW0;2`/080^KVi02X0]kNg0:^[Z`2SXj<0VYZJ09^KV`2FUYH0Vi^K0:BT
Y02c/k<0_Kfm0<?3``31`L40`<300<;2`P35aLD0`<300;jn_P2k^k/0^KVi0;2`/029RHT0Cdm?04E5
A@17AdL0EEEE05UIF@1MGEd0IFEU06YZJP1^KVh0J6QX07AdM01iNGT0OGem07inOP1mOGd0Q8B408N7
Q`29RHT0U9BD09RHV02NWYh20:JVYP040:b/[02a/K40[jn_0;Fe]@80];Bd00D0]kNg0;Fe]@2e]KD0
];Bd0:j^[P030;>c/`80[jn_00X0/[:b0:n_[`2d];@0]kNg0;Rh^02g]kL0_Kfm0;^k^`33`l<0`/;2
0P33`l<01@30`<00`/;20;no_`30`<00_[jn0080a<C400L0`/;20<?3``34a<@0b<S80<C4a039bLT0
b/[:0080bLW90P3;bl/00`3?cll0c/k>0<g=c@020=3@d00/0<c<c03=cLd0b<S80<;2`P2i^KT0[Zj^
0:BTY02HV9P0Q8B406m_K`1BDU80@D5103`l?00g=cL0<30`038b<P0[:b/09RHV02DU9@0V9RH08R8R
02DU9@0/;2`0;bl_0451@@1OGel0;Rh^051@D02PX:00^KVi0;Fe]@2OWil0QhN705iNGP10@400>3Ph
03De=@0n?Sh0@41004=3@`0h>3P0=cLg03<c<`0i>CT203dm?@0303Xj>P0k>c/0>c/k0080BDU900T0
AdM704I6AP18B4P0?Cdm03De=@0b<S80=CDe03@d=00`<3000P0c<c<0500b<S80<30`034a<@0e=CD0
=3@d038b<P0a<C40;bl_03<c<`0[:b/0<C4a04Q8B01MGEd0Lg=c08:2PP2:RXX0Rh^;08V9R@26QXH0
Q8B40P20P8007P26QXH0TI6A09NGU`2OWil0XJ6Q09nOW`2TY:@0XJ6Q0:2PX02QXJ40WYjN0:2PX02N
WYh0X:2P09jNWP2PX:00Vi^K09fMW@2NWYh0YJFU09bLW02QXJ40WYjN09nOW`2LW9`0WYjN09fMW@2R
XZ80X:2P09nOW`80X:2P00D0XZ:R0:BTY02NWYh0Xj>S0:VYZ@020:6QX@0:0:FUY@2QXJ40WinO09^K
V`2LW9`0VYZJ09^KV`2NWYh0W9bL09VIV@<0Vi^K00<0WYjN09^KV`2GUiL00P2HV9P03P2FUYH0V9RH
09BDU02DU9@0TY:B09NGU`2FUYH0TY:B09FEU@2FUYH0UIFE09JFUP2KVi/0T92@0P2BTY802P2@T900
Shn?08^;R`2>SXh0Shn?08j>SP2ATI40RXZ:09:BTP2@T90208b<S00308Z:RP2@T900Rh^;0080RXZ:
00<0Rh^;08Z:RP2;Rh/03P38h=P000`0b>3H0P1YJFT00`1XJ6P0IFEU06i^KP0206=SH`0506QXJ01T
I6@0HV9R06=SH`1VIVH00`1QHF401@1TI6@0IFEU05eMG@1QHF40GemO00<0GEeM01<0GemO05EEE@1N
GUh0I6AT06QXJ01bLW80OGem08Z:RP2?Shl0RHV909JFUP2MWId0WYjN0:JVYP2UYJD0[:b/0:^[Z`2/
[:`0[Zj^0080[Jf]0P2_[jl20:f][@030;6a/@2^[Zh0/[:b0080[Zj^0P2][Jd03`2YZJT0Z:RX0:>S
X`2OWil0U9BD09:BTP2<S8`0P82007EeM@1YJFT0GEeM05IFEP1CDe<0BTY:04I6AP0205=CD`07059B
DP1GEeL0FEUI059BDP1IFET0F5QH05iNGP03061PH00<065QH@1TI6@0IfMW06ATI01YJFT0K6a/06IV
IP1WIfL0JFUY06ATI01WIfL0IVIV0P1XJ6P206EUI@0:06ATI01WIfL0IFEU06UYJ@1TI6@0JVYZ06e]
K@1YJFT0Jf][06UYJ@<0L71`0180Kfm_07AdM01_Kfl0MWIf07MgM`1jNWX0M7Ad07EeM@1iNGT0MgMg
07EeM@1hN7P0MGEe07QhN01eMGD0M7Ad07emO@2GUiL20:VYZ@080;Jf]P2IVIT0RHV909nOW`21PH40
>3Ph03<c<`0n?Sh204=3@`0804i>CP1IFET0HV9R07IfMP1oOgl0QXJ607alO01mOGd208:2PP0j0861
P@20P800NGUi071`L01]KFd0PH6107emO@1aLG40GUiN03@d=00^;Rh0<S8b04e=C@1NGUh0AdM707Mg
M`1GEeL08R8R02<S8`0Y:BT09bLW02l_;`0l?3`0FUYJ0861P@1ZJVX0>SXj02@T900V9RH08R8R030`
<00g=cL0<S8b03De=@18B4P0CDe=04I6AP0n?Sh0?3`l038b<P0n?Sh0@d=302d];@0X:2P0;2`/02PX
:00U9BD0:RXZ02PX:00];Bd0<C4a038b<P0c<c<0>SXj03<c<`0_;bl0EeMG04M7A`8092@T00@09RHV
02`/;01DE5@0IFEU0P1/K6`06`0l?3`08b<S02<S8`1:BTX0KFe]0451@@15ADD0D51@03/k>`0W9bL0
8B4Q02XZ:P15ADD0OGem09fMW@2GUiL0M7Ad05]KF`1UIFD0OGem0:ZZZP36a/H0^KVi0:BTY02XZ:P0
YjNW0:^[Z`020;>c/`0:0;Ng]`2[Zj/0YZJV09ZJVP2LW9`0UYJF09fMW@2VYZH0/[:b0;Rh^0<0`<30
0100_[jn0<K6aP2o_kl0_[jn0;no_`2k^k/0][Jf0;Rh^02SXj<0KFe]04i>CP1:BTX0DU9B06IVIP1e
MGD0KVi^0P1iNGT01P26QXH0RHV908j>SP2CTi<0TI6A09BDU080V9RH00@0WYjN0:BTY02[Zj/0ZZZZ
0P2^[Zh02@2ZZZX0/K6a0;Bd]02`/;00];Bd0;Jf]P2d];@0/;2`0;Bd]0030:j^[P090;6a/@2`/;00
/K6a0;:b/P2_[jl0]KFe0;Ng]`2f][H0^;Rh0080_Kfm0P34a<@20<K6aP070<71`@34a<@0`L710<;2
`P2m_Kd0_[jn0<?3``020<G5a@80alO70P3:b/X01P37alL0b<S80<W9b@3;bl/0c/k>0=7Ad@80d=3@
01l0d];B0=7Ad@3?cll0c<c<0<k>cP38b<P0aLG50;fm_@2c/k<0WYjN09:BTP1iNGT0HV9R04M7A`0m
?Cd0=cLg03<c<`0`<300<S8b02XZ:P0X:2P0:b/[02PX:00^;Rh09BDU02d];@18B4P0FEUI02`/;01N
GUh0WYjN0080/[:b00<0Vi^K08J6QP1OGel00P13@d<02`12@T80>3Ph03Hf=P0n?Sh0@D5103Xj>P14
A4@0Bd];0410@00n?Sh0@4100080?Cdm01D0ADE504=3@`1?Cdl0De=C03hn?P0o?cl0=cLg03Xj>P0_
;bl0<C4a02`/;00g=cL0=3@d034a<@0f=SH0=3@d03Ph>00n?Sh0>CTi030`<00/;2`00P0a<C401@0d
=3@0ADE505MGE`1bLW80OWin0080RXZ:00<0SXj>08Z:RP2:RXX00P21PH405P25QHD0Rh^;09>CT`2M
WId0XZ:R0:>SX`2UYJD0XZ:R09nOW`2RXZ80WYjN09nOW`2PX:00XZ:R0:6QX@2SXj<0WinO0::RXP2P
X:00WIfM09jNWP2OWil20:6QX@0309fMW@2PX:00XJ6Q0080Xj>S00<0Y:BT0:FUY@2TY:@00P2RXZ80
202UYJD0Y:BT0:BTY02SXj<0YZJV0:2PX02NWYh0VYZJ0P2MWId00`2KVi/0WinO09bLW00209^KV`80
WIfM00l0Vi^K09bLW02GUiL0U9BD09RHV02FUYH0VYZJ09FEU@2BTY80UYJF09>CT`2ATI40TY:B09FE
U@2DU9@00P2ATI403`2BTY80TI6A092@T02BTY80T92@08n?S`2>SXh0S8b<092@T02<S8`0Rh^;08j>
SP2?Shl0T92@08b<S00308f=S@0708^;R`29RHT0SXj>08n?S`2<S8`0SXj>09>CT`0>0<SPf0003038
h=P205mOG`80J6QX00`0IFEU06IVIP1RHV80IfMW06IVIP1MGEd0HV9R06IVIP1XJ6P0HV9R06=SH`1T
I6@2069RHP0C06MWI`1PH600GemO05aLG01NGUh0FEUI05YJFP1KFe/0JFUY06QXJ01^KVh0PH6108R8
R02?Shl0TI6A09NGU`2IVIT0W9bL0:>SX`020:JVYP030:VYZ@2/[:`0[:b/0080[:b/00<0[Zj^0:n_
[`2^[Zh00P2a/K401@2b/[80[jn_0;6a/@2_[jl0/k>c0080[:b/01H0Z:RX0:2PX02MWId0UYJF09>C
T`2;Rh/0QHF507IfMP1/K6`0H61P05EEE@1CDe<0BTY:04Q8B01<C4`0CTi>04m?C`1DE5@0De=C05QH
F01NGUh0FEUI0P1OGel0801SHf<0IFEU06EUI@1SHf<0I6AT06MWI`1YJFT0IFEU06MWI`1YJFT0KFe]
06IVIP1SHf<0IfMW06=SH`1VIVH0I6AT06=SH`1WIfL0I6AT06][J`1RHV80Hf=S069RHP1VIVH0IfMW
06QXJ01ZJVX0Jf][071`L01bLW80Lg=c0P1aLG403`1bLW80M7Ad07IfMP1`L700LW9b07MgM`1mOGd0
MWIf07]kN`1eMGD0N7Qh07MgM`1lO7`0MgMg07emO@0208B4Q00?08F5Q@1mOGd0OWin09jNWP2^[Zh0
PH6105YJFP1_Kfl0MWIf07UiN@2:RXX0VYZJ0::RXP2>SXh0Ogmo00<0O7al0P1nOWh0:P24Q8@0PX:2
0820P01dM7@0LG5a07UiN@2:RXX0PH6106IVIP11@D40;Bd]02h^;P0g=cL0E5AD04U9B@1ZJVX0LG5a
02`/;00Q8B40:BTY028R8P0/;2`0<C4a04U9B@27QhL0IfMW05YJFP0Z:RX08R8R02TY:@0_;bl0<c<c
02TY:@0Z:RX0<S8b0410@01JFUX0HF5Q05mOG`1@D500@d=304I6AP80>SXj0100<C4a02/[:`0W9bL0
;2`/02TY:@0Z:RX0;2`/03@d=00e=CD0>3Ph02/[:`0a<C40FUYJ05QHF00];Bd08b<S0P0V9RH0;00l
?3`0JFUY06=SH`1SHf<0?Cdm02DU9@0T92@0>SXj06YZJP11@D40;2`/03@d=010@400=SHf02h^;P0_
;bl0:b/[05QHF023Ph<0YZJV08V9R@1PH600GEeM065QH@27QhL0];Bd0<;2`P2_[jl0Xj>S0:JVYP2`
/;00[:b/0;>c/`2b/[80[Zj^0:FUY@2VYZH0Vi^K09bLW02NWYh0YjNW0;>c/`2g]kL0_kno0P2n_[h0
402j^[X0_kno0;fm_@2i^KT0];Bd0;Vi^@2d];@0][Jf0;Fe]@2UYJD0RHV906a/K01TI6@0J6QX07al
O01kNg/208Z:RP0508j>SP2CTi<0U9BD09VIV@2PX:000P2SXj<20:FUY@090:RXZ02YZJT0YZJV0:j^
[P2a/K40[jn_0;:b/P2_[jl0/;2`0080/k>c00@0];Bd0;:b/P2`/;00/[:b0P2`/;003P2a/K40[jn_
0;Bd]02g]kL0]KFe0;Rh^02g]kL0^[Zj0;jn_P31`L40`<300<;2`P36a/H0aLG50P33`l<01030`<00
`L710<C4a030`<030<C4a00B0<G5a@38b<P0alO70<[:bP3;bl/0b/[:0<c<c03=cLd0c/k>0<c<c03A
dM40d=3@0=CDe03Cdm<0e=CD0=7Ad@3@d=00c/k>0P3=cLd03@35aLD0]kNg0:VYZ@2EUID0O7al06IV
IP1EEED0?clo03Xj>P0g=cL0;2`/02XZ:P0X:2P00P0Y:BT04`0W9bL0:RXZ02TY:@0_;bl0?Cdm055A
D@0c<c<0KFe]0:NWY`2d];@0/k>c09NGU`1nOWh0D51@0492@P1<C4`0B4Q803Hf=P0b<S800P0n?Sh0
1P11@D40>SXj03Xj>P0h>3P0?Shn03Xj>P80>3Ph00P0@41004I6AP0j>SX0ADE503hn?P0f=SH0>3Ph
034a<@80<S8b00<0;bl_03<c<`0k>c/00P0_;bl08P0g=cL0<c<c03Ti>@0f=SH0;bl_02`/;00Z:RX0
;Bd]03<c<`10@400De=C06QXJ01fMWH0P82008b<S02:RXX0SHf=08J6QP27QhL0PH6108B4Q02;Rh/0
UYJF09RHV02NWYh0WinO0:6QX@2SXj<0WIfM0:FUY@2RXZ80XJ6Q0:>SX`2PX:020:6QX@0309nOW`2R
XZ80XJ6Q0080WinO00@0WIfM0:6QX@2NWYh0Xj>S0P2OWil20:FUY@040:>SX`2UYJD0Xj>S0:NWY`80
YZJV00d0YJFU0:BTY02RXZ80Xj>S0:6QX@2OWil0X:2P09bLW02RXZ80WIfM09jNWP2PX:00WYjN00@0
Vi^K00`0UiNG09JFUP2HV9P0Ti>C09NGU`2FUYH0Shn?092@T02ATI40TY:B08n?S`2BTY8208n?S`0?
09BDU02@T900T92@092@T02CTi<0TY:B096AT@2CTi<0T92@08f=S@2<S8`0RHV908f=S@2?Shl0T92@
0080Shn?00X0SXj>08f=S@2:RXX0S8b<092@T02?Shl0SXj>08n?S`2@T900Ti>C3P38h=P000`0b>3H
0P1TI6@07@1VIVH0KFe]06=SH`1QHF40I6AT05iNGP1WIfL0HF5Q06EUI@1QHF40IFEU061PH01QHF40
H61P05aLG01MGEd0HF5Q05mOG`1MGEd0GemO05eMG@1HF5P0FEUI05aLG01TI6@0J6QX07MgM`1oOgl0
R8R80080TI6A00H0VIVI09bLW02OWil0YZJV0:RXZ02[Zj/20:f][@<0Zj^[00X0/;2`0:f][@2`/;00
[jn_0:f][@2a/K40[jn_0;6a/@2`/;00/k>c0P2][Jd05P2SXj<0WinO09fMW@2HV9P0Shn?08^;R`23
Ph<0MGEe06e]K@1TI6@0DU9B05ADE01?Cdl0AdM704i>CP1@D500Cdm?05=CD`1FEUH0F5QH05iNGP1O
Gel205iNGP0;069RHP1VIVH0IVIV069RHP1WIfL0GemO065QH@1TI6@0J6QX065QH@1[Jf/00P1WIfL0
0`1ZJVX0J6QX06ATI00206ATI00606MWI`1XJ6P0JFUY06MWI`1XJ6P0IFEU0P1WIfL306a/K00?075a
L@1^KVh0LG5a07=cL`1aLG40Lg=c07MgM`1dM7@0LG5a07QhN01fMWH0Lg=c07QhN01fMWH0N7Qh0080
NGUi00<0MgMg07UiN@1bLW800P1gMgL03P1fMWH0MgMg08J6QP2WYjL0[jn_08N7Q`1oOgl0PX:208N7
Q`2:RXX0WIfM0;fm_@31`L40UIFE0P1eMGD0201dM7@0N7Qh07MgM`20P800QHF508J6QP1oOgl0NGUi
0P1cLg<0:01nOWh0PH6106e]K@1KFe/0>c/k02d];@0_;bl0>SXj0410@01JFUX0N7Qh0410@00R8R80
9RHV01lO7`0T92@0;2`/04i>CP27QhL0H61P06ATI00e=CD09RHV024Q8@0U9BD0=cLg02DU9@0X:2P0
;bl_03Ph>018B4P0De=C06IVIP1^KVh0EUIF051@D01FEUH0@d=303hn?P0a<C4202`/;080;Bd]00h0
<C4a03hn?P0h>3P0<c<c02d];@0[:b/0AdM706m_K`0_;bl09bLW02PX:00V9RH0>3Ph06ATI080MGEe
02T0?Cdm02TY:@0U9BD0;2`/05aLG01VIVH0:RXZ02/[:`0`<300>3Ph038b<P0V9RH092@T02h^;P1T
I6@0SXj>09ZJVP1cLg<0GemO05UIF@1YJFT0U9BD0;Bd]02i^KT0[:b/0:2PX02YZJT0YZJV0;2`/02[
Zj/0[Zj^0:VYZ@2UYJD0WinO0:6QX@2NWYh0YjNW0;2`/02m_Kd0_kno0;jn_P020;Zj^P0Q0;Vi^@2o
_kl0_;bl0;Ng]`2b/[80][Jf0;:b/P2`/;00];Bd0:b/[02RXZ80S8b<07alO025QHD0Rh^;09>CT`2G
UiL0UYJF09jNWP2OWil0XZ:R0:6QX@2SXj<0Y:BT0:NWY`2TY:@0YZJV0:n_[`2YZJT0Z:RX0:j^[P2`
/;00[Zj^0080/K6a00H0/[:b0;6a/@2c/k<0][Jf0;Ng]`2_[jl20;Fe]@040;:b/P2_[jl0][Jf0;Jf
]P<0]kNg0P2j^[X20;jn_P0<0<C4a032`/80`/;20<C4a032`/80`<300<G5a@34a<@0`L710<S8b035
aLD0alO70P36a/H00`39bLT0cLg=0<_;b`020<[:bP050<g=c@3?cll0c<c<0=;BdP3AdM400`3De=@3
0<o?c`0E0<g=c@3;bl/0a/K60;Jf]P2TY:@0U9BD07inOP1YJFT0GemO059BDP17AdL0?3`l034a<@0`
<3009bLW02DU9@0W9bL0:b/[02d];@0X:2P0=CDe0080A4A401D0>c/k07UiN@2VYZH0/[:b0;>c/`2D
U9@0MGEe04m?C`17AdL0@D5104Q8B00f=SH0?clo03dm?@1ADE40B4Q804A4A012@T80<30`03<c<`0j
>SX00P0k>c/02`11@D40@41003`l?014A4@0@41003hn?P0k>c/0=CDe030`<00a<C40<30`0080=3@d
00D0<30`0410@00c<c<0=cLg0410@00203Ph>00>034a<@0^;Rh0:RXZ03@d=00l?3`0BTY:05iNGP1d
M7@0OWin08R8R02<S8`0Rh^;08V9R@26QXH208:2PP0408J6QP2ATI40UiNG09jNWP80Y:BT00H0WinO
0:FUY@2VYZH0XJ6Q0:>SX`2TY:@20::RXP050:2PX02TY:@0Y:BT09jNWP2OWil00`2PX:003@2OWil0
XZ:R0:2PX02PX:00YJFU0:BTY02QXJ40XZ:R0:JVYP2YZJT0Z:RX0:NWY`2TY:@00P2SXj<02@2TY:@0
Xj>S0:2PX02OWil0WIfM09bLW02JVYX0WIfM09bLW00209ZJVP80UiNG00l0UIFE09JFUP2GUiL0T92@
096AT@2HV9P0UYJF08j>SP2CTi<0TY:B092@T02BTY80SXj>08n?S`2@T9000P2ATI404`2=SHd0S8b<
08j>SP2ATI40S8b<08f=S@2ATI40S8b<09:BTP29RHT0SXj>08f=S@2;Rh/0SXj>09BDU02?Shl0T92@
08n?S`2BTY800P2FUYH0102HV9P0UIFE09FEU@2GUiL>0<SPf0003038h=P206EUI@<0IfMW00X0IVIV
06MWI`1WIfL0J6QX069RHP1SHf<0HV9R065QH@1SHf<0GEeM101QHF404`1OGel0HF5Q05YJFP1JFUX0
EUIF05UIF@1LG5`0Hf=S06UYJ@1dM7@0OWin08J6QP2<S8`0UIFE09NGU`2OWil0XJ6Q0:>SX`2UYJD0
0P2ZZZX01`2^[Zh0Z:RX0:f][@2][Jd0[Zj^0;6a/@2^[Zh00P2`/;00902a/K40[Jf]0:n_[`2_[jl0
[Zj^0:b/[02[Zj/0ZJVY0:2PX02MWId0Ti>C09:BTP2<S8`0PH6107=cL`1]KFd0IFEU05MGE`1?Cdl0
BTY:04Q8B01;Bd/0Cdm?04e=C@1BDU80EUIF05YJFP1KFe/0FEUI069RHP1NGUh0Hf=S06ATI01RHV80
IfMW06IVIP80IfMW00`0IFEU065QH@1WIfL0IfMW06IVIP1SHf<0IVIV06QXJ01ZJVX0JFUY06YZJP1V
IVH206QXJ00706EUI@1YJFT0J6QX06MWI`1/K6`0J6QX06][J`02075aL@0=06i^KP1aLG40JVYZ075a
L@1fMWH0LW9b07=cL`1eMGD0NGUi07]kN`1iNGT0NWYj07AdM00207UiN@80MWIf05P0N7Qh07UiN@1e
MGD0MGEe07IfMP1gMgL0QHF50:FUY@2>SXh0HF5Q06m_K`1gMgL0QhN709bLW02XZ:P0^[Zj0;Jf]P1m
OGd0KVi^07YjNP1dM7@0OGem08F5Q@1lO7`0P82008J6QP23Ph<0O7al075aL@1`L700NWYj08B4Q01e
MGD0JVYZ05IFEP0i>CT0;bl_03@d=012@T80FEUI07YjNP1<C4`0:b/[02@T900P82009BDU02`/;01<
C4`0QHF505eMG@1ADE40ADE502LW9`0Y:BT0:RXZ03@d=00g=cL08b<S03@d=017AdL0Bd];04A4A01>
CTh0J6QX07QhN01GEeL0BDU904m?C`18B4P0=CDe034a<@0W9bL0:2PX02l_;`0X:2P0>3Ph03dm?@0a
<C409BDU02/[:`14A4@0LW9b03<c<`0Z:RX0:2PX02/[:`0o?cl0GUiN0P1bLW806`0n?Sh0=SHf02TY
:@0[:b/0@D5107emO@0j>SX0:BTY02@T900];Bd0=3@d02h^;P0Q8B408R8R03hn?P1fMWH0S8b<092@
T01YJFT0EUIF05UIF@1bLW80T92@0;Vi^@2h^;P0WinO0:2PX0020:NWY`090:FUY@2XZ:P0ZZZZ0:FU
Y@2MWId0WinO0:6QX@2YZJT0[jn_00<0_[jn00l0_Kfm0;Zj^P2e]KD0`<300;Zj^P2g]kL0[Jf]0:n_
[`2b/[80^;Rh0:n_[`2^[Zh0/[:b0:RXZ02NWYh00P2EUID0102HV9P0X:2P0:2PX02QXJ420:>SX`09
0:NWY`2UYJD0YJFU0:NWY`2SXj<0YjNW0:VYZ@2WYjL0ZJVY0080Zj^[00<0[Zj^0:n_[`2d];@00P2a
/K40102_[jl0/K6a0;:b/P2b/[820;6a/@80/;2`00l0];Bd0;:b/P2h^;P0^;Rh0;^k^`2h^;P0_kno
0<71`@2n_[h0a<C40<G5a@34a<@0alO70<71`@32`/800P33`l<01@35aLD0b<S80<S8b038b<P0alO7
0080bLW900d0bl_;0<g=c@3<c<`0bl_;0=3@d03AdM40clo?0=;BdP3Cdm<0eMGE0=;BdP3De=@0d=3@
00<0d];B00h0c<c<0<K6aP2a/K40Y:BT096AT@1nOWh0J6QX065QH@1EEED0CTi>03/k>`0b<S809bLW
02HV9P809bLW01/0;Rh^02/[:`0d=3@0>3Ph05ADE01?Cdl0B4Q807MgM`2/[:`0/[:b0;2`/02DU9@0
K6a/05UIF@0g=cL0>3Ph04];B`0c<c<0=SHf03/k>`11@D40BTY:03dm?@0e=CD0>SXj04=3@`0o?cl0
0P0k>c/09@0i>CT0@d=303`l?00m?Cd0@4100451@@0o?cl0=SHf02d];@0`<300<S8b03<c<`11@D40
=3@d03<c<`0f=SH0<c<c03De=@0h>3P0<c<c02d];@0c<c<0:RXZ02/[:`0g=cL0@410059BDP1[Jf/0
NGUi08V9R@2?Shl0SXj>08Z:RP27QhL0P82007emO@23Ph<00P2CTi<02P2KVi/0XZ:R0:>SX`2QXJ40
WYjN0:BTY02VYZH0Xj>S09nOW`2XZ:P30::RXP0409bLW02MWId0XJ6Q09jNWP80WinO00h0Xj>S0:6Q
X@2RXZ80Y:BT0:FUY@2XZ:P0Xj>S0:JVYP2WYjL0YZJV0::RXP2UYJD0YZJV0:NWY`80Xj>S00L0W9bL
0:6QX@2MWId0WYjN09bLW02MWId0Vi^K0080VIVI00H0TY:B09BDU02DU9@0UIFE09NGU`2CTi<2092@
T00609JFUP2ATI40UIFE09:BTP2?Shl0TI6A0P2?Shl03@2>SXh0TI6A096AT@2>SXh0SHf=096AT@2@
T900Ti>C092@T02;Rh/0SXj>092@T02BTY800P2>SXh0102?Shl0TI6A09>CT`2>SXh209>CT`0809BD
U02ATI40U9BD09BDU02HV9P0VIVI09ZJVP2HV9P>0<SPf0003038h=P206MWI`0?06IVIP1^KVh0IfMW
06ATI01VIVH0J6QX069RHP1TI6@0IVIV05iNGP1VIVH0IFEU05iNGP1QHF40Hf=S0080H61P01L0JFUY
06EUI@1NGUh0EeMG05]KF`1IFET0G5aL06EUI@1WIfL0MWIf0861P@28R8P0SXj>09>CT`2LW9`0WIfM
0:6QX@2VYZH0Z:RX0:^[Z`2ZZZX0Z:RX0:^[Z`020:j^[P080;6a/@2`/;00/;2`0:f][@2_[jl0/k>c
0:n_[`2b/[820:b/[00K0:f][@2[Zj/0ZJVY0:2PX02LW9`0Ti>C08f=S@2:RXX0OWin07=cL`1XJ6P0
H61P05QHF01DE5@0Cdm?04Q8B01<C4`0DE5A059BDP1GEeL0G5aL05ADE01IFET0H61P05eMG@1NGUh0
HV9R00@0I6AT00h0IfMW06QXJ01UIFD0H61P06ATI01/K6`0HF5Q06QXJ01YJFT0J6QX06IVIP1WIfL0
HV9R06QXJ080JFUY00@0IVIV06UYJ@1[Jf/0IVIV0P1ZJVX00`1[Jf/0K6a/06i^KP0206e]K@07071`
L01bLW80MgMg07QhN01gMgL0NGUi07IfMP0207UiN@0507MgM`1dM7@0MWIf07emO@1eMGD00P1hN7P0
201jNWX0O7al07alO01gMgL0OGem07inOP2CTi<0N7Qh0P1<C4`09`1QHF40LW9b08j>SP2BTY80RXZ:
08j>SP1WIfL0LW9b0820P01mOGd0O7al08B4Q020P800NWYj08J6QP28R8P0OWin07QhN01fMWH0Lg=c
0820P01kNg/0Kfm_06QXJ01EEED0>c/k02l_;`0c<c<0GEeM06i^KP1=CDd09bLW02HV9P0R8R808b<S
02LW9`1FEUH0Ogmo05YJFP0203lo?`0803Hf=P0d=3@092@T02PX:00m?Cd0;2`/03Xj>P0o?cl203/k
>`0I03<c<`17AdL0KFe]075aL@12@T80>CTi04I6AP0f=SH0=3@d02DU9@0W9bL0;Rh^02`/;00l?3`0
=cLg02TY:@0X:2P09bLW03Lg=`1[Jf/0CDe=02LW9`0Z:RX0;2`/03lo?`0305eMG@0Q03Xj>P0k>c/0
>c/k02PX:00Z:RX0GEeM07EeM@0n?Sh0:2PX02`/;00X:2P09BDU020P800Y:BT0:b/[04U9B@1hN7P0
QhN707EeM@1SHf<0G5aL06IVIP1iNGT0VYZJ0;^k^`2`/;00XJ6Q0:2PX02TY:@0Xj>S0:FUY@2RXZ80
W9bL0080WYjN01<0Xj>S0:JVYP2_[jl0_;bl0;jn_P32`/80_;bl0;Ng]`2d];@0_;bl0;Ng]`2h^;P0
/[:b0:ZZZP2^[Zh0^KVi0;Fe]@2/[:`0ZJVY0080YZJV00X0YjNW09^KV`2HV9P0VYZJ0:6QX@2TY:@0
Z:RX0::RXP2TY:@0YZJV0P2TY:@0102QXJ40YZJV0:>SX`2YZJT20:NWY`050:b/[02[Zj/0];Bd0;:b
/P2][Jd00`2`/;001@2b/[80/;2`0;:b/P2b/[80];Bd0080[Zj^00@0/K6a0;Jf]P2l_;`0_Kfm0P2o
_kl01`32`/80a<C40<C4a038b<P0`/;20<G5a@33`l<00P31`L402@35aLD0`/;20<W9b@38b<P0bLW9
0<S8b03<c<`0b/[:0<W9b@030<c<c0050=3@d03Bd]80e=CD0=3@d03AdM400`3De=@00`3Fe]H0d];B
0=?Cd`020<k>cP0=0<K6aP2d];@0XZ:R08R8R01eMGD0Hf=S061PH01KFe/0EEEE0410@00d=3@0:b/[
02HV9P0302XZ:P0=02PX:00^;Rh0=CDe055AD@1:BTX0Cdm?07QhN02/[:`0Zj^[0;6a/@2ATI40HF5Q
05]KF`0203Hf=P0;0451@@0b<S80>CTi03Xj>P0m?Cd0BDU903/k>`0m?Cd0?clo03hn?P0k>c/00P0l
?3`03`0k>c/0>SXj04E5A@14A4@0@T920410@00i>CT0?3`l03Ti>@0h>3P0<S8b02h^;P0`<300>3Ph
038b<P0202l_;`0=03De=@0g=cL0=CDe02l_;`0c<c<0;2`/02/[:`0/;2`0<c<c04];B`1XJ6P0NWYj
08N7Q`0208b<S00908^;R`27QhL0PX:20861P@23Ph<0RXZ:09>CT`2IVIT0X:2P0080Y:BT00D0XJ6Q
0:FUY@2SXj<0Xj>S0:6QX@020::RXP060:BTY02OWil0Xj>S0:FUY@2RXZ80Xj>S0P2OWil0202RXZ80
X:2P0:6QX@2TY:@0YJFU0:BTY02WYjL0YZJV0P2WYjL01@2RXZ80YjNW0:RXZ02VYZH0XZ:R0080XJ6Q
00H0X:2P09bLW02PX:00WIfM09^KV`2HV9P209JFUP<0UIFE01L0Ti>C09BDU02EUID0Ti>C09BDU02F
UYH0TI6A08n?S`2>SXh0T92@09:BTP2=SHd0S8b<08j>SP2?Shl0SXj>09:BTP2?Shl0SHf=08j>SP2B
TY80Shn?08f=S@0308j>SP07096AT@2BTY80UYJF09>CT`2GUiL0UYJF09RHV00209NGU`0709>CT`2I
VIT0UIFE09NGU`2HV9P0UiNG09^KV`0>0<SPf0003038h=P206IVIP0<06EUI@1[Jf/0IVIV06=SH`1Z
JVX0JFUY06IVIP1TI6@0Hf=S06YZJP1TI6@0IFEU0P1OGel01P1QHF40GUiN05mOG`1WIfL0GemO05iN
GP80Fe]K00h0E5AD05mOG`1UIFD0J6QX07UiN@1jNWX0Q8B408f=S@2CTi<0UIFE09RHV02LW9`0YZJV
0:ZZZP<0[:b/102_[jl08@2^[Zh0/;2`0;2`/02`/;00/K6a0:n_[`2a/K40[jn_0:j^[P2/[:`0Zj^[
0:FUY@2SXj<0W9bL09>CT`2@T900RHV908>3P`1gMgL0Jf][06EUI@1GEeL0Cdm?04];B`1<C4`0B4Q8
04m?C`1DE5@0EeMG05EEE@1DE5@0EUIF05iNGP0205mOG`0;069RHP1XJ6P0Hf=S06ATI01SHf<0IfMW
06IVIP1SHf<0IfMW06UYJ@1XJ6P00P1YJFT08@1XJ6P0IFEU06MWI`1/K6`0JFUY06ATI01UIFD0IVIV
06=SH`1WIfL0K6a/06MWI`1[Jf/0K6a/06YZJP1[Jf/0K6a/06i^KP1bLW80LG5a07AdM01iNGT0MgMg
07IfMP1jNWX0N7Qh07MgM`1fMWH0Lg=c07AdM01cLg<0MWIf079bLP02075aL@0F06i^KP1aLG40LG5a
07MgM`1eMGD0NWYj08V9R@2;Rh/0LG5a05UIF@1KFe/0EEEE065QH@1iNGT0Ng]k07MgM`1PH600L71`
08N7Q`23Ph<0Ng]k0820P080PX:203l0P8200861P@1lO7`0N7Qh07]kN`21PH40Ogmo07QhN01]KFd0
IVIV05MGE`16ATH0;2`/02/[:`0m?Cd0HV9R05YJFP0/;2`09bLW02HV9P0R8R809RHV051@D01mOGd0
DU9B0410@00_;bl0@41004m?C`0[:b/092@T03<c<`0g=cL0?Cdm02l_;`0b<S80;Bd]02h^;P0g=cL0
@T9206][J`1XJ6P0IFEU04M7A`0f=SH0>c/k02XZ:P0U9BD08R8R02/[:`0k>c/0=cLg02h^;P0V9RH0
:BTY03Lg=`1IFET0I6AT02XZ:P0U9BD0:RXZ04M7A`1ADE400P1HF5P03@0i>CT0@41004=3@`0_;bl0
9bLW03`l?01hN7P0LG5a0451@@0`<3008b<S01dM7@0N7Qh00P0P82003P0b<S80De=C079bLP1fMWH0
OWin06a/K01SHf<0JVYZ08>3P`2NWYh0];Bd0:j^[P2RXZ80WIfM0P2QXJ402@2PX:00WinO0:6QX@2Q
XJ40X:2P0:JVYP2][Jd0_;bl0;^k^`020;jn_P0A0;Fe]@2g]kL0^KVi0;Ng]`2d];@0[:b/09bLW02R
XZ80][Jf0;Vi^@2f][H0[:b/0:>SX`2WYjL0YZJV0:BTY02KVi/00P2JVYX05`2LW9`0XJ6Q0:JVYP2Y
ZJT0Y:BT0:6QX@2SXj<0XZ:R09jNWP2TY:@0ZJVY0:NWY`2VYZH0Z:RX0:f][@2`/;00[Jf]0:j^[P2]
[Jd0[Zj^0:n_[`2a/K40/[:b00<0];Bd01L0/K6a0;:b/P2d];@0^;Rh0;jn_P30`<00_Kfm0<;2`P33
`l<0aLG50<K6aP35aLD0`/;20<?3``31`L40a/K60<?3``36a/H0a<C40<W9b@38b<P0alO70<W9b@03
0<c<c0040<S8b03>c/h0dM7A0<o?c`<0d];B0P3Cdm<30=CDe00@0=3@d03<c<`0bl_;0<_;b`36a/H0
/k>c09jNWP28R8P0MgMg06IVIP1PH600HV9R04e=C@14A4@0<c<c02/[:`809bLW01`0:RXZ02PX:00X
:2P0;Rh^03Hf=P1NGUh0AdM705MGE`2?Shl0Zj^[0;2`/02ZZZX0RHV906EUI@1HF5P0;Rh^02l_;`0i
>CT0<30`03<c<`0k>c/0=cLg03/k>`0e=CD0>SXj03Ti>@0d=3@0>SXj0P0n?Sh04@0k>c/0?Cdm04=3
@`16ATH0@41003`l?00k>c/0?clo03Ph>00c<c<0<S8b02h^;P0b<S80=3@d038b<P0`<300<S8b0080
=CDe0100<c<c03Ti>@0^;Rh0;2`/02TY:@0d=3@0<C4a04=3@`1IFET0MWIf08:2PP27QhL0SXj>08b<
S029RHT0QhN70P25QHD02P28R8P0T92@09RHV02NWYh0Y:BT0:NWY`2RXZ80Xj>S0:FUY@2SXj<20::R
XP0909nOW`2QXJ40Xj>S0:2PX02QXJ40Xj>S09nOW`2QXJ40WinO0080XZ:R00D0XJ6Q0:NWY`2UYJD0
XZ:R0:NWY`020:>SX`050:JVYP2RXZ80YJFU0:FUY@2RXZ800P2PX:000`2MWId0VIVI09^KV`0209fM
W@0409bLW02FUYH0UiNG09VIV@<0U9BD00L0TY:B09JFUP2EUID0TI6A09RHV02BTY80Ti>C0080T92@
00P0TY:B09BDU02>SXh0Ti>C092@T02>SXh0SHf=08n?S`80S8b<00T0T92@096AT@2ATI40TY:B08j>
SP2=SHd0TI6A08n?S`2BTY800P2HV9P0202KVi/0VIVI09FEU@2EUID0Ti>C09NGU`2FUYH0UiNG0P2H
V9P00`2FUYH0VIVI0<SPf00=0<SPf0003038h=P206ATI00306QXJ01ZJVX0Hf=S0080IVIV00<0Jf][
06YZJP1UIFD00P1SHf<03@1TI6@0IVIV065QH@1QHF40I6AT06IVIP1YJFT0HF5Q069RHP1LG5`0FUYJ
05UIF@1KFe/00P1QHF403@1[Jf/0MWIf0861P@24Q8@0Rh^;096AT@2FUYH0VIVI09nOW`2TY:@0Z:RX
0:n_[`2/[:`00P2_[jl20:b/[080[jn_00@0/;2`0:b/[02`/;00[jn_0P2c/k<06P2_[jl0[Zj^0:n_
[`2[Zj/0Z:RX09fMW@2LW9`0VYZJ09:BTP2;Rh/0Q8B407=cL`1VIVH0H61P05IFEP1ADE40Bd];055A
D@1>CTh0DE5A05=CD`1DE5@0De=C05UIF@1OGel0GUiN0P1PH6001@1OGel0IVIV06IVIP1PH600IFEU
0080J6QX00h0HV9R06EUI@1ZJVX0IVIV06QXJ01VIVH0JFUY06m_K`1ZJVX0JFUY06YZJP1[Jf/0IVIV
06ATI080IVIV00X0J6QX06UYJ@1[Jf/0KFe]06i^KP1]KFd0JVYZ07=cL`1/K6`0LW9b0P1fMWH03P1h
N7P0M7Ad079bLP1_Kfl0K6a/079bLP1/K6`0Kfm_06][J`1]KFd0KVi^06EUI@1/K6`0JFUY0P1TI6@0
E01UIFD0IfMW079bLP21PH40U9BD09:BTP1hN7P0EeMG05eMG@1GEeL0OGem07UiN@1XJ6P0JFUY07=c
L`26QXH0Ph>30820P01nOWh0QXJ609:BTP29RHT0QhN707]kN`1jNWX0OWin08:2PP1jNWX0Lg=c069R
HP1KFe/0CTi>04M7A`0_;bl0:BTY02d];@1FEUH0Fe]K02l_;`0Y:BT092@T02HV9P0T92@0Cdm?07]k
N`15ADD0<30`02`/;00j>SX0HV9R03@d=00Y:BT0:2PX03Ti>@0X:2P09BDU02@T900W9bL0;2`/03Hf
=P0n?Sh0CDe=06=SH`1YJFT0HV9R03lo?`0f=SH0=cLg02PX:00Y:BT0<30`03Ti>@0l?3`0;Rh^02/[
:`0/;2`0;Bd]059BDP1TI6@0;Bd]02HV9P0];Bd0BTY:03`l?080?Shn00X0>CTi02TY:@0a<C40<S8b
02d];@0^;Rh0Hf=S08b<S01QHF40:BTY0P0O7al07`0M7Ad07alO024Q8@0X:2P0?Shn06a/K02>SXh0
UiNG08B4Q01lO7`0LG5a06i^KP26QXH0YjNW0;bl_02][Jd0WIfM09jNWP2SXj<0X:2P09nOW`2RXZ80
XJ6Q0:JVYP2/[:`0[jn_0;^k^`2l_;`0^[Zj0;^k^`2l_;`00`2k^k/06`2b/[80[Zj^092@T02?Shl0
Zj^[0;Fe]@2l_;`0^;Rh0:NWY`2YZJT0YjNW0:JVYP2QXJ40WYjN09ZJVP2KVi/0W9bL0:2PX02UYJD0
YZJV0:>SX`2NWYh0WIfM0:>SX`2QXJ40YZJV0:6QX@020:RXZ0030;2`/02[Zj/0/;2`0080[Jf]0P2`
/;009@2^[Zh0];Bd0;Fe]@2e]KD0][Jf0;:b/P2f][H0^;Rh0;Vi^@2n_[h0_Kfm0;no_`31`L40a<C4
0<?3``36a/H0alO70<C4a037alL0`/;20<C4a037alL0`l?30<C4a035aLD0bl_;0<S8b03:b/X0bLW9
0<[:bP3>c/h0bl_;0<c<c03?cll0d=3@0<o?c`3AdM400P3Bd]80503Cdm<0e]KF0=KFeP3Cdm<0dM7A
0<k>cP3:b/X0alO70<30`02/[:`0Vi^K08Z:RP1cLg<0I6AT05aLG01IFET0DE5A0410@00d=3@0:RXZ
0P0U9BD05P0Z:RX0:BTY02`/;00a<C40>3Ph05eMG@19BDT0F5QH09JFUP2ZZZX0[Zj^0:ZZZP23Ph<0
FEUI05IFEP0];Bd0>CTi03`l?00_;bl0;Rh^02XZ:P0_;bl203Ti>@0303<c<`0d=3@0?Cdm00<0>3Ph
00<0?3`l04A4A00n?Sh00P10@400:P12@T80@41003/k>`0i>CT0<c<c030`<00Z:RX0:b/[03<c<`0_
;bl0<S8b03@d=00h>3P0<S8b03Ti>@0b<S80<c<c02d];@0Y:BT0;2`/03<c<`0j>SX0De=C079bLP1k
Ng/0Q8B408^;R`2?Shl0SXj>08F5Q@28R8P0QhN708J6QP2?Shl0UIFE09ZJVP2QXJ40Y:BT0:>SX`2W
YjL0YZJV0:>SX`80XJ6Q00X0XZ:R0:6QX@2OWil0X:2P09nOW`2NWYh0WIfM09jNWP2OWil0X:2P0P2R
XZ802`2UYJD0XZ:R0:>SX`2TY:@0XJ6Q0:BTY02WYjL0Xj>S0:BTY02SXj<0X:2P0080WinO00X0Vi^K
09fMW@2MWId0VYZJ09fMW@2HV9P0VYZJ09:BTP2FUYH0T92@0P2BTY80202ATI40Ti>C09>CT`2BTY80
Ti>C09FEU@2DU9@0Shn?0`2@T9001@2>SXh0Shn?092@T02?Shl0TI6A0080Shn?00@0S8b<096AT@2=
SHd0SXj>0P2BTY8209>CT`0909FEU@2DU9@0Vi^K09RHV02LW9`0VYZJ09FEU@2HV9P0UiNG0080UYJF
00D0V9RH09FEU@2FUYH0U9BD09RHV00>0<SPf0003038h=P206ATI00706IVIP1ZJVX0HV9R06UYJ@1S
Hf<0I6AT06=SH`0206MWI`0C06ATI01QHF40IFEU06=SH`1LG5`0HV9R06EUI@1MGEd0I6AT05mOG`1N
GUh0Fe]K05YJFP1IFET0H61P06ATI01/K6`0Lg=c07inOP0208Z:RP07092@T02CTi<0U9BD09bLW02X
Z:P0Y:BT0:VYZ@020:f][@060:b/[02[Zj/0Zj^[0:n_[`2^[Zh0[Jf]0P2^[Zh00`2b/[80[jn_0;2`
/0020:j^[P0G0:f][@2[Zj/0XZ:R0:6QX@2LW9`0VYZJ09BDU02=SHd0PH6107IfMP1ZJVX0GEeM05AD
E01EEED0DE5A04];B`1<C4`0Cdm?059BDP1JFUX0EeMG05UIF@1NGUh00P1PH6001@1OGel0GEeM061P
H01SHf<0J6QX0080IFEU00X0IfMW06QXJ01TI6@0JFUY06ATI01VIVH0I6AT06YZJP1XJ6P0KFe]0P1U
IFD0201YJFT0IVIV06=SH`1VIVH0IFEU06MWI`1UIFD0JVYZ0P1]KFd05@1[Jf/0K6a/071`L01`L700
Lg=c07AdM01gMgL0M7Ad075aL@1`L700LG5a071`L01cLg<0Jf][075aL@1ZJVX0Lg=c06m_K`1^KVh0
Kfm_071`L00206YZJP0g06EUI@1VIVH0NGUi07emO@25QHD0S8b<08B4Q01aLG40KVi^08:2PP2<S8`0
LG5a06e]K@1eMGD0L71`07YjNP1nOWh0P82008B4Q02;Rh/0SXj>08b<S02=SHd0QXJ607alO020P800
Ogmo07YjNP1mOGd0K6a/061PH01IFET0CTi>03Ti>@0`<300;Rh^04E5A@1IFET0>3Ph02`/;00Q8B40
9RHV02LW9`15ADD0MWIf0410@00h>3P0:RXZ02LW9`1:BTX0E5AD038b<P0a<C40?3`l02XZ:P0202DU
9@0B02PX:00d=3@0DU9B04Q8B00n?Sh0>CTi05YJFP1RHV80De=C03dm?@0b<S809RHV02PX:00Y:BT0
<S8b03Ti>@0g=cL0;2`/0P0Y:BT01`10@400IVIV03/k>`0W9bL0>c/k05YJFP0a<C400P0d=3@0300b
<S809BDU02HV9P0b<S80ADE503@d=01?Cdl0NWYj05=CD`0Q8B40820P02<S8`807QhN00@0820P034a
<@1RHV80IfMW0P2>SXh03@2QXJ40R8R807emO@1ZJVX0M7Ad08R8R02SXj<0/[:b0:FUY@2PX:00Y:BT
0:6QX@2LW9`00P2RXZ807`2UYJD0[jn_0;>c/`30`<00_;bl0;Zj^P2i^KT0^k^k0;Rh^02k^k/0^KVi
0:n_[`2TY:@0RXZ:08B4Q02[Zj/0/;2`0;Vi^@33`l<0^;Rh0:j^[P2XZ:P0YZJV09nOW`2LW9`0WYjN
09bLW02KVi/0V9RH09jNWP2PX:000`2NWYh02P2SXj<0X:2P0::RXP2VYZH0YJFU0:b/[02ZZZX0[Zj^
0:n_[`2[Zj/20:b/[0030;2`/02_[jl0[jn_00<0];Bd00X0/k>c0;Ng]`2f][H0_;bl0;fm_@2o_kl0
`/;20<?3``35aLD0a<C40`36a/H20<[:bP080<K6aP37alL0a/K60<O7a`3:b/X0bLW90<[:bP3;bl/2
0<c<c0030<o?c`3=cLd0clo?0080dM7A03H0d=3@0=;BdP3Cdm<0e=CD0=?Cd`3Fe]H0emOG0=CDe03B
d]80e=CD0<k>cP34a<@0^;Rh0:ZZZP2DU9@0QXJ607EeM@1UIFD0Hf=S05QHF01@D500?Cdm038b<P0[
:b/0;Bd]02TY:@0X:2P0:BTY02PX:00a<C40B4Q806EUI@1@D500JFUY0:BTY02/[:`0[Zj^0:^[Z`1^
KVh0F5QH04Q8B00a<C40@d=303Ph>00/;2`0:BTY02h^;P0h>3P0?Cdm03lo?`0i>CT0>SXj03`l?00o
?cl203Xj>P0403Ph>010@400@4100492@P80?clo02T0B4Q80410@00h>3P0=CDe030`<00b<S80=3@d
030`<00a<C40>CTi03Ph>00c<c<0=SHf03Ph>00j>SX0=SHf02`/;00[:b/0:RXZ03<c<`16ATH0CDe=
06a/K01hN7P0Q8B408R8R02ATI40SHf=08N7Q`2:RXX0QhN708R8R02?Shl0T92@09VIV@2RXZ80YjNW
0:BTY02UYJD0Y:BT0::RXP020:2PX0040:6QX@2RXZ80WinO0::RXP80XJ6Q00T0X:2P09nOW`2QXJ40
XZ:R0:JVYP2SXj<0XZ:R0:FUY@2SXj<00P2RXZ80102PX:00Y:BT0:6QX@2SXj<30:2PX00309^KV`2L
W9`0Vi^K0080Vi^K00H0W9bL09RHV02BTY80V9RH09BDU02CTi<209BDU00608j>SP2@T900SHf=096A
T@2GUiL0U9BD0P2@T90209BDU00:09>CT`2>SXh0TY:B096AT@2@T900TI6A08j>SP2?Shl0T92@09>C
T`80U9BD00l0TY:B092@T02HV9P0Vi^K09RHV02EUID0UYJF09ZJVP2IVIT0Vi^K09ZJVP2LW9`0V9RH
09ZJVP2GUiL00P2DU9@00`2HV9P0VIVI09JFUP0>0<SPf0003038h=P206MWI`0706EUI@1WIfL0JFUY
06MWI`1RHV80IfMW06=SH`0206IVIP0506EUI@1SHf<0Hf=S06ATI01OGel00`1SHf<05@1NGUh0FUYJ
05iNGP1NGUh0EUIF05QHF01KFe/0JFUY06i^KP1hN7P0P82008R8R02:RXX0Ti>C09VIV@2GUiL0XJ6Q
09nOW`2YZJT0Zj^[0:b/[0020:f][@80[Zj^00H0/[:b0:n_[`2_[jl0[:b/0;6a/@2`/;030:f][@0I
0:j^[P2XZ:P0ZZZZ0:FUY@2PX:00WIfM09RHV02CTi<0Shn?08:2PP1eMGD0JVYZ06ATI01DE5@0Bd];
04U9B@1;Bd/0C4a<04];B`1HF5P0EeMG05aLG01NGUh0FEUI065QH@02069RHP0C05aLG01XJ6P0J6QX
069RHP1WIfL0Hf=S06MWI`1UIFD0HV9R06YZJP1WIfL0JVYZ06IVIP1ZJVX0KFe]06UYJ@1SHf<0IFEU
06IVIP0206QXJ00406IVIP1YJFT0J6QX06IVIP80J6QX00h0K6a/06i^KP1YJFT0KVi^07AdM01eMGD0
MgMg06i^KP1eMGD0LG5a079bLP1gMgL0MGEe07YjNP80Ng]k00<0MGEe07QhN01gMgL00P1jNWX0101i
NGT0OWin07inOP1kNg/207UiN@0F07EeM@1iNGT0Ogmo07inOP21PH40RHV909ZJVP2;Rh/0LG5a07=c
L`1jNWX0MgMg06i^KP1lO7`0QhN708J6QP2:RXX0RHV90861P@27QhL0TY:B08N7Q`80P82003T0Ng]k
07alO01nOWh0MGEe065QH@1DE5@0B4Q8038b<P0];Bd0=cLg04];B`14A4@0<c<c02LW9`0X:2P0;Bd]
03lo?`1^KVh0ATI6038b<P0Z:RX0:BTY034a<@15ADD0<c<c02LW9`0`<300;2`/02HV9P0Y:BT0=3@d
04U9B@1QHF40>c/k02h^;P0Y:BT0>c/k05EEE@1HF5P0BTY:03Ti>@0^;Rh0:b/[02l_;`0h>3P0<C4a
03Ti>@0Z:RX0;2`/02XZ:P0l?3`0GemO0451@@0[:b/0ADE505eMG@0c<c<00P0];Bd0300g=cL09bLW
02/[:`0^;Rh0?Cdm03Hf=P1?Cdl0IFEU03lo?`0T92@07alO024Q8@80820P01<0;2`/04m?C`1mOGd0
IfMW05mOG`1bLW80Vi^K0:6QX@27QhL0M7Ad06m_K`1jNWX0Q8B40:^[Z`2_[jl0Xj>S0:BTY02RXZ80
WIfM0080YZJV02h0ZZZZ0;Bd]02e]KD0_Kfm0;^k^`2j^[X0][Jf0;no_`2k^k/0^;Rh0;6a/@2PX:00
V9RH07AdM01mOGd0ZJVY0;2`/02l_;`0`l?30<30`02f][H0[jn_0:JVYP2RXZ80XJ6Q09VIV@2GUiL0
Vi^K09JFUP2KVi/0VYZJ09^KV`2IVIT0Vi^K0:2PX02TY:@0XJ6Q0:>SX`2UYJD0ZJVY0:ZZZP2][Jd0
ZZZZ0:VYZ@2/[:`0[jn_0P2a/K40202d];@0/;2`0;2`/02g]kL0]KFe0;Ng]`2e]KD0_Kfm0P31`L40
0`33`l<0`/;20<G5a@020<?3``80alO700P0bl_;0<C4a036a/H0alO70<S8b039bLT0bl_;0<[:bP80
bl_;00/0bLW90<k>cP3=cLd0clo?0=;BdP3De=@0d];B0=CDe03Bd]80e]KF0=GEe@030=CDe00D0=KF
eP3Cdm<0dm?C0<g=c@34a<@0/[:b0:>SX`2BTY80PX:206e]K@1LG5`0H61P05MGE`1=CDd0?Shn03<c
<`0_;bl0:BTY02`/;00[:b/202LW9`0E034a<@17AdL0Hf=S04=3@`1ZJVX0XJ6Q0:VYZ@2^[Zh0Y:BT
06UYJ@1IFET0@T9203<c<`14A4@0?3`l038b<P0/;2`0>c/k03Hf=P0c<c<0>c/k0080>CTi0P0j>SX2
0451@@0403/k>`11@D40?Cdm03/k>`80?Cdm01`0?Shn03/k>`0k>c/0=cLg02d];@0`<300<S8b03Hf
=P0d=3@0<c<c02l_;`0c<c<0>CTi03Lg=`0f=SH0<c<c02`/;00[:b/0:2PX02h^;P0e=CD0ADE505]K
F`1cLg<0OGem08R8R02CTi<0Shn?0P2;Rh/04026QXH0Ogmo08Z:RP2?Shl0UiNG0::RXP2QXJ40XZ:R
0:RXZ02TY:@0XJ6Q0:>SX`2TY:@0XZ:R0:>SX`2UYJD30:BTY00509nOW`2RXZ80WinO09jNWP2SXj<0
0P2VYZH02@2UYJD0WYjN0:2PX02SXj<0X:2P0::RXP2OWil0X:2P09bLW00209jNWP0609bLW02HV9P0
VYZJ09bLW02HV9P0W9bL0P2IVIT00`2<S8`0Ti>C08n?S`0208b<S00B09:BTP2@T900UIFE09>CT`2E
UID0UYJF09>CT`2>SXh0SHf=09>CT`2>SXh0SHf=08j>SP2BTY80UIFE08n?S`2=SHd0Shn?0P2DU9@0
102GUiL0V9RH09VIV@2GUiL209VIV@0309NGU`2EUID0UYJF00<0VYZJ00H0Vi^K09jNWP2JVYX0VIVI
09RHV02IVIT209NGU`0309FEU@2GUiL0b>3H00d0b>3H000<0<SPf080I6AT01@0KFe]06MWI`1XJ6P0
IfMW06YZJP1PH600I6AT06][J`1TI6@0J6QX06MWI`1QHF40Jf][065QH@1NGUh0HF5Q05aLG01MGEd0
F5QH05mOG`<0F5QH0100FEUI065QH@1]KFd0O7al07emO@25QHD0Rh^;092@T02HV9P0W9bL0:2PX02T
Y:@0YJFU0:ZZZP2YZJT0[:b/0`2^[Zh01@2_[jl0[Jf]0;2`/02/[:`0/K6a0080[jn_0`2^[Zh01@2X
Z:P0ZZZZ0:FUY@2QXJ40WYjN0080U9BD00H0S8b<08R8R01eMGD0J6QX061PH01HF5P204];B`0704a<
C01>CTh0Cdm?059BDP1GEeL0GemO05]KF`0205eMG@0405mOG`1MGEd0HF5Q05iNGP<0Hf=S00T0IFEU
06a/K01VIVH0IVIV06ATI01XJ6P0IFEU06MWI`1VIVH00P1YJFT0201TI6@0JVYZ06QXJ01]KFd0I6AT
06MWI`1[Jf/0HV9R0`1YJFT02P1_Kfl0KFe]06UYJ@1]KFd0MGEe07alO01^KVh0Kfm_07IfMP1lO7`2
07EeM@0507YjNP1gMgL0NWYj07AdM01fMWH00P1iNGT00`1gMgL0MWIf07YjNP0207MgM`0J07UiN@1g
MgL0M7Ad06m_K`1fMWH0NGUi07MgM`1mOGd0WYjN0;Vi^@2GUiL0N7Qh07inOP1iNGT0LW9b06UYJ@1_
Kfl0Ph>308^;R`23Ph<0PH6108B4Q025QHD0QXJ607inOP1oOgl208B4Q080RXZ:03H0Q8B406i^KP1N
GUh0GEeM04=3@`0c<c<0;Bd]034a<@11@D40>CTi02TY:@0V9RH0@d=3051@D01TI6@0IfMW03<c<`0/
;2`0:BTY02HV9P0f=SH0=cLg02PX:00Y:BT0:b/[02`/;00c<c<0B4Q806QXJ01;Bd/0=SHf02DU9@0b
<S80;Rh^03hn?P1GEeL0CTi>03De=@0d=3@0;Bd]03`l?00f=SH0;bl_03/k>`0Z:RX0<30`02XZ:P0f
=SH0FEUI04];B`0b<S80?Cdm04i>CP0_;bl2034a<@0903Lg=`0a<C40;Rh^0492@P0];Bd0=3@d04i>
CP1CDe<0?clo00808b<S01D07alO020P800T92@0<c<c07=cL`26QXH0FUYJ034a<@1FEUH0PH6109nO
W`2DU9@0OGem06m_K`1gMgL0NWYj092@T02g]kL0ZJVY09fMW@2RXZ800P2UYJD0202[Zj/0[Zj^0;>c
/`2c/k<0^[Zj0;jn_P2j^[X0^KVi0P2k^k/06@2j^[X0[Zj^09:BTP2JVYX0MWIf0861P@2/[:`0Zj^[
0;Rh^030`<00`/;20;jn_P2h^;P0ZZZZ0:^[Z`2QXJ40WIfM09VIV@2LW9`0XZ:R0:FUY@2JVYX0V9RH
09^KV`2HV9P00P2QXJ403@2PX:00Xj>S0::RXP2XZ:P0ZZZZ0:j^[P2][Jd0[:b/0:j^[P2][Jd0/k>c
0:j^[P2c/k<00`2`/;00202b/[80]KFe0;Ng]`2k^k/0_Kfm0<?3``32`/80`l?30P32`/801`34a<@0
aLG50<O7a`3:b/X0a<C40<?3``3=cLd00P3<c<`01@39bLT0bl_;0<g=c@3<c<`0b/[:0080c/k>00@0
d=3@0=?Cd`3Bd]80e=CD0P3Bd]800`3GemL0e=CD0=KFeP030=KFeP0J0=?Cd`3AdM40b/[:0<71`@2`
/;00WIfM08n?S`1nOWh0IFEU061PH01HF5P0CDe=04A4A00g=cL0;2`/02d];@0_;bl0:2PX02TY:@0T
92@0;Bd]034a<@1DE5@0GEeM03hn?P1nOWh20:RXZ00B0:n_[`2SXj<0GUiN06i^KP0l?3`0<c<c02h^
;P0g=cL0<30`02HV9P0_;bl0=SHf03Ph>00f=SH0?3`l03De=@10@400?Shn0P13@d<02P11@D40>SXj
03/k>`0h>3P0?3`l03dm?@0o?cl0?Cdm03<c<`0j>SX203Lg=`0603Hf=P0^;Rh0<c<c034a<@0_;bl0
;Bd]0P0e=CD03P0d=3@0<c<c038b<P0];Bd09bLW02XZ:P0X:2P0<S8b04I6AP1QHF40MGEe08N7Q`2<
S8`0U9BD0P2?Shl208N7Q`0708B4Q02?Shl0UYJF09nOW`2TY:@0YZJV0:NWY`020:BTY080XJ6Q00H0
YJFU0:6QX@2TY:@0Xj>S0:2PX02QXJ4209nOW`0409^KV`2QXJ40XJ6Q0:BTY080Xj>S00@0XJ6Q09jN
WP2MWId0VYZJ0`2LW9`01@2HV9P0VYZJ09ZJVP2NWYh0VYZJ0080Vi^K00<0V9RH09NGU`2EUID00P2B
TY801`2ATI40TY:B096AT@2ATI40UIFE096AT@2HV9P00P2ATI403@2CTi<0U9BD096AT@2>SXh0UIFE
09BDU02ATI40TY:B09>CT`2@T900TI6A09JFUP2DU9@00P2HV9P0102DU9@0Vi^K09VIV@2OWil209NG
U`0509^KV`2FUYH0UIFE09NGU`2KVi/00P2IVIT0102JVYX0UiNG09VIV@2JVYX309NGU`80UYJF3P38
h=P000`0b>3H0P1XJ6P04P1YJFT0JVYZ06MWI`1XJ6P0Jf][06MWI`1UIFD0HV9R06ATI01VIVH0IfMW
05mOG`1UIFD0HF5Q05mOG`1NGUh0GemO065QH@<0GUiN01<0FUYJ05IFEP1FEUH0Hf=S06][J`1dM7@0
OGem08>3P`2<S8`0TI6A09VIV@2KVi/0WinO0:JVYP2YZJT0[Zj^0:b/[02^[Zh0/[:b0080[Zj^00H0
Zj^[0;2`/02/[:`0/;2`0;:b/P2`/;020:n_[`0J0;6a/@2^[Zh0[:b/0:NWY`2VYZH0WIfM09bLW02B
TY80T92@08^;R`23Ph<0MgMg06e]K@1TI6@0FEUI051@D01;Bd/0CTi>055AD@1;Bd/0De=C05YJFP1M
GEd0EeMG05eMG@1NGUh2069RHP0505mOG`1WIfL0HF5Q06IVIP1SHf<00`1TI6@03P1SHf<0IVIV06IV
IP1UIFD0I6AT06MWI`1/K6`0Jf][06YZJP1TI6@0IfMW06QXJ01SHf<0IFEU0P1WIfL04@1VIVH0IFEU
06YZJP1XJ6P0IfMW06YZJP1`L700QHF508J6QP1eMGD0Lg=c07EeM@1cLg<0LW9b07=cL`1jNWX0MWIf
0080N7Qh00@0MWIf07alO01lO7`0MWIf0P1kNg/207IfMP0B07EeM@1aLG40LW9b07MgM`1fMWH0MgMg
07IfMP27QhL0_Kfm0=;BdP2[Zj/0Ogmo07alO01kNg/0LG5a06UYJ@1WIfL0LG5a0P26QXH01P24Q8@0
S8b<08Z:RP1oOgl0P82008B4Q080QHF501T0SHf=08:2PP1jNWX0Ogmo06m_K`1YJFT0DE5A04I6AP0_
;bl0;2`/034a<@0o?cl0<c<c02/[:`1DE5@0LG5a05eMG@1XJ6P0>CTi02LW9`0S8b<0:2PX02TY:@0^
;Rh0:BTY0080:RXZ01d0=3@d04M7A`1[Jf/0GemO03/k>`0a<C40:b/[02l_;`0`<300<c<c04e=C@1L
G5`0ATI603Hf=P0];Bd0;2`/03De=@0h>3P0>SXj02d];@0/;2`0;Rh^03<c<`1:BTX0E5AD02l_;`0d
=3@0>c/k02PX:00202l_;`0P02h^;P0d=3@0DE5A05IFEP0Z:RX0<S8b04e=C@1ADE40@D5102/[:`0X
:2P08b<S020P800[:b/0ADE509BDU01kNg/0Bd];020P800/;2`0IVIV08N7Q`2PX:00T92@07YjNP1g
MgL0Ogmo0820P02EUID0/K6a0:ZZZP2MWId20:NWY`090:j^[P2a/K40[Zj^0;2`/02l_;`0`l?30;^k
^`2h^;P0^k^k0080^KVi01h0[:b/08b<S02KVi/0OGem08R8R02`/;00[Jf]0;6a/@2j^[X0`<300<G5
a@31`L40][Jf0:n_[`2YZJT0Y:BT0:2PX02LW9`0Vi^K0:VYZ@2RXZ80Ti>C09bLW02MWId0WinO09fM
W@2YZJT0WIfM0:6QX@2XZ:P20:VYZ@040:^[Z`2^[Zh0[Zj^0:f][@80[Zj^00D0/k>c0;2`/02`/;00
/;2`0;Vi^@020;Rh^0070;Zj^P33`l<0`l?30;jn_P31`L40_[jn0<G5a@020<O7a`050<G5a@37alL0
b<S80<O7a`3>c/h00P3=cLd20<[:bP0;0<k>cP3=cLd0cLg=0=3@d03?cll0dM7A0=3@d03Cdm<0d];B
0<o?c`3Bd]800`3Fe]H04@3GemL0e]KF0=KFeP3AdM40c/k>0<W9b@2k^k/0ZJVY09VIV@2;Rh/0MgMg
06EUI@1MGEd0FEUI04i>CP0n?Sh0<C4a0080;bl_0P0X:2P05`0Y:BT0:RXZ03<c<`0h>3P0EUIF04=3
@`18B4P0V9RH0:ZZZP2YZJT0/K6a09jNWP1KFe/0LG5a03hn?P0^;Rh0:2PX034a<@0d=3@0=cLg03De
=@0f=SH0>c/k0080=CDe0P0j>SX02`10@400>3Ph03Ph>00j>SX0=cLg03@d=00l?3`0=cLg03Ph>00n
?Sh0@T920080>SXj00/0<c<c034a<@0h>3P0<c<c02l_;`0/;2`0;Rh^02`/;00b<S80>SXj03Ph>002
03Hf=P0L030`<00Y:BT0;bl_02`/;00_;bl0>SXj05=CD`1dM7@0QHF509:BTP2ATI40Shn?08j>SP2:
RXX0QXJ608B4Q02;Rh/0U9BD09fMW@2PX:00YJFU0:NWY`2YZJT0YjNW0:JVYP2QXJ40Xj>S0:BTY0<0
XZ:R00P0X:2P0:6QX@2PX:00WYjN0:2PX02MWId0WinO09bLW080WinO00<0Vi^K09nOW`2JVYX00`2J
VYX01@2KVi/0VIVI09ZJVP2GUiL0VIVI0080V9RH00D0Ti>C09FEU@2FUYH0TI6A09:BTP0209>CT`80
TI6A0P2?Shl0302ATI40SXj>096AT@2EUID0TY:B096AT@2BTY80T92@09FEU@2FUYH0UIFE09VIV@80
UiNG00L0Vi^K09NGU`2KVi/0W9bL09ZJVP2LW9`0UiNG0080VIVI00@0UiNG09VIV@2IVIT0UiNG0P2I
VIT01P2KVi/0VYZJ09^KV`2HV9P0UiNG09FEU@80V9RH00<0UYJF09FEU@2CTi<03P38h=P000`0b>3H
0`1XJ6P01@1[Jf/0J6QX06QXJ01YJFT0IFEU0080IVIV00T0HV9R06=SH`1VIVH0I6AT06EUI@1PH600
HF5Q061PH01LG5`00P1MGEd0401LG5`0GUiN05IFEP1HF5P0GEeM06IVIP1]KFd0M7Ad07moO`21PH40
S8b<08n?S`2DU9@0W9bL09fMW@2SXj<20:RXZ0030:^[Z`2^[Zh0ZZZZ0080[Jf]00T0[jn_0;6a/@2`
/;00/;2`0;6a/@2`/;00[Zj^0:f][@2ZZZX00P2^[Zh03P2XZ:P0Zj^[09jNWP2JVYX0V9RH096AT@2=
SHd0OWin07EeM@1/K6`0Hf=S05MGE`1ADE40BTY:0P1>CTh02`1ADE40De=C05UIF@1OGel0HV9R05eM
G@1PH600Hf=S05mOG`1KFe/0H61P0080HV9R01H0I6AT06IVIP1TI6@0IfMW06EUI@1QHF40JFUY06IV
IP1ZJVX0IVIV06QXJ01ZJVX0HV9R06IVIP1SHf<0JFUY06ATI01YJFT0IFEU06MWI`1YJFT0JVYZ0P1V
IVH02`1^KVh0K6a/07IfMP26QXH0OGem06e]K@1_Kfl0LG5a071`L01^KVh0N7Qh0080O7al00L0MGEe
07MgM`1hN7P0MWIf07UiN@1gMgL0MWIf00<0N7Qh02l0MGEe079bLP1bLW80LW9b071`L01aLG40O7al
09bLW03Fe]H0f=SH0:ZZZP20P800MWIf07moO`1iNGT0LW9b06i^KP1SHf<0MWIf08>3P`28R8P0QhN7
07UiN@1jNWX0PH6108F5Q@26QXH0RXZ:08:2PP1gMgL0N7Qh08>3P`1gMgL0GEeM05UIF@1MGEd0EUIF
0451@@0_;bl0=SHf034a<@0d=3@0>SXj05=CD`1MGEd0G5aL04e=C@0202/[:`0P02PX:00[:b/0:b/[
02TY:@0Z:RX0:b/[03<c<`1JFUX0K6a/04e=C@0o?cl0?Shn03dm?@0d=3@0;bl_03lo?`11@D40B4Q8
04];B`0a<C40;bl_02XZ:P0b<S80>CTi04M7A`0b<S80<C4a02`/;00`<300?Cdm059BDP0o?cl203Ph
>00S02l_;`0X:2P0:2PX02`/;00h>3P0J6QX065QH@0^;Rh0BTY:055AD@1<C4`0B4Q802l_;`0W9bL0
8R8R02@T900^;Rh0KVi^096AT@1YJFT0;Rh^01dM7@0S8b<0=SHf06UYJ@2:RXX0XZ:R08Z:RP1hN7P0
NWYj079bLP1kNg/0UYJF0;Zj^P2[Zj/00P2VYZH01`2/[:`0[Jf]0:b/[02c/k<0_kno0<;2`P2l_;`0
0P2j^[X0:@2d];@0^KVi0:n_[`29RHT0V9RH08N7Q`2;Rh/0ZZZZ0:JVYP2][Jd0];Bd0;bl_035aLD0
bLW90<30`02b/[80[:b/0:NWY`2RXZ80XJ6Q09nOW`2QXJ40ZZZZ0::RXP2LW9`0UYJF09VIV@2KVi/0
XJ6Q0:2PX02LW9`0Xj>S0:JVYP2YZJT0ZZZZ0:^[Z`2^[Zh0ZZZZ0:j^[P2/[:`0/;2`0080Zj^[01H0
/[:b0;fm_@2k^k/0^;Rh0;no_`31`L40a<C40<30`033`l<0`<300<O7a`38b<P0`l?30<O7a`38b<P0
a/K60<O7a`3<c<`0b/[:0<_;b`39bLT0bl_;0P3<c<`01P3?cll0cLg=0<k>cP3>c/h0d=3@0=?Cd`80
d];B00<0eMGE0=CDe03Cdm<00P3De=@0503EeMD0dm?C0=7Ad@3<c<`0`l?30;bl_02ZZZX0V9RH08F5
Q@1hN7P0JVYZ05YJFP1>CTh0BDU903Ph>00^;Rh0:RXZ02/[:`0Y:BT0:b/[0P0_;bl01P0[:b/0>c/k
05MGE`0j>SX0D51@0:BTY080ZJVY00/0Zj^[08f=S@1MGEd0M7Ad055AD@0_;bl0;Bd]03@d=00a<C40
<30`03@d=00203De=@0503Lg=`0h>3P0?3`l03Ph>00g=cL00P0j>SX02@0f=SH0>SXj03hn?P0k>c/0
>CTi03dm?@0k>c/0?3`l04];B`0203`l?00N04=3@`0d=3@0<S8b038b<P0^;Rh0<C4a030`<00d=3@0
=CDe03Lg=`0i>CT0=SHf034a<@0_;bl0;Bd]02l_;`0d=3@0<c<c059BDP1]KFd0OWin08f=S@2CTi<0
TI6A08^;R`29RHT0PX:20820P027QhL0S8b<0P2JVYX00`2SXj<0Z:RX0:JVYP020:FUY@030:2PX02T
Y:@0Y:BT00@0Xj>S00X0XZ:R0:>SX`2MWId0Vi^K09bLW02KVi/0W9bL09fMW@2KVi/0V9RH0P2LW9`0
3@2HV9P0Vi^K09RHV02IVIT0WIfM09VIV@2LW9`0UIFE09VIV@2CTi<0T92@09JFUP2DU9@00P2BTY80
2`2ATI40TY:B09>CT`2CTi<0TY:B08j>SP2@T900Shn?09:BTP2ATI40UiNG0080Ti>C00/0UYJF09RH
V02HV9P0VYZJ09^KV`2OWil0Vi^K09nOW`2NWYh0V9RH09bLW00209ZJVP0809NGU`2FUYH0VIVI09RH
V02IVIT0V9RH09fMW@2GUiL209ZJVP0:09^KV`2OWil0W9bL09VIV@2JVYX0UiNG09RHV02LW9`0U9BD
09NGU`h0b>3H000<0<SPf080Jf][00H0JVYZ06a/K01XJ6P0Jf][06a/K01[Jf/206IVIP0;069RHP1Q
HF40IFEU05mOG`1YJFT0JVYZ05iNGP1RHV80IFEU05YJFP1OGel00P1NGUh04P1MGEd0H61P05mOG`1S
Hf<0Jf][07=cL`1mOGd0P82008R8R02ATI40U9BD09NGU`2OWil0Y:BT0:RXZ02WYjL0ZJVY0:b/[0D0
[jn_01/0[Zj^0:n_[`2^[Zh0[jn_0:f][@2`/;00[Zj^0;2`/02[Zj/0[Jf]0:JVYP2QXJ40W9bL09FE
U@2@T900Rh^;08B4Q01jNWX0KFe]065QH@1IFET0EEEE04i>CP1BDU80Cdm?05ADE01KFe/00P1IFET0
2P1JFUX0GEeM05eMG@1LG5`0HF5Q05aLG01SHf<0IVIV065QH@1UIFD206IVIP0F06MWI`1UIFD0JFUY
061PH01UIFD0I6AT06IVIP1WIfL0JVYZ065QH@1XJ6P0IFEU06YZJP1TI6@0HV9R06a/K01SHf<0IFEU
06a/K01[Jf/0IFEU06e]K@80L71`00L0MgMg07EeM@1bLW80MGEe079bLP1]KFd0LG5a0080MWIf00T0
N7Qh07EeM@1gMgL0N7Qh07EeM@1dM7@0N7Qh07=cL`1fMWH00P1gMgL207AdM01207=cL`1^KVh0KVi^
06i^KP2:RXX0a/K60>;RhP3Bd]80WYjN07moO`1gMgL0N7Qh07AdM01_Kfl0M7Ad06e]K@1ZJVX0Ng]k
08V9R@21PH40MgMg07]kN`1mOGd0P82008F5Q@2;Rh/0O7al07moO`25QHD0PX:207QhN01XJ6P0HF5Q
05iNGP1VIVH0HF5Q04e=C@0i>CT0?3`l03/k>`0`<300<C4a0451@@1CDe<0G5aL02l_;`0U9BD09bLW
02TY:@0S8b<0;Bd]02PX:00_;bl0ADE506QXJ01GEeL0<c<c04M7A`1;Bd/0CTi>03De=@0[:b/0;2`/
02l_;`0j>SX0@T920`0a<C403@0`<300>CTi03Ph>00e=CD0=SHf03<c<`0b<S80>CTi04Q8B01;Bd/0
>SXj03Ti>@0V9RH00P0W9bL08@0/;2`0>3Ph06YZJP1KFe/0?3`l06MWI`13@d<0@T92055AD@17AdL0
=cLg03<c<`0d=3@0Cdm?09ZJVP28R8P0DE5A02XZ:P0O7al08B4Q020P8011@D40N7Qh08^;R`2ZZZX0
QHF507UiN@1`L700MgMg0861P@2RXZ80][Jf0;>c/`030:ZZZP050:f][@2k^k/0^;Rh0;^k^`2n_[h0
0P2d];@0302][Jd0][Jf0;:b/P2CTi<0VYZJ08n?S`2EUID0YjNW0:6QX@2TY:@0/[:b0;Vi^@80a/K6
00d0aLG50;bl_02^[Zh0ZZZZ0::RXP2UYJD0YZJV0:6QX@2TY:@0YZJV0:NWY`2GUiL0Ti>C0080VYZJ
00`0WYjN09^KV`2UYJD0XZ:R0:VYZ@2UYJD0Z:RX0:^[Z`2][Jd0[jn_0:^[Z`2][Jd20;Bd]0050;Fe
]@2h^;P0]kNg0;bl_02n_[h00`33`l<01@37alL0aLG50<C4a037alL0`l?300<0alO700d0bLW90<_;
b`3=cLd0cLg=0<[:bP3>c/h0bl_;0<c<c03@d=00clo?0=;BdP3?cll0dm?C0080dM7A0P3EeMD08@3F
e]H0e=CD0=GEe@3EeMD0emOG0=7Ad@3@d=00b/[:0<?3``2h^;P0XZ:R096AT@1oOgl0J6QX065QH@1M
GEd0D51@03hn?P0e=CD0;Rh^02PX:00R8R809RHV02PX:00Z:RX0:2PX038b<P17AdL0H61P03Lg=`1V
IVH0[Zj^0:BTY0020:ZZZP0A08>3P`1SHf<0KVi^04i>CP0/;2`0;bl_038b<P0^;Rh0;Bd]03<c<`0d
=3@0>3Ph03hn?P0f=SH0>c/k03@d=00k>c/00P0i>CT203dm?@0403hn?P0h>3P0=SHf03dm?@80ADE5
00<0>c/k03lo?`0f=SH00P0f=SH01`0^;Rh0:b/[02d];@0c<c<0=CDe03<c<`0`<3000P0g=cL05@0h
>3P0>c/k03Ph>00^;Rh0:RXZ02d];@0d=3@0Bd];06EUI@1jNWX0R8R8096AT@2BTY80SHf=08j>SP2:
RXX0QhN708J6QP2:RXX0U9BD09^KV`030:BTY0060:FUY@2RXZ80YJFU0:>SX`2UYJD0XZ:R0P2TY:@2
09nOW`80WYjN00P0W9bL09ZJVP2LW9`0VIVI09NGU`2HV9P0UIFE09RHV080VIVI00H0UYJF09BDU02J
VYX0UIFE09RHV02GUiL309FEU@80Ti>C00<0TI6A09>CT`2CTi<00P2DU9@209>CT`0@09BDU02CTi<0
TY:B08n?S`2CTi<0UYJF09ZJVP2KVi/0WIfM09ZJVP2MWId0VIVI09^KV`2LW9`0WYjN09^KV`80W9bL
0P2IVIT00`2MWId0VIVI09RHV00209RHV00309^KV`2LW9`0VIVI0080VYZJ00L0VIVI09RHV02KVi/0
Vi^K09BDU02IVIT0V9RH0080UiNG00<0UYJF09FEU@2DU9@03P38h=P000`0b>3H0P1VIVH02P1ZJVX0
J6QX06YZJP1VIVH0JFUY06MWI`1VIVH0IFEU06ATI01PH60206ATI080Hf=S0P1TI6@0201RHV80GUiN
05YJFP1JFUX0Fe]K05aLG01ZJVX0IFEU0P1WIfL03P1eMGD0O7al08>3P`2:RXX0T92@09FEU@2IVIT0
Vi^K0:BTY02WYjL0ZJVY0:^[Z`2ZZZX0[:b/0`2_[jl0:02][Jd0/;2`0:n_[`2`/;00[Jf]0:n_[`2`
/;00[Jf]0;6a/@2^[Zh0[Jf]0:FUY@2PX:00W9bL09BDU02=SHd0SXj>08:2PP1`L700LW9b061PH01K
Fe/0DE5A04i>CP1?Cdl0DU9B05MGE`1EEED0De=C05ADE01FEUH0Fe]K06=SH`1UIFD0HV9R06=SH`1U
IFD0IfMW06=SH`1UIFD206=SH`0306QXJ01TI6@0I6AT0080I6AT00T0IFEU06IVIP1WIfL0J6QX06AT
I01SHf<0I6AT06YZJP1QHF400P1UIFD02`1VIVH0JVYZ06QXJ01WIfL0JFUY06YZJP1]KFd0M7Ad07Mg
M`1aLG40M7Ad0080LW9b00/0MWIf07=cL`1cLg<0MGEe07QhN01bLW80MGEe07YjNP1iNGT0MGEe07If
MP0507AdM00>06i^KP1aLG40JFUY06YZJP1dM7@0Y:BT0=_Kf`3Shn<0clo?09VIV@1fMWH0Ng]k07If
MP1eMGD2079bLP0<06YZJP1YJFT0LW9b08>3P`20P800OGem07]kN`1iNGT0Ph>308V9R@1jNWX0NGUi
0P27QhL05@23Ph<0OWin07AdM01[Jf/0IVIV069RHP1TI6@0GemO04U9B@0^;Rh0<S8b034a<@0`<300
<c<c0410@01?Cdl0?clo02/[:`0W9bL09BDU02`/;00202TY:@0F034a<@1=CDd0KVi^04U9B@0/;2`0
<c<c03Hf=P0h>3P0?Shn03<c<`0^;Rh0;Bd]03De=@0m?Cd0AdM7030`<00];Bd0<c<c03Lg=`0c<c<0
>SXj0492@P80<C4a00H0=cLg03/k>`18B4P0?Cdm03De=@0V9RH202@T900;02h^;P17AdL0JFUY05UI
F@1>CTh0I6AT03`l?01;Bd/0FEUI065QH@1MGEd00P1FEUH0A`1gMgL0YZJV08Z:RP1NGUh09bLW01dM
7@0N7Qh0820P02XZ:P16ATH0MWIf09ZJVP2KVi/0Ph>307QhN01kNg/0N7Qh0861P@2ZZZX0_[jn0;Jf
]P2UYJD0ZZZZ0:b/[02i^KT0/k>c0;Rh^02k^k/0][Jf0;Fe]@2/[:`0]KFe0;>c/`2IVIT0TI6A09:B
TP2HV9P0YjNW0:2PX02SXj<0[Zj^0;Jf]P33`l<0bLW90<O7a`33`l<0][Jf0:f][@2UYJD0YjNW0:RX
Z02YZJT0Y:BT09nOW`2PX:00YZJV09BDU02CTi<0V9RH09^KV`2LW9`0X:2P09nOW`2SXj<0XZ:R0:JV
YP2][Jd0ZZZZ0:VYZ@2XZ:P0[Zj^0080/k>c01T0]kNg0;Bd]02j^[X0^k^k0;fm_@2o_kl0`l?30<71
`@35aLD0`/;20<?3``35aLD0`L710<C4a037alL0b/[:0<S8b03;bl/0c<c<0<k>cP3<c<`0cLg=0<[:
bP38b<P0c/k>0080clo?00L0d=3@0=;BdP3@d=00d];B0=?Cd`3De=@0dm?C00@0eMGE0140d=3@0<o?
c`35aLD0`<300;>c/`2QXJ40T92@07YjNP1VIVH0GEeM05MGE`1=CDd0?Shn03@d=00/;2`09RHV028R
8P0202TY:@0J02PX:00a<C40>c/k05ADE01@D500>CTi08B4Q02`/;00YjNW0:VYZ@2ZZZX0O7al069R
HP1JFUX0@D5103Xj>P0f=SH0>SXj02XZ:P0[:b/0;2`/03De=@0i>CT0>c/k034a<@0l?3`203De=@80
@T9200P0@41003De=@10@400?Shn03`l?00k>c/0@T9203lo?`80A4A401`0>SXj03Ti>@0a<C40;Bd]
02/[:`0];Bd0<C4a038b<P0];Bd0<30`038b<P0a<C40=CDe03Ph>00a<C40:b/[02XZ:P0W9bL0;Rh^
03Ph>01BDU80LW9b08:2PP2?Shl0TI6A08n?S`2>SXh0R8R80P23Ph<0502:RXX0TI6A09RHV02NWYh0
YJFU0::RXP2TY:@0XZ:R0:FUY@2SXj<0XZ:R0:JVYP2NWYh0XJ6Q09jNWP2MWId0VYZJ09fMW@2JVYX0
UIFE0P2HV9P05P2EUID0UiNG09JFUP2HV9P0U9BD09>CT`2BTY80UIFE09BDU02ATI40VIVI09FEU@2F
UYH0VYZJ09BDU02EUID0Ti>C08j>SP2BTY80TI6A09:BTP2GUiL209>CT`0<09JFUP2ATI40UIFE09BD
U02LW9`0Vi^K0:6QX@2KVi/0WinO0:2PX02MWId0Vi^K0P2OWil04`2LW9`0Vi^K09fMW@2LW9`0Vi^K
09fMW@2QXJ40WIfM09^KV`2JVYX0Vi^K09fMW@2LW9`0VYZJ09NGU`2JVYX0Vi^K09ZJVP2KVi/00P2G
UiL01`2JVYX0UIFE09NGU`2HV9P0VIVI09>CT`2HV9P03P38h=P000`0b>3H0P1[Jf/01P1WIfL0K6a/
06][J`1[Jf/0IfMW06ATI0<0IfMW00@0GemO06EUI@1SHf<0J6QX0`1QHF404@1RHV80Hf=S065QH@1K
Fe/0GEeM05YJFP1IFET0HF5Q06UYJ@1_Kfl0MWIf07moO`27QhL0SHf=08n?S`2GUiL0VIVI0080Xj>S
00D0YjNW0:ZZZP2/[:`0Z:RX0:n_[`020;2`/00=0:j^[P2_[jl0[jn_0:ZZZP2_[jl0[:b/0:j^[P2b
/[80Zj^[0;6a/@2_[jl0ZJVY0:FUY@0209fMW@0?09RHV02@T900Rh^;08B4Q021PH40K6a/06EUI@1I
FET0EEEE04a<C018B4P0C4a<05ADE01CDe<0EeMG0080F5QH00l0G5aL05]KF`1MGEd0Hf=S05mOG`1W
IfL0J6QX06IVIP1XJ6P0IFEU06UYJ@1XJ6P0I6AT06MWI`1/K6`00P1TI6@0701UIFD0IVIV06EUI@1R
HV80IVIV06ATI01SHf<0HV9R06=SH`1QHF40Hf=S06MWI`1ZJVX0IFEU06][J`1]KFd0K6a/07moO`1g
MgL0KFe]079bLP1^KVh0LW9b07IfMP1bLW80MWIf07QhN01gMgL307AdM00507IfMP1`L700LW9b07If
MP1eMGD00P1fMWH05P1bLW80KVi^06YZJP1VIVH0L71`07emO@31`L40h^;R0>7Qh@39bLT0SHf=075a
L@1gMgL0MWIf079bLP1aLG40KVi^06MWI`1]KFd0LW9b07MgM`1mOGd208:2PP0l07emO@1eMGD0MWIf
079bLP1nOWh0QXJ608R8R01mOGd0Q8B40861P@1mOGd0JVYZ06QXJ01WIfL0I6AT05ADE00n?Sh0@410
03Ti>@0e=CD0>3Ph03Hf=P0d=3@0@d=302d];@0Y:BT09RHV02LW9`0^;Rh0:2PX02/[:`1GEeL0KVi^
03hn?P0W9bL0:b/[02h^;P0Z:RX0>3Ph0410@00o?cl0;bl_03De=@0g=cL0A4A403@d=00/;2`0;bl_
03@d=00h>3P0?Cdm03Lg=`0a<C40<S8b034a<@0^;Rh0A4A403`l?00a<C40;Rh^0P0a<C404`0l?3`0
Bd];05EEE@18B4P0FEUI05]KF`15ADD0J6QX06EUI@1OGel0DU9B05=CD`0n?Sh0J6QX0:BTY02<S8`0
Kfm_03Hf=P0S8b<00P0M7Ad05P0P8200:BTY059BDP25QHD0UiNG09^KV`20P800NGUi079bLP1kNg/0
SXj>0:n_[`30`<00]kNg0:JVYP2/[:`0^;Rh0;Fe]@2j^[X0/;2`0;:b/P2`/;020;>c/`050;6a/@2Q
XJ40SHf=092@T02TY:@00P2VYZH02`2ZZZX0/K6a0;Ng]`30`<00alO70<G5a@3:b/X0_[jn0;2`/02X
Z:P0YZJV0080[Jf]00l0Zj^[0:BTY02RXZ80Xj>S0:BTY02MWId0UIFE09:BTP2KVi/0W9bL0:6QX@2P
X:00XZ:R0:JVYP2ZZZX00P2[Zj/02@2ZZZX0Z:RX0:b/[02/[:`0];Bd0;Rh^02k^k/0_Kfm0<30`003
0<71`@0:0<?3``31`L40`l?30<K6aP35aLD0alO70<S8b03:b/X0a<C40<[:bP<0c<c<0P3;bl/0103<
c<`0bLW90=7Ad@3=cLd20=7Ad@070=;BdP3De=@0d];B0=?Cd`3Bd]80dm?C0=CDe0020=7Ad@0_0<o?
c`3;bl/0a/K60;fm_@2_[jl0WinO08f=S@1dM7@0I6AT05EEE@1GEeL0AdM703/k>`0];Bd0:2PX02@T
900S8b<08R8R02PX:00V9RH0<S8b0451@@1JFUX0ATI60410@02CTi<0Zj^[0::RXP2TY:@0[:b/0861
P@1SHf<0FUYJ03Ti>@0h>3P0<c<c038b<P0d=3@0@d=303Ph>00f=SH0?3`l03/k>`0b<S80=3@d03Lg
=`0h>3P00P0l?3`203Ti>@0603lo?`0m?Cd0?Shn04=3@`0n?Sh0@d=30P12@T80200h>3P0?Shn03@d
=00b<S80;Bd]03@d=00[:b/0<C4a0P0_;bl203@d=080=SHf00l0<30`02l_;`0[:b/0;Rh^03<c<`0h
>3P0DE5A061PH01fMWH0QXJ608b<S02ATI40T92@08Z:RP28R8P00P25QHD0102ATI40UiNG09bLW02U
YJD30:RXZ0050:FUY@2NWYh0Xj>S09bLW02MWId00P2JVYX05P2HV9P0VYZJ09JFUP2FUYH0UiNG09JF
UP2IVIT0UiNG09FEU@2GUiL0V9RH09BDU02ATI40UIFE092@T02CTi<0UiNG09JFUP2GUiL0UIFE09BD
U02GUiL309JFUP0409>CT`2@T900TY:B09JFUP80UiNG00D0VIVI09RHV02HV9P0Vi^K09bLW00209jN
WP050:6QX@2PX:00XJ6Q0:6QX@2RXZ800P2NWYh01`2OWil0WYjN09fMW@2KVi/0WIfM09jNWP2JVYX0
0P2MWId0102KVi/0W9bL09VIV@2JVYX209^KV`0509VIV@2MWId0Vi^K09ZJVP2IVIT00P2EUID01P2D
U9@0UiNG09RHV02FUYH0U9BD09FEU@h0b>3H000<0<SPf080IfMW00<0K6a/075aL@1ZJVX00P1XJ6P0
0`1[Jf/0JVYZ06MWI`0206IVIP0406EUI@1VIVH0J6QX06EUI@80Hf=S01P0J6QX06ATI01QHF40GUiN
05aLG01KFe/0F5QH05mOG`1UIFD0LG5a07EeM@20P800QXJ608f=S@2CTi<0UIFE09fMW@2PX:00Xj>S
0:b/[02[Zj/0[Jf]0:^[Z`2^[Zh20:b/[0050:f][@2/[:`0[jn_0:n_[`2/[:`00`2^[Zh05@2/[:`0
[Jf]0:f][@2XZ:P0YZJV0:>SX`2IVIT0UYJF08b<S026QXH0Ph>3071`L01[Jf/0I6AT05YJFP1CDe<0
BDU904E5A@17AdL0De=C05ADE00205EEE@0605IFEP1OGel0H61P05aLG01NGUh0JFUY0P1UIFD01@1S
Hf<0IfMW06MWI`1VIVH0IfMW0080J6QX0P1ZJVX00`1[Jf/0I6AT06UYJ@0206QXJ00?06ATI01WIfL0
HV9R06ATI01SHf<0IFEU065QH@1RHV80J6QX06UYJ@1TI6@0JFUY06i^KP2;Rh/0QXJ60080LW9b00l0
L71`079bLP1eMGD0LG5a079bLP1aLG40LW9b075aL@1eMGD0M7Ad07=cL`1eMGD0M7Ad07=cL`1eMGD0
0P1^KVh306e]K@0:06a/K01dM7@0VIVI0=WIf@3Rh^80g=cL0;jn_P1oOgl0Kfm_075aL@80MGEe00@0
Kfm_075aL@1`L700Lg=c0P1dM7@00`1bLW80O7al0861P@0207alO00B079bLP1gMgL0Q8B408F5Q@22
PX80QXJ608R8R025QHD0PX:207IfMP1YJFT0J6QX06YZJP1/K6`0HF5Q05]KF`1EEED0>CTi0`0e=CD0
300f=SH0>SXj02LW9`0Y:BT09BDU02h^;P0i>CT0=3@d05]KF`1YJFT0?clo02DU9@809bLW01L0;bl_
030`<017AdL0DE5A03hn?P0`<300>3Ph0410@012@T80:b/[02TY:@0];Bd0>3Ph03@d=00h>3P0=SHf
02XZ:P0[:b/0;Rh^03Xj>P18B4P0>c/k02d];@0203Ti>@0:03Ph>00c<c<0ATI604U9B@1VIVH0K6a/
06m_K`1iNGT0FEUI04a<C080>c/k01`0;Bd]05iNGP2HV9P0JVYZ0451@@0U9BD07alO01`L700P8200
7AdM02DU9@0^;Rh0FEUI08>3P`2QXJ40UYJF08F5Q@1lO7`0Lg=c07]kN`2CTi<0];Bd0;fm_@2YZJT0
ZZZZ0;2`/02h^;P0^KVi0P2^[Zh03P2YZJT0Z:RX0:^[Z`2^[Zh0VIVI08Z:RP2@T900YjNW0:RXZ02W
YjL0YZJV0;Jf]P2j^[X0_Kfm0P2o_kl01`34a<@0_kno0;>c/`2[Zj/0YJFU0:VYZ@2/[:`00P2WYjL0
2`2YZJT0YjNW0::RXP2UYJD0VIVI096AT@2FUYH0Vi^K09fMW@2LW9`0WinO0080YZJV00@0Z:RX0:NW
Y`2YZJT0[Jf]0P2_[jl01P2g]kL0^;Rh0;Zj^P31`L40`/;20;jn_P80`<3000H0`L710<G5a@33`l<0
a<C40<[:bP38b<P20<W9b@050<C4a03:b/X0bl_;0<[:bP3;bl/00P39bLT0203=cLd0bl_;0=3@d03A
dM40d];B0=7Ad@3Cdm<0dM7A0P3Bd]80=03Fe]H0e=CD0=?Cd`3AdM40clo?0<k>cP3:b/X0b<S80;fm
_@2[Zj/0VIVI08J6QP1cLg<0IfMW05IFEP1ADE40ATI603Lg=`0^;Rh09RHV024Q8@0O7al08b<S02XZ
:P0^;Rh0<C4a04];B`1IFET0?3`l04i>CP2MWId0YJFU0:>SX`2YZJT0Y:BT08B4Q01XJ6P0B4Q803Hf
=P0l?3`0<S8b03Hf=P19BDT0>SXj02h^;P0c<c<0>3Ph03@d=00c<c<0=cLg03/k>`0f=SH203`l?00H
03Xj>P0m?Cd0?Cdm03Ti>@0g=cL0?Shn03`l?011@D40A4A403hn?P0m?Cd0>c/k030`<00^;Rh0=3@d
02d];@0[:b/0;bl_02d];@0a<C40<30`03@d=00b<S80=SHf0P0e=CD02P0Y:BT0:RXZ030`<00e=CD0
?Cdm05YJFP1ZJVX0PH6108V9R@2CTi<208n?S`0=08R8R021PH40P820092@T02DU9@0WIfM0:2PX02V
YZH0YJFU0::RXP2NWYh0X:2P09nOW`0209bLW00F09^KV`2MWId0VIVI09ZJVP2GUiL0VIVI09RHV02N
WYh0UYJF09NGU`2JVYX0UYJF09FEU@2GUiL0U9BD09VIV@2FUYH0TI6A09VIV@2PX:00UYJF09FEU@80
V9RH0P2FUYH209RHV00309NGU`2HV9P0VIVI00<0WYjN00@0XJ6Q09nOW`2LW9`0XJ6Q0P2PX:002P2R
XZ80X:2P0:2PX02QXJ40WinO0::RXP2OWil0X:2P09jNWP2MWId309nOW`0809jNWP2MWId0Vi^K09bL
W02NWYh0W9bL09VIV@2NWYh209^KV`80VYZJ00X0WIfM09RHV02IVIT0VIVI09NGU`2DU9@0VIVI09JF
UP2DU9@0TY:B3P38h=P000`0b>3H0P1ZJVX0201YJFT0Jf][06QXJ01[Jf/0JVYZ06a/K01SHf<0JFUY
0P1WIfL0201YJFT0Hf=S06MWI`1SHf<0I6AT06=SH`1UIFD0GemO0P1PH600501MGEd0Fe]K05aLG01R
HV80Hf=S079bLP1gMgL0P82008R8R02>SXh0TY:B09BDU02KVi/0WinO0::RXP2UYJD0Z:RX0:^[Z`2/
[:`0[Zj^0`2][Jd01P2_[jl0/K6a0:n_[`2_[jl0[:b/0:f][@80[jn_01H0Zj^[0:b/[02][Jd0ZZZZ
09nOW`2LW9`0UiNG08n?S`2;Rh/0Ph>307MgM`1^KVh0IVIV05YJFP1CDe<0AdM704a<C01>CTh0ATI6
059BDP1?Cdl0EUIF0P1IFET02`1PH600GEeM069RHP1MGEd0Hf=S06MWI`1SHf<0IFEU06MWI`1TI6@0
IfMW0080JVYZ00T0IVIV06YZJP1YJFT0IfMW06QXJ01YJFT0HV9R06QXJ01UIFD00P1RHV801@1UIFD0
I6AT06EUI@1UIFD0HV9R0080I6AT01D0IVIV06a/K023Ph<0YjNW08j>SP1hN7P0LG5a079bLP1^KVh0
N7Qh07UiN@1cLg<0L71`07=cL`1dM7@0L71`075aL@1fMWH0MGEe07AdM01eMGD00P1`L7003@1^KVh0
L71`06EUI@1`L700Q8B40;bl_03Ti>@0gmoO0=KFeP2[Zj/0NGUi06i^KP1eMGD00P1bLW800`1eMGD0
NGUi07EeM@0207UiN@0907AdM01TI6@0JFUY07inOP1iNGT0OWin07UiN@23Ph<0P8200080OGem00H0
QHF508j>SP2;Rh/0Ph>307YjNP1dM7@206m_K`0]06UYJ@1SHf<0EeMG05YJFP14A4@0<c<c02h^;P0]
;Bd0;bl_038b<P0[:b/0<S8b02HV9P0_;bl0=CDe03Ph>01YJFT0KFe]0451@@0W9bL0:RXZ02TY:@0_
;bl0;Rh^0451@@1<C4`0AdM703Ph>00/;2`0=SHf03dm?@0`<300;Bd]03<c<`0g=cL0<S8b0492@P0e
=CD0=cLg02TY:@0^;Rh0=SHf0451@@0l?3`0>3Ph0080=cLg05<0=3@d038b<P0o?cl0H61P079bLP1Y
JFT0N7Qh07inOP1@D500@41002XZ:P0e=CD0=SHf06QXJ029RHT0F5QH02TY:@0P82009RHV020P800T
92@08R8R01hN7P0T92@0=SHf05eMG@2ATI40ZJVY09BDU024Q8@0Ng]k07MgM`1mOGd0UIFE0;Jf]P2i
^KT0ZJVY0:RXZ02f][H0/k>c0:j^[P2ZZZX0YZJV0:>SX`2`/;00Xj>S09BDU02;Rh/0Shn?0:VYZ@2e
]KD0[Jf]0:b/[02_[jl0[Zj^0;Vi^@2n_[h0`l?30;no_`2j^[X0][Jf0:b/[02WYjL0[:b/0:^[Z`2W
YjL0Zj^[0:f][@2XZ:P0YjNW0:^[Z`2UYJD0X:2P09FEU@2CTi<0U9BD09NGU`2MWId0YJFU0:JVYP2Y
ZJT0Zj^[0:RXZ0030:f][@080;>c/`2g]kL0^KVi0;jn_P2o_kl0_[jn0;no_`2j^[X20<?3``030<G5
a@37alL0b/[:0080a/K600@0aLG50<K6aP3:b/X0cLg=0P3;bl/0103:b/X0bLW90<[:bP3;bl/20=7A
d@030=3@d03Bd]80eMGE00<0dm?C0P3De=@0103Fe]H0d];B0<o?c`3:b/X20<C4a00F0;Zj^P2WYjL0
VIVI08B4Q01cLg<0Hf=S059BDP1>CTh0?3`l03@d=00`<300:BTY028R8P0S8b<09bLW02XZ:P0c<c<0
=SHf04];B`1BDU80<C4a06QXJ080W9bL0100WYjN0:b/[02VYZH0RHV907=cL`1:BTX0=cLg030`<00a
<C40>CTi03`l?00_;bl0<30`034a<@0f=SH0<c<c0P0e=CD0200g=cL0>3Ph03Ph>00h>3P0=cLg03Xj
>P0l?3`0>SXj0P0l?3`01`0o?cl0@T9204I6AP12@T80?Cdm03De=@0g=cL00P0c<c<03@0];Bd0:RXZ
02XZ:P0a<C40<c<c02d];@0h>3P0=cLg03`l?00e=CD0>3Ph02PX:00/;2`00P0Z:RX02@0e=CD0Bd];
069RHP1jNWX0RXZ:08b<S02?Shl0Rh^;08Z:RP0208:2PP0>08b<S02@T900Vi^K09bLW02RXZ80YZJV
0:FUY@2NWYh0X:2P09bLW02KVi/0W9bL09^KV`2JVYX209VIV@0609NGU`2HV9P0UiNG09RHV02JVYX0
U9BD0P2IVIT00`2FUYH0Ti>C09>CT`0209NGU`0;09VIV@2KVi/0UiNG09VIV@2FUYH0Vi^K09JFUP2K
Vi/0VYZJ09VIV@2HV9P00P2JVYX03@2OWil0WIfM09fMW@2MWId0WinO09bLW02OWil0XJ6Q0:2PX02S
Xj<0XJ6Q09nOW`2RXZ800P2PX:00102QXJ40Y:BT09nOW`2QXJ4209jNWP0609nOW`2LW9`0X:2P09jN
WP2KVi/0WIfM0P2LW9`00`2MWId0W9bL09^KV`0209^KV`0909VIV@2NWYh0UiNG09bLW02HV9P0UYJF
09VIV@2HV9P0VYZJ0080U9BD3P38h=P000`0b>3H0P1XJ6P01@1[Jf/0IfMW06IVIP1XJ6P0IFEU0080
J6QX01X0IfMW06EUI@1TI6@0IfMW06=SH`1VIVH0Hf=S06UYJ@1SHf<0HF5Q06ATI01OGel0GUiN05mO
G`1LG5`0F5QH061PH01YJFT0J6QX07EeM@1oOgl0QhN708^;R`2ATI40UYJF09nOW`80XZ:R00@0YZJV
0:ZZZP2][Jd0ZZZZ0`2][Jd01P2/[:`0[jn_0:ZZZP2^[Zh0/[:b0;2`/080[Zj^0P2][Jd0=02^[Zh0
ZZZZ0:VYZ@2NWYh0W9bL09VIV@2ATI40RXZ:07moO`1fMWH0Kfm_061PH01HF5P0Cdm?04U9B@17AdL0
DE5A04Q8B01=CDd0Cdm?05IFEP1ADE40FUYJ05eMG@1JFUX0GEeM05aLG01OGel0Hf=S069RHP1VIVH0
J6QX06MWI`1RHV80JVYZ06MWI`1VIVH0IfMW06UYJ@1SHf<0JVYZ06a/K01SHf<0J6QX06=SH`1RHV80
IFEU06QXJ01QHF40Hf=S06ATI01UIFD2069RHP0<06MWI`1VIVH0L71`08n?S`2`/;00Xj>S07QhN01]
KFd0Kfm_07=cL`1^KVh0N7Qh0P1dM7@01`1aLG40L71`07AdM01`L700Lg=c06m_K`1`L7000P1^KVh0
401WIfL0K6a/06UYJ@1_Kfl0Vi^K0=cLg03UiND0gMgM0=KFeP2TY:@0Lg=c06e]K@1eMGD0LG5a079b
LP1fMWH207QhN00R07emO@1cLg<0KFe]06=SH`1QHF40LW9b07EeM@21PH40QXJ608F5Q@1jNWX0OWin
07UiN@25QHD0S8b<08J6QP1cLg<0JVYZ07YjNP1[Jf/0IfMW061PH01;Bd/0AdM7055AD@1CDe<0@d=3
02l_;`0^;Rh0<c<c03lo?`0g=cL0;Rh^02XZ:P80;2`/00L0?3`l06QXJ01]KFd0CDe=02h^;P0a<C40
;2`/0080:b/[01D0<30`03hn?P17AdL0?clo038b<P0c<c<0>c/k03De=@0b<S80=CDe034a<@0g=cL0
=SHf04A4A00^;Rh0:b/[02h^;P0k>c/0?Shn0410@00i>CT00`0b<S80:P0g=cL0CTi>06=SH`1^KVh0
IfMW05aLG01jNWX0?clo03Lg=`0];Bd0<c<c03/k>`20P800RHV904M7A`0U9BD092@T02PX:00O7al0
92@T02<S8`0X:2P08b<S02TY:@0[:b/0HV9R096AT@2UYJD0UIFE0861P@1dM7@0LW9b07]kN`2PX:00
]KFe0;Vi^@2UYJD0[Zj^0:f][@2XZ:P0ZJVY0:6QX@80Z:RX02L0ZZZZ09JFUP27QhL0SXj>0:VYZ@2f
][H0/K6a0:VYZ@2XZ:P0[jn_0;Vi^@2l_;`0`<300<K6aP2i^KT0^;Rh0:n_[`2WYjL0ZZZZ0:^[Z`2Y
ZJT0ZZZZ0:b/[02YZJT0Zj^[0:j^[P2ZZZX0[jn_0:6QX@2FUYH0Ti>C09FEU@2LW9`0Xj>S0:JVYP2U
YJD0ZJVY0:NWY`2^[Zh00P2/[:`02@2b/[80/;2`0;Zj^P2m_Kd0_kno0;Vi^@2j^[X0_[jn0<?3``02
0<;2`P090<C4a036a/H0`l?30<G5a@34a<@0bLW90<S8b039bLT0b/[:0080bLW900D0b<S80<g=c@3<
c<`0dM7A0=3@d0050=7Ad@0W0=?Cd`3AdM40e=CD0=KFeP3De=@0dM7A0<c<c033`l<0`L710;Fe]@2T
Y:@0U9BD07inOP1_Kfl0HF5Q055AD@1=CDd0>SXj03/k>`0b<S80;2`/02HV9P0W9bL0:2PX02/[:`0`
<300=cLg04a<C016ATH0;Rh^07QhN02IVIT0UiNG0:6QX@2^[Zh0ZJVY08J6QP1/K6`0@D5100<0<c<c
00L0>CTi02h^;P0Y:BT0;bl_02`/;00a<C40=CDe0080<c<c00/0=cLg03/k>`0i>CT0>CTi03`l?00m
?Cd0>CTi03/k>`14A4@0>CTi03dm?@0204=3@`0703dm?@0l?3`0>3Ph03@d=00c<c<0;Rh^02d];@02
02l_;`0502`/;00b<S80;Rh^030`<00i>CT00P0d=3@0400e=CD0<C4a02XZ:P0Z:RX0;2`/02l_;`15
ADD0GemO07AdM01oOgl0RXZ:092@T02=SHd0QhN708J6QP22PX8208V9R@0609>CT`2MWId0Y:BT0::R
XP2SXj<0WYjN0`2LW9`0102DU9@0UYJF09VIV@2JVYX309FEU@0709JFUP2GUiL0UYJF09BDU02EUID0
UYJF09RHV00209BDU00@09:BTP2FUYH0U9BD09JFUP2JVYX0V9RH09JFUP2KVi/0VIVI09bLW02NWYh0
XZ:R09^KV`2MWId0WYjN0::RXP80WinO00D0XJ6Q09jNWP2LW9`0WinO0:2PX0020::RXP0;0:2PX02Q
XJ40XJ6Q0:6QX@2RXZ80X:2P09jNWP2QXJ40WinO09bLW02OWil00P2QXJ400`2NWYh0WIfM09RHV002
09fMW@0A09jNWP2LW9`0Vi^K09RHV02LW9`0WinO09RHV02IVIT0WYjN09RHV02NWYh0VIVI09bLW02I
VIT0VYZJ09RHV02EUID03P38h=P000`0b>3H0P1TI6@02`1VIVH0KVi^06e]K@1YJFT0IVIV06=SH`1_
Kfl0IfMW06YZJP1]KFd0IFEU0080IfMW01@0Hf=S06EUI@1RHV80Hf=S069RHP1TI6@0GUiN069RHP1K
Fe/0GUiN061PH01TI6@0KFe]07IfMP1oOgl0R8R809:BTP2CTi<0V9RH09fMW@80XZ:R00D0YJFU0:VY
Z@2[Zj/0ZZZZ0;2`/0020:n_[`040:f][@2^[Zh0[:b/0:f][@80[Zj^01l0/[:b0:j^[P2][Jd0[:b/
0:n_[`2^[Zh0YZJV0:6QX@2MWId0UiNG08j>SP2:RXX0Q8B407MgM`1/K6`0IFEU05QHF01EEED0B4Q8
04I6AP1;Bd/0CDe=04m?C`1>CTh0E5AD05EEE@1GEeL0Fe]K05IFEP1HF5P0GUiN0080HV9R02P0GemO
06QXJ01ZJVX0Hf=S06EUI@1YJFT0IVIV06EUI@1[Jf/0JVYZ06EUI@1ZJVX0Jf][06EUI@1SHf<0I6AT
06UYJ@1PH600Hf=S06EUI@1TI6@0HF5Q06IVIP1RHV80Hf=S06IVIP1YJFT0JVYZ06e]K@2<S8`0^KVi
09VIV@1bLW80KVi^06e]K@1cLg<0MWIf07=cL`1fMWH0KFe]0P1aLG40101/K6`0Kfm_06][J`1[Jf/2
06e]K@0B06EUI@1RHV80IfMW07inOP2d];@0i>CT0>7Qh@3Ng]h0e]KF0:JVYP1dM7@0MGEe079bLP1Z
JVX0M7Ad07EeM@1oOgl0N7Qh0P1dM7@0:01bLW80IfMW06EUI@1TI6@0IfMW07moO`2;Rh/0QHF508B4
Q022PX80Ogmo08>3P`27QhL0O7al05mOG`1<C4`0Fe]K05YJFP1@D500DU9B03`l?019BDT0Fe]K05UI
F@1?Cdl0>CTi03Lg=`0h>3P0Cdm?059BDP17AdL0<c<c02/[:`0/;2`0=CDe06IVIP1]KFd0BDU903@d
=00];Bd202XZ:P0302`/;00^;Rh0=SHf0080ATI600L0>SXj03/k>`0l?3`0>CTi02XZ:P0[:b/0;Rh^
0080;bl_00P0>c/k03De=@0a<C40=3@d04=3@`0n?Sh0@T9203Ti>@80=SHf02@0=3@d04A4A01JFUX0
H61P06=SH`0k>c/0@d=306YZJP0g=cL0;2`/02l_;`0d=3@0D51@092@T021PH40=cLg02TY:@0];Bd0
:RXZ02LW9`0T92@08B4Q02<S8`0P82008B4Q02@T900d=3@0Jf][09^KV`2PX:00Shn?07QhN01[Jf/0
JVYZ07emO@2KVi/20;Fe]@040:b/[02[Zj/0YJFU0:FUY@80YZJV0180YjNW0:>SX`2DU9@0Q8B408f=
S@2WYjL0/K6a0:f][@2SXj<0WinO0;6a/@2j^[X0`L710;jn_P2m_Kd0^;Rh0;Ng]`2a/K430:NWY`0C
0:RXZ02ZZZX0Zj^[0:^[Z`2ZZZX0Zj^[0:f][@2^[Zh0[:b/0:NWY`2LW9`0Ti>C09FEU@2RXZ80X:2P
0::RXP2YZJT0ZZZZ0:f][@020:n_[`0A0;2`/02^[Zh0][Jf0;Zj^P2l_;`0^k^k0;Ng]`33`l<0a<C4
0<71`@33`l<0a<C40<W9b@36a/H0a<C40<O7a`3:b/X00`38b<P01@39bLT0b<S80<[:bP3;bl/0c<c<
0080c/k>00H0d];B0=3@d03?cll0d=3@0=;BdP3EeMD20=3@d00]0=?Cd`3De=@0c/k>0<[:bP34a<@0
_kno0;6a/@2UYJD0RXZ:07YjNP1[Jf/0HV9R05QHF01;Bd/0=cLg034a<@0^;Rh0;Bd]02XZ:P0W9bL0
:b/[02XZ:P0g=cL0ATI6059BDP0o?cl0@T9208Z:RP2IVIT0Vi^K0:FUY@2ZZZX0YZJV08J6QP1UIFD0
>SXj03<c<`10@400?clo03Hf=P0b<S80:b/[03<c<`0j>SX0=SHf0080<30`00<0>c/k03Lg=`0g=cL0
0P0h>3P0100i>CT0>3Ph03Lg=`0i>CT203/k>`0303lo?`14A4@0?3`l0080A4A402H0?Shn03Lg=`0h
>3P0=3@d02h^;P0Z:RX0;2`/02XZ:P0`<300=3@d038b<P0g=cL0=SHf03lo?`0f=SH0;bl_02TY:@0^
;Rh0;2`/02d];@0j>SX0DE5A075aL@20P800Shn?096AT@2>SXh0RXZ:08F5Q@24Q8@0Ph>308N7Q`2@
T900VYZJ09nOW`2QXJ40Xj>S09jNWP80WIfM00@0UiNG09bLW02GUiL0Vi^K0P2FUYH03@2GUiL0Ti>C
09FEU@2HV9P0UiNG09FEU@2DU9@0UYJF09RHV02EUID0V9RH09JFUP2GUiL00`2JVYX02`2GUiL0WinO
0::RXP2QXJ40X:2P0:6QX@2PX:00WIfM0:6QX@2SXj<0XJ6Q0080WinO00H0Xj>S09nOW`2PX:00X:2P
09fMW@2OWil20:2PX0<0Xj>S0P2OWil0402NWYh0XJ6Q09fMW@2LW9`0WYjN0:6QX@2OWil0Vi^K09jN
WP2OWil0W9bL09fMW@2LW9`0Vi^K09bLW02NWYh209fMW@0609ZJVP2IVIT0W9bL09jNWP2KVi/0VIVI
0P2JVYX00`2GUiL0UIFE09RHV00>0<SPf0003038h=P306=SH`0<06e]K@1XJ6P0IFEU06a/K01WIfL0
Jf][06ATI01ZJVX0J6QX06UYJ@1WIfL0IFEU0P1RHV801@1OGel0HV9R065QH@1PH600GUiN0080Fe]K
0180FUYJ05QHF01SHf<0KFe]07IfMP25QHD0QXJ608j>SP2DU9@0UYJF09ZJVP2PX:00Y:BT0:>SX`2X
Z:P0YjNW0:b/[02YZJT20:f][@090;2`/02[Zj/0Zj^[0:f][@2b/[80/K6a0:j^[P2[Zj/0[Jf]0080
[jn_01d0[Jf]0:RXZ02PX:00VYZJ09>CT`2>SXh0RXZ:08N7Q`1jNWX0Lg=c065QH@1IFET0DE5A04e=
C@19BDT0D51@055AD@1;Bd/0D51@055AD@1DE5@0EEEE05mOG`1PH600GEeM061PH01RHV80HF5Q06IV
IP0206QXJ00;06=SH`1[Jf/0IFEU069RHP1XJ6P0K6a/06QXJ01RHV80J6QX06ATI01SHf<00P1VIVH0
201XJ6P0IFEU06IVIP1TI6@0JFUY06EUI@1VIVH0JFUY0P1VIVH0501QHF40Hf=S06MWI`1_Kfl0S8b<
0:NWY`1kNg/0K6a/075aL@1eMGD0LW9b07MgM`1^KVh0L71`07IfMP1bLW80KVi^071`L01]KFd0IfMW
0P1TI6@0<01RHV80H61P06QXJ02CTi<0dM7A0>3Ph03Ng]h0g=cL0=KFeP2f][H0NGUi079bLP1dM7@0
Jf][075aL@1eMGD0Ng]k07QhN01eMGD0M7Ad075aL@1]KFd0Kfm_06EUI@1QHF40JFUY07YjNP26QXH0
RXZ:08:2PP1mOGd0P82007YjNP1gMgL0K6a/06=SH`1XJ6P0D51@0451@@10@400>c/k04Q8B01GEeL0
Cdm?059BDP19BDT0Bd];04e=C@80G5aL0280FUYJ04=3@`0i>CT0;Rh^03Lg=`1DE5@0J6QX05YJFP0b
<S80;Bd]02TY:@0Z:RX0;Bd]02HV9P0];Bd0@41004=3@`0g=cL0;Rh^0451@@0j>SX0<S8b02`/;00^
;Rh0=3@d02/[:`0`<300>SXj03`l?011@D40C4a<03Xj>P0k>c/0@D510P0e=CD0?`0d=3@0B4Q805AD
E01LG5`0Cdm?034a<@0g=cL0HF5Q03Xj>P0/;2`0;Rh^0410@01_Kfl0Shn?075aL@0/;2`0;Rh^02TY
:@0S8b<09bLW02HV9P0S8b<08R8R024Q8@0O7al0820P02DU9@0f=SH0L71`09NGU`2XZ:P0SXj>07Ad
M01WIfL0LW9b08>3P`2PX:00/k>c0;no_`2a/K40ZJVY0:BTY02UYJD0Y:BT0:FUY@2PX:00SXj>08B4
Q029RHT0Y:BT0:VYZ@2UYJD0WYjN09nOW`2YZJT0][Jf0<71`@2k^k/0]KFe0:f][@2f][H0];Bd0:^[
Z`020:b/[080ZJVY0140[:b/0:JVYP2XZ:P0Y:BT0:ZZZP2XZ:P0/[:b0;>c/`2_[jl0WIfM08Z:RP2C
Ti<0WIfM09nOW`2VYZH0YjNW0:VYZ@020:b/[080[jn_00h0];Bd0;Vi^@2k^k/0]kNg0;fm_@31`L40
`<300<71`@30`<00alO70<S8b033`l<0`/;20<[:bP80bLW90P3:b/X01`37alL0bLW90<W9b@37alL0
bLW90<k>cP3:b/X00P3@d=00603?cll0d];B0=;BdP3Bd]80dM7A0=3@d03Cdm<0d];B0=3@d03:b/X0
a<C40;Vi^@2ZZZX0WIfM08N7Q`1hN7P0IFEU061PH01IFET0AdM703Ph>00`<3009RHV02LW9`809RHV
01h0;2`/03Ti>@16ATH0C4a<051@D00h>3P0EUIF09:BTP2OWil0X:2P0:RXZ02][Jd0WYjN08R8R01B
DU80<30`03Ph>00k>c/0=cLg03Xj>P0_;bl0>SXj02XZ:P0d=3@0<c<c034a<@0d=3@0@D5103Hf=P0e
=CD203Hf=P0A03@d=00k>c/0<c<c03/k>`0j>SX0=cLg03`l?011@D40@d=303hn?P10@400?3`l03@d
=00c<c<0<30`02d];@0_;bl00P0`<300100a<C40<30`03De=@0f=SH203Lg=`0S03Hf=P0h>3P0;2`/
02XZ:P0];Bd0<C4a03Hf=P1ADE40JFUY07UiN@29RHT0TY:B096AT@2<S8`0QXJ608B4Q01nOWh0PH61
08j>SP2EUID0V9RH0:6QX@2TY:@0WinO09jNWP2GUiL0VIVI09fMW@2GUiL0Ti>C09ZJVP2HV9P0UiNG
09FEU@2IVIT00P2DU9@01`2FUYH0Vi^K09RHV02HV9P0Vi^K09RHV02KVi/00P2MWId01P2PX:00XJ6Q
09jNWP2RXZ80WYjN09nOW`80XZ:R00D0X:2P0::RXP2OWil0X:2P0:>SX`020:6QX@070:>SX`2PX:00
X:2P0:>SX`2PX:00WinO0:BTY0020:>SX`030:2PX02OWil0WinO00@0X:2P01@0Y:BT0:6QX@2NWYh0
WinO09jNWP2QXJ40WYjN09bLW02KVi/0WYjN09^KV`2NWYh0WIfM09^KV`2PX:00VYZJ09fMW@2HV9P0
VYZJ09fMW@80UiNG00@0VYZJ09RHV02FUYH0Ti>C3P38h=P000`0b>3H0P1XJ6P03P1YJFT0IfMW06UY
J@1XJ6P0Jf][06MWI`1]KFd0IfMW06UYJ@1ZJVX0J6QX06IVIP1XJ6P0IfMW0P1SHf<04P1UIFD0IVIV
061PH01UIFD0H61P05]KF`1LG5`0Hf=S06YZJP1_Kfl0MgMg0820P025QHD0SXj>096AT@2GUiL0WIfM
09nOW`80YJFU00@0YjNW0:ZZZP2/[:`0[Zj^0P2ZZZX0202[Zj/0[Jf]0;2`/02YZJT0[Zj^0:n_[`2a
/K40[:b/0P2_[jl0302/[:`0ZJVY0:JVYP2QXJ40V9RH09^KV`2CTi<0SXj>08B4Q01gMgL0K6a/065Q
H@80DE5A0P13@d<01P17AdL0CTi>051@D01ADE40D51@05MGE`80Fe]K00X0GemO05iNGP1KFe/0Fe]K
065QH@1SHf<0GemO06QXJ01QHF40Hf=S0P1OGel02@1TI6@0HF5Q06=SH`1VIVH0JVYZ06ATI01UIFD0
I6AT06UYJ@0206ATI00H06IVIP1TI6@0IVIV06=SH`1VIVH0JFUY06QXJ01WIfL0J6QX06ATI01YJFT0
JVYZ071`L01nOWh0O7al06YZJP1_Kfl0M7Ad07EeM@1cLg<0L71`079bLP1_Kfl0M7Ad0P1aLG40401`
L700JVYZ06EUI@1UIFD0HF5Q05iNGP1[Jf/0YjNW0=gMg@3Ng]h0f=SH0=_Kf`3Hf=P0^k^k0861P@1a
LG4206i^KP0506m_K`1cLg<0LG5a075aL@1dM7@00P1^KVh03@1fMWH0Lg=c06YZJP1/K6`0HV9R06i^
KP1nOWh0SHf=08b<S01lO7`0N7Qh07MgM`1kNg/00P21PH404@20P800KVi^05QHF01GEeL0Hf=S05]K
F`1PH600CTi>04a<C011@D40>CTi0451@@13@d<0@T9204A4A00e=CD0=3@d0080;Rh^00`0EEEE065Q
H@1RHV80?Shn02d];@0Z:RX09bLW02d];@0Y:BT0;Bd]03@d=00k>c/202h^;P0?03Ph>00n?Sh0<c<c
034a<@0_;bl0=SHf034a<@0c<c<0@410055AD@1<C4`0BTY:0451@@0m?Cd0A4A40080>CTi01D0@D51
04e=C@16ATH0FEUI051@D00Y:BT0:b/[04];B`0k>c/0=CDe02d];@1IFET0R8R808Z:RP1NGUh09bLW
02TY:@0V9RH092@T02h^;P0X:2P00P0S8b<07@0Q8B407AdM01hN7P0O7al09RHV0451@@1cLg<0Y:BT
0:b/[028R8P0LG5a06MWI`1dM7@0QhN709nOW`2f][H0_kno0:f][@2VYZH0Y:BT0:JVYP2UYJD0Xj>S
08f=S@26QXH0P82009^KV`2WYjL0Y:BT0080[:b/01h0XZ:R0;2`/030`<00_kno0;Jf]P2][Jd0[:b/
0;fm_@2^[Zh0YjNW0:f][@2ZZZX0ZJVY0:ZZZP2QXJ40YjNW0:2PX02XZ:P0Xj>S0:j^[P2`/;00]kNg
0;Fe]@2NWYh0Shn?09VIV@2OWil0YZJV0:FUY@2ZZZX20;:b/P0=0:f][@2_[jl0];Bd0;^k^`2d];@0
^KVi0;fm_@31`L40a<C40<;2`P34a<@0c<c<0<S8b0020<K6aP070<O7a`39bLT0b/[:0<W9b@3;bl/0
b/[:0<O7a`020<W9b@030<c<c03;bl/0bl_;0080clo?00D0d];B0=7Ad@3Bd]80dM7A0=?Cd`020=GE
e@0K0=7Ad@3=cLd0bLW90<;2`P2h^;P0YjNW09JFUP1oOgl0K6a/065QH@1LG5`0DE5A04I6AP0a<C40
9RHV02<S8`0V9RH0;Rh^02l_;`0`<300?clo04E5A@1=CDd0ATI603dm?@1fMWH0UYJF0080W9bL00D0
/[:b0:j^[P2LW9`0Ogmo04e=C@0202l_;`03038b<P0a<C40=SHf0080;Rh^00P0<30`04=3@`15ADD0
=cLg03Ph>00o?cl0>3Ph03De=@80>3Ph01D0>CTi03@d=00e=CD0=SHf03Lg=`0k>c/0?Cdm0492@P13
@d<0>SXj03lo?`11@D40>SXj03De=@0`<300<c<c02/[:`0`<300;bl_02`/;00a<C400`0b<S80:@0j
>SX0=cLg02l_;`0X:2P0;2`/02/[:`0d=3@0=SHf04e=C@1PH600MGEe0861P@2?Shl0U9BD08n?S`27
QhL0R8R807emO@1nOWh0Rh^;09:BTP2JVYX0W9bL0::RXP2LW9`0WIfM09VIV@2EUID0Vi^K09VIV@2G
UiL0VIVI09NGU`2FUYH0TI6A09>CT`2IVIT0Vi^K09NGU`2IVIT0V9RH0080VYZJ00D0X:2P09bLW02M
WId0XJ6Q0:>SX`0209nOW`050:6QX@2NWYh0WinO0:>SX`2QXJ400P2RXZ820:6QX@<0X:2P00D0Xj>S
09nOW`2XZ:P0X:2P0:BTY0030:FUY@0;09nOW`2NWYh0XJ6Q0:6QX@2OWil0X:2P0::RXP2QXJ40X:2P
0:6QX@2MWId00P2LW9`0402QXJ40Vi^K0:2PX02LW9`0WYjN09fMW@2NWYh0WIfM09bLW02IVIT0W9bL
09fMW@2IVIT0WIfM09ZJVP2HV9P209JFUP80VIVI00<0UYJF0<SPf038h=P03038h=P000`0b>3H0`1V
IVH206ATI00706YZJP1SHf<0J6QX06UYJ@1ZJVX0JFUY06=SH`0206EUI@0G06UYJ@1QHF40I6AT06MW
I`1TI6@0IfMW06ATI01PH600G5aL05UIF@1JFUX0HF5Q06EUI@1^KVh0MWIf08>3P`26QXH0SHf=09:B
TP2GUiL0VYZJ0:2PX02SXj<00P2WYjL00`2ZZZX0[jn_0:b/[0020:b/[0080:j^[P2ZZZX0[:b/0:b/
[02`/;00[Zj^0:n_[`2^[Zh20:f][@030:VYZ@2XZ:P0YjNW0080WYjN02H0X:2P09BDU029RHT0PH61
07YjNP1^KVh0JVYZ05EEE@1ADE40BTY:04I6AP13@d<0Cdm?04e=C@1?Cdl0EUIF059BDP1FEUH0Fe]K
065QH@1JFUX0HF5Q05aLG01VIVH0IFEU06ATI01QHF40H61P06IVIP1OGel0HF5Q06ATI01VIVH0HF5Q
06MWI`1QHF40IFEU06MWI`80Hf=S0P1VIVH01`1TI6@0IVIV06ATI01UIFD0JVYZ06IVIP1ZJVX00`1W
IfL0301[Jf/0KFe]06YZJP1ZJVX0L71`06m_K`1bLW80N7Qh07MgM`1hN7P0LG5a071`L080Kfm_00@0
L71`06e]K@1[Jf/0JFUY0P1SHf<04P1OGel0GUiN07MgM`2j^[X0g=cL0=kNgP3Fe]H0f][J0=_Kf`3:
b/X0RXZ:06][J`1XJ6P0L71`06m_K`1aLG40KVi^07=cL`80JFUY00<0LG5a07EeM@1`L7000P1]KFd0
2@1eMGD0Kfm_07AdM026QXH0QhN708:2PP1iNGT0OWin0820P0020861P@0[08:2PP1dM7@0EeMG06EU
I@1cLg<0LW9b071`L01aLG40Kfm_06IVIP1FEUH0EeMG051@D01FEUH0?clo02l_;`0^;Rh0<S8b03<c
<`1ADE40GUiN061PH01=CDd0<S8b02/[:`0Z:RX0:BTY02LW9`0];Bd0<S8b03Lg=`0c<c<0;bl_034a
<@0k>c/0<c<c038b<P0e=CD0;Rh^03<c<`0h>3P0De=C05ADE00204Q8B00304E5A@12@T80ADE50080
@D5101T0@d=303Xj>P10@400HF5Q05IFEP0[:b/0;Rh^03hn?P10@400=cLg03`l?01GEeL0TY:B08j>
SP1KFe/0:2PX02LW9`0/;2`0;Bd]02/[:`0Z:RX09BDU02@T900Z:RX08B4Q00807QhN03T08B4Q02DU
9@1:BTX0QHF50:BTY02LW9`0RHV9071`L01ZJVX0LW9b08B4Q02PX:00^[Zj0;fm_@2WYjL0Y:BT0:FU
Y@2TY:@0Xj>S08J6QP20P800Ph>309VIV@2_[jl0]KFe0;Jf]P2^[Zh0Y:BT0;:b/P31`L40`<300;Rh
^02i^KT0/k>c0;^k^`2c/k<0ZJVY0:NWY`2VYZH0X:2P0:RXZ02PX:00Y:BT0:6QX@2UYJD0Y:BT0:j^
[P2_[jl0];Bd0;^k^`2e]KD0YJFU09^KV`2LW9`0Vi^K0:BTY02WYjL00P2^[Zh0302/[:`0[Jf]0;Fe
]@2f][H0/k>c0;fm_@2i^KT0`<300<?3``32`/80aLG50<C4a080alO700X0`/;20<C4a039bLT0c/k>
0<_;b`39bLT0cLg=0<K6aP37alL0b<S80P3;bl/0103>c/h0clo?0<o?c`3Cdm<20=GEe@0=0=CDe03@
d=00dm?C0=?Cd`3@d=00b<S80<71`@2k^k/0];Bd0:>SX`2DU9@0NWYj06][J`0205mOG`0J059BDP0n
?Sh0;Bd]02TY:@0W9bL0:b/[02h^;P0_;bl0=SHf0492@P1<C4`0BDU903lo?`1GEeL0QhN709^KV`2L
W9`0WinO0:b/[02VYZH0UiNG07IfMP1=CDd0<C4a02/[:`0b<S8202l_;`0702/[:`0Y:BT0<C4a03Lg
=`0`<300;2`/02h^;P0303@d=080>3Ph01`0>SXj0410@00e=CD0>c/k03Hf=P0h>3P0=SHf03Ph>00k
>c/0@T9204=3@`0o?cl0=SHf02l_;`0c<c<0;bl_02`/;00^;Rh0:2PX02`/;00X:2P0:BTY02d];@0^
;Rh0=cLg038b<P0^;Rh0;2`/0P0^;Rh05P0g=cL0>CTi04A4A01?Cdl0L71`07inOP2;Rh/0SXj>092@
T02;Rh/0RHV908F5Q@1oOgl0Ph>3092@T02DU9@0W9bL09jNWP2IVIT0Vi^K09ZJVP2HV9P209FEU@09
09JFUP2CTi<0W9bL09:BTP2DU9@0UIFE09bLW02OWil0VYZJ0080W9bL00@0XZ:R09bLW02RXZ80XJ6Q
0P2NWYh0102PX:00WinO0:6QX@2QXJ420::RXP070:2PX02OWil0XZ:R0:6QX@2RXZ80X:2P09nOW`02
0:2PX00?0:BTY02QXJ40Y:BT0:>SX`2PX:00YZJV0:>SX`2QXJ40Y:BT09fMW@2LW9`0X:2P09fMW@2P
X:00XJ6Q00@0WYjN0100WinO09jNWP2PX:00WIfM09^KV`2MWId0WinO09fMW@2NWYh0WIfM09jNWP2L
W9`0Vi^K09bLW02KVi/0WIfM0`2JVYX209RHV00309FEU@2FUYH0b>3H00d0b>3H000<0<SPf080I6AT
00D0K6a/06YZJP1[Jf/0KVi^06MWI`0206UYJ@0406MWI`1PH600IfMW06MWI`80Hf=S01/0IFEU06IV
IP1VIVH0IFEU06ATI01LG5`0Hf=S05]KF`1LG5`0Fe]K06=SH`1YJFT0LW9b07]kN`1nOWh0QXJ608V9
R@2ATI40VYZJ09jNWP2MWId0YJFU0:RXZ02UYJD0[jn_0;6a/@2^[Zh00P2_[jl01@2ZZZX0Zj^[0:VY
Z@2`/;00/K6a0080[:b/0100[Zj^0:n_[`2^[Zh0Zj^[0:RXZ02TY:@0WYjN09bLW02IVIT0TY:B08^;
R`21PH40N7Qh06IVIP1SHf<0Cdm?0P18B4P00`19BDT0ATI605=CD`0305=CD`0305IFEP1KFe/0GEeM
0080Fe]K00T0G5aL065QH@1OGel0HF5Q05eMG@1WIfL0HV9R06IVIP1WIfL00P1TI6@0401UIFD0HV9R
06UYJ@1[Jf/0IFEU069RHP1OGel0IVIV069RHP1SHf<0HV9R06=SH`1TI6@0IfMW06QXJ01WIfL206QX
J00D06YZJP1XJ6P0K6a/06i^KP1/K6`0KVi^07=cL`1]KFd0M7Ad07IfMP1gMgL0MWIf06i^KP1`L700
K6a/071`L01^KVh0K6a/06YZJP1NGUh206MWI`0<069RHP1SHf<0SHf=0<k>cP3Ogml0fm_K0=GEe@3J
f]X0f=SH0<_;b`2IVIT0K6a/0P1ZJVX0401XJ6P0JVYZ06][J`1XJ6P0JFUY06YZJP1`L700MgMg07Ee
M@1aLG40MgMg07QhN01dM7@0KVi^07EeM@1lO7`207moO`0;08>3P`24Q8@0Q8B407inOP24Q8@0Jf][
05MGE`1hN7P0O7al079bLP1`L7000P1bLW809`1iNGT0Kfm_06i^KP1eMGD0JFUY04M7A`0];Bd09bLW
02/[:`0];Bd0?Shn05MGE`1OGel0EUIF02`/;00];Bd0:BTY02l_;`0V9RH0:b/[02l_;`0f=SH0=3@d
02d];@0[:b/0<S8b030`<00];Bd0<C4a03@d=00h>3P0BTY:05IFEP1?Cdl0ADE503Xj>P0o?cl0BDU9
04];B`0204E5A@070410@00a<C40ADE5069RHP1HF5P0:b/[02d];@0203`l?00@02`/;00b<S80DE5A
08j>SP25QHD0F5QH034a<@0n?Sh0@41004];B`13@d<0?Shn02h^;P0Y:BT09RHV02@T90808b<S01l0
7alO024Q8@0Y:BT0EUIF08:2PP2JVYX0X:2P08R8R01aLG40K6a/06QXJ01hN7P0WinO0;Rh^02e]KD0
X:2P0:NWY`2RXZ80V9RH0820P01kNg/0SXj>0:2PX02k^k/0^[Zj0;6a/@2d];@0YZJV0;Ng]`2l_;`0
`l?30080_;bl01P0_[jn0;Rh^02e]KD0[Jf]0:ZZZP2/[:`0XZ:R0:BTY02SXj<0WinO0:6QX@2NWYh0
WinO0:NWY`2a/K40];Bd0;Jf]P2l_;`0/K6a0;2`/02OWil0V9RH09bLW02TY:@30:RXZ00:0:NWY`2_
[jl0/;2`0;Bd]02j^[X0^KVi0;^k^`2m_Kd0_[jn0<30`080a<C40P31`L402@36a/H0bLW90<_;b`38
b<P0bLW90<[:bP39bLT0b/[:0<W9b@020<_;b`050<c<c03;bl/0bl_;0=?Cd`3AdM400P3Bd]809@3?
cll0dM7A0=7Ad@3>c/h0bl_;0<71`@2i^KT0[jn_0:BTY029RHT0Lg=c06QXJ01GEeL0FEUI04];B`0m
?Cd0;Rh^02HV9P0Z:RX0;Rh^02l_;`0^;Rh0@T9204U9B@1EEED0Bd];03hn?P1UIFD0TY:B09ZJVP2D
U9@0Vi^K0:f][@2SXj<0VYZJ07emO@1=CDd00P0];Bd02P0_;bl0<c<c034a<@0Z:RX0:b/[02l_;`0a
<C40;Bd]034a<@0[:b/203<c<`0D03Lg=`0a<C40<C4a03De=@0f=SH0=CDe03Xj>P0a<C40@41003Xj
>P0m?Cd0>3Ph0410@00o?cl0ADE504M7A`0j>SX0=3@d02l_;`0[:b/202`/;009034a<@0_;bl0<c<c
02d];@0_;bl0<C4a03dm?@0a<C40:RXZ0080;Bd]00`0<C4a03Hf=P0o?cl0CTi>05mOG`1fMWH0Ph>3
08n?S`2;Rh/0RHV908J6QP25QHD207moO`0608N7Q`2CTi<0UiNG09^KV`2JVYX0Vi^K0P2FUYH07@2H
V9P0UYJF09NGU`2KVi/0UYJF09RHV02IVIT0Vi^K09nOW`2NWYh0W9bL0:6QX@2OWil0XZ:R0:JVYP2W
YjL0YJFU0::RXP2TY:@0X:2P0:NWY`2RXZ80YZJV0:>SX`2TY:@0YZJV0:6QX@2PX:00WinO0080X:2P
00<0XJ6Q0:>SX`2SXj<00P2RXZ803@2SXj<0WinO0::RXP2VYZH0XJ6Q0::RXP2QXJ40X:2P0:>SX`2Q
XJ40WinO0:6QX@2PX:000P2OWil00`2QXJ40WIfM09bLW00209bLW00:0:6QX@2OWil0WinO09fMW@2N
WYh0X:2P09nOW`2RXZ80X:2P09ZJVP80W9bL00P0VIVI09^KV`2FUYH0V9RH09^KV`2HV9P0U9BD09NG
U`h0b>3H000<0<SPf0<0Jf][00P0JFUY06][J`1^KVh0J6QX06i^KP1VIVH0JVYZ06=SH`80IVIV00<0
Hf=S06IVIP1UIFD00P1UIFD04`1TI6@0HV9R065QH@1QHF40GUiN05]KF`1LG5`0Hf=S06YZJP1/K6`0
NGUi0820P028R8P0RXZ:092@T02HV9P0VYZJ09fMW@2RXZ800P2YZJT00`2[Zj/0ZZZZ0:f][@020:b/
[00@0:ZZZP2_[jl0[jn_0:j^[P2`/;00[Zj^0:b/[02ZZZX0[Zj^0:n_[`2][Jd0YjNW0:BTY02PX:00
WIfM09NGU`80SXj>01h0OWin07EeM@1WIfL0HV9R05IFEP1BDU80BTY:04=3@`1<C4`0Bd];04e=C@1A
DE40De=C051@D01HF5P0GemO06EUI@1MGEd0Fe]K06=SH`1TI6@0GemO06=SH`1QHF40IFEU06=SH`1P
H600I6AT06IVIP1UIFD206QXJ00<06MWI`1VIVH0H61P069RHP1TI6@0GemO069RHP1QHF40Hf=S06YZ
JP1XJ6P0KFe]0P1VIVH01`1/K6`0IVIV06YZJP1/K6`0Kfm_06i^KP1/K6`00P1^KVh00`1`L700LG5a
07AdM002075aL@03071`L01]KFd0KFe]0080KVi^00L0IfMW06ATI01NGUh0GUiN05mOG`1TI6@0Z:RX
0080gMgM00P0e]KF0=_Kf`3Kfm/0d];B0<k>cP2^[Zh0NGUi06e]K@80IfMW00L0Jf][06UYJ@1WIfL0
JFUY071`L01cLg<0L71`0080MGEe00<0LW9b07MgM`1^KVh00P1WIfL01@1aLG40NWYj0820P024Q8@0
QHF50080Ng]k01d0O7al06i^KP1UIFD0Ogmo08B4Q01mOGd0MGEe06i^KP1cLg<0Ng]k07moO`22PX80
N7Qh06QXJ01GEeL0<30`02`/;00V9RH0:b/[03Hf=P0o?cl0Fe]K05eMG@0f=SH0;Bd]02l_;`0/;2`0
:b/[03De=@0302XZ:P0@02/[:`0^;Rh0<30`034a<@0[:b/0=cLg04=3@`1<C4`0E5AD051@D01>CTh0
>c/k03lo?`18B4P0EUIF05EEE@80ADE503X0>3Ph02PX:00h>3P0IfMW05=CD`0T92@08b<S02d];@0i
>CT0:b/[03/k>`1RHV80TI6A08N7Q`1SHf<0EUIF055AD@1TI6@0Kfm_06=SH`1IFET0<c<c02DU9@0Q
8B40:RXZ028R8P0T92@07alO028R8P0X:2P0;Rh^051@D026QXH0WinO0::RXP21PH40IVIV05eMG@1S
Hf<0O7al09jNWP2e]KD0Zj^[0:6QX@2TY:@0SXj>07YjNP1kNg/0QXJ60;2`/02n_[h0^[Zj0:j^[P2_
[jl0];Bd0;Fe]@30`<00`L710P2o_kl06031`L40_kno0;Fe]@2^[Zh0ZZZZ0:JVYP2RXZ80YJFU0::R
XP2OWil0W9bL0:6QX@2OWil0YZJV0:ZZZP2][Jd0]KFe0;Vi^@2f][H0/[:b0;2`/02RXZ80WYjN0:2P
X080Y:BT00D0YjNW0:f][@2][Jd0[Jf]0;2`/0030;^k^`060;bl_030`<00`L710<O7a`33`l<0`<30
0P33`l<02@35aLD0bLW90<c<c038b<P0bLW90<O7a`39bLT0b<S80<c<c0020<_;b`030<c<c03=cLd0
c<c<0080clo?0P3>c/h20<g=c@0T0<W9b@38b<P0_[jn0;Bd]02[Zj/0VIVI08R8R01]KFd0IFEU05aL
G01KFe/0BDU903<c<`0W9bL092@T030`<00a<C40;2`/034a<@1@D500E5AD04a<C011@D40ADE5079b
LP2JVYX0VIVI09>CT`2NWYh0Xj>S0:RXZ02MWId0N7Qh04Y:BP0c<c<0<30`0P0^;Rh02`0_;bl0=3@d
02`/;00Y:BT0:b/[02`/;00c<c<0;Bd]03@d=00a<C40<30`0080<S8b00X0<c<c034a<@0g=cL0>CTi
038b<P0f=SH0>SXj0492@P0n?Sh0>CTi0P0o?cl0;`0k>c/0=3@d03Lg=`0^;Rh0;bl_03Lg=`0];Bd0
<30`02h^;P0X:2P0;bl_02TY:@0b<S80<C4a03Hf=P0^;Rh0=CDe034a<@0j>SX0=cLg03Ph>018B4P0
F5QH075aL@1oOgl0QXJ6092@T02?Shl0RHV908R8R021PH40PX:208F5Q@2@T900TY:B09JFUP2IVIT0
Vi^K09JFUP2JVYX0UIFE09BDU02GUiL0V9RH09fMW@2IVIT0WIfM0080WYjN00D0Y:BT0:6QX@2UYJD0
Z:RX0:VYZ@020:FUY@0>0:JVYP2UYJD0YjNW0:BTY02WYjL0YJFU0:6QX@2TY:@0Xj>S0::RXP2OWil0
XJ6Q0:2PX02SXj<20:6QX@80X:2P00H0Y:BT0::RXP2TY:@0Xj>S0::RXP2XZ:P20:6QX@80X:2P00h0
XZ:R0:2PX02KVi/0WinO0:2PX02NWYh0X:2P09jNWP2PX:00W9bL0:6QX@2NWYh0X:2P09nOW`80WIfM
00D0W9bL09nOW`2OWil0WinO09jNWP0209ZJVP0909fMW@2GUiL0W9bL09JFUP2IVIT0VYZJ09bLW02D
U9@0UYJF00h0b>3H000<0<SPf080IfMW00d0JVYZ06][J`1VIVH0J6QX06UYJ@1]KFd0IVIV071`L01[
Jf/0IVIV06i^KP1SHf<0IFEU00<0HF5Q01L0H61P06ATI01PH600Fe]K05eMG@1JFUX0EeMG05YJFP1R
HV80M7Ad07QhN01nOWh0QHF508j>SP2BTY80VYZJ09^KV`2QXJ40XZ:R0:FUY@2XZ:P0[Zj^0:ZZZP03
0:b/[0030;6a/@2/[:`0[Jf]00@0[Jf]0100ZZZZ0:b/[02/[:`0ZJVY0:NWY`2UYJD0Xj>S09bLW02G
UiL0SHf=08^;R`23Ph<0MgMg06m_K`1PH600EEEE0P1=CDd0;@14A4@0C4a<04m?C`1<C4`0DU9B05EE
E@1FEUH0FEUI05YJFP1SHf<0GemO061PH01NGUh0GEeM06ATI01RHV80IFEU06MWI`1XJ6P0I6AT05mO
G`1XJ6P0JFUY06ATI01UIFD0HF5Q06=SH`1RHV80HF5Q06IVIP1RHV80H61P06QXJ01VIVH0HV9R05iN
GP1TI6@0IFEU06][J`1_Kfl0JVYZ06a/K01WIfL0KVi^06e]K@0206m_K`0407AdM01aLG40Kfm_06m_
K`80LW9b00L0L71`075aL@1/K6`0K6a/06][J`1SHf<0HV9R0080GUiN01<0GEeM06m_K`2g]kL0gmoO
0=_Kf`3EeMD0fm_K0=KFeP3AdM40fMWI0<K6aP2<S8`0L71`06EUI@1XJ6P0IfMW06UYJ@1`L700MWIf
0080Lg=c00P0KVi^07=cL`1aLG40M7Ad07YjNP1eMGD0Lg=c079bLP80L71`01l0MWIf0820P01oOgl0
Ogmo07alO021PH40Ogmo07QhN023Ph<0S8b<08>3P`1gMgL0LW9b07moO`1nOWh0MgMg07QhN01bLW80
GEeM03@d=00];Bd09RHV02TY:@0_;bl0?3`l03<c<`13@d<0F5QH04M7A`11@D40<c<c0080<30`01@0
:b/[02d];@0a<C40;Bd]034a<@0b<S80>3Ph02l_;`0a<C40=3@d04I6AP1LG5`0D51@05=CD`0k>c/0
?clo04];B`1>CTh0FEUI04];B`80?Cdm03`0;2`/02h^;P0j>SX0HV9R05=CD`0U9BD08b<S02XZ:P0g
=cL0<C4a05=CD`1bLW80R8R808N7Q`1[Jf/0J6QX05iNGP1OGel0GEeM04Q8B00e=CD09BDU02<S8`0V
9RH0:RXZ02@T900Q8B409BDU02@T900U9BD08B4Q038b<P1KFe/0Ph>309ZJVP2DU9@0MGEe05YJFP1C
De<0IVIV07IfMP2FUYH0];Bd0;Jf]P2UYJD0RHV907QhN02=SHd0UIFE0:b/[02k^k/0_;bl0;Jf]P2`
/;00]KFe0;^k^`2j^[X0_;bl0<30`032`/820<71`@050;fm_@2f][H0/k>c0:NWY`2YZJT00P2UYJD3
0:6QX@0<0:JVYP2UYJD0ZZZZ0:n_[`2/[:`0];Bd0;Ng]`2f][H0/[:b0:f][@2WYjL0Y:BT0P2QXJ40
4@2VYZH0Zj^[0:f][@2/[:`0/K6a0;Rh^02g]kL0^;Rh0;^k^`2m_Kd0`<300<G5a@33`l<0`L710;jn
_P33`l<0alO70080bl_;00<0alO70<W9b@37alL00P38b<P0>`36a/H0bl_;0<S8b03<c<`0bl_;0<c<
c03?cll0c<c<0<W9b@3=cLd0b/[:0<g=c@38b<P0`l?30;Zj^P2`/;00Xj>S09>CT`20P800K6a/05iN
GP1DE5@0De=C04M7A`0b<S80;2`/02TY:@0_;bl0:2PX02DU9@0f=SH0FEUI055AD@1<C4`0?3`l04U9
B@20P800UYJF09BDU028R8P0XJ6Q0:2PX02SXj<0WYjN08:2PP1GEeL0=CDe02l_;`0b<S80;2`/02XZ
:P0Y:BT0<30`02`/;00`<300;Rh^02l_;`0a<C40<30`00@0<S8b00T0=cLg03Hf=P0m?Cd0=CDe0451
@@0i>CT0=SHf03Xj>P10@4000`0o?cl01`0l?3`0?Shn03`l?00[:b/0=3@d02h^;P0Z:RX00P0];Bd2
02`/;080;Rh^00D0=cLg038b<P0`<300;Rh^030`<00202l_;`0703De=@0o?cl0DE5A06MWI`1fMWH0
QHF508j>SP0208b<S00708N7Q`23Ph<0Ogmo0861P@2;Rh/0Shn?09>CT`0209RHV00=09ZJVP2EUID0
Ti>C09NGU`2FUYH0Vi^K09ZJVP2MWId0Xj>S0:NWY`2SXj<0Y:BT0:NWY`020:FUY@040:BTY02XZ:P0
YZJV0:JVYP80YJFU0`2TY:@0102QXJ40X:2P0:BTY02TY:@30:6QX@030::RXP2QXJ40XJ6Q0080X:2P
00<0YJFU0:BTY02TY:@00P2TY:@00`2QXJ40Y:BT0::RXP020::RXP0609fMW@2QXJ40X:2P0:6QX@2R
XZ80W9bL0P2MWId00`2NWYh0WinO09jNWP0209nOW`80X:2P0140WIfM09bLW02MWId0WYjN09^KV`2O
Wil0V9RH09ZJVP2MWId0VYZJ09jNWP2IVIT0VYZJ09JFUP2LW9`0UYJF09FEU@0>0<SPf0003038h=P2
06UYJ@0406m_K`1/K6`0J6QX06QXJ080JVYZ00<0IfMW06YZJP1XJ6P00P1YJFT04P1WIfL0K6a/061P
H01PH600IFEU06=SH`1PH600HF5Q05MGE`1IFET0Fe]K05QHF01LG5`0Hf=S06QXJ01dM7@0PX:208F5
Q@80TI6A00T0U9BD09bLW02NWYh0Xj>S0:JVYP2[Zj/0[:b/0:ZZZP2[Zj/00P2/[:`20:j^[P050:^[
Z`2][Jd0[Jf]0:^[Z`2`/;000P2^[Zh08@2ZZZX0[Jf]0:VYZ@2RXZ80W9bL09VIV@2DU9@0Shn?08V9
R@1mOGd0L71`06e]K@1MGEd0DU9B04e=C@18B4P0BTY:04a<C016ATH0CDe=051@D01FEUH0Cdm?061P
H01KFe/0HF5Q05iNGP1LG5`0I6AT05eMG@1RHV80Hf=S065QH@02069RHP0<061PH01MGEd0J6QX065Q
H@1PH600HF5Q06EUI@1QHF40J6QX05mOG`1TI6@0IFEU0P1PH6003@1TI6@0Hf=S06IVIP1WIfL0HV9R
06QXJ01[Jf/0KFe]06IVIP1XJ6P0K6a/071`L01bLW800P1dM7@207=cL`0:07EeM@1aLG40LW9b06a/
K01bLW80K6a/06YZJP1/K6`0HV9R061PH0<0Fe]K00<0NWYj0<30`03Ng]h00`3Hf=P02`3@d=00d];B
0=_Kf`3AdM40ZZZZ07QhN01SHf<0I6AT065QH@1[Jf/0LG5a0080N7Qh01@0Kfm_075aL@1bLW80MgMg
07QhN01mOGd0Ng]k07emO@1fMWH0KVi^06YZJP1`L700MgMg07inOP25QHD0PX:208^;R`26QXH0PH61
08F5Q@<0Q8B401L0MgMg07]kN`1jNWX0N7Qh0820P01fMWH0DU9B02h^;P0W9bL0:b/[034a<@0k>c/0
=3@d02/[:`0l?3`0E5AD051@D00m?Cd0>CTi034a<@0/;2`0:b/[02d];@0202l_;`0@03De=@0_;bl0
;Rh^02/[:`0_;bl0?Shn05QHF01OGel0F5QH0492@P0j>SX0@D5105EEE@1GEeL0H61P04e=C@80:b/[
01/09bLW02l_;`10@400EeMG051@D00U9BD0:RXZ02`/;00j>SX0G5aL06QXJ01mOGd0SHf=08J6QP1L
G5`0ATI603lo?`0f=SH0;bl_02h^;P0Z:RX0<C4a02TY:@0Z:RX09RHV02TY:@0S8b<00P0R8R805`0T
92@0:2PX02HV9P0_;bl0GemO07inOP2CTi<0NWYj06IVIP1YJFT0H61P05aLG01gMgL0UIFE0;Fe]@2^
[Zh0QXJ607MgM`2VYZH0WYjN0:NWY`2l_;`0][Jf0080];Bd01h0]KFe0;Jf]P2e]KD0^[Zj0;bl_031
`L40_[jn0;no_`2n_[h0^KVi0;Bd]02a/K40ZJVY0::RXP2TY:@0Vi^K09bLW02RXZ80Y:BT0:FUY@2X
Z:P0Zj^[0:b/[02`/;00]KFe0;Jf]P2c/k<0/K6a0:JVYP2RXZ8209^KV`040:2PX02UYJD0[:b/0:j^
[P80][Jf01P0]KFe0;^k^`2i^KT0^[Zj0<71`@35aLD0`l?30<C4a030`<00`/;20<O7a`39bLT0b<S8
0<K6aP38b<P0alO70<G5a@39bLT0a/K60<O7a`35aLD0bLW90<O7a`38b<P20<k>cP0e0<c<c03=cLd0
b<S80<W9b@37alL0`L710;Rh^02^[Zh0X:2P08R8R01fMWH0Jf][05YJFP1FEUH0EEEE0451@@0d=3@0
:BTY02h^;P0/;2`0:BTY02XZ:P14A4@0F5QH05ADE01ADE40@D51055AD@27QhL0VYZJ08R8R02;Rh/0
YZJV09NGU`2MWId0W9bL08V9R@1IFET0>CTi034a<@0g=cL0>c/k03@d=00f=SH0;Bd]02`/;00Z:RX0
<30`02`/;00[:b/0<c<c034a<@0_;bl00P0j>SX06`0i>CT0>SXj03@d=00j>SX0>3Ph03Hf=P0l?3`0
>SXj03dm?@12@T80ATI603`l?00j>SX0@d=303Ti>@0f=SH0<c<c02d];@0d=3@0<30`02d];@0/;2`0
:2PX02l_;`0f=SH0;Rh^03@d=00202l_;`0_02`/;00[:b/0<C4a03Hf=P0j>SX0@d=305]KF`1[Jf/0
Ogmo08Z:RP2;Rh/0SXj>08R8R029RHT0NGUi07moO`21PH40R8R8096AT@2GUiL0VIVI09^KV`2IVIT0
UYJF09FEU@2LW9`0WinO0:2PX02UYJD0Xj>S0:BTY02UYJD0YjNW0:>SX`2RXZ80Y:BT0:NWY`2XZ:P0
YZJV0:FUY@2SXj<0XJ6Q0:>SX`2UYJD0XZ:R09fMW@2QXJ400`2OWil01@2RXZ80WIfM0::RXP2TY:@0
WYjN0080Xj>S00@0YJFU0:>SX`2QXJ40XJ6Q0P2SXj<00`2RXZ80X:2P0:6QX@020::RXP0909jNWP2P
X:00X:2P0:>SX`2QXJ40X:2P09bLW02PX:00WYjN00@0WinO00H0W9bL09fMW@2NWYh0XJ6Q0:2PX02N
WYh209bLW00309VIV@2LW9`0Vi^K0080VIVI0P2JVYX00`2GUiL0UIFE09BDU00>0<SPf0003038h=P2
06][J`0Q06a/K01WIfL0J6QX06ATI01]KFd0K6a/06i^KP1ZJVX0K6a/071`L01TI6@0J6QX06IVIP1U
IFD0IfMW05mOG`1UIFD0I6AT061PH01KFe/0GemO05]KF`1HF5P0GEeM06EUI@1]KFd0OGem07moO`21
PH40SHf=096AT@2HV9P0Vi^K0080Xj>S00D0Z:RX0:NWY`2WYjL0ZZZZ0:^[Z`020:b/[0030:n_[`2]
[Jd0[Jf]0080/;2`02X0[jn_0:f][@2][Jd0[jn_0:j^[P2][Jd0Zj^[0:6QX@2RXZ80Vi^K09RHV02B
TY80RXZ:07emO@1eMGD0Jf][05]KF`1BDU80Cdm?04Q8B019BDT0Bd];04U9B@1:BTX0FEUI05MGE`1D
E5@0GemO061PH01LG5`0GUiN05eMG@1TI6@0Hf=S06ATI01UIFD0H61P06=SH`1WIfL0I6AT06IVIP1Y
JFT206=SH`0<069RHP1SHf<0HV9R06QXJ01QHF40IVIV069RHP1TI6@0JVYZ06=SH`1TI6@0Hf=S0P1V
IVH0201YJFT0J6QX06UYJ@1WIfL0K6a/06YZJP1_Kfl0KVi^0P1dM7@207IfMP05079bLP1aLG40LG5a
06i^KP1_Kfl00P1XJ6P00`1_Kfl0HV9R05iNGP0205QHF00F05]KF`21PH40bl_;0=WIf@3GemL0fm_K
0=GEe@3?cll0f=SH0=_Kf`3:b/X0[jn_08Z:RP1dM7@0IFEU069RHP1_Kfl0MWIf07YjNP1lO7`0MWIf
07AdM080N7Qh01/0NGUi07YjNP1mOGd0NWYj07emO@1^KVh0JFUY06ATI01aLG40Lg=c0820P02:RXX0
QhN708B4Q02:RXX0S8b<08:2PP24Q8@0R8R807IfMP1eMGD0MWIf07]kN`21PH40MWIf05eMG@13@d<0
0P0e=CD07`0m?Cd0>CTi02h^;P0[:b/0>3Ph04i>CP1OGel0BTY:03Hf=P0d=3@0:b/[02d];@0c<c<0
<C4a02TY:@0a<C40;bl_038b<P0c<c<0>CTi04Y:BP1RHV80FEUI04Y:BP0n?Sh0ADE504M7A`1BDU80
E5AD065QH@0k>c/00P0[:b/03`0_;bl0=SHf04Q8B01FEUH0@D5102LW9`0X:2P0;Rh^04M7A`1fMWH0
MGEe07inOP21PH40HV9R03Ti>@0202XZ:P0;02d];@0_;bl0;Rh^030`<00a<C40=3@d02/[:`0_;bl0
;2`/02h^;P0S8b<00P0R8R809@0T92@09RHV02TY:@0g=cL0GemO07IfMP1lO7`0K6a/07EeM@1LG5`0
CTi>05]KF`1gMgL0Ti>C0:>SX`2;Rh/0NWYj0;6a/@2HV9P0Ti>C0;Vi^@2e]KD0/k>c0;Jf]P2d];@0
^;Rh0;Jf]P2h^;P0^[Zj0;bl_02k^k/0_Kfm0;^k^`2f][H0]KFe0;>c/`2ZZZX00P2UYJD03`2QXJ40
X:2P0:6QX@2PX:00YZJV0:BTY02VYZH0Zj^[0:b/[02c/k<0^KVi0;Bd]02_[jl0[:b/0:NWY`0209VI
V@0809bLW02SXj<0WYjN0:FUY@2^[Zh0]KFe0;Vi^@2j^[X20;fm_@0S0<;2`P34a<@0a<C40<O7a`34
a<@0alO70<S8b03<c<`0b/[:0<K6aP3:b/X0alO70<S8b035aLD0_kno0<?3``38b<P0alO70<K6aP3<
c<`0bLW90<_;b`38b<P0c<c<0<G5a@34a<@0a/K60;jn_P2g]kL0Z:RX09jNWP26QXH0M7Ad06QXJ01L
G5`00P1CDe<09P13@d<0;bl_030`<00b<S80<30`02`/;00f=SH0CDe=05=CD`1?Cdl0B4Q804U9B@1M
GEd0T92@096AT@26QXH0RHV909fMW@2FUYH0VIVI09jNWP23Ph<0H61P04M7A`0];Bd0>SXj03De=@0]
;Bd0;Rh^03Hf=P0`<300<S8b02h^;P0d=3@0<30`02`/;00_;bl0<C4a0`0d=3@00`0c<c<0=SHf03`l
?00203hn?P0F03Ti>@0l?3`0?3`l04Q8B012@T80@D5103hn?P0o?cl0?Shn03Hf=P0d=3@0<30`02/[
:`0_;bl09bLW03<c<`0b<S80:2PX030`<00];Bd0=cLg03<c<`80<C4a03D0:2PX02d];@0d=3@0>3Ph
03Xj>P1IFET0JVYZ07QhN025QHD0T92@08n?S`28R8P0PX:207moO`1lO7`0OGem08F5Q@2<S8`0UIFE
09^KV`2LW9`0VIVI09nOW`2QXJ40W9bL0::RXP2VYZH0Xj>S0:JVYP2XZ:P0YJFU0:NWY`2TY:@0YJFU
0:NWY`2TY:@0YjNW0:>SX`2WYjL0Y:BT0:JVYP2QXJ40X:2P0:>SX`2QXJ40XZ:R0:6QX@2PX:00Y:BT
0:JVYP2TY:@0X:2P0::RXP030:BTY0050:>SX`2PX:00YJFU0:>SX`2VYZH00P2PX:001@2RXZ80WinO
0:2PX02PX:00WinO0080X:2P00H0XJ6Q09nOW`2QXJ40WYjN09^KV`2OWil309fMW@0809jNWP2OWil0
WYjN09^KV`2MWId0WYjN0:6QX@2PX:0209bLW080Vi^K0P2LW9`01@2KVi/0VYZJ09^KV`2IVIT0U9BD
00h0b>3H000<0<SPf080JVYZ01H0I6AT06YZJP1VIVH0IfMW06QXJ01/K6`0Jf][06UYJ@1^KVh0JFUY
06a/K01VIVH0HF5Q069RHP1TI6@0HV9R06=SH`1OGel0GEeM05aLG01HF5P0FEUI0P1LG5`03@1YJFT0
LW9b07EeM@1oOgl0Q8B4092@T02BTY80UYJF09bLW02OWil0XJ6Q0:JVYP2/[:`00P2[Zj/0102][Jd0
[Zj^0:j^[P2][Jd20:j^[P090;:b/P2^[Zh0/K6a0:^[Z`2][Jd0[Zj^0:b/[02`/;00Zj^[0080WYjN
00d0WIfM09NGU`2ATI40S8b<0861P@1gMgL0KFe]05iNGP1ADE40CTi>04Q8B017AdL0@D510080Cdm?
00P0DU9B05QHF01GEeL0GEeM05iNGP1LG5`0Fe]K05eMG@80Hf=S00@0HV9R06ATI01TI6@0Hf=S0P1R
HV804@1VIVH0I6AT069RHP1YJFT0Hf=S06MWI`1RHV80I6AT065QH@1SHf<0IFEU06ATI01RHV80H61P
06=SH`1NGUh0HF5Q0080I6AT0140J6QX06IVIP1ZJVX0JVYZ071`L01dM7@0KFe]075aL@1`L700LG5a
06m_K`1fMWH0L71`06e]K@1[Jf/0J6QX06][J`0206MWI`0I06=SH`1MGEd0F5QH05QHF01IFET0O7al
0<o?c`3Jf]X0fMWI0=[JfP3AdM40emOG0=SHf03GemL0c<c<0;bl_02UYJD0MWIf06UYJ@1UIFD0JVYZ
07IfMP1lO7`0P82007emO@0207AdM00807UiN@1cLg<0MWIf07alO01kNg/0Ogmo07EeM@1aLG4206MW
I`0706IVIP1hN7P0R8R808J6QP2:RXX0S8b<08R8R0020861P@0H08R8R01oOgl0PH6108B4Q01mOGd0
NGUi06e]K@1NGUh0EUIF04=3@`1:BTX0De=C04A4A00c<c<0<C4a038b<P19BDT0IVIV05UIF@19BDT0
@D5102h^;P0c<c<0=3@d0P0Z:RX0400`<300:b/[02l_;`0d=3@0<c<c04I6AP1QHF40Bd];03/k>`15
ADD0A4A405QHF01EEED0Fe]K05UIF@15ADD202TY:@0G02d];@0g=cL0B4Q8051@D00f=SH08R8R02l_
;`0k>c/0FUYJ07IfMP25QHD0O7al06m_K`1;Bd/0:RXZ02/[:`0/;2`0<30`02h^;P0c<c<0>SXj034a
<@0[:b/00`0Y:BT01@0/;2`0;Bd]02PX:00Z:RX08b<S008092@T00L09bLW03Hf=P1LG5`0JFUY06i^
KP1jNWX0Jf][0080Cdm?01H0GemO06m_K`29RHT0PX:207emO@2a/K40UiNG08F5Q@2c/k<0]kNg0;Bd
]02g]kL0/K6a0;Jf]P2b/[80][Jf0;^k^`2f][H0^k^k0;fm_@2k^k/0^;Rh0P2d];@0202_[jl0ZJVY
0:NWY`2QXJ40XZ:R0:>SX`2UYJD0YjNW0P2VYZH00`2UYJD0Zj^[0;6a/@020;Jf]P030;2`/02/[:`0
Zj^[0080Xj>S00P0VYZJ09fMW@2UYJD0YjNW0:VYZ@2WYjL0[jn_0;Vi^@80_Kfm00T0`L710<C4a033
`l<0a/K60<30`035aLD0b/[:0<g=c@3;bl/00P37alL02P33`l<0a<C40<?3``33`l<0a<C40<K6aP35
aLD0bLW90<k>cP3;bl/20<G5a@0_0<S8b033`l<0`L710<30`02j^[X0[Zj^0:RXZ02NWYh0Q8B407Ui
N@1UIFD0GemO055AD@19BDT0?3`l03Lg=`0^;Rh0<30`02/[:`0b<S80CTi>05mOG`1EEED0Bd];05AD
E017AdL0L71`08Z:RP25QHD0Ogmo08:2PP2CTi<0VIVI09BDU02HV9P0QhN7075aL@1ADE40=CDe03@d
=00/;2`0;Rh^02d];@0[:b/0;bl_02`/;00^;Rh00P0`<3000`0_;bl0<C4a02l_;`0303<c<`0903De
=@0l?3`0=cLg03De=@15ADD0<S8b03Hf=P0h>3P0>SXj0080?3`l0180>SXj03@d=00k>c/0?Cdm034a
<@0];Bd0<S8b02h^;P0[:b/0<30`02/[:`0Z:RX0;Bd]030`<00e=CD0>3Ph03<c<`0f=SH202/[:`0B
034a<@0^;Rh0>3Ph05=CD`1QHF40M7Ad08F5Q@29RHT0S8b<08V9R@22PX80QHF508:2PP1nOWh0OGem
08V9R@2>SXh0UYJF0P2MWId0102PX:00Y:BT0::RXP2PX:020:BTY080YJFU00D0YjNW0:FUY@2SXj<0
Y:BT0:6QX@030:BTY0030:FUY@2VYZH0Y:BT0080XJ6Q0P2PX:00102QXJ40X:2P0:2PX02TY:@20:FU
Y@030:>SX`2OWil0Xj>S0080YjNW00<0YJFU0:>SX`2QXJ400P2RXZ801@2OWil0XZ:R0:>SX`2RXZ80
WYjN0080XJ6Q00/0WinO0:6QX@2PX:00WinO0:>SX`2PX:00WinO09jNWP2OWil0W9bL09nOW`020:2P
X00509jNWP2LW9`0WIfM09fMW@2PX:000P2MWId02P2NWYh0VIVI09^KV`2KVi/0VIVI09JFUP2GUiL0
UYJF09NGU`2FUYH>0<SPf0003038h=P306i^KP0506QXJ01/K6`0JVYZ06MWI`1[Jf/00P1UIFD03@1[
Jf/0JFUY06MWI`1YJFT0HV9R05mOG`1TI6@0HV9R061PH01TI6@0H61P05YJFP1IFET00P1LG5`02@1T
I6@0J6QX06i^KP1lO7`0OWin08J6QP2;Rh/0Shn?09NGU`0209fMW@060:2PX02ZZZX0[:b/0:^[Z`2a
/K40[jn_0P2[Zj/00`2/[:`0[jn_0:f][@050:n_[`0D0;6a/@2_[jl0[Zj^0:b/[02TY:@0X:2P09ZJ
VP2HV9P0SXj>08b<S024Q8@0MgMg06YZJP1NGUh0CTi>04Y:BP17AdL0ADE504i>CP1;Bd/2051@D007
05QHF01EEED0FEUI05eMG@1PH600FEUI05QHF002061PH00S065QH@1LG5`0H61P06ATI01RHV80GUiN
06EUI@1PH600HV9R06IVIP1SHf<0GemO069RHP1SHf<0H61P06=SH`1UIFD0GEeM05iNGP1OGel0GUiN
06=SH`1TI6@0IfMW06IVIP1UIFD0JFUY06e]K@1WIfL0JVYZ06a/K01aLG40L71`07=cL`1^KVh00P1a
LG400`1^KVh0LW9b06e]K@0206UYJ@0406EUI@1VIVH0HF5Q061PH080FUYJ05@0FEUI07alO03Bd]80
fMWI0=cLg03GemL0dm?C0=cLg03De=@0dm?C0<g=c@33`l<0^k^k08J6QP1bLW80KVi^06YZJP1dM7@0
NGUi0861P@1jNWX0O7al079bLP1aLG40NGUi07alO020P800O7al07inOP1jNWX0MGEe06QXJ01VIVH0
K6a/07EeM@1jNWX0OGem08V9R@2:RXX0RHV908Z:RP27QhL0QXJ608V9R@2:RXX0Ph>307inOP1gMgL0
JVYZ06IVIP1HF5P0Cdm?06MWI`1RHV80GEeM04i>CP16ATH0>c/k04A4A01GEeL0FUYJ04m?C`12@T80
<c<c03@d=00^;Rh0;bl_02d];@0^;Rh0:b/[034a<@0e=CD0?Cdm04Y:BP1EEED0DE5A04I6AP1EEED0
A4A404Q8B01EEED0H61P04a<C00m?Cd203Ph>00D02DU9@0h>3P0Bd];04m?C`0o?cl0:2PX02`/;01N
GUh0FEUI07]kN`20P800K6a/05iNGP0e=CD0:BTY02d];@0_;bl0<S8b02d];@0a<C42038b<P0N03@d
=00`<300;2`/02XZ:P0a<C40<c<c02/[:`0_;bl08B4Q02LW9`0/;2`09RHV03De=@0l?3`0De=C06m_
K`2:RXX0MWIf05IFEP19BDT0E5AD05eMG@1/K6`0IFEU07alO02a/K40VYZJ08J6QP2WYjL0_Kfm0P2g
]kL00`2_[jl0/k>c0;Ng]`020;Jf]P060;Ng]`2i^KT0_Kfm0;no_`2l_;`0^KVi0P2f][H0202][Jd0
[:b/0:BTY02RXZ80X:2P0:VYZ@2XZ:P0ZJVY0P2^[Zh01`2`/;00/k>c0;6a/@2h^;P0/;2`0:j^[P2a
/K400P2[Zj/209fMW@030:ZZZP2][Jd0Z:RX0080YZJV00@0Zj^[0;Bd]02k^k/0`L710P35aLD02034
a<@0`L710<C4a038b<P0b/[:0<S8b033`l<0a<C40P35aLD00`32`/80`l?30<O7a`020<K6aP030<?3
``38b<P0b<S80080a/K603@0aLG50<O7a`37alL0_[jn0;Rh^02][Jd0YjNW09ZJVP27QhL0LW9b069R
HP1IFET0D51@04a<C016ATH0>3Ph030`<00];Bd09bLW03De=@1/K6`0HV9R05EEE@18B4P0EeMG04a<
C026QXH0PX:208Z:RP26QXH0SHf=096AT@2HV9P0UiNG09:BTP27QhL0O7al05eMG@0m?Cd0<c<c02`/
;00c<c<09RHV02`/;00Z:RX0:BTY02XZ:P0^;Rh0;2`/03<c<`0^;Rh0<S8b0P0^;Rh01@0`<300?Shn
03Ti>@0f=SH0=cLg0080>c/k00T0>SXj03Ti>@0k>c/0<c<c03Xj>P12@T80>3Ph03Ti>@0g=cL00P0b
<S809P0d=3@0ADE502h^;P0_;bl0:2PX02d];@0X:2P0:RXZ030`<00b<S80>CTi03<c<`0a<C40;Bd]
030`<00_;bl0>SXj04];B`1GEeL0KFe]07alO026QXH0S8b<08j>SP27QhL0PX:207alO01gMgL0PH61
07inOP2<S8`0UiNG09fMW@2RXZ80WinO0:6QX@2RXZ80X:2P0P2UYJD20:BTY0070:>SX`2UYJD0YJFU
0::RXP2SXj<0Y:BT0:JVYP020:6QX@0?0::RXP2TY:@0XZ:R0:2PX02TY:@0XJ6Q0:>SX`2VYZH0XZ:R
0:FUY@2OWil0Xj>S0:6QX@2SXj<0XZ:R0080YjNW00T0YJFU0::RXP2PX:00Y:BT0:6QX@2SXj<0X:2P
0::RXP2QXJ400P2SXj<00`2RXZ80X:2P09nOW`0209jNWP040:2PX02QXJ40XJ6Q09nOW`80X:2P00@0
YZJV09jNWP2OWil0WinO0P2MWId02@2NWYh0WIfM09ZJVP2OWil0W9bL09fMW@2LW9`0VIVI09NGU`02
09JFUP0309FEU@2FUYH0UiNG00h0b>3H000<0<SPf080K6a/00D0JVYZ06MWI`1^KVh0JFUY06MWI`02
06YZJP0@06MWI`1XJ6P0Jf][06IVIP1UIFD0IVIV069RHP1PH600IVIV06ATI01PH600HV9R05aLG01K
Fe/0F5QH05MGE`80I6AT00/0KVi^07emO@1mOGd0RXZ:08b<S02ATI40UiNG09bLW02OWil0Xj>S0:NW
Y`020:ZZZP030:j^[P2/[:`0ZZZZ0080ZZZZ02P0[Zj^0:VYZ@2ZZZX0[jn_0;6a/@2][Jd0[:b/0;6a
/@2_[jl0[Zj^0:^[Z`2WYjL0WYjN09fMW@2GUiL0TI6A08N7Q`24Q8@0MWIf06UYJ@1JFUX0CTi>04e=
C@15ADD0@d=304U9B@1=CDd0D51@04e=C@1?Cdl0E5AD05EEE@1IFET0GEeM05YJFP1HF5P0FUYJ05aL
G01SHf<0I6AT0P1RHV80101PH600I6AT06EUI@1KFe/2069RHP0@06ATI01UIFD0H61P06MWI`1VIVH0
HF5Q06EUI@1SHf<0HV9R05mOG`1SHf<0HV9R06EUI@1YJFT0HV9R06QXJ080JVYZ00T0Hf=S06MWI`1^
KVh0Lg=c071`L01cLg<0LG5a079bLP1_Kfl00P1]KFd01P1[Jf/0KFe]06e]K@1/K6`0HV9R061PH0<0
Fe]K0140EUIF0820P03Cdm<0g=cL0=_Kf`3Bd]80e]KF0=[JfP3>c/h0clo?0<K6aP32`/80^k^k0:>S
X`25QHD0MgMg075aL@0207IfMP0:07emO@1gMgL0O7al07MgM`1eMGD0LW9b07QhN01eMGD0OGem0820
P080NWYj02l0M7Ad075aL@1dM7@0LG5a07AdM01hN7P0PH6108B4Q02>SXh0T92@08J6QP28R8P0QXJ6
08B4Q020P800OWin07alO01fMWH0Kfm_05aLG01KFe/0O7al075aL@1ZJVX0FEUI05EEE@1CDe<0BDU9
04Y:BP1ADE40CDe=04a<C00m?Cd0?Shn03/k>`0b<S80<30`02TY:@0Z:RX0>3Ph03Xj>P18B4P0CDe=
04Q8B01>CTh0@d=30451@@0204E5A@0405EEE@1ADE40AdM703hn?P80>c/k01H09bLW03Hf=P1<C4`0
DE5A03Ph>00V9RH0=SHf075aL@1KFe/0NGUi07QhN01OGel0F5QH038b<P0X:2P0;2`/02/[:`0_;bl0
>SXj02l_;`0/;2`0;Bd]0P0`<3009`0f=SH0<C4a030`<00j>SX0;bl_02TY:@0Z:RX0;2`/02TY:@0W
9bL0:BTY02`/;011@D40GemO06a/K024Q8@0Jf][05QHF01EEED0FEUI065QH@1?Cdl0LW9b0:NWY`2Q
XJ40Ph>309fMW@2f][H0/;2`0:j^[P2YZJT0/K6a0;Ng]`2a/K40/;2`0;>c/`2e]KD0]kNg0;^k^`02
0;bl_0030;Ng]`2b/[80Zj^[0080[Jf]00L0YJFU0:>SX`2VYZH0Zj^[0:b/[02_[jl0[:b/0080/k>c
00D0[jn_0;:b/P2d];@0/k>c0;2`/0020:VYZ@0=0:NWY`2PX:00[jn_0;>c/`2/[:`0[Jf]0:ZZZP2R
XZ80Z:RX0;6a/@2l_;`0_Kfm0<71`@020<?3``080<;2`P35aLD0bLW90<O7a`30`<00a<C40<K6aP37
alL20<C4a0040<S8b036a/H0a<C40<;2`P80a/K602<0alO70<S8b034a<@0bLW90<S8b02m_Kd0]KFe
0;2`/02OWil0T92@08B4Q01ZJVX0G5aL069RHP1>CTh0DE5A03lo?`0h>3P0<30`02PX:00`<300EeMG
06YZJP1RHV80BTY:04m?C`1=CDd0IfMW08V9R@1oOgl0Rh^;08F5Q@2IVIT0U9BD09bLW00209NGU`0A
08:2PP1fMWH0H61P03/k>`0^;Rh0;Bd]02h^;P0V9RH0;2`/02PX:00V9RH0:2PX02/[:`0/;2`0;Bd]
02l_;`0];Bd00P0a<C40500j>SX0>3Ph03Ti>@0g=cL0>3Ph03Hf=P0e=CD0>3Ph03`l?00g=cL0>CTi
04U9B@0k>c/0@D5103Xj>P0d=3@0<C4a02d];@0_;bl0<c<c0P0];Bd0100Z:RX0:b/[02XZ:P0V9RH2
02h^;P0=03Ph>00a<C40<S8b02h^;P0e=CD0=cLg03De=@18B4P0BDU9069RHP1dM7@0N7Qh08J6QP02
08R8R00P07moO`1nOWh0Ogmo07YjNP1mOGd0Rh^;09>CT`2JVYX0X:2P09fMW@2RXZ80YJFU0:6QX@2U
YJD0ZJVY0:BTY02VYZH0Y:BT0:JVYP2UYJD0Xj>S0:RXZ02WYjL0ZJVY0:BTY02RXZ80YJFU09nOW`2S
Xj<0XZ:R0:FUY@2QXJ420:BTY0050:>SX`2QXJ40YJFU0:6QX@2VYZH00P2PX:020:>SX`0?09nOW`2R
XZ80XZ:R0:6QX@2RXZ80Y:BT09bLW02OWil0XJ6Q0:>SX`2RXZ80XJ6Q09jNWP2SXj<0XJ6Q0080WYjN
00h0XJ6Q0:BTY02PX:00WinO09jNWP2PX:00WIfM0:2PX02OWil0XZ:R09bLW02OWil0WIfM0:2PX080
WIfM00T0WinO09ZJVP2GUiL0WIfM09VIV@2GUiL0VIVI09RHV02GUiL03P38h=P000`0b>3H0`1ZJVX0
2P1/K6`0J6QX06UYJ@1ZJVX0JFUY06a/K01XJ6P0IFEU06][J`1ZJVX206ATI00J06IVIP1TI6@0IVIV
06ATI01UIFD0HF5Q05eMG@1KFe/0FUYJ05EEE@1RHV80J6QX06i^KP1dM7@0OGem08F5Q@2=SHd0U9BD
09FEU@2GUiL0WYjN0:>SX`2[Zj/0Z:RX0:VYZ@2ZZZX30:b/[0030:^[Z`2/[:`0ZZZZ0080[:b/00<0
[jn_0;2`/02][Jd00P2/[:`05@2^[Zh0YjNW0:JVYP2QXJ40Vi^K09RHV02;Rh/0QHF508:2PP1fMWH0
KFe]05eMG@1@D500C4a<04A4A016ATH0Bd];04m?C`1DE5@0BTY:051@D00205ADE00=05eMG@1PH600
GUiN05mOG`1LG5`0HV9R065QH@1VIVH0I6AT06IVIP1RHV80Hf=S06MWI`0206IVIP0306=SH`1VIVH0
H61P00<0H61P0P1QHF402@1TI6@0HV9R05iNGP1SHf<0I6AT06UYJ@1UIFD0IVIV06MWI`0206YZJP04
06MWI`1XJ6P0KFe]06i^KP80M7Ad00L0Kfm_06a/K01_Kfl0K6a/071`L01[Jf/0Kfm_0080J6QX00<0
I6AT061PH01FEUH00P1FEUH0601JFUX0Ogmo0=?Cd`3Lg=`0e]KF0=CDe03IfMT0e]KF0<O7a`3;bl/0
a<C40<W9b@2o_kl0]KFe09^KV`26QXH0MWIf07]kN`21PH40OGem07YjNP1oOgl0PH6107UiN@80Jf][
00h0KVi^07YjNP1kNg/0NGUi07inOP1iNGT0MgMg07UiN@1aLG40JVYZ07EeM@24Q8@0O7al0861P@80
Rh^;00h0Shn?0861P@22PX80OWin07moO`24Q8@0P82007IfMP1SHf<0Fe]K07QhN01fMWH0M7Ad06a/
K080Hf=S00X0EEEE04=3@`1?Cdl0AdM70410@00n?Sh0>c/k03Hf=P0h>3P0?Shn0P0^;Rh03P0f=SH0
?Cdm05MGE`1TI6@0ADE505=CD`15ADD0A4A404Q8B01=CDd0DU9B0451@@0g=cL0?Shn0P0e=CD08P0c
<c<0>SXj04M7A`1EEED0>c/k02LW9`0d=3@0IVIV06][J`1_Kfl0IVIV05QHF01:BTX0:2PX02LW9`0X
:2P0;Bd]02l_;`0d=3@0;bl_038b<P0_;bl0<c<c030`<00_;bl0;Bd]03De=@0l?3`0<c<c02/[:`0]
;Bd0;bl_02`/;00];Bd202XZ:P0603lo?`1NGUh0FEUI06MWI`1hN7P0IVIV0P1FEUH0:01NGUh0@410
05aLG026QXH0SHf=0861P@2=SHd0XJ6Q09nOW`2UYJD0YZJV0:f][@2a/K40[Zj^0;Bd]02a/K40/;2`
0;Fe]@2g]kL0^;Rh0;Zj^P2d];@0]kNg0;6a/@2XZ:P0ZJVY0:b/[02^[Zh0Y:BT0:JVYP2YZJT0[Jf]
0;2`/02/[:`0[Zj^0;6a/@2d];@0/;2`0;>c/`2e]KD30;2`/00E0:VYZ@2[Zj/0/K6a0;2`/02a/K40
[Zj^0:^[Z`2UYJD0XJ6Q0:j^[P2k^k/0_kno0;jn_P2l_;`0`L710<K6aP38b<P0bLW90<71`@37alL0
`l?30080aLG500P0`l?30<O7a`37alL0alO70<S8b037alL0aLG50<?3``80b/[:03<0b<S80<?3``30
`<00^[Zj0:n_[`2KVi/0S8b<07UiN@1TI6@0GUiN06IVIP1FEUH0?clo03`l?00m?Cd0;2`/02DU9@0m
?Cd0JFUY05IFEP1LG5`0CTi>04=3@`11@D40LW9b08J6QP23Ph<0Q8B408R8R02GUiL0UYJF09nOW`2I
VIT0TY:B08:2PP1eMGD0J6QX04Y:BP0d=3@0<c<c034a<@0Z:RX09bLW02TY:@0X:2P09bLW02PX:00_
;bl0<30`02h^;P0c<c<00P0h>3P07@0m?Cd0?Shn03Ti>@0h>3P0=SHf03De=@0f=SH0>c/k03`l?012
@T80?3`l03Ti>@0o?cl0>CTi04A4A010@400=SHf03@d=00`<300=SHf02XZ:P0c<c<08b<S02PX:00^
;Rh0;2`/02h^;P0_;bl0=cLg0080<S8b01L0<30`02d];@0h>3P0=SHf03hn?P17AdL0FUYJ06i^KP1o
Ogl0Q8B408Z:RP24Q8@0Ogmo08>3P`1kNg/0MWIf07moO`25QHD0SHf=09FEU@2IVIT0X:2P0::RXP02
0:JVYP0L0:RXZ02UYJD0ZJVY0:JVYP2XZ:P0YJFU0:BTY02VYZH0YjNW0:JVYP2SXj<0YZJV0::RXP2P
X:00YjNW0:FUY@2TY:@0Xj>S0:FUY@2QXJ40Y:BT0::RXP2WYjL0XZ:R0:JVYP2UYJD0YZJV0:>SX`80
Y:BT0P2QXJ40402SXj<0X:2P0::RXP2RXZ80WIfM0:2PX02OWil0X:2P0:6QX@2NWYh0Xj>S0:BTY02S
Xj<0X:2P09jNWP2OWil20:2PX00509ZJVP2KVi/0WinO09^KV`2NWYh00`2MWId03P2PX:00W9bL09fM
W@2JVYX0UiNG09VIV@2MWId0VIVI09JFUP2JVYX0WYjN09ZJVP2HV9P0UIFE3P38h=P000`0b>3H0P1Y
JFT0:01aLG40L71`06m_K`1ZJVX0Jf][06MWI`1XJ6P0JVYZ06a/K01YJFT0IVIV06MWI`1PH600IVIV
06QXJ01VIVH0H61P06IVIP1QHF40G5aL05]KF`1PH600FUYJ05eMG@1VIVH0LG5a07QhN022PX80Ph>3
08b<S02EUID0V9RH09ZJVP2NWYh0YZJV0:RXZ02[Zj/0ZJVY0:^[Z`2a/K420:j^[P0J0;:b/P2][Jd0
[:b/0:^[Z`2/[:`0[Zj^0;6a/@2`/;00Zj^[0:f][@2[Zj/0ZZZZ0:RXZ02PX:00WIfM09BDU02=SHd0
Rh^;0861P@1gMgL0K6a/065QH@1BDU80BDU904=3@`11@D4204U9B@0@059BDP1?Cdl0FEUI05QHF01C
De<0G5aL05YJFP1FEUH0EeMG05eMG@1OGel0IFEU061PH01QHF40IFEU069RHP80H61P00@0HF5Q05iN
GP1QHF40IFEU0P1OGel02@1LG5`0GUiN069RHP1OGel0HF5Q069RHP1PH600Hf=S069RHP0206EUI@0:
06ATI01UIFD0JFUY06MWI`1ZJVX0Jf][06UYJ@1/K6`0LW9b06][J`80Lg=c00X0NGUi06YZJP1gMgL0
Jf][06m_K`1ZJVX0IfMW06=SH`1OGel0EUIF0P1HF5P01@1MGEd0Ph>30=3@d03De=@0dm?C0080fMWI
00d0cLg=0<W9b@34a<@0bLW90<_;b`2m_Kd0Zj^[0;Jf]P2BTY80P82007QhN01kNg/0OWin0080O7al
03h0Ogmo079bLP1PH600GUiN06MWI`1dM7@0Lg=c07]kN`23Ph<0O7al0820P01kNg/0MGEe07IfMP1d
M7@0OGem07=cL`1`L700OWin08N7Q`2=SHd0RHV908>3P`24Q8@0RHV90820P01mOGd0LG5a05eMG@1>
CTh0NGUi08B4Q025QHD0OGem07QhN01bLW80F5QH0410@00o?cl0@T9203hn?P18B4P0ATI603`l?00h
>3P0>CTi03Lg=`0j>SX0>3Ph0410@01HF5P0HF5Q04m?C`1DE5@0D51@04A4A013@d<0?Cdm04E5A@0b
<S80;bl_03Hf=P80=CDe00d0=3@d03lo?`14A4@0Cdm?0492@P0d=3@0?clo05mOG`1VIVH0GEeM05QH
F01OGel0Bd];0080<S8b00@0=CDe02h^;P0^;Rh0;Bd]0`0`<300500^;Rh0<C4a03De=@0a<C40=cLg
03<c<`0^;Rh0<C4a02TY:@0a<C40<S8b02HV9P0Z:RX0:BTY03<c<`1?Cdl0ATI6055AD@1YJFT0K6a/
0P1CDe<04P1IFET0>3Ph04a<C01WIfL0Jf][07EeM@1iNGT0RXZ:08f=S@2EUID0WIfM0:BTY02[Zj/0
]KFe0;Ng]`2b/[80[Zj^0:^[Z`80/k>c00h0][Jf0;:b/P2g]kL0/k>c0:n_[`2ZZZX0ZJVY0;6a/@2Z
ZZX0Z:RX0:BTY02ZZZX0];Bd0;6a/@80[:b/00@0[jn_0:b/[02][Jd0]KFe0P2a/K401@2d];@0/K6a
0:b/[02b/[80ZZZZ00<0/;2`0180[:b/0:>SX`2XZ:P0ZZZZ0;Zj^P2o_kl0a<C40<G5a@37alL0b<S8
0<G5a@30`<00`l?30<;2`P34a<@0`/;20<30`034a<@30<G5a@040<?3``37alL0a/K60<K6aP80b<S8
00X0aLG50<30`02h^;P0Zj^[09ZJVP27QhL0M7Ad06IVIP1RHV80GEeM0P1:BTX02`18B4P0>3Ph02TY
:@0n?Sh0KVi^05YJFP1MGEd0E5AD055AD@0f=SH0GemO0080Q8B40140PX:208J6QP2@T900TI6A09^K
V`2JVYX0Ti>C08^;R`1nOWh0LW9b06UYJ@1DE5@0>3Ph038b<P0Y:BT092@T02PX:00202`/;00602TY
:@0X:2P0;2`/02/[:`0`<300;Bd]0P0e=CD0200g=cL0>c/k03Lg=`0h>3P0=3@d03Ph>00e=CD0>SXj
0P0m?Cd05P0o?cl0>3Ph03Ph>00f=SH0>c/k03De=@0c<c<0<30`02h^;P0e=CD0;bl_02h^;P0Z:RX0
9BDU02TY:@0`<300<C4a03@d=00i>CT0<S8b03<c<`0b<S82030`<00I03hn?P12@T80@d=304m?C`1R
HV80N7Qh08B4Q02;Rh/0RHV908>3P`25QHD0NWYj07MgM`1fMWH0PX:208b<S02BTY80VYZJ0:6QX@2V
YZH0YJFU0:NWY`2VYZH0Y:BT0:FUY@020:RXZ0030:FUY@2VYZH0YZJV0080Y:BT00<0YZJV0:NWY`2/
[:`00P2RXZ830:BTY080Xj>S00P0Y:BT0:FUY@2XZ:P0YJFU0:2PX02SXj<0XZ:R0:2PX080Y:BT00D0
X:2P0:>SX`2QXJ40Xj>S0:2PX0020:6QX@80X:2P00@0Y:BT0:2PX02SXj<0XZ:R0P2PX:002P2OWil0
WIfM09nOW`2NWYh0XJ6Q09nOW`2NWYh0WinO09ZJVP2MWId209jNWP0:09fMW@2KVi/0W9bL09^KV`2J
VYX0WIfM09RHV02LW9`0WYjN09FEU@80VIVI00<0V9RH09^KV`2GUiL03P38h=P000`0b>3H0P1YJFT0
:01aLG40L71`06m_K`1ZJVX0Jf][06MWI`1XJ6P0JVYZ06a/K01YJFT0IVIV06MWI`1PH600IVIV06QX
J01VIVH0H61P06IVIP1QHF40G5aL05]KF`1PH600FUYJ05eMG@1VIVH0LG5a07QhN022PX80Ph>308b<
S02EUID0V9RH09ZJVP2NWYh0YZJV0:RXZ02[Zj/0ZJVY0:^[Z`2a/K420:j^[P0J0;:b/P2][Jd0[:b/
0:^[Z`2/[:`0[Zj^0;6a/@2`/;00Zj^[0:f][@2[Zj/0ZZZZ0:RXZ02PX:00WIfM09BDU02=SHd0Rh^;
0861P@1gMgL0K6a/065QH@1BDU80BDU904=3@`11@D4204U9B@0@059BDP1?Cdl0FEUI05QHF01CDe<0
G5aL05YJFP1FEUH0EeMG05eMG@1OGel0IFEU061PH01QHF40IFEU069RHP80H61P00@0HF5Q05iNGP1Q
HF40IFEU0P1OGel02@1LG5`0GUiN069RHP1OGel0HF5Q069RHP1PH600Hf=S069RHP0206EUI@0:06AT
I01UIFD0JFUY06MWI`1ZJVX0Jf][06UYJ@1/K6`0LW9b06][J`80Lg=c00X0NGUi06YZJP1gMgL0Jf][
06m_K`1ZJVX0IfMW06=SH`1OGel0EUIF0P1HF5P01@1MGEd0Ph>30=3@d03De=@0dm?C0080fMWI00d0
cLg=0<W9b@34a<@0bLW90<_;b`2m_Kd0Zj^[0;Jf]P2BTY80P82007QhN01kNg/0OWin0080O7al03h0
Ogmo079bLP1PH600GUiN06MWI`1dM7@0Lg=c07]kN`23Ph<0O7al0820P01kNg/0MGEe07IfMP1dM7@0
OGem07=cL`1`L700OWin08N7Q`2=SHd0RHV908>3P`24Q8@0RHV90820P01mOGd0LG5a05eMG@1>CTh0
NGUi08B4Q025QHD0OGem07QhN01bLW80F5QH0410@00o?cl0@T9203hn?P18B4P0ATI603`l?00h>3P0
>CTi03Lg=`0j>SX0>3Ph0410@01HF5P0HF5Q04m?C`1DE5@0D51@04A4A013@d<0?Cdm04E5A@0b<S80
;bl_03Hf=P80=CDe00d0=3@d03lo?`14A4@0Cdm?0492@P0d=3@0?clo05mOG`1VIVH0GEeM05QHF01O
Gel0Bd];0080<S8b00@0=CDe02h^;P0^;Rh0;Bd]0`0`<300500^;Rh0<C4a03De=@0a<C40=cLg03<c
<`0^;Rh0<C4a02TY:@0a<C40<S8b02HV9P0Z:RX0:BTY03<c<`1?Cdl0ATI6055AD@1YJFT0K6a/0P1C
De<04P1IFET0>3Ph04a<C01WIfL0Jf][07EeM@1iNGT0RXZ:08f=S@2EUID0WIfM0:BTY02[Zj/0]KFe
0;Ng]`2b/[80[Zj^0:^[Z`80/k>c00h0][Jf0;:b/P2g]kL0/k>c0:n_[`2ZZZX0ZJVY0;6a/@2ZZZX0
Z:RX0:BTY02ZZZX0];Bd0;6a/@80[:b/00@0[jn_0:b/[02][Jd0]KFe0P2a/K401@2d];@0/K6a0:b/
[02b/[80ZZZZ00<0/;2`0180[:b/0:>SX`2XZ:P0ZZZZ0;Zj^P2o_kl0a<C40<G5a@37alL0b<S80<G5
a@30`<00`l?30<;2`P34a<@0`/;20<30`034a<@30<G5a@040<?3``37alL0a/K60<K6aP80b<S800X0
aLG50<30`02h^;P0Zj^[09ZJVP27QhL0M7Ad06IVIP1RHV80GEeM0P1:BTX02`18B4P0>3Ph02TY:@0n
?Sh0KVi^05YJFP1MGEd0E5AD055AD@0f=SH0GemO0080Q8B40140PX:208J6QP2@T900TI6A09^KV`2J
VYX0Ti>C08^;R`1nOWh0LW9b06UYJ@1DE5@0>3Ph038b<P0Y:BT092@T02PX:00202`/;00602TY:@0X
:2P0;2`/02/[:`0`<300;Bd]0P0e=CD0200g=cL0>c/k03Lg=`0h>3P0=3@d03Ph>00e=CD0>SXj0P0m
?Cd05P0o?cl0>3Ph03Ph>00f=SH0>c/k03De=@0c<c<0<30`02h^;P0e=CD0;bl_02h^;P0Z:RX09BDU
02TY:@0`<300<C4a03@d=00i>CT0<S8b03<c<`0b<S82030`<00I03hn?P12@T80@d=304m?C`1RHV80
N7Qh08B4Q02;Rh/0RHV908>3P`25QHD0NWYj07MgM`1fMWH0PX:208b<S02BTY80VYZJ0:6QX@2VYZH0
YJFU0:NWY`2VYZH0Y:BT0:FUY@020:RXZ0030:FUY@2VYZH0YZJV0080Y:BT00<0YZJV0:NWY`2/[:`0
0P2RXZ830:BTY080Xj>S00P0Y:BT0:FUY@2XZ:P0YJFU0:2PX02SXj<0XZ:R0:2PX080Y:BT00D0X:2P
0:>SX`2QXJ40Xj>S0:2PX0020:6QX@80X:2P00@0Y:BT0:2PX02SXj<0XZ:R0P2PX:002P2OWil0WIfM
09nOW`2NWYh0XJ6Q09nOW`2NWYh0WinO09ZJVP2MWId209jNWP0:09fMW@2KVi/0W9bL09^KV`2JVYX0
WIfM09RHV02LW9`0WYjN09FEU@80VIVI00<0V9RH09^KV`2GUiL03P38h=P000`0b>3H0P1/K6`02P1[
Jf/0JVYZ06a/K01/K6`0IVIV06YZJP1XJ6P0Jf][06a/K01WIfL206EUI@0306ATI01XJ6P0Hf=S0080
H61P0P1RHV8205aLG00C05iNGP1LG5`0Hf=S06YZJP1]KFd0MgMg08:2PP2:RXX0S8b<09FEU@2JVYX0
W9bL09nOW`2PX:00YjNW0:FUY@2[Zj/0[:b/0:f][@020:b/[0050:n_[`2/[:`0[Jf]0:^[Z`2^[Zh0
102_[jl09@2^[Zh0Zj^[0:NWY`2YZJT0WYjN09bLW02DU9@0TI6A08J6QP21PH40MgMg06e]K@1KFe/0
EEEE04i>CP16ATH0ADE504Q8B019BDT0CDe=051@D01ADE40C4a<05=CD`1HF5P0G5aL05YJFP1HF5P0
H61P069RHP1MGEd0H61P06=SH`1OGel0Hf=S05eMG@1QHF400P1OGel01P1TI6@0GemO05mOG`1MGEd0
HF5Q05iNGP80HV9R00@0IfMW06EUI@1RHV80HV9R0P1TI6@00`1UIFD0J6QX06IVIP0206QXJ00406i^
KP1/K6`0J6QX06m_K`80KFe]00X0M7Ad06e]K@1`L700JVYZ06][J`1SHf<0JVYZ069RHP1SHf<0I6AT
0P1OGel205IFEP0@05YJFP26QXH0clo?0=WIf@3Lg=`0gmoO0=3@d038b<P0c/k>0<K6aP38b<P0aLG5
0<30`02TY:@0/;2`08f=S@80O7al00h0MGEe07inOP1oOgl0P82007QhN01gMgL0IfMW06EUI@1YJFT0
L71`07=cL`1kNg/0P82007emO@80Q8B400h0Ogmo07inOP1bLW80LW9b06a/K01[Jf/0Lg=c07alO023
Ph<0R8R808V9R@21PH40QhN707inOP80NGUi0280GEeM05aLG01lO7`0SHf=08F5Q@26QXH0M7Ad06][
J`1HF5P0Cdm?04Q8B011@D40E5AD04M7A`0l?3`0>SXj03De=@0k>c/0AdM704Q8B010@400@T9205UI
F@1KFe/0HV9R05YJFP19BDT0BTY:04E5A@0h>3P0=SHf02l_;`0`<300;Bd]0P0a<C40500];Bd0>SXj
0451@@15ADD0@D5104I6AP10@400GemO061PH012@T80F5QH04i>CP13@d<0<C4a02/[:`0Z:RX0;bl_
03Hf=P0^;Rh0<C4a100^;Rh08@0_;bl0<C4a034a<@0e=CD0<C4a02l_;`0`<300;2`/02PX:00U9BD0
92@T02/[:`0j>SX0EUIF03`l?011@D40C4a<05]KF`1<C4`0GEeM05YJFP0g=cL0DU9B07YjNP1dM7@0
N7Qh07EeM@25QHD0S8b<09>CT`2@T900VIVI0:NWY`020;Fe]@80/[:b01L0ZZZZ0:j^[P2f][H0^;Rh
0;:b/P2f][H0]KFe0;:b/P2^[Zh0[:b/0:NWY`2^[Zh0YjNW0:RXZ02RXZ80[Zj^0;Fe]@2c/k<0ZJVY
0:^[Z`2_[jl0/K6a0;2`/0020:f][@070;>c/`2b/[80Zj^[0;2`/02][Jd0Zj^[0:j^[P020;6a/@80
Zj^[00<0[Zj^0:n_[`2c/k<00P2n_[h01`34a<@0b<S80<?3``2o_kl0`/;20<71`@32`/800P31`L40
1@34a<@0aLG50<G5a@34a<@0`l?30080a/K602/0aLG50<K6aP31`L40aLG50<71`@2f][H0[:b/09JF
UP25QHD0L71`069RHP1KFe/0Bd];0451@@1@D500?Shn02/[:`0l?3`0NGUi07YjNP1FEUH0HV9R05MG
E`15ADD0@41007]kN`2:RXX0QXJ608:2PP2;Rh/0TI6A08J6QP2GUiL0V9RH09BDU02:RXX0OGem07If
MP1[Jf/0Fe]K03Xj>P0W9bL092@T0080:RXZ0`0];Bd01@0U9BD0;2`/02`/;00_;bl0:b/[0080<c<c
01/0=SHf02l_;`0g=cL0=SHf03Lg=`0k>c/0>CTi03Xj>P0l?3`0>SXj03De=@0g=cL0=3@d03Lg=`0h
>3P0?Cdm03Hf=P0h>3P0<c<c02l_;`0Z:RX0;bl_02HV9P0X:2P0;2`/030`<00b<S800P0j>SX04`0f
=SH0>3Ph034a<@0`<300;bl_03Ti>@12@T80@D5104a<C01QHF40KVi^08>3P`24Q8@0RHV908F5Q@20
P800Ng]k07QhN01gMgL00P22PX800`2>SXh0VIVI09bLW0020:NWY`0>0:JVYP2XZ:P0Xj>S0:NWY`2X
Z:P0YZJV0:BTY02VYZH0YjNW0:BTY02UYJD0Xj>S0:FUY@2SXj<20:6QX@0=0:FUY@2TY:@0YZJV0:2P
X02TY:@0YJFU0:BTY02RXZ80YJFU0:BTY02QXJ40Xj>S09jNWP020:FUY@040:>SX`2VYZH0Xj>S0:2P
X080XZ:R00X0X:2P0::RXP2QXJ40YJFU0:2PX02SXj<0YJFU0:BTY02RXZ80XJ6Q0P2PX:002@2KVi/0
X:2P09fMW@2KVi/0XJ6Q09^KV`2PX:00WIfM09^KV`0209fMW@0=09jNWP2LW9`0W9bL09^KV`2HV9P0
W9bL09VIV@2HV9P0UYJF09NGU`2HV9P0VYZJ09JFUP0>0<SPf0003038h=P306e]K@0606i^KP1`L700
Jf][06e]K@1/K6`0IfMW0`1XJ6P02P1VIVH0JFUY06IVIP1YJFT0IVIV06EUI@1QHF40Hf=S069RHP1Q
HF4205eMG@80GUiN00d0JVYZ07=cL`1lO7`0PX:208N7Q`2BTY80Ti>C09ZJVP2OWil0XZ:R0:6QX@2Z
ZZX0Zj^[00D0[Zj^00X0[:b/0:f][@2YZJT0[:b/0;>c/`2_[jl0[Jf]0:n_[`2[Zj/0[Jf]0P2ZZZX0
902TY:@0W9bL09ZJVP2IVIT0T92@08V9R@1oOgl0M7Ad06UYJ@1QHF40DU9B04e=C@11@D40ATI604];
B`17AdL0DE5A05IFEP1EEED0E5AD05EEE@1JFUX0GEeM05QHF01KFe/0FUYJ05aLG01SHf<0GUiN05mO
G`1LG5`0I6AT069RHP1OGel0HF5Q05aLG080H61P01<0GEeM05mOG`1RHV80I6AT069RHP1SHf<0IFEU
069RHP1NGUh0I6AT069RHP1UIFD0HV9R06MWI`1YJFT0J6QX06IVIP1^KVh0JVYZ0080K6a/00H0Jf][
071`L01bLW80L71`06i^KP1_Kfl206][J`0606a/K01XJ6P0IVIV061PH01MGEd0FEUI0P1EEED04`1K
Fe/0Shn?0=GEe@3Ogml0h>3P0=KFeP39bLT0`l?30<K6aP34a<@0`/;20<W9b@31`L40VYZJ09NGU`2=
SHd0SXj>07emO@1iNGT00P1jNWX04@1hN7P0M7Ad07IfMP1bLW80Kfm_06=SH`1[Jf/0MGEe07QhN01l
O7`0Ogmo08F5Q@22PX80Ogmo07YjNP1gMgL0KVi^0080K6a/00@0LW9b06][J`1aLG40PH610P2:RXX0
3P28R8P0O7al0820P020P800Lg=c07QhN024Q8@0SHf=08F5Q@1lO7`0LG5a06QXJ01FEUH0A4A40P10
@4005P16ATH0CDe=03lo?`0n?Sh0?3`l04M7A`1BDU80D51@04A4A019BDT0GEeM06ATI01EEED0GEeM
04M7A`16ATH0BDU903dm?@0i>CT0=cLg03@d=00`<30203<c<`0;02h^;P0];Bd0?Cdm04=3@`19BDT0
EEEE059BDP1SHf<0D51@03<c<`0o?cl00P17AdL01P16ATH0B4Q802d];@0[:b/0;bl_02h^;P80<30`
02P0<S8b034a<@0c<c<0<S8b03Ti>@0`<300;2`/034a<@0h>3P0>SXj03dm?@0Z:RX0;Bd]02/[:`0^
;Rh0@d=305mOG`0g=cL0C4a<04];B`10@400A4A406a/K01TI6@0ADE505mOG`1kNg/0S8b<08Z:RP1g
MgL0O7al0:JVYP2[Zj/0WIfM09^KV`2ZZZX0];Bd0;Ng]`2`/;00/k>c0P2_[jl00`2d];@0^KVi0;Fe
]@020;Zj^P050;Fe]@2d];@0[jn_0:f][@2ZZZX00P2[Zj/02@2YZJT0ZZZZ0:b/[02d];@0/K6a0:VY
Z@2[Zj/0ZJVY0:n_[`020:b/[00A0:n_[`2d];@0/;2`0:j^[P2`/;00/[:b0:n_[`2^[Zh0/[:b0:j^
[P2a/K40/;2`0:f][@2a/K40/[:b0;Zj^P2n_[h00P34a<@06@30`<00`l?30<71`@2o_kl0`L710;jn
_P36a/H0`l?30<G5a@32`/80alO70<S8b03;bl/0b/[:0<K6aP33`l<0`/;20<71`@2b/[80X:2P092@
T01jNWX0J6QX05iNGP1CDe<00P1BDU801P14A4@0;bl_03Hf=P1nOWh0Ogmo05EEE@80De=C01<0FUYJ
0451@@1KFe/0Q8B4092@T026QXH0Q8B408^;R`24Q8@0T92@09NGU`2MWId0Xj>S08f=S@1kNg/0LW9b
075aL@1IFET0>CTi0080:BTY00X09BDU02TY:@0Y:BT0;Rh^03@d=00/;2`0:BTY02l_;`0/;2`0:b/[
0P0_;bl00`0a<C40=CDe034a<@0203@d=00703Ph>00g=cL0>c/k03hn?P0l?3`0=CDe03Lg=`0203dm
?@0E03Hf=P0h>3P0=SHf03Ph>00i>CT0=3@d02l_;`0];Bd09bLW02XZ:P0d=3@0<C4a030`<00e=CD0
<S8b03/k>`0a<C40<30`03Hf=P0b<S80=cLg0080?Cdm00P0BDU9055AD@1TI6@0NGUi08N7Q`25QHD0
R8R808F5Q@80O7al00h0OWin07moO`22PX80S8b<09VIV@2RXZ80YjNW0:VYZ@2[Zj/0YjNW0:>SX`2V
YZH0YjNW0:RXZ0<0YZJV00<0Y:BT0::RXP2UYJD00P2VYZH01`2RXZ80Xj>S0:6QX@2RXZ80Y:BT0:6Q
X@2UYJD00P2TY:@01P2SXj<0XJ6Q0::RXP2RXZ80X:2P0:>SX`80XZ:R0P2TY:@20:2PX0060::RXP2O
Wil0XJ6Q0:6QX@2LW9`0XJ6Q0P2SXj<0102TY:@0XZ:R0:6QX@2QXJ4209jNWP080:2PX02KVi/0X:2P
09jNWP2LW9`0WIfM09jNWP2OWil209bLW00409^KV`2MWId0WIfM09jNWP<0VIVI00L0VYZJ09^KV`2F
UYH0U9BD09JFUP2MWId0V9RH00h0b>3H000<0<SPf0<0Jf][00@0K6a/06][J`1`L700KFe]0P1XJ6P0
301YJFT0IVIV06ATI01[Jf/0J6QX06YZJP1VIVH0IFEU06MWI`1TI6@0GEeM061PH080GUiN0140GemO
05eMG@1QHF40IVIV06m_K`1lO7`0PH6108F5Q@2@T900U9BD09^KV`2QXJ40XZ:R0:>SX`2UYJD0ZJVY
0:j^[P020:b/[080Zj^[00<0[Jf]0;>c/`2[Zj/00P2][Jd00`2/[:`0[Zj^0;2`/0020:n_[`80[:b/
02/0Xj>S09jNWP2KVi/0UYJF08f=S@2<S8`0Q8B407=cL`1TI6@0FEUI051@D01<C4`0ADE50492@P15
ADD0Bd];04m?C`1=CDd0EEEE05ADE01MGEd0F5QH05MGE`1JFUX0GEeM05iNGP1OGel0GUiN065QH@1N
GUh0HF5Q05mOG`1NGUh0HV9R065QH@1NGUh0HF5Q069RHP1TI6@0HF5Q06EUI@1SHf<0HV9R0080H61P
00<0Hf=S06ATI01RHV800P1QHF405`1SHf<0Jf][06UYJ@1/K6`0J6QX06a/K01YJFT0Jf][07EeM@1^
KVh0K6a/079bLP1/K6`0JVYZ06a/K01]KFd0IfMW06a/K01PH600IFEU05mOG`1JFUX0FEUI0080EUIF
0300HV9R09jNWP3Lg=`0gMgM0=SHf03;bl/0bLW90<30`032`/80_kno0<30`03=cLd0`l?309VIV@1n
OWh0QXJ60::RXP21PH40OWin07alO01hN7P0Lg=c07AdM01eMGD0MWIf071`L01SHf<0IFEU06e]K@1a
LG40O7al0820P01mOGd0PX:20861P@26QXH0PH6107EeM@1`L700N7Qh07=cL`1[Jf/0IVIV071`L01k
Ng/0O7al0861P@26QXH208V9R@0608F5Q@29RHT0R8R808Z:RP1nOWh0Kfm_0P1]KFd06P1JFUX0@T92
03lo?`0k>c/0@T92051@D01DE5@0C4a<04A4A01:BTX0F5QH05eMG@18B4P0CDe=061PH01ZJVX0HF5Q
06EUI@18B4P0@T9204E5A@0g=cL0?clo03@d=012@T80=SHf0P0a<C4202XZ:P0i03Lg=`12@T80DE5A
05EEE@19BDT0IVIV04M7A`0Z:RX0;Rh^03Lg=`0i>CT0@T9206][J`16ATH0:RXZ02d];@0c<c<0=CDe
03Lg=`0e=CD0;Rh^03<c<`0`<300@T9203Ph>00k>c/0?clo04U9B@12@T80>c/k03De=@15ADD0>CTi
03`l?01EEED0JFUY03Xj>P1:BTX0CDe=0410@00n?Sh0Kfm_06][J`1DE5@0EUIF06=SH`2;Rh/0SXj>
07YjNP1/K6`0V9RH0;Rh^02][Jd0WinO0:RXZ02l_;`0^[Zj0080^KVi00D0];Bd0;Fe]@2a/K40]kNg
0;Rh^0020;^k^`080;Fe]@2i^KT0]KFe0;Bd]02_[jl0Z:RX0:b/[02_[jl20;2`/0060:j^[P2c/k<0
/;2`0:f][@2_[jl0/;2`0P2d];@03P2][Jd0/k>c0:j^[P2_[jl0];Bd0:f][@2_[jl0Zj^[0:n_[`2`
/;00];Bd0;:b/P2e]KD0];Bd0P2a/K400`2f][H0^k^k0;no_`020<30`080`L7102<0a<C40<;2`P31
`L40a<C40<G5a@32`/80aLG50<_;b`3<c<`0bl_;0<O7a`35aLD0`L710;Zj^P2XZ:P0VIVI08b<S01a
LG40Hf=S05QHF01GEeL0F5QH04m?C`0k>c/0?clo06IVIP21PH40FUYJ05=CD`1EEED0De=C04M7A`10
@400Ph>308b<S00208J6QP0?08B4Q02:RXX0PH6108b<S02IVIT0WYjN0:FUY@2MWId0Shn?08:2PP1]
KFd0DU9B03Hf=P0Y:BT0:b/[0080;2`/00P09RHV02XZ:P0^;Rh0:b/[02TY:@0`<300<c<c038b<P80
<c<c00@0<S8b030`<00_;bl0<C4a0P0i>CT0100d=3@0>SXj038b<P0h>3P203Lg=`0903Xj>P0g=cL0
?Cdm03Ti>@0j>SX0?3`l03Ti>@0`<300;2`/0080:RXZ00@0:b/[02l_;`0a<C40;Rh^0P0b<S80100e
=CD0<S8b03@d=00f=SH202/[:`0a038b<P0n?Sh0@41004e=C@1JFUX0KFe]07moO`1nOWh0QXJ608B4
Q022PX80O7al07emO@20P800OWin08R8R02DU9@0X:2P0:JVYP2WYjL0Z:RX0:VYZ@2ZZZX0XZ:R0:JV
YP2YZJT0Y:BT0:VYZ@2SXj<0YjNW0:FUY@2QXJ40YjNW0::RXP2VYZH0XJ6Q0:>SX`2TY:@0ZJVY0:NW
Y`2TY:@0Xj>S0:FUY@2RXZ80X:2P0::RXP2PX:00XJ6Q09jNWP020:2PX080Xj>S00D0XZ:R0:>SX`2S
Xj<0Xj>S0::RXP020:6QX@040:>SX`2OWil0X:2P09nOW`80X:2P00H0XJ6Q0:2PX02NWYh0WinO09jN
WP2QXJ4209jNWP0;0:2PX02NWYh0WIfM09nOW`2LW9`0WIfM09ZJVP2OWil0WIfM09ZJVP2HV9P00P2K
Vi/0102IVIT0UYJF09JFUP2HV9P209NGU`h0b>3H000<0<SPf080K6a/00L0JVYZ06a/K01/K6`0KFe]
06][J`1]KFd0I6AT0080JFUY00<0IfMW06EUI@1VIVH00P1TI6@2069RHP0406QXJ01SHf<0H61P069R
HP80GemO0180G5aL06MWI`1YJFT0KVi^07UiN@26QXH0RXZ:08^;R`2@T900UIFE0:2PX02SXj<0Z:RX
0:^[Z`2ZZZX0[Jf]0:ZZZP2/[:`20:^[Z`070:n_[`2/[:`0[Jf]0:ZZZP2[Zj/0[Zj^0;2`/0030:n_
[`0;0:^[Z`2ZZZX0XZ:R09fMW@2GUiL0V9RH08j>SP27QhL0P82007QhN01UIFD00P1IFET01@1<C4`0
Bd];04M7A`17AdL0ATI60080Cdm?00`0E5AD059BDP1EEED0GEeM05IFEP1NGUh0HV9R05eMG@1LG5`0
IfMW061PH01RHV82065QH@0606EUI@1PH600Hf=S05mOG`1SHf<0I6AT0P1QHF42061PH00805iNGP1R
HV80HF5Q06ATI01VIVH0HV9R065QH@1TI6@206IVIP80JVYZ01<0J6QX06EUI@1ZJVX0Jf][06i^KP1[
Jf/0LG5a071`L01_Kfl0KVi^06YZJP1/K6`0JFUY06IVIP1TI6@0GEeM05]KF`1HF5P0FEUI0080DU9B
00D0M7Ad0;Fe]@3Ogml0d=3@0<S8b0020<O7a`0J0<;2`P33`l<0_Kfm0<;2`P36a/H0`L7109VIV@1]
KFd0MWIf0:FUY@28R8P0QXJ607YjNP1aLG40MWIf071`L01fMWH0NWYj079bLP1_Kfl0K6a/06i^KP1h
N7P0QhN70861P@1oOgl208:2PP0a08J6QP24Q8@0PH6107IfMP1kNg/0NWYj07EeM@1_Kfl0KFe]06m_
K`1fMWH0N7Qh0820P023Ph<0PH6107UiN@1jNWX0N7Qh07EeM@1^KVh0L71`06][J`1UIFD0I6AT05YJ
FP1LG5`0DE5A04Q8B00n?Sh0AdM704m?C`1;Bd/0AdM705=CD`1KFe/0F5QH04i>CP1JFUX0I6AT06=S
H`1TI6@0FUYJ0410@013@d<0>CTi03Hf=P0j>SX0>CTi03Hf=P0202XZ:P0C02LW9`0a<C40<C4a03`l
?01IFET0KVi^061PH01^KVh0@41002LW9`0^;Rh0<30`0492@P0f=SH0EUIF05]KF`0Z:RX0;bl_038b
<P02034a<@0903@d=00f=SH0?clo03dm?@0o?cl0Cdm?05aLG01HF5P0HV9R0080GUiN0240HV9R05YJ
FP1BDU80CTi>061PH01jNWX0FUYJ051@D01>CTh0C4a<04E5A@1lO7`0M7Ad05EEE@1PH600JFUY07]k
N`24Q8@0O7al06][J`1fMWH0WIfM0;Rh^02][Jd0Y:BT0;fm_@2j^[X0^k^k0;jn_P2h^;P0^k^k0;Ng
]`2i^KT00`2l_;`0302j^[X0^;Rh0;Fe]@2i^KT0]KFe0;2`/02a/K40/[:b0;6a/@2d];@0/k>c0:n_
[`80/K6a00L0[jn_0;>c/`2_[jl0[jn_0:b/[02a/K40[Zj^0080[jn_01D0/k>c0:b/[02YZJT0/[:b
0;Jf]P2h^;P0];Bd0;Zj^P2e]KD0]kNg0;Fe]@2d];@0^;Rh0;Ng]`2j^[X0`<300<;2`P2m_Kd0_kno
0;Vi^@32`/800P31`L407`36a/H0bLW90<[:bP3<c<`0alO70<G5a@2j^[X0_;bl0;>c/`2PX:00RHV9
07alO01WIfL0Fe]K05UIF@1JFUX0DU9B0492@P1;Bd/0N7Qh08J6QP1[Jf/0CDe=05aLG015ADD0De=C
03lo?`1YJFT0Rh^;08J6QP22PX800P24Q8@0401nOWh0QHF508j>SP2GUiL0YZJV0:j^[P2g]kL0[:b/
09jNWP23Ph<0FEUI0451@@0d=3@0<C4a02`/;00X:2P202TY:@0602/[:`0_;bl0;Rh^02h^;P0d=3@0
;bl_0P0[:b/01@0Y:BT0;Bd]03@d=00d=3@0>CTi0080>3Ph00/0@T9203Ti>@0i>CT0=cLg03Hf=P10
@400>SXj03Ti>@0f=SH0>SXj03Ti>@0203De=@0G03Xj>P0^;Rh0:BTY02LW9`0Z:RX0:b/[03@d=00]
;Bd0;Rh^03Lg=`0c<c<0?Cdm03@d=00_;bl0<C4a03Hf=P13@d<0BDU904=3@`1BDU80K6a/07QhN023
Ph<00P24Q8@05P21PH40O7al07inOP1gMgL0PH6108V9R@2CTi<0W9bL0:>SX`2ZZZX0YZJV0:NWY`2V
YZH0ZZZZ0:RXZ02[Zj/0Y:BT0:NWY`2RXZ80XJ6Q0:>SX`2RXZ820:BTY0070:FUY@2TY:@0YZJV0:FU
Y@2RXZ80YJFU0::RXP020:BTY0060:FUY@2RXZ80WYjN0:BTY02RXZ80XJ6Q0P2OWil03@2RXZ80Y:BT
0:>SX`2NWYh0XJ6Q0::RXP2OWil0X:2P09^KV`2PX:00WinO0:2PX02MWId00P2RXZ801@2OWil0X:2P
09fMW@2NWYh0X:2P0080WYjN0100WIfM09^KV`2MWId0Vi^K09bLW02PX:00WYjN09VIV@2NWYh0Vi^K
09RHV02JVYX0W9bL09VIV@2JVYX0VIVI0P2GUiL00`2FUYH0UiNG0<SPf00=0<SPf0003038h=P206a/
K080Jf][02H0KVi^06][J`1YJFT0K6a/06YZJP1VIVH0JFUY06YZJP1YJFT0IfMW06IVIP1SHf<0HF5Q
069RHP1TI6@0IFEU069RHP1NGUh0GemO069RHP1OGel0JFUY06i^KP1bLW80NGUi0861P@2;Rh/0S8b<
092@T02HV9P0XJ6Q0:>SX`2WYjL0ZJVY0:j^[P2ZZZX0[:b/0:f][@80[jn_00D0/;2`0:^[Z`2^[Zh0
Zj^[0:f][@020:n_[`0A0;:b/P2a/K40Zj^[0:^[Z`2ZZZX0Y:BT0::RXP2IVIT0Ti>C08n?S`25QHD0
O7al075aL@1ZJVX0Fe]K05=CD`1<C4`00P17AdL00`1:BTX0C4a<05=CD`0205=CD`0405aLG01DE5@0
EeMG05QHF0<0Fe]K00@0H61P06=SH`1RHV80I6AT0P1MGEd0301LG5`0GUiN05mOG`1PH600FUYJ065Q
H@1PH600I6AT06IVIP1QHF40H61P06EUI@80I6AT00<0JFUY06MWI`1VIVH00`1TI6@00`1WIfL0J6QX
06EUI@0206YZJP80K6a/0P1[Jf/0301`L700KVi^06][J`1_Kfl0KFe]06=SH`1WIfL0IVIV05eMG@1F
EUH0EeMG05EEE@80G5aL01L0Vi^K0=CDe03GemL0cLg=0<K6aP32`/80`<300<C4a02m_Kd0`<300;no
_`37alL0_Kfm09^KV`1`L700J6QX08f=S@2HV9P0SXj>07emO@1dM7@0L71`07EeM@0207inOP0k07Yj
NP1lO7`0N7Qh06YZJP1fMWH0Ogmo0861P@22PX80OGem08:2PP25QHD0Q8B407inOP1jNWX0NGUi08F5
Q@22PX80NWYj07=cL`1hN7P0PX:207alO01mOGd0OWin08B4Q01bLW80LG5a06IVIP1NGUh0Lg=c0820
P027QhL0Ph>307MgM`1`L700IVIV05MGE`15ADD0?Shn04A4A01MGEd0FEUI04U9B@11@D40DE5A05QH
F01CDe<0GemO05YJFP1QHF40H61P06QXJ01ADE40ADE503Hf=P0c<c<0<C4a02h^;P0b<S800P0/;2`0
?`0Z:RX092@T02h^;P0h>3P0DU9B07QhN01/K6`0LW9b03Hf=P0R8R8092@T02PX:00[:b/0<S8b05aL
G01RHV80:b/[03/k>`0e=CD0>c/k03Xj>P0f=SH0=cLg03Ti>@0o?cl0?3`l04i>CP1GEeL0Fe]K059B
DP1DE5@0DE5A05QHF01>CTh0>3Ph030`<01LG5`0N7Qh05EEE@17AdL0ATI6038b<P1PH600O7al07Qh
N01LG5`0NWYj09RHV01nOWh0Shn?0861P@1[Jf/0E5AD07QhN02KVi/0[Jf]09^KV`2h^;P0^k^k0;no
_`2n_[h0_Kfm0;jn_P020;Zj^P0C0;fm_@32`/80_kno0;^k^`2j^[X0^k^k0;Ng]`2i^KT0]KFe0;Ng
]`2a/K40/[:b0;>c/`2i^KT0/[:b0;2`/02b/[80]kNg0;Fe]@020;>c/`0F0:f][@2^[Zh0ZZZZ0:j^
[P2`/;00/K6a0:f][@2/[:`0/K6a0;>c/`2k^k/0][Jf0;^k^`2e]KD0^;Rh0;Bd]02e]KD0^[Zj0;Jf
]P2a/K40];Bd0;^k^`<0_;bl0100`L710;^k^`31`L40a/K60<O7a`36a/H0aLG50<30`02o_kl0^;Rh
0;:b/P2XZ:P0U9BD08>3P`1_Kfl0H61P0P1IFET01P1MGEd0Bd];04U9B@1nOWh0RXZ:07=cL`80Jf][
0140HV9R05eMG@1LG5`0G5aL08R8R02EUID0QXJ608B4Q02:RXX0PH6107]kN`28R8P0Ti>C09^KV`2S
Xj<0/k>c0;^k^`020<71`@0=0;6a/@2CTi<0J6QX03/k>`0b<S80=3@d02TY:@0a<C40;Rh^02`/;00^
;Rh0;bl_02d];@0202/[:`<0:BTY00d0;Rh^03Lg=`0d=3@0?Cdm03<c<`0j>SX0>c/k03Ti>@0d=3@0
>3Ph02l_;`0b<S80>3Ph0080=3@d00<0<c<c03Xj>P0g=cL00P0a<C401P0[:b/0<30`02XZ:P0[:b/0
;bl_038b<P80;bl_0140<S8b03<c<`0f=SH0=cLg03Hf=P0b<S80=SHf03/k>`0n?Sh0@T9204U9B@1Q
HF40MGEe08:2PP27QhL0RXZ:08J6QP020820P00:07MgM`1kNg/0QHF508b<S02KVi/0XJ6Q0:VYZ@2W
YjL0ZJVY0:b/[080YZJV0P2YZJT00`2RXZ80Y:BT0:>SX`020:>SX`050:BTY02SXj<0Xj>S0:>SX`2T
Y:@00P2RXZ80102WYjL0YJFU0:JVYP2SXj<20:JVYP040:2PX02QXJ40XZ:R0:>SX`80XZ:R00<0Y:BT
0::RXP2RXZ800P2OWil00`2NWYh0X:2P0:2PX0020:6QX@80X:2P00/0WinO0:2PX02PX:00X:2P0:6Q
X@2NWYh0XJ6Q09nOW`2LW9`0WIfM0:>SX`0209jNWP80VYZJ00@0W9bL09fMW@2JVYX0WYjN0P2IVIT0
2@2JVYX0VIVI09bLW02FUYH0UIFE09^KV`2GUiL0UYJF09VIV@0>0<SPf0003038h=P306i^KP80KFe]
0P1/K6`07`1]KFd0JFUY06MWI`1VIVH0J6QX06MWI`1XJ6P0IfMW06EUI@1XJ6P0IFEU06=SH`1WIfL0
H61P06=SH`1OGel0Hf=S061PH01UIFD0Jf][075aL@1iNGT0PH6108Z:RP2>SXh0UYJF09ZJVP2NWYh0
XJ6Q0:RXZ02VYZH00P2XZ:P00`2_[jl0[:b/0:f][@020:f][@060:^[Z`2][Jd0[jn_0;2`/02^[Zh0
/[:b0P2][Jd05P2/[:`0ZJVY0:RXZ02WYjL0WYjN09bLW02CTi<0SHf=08R8R020P800MGEe06UYJ@1H
F5P0DE5A04Y:BP1;Bd/0A4A404Y:BP1<C4`0D51@04e=C@1@D50205MGE`0705QHF01LG5`0G5aL05mO
G`1JFUX0GUiN06=SH`02069RHP0305iNGP1SHf<0HV9R0080HV9R00H0GUiN065QH@1PH600Hf=S06EU
I@1RHV8206ATI00D06MWI`1UIFD0HV9R06=SH`1TI6@0G5aL06UYJ@1UIFD0IVIV06YZJP1YJFT0J6QX
06YZJP1[Jf/0KVi^06a/K01YJFT0JVYZ06QXJ01_Kfl206][J`0806UYJ@1UIFD0HF5Q065QH@1PH600
FUYJ051@D01IFET207=cL`0D0<71`@3Rh^80d=3@0=;BdP3=cLd0`L710<30`02o_kl0alO70<C4a02g
]kL0`L710;Zj^P2VYZH0MgMg05QHF01XJ6P0TI6A09BDU026QXH207AdM00L07QhN01iNGT0P82008>3
P`1kNg/0NGUi06m_K`1eMGD0MWIf07alO01jNWX0Ng]k0861P@23Ph<0QXJ607alO01jNWX0QHF5096A
T@2<S8`0RHV907inOP27QhL0S8b<08J6QP23Ph<0O7al07moO`80NGUi01@0Kfm_07]kN`27QhL0QXJ6
08B4Q01oOgl0P82007]kN`1YJFT0DE5A04M7A`1:BTX0CDe=05IFEP1HF5P0CTi>04I6AP1<C4`0BDU9
04Y:BP80De=C00T0IfMW05eMG@1YJFT0IVIV0492@P0j>SX0<c<c038b<P0^;Rh00`0[:b/07@0X:2P0
9RHV02TY:@0a<C40AdM706YZJP1kNg/0O7al0410@00W9bL092@T02HV9P0U9BD0=SHf03Ti>@11@D40
@T9204Q8B010@400?Cdm0410@01<C4`0>c/k03<c<`0_;bl0ATI604a<C00m?Cd0>c/k0080<S8b00<0
=cLg03dm?@0^;Rh00P0^;Rh03@1=CDd0L71`05QHF01:BTX0<C4a02/[:`1=CDd0PX:207moO`1YJFT0
NGUi096AT@2QXJ400P2=SHd0401/K6`0AdM706QXJ01nOWh0Shn?09:BTP2h^;P0`<300;Zj^P30`<00
`/;20;no_`31`L40_[jn0<71`@32`/820;jn_P80^k^k00d0^;Rh0;Vi^@2f][H0]kNg0;Jf]P2_[jl0
/[:b0;>c/`2f][H0/K6a0;>c/`2f][H0];Bd0080^[Zj00H0];Bd0;:b/P2/[:`0ZJVY0:b/[02a/K42
0:f][@0>0;>c/`2e]KD0][Jf0;Rh^02k^k/0];Bd0;Fe]@2b/[80]KFe0;Zj^P2n_[h0][Jf0;Rh^02b
/[820;Bd]080^[Zj0380^KVi0;no_`33`l<0`/;20<71`@32`/80a<C40<;2`P2i^KT0/[:b0::RXP2<
S8`0NWYj06IVIP1LG5`0GemO05UIF@17AdL0ADE506m_K`27QhL0MWIf071`L01YJFT0KFe]06IVIP1_
Kfl0Jf][07emO@2EUID0S8b<07moO`1jNWX0Ph>307]kN`1iNGT0Shn?09>CT`2KVi/0WinO0:ZZZP2h
^;P0_Kfm0<G5a@38b<P0alO70:b/[01lO7`0FEUI03Hf=P80;Bd]00@0;2`/034a<@0^;Rh0:RXZ0P0[
:b/0200_;bl0;Rh^02h^;P0[:b/0;2`/034a<@0c<c<0=CDe0P0i>CT04P0e=CD0=cLg03<c<`0b<S80
<c<c02l_;`0d=3@0>CTi03<c<`0k>c/0>3Ph03<c<`0g=cL0>CTi030`<00];Bd0;2`/02l_;`80<30`
00D0:b/[02d];@0b<S80>3Ph03Hf=P0203Ti>@0N02l_;`0];Bd0>3Ph03`l?00k>c/0BTY:05aLG01]
KFd0N7Qh08B4Q029RHT0QhN708B4Q020P800O7al07]kN`21PH40R8R809RHV02MWId0YZJV0:BTY02Y
ZJT0YjNW0:VYZ@2UYJD0Zj^[0:JVYP2WYjL0YZJV0P2RXZ801P2SXj<0XJ6Q0:>SX`2RXZ80Y:BT0:FU
Y@80Y:BT00H0XZ:R0:6QX@2SXj<0Xj>S0:6QX@2UYJD20:>SX`0E0:FUY@2RXZ80X:2P0:2PX02QXJ40
YZJV0:6QX@2PX:00XZ:R09jNWP2PX:00WinO09jNWP2QXJ40W9bL09fMW@2LW9`0WinO0:6QX@2MWId0
XZ:R00<0XJ6Q0`2NWYh0102IVIT0WYjN09bLW02LW9`209ZJVP060:2PX02KVi/0V9RH09^KV`2MWId0
Vi^K0P2JVYX01@2HV9P0W9bL09^KV`2MWId0V9RH00h0b>3H000<0<SPf080KVi^00/0KFe]06YZJP1/
K6`0JVYZ06IVIP1^KVh0J6QX06ATI01ZJVX0IfMW06UYJ@0306IVIP0706=SH`1UIFD0I6AT06ATI01L
G5`0Hf=S05mOG`0206=SH`0=06IVIP1^KVh0Lg=c07]kN`27QhL0RHV908f=S@2DU9@0VIVI09jNWP2Q
XJ40YjNW0:JVYP020:NWY`090:n_[`2^[Zh0[Zj^0:j^[P2[Zj/0[Jf]0;:b/P2^[Zh0[Jf]0080[:b/
01X0[Jf]0:ZZZP2][Jd0YjNW0:b/[02SXj<0WYjN09^KV`2CTi<0T92@08R8R01oOgl0MgMg06UYJ@1I
FET0DE5A04U9B@16ATH0BDU904Q8B01=CDd0Cdm?05ADE01EEED0EeMG05EEE@80Fe]K00T0G5aL05eM
G@1JFUX0F5QH06EUI@1SHf<0HV9R05mOG`1SHf<00P1QHF401@1PH600Hf=S05mOG`1QHF40H61P00<0
I6AT01@0Hf=S061PH01OGel0GUiN061PH01RHV80IFEU06MWI`1PH600IfMW06UYJ@1TI6@0JFUY06QX
J01WIfL0JVYZ06a/K01YJFT0J6QX06UYJ@80J6QX00H0IFEU06IVIP1PH600GEeM05mOG`1KFe/205AD
E00G06=SH`2CTi<0Ti>C0=;BdP3Ph>00dM7A0<o?c`39bLT0_Kfm0<71`@36a/H0b<S80;Vi^@2f][H0
^k^k0;Vi^@2_[jl0TI6A06UYJ@1MGEd0QhN70:2PX029RHT00P1eMGD01@1lO7`0Ph>308F5Q@24Q8@0
PH610080P82002l0M7Ad07IfMP1dM7@0Ng]k07alO01oOgl0PH6108F5Q@21PH40Ogmo08J6QP2<S8`0
Ph>307emO@1oOgl0NWYj07AdM01jNWX0M7Ad06e]K@1`L700Ogmo08^;R`25QHD0R8R808>3P`1nOWh0
PH6107moO`1mOGd0Ph>307YjNP1eMGD0NGUi07EeM@1NGUh0GemO06ATI01SHf<0FUYJ04i>CP1;Bd/0
?clo04Y:BP16ATH0F5QH069RHP0205iNGP0605EEE@0n?Sh0>c/k02`/;00];Bd09bLW0P0V9RH03@0Y
:BT0:2PX02`/;015ADD0@d=306MWI`1bLW80Ph>304i>CP0Z:RX09RHV02l_;`0Z:RX00P0`<300;P0Y
:BT0<30`05MGE`1<C4`0Fe]K03`l?01HF5P0>3Ph02LW9`0[:b/0;Bd]03`l?00k>c/0<S8b02/[:`0`
<300>SXj03De=@0Z:RX0:2PX02HV9P0n?Sh0Kfm_071`L013@d<0:RXZ02DU9@0e=CD0L71`08Z:RP1m
OGd0IFEU06i^KP2@T900SXj>08b<S01lO7`0@T9205QHF01_Kfl0LW9b08>3P`2b/[80a<C40;Vi^@2o
_kl20<?3``090<71`@2o_kl0`L710<30`032`/80`<300;no_`2g]kL0][Jf0080]kNg00@0]KFe0;>c
/`2c/k<0/K6a0P2b/[820;Bd]0090;:b/P2e]KD0^k^k0;^k^`2c/k<0^;Rh0;6a/@2][Jd0ZZZZ0080
Zj^[00`0[:b/0:n_[`2e]KD0]kNg0;Rh^02i^KT0];Bd0;Zj^P2d];@0]kNg0;Rh^02k^k/20;Zj^P06
0;Ng]`2j^[X0/[:b0;Fe]@2a/K40^KVi0P2m_Kd0>033`l<0_kno0<?3``2o_kl0_Kfm0;Ng]`2][Jd0
WinO08B4Q01_Kfl0GEeM05aLG01@D500?3`l04A4A01/K6`0O7al06YZJP1KFe/0J6QX06MWI`1JFUX0
H61P07QhN01VIVH0R8R8096AT@1mOGd0N7Qh07emO@1jNWX0Lg=c07UiN@29RHT0U9BD09VIV@2JVYX0
YZJV0;:b/P2h^;P0^k^k0<O7a`3=cLd0b/[:0;fm_@2LW9`0LG5a04A4A00_;bl0;Bd]02h^;P0W9bL0
9BDU02d];@0[:b/0;Bd]0P0`<300400Y:BT0:b/[038b<P0e=CD0;bl_03Lg=`0h>3P0=cLg03`l?00k
>c/0=CDe03@d=00b<S80<c<c03dm?@0c<c<203Lg=`0303Hf=P0k>c/0<c<c0080<S8b0P0_;bl00`0/
;2`0=SHf02h^;P0202`/;00L03@d=00a<C40>CTi03Xj>P0a<C40>SXj03@d=00k>c/0ADE504U9B@1A
DE40I6AT07AdM020P800SHf=08^;R`22PX80OWin07alO01hN7P0NWYj08B4Q02DU9@0VYZJ0:FUY@2W
YjL0YZJV0:NWY`80YZJV0100Z:RX0:NWY`2UYJD0XZ:R0:FUY@2QXJ40YJFU0:>SX`2RXZ80WinO0:NW
Y`2VYZH0XJ6Q0:>SX`2PX:00Xj>S0P2UYJD00`2XZ:P0Y:BT0:FUY@020:>SX`<0XZ:R00H0XJ6Q0:>S
X`2QXJ40X:2P09fMW@2OWil20:2PX00O0::RXP2NWYh0W9bL0:2PX02JVYX0WYjN0:2PX02LW9`0X:2P
0:6QX@2SXj<0WinO0:2PX02QXJ40WinO09^KV`2OWil0WYjN09bLW02NWYh0WIfM09jNWP2LW9`0UYJF
09ZJVP2NWYh0VYZJ09^KV`2HV9P0UiNG09VIV@0209ZJVP0309NGU`38h=P0b>3H00`0b>3H000<0<SP
f080Jf][00H0JVYZ06UYJ@1XJ6P0K6a/06e]K@1`L70206YZJP0806UYJ@1UIFD0Jf][06=SH`1XJ6P0
IFEU06ATI01QHF42069RHP08065QH@1NGUh0G5aL06=SH`1QHF40JFUY06i^KP1gMgL20820P00;08Z:
RP2@T900UYJF09^KV`2MWId0X:2P0:RXZ02WYjL0Zj^[0:f][@2^[Zh00`2][Jd30:b/[0040:j^[P2Y
ZJT0[jn_0;6a/@80Zj^[00h0[Jf]0:ZZZP2VYZH0YJFU0:6QX@2LW9`0UYJF09BDU029RHT0O7al07Ee
M@1VIVH0EUIF055AD@80BTY:00<0BDU904];B`1?Cdl00P1EEED0101IFET0Cdm?05EEE@1GEeL205]K
F`80GEeM00D0GUiN061PH01OGel0GUiN06=SH`02069RHP80Hf=S00<0IVIV05iNGP1OGel00P1QHF40
0`1SHf<0IVIV069RHP02069RHP07061PH01OGel0GUiN06=SH`1UIFD0HV9R06EUI@0206MWI`0:06a/
K01ZJVX0J6QX06QXJ01[Jf/0JFUY06IVIP1/K6`0KVi^06UYJ@80IVIV00L0I6AT06=SH`1KFe/0FEUI
05=CD`1GEeL0PH610080`/;201@0cLg=0=kNgP3Jf]X0dM7A0<S8b02k^k/0_Kfm0<C4a02j^[X0/K6a
0:b/[02g]kL0^k^k0;Zj^P2YZJT0UIFE06][J`1hN7P0VYZJ07inOP80O7al0240Ph>308N7Q`24Q8@0
QHF508:2PP1nOWh0MGEe079bLP1^KVh0L71`07YjNP1kNg/0OWin0861P@24Q8@0P82008F5Q@21PH40
PX:207moO`1mOGd0OWin07UiN@1fMWH0OWin07YjNP1`L700Lg=c08Z:RP2>SXh0QhN708R8R01jNWX0
0P1gMgL01@1lO7`0MgMg07alO01iNGT0MgMg0080LW9b01@0I6AT06IVIP1YJFT0IFEU05UIF@1LG5`0
EEEE0492@P0j>SX0@41004I6AP1ADE40Fe]K05YJFP1?Cdl0?3`l03De=@0_;bl0:b/[02TY:@809RHV
00X09bLW02<S8`0_;bl0A4A40451@@1HF5P0KVi^08B4Q01YJFT0;Bd]0P0Z:RX04P0T92@0:RXZ030`
<00^;Rh0<c<c05MGE`1TI6@0GUiN038b<P1WIfL0;bl_02TY:@0^;Rh0>3Ph03`l?00i>CT0<30`038b
<P80>c/k02T0=SHf03De=@0`<300<S8b03dm?@1]KFd0MgMg0492@P0];Bd08R8R02`/;01;Bd/0P820
08R8R01JFUX0@d=3071`L01oOgl0O7al08Z:RP1BDU80Hf=S075aL@1RHV80Kfm_0:>SX`2n_[h0a<C4
0;fm_@35aLD0a/K60<C4a030`<00`L710;no_`30`<00`/;20;jn_P2j^[X0^KVi0;Zj^P020;Rh^080
][Jf00D0]kNg0;6a/@2_[jl0/K6a0;:b/P020;Jf]P80^;Rh01D0/K6a0;Vi^@2e]KD0[jn_0:^[Z`2V
YZH0YJFU0:VYZ@2/[:`0/;2`0;Jf]P2g]kL0/k>c0;2`/02d];@0^k^k0;>c/`2h^;P0_Kfm0;Vi^@2l
_;`00P2j^[X0?P2l_;`0][Jf0;2`/02c/k<0][Jf0;:b/P31`L40`/;20<G5a@32`/80_[jn0;:b/P2/
[:`0U9BD07QhN01OGel0E5AD04a<C015ADD0BTY:071`L01eMGD0Hf=S04Y:BP1CDe<0I6AT065QH@1I
FET0IFEU05UIF@1`L700Shn?08:2PP1kNg/0MGEe07emO@1/K6`0IVIV07inOP29RHT0UIFE09NGU`2I
VIT0XJ6Q0:VYZ@2e]KD0];Bd0;^k^`33`l<0aLG50<[:bP33`l<0]kNg08>3P`10@400:b/[02`/;00X
:2P0:RXZ02/[:`0^;Rh0:b/[0P0Z:RX00`0_;bl09BDU02/[:`02034a<@0603@d=00e=CD0>3Ph03/k
>`0f=SH0=cLg0P0b<S802@0j>SX0=SHf03Lg=`0j>SX0?clo03De=@0h>3P0<C4a038b<P0202d];@0D
02PX:00Y:BT0<30`034a<@0_;bl0;2`/02l_;`0i>CT0>c/k03Lg=`0n?Sh0<S8b03<c<`0i>CT0B4Q8
04M7A`14A4@0FEUI07AdM01iNGT208R8R00908>3P`22PX80Q8B408:2PP20P800Q8B4096AT@2KVi/0
XJ6Q0080YjNW0P2XZ:P20:FUY@050:RXZ02SXj<0Xj>S0:NWY`2RXZ800`2SXj<0102UYJD0XZ:R0:>S
X`2UYJD30::RXP080:6QX@2RXZ80Xj>S0::RXP2TY:@0Xj>S0:BTY02SXj<20:BTY00@0:6QX@2SXj<0
XJ6Q0:6QX@2MWId0X:2P0:FUY@2PX:00Xj>S09bLW02NWYh0Xj>S0::RXP2OWil0XJ6Q09bLW080WIfM
00D0WinO09jNWP2LW9`0XJ6Q09fMW@0209^KV`0909jNWP2LW9`0W9bL09fMW@2KVi/0VYZJ09VIV@2H
V9P0W9bL0080VYZJ00@0UYJF09^KV`2FUYH0TY:B0P2FUYH>0<SPf0003038h=P206MWI`80KFe]00h0
KVi^06e]K@1`L700J6QX07AdM01ZJVX0Kfm_06e]K@1YJFT0JVYZ06MWI`1SHf<0H61P069RHP80Hf=S
00P0IFEU06ATI01VIVH0HV9R06ATI01ZJVX0M7Ad07IfMP80P82000`0Rh^;08j>SP2DU9@0Vi^K09nO
W`2SXj<0YJFU0:RXZ02WYjL0[Jf]0:ZZZP2][Jd20:n_[`80ZZZZ0P2^[Zh04@2_[jl0[:b/0:j^[P2_
[jl0[:b/0:f][@2XZ:P0Y:BT0:6QX@2LW9`0UiNG09BDU02@T900R8R807emO@1eMGD0Hf=S0080EeMG
0180CDe=04];B`1;Bd/0ATI604e=C@1@D500De=C059BDP1DE5@0FEUI05aLG01JFUX0GEeM061PH01L
G5`0GEeM05iNGP1RHV8206EUI@0406ATI01WIfL0GemO065QH@80Hf=S00/0HV9R065QH@1QHF40GUiN
065QH@1NGUh0JFUY05aLG01QHF40GEeM06ATI00206=SH`0306ATI01PH600IfMW00<0IVIV00D0Jf][
06UYJ@1/K6`0KVi^06UYJ@0206IVIP0:06EUI@1RHV80HV9R069RHP1NGUh0EEEE05ADE01FEUH0K6a/
0:f][@80gMgM00D0c/k>0<c<c03IfMT0f=SH0<[:bP020;no_`0@0;Jf]P2XZ:P0[Jf]0:^[Z`2d];@0
^;Rh0;no_`2`/;00Ti>C07AdM01WIfL0P82008:2PP26QXH0QHF508:2PP80Ogmo00D0Ph>308F5Q@1l
O7`0OGem07QhN00206][J`0I07EeM@1fMWH0PX:207moO`26QXH0QhN708V9R@23Ph<0OWin08B4Q01m
OGd0NGUi07emO@20P800Ng]k07UiN@1gMgL0OGem07alO029RHT0R8R808Z:RP21PH40NGUi06IVIP02
06QXJ00G06UYJ@1ZJVX0MWIf07EeM@1[Jf/0JFUY06m_K`1JFUX0F5QH05ADE01CDe<0E5AD04e=C@13
@d<0?3`l03hn?P12@T80EUIF06=SH`1JFUX0BDU903/k>`11@D400P0_;bl203@d=00:02d];@0/;2`0
:BTY02d];@10@400GemO075aL@25QHD0Jf][02XZ:P808R8R01d09BDU02/[:`0Z:RX0:RXZ03Ti>@1A
DE40HV9R06IVIP0`<300GUiN02l_;`0];Bd0:b/[03hn?P0k>c/0>SXj03Ph>00e=CD0>c/k03<c<`0e
=CD0;Bd]02l_;`0W9bL0?Cdm06ATI01dM7@0CTi>02LW9`0202<S8`0I0451@@24Q8@0Ti>C06e]K@0U
9BD0@D5105]KF`1UIFD0QhN707emO@1eMGD0M7Ad065QH@1WIfL0QXJ60:>SX`2h^;P0`<300<O7a`36
a/H0`l?30<;2`P35aLD0`/;20<30`0020<;2`P030;no_`2i^KT0^k^k0080^[Zj00T0][Jf0;:b/P2f
][H0]KFe0;>c/`2a/K40[Jf]0;Jf]P2i^KT00P2j^[X20;Rh^080][Jf00d0[jn_0:b/[02UYJD0YjNW
0:VYZ@2`/;00];Bd0;^k^`2f][H0]KFe0;6a/@2e]KD0/;2`0080^[Zj00@0_;bl0;jn_P2k^k/0^[Zj
0P2o_kl09`2h^;P0_Kfm0;Ng]`2a/K40^[Zj0<30`032`/80_kno0;bl_02^[Zh0Z:RX08J6QP1VIVH0
DE5A04];B`1:BTX0F5QH06i^KP1/K6`0DU9B04a<C01IFET0GemO05aLG01OGel0HF5Q05QHF01KFe/0
Rh^;08j>SP1lO7`0LW9b07EeM@1gMgL0J6QX06ATI01kNg/0S8b<09bLW00209RHV00?0:6QX@2TY:@0
[:b/0:j^[P2c/k<0][Jf0;^k^`33`l<0b<S80<k>cP2o_kl0SXj>04Y:BP0d=3@0:RXZ0080:b/[00L0
=SHf02TY:@0a<C40<C4a02HV9P0/;2`09bLW0080;Bd]03@0;Rh^02l_;`0c<c<0=SHf03<c<`0a<C40
=3@d02h^;P0j>SX0>CTi03Hf=P0e=CD0@41003Hf=P0i>CT0<30`03@d=00Z:RX0;2`/02l_;`0g=cL0
;Rh^02XZ:P0/;2`0;bl_02/[:`0e=CD0<S8b03Hf=P0b<S80>CTi034a<@0e=CD0@d=304E5A@13@d<0
DU9B06MWI`1gMgL0QXJ608V9R@28R8P0Ph>308J6QP25QHD0Ph>307moO`2?Shl0UiNG09nOW`2WYjL0
Z:RX0P2WYjL04P2VYZH0YJFU0:VYZ@2WYjL0XZ:R0:FUY@2WYjL0Y:BT0:2PX02TY:@0YZJV09nOW`2S
Xj<0Y:BT0::RXP2PX:00Y:BT0::RXP80Xj>S00D0YJFU0::RXP2SXj<0XZ:R0:FUY@030::RXP0:0:6Q
X@2PX:00WYjN0:2PX02SXj<0XZ:R0:6QX@2RXZ80WinO0:6QX@80X:2P00D0Xj>S0:6QX@2QXJ40X:2P
0:6QX@0209nOW`80X:2P00/0WIfM09nOW`2NWYh0WYjN09^KV`2PX:00Vi^K09ZJVP2LW9`0Vi^K09ZJ
VP0209^KV`0709VIV@2HV9P0UiNG09FEU@2FUYH0VIVI09NGU`0>0<SPf0003038h=P207EeM@0806][
J`1^KVh0JFUY06m_K`1^KVh0IFEU06e]K@1ZJVX206][J`0506i^KP1XJ6P0Hf=S06ATI01QHF400P1R
HV805@1SHf<0I6AT06=SH`1VIVH0IFEU069RHP1^KVh0Lg=c07IfMP22PX80OWin08Z:RP2>SXh0U9BD
09VIV@2PX:00YjNW0:FUY@2ZZZX0Zj^[0:b/[0020:ZZZP80ZJVY00L0Zj^[0:b/[02][Jd0[jn_0;6a
/@2^[Zh0Zj^[0080[:b/00d0[jn_0:VYZ@2UYJD0XJ6Q0:2PX02JVYX0U9BD08j>SP29RHT0PH6107Mg
M`1WIfL0G5aL0080CTi>00T0Bd];04A4A019BDT0C4a<04m?C`1GEeL0EEEE05ADE01MGEd00P1OGel0
1P1TI6@0H61P061PH01NGUh0G5aL06QXJ080HF5Q00D0H61P06=SH`1NGUh0HV9R065QH@02061PH00<
05mOG`1JFUX0GUiN069RHP1SHf<0JVYZ06ATI01OGel0HV9R065QH@1TI6@0JFUY0P1RHV80201WIfL0
IFEU06][J`1TI6@0J6QX06IVIP1WIfL0KFe]0P1XJ6P02`1TI6@0IFEU06MWI`1RHV80G5aL05QHF01E
EED0EeMG05mOG`2HV9P0cLg=0080hN7Q01L0e]KF0<_;b`3<c<`0eMGE0=3@d032`/80][Jf0:JVYP2O
Wil0YjNW0;2`/02XZ:P0^KVi0;jn_P2VYZH0Shn?06][J`1TI6@0KFe]07]kN`2<S8`0RHV908B4Q002
0861P@0[08R8R021PH40Ogmo07emO@1hN7P0MGEe06i^KP1[Jf/0LG5a07YjNP1hN7P0OWin08B4Q020
P800PX:20861P@20P800Ng]k07UiN@1jNWX0NGUi07IfMP1iNGT0OWin07moO`1cLg<0O7al08N7Q`2?
Shl0RXZ:0820P01iNGT0MWIf06e]K@1ZJVX0G5aL06IVIP1TI6@0JFUY05]KF`1EEED0CTi>04M7A`02
03lo?`0504=3@`1FEUH0B4Q804Y:BP16ATH00P11@D401@1QHF40FUYJ04i>CP18B4P0A4A40080?Cdm
0P0n?Sh02`0e=CD0;Rh^02XZ:P0/;2`0<S8b03`l?01PH600Ogmo07=cL`0f=SH0:RXZ00809BDU00/0
;Bd]02HV9P0[:b/0<c<c05ADE01PH600HF5Q030`<01UIFD0>3Ph02/[:`0202l_;`0i03@d=00n?Sh0
D51@04];B`0n?Sh0?clo0492@P0b<S80;Rh^02d];@0g=cL0EeMG06UYJ@1LG5`0:RXZ02PX:00U9BD0
=SHf07alO02NWYh0RXZ:03Ti>@0S8b<0:RXZ04I6AP1ZJVX0UYJF096AT@1jNWX0GemO06i^KP1hN7P0
QXJ609ZJVP2f][H0a/K60<G5a@2n_[h0`l?30<O7a`34a<@0`/;20<30`02o_kl0_Kfm0;jn_P2l_;`0
_kno0;jn_P2i^KT0^;Rh0;:b/P2g]kL0^KVi0;Fe]@2b/[80];Bd00<0]kNg00X0^KVi0;Rh^02i^KT0
/K6a0:b/[02`/;00[Zj^0:ZZZP2XZ:P0Zj^[0P2e]KD01P2d];@0]KFe0;6a/@2d];@0[Zj^0;Vi^@80
^k^k00`0`L710;fm_@30`<00_;bl0;no_`2m_Kd0^k^k0;fm_@2k^k/0][Jf0;^k^`2i^KT20;>c/`0E
0:FUY@2ATI40MgMg05eMG@1<C4`0BDU905aLG01XJ6P0GemO055AD@0n?Sh0AdM706UYJ@1UIFD0IfMW
06EUI@1SHf<0Bd];07moO`2BTY80Q8B40080Kfm_00X0PH6107MgM`1/K6`0IfMW08>3P`2DU9@0V9RH
09VIV@2CTi<0XZ:R0`2WYjL03`2_[jl0/;2`0:n_[`2e]KD0_Kfm0<[:bP3@d=00a/K609RHV01NGUh0
<c<c02PX:00Y:BT0:RXZ02TY:@0202l_;`0803Hf=P0Y:BT0:2PX02`/;00];Bd0;Rh^038b<P0d=3@2
034a<@80;bl_01L0<S8b03@d=00k>c/0=cLg03hn?P0i>CT0>3Ph04E5A@0e=CD0<S8b030`<00^;Rh0
:b/[03De=@0Z:RX0;Bd]02TY:@0/;2`0:BTY030`<00c<c<0=3@d03Lg=`02038b<P0:02l_;`0b<S80
@D510492@P1<C4`0F5QH071`L021PH40RXZ:08V9R@80QHF500L0QXJ608V9R@26QXH0RHV909>CT`2K
Vi/0WIfM0080YJFU00P0Xj>S0:JVYP2/[:`0ZZZZ0:RXZ02YZJT0YjNW0:FUY@80Xj>S0P2WYjL01`2V
YZH0YjNW0:>SX`2SXj<0X:2P0:6QX@2TY:@00P2UYJD01@2TY:@0XZ:R0:2PX02RXZ80Xj>S0080XJ6Q
00<0Xj>S0::RXP2QXJ400P2QXJ4209nOW`0509fMW@2SXj<0WIfM09jNWP2KVi/00`2MWId04`2PX:00
W9bL09jNWP2MWId0XJ6Q09fMW@2KVi/0W9bL09^KV`2NWYh0W9bL09jNWP2KVi/0VYZJ09bLW02KVi/0
VYZJ09VIV@2GUiL00P2JVYX309NGU`0309FEU@2JVYX0UiNG00h0b>3H000<0<SPf080Jf][00T0KVi^
06YZJP1YJFT0K6a/075aL@1/K6`0KFe]06IVIP1YJFT00P1XJ6P03`1SHf<0IFEU06ATI01ZJVX0HF5Q
06=SH`1TI6@0J6QX06EUI@1VIVH0GemO069RHP1`L700Lg=c07QhN0020861P@0808^;R`2@T900UiNG
09^KV`2PX:00YZJV0:FUY@2[Zj/20:f][@090:b/[02][Jd0Zj^[0:^[Z`2][Jd0Zj^[0:VYZ@2[Zj/0
ZZZZ00<0[:b/01H0[Zj^0:f][@2YZJT0Xj>S0::RXP2PX:00VYZJ09>CT`2;Rh/0R8R80861P@1gMgL0
IVIV05aLG01CDe<0BTY:0451@@14A4@0Bd];04U9B@1HF5P0EEEE0P1GEeL305UIF@0705QHF01MGEd0
GemO05eMG@1KFe/0FUYJ061PH002069RHP0=05]KF`1OGel0HV9R065QH@1NGUh0GEeM069RHP1QHF40
GemO061PH01TI6@0J6QX061PH00205mOG`03061PH01TI6@0HF5Q0080HV9R00@0IFEU06MWI`1[Jf/0
JFUY0P1WIfL03P1]KFd0Jf][06a/K01UIFD0Jf][06IVIP1TI6@0GUiN05]KF`1GEeL0E5AD05UIF@1o
Ogl0a/K60`3Hf=P02@3MgMd0dm?C0<K6aP37alL0d=3@0;fm_@2YZJT0X:2P096AT@020:n_[`0H0:^[
Z`2l_;`0/;2`0:NWY`2QXJ40M7Ad05mOG`1RHV80JFUY08R8R02?Shl0Ogmo08:2PP2;Rh/0Q8B407]k
N`1lO7`0Ogmo08:2PP1lO7`0M7Ad06a/K01_Kfl0MGEe0P20P800201kNg/0OWin08F5Q@1kNg/0OWin
07]kN`1lO7`0NWYj0P1hN7P07`1lO7`0Ng]k07alO01nOWh0N7Qh08>3P`2=SHd0RHV908R8R02:RXX0
RHV908^;R`2=SHd0R8R807QhN01bLW80Hf=S04i>CP0h>3P0<S8b03@d=00m?Cd0@d=303`l?01>CTh0
De=C05ADE01CDe<0@41004I6AP1=CDd00P1GEeL0101RHV80EeMG04Q8B012@T8203hn?P0:0492@P0n
?Sh0:b/[02@T900X:2P0;Bd]05ADE01bLW80Jf][0451@@80:BTY0P0X:2P0@`0/;2`0:RXZ02l_;`1B
DU80F5QH06e]K@0e=CD0GUiN04E5A@0Z:RX0:BTY02HV9P0_;bl0;Bd]03Lg=`0k>c/0?3`l05MGE`1L
G5`0D51@04E5A@0b<S80?Shn04U9B@1TI6@0J6QX03/k>`0a<C409bLW02h^;P1TI6@0Y:BT096AT@1/
K6`08R8R020P800Z:RX0B4Q809:BTP2^[Zh0TY:B075aL@1kNg/0NGUi07MgM`23Ph<0VIVI0;:b/P2n
_[h0`L710<C4a036a/H0alO70<?3``32`/80`<300;no_`31`L40_Kfm0;bl_02m_Kd0^k^k0;Zj^P2f
][H0]kNg0;Fe]@2j^[X00P2f][H30;Bd]080]KFe01L0][Jf0;Bd]02^[Zh0/;2`0;>c/`2_[jl0Zj^[
0:b/[02`/;00][Jf0;:b/P2j^[X0[Zj^0;6a/@2`/;00][Jf0;bl_02n_[h0`<300<71`@2n_[h0`L71
0<30`0020<71`@0I0;no_`2n_[h0^[Zj0;fm_@2g]kL0/K6a0:JVYP2HV9P0LG5a05YJFP1BDU80B4Q8
051@D01LG5`0EUIF03hn?P15ADD0De=C06MWI`1_Kfl0M7Ad06IVIP1OGel0D51@07AdM00208j>SP09
07]kN`1]KFd0OGem0861P@1mOGd0Hf=S07AdM02>SXh0Vi^K0080V9RH01@0VYZJ0:BTY02WYjL0Xj>S
0:RXZ02[Zj/0[Zj^0:ZZZP2][Jd0][Jf0;fm_@35aLD0c/k>0<c<c02/[:`0IVIV03@d=00V9RH0:RXZ
02d];@809bLW00X09BDU020P800T92@0:RXZ030`<00];Bd0;2`/02h^;P0c<c<0<S8b0P0d=3@04@0e
=CD0>3Ph0410@00l?3`0=SHf03@d=015ADD0@d=303Hf=P0e=CD0@D5103De=@0a<C40;bl_03De=@0a
<C40;2`/0080<30`01@0<c<c03Lg=`0a<C40=cLg03Xj>P0d=3@0<S8b034a<@0b<S80@D5104E5A@1G
EeL0K6a/07alO028R8P0SXj>08Z:RP2;Rh/0RHV908b<S080Q8B400D0TI6A09ZJVP2PX:00YJFU0:NW
Y`020:FUY@030:NWY`2SXj<0YJFU0080Xj>S00P0ZJVY0:JVYP2VYZH0Z:RX0:BTY02VYZH0XZ:R0:FU
Y@80XZ:R00T0Y:BT0::RXP2RXZ80Xj>S0:FUY@2WYjL0Xj>S0::RXP2QXJ400P2RXZ80302QXJ40YJFU
0:2PX02NWYh0Y:BT09jNWP2PX:00WinO09fMW@2NWYh0X:2P09bLW080WYjN00/0X:2P09nOW`2JVYX0
Vi^K09fMW@2OWil0XJ6Q09jNWP2MWId0VYZJ09bLW00209^KV`0309fMW@2NWYh0Vi^K00<0VIVI00T0
V9RH09JFUP2JVYX0U9BD09ZJVP2HV9P0VYZJ09VIV@2KVi/03P38h=P000`0b>3H0P1ZJVX01`1[Jf/0
JVYZ06YZJP1XJ6P0JFUY06QXJ01]KFd00P1XJ6P01P1VIVH0I6AT06=SH`1TI6@0HV9R06YZJP80I6AT
0P1SHf<0501/K6`0IVIV06YZJP1YJFT0K6a/075aL@1jNWX0P82008:2PP2:RXX0U9BD09JFUP2JVYX0
XZ:R0:BTY02XZ:P0ZZZZ0:^[Z`2ZZZX0[Jf]0`2/[:`03`2ZZZX0[Zj^0:n_[`2YZJT0Zj^[0:b/[02^
[Zh0[Jf]0:b/[02^[Zh0[:b/0:VYZ@2TY:@0WIfM09^KV`02096AT@0908b<S020P800MGEe06][J`1I
FET0EEEE04i>CP17AdL0@d=30080AdM700D0Cdm?055AD@1CDe<0F5QH05eMG@0205YJFP0@05eMG@1K
Fe/0GUiN065QH@1SHf<0GemO05iNGP1LG5`0Hf=S065QH@1RHV80IVIV05mOG`1QHF40H61P06ATI080
HV9R00`0IFEU05iNGP1QHF40HF5Q06=SH`1RHV80IFEU069RHP1SHf<0GemO069RHP1SHf<206ATI080
IVIV00@0KFe]06MWI`1UIFD0Jf][0P1VIVH02P1PH600Hf=S05]KF`1EEED0FEUI05ADE01OGel0YZJV
0=cLg03MgMd20<g=c@140=GEe@3Kfm/0c/k>0;bl_034a<@0_[jn0:^[Z`2KVi/0WIfM0:j^[P2d];@0
][Jf0;Bd]02KVi/0[Zj^09ZJVP1/K6`0FEUI05QHF01WIfL0Ogmo08b<S020P800Q8B408J6QP24Q8@0
NGUi07YjNP22PX80RHV907emO@1dM7@0JFUY06=SH`1[Jf/0OWin08B4Q01jNWX0Ph>308:2PP1jNWX0
Ng]k0861P@1jNWX0N7Qh07YjNP1hN7P0Lg=c07UiN@1jNWX0Ogmo07=cL`1hN7P0Ph>308V9R@21PH40
QHF508V9R@2=SHd0Ti>C08V9R@2;Rh/0R8R806m_K`1FEUH0?Cdm03Lg=`1:BTX205eMG@0>04M7A`15
ADD0A4A4051@D01KFe/0EeMG05ADE015ADD0A4A404e=C@1RHV80J6QX055AD@17AdL203hn?P0L04E5
A@0o?cl0?Shn02d];@0Z:RX0<c<c03Ti>@1MGEd0N7Qh069RHP0];Bd0:b/[02HV9P0T92@09RHV02LW
9`0X:2P0B4Q804i>CP1^KVh0?3`l069RHP1IFET0;Bd]02h^;P0[:b/0;Bd]02`/;080:b/[01P0=3@d
0410@01PH600De=C04Y:BP13@d<0E5AD05EEE@1PH600GUiN059BDP0n?Sh09bLW02HV9P1=CDd0PX:2
092@T01mOGd0:RXZ01hN7P0O7al0;Rh^071`L02UYJD209nOW`0?092@T01oOgl0M7Ad07AdM01oOgl0
TI6A0:b/[02o_kl0`L710<C4a037alL0a/K60<C4a02o_kl0_;bl0080_kno00L0_;bl0;^k^`2h^;P0
^;Rh0;Fe]@2g]kL0[jn_0080]KFe00H0];Bd0;Ng]`2a/K40/K6a0;Bd]02g]kL30;Fe]@0?0;2`/02^
[Zh0[Zj^0:f][@2^[Zh0/K6a0:n_[`2d];@0]kNg0;6a/@2[Zj/0[jn_0;Jf]P2k^k/0_;bl0080_Kfm
00D0`<300<;2`P31`L40`L710;no_`030;jn_P0T0<C4a032`/80][Jf0;Jf]P2OWil0LG5a05IFEP1=
CDd0AdM704I6AP0i>CT0<S8b03Lg=`18B4P0JVYZ06a/K01bLW80K6a/059BDP16ATH0Hf=S08^;R`2B
TY80PX:206YZJP1dM7@0RXZ:07YjNP1_Kfl0JVYZ07alO02ATI40VYZJ092@T02IVIT0V9RH0`2YZJT0
2@2[Zj/0ZJVY0:n_[`2][Jd0/K6a0;Ng]`2e]KD0^KVi0<71`@020<W9b@040;Rh^01nOWh0>c/k038b
<P<0:RXZ00@0=CDe02<S8`0U9BD09bLW0P0Z:RX01`0/;2`0;Rh^030`<00d=3@0=SHf03Ph>00f=SH0
0`0d=3@0400f=SH0>c/k03/k>`0k>c/0?Cdm03@d=00h>3P0<c<c030`<00d=3@0=CDe034a<@0];Bd0
;2`/02h^;P0b<S8203<c<`05030`<00g=cL0;bl_034a<@0c<c<00P0i>CT01P0l?3`0EEEE06ATI01h
N7P0QHF508n?S`80SXj>0240Shn?09BDU02>SXh0QXJ6096AT@2FUYH0W9bL0:6QX@2SXj<0ZJVY0:FU
Y@2WYjL0Z:RX0:JVYP2SXj<0WinO0:NWY`2XZ:P0XZ:R0:>SX`2TY:@0Xj>S0:BTY02SXj<0Z:RX0:>S
X`2QXJ40YZJV0:6QX@2UYJD0Xj>S0:6QX@2TY:@00P2UYJD30::RXP090:6QX@2JVYX0XZ:R0:2PX02N
WYh0VIVI0::RXP2PX:00WYjN0080WIfM00H0W9bL09nOW`2MWId0WYjN09fMW@2OWil409jNWP80W9bL
00H0WinO09fMW@2LW9`0WYjN09fMW@2LW9`209ZJVP0709^KV`2GUiL0Vi^K09ZJVP2IVIT0U9BD09FE
U@0209VIV@0309NGU`38h=P0b>3H00`0b>3H000<0<SPf080IfMW00P0JFUY06QXJ01WIfL0Jf][06UY
J@1[Jf/0J6QX06UYJ@<0J6QX0P1TI6@00`1UIFD0IfMW06=SH`0206EUI@0>06ATI01SHf<0K6a/069R
HP1UIFD0KFe]071`L01dM7@0Ogmo0820P02=SHd0T92@09BDU02KVi/20:2PX0040:NWY`2ZZZX0ZJVY
0:^[Z`80[Zj^0P2YZJT01P2ZZZX0Zj^[0:ZZZP2[Zj/0Z:RX0:ZZZP80Zj^[01d0[Zj^0:f][@2ZZZX0
Zj^[0:>SX`2OWil0WIfM092@T02>SXh0S8b<0861P@1dM7@0I6AT05eMG@1ADE40B4Q80451@@1;Bd/0
@T9204m?C`1ADE40De=C05ADE01MGEd0EUIF05]KF`1HF5P0GUiN05]KF`0205iNGP04061PH01OGel0
HF5Q05mOG`80GEeM00D0G5aL05mOG`1MGEd0GemO06EUI@0206UYJ@0906=SH`1PH600GUiN069RHP1P
H600GemO05aLG01TI6@0GUiN0080HF5Q01H0GUiN06MWI`1ZJVX0JFUY06YZJP1[Jf/0K6a/06][J`1W
IfL0Hf=S06MWI`1TI6@0HF5Q05iNGP1OGel0EeMG05UIF@1GEeL0MgMg0;Zj^P3Ph>00f][J0P3<c<`0
>P33`l<0clo?0=WIf@3<c<`0^KVi0;Jf]P2ZZZX0Y:BT0:NWY`2[Zj/0^k^k0;bl_02QXJ40WYjN0:b/
[020P800JFUY069RHP1IFET0HF5Q07AdM01mOGd0QXJ608:2PP1mOGd0N7Qh07MgM`1mOGd0Rh^;08N7
Q`25QHD0NGUi07IfMP1VIVH0H61P07]kN`1lO7`0PX:207inOP1oOgl0NWYj08R8R022PX80M7Ad07Qh
N01jNWX0LG5a071`L01kNg/0OGem07YjNP1fMWH0OGem07]kN`24Q8@0Rh^;08R8R02@T90208^;R`0H
08V9R@27QhL0Ph>306m_K`1YJFT0J6QX05mOG`1bLW80Kfm_05]KF`1?Cdl0CTi>04Q8B01BDU80CTi>
04Y:BP19BDT0AdM704=3@`10@400BTY:05EEE@1NGUh0De=C0P1@D500A01=CDd0?clo03hn?P0o?cl0
=cLg030`<00b<S80?Cdm05aLG01SHf<0BTY:02`/;00W9bL092@T02HV9P0W9bL0:b/[03`l?00m?Cd0
IFEU04Q8B01QHF40Lg=c03dm?@0^;Rh0=SHf03/k>`0f=SH0>CTi03`l?00f=SH0CDe=0861P@1RHV80
BTY:0492@P1CDe<0Kfm_07MgM`1NGUh0De=C04E5A@0/;2`09RHV038b<P1<C4`0OGem08F5Q@1ADE40
7alO024Q8@0Y:BT0AdM7092@T02OWil0/K6a0:j^[P29RHT0NWYj06i^KP1gMgL0NWYj08n?S`2[Zj/0
_;bl0<K6aP37alL0aLG50P33`l<02P2n_[h0`/;20<30`02o_kl0_[jn0;Jf]P2d];@0]KFe0;>c/`2`
/;020;Fe]@0B0;Bd]02i^KT0]KFe0;Fe]@2_[jl0/k>c0;Vi^@2c/k<0]KFe0;>c/`2a/K40[Jf]0;6a
/@2][Jd0];Bd0;6a/@2_[jl0[Zj^0P2`/;001`2f][H0]KFe0;jn_P32`/80^k^k0;Zj^P30`<000P33
`l<01`30`<00^k^k0<;2`P2l_;`0_kno0<?3``36a/H00P31`L401P2j^[X0ZJVY0820P01HF5P0=cLg
030`<080;Rh^01/0>CTi05mOG`1/K6`0LW9b06MWI`1<C4`0?3`l061PH025QHD0Ti>C08R8R01`L700
JFUY07]kN`25QHD0M7Ad06m_K`20P800RXZ:09BDU02JVYX0Ti>C09RHV02IVIT0ZJVY0:JVYP2][Jd0
0P2ZZZX03P2^[Zh0[:b/0:j^[P2c/k<0]KFe0;:b/P2k^k/0`/;20<S8b03=cLd0_kno09VIV@1QHF40
>CTi0P0];Bd0300U9BD09RHV02PX:00Z:RX0:BTY02XZ:P0_;bl0;Rh^034a<@0`<300=3@d03De=@80
<c<c01P0<S8b03De=@0e=CD0>3Ph03@d=00c<c<0>SXj03@d=00n?Sh0=SHf02`/;00_;bl0;2`/02h^
;P0];Bd0:b/[03@d=00Z:RX0=SHf03De=@0d=3@0<S8b03<c<`0b<S8202h^;P0803Lg=`0c<c<0B4Q8
065QH@1`L700Ph>308V9R@2BTY82096AT@0;08n?S`2<S8`0RHV9092@T02BTY80Vi^K0:2PX02QXJ40
Z:RX0:>SX`2XZ:P00P2WYjL00`2VYZH0YJFU0:ZZZP020:JVYP@0Y:BT00`0Z:RX0:JVYP2WYjL0Y:BT
0:NWY`2UYJD0Xj>S0::RXP2SXj<0X:2P0:>SX`2RXZ820:6QX@0<0:2PX02QXJ40X:2P09jNWP2PX:00
WIfM09bLW02OWil0W9bL0:6QX@2PX:00WinO0P2MWId0102KVi/0WinO09jNWP2QXJ4209jNWP0309ZJ
VP2NWYh0VYZJ0080WIfM00d0Vi^K09ZJVP2KVi/0VYZJ09jNWP2JVYX0W9bL09NGU`2KVi/0VIVI09nO
W`2FUYH0VIVI0080Vi^K00<0UYJF09VIV@38h=P03@38h=P000`0b>3H0P1/K6`01P1ZJVX0KFe]06YZ
JP1YJFT0Jf][06QXJ080IVIV0P1XJ6P0701UIFD0I6AT06ATI01XJ6P0HF5Q06UYJ@1QHF40JVYZ06MW
I`1SHf<0IFEU06MWI`1[Jf/0KFe]07=cL`1jNWX0P82008N7Q`2<S8`0TY:B09BDU02GUiL0X:2P0:>S
X`2TY:@0YZJV0:^[Z`2/[:`20:^[Z`80ZJVY00P0/K6a0:b/[02_[jl0[:b/0:f][@2[Zj/0[Jf]0:RX
Z080Zj^[00l0ZJVY0:RXZ02OWil0WinO09ZJVP2GUiL0T92@08R8R025QHD0MgMg06UYJ@1JFUX0EeMG
04e=C@17AdL00`1:BTX0101ADE40FEUI05UIF@1JFUX205mOG`0<05aLG01OGel0H61P05iNGP1RHV80
GUiN06IVIP1RHV80G5aL065QH@1SHf<0H61P0`1QHF400`1TI6@0IFEU06QXJ00205mOG`0O05iNGP1O
Gel0GEeM05mOG`1TI6@0H61P069RHP1VIVH0IFEU065QH@1SHf<0IVIV06UYJ@1TI6@0JVYZ06a/K01[
Jf/0IfMW06IVIP1QHF40IFEU05eMG@1KFe/0F5QH055AD@1EEED0J6QX0:JVYP3EeMD0dm?C0=[JfP02
0=?Cd`0?0<S8b02n_[h0b<S80=GEe@36a/H0/k>c0:b/[02QXJ40XZ:R0:n_[`2j^[X0[:b/09jNWP2X
Z:P0XZ:R0080Ph>30340Ogmo06MWI`1RHV80IVIV06m_K`25QHD0OWin07YjNP1iNGT0OGem08F5Q@2:
RXX0S8b<08R8R020P800PH6107alO01[Jf/0KFe]07]kN`22PX80P82007emO@1lO7`0QHF507emO@1n
OWh0Ph>307UiN@1fMWH0MgMg07UiN@1kNg/0PH6107emO@1hN7P0Lg=c07QhN02:RXX0SHf=08b<S028
R8P0RXZ:08b<S029RHT0PH6107moO`22PX80Ng]k0080Jf][0100EeMG05EEE@1@D500I6AT06m_K`1/
K6`0D51@03/k>`0j>SX0@T920410@012@T80ADE504];B`1FEUH0BDU90P14A4@03`1?Cdl0?Shn03Ti
>@0i>CT0?3`l03/k>`0c<c<0>CTi03dm?@1ADE40D51@03Lg=`0^;Rh0:2PX02XZ:P0202LW9`1303@d
=00f=SH0GemO06EUI@1?Cdl0KFe]04I6AP0[:b/0<30`03/k>`0g=cL0ADE503Ti>@0d=3@0?Shn06EU
I@1hN7P0I6AT04Y:BP0o?cl0GUiN07QhN01nOWh0M7Ad06EUI@13@d<0:RXZ02/[:`0/;2`0EUIF08>3
P`1fMWH08R8R020P800L71`0<C4a07YjNP2NWYh0T92@0;6a/@2b/[80Rh^;07]kN`1gMgL0MGEe07Ui
N@2>SXh0Y:BT0;fm_@38b<P0a<C40;no_`32`/80`L710<K6aP34a<@0`<300;^k^`2h^;P0][Jf0;:b
/P2e]KD0];Bd0;:b/P2e]KD0];Bd0;Ng]`020;^k^`80/k>c00H0]kNg0;Bd]02i^KT0]kNg0;Jf]P2_
[jl20;:b/P060;Bd]02f][H0/[:b0:RXZ02[Zj/0/K6a0P2g]kL20;fm_@80_kno00@0^[Zj0;^k^`30
`<00_Kfm0P2k^k/01030`<00`l?30<30`034a<@20<?3``0U0;jn_P30`<00^k^k09NGU`15ADD0;Bd]
02<S8`0Z:RX0AdM705mOG`1bLW80Kfm_05]KF`0m?Cd0AdM707QhN02EUID0Shn?07UiN@1YJFT0JVYZ
07MgM`1nOWh0IFEU06YZJP20P800Rh^;09ZJVP2MWId0WYjN0:6QX@2LW9`0Z:RX0:^[Z`2YZJT0[:b/
0:f][@020:VYZ@0<0:n_[`2a/K40[jn_0;6a/@2l_;`0^k^k0<;2`P33`l<0alO70<g=c@2l_;`0PX:2
0P0k>c/03@0V9RH09BDU02/[:`0i>CT0:2PX02`/;00_;bl0<c<c02l_;`0a<C40=3@d030`<00f=SH0
0P0e=CD0200d=3@0>c/k03De=@0f=SH0=CDe030`<00a<C40=cLg0P0c<c<05P0e=CD0;Bd]02/[:`0[
:b/0;Rh^03Ph>00/;2`0=3@d03<c<`0g=cL0>SXj030`<00b<S80>SXj03@d=00l?3`0=SHf03hn?P1H
F5P0JVYZ08J6QP27QhL209:BTP0;09BDU02BTY80SHf=08j>SP2@T900TI6A09RHV02MWId0X:2P0:RX
Z02UYJD00P2VYZH00`2TY:@0YJFU0:NWY`020:JVYP060:>SX`2UYJD0Y:BT0:RXZ02ZZZX0YjNW0P2U
YJD0102TY:@0Xj>S0:6QX@2RXZ820:6QX@030:FUY@2QXJ40XZ:R0080X:2P00D0Y:BT0:6QX@2RXZ80
X:2P09jNWP020:2PX00309jNWP2LW9`0WinO0080W9bL00T0Vi^K09ZJVP2LW9`0W9bL09^KV`2MWId0
XJ6Q09^KV`2QXJ401@2MWId01@2JVYX0WIfM09ZJVP2LW9`0VIVI0080VYZJ00D0UIFE09VIV@2MWId0
VIVI09NGU`0309VIV@0309FEU@38h=P0b>3H00`0b>3H000<0<SPf080JVYZ02P0JFUY06][J`1^KVh0
IfMW06YZJP1WIfL0J6QX06a/K01[Jf/0IFEU06UYJ@1TI6@0HV9R06QXJ01TI6@0JFUY06IVIP1YJFT0
HV9R06EUI@1WIfL0JVYZ06UYJ@1`L700NGUi07moO`23Ph<0R8R808b<S02CTi<0UiNG09ZJVP2LW9`0
Xj>S0::RXP2XZ:P0YjNW0:f][@2^[Zh0[:b/0P2][Jd0102[Zj/0[:b/0:f][@2[Zj/20:b/[0030:^[
Z`2^[Zh0ZZZZ0080[:b/01H0Xj>S0:6QX@2NWYh0VIVI09>CT`2=SHd0QHF507alO01bLW80JFUY05YJ
FP1KFe/0Bd];04I6AP18B4P0DE5A04];B`1CDe<0FEUI05ADE01IFET0GUiN0P1LG5`08@1NGUh0H61P
05UIF@1RHV80GUiN05eMG@1UIFD0GUiN06EUI@1QHF40GemO06IVIP1NGUh0H61P05mOG`1VIVH0HF5Q
05mOG`1UIFD0GUiN05mOG`1SHf<0G5aL065QH@1UIFD0IVIV06=SH`1PH600IFEU06ATI01WIfL0I6AT
06IVIP0206EUI@80Hf=S00d0JVYZ06=SH`1MGEd0FEUI05aLG01BDU80CTi>05EEE@2:RXX0bLW90>3P
h039bLT0b/[:00<0dm?C00P0aLG50;Jf]P38b<P0dM7A0<?3``2`/;00W9bL0:FUY@80/k>c02<0WinO
0;2`/02^[Zh0T92@08R8R02KVi/0W9bL06i^KP1OGel0IVIV07EeM@21PH40Ogmo07emO@22PX80R8R8
08b<S026QXH0RHV908R8R025QHD0QhN708>3P`1hN7P0IVIV075aL@1hN7P0MWIf07YjNP1kNg/0OWin
0820P021PH40P8200861P@0207QhN00T07EeM@1nOWh0Ph>307inOP1lO7`0MgMg07=cL`1kNg/0Rh^;
08j>SP2?Shl0R8R808j>SP2?Shl0Q8B407QhN01^KVh0I6AT055AD@1;Bd/0F5QH07QhN01iNGT0QXJ6
0820P01fMWH0FUYJ05EEE@10@400>SXj03dm?@10@400Cdm?05MGE`1FEUH0De=C0P1=CDd20451@@0F
03dm?@11@D40=cLg03Lg=`0j>SX0;Rh^030`<00n?Sh0Cdm?04i>CP0_;bl09RHV02<S8`0T92@0:2PX
02h^;P0g=cL0B4Q806IVIP1/K6`0M7Ad05eMG@80>c/k03X0?Cdm03Lg=`0/;2`0<S8b03@d=00a<C40
>3Ph06=SH`1kNg/0LG5a04i>CP1=CDd0G5aL07YjNP1gMgL0L71`05aLG00c<c<08R8R02HV9P0Y:BT0
H61P07MgM`19BDT06QXJ01/K6`0Q8B40GEeM09RHV01bLW80SHf=0:f][@2[Zj/0UYJF08V9R@1jNWX0
NGUi07alO02>SXh0ZZZZ0;bl_031`L40];Bd0<30`035aLD0a/K60<O7a`2o_kl0_;bl0;:b/P2f][H0
/K6a0:^[Z`2`/;00];Bd0;Ng]`2l_;`0];Bd0P2i^KT06P2b/[80^k^k0;^k^`2a/K40]KFe0;Ng]`2b
/[80];Bd0;>c/`2a/K40];Bd0;Fe]@2b/[80/;2`0:^[Z`2e]KD0/K6a0;^k^`2m_Kd0^k^k0;bl_02o
_kl0`<300;Zj^P2o_kl0_;bl0P2k^k/00`30`<00`l?30<?3``020<?3``80`/;202@0`L710<30`02n
_[h0XZ:R05YJFP0`<300<S8b03hn?P1HF5P0IfMW05aLG00o?cl0@D5105MGE`26QXH0SXj>0820P01d
M7@0IVIV07AdM01iNGT0MgMg06ATI01gMgL0Rh^;08f=S@2FUYH0YJFU0::RXP2VYZH0WinO0:BTY02X
Z:P0ZZZZ0:VYZ@2XZ:P30:ZZZP030:VYZ@2_[jl0[Jf]0080][Jf00H0^[Zj0<30`034a<@0clo?0=3@
d032`/8207emO@0502d];@0W9bL0:2PX02PX:00U9BD00P0Z:RX00`0];Bd0<30`02`/;002030`<00@
038b<P0`<300=cLg03Ti>@0`<300<S8b03Ti>@0g=cL0<S8b03@d=00e=CD0=SHf03<c<`0a<C40;Bd]
02`/;080;Rh^00/0<30`038b<P0a<C40<C4a03Ph>00c<c<0<30`03@d=00/;2`0=3@d02l_;`0203De
=@0704Y:BP1UIFD0MgMg08R8R02ATI40UIFE09:BTP0308n?S`0<092@T02?Shl0TY:B09VIV@2QXJ40
Y:BT0:RXZ02QXJ40Y:BT0:NWY`2VYZH0ZJVY0P2UYJD01`2TY:@0XJ6Q0::RXP2ZZZX0Z:RX0:FUY@2T
Y:@00P2RXZ820:BTY0060:6QX@2RXZ80YjNW0:BTY02PX:00YJFU0P2TY:@01`2PX:00WYjN0:2PX02O
Wil0WIfM09nOW`2RXZ800P2OWil20::RXP0<09jNWP2KVi/0WIfM09ZJVP2LW9`0WIfM09bLW02OWil0
WYjN09fMW@2KVi/0VIVI0P2JVYX209bLW00409ZJVP2LW9`0UiNG09fMW@80VIVI00T0VYZJ09bLW02M
WId0UYJF09^KV`2JVYX0VIVI09JFUP2HV9P03P38h=P000`0b>3H0`1[Jf/00`1_Kfl0JVYZ06UYJ@02
06QXJ00906YZJP1XJ6P0K6a/06EUI@1YJFT0K6a/05mOG`1VIVH0IFEU0080HF5Q0140IfMW06EUI@1U
IFD0JVYZ06e]K@1[Jf/0M7Ad079bLP1oOgl0PX:208J6QP2>SXh0Ti>C09BDU02KVi/0WinO0:>SX`02
0:NWY`040:^[Z`2`/;00Zj^[0:n_[`80[Jf]00<0Z:RX0:NWY`2/[:`00`2[Zj/0602_[jl0[Jf]0:ZZ
ZP2ZZZX0[:b/0:ZZZP2UYJD0WIfM09RHV02CTi<0SXj>08R8R01nOWh0LW9b06e]K@1KFe/0FUYJ05AD
E015ADD0ATI604e=C@1<C4`0DU9B05UIF@80F5QH0100Fe]K05mOG`1GEeL0Fe]K061PH01MGEd0HF5Q
06ATI01LG5`0Fe]K05mOG`1NGUh0I6AT06EUI@1TI6@0HV9R0P1UIFD05@1XJ6P0I6AT069RHP1VIVH0
HV9R06EUI@1RHV80Hf=S06MWI`1SHf<0J6QX06ATI01QHF40Hf=S05mOG`1XJ6P0IVIV06EUI@1QHF40
I6AT06EUI@0206ATI00<05iNGP1LG5`0GUiN05ADE01CDe<0DU9B05UIF@2/[:`0gMgM0=kNgP3@d=00
_;bl0P36a/H0703@d=00dm?C0;jn_P2c/k<0cLg=0<o?c`35aLD0ZZZZ0:JVYP2ZZZX0X:2P0:BTY02e
]KD0WIfM08J6QP2GUiL0Zj^[09BDU01XJ6P0GEeM06MWI`1/K6`0NWYj07inOP25QHD0Ph>308R8R02>
SXh208R8R080QHF50100RXZ:08^;R`21PH40JVYZ061PH01SHf<0LW9b07QhN01mOGd0NGUi07emO@1j
NWX0QHF508N7Q`1hN7P0NGUi0P1jNWX08P21PH40P82007alO01hN7P0MgMg07EeM@20P800S8b<08f=
S@25QHD0OGem07EeM@1`L700HV9R05YJFP1>CTh0De=C07EeM@20P800Rh^;08b<S02;Rh/0PH6106m_
K`1JFUX0EUIF05QHF00o?cl0=3@d04M7A`1CDe<0@T920410@01BDU82069RHP0405EEE@14A4@0>CTi
03Hf=P80@D5101H0<C4a02d];@0^;Rh0;Rh^03dm?@15ADD0ATI6034a<@0[:b/08b<S02`/;00d=3@0
>SXj02l_;`17AdL0MWIf07emO@1jNWX0CDe=03<c<`1<C4`0BDU90P0b<S80;P0`<300;Rh^03Ph>01:
BTX0KVi^08n?S`1dM7@0J6QX05]KF`1NGUh0J6QX06IVIP1oOgl0F5QH02LW9`0R8R8092@T030`<01R
HV80DU9B020P800K6a/07alO04M7A`2>SXh0CDe=05mOG`2<S8`0WYjN0;Bd]02NWYh0TI6A0820P01f
MWH0P82008n?S`2ZZZX0^k^k0;>c/`2j^[X0a<C40<O7a`38b<P0`L710;fm_@2d];@20;Ng]`030;:b
/P2^[Zh0/[:b0080]kNg00<0/[:b0;bl_02l_;`00P2j^[X05@2h^;P0][Jf0;Fe]@2e]KD0/K6a0;Jf
]P2b/[80]kNg0;:b/P2`/;00/k>c0;Bd]02h^;P0];Bd0;Fe]@2j^[X0]KFe0;Rh^02l_;`0^[Zj0;fm
_@020<;2`P030<30`033`l<0`/;20080_[jn0P33`l<01032`/80`l?30<O7a`34a<@30<71`@0L0;>c
/`1jNWX0@D5103Lg=`1@D500HF5Q03hn?P0c<c<0@D51069RHP2=SHd0OWin07IfMP1TI6@0IFEU075a
L@1iNGT0JFUY069RHP22PX80UIFE092@T02EUID0YJFU0:NWY`2XZ:P0Xj>S0:FUY@80YZJV0100Z:RX
0:BTY02ZZZX0YZJV0:FUY@2ZZZX0YZJV0:NWY`2[Zj/0[jn_0;Ng]`2j^[X0`<300<O7a`3=cLd0dM7A
0P2k^k/03P1aLG40;Rh^02TY:@0U9BD09bLW02PX:00W9bL09BDU02`/;00_;bl0<S8b03@d=00f=SH0
;bl_0P0e=CD0:`0b<S80>3Ph03Ti>@0m?Cd0=cLg03Ph>00l?3`0=cLg03Ti>@0`<300:BTY02d];@0Z
:RX0;Rh^02d];@0Y:BT0;Rh^03@d=00k>c/0>3Ph03Ti>@0n?Sh0=SHf038b<P0];Bd0>CTi03@d=00h
>3P0F5QH071`L024Q8@0U9BD09VIV@2CTi<0TY:B09>CT`2>SXh0Ti>C08j>SP2ATI40UIFE09jNWP2M
WId00P2UYJD0402SXj<0ZJVY0:BTY02VYZH0YJFU0:BTY02SXj<0XZ:R0:BTY02XZ:P0YjNW0:FUY@2W
YjL0Xj>S09nOW`2UYJD20:>SX`050:6QX@2PX:00Y:BT0:BTY02SXj<00P2OWil209jNWP80WIfM00L0
WYjN09fMW@2NWYh0WYjN09fMW@2PX:00XJ6Q0080WinO00@0W9bL09fMW@2KVi/0WYjN0P2LW9`00`2K
Vi/0W9bL09bLW00209bLW080WIfM00T0Vi^K09ZJVP2LW9`0VYZJ09bLW02JVYX0VIVI09NGU`2JVYX0
0P2GUiL01@2IVIT0VYZJ09VIV@2GUiL0UYJF00h0b>3H000<0<SPf080Kfm_00P0JVYZ06a/K01YJFT0
JFUY06QXJ01VIVH0JFUY06EUI@80Jf][00X0JVYZ06IVIP1RHV80Hf=S06EUI@1YJFT0IFEU06e]K@1X
J6P0I6AT0P1ZJVX0301/K6`0KFe]07=cL`1kNg/0OGem08J6QP2=SHd0TY:B09NGU`2HV9P0WYjN0:JV
YP80Y:BT00<0[:b/0:^[Z`2[Zj/00`2/[:`07@2[Zj/0Z:RX0:n_[`2ZZZX0Zj^[0:VYZ@2][Jd0Zj^[
0:b/[02][Jd0Z:RX0:JVYP2SXj<0WIfM09NGU`2ATI40RXZ:08R8R01mOGd0Kfm_06IVIP1IFET0DU9B
04i>CP14A4@0ATI604i>CP1<C4`0EeMG0080F5QH00/0EUIF05]KF`1NGUh0GUiN065QH@1SHf<0HF5Q
05]KF`1QHF40GemO061PH002069RHP0306EUI@1QHF40I6AT0080Hf=S0240HV9R06MWI`1UIFD0Hf=S
06MWI`1TI6@0HF5Q06EUI@1MGEd0HV9R061PH01RHV80H61P06ATI01UIFD0GUiN065QH@1SHf<0I6AT
06QXJ01SHf<0J6QX06=SH`1XJ6P0HF5Q05UIF@1FEUH0DU9B055AD@1@D500HF5Q0;^k^`3Kfm/00P3A
dM40303;bl/0^[Zj0;Zj^P2l_;`0cLg=0=7Ad@2n_[h0^;Rh0<K6aP39bLT0_kno0:BTY080WIfM00@0
[jn_0:JVYP27QhL0Ti>C0P2WYjL03024Q8@0M7Ad06ATI01OGel0JFUY075aL@1jNWX0Ng]k07emO@22
PX80R8R808Z:RP80QXJ600H0RXZ:096AT@27QhL0Ng]k07IfMP1WIfL206=SH`0<07IfMP1eMGD0OWin
0820P01nOWh0PX:207emO@1oOgl0OWin08>3P`24Q8@0PX:20P1nOWh07`1iNGT0LW9b06m_K`1dM7@0
PH6107YjNP1nOWh0M7Ad065QH@1HF5P0FUYJ06][J`1iNGT0P82008Z:RP29RHT0Shn?09RHV02=SHd0
RXZ:07=cL`1IFET0EUIF079bLP1OGel0A4A403lo?`11@D40>SXj03hn?P0i>CT00P1CDe<07P1XJ6P0
IVIV04m?C`0d=3@0<c<c03Lg=`0c<c<0:RXZ02TY:@0];Bd0=SHf03Xj>P14A4@0=SHf02`/;00U9BD0
9RHV03@d=00i>CT0<30`03@d=01SHf<0M7Ad092@T01TI6@0?clo051@D01FEUH0@d=302h^;P80;2`/
03@0<S8b03Xj>P16ATH0K6a/08J6QP23Ph<0IfMW05]KF`1:BTX0CDe=05YJFP1YJFT0@41002DU9@0V
9RH092@T030`<01:BTX0;2`/020P800];Bd0=CDe08V9R@18B4P0<30`06=SH`21PH40WIfM0;:b/P2]
[Jd0Ti>C07UiN@1dM7@0QHF508Z:RP2OWil0^;Rh0;jn_P32`/80a/K60<O7a`35aLD0_[jn0;Fe]@2g
]kL0]KFe0;Vi^@2d];@0/;2`0;6a/@2e]KD0^KVi0P2f][H01P2i^KT0^;Rh0;Rh^02g]kL0^;Rh0;Fe
]@80/k>c00X0[jn_0;Bd]02e]KD0];Bd0;Fe]@2a/K40];Bd0;Zj^P2g]kL0^;Rh0P2g]kL02P2m_Kd0
_;bl0;fm_@2o_kl0`<300<;2`P30`<00_[jn0;bl_02o_kl20<?3``050<G5a@31`L40aLG50<G5a@36
a/H00P37alL00`36a/H0`<300:2PX00205aLG00804A4A00^;Rh0;bl_03Xj>P1YJFT0NWYj07EeM@1`
L702061PH00407QhN01[Jf/0H61P06QXJ080RXZ:01T0Rh^;09VIV@2TY:@0YJFU0:RXZ02PX:00YZJV
0:NWY`2UYJD0YjNW0:RXZ02WYjL0Z:RX0:FUY@2VYZH0ZZZZ0:FUY@2[Zj/0[Zj^0;6a/@2[Zj/0_;bl
0<;2`P38b<P0clo?0080d];B0300_;bl07IfMP0h>3P0;Rh^02PX:00[:b/0;2`/02DU9@0Z:RX0:BTY
02`/;00];Bd0=3@d034a<@0c<c<0=cLg034a<@0h>3P0?Cdm03Lg=`0^;Rh0<S8b03Lg=`0l?3`0=cLg
034a<@0];Bd0<30`02h^;P0/;2`0<C4a03De=@0a<C40<S8b03<c<`0f=SH0=3@d034a<@0b<S80:2PX
02l_;`0n?Sh0<C4a038b<P1@D500J6QX07moO`2=SHd209NGU`0@09BDU02ATI40TI6A09BDU02=SHd0
Shn?09FEU@2MWId0WinO0:BTY02VYZH0YJFU0:>SX`2UYJD0YZJV0::RXP80YJFU00<0Xj>S0:BTY02V
YZH00P2VYZH01@2UYJD0XZ:R0::RXP2SXj<0X:2P0080Y:BT00<0Xj>S09jNWP2UYJD00`2QXJ400`2S
Xj<0VYZJ0:6QX@0209bLW00609jNWP2KVi/0WYjN0::RXP2NWYh0WinO0P2LW9`00`2PX:00WinO09bL
W00209bLW00>0:2PX02JVYX0Vi^K09^KV`2JVYX0WIfM09bLW02NWYh0VYZJ09bLW02HV9P0W9bL09^K
V`2GUiL209RHV00509^KV`2JVYX0Vi^K09JFUP2HV9P00P2IVIT00`2DU9@0b>3H0<SPf00<0<SPf000
3038h=P206e]K@0F06a/K01WIfL0I6AT071`L01XJ6P0IFEU06][J`1VIVH0HF5Q06QXJ01WIfL0IVIV
06MWI`1OGel0Hf=S06EUI@1PH600IVIV06ATI01UIFD0J6QX06YZJP80L71`00d0Kfm_07YjNP20P800
Q8B4096AT@2CTi<0V9RH09bLW02IVIT0Y:BT0:JVYP2ZZZX0Z:RX0080[Jf]00T0[:b/0:f][@2][Jd0
[:b/0:NWY`2^[Zh0[:b/0:j^[P2[Zj/00P2ZZZX07@2[Zj/0[Jf]0:^[Z`2VYZH0Xj>S09nOW`2IVIT0
U9BD08b<S027QhL0PH61079bLP1YJFT0FUYJ05MGE`1?Cdl0B4Q804U9B@1<C4`0BTY:05ADE01BDU80
EUIF05QHF01LG5`0GUiN061PH01KFe/0H61P0080GemO00@0H61P069RHP1QHF40GEeM0P1TI6@0:01Z
JVX0GUiN06=SH`1WIfL0HV9R06ATI01VIVH0I6AT06QXJ01TI6@0GUiN06EUI@1TI6@0HV9R05iNGP1T
I6@0GEeM05iNGP1PH600HF5Q061PH01VIVH0IFEU06IVIP1SHf<0J6QX069RHP1SHf<0HF5Q05UIF@1A
DE40D51@04m?C`1EEED0K6a/0<_;b`3Ogml0b<S80<W9b@3Bd]820<S8b0040;Ng]`2h^;P0c/k>0<g=
c@80^k^k02P0_[jn0;no_`2SXj<0UYJF0:JVYP2WYjL0R8R807UiN@2ATI40Z:RX09NGU`1gMgL0OWin
07QhN01[Jf/0IVIV075aL@1eMGD0L71`075aL@1lO7`0R8R808Z:RP25QHD0R8R808Z:RP2;Rh/0Ogmo
08:2PP21PH40Lg=c06MWI`1QHF40Lg=c07EeM@24Q8@0O7al08:2PP1nOWh0NWYj0P24Q8@03P22PX80
Ph>308:2PP1oOgl0NWYj07EeM@1jNWX0N7Qh07MgM`1XJ6P0KFe]08B4Q028R8P0P8200P22PX804027
QhL0Ph>308N7Q`27QhL0SHf=092@T02CTi<0TI6A08J6QP1iNGT0GemO06][J`2;Rh/0NGUi05IFEP13
@d<203/k>`0803dm?@0h>3P0?Cdm03dm?@1;Bd/0J6QX06m_K`1BDU8203Ti>@0;030`<00a<C40<C4a
02h^;P0c<c<0;2`/03Lg=`0o?cl0;Rh^02XZ:P0/;2`00`0`<3000`0_;bl0?3`l06ATI00207moO`04
05ADE01PH600I6AT05eMG@80=3@d02P0<c<c03Lg=`0f=SH0=SHf0451@@1YJFT0UIFE07UiN@1IFET0
B4Q803dm?@1>CTh0HF5Q05mOG`17AdL0;bl_02DU9@0Q8B40:RXZ034a<@0/;2`092@T038b<P21PH40
E5AD02`/;019BDT0FUYJ07emO@2LW9`0][Jf0;:b/P2<S8`0P82007emO@1jNWX0P8200::RXP2g]kL0
`<300`35aLD02P34a<@0_;bl0;Ng]`2g]kL0_;bl0;Vi^@2c/k<0/K6a0;>c/`2d];@20;Jf]P80^KVi
00X0_[jn0;Rh^02f][H0^;Rh0;Zj^P2h^;P0/k>c0;:b/P2d];@0^k^k0P2i^KT06@2b/[80]kNg0;Rh
^02l_;`0_[jn0;Rh^02k^k/0_;bl0;fm_@2o_kl0_;bl0;fm_@2o_kl0`<300;fm_@31`L40`/;20<30
`033`l<0`L710<;2`P35aLD0alO70<W9b@36a/H00P39bLT07P38b<P0^[Zj09ZJVP1PH600=cLg03<c
<`12@T80Fe]K06QXJ01TI6@0FEUI05QHF01SHf<0KFe]06EUI@1MGEd0LG5a08N7Q`23Ph<0Ti>C09RH
V02OWil0YJFU0:JVYP2RXZ80Y:BT0::RXP2SXj<0YZJV0:NWY`80YZJV00`0Y:BT0:JVYP2VYZH0YJFU
0:JVYP2^[Zh0ZZZZ0:JVYP2a/K40][Jf0;^k^`35aLD20<o?c`090=?Cd`30`<00Lg=c03@d=00T92@0
9RHV02TY:@0U9BD0;Bd]0080;bl_02P0<C4a02d];@0f=SH0>3Ph03De=@0m?Cd0=SHf03Ph>00b<S80
=3@d03<c<`0/;2`0<C4a03Hf=P0`<300;2`/030`<00g=cL0:RXZ038b<P0e=CD0<C4a03De=@0_;bl0
=CDe03Xj>P0f=SH0;Rh^02TY:@0[:b/0;Rh^038b<P0a<C40ADE506ATI01gMgL0R8R809>CT`2FUYH0
Ti>C0P2ATI403@2DU9@0Shn?08^;R`2BTY80UiNG09nOW`2SXj<0YZJV0:VYZ@2UYJD0XJ6Q0:>SX`2T
Y:@00P2VYZH01`2SXj<0Z:RX0:VYZ@2XZ:P0Y:BT0::RXP2SXj<00P2RXZ801@2PX:00XZ:R0:>SX`2T
Y:@0X:2P00@0XZ:R00L0XJ6Q09jNWP2NWYh0WIfM0:>SX`2LW9`0WinO0080X:2P0P2MWId0102KVi/0
WYjN09bLW02RXZ8209^KV`0309RHV02MWId0W9bL0080WYjN00L0VIVI09^KV`2LW9`0WIfM09bLW02H
V9P0WIfM0080VYZJ00H0W9bL09fMW@2JVYX0W9bL09ZJVP2GUiL309RHV00309ZJVP2FUYH0b>3H00d0
b>3H000<0<SPf080KVi^00/0JVYZ06EUI@1SHf<0JFUY06IVIP1UIFD0K6a/06YZJP1YJFT0J6QX06UY
J@0206EUI@0<05iNGP1TI6@0IVIV06EUI@1RHV80IVIV06][J`1VIVH0JFUY06m_K`1bLW80MgMg0P1o
Ogl0102=SHd0S8b<08n?S`2FUYH209^KV`030::RXP2WYjL0Y:BT0080ZJVY00`0Zj^[0:VYZ@2XZ:P0
Z:RX0:j^[P2ZZZX0Zj^[0:f][@2/[:`0ZJVY0:ZZZP2[Zj/20:b/[00R0:RXZ02VYZH0Z:RX09fMW@2L
W9`0U9BD09>CT`24Q8@0Ng]k06e]K@1UIFD0G5aL05ADE01>CTh0ATI604Y:BP19BDT0Bd];04m?C`1D
E5@0EEEE059BDP1EEED0F5QH05iNGP1MGEd0HF5Q06=SH`1TI6@0HF5Q069RHP1PH600HF5Q06UYJ@80
H61P00D0IfMW06EUI@1QHF40Hf=S069RHP04065QH@0706EUI@1SHf<0I6AT065QH@1PH600HF5Q061P
H002065QH@0306ATI01RHV80I6AT0080I6AT00H0IFEU06MWI`1TI6@0HV9R05eMG@1KFe/205ADE008
04i>CP1@D500PX:20=7Ad@3MgMd0clo?0;fm_@36a/H20<k>cP0O0<c<c02f][H0^KVi0<k>cP3;bl/0
];Bd09jNWP2a/K40YJFU09VIV@2OWil0QhN707]kN`25QHD0TI6A0:>SX`24Q8@0NGUi08J6QP2@T900
NWYj06UYJ@1_Kfl0Jf][079bLP1dM7@0Ng]k08J6QP2;Rh/0RHV908^;R`0208J6QP0c08V9R@25QHD0
QHF50861P@1oOgl0LG5a06ATI01[Jf/0Ng]k07alO022PX80MgMg0861P@28R8P0Ph>308:2PP27QhL0
Q8B407IfMP1eMGD0OWin08J6QP1mOGd0LG5a07QhN022PX80TI6A08n?S`2;Rh/0SHf=08J6QP22PX80
QXJ608R8R027QhL0RXZ:08n?S`2CTi<0UYJF08>3P`1dM7@0De=C07EeM@2<S8`0QHF5071`L01JFUX0
E5AD04M7A`0m?Cd0>3Ph0080=CDe0380>CTi04M7A`1VIVH0KVi^071`L01ADE40>3Ph03<c<`0`<300
;bl_02h^;P0[:b/0<S8b03Xj>P0l?3`0=SHf02XZ:P0a<C40<c<c03Hf=P0[:b/0;Rh^05eMG@1hN7P0
Ogmo06][J`1jNWX0Jf][05IFEP1=CDd0;Rh^030`<00a<C40>3Ph02h^;P0Z:RX0@D5106m_K`28R8P0
JVYZ055AD@0m?Cd0Bd];05IFEP1HF5P0GEeM051@D00a<C408b<S024Q8@80<30`01L09RHV02LW9`1]
KFd0Jf][0451@@1[Jf/0<c<c04Q8B01iNGT0WinO0;6a/@2b/[80VIVI08R8R01hN7P0MGEe0861P@2L
W9`0];Bd0<30`038b<P0alO70<?3``020<30`0<0^[Zj00@0]KFe0;Rh^02d];@0/[:b0P2e]KD02`2g
]kL0][Jf0;Vi^@2i^KT0^;Rh0;Fe]@2g]kL0][Jf0;^k^`2h^;P0];Bd0080^k^k00P0_;bl0;Rh^02e
]KD0][Jf0;Vi^@2h^;P0_Kfm0;jn_P80^[Zj00T0`<300;no_`30`<00_Kfm0<71`@2m_Kd0`L710;fm
_@2n_[h00P33`l<01031`L40a<C40<G5a@35aLD20<O7a`0>0<S8b03:b/X0a/K60<71`@2`/;00SXj>
05ADE013@d<0JFUY05mOG`1ADE40CTi>05aLG01`L70206a/K00@06][J`1jNWX0RXZ:08f=S@2?Shl0
TY:B09ZJVP2QXJ40WYjN0:2PX02QXJ40WinO0:JVYP2WYjL0Z:RX0:>SX`80YjNW00<0ZJVY0:BTY02U
YJD00P2^[Zh20:NWY`040:ZZZP2][Jd0]KFe0;Ng]`80`l?301<0c/k>0=CDe02e]KD0HF5Q02l_;`0V
9RH09bLW02TY:@0];Bd09RHV02d];@0_;bl0<c<c038b<P0c<c<0>c/k03Lg=`0h>3P0@T920080=SHf
00`0?3`l03@d=00a<C40<S8b030`<00[:b/0<S8b03@d=00`<300<S8b03Lg=`0^;Rh203<c<`0303Lg
=`0l?3`0<C4a0080;Rh^01H0:2PX02`/;00d=3@0=SHf03De=@1JFUX0KFe]07alO02<S8`0UiNG09BD
U02FUYH0Ti>C09JFUP2BTY80Rh^;08f=S@2?Shl0VIVI0:FUY@2SXj<0Y:BT0P2UYJD00`2SXj<0YJFU
0:JVYP020:NWY`0;0:BTY02SXj<0Z:RX0:FUY@2XZ:P0Y:BT0:>SX`2OWil0X:2P0::RXP2PX:000P2R
XZ803`2NWYh0XZ:R09nOW`2OWil0WYjN0:6QX@2MWId0XJ6Q09jNWP2TY:@0W9bL09fMW@2RXZ80W9bL
09nOW`0209fMW@0809jNWP2KVi/0V9RH09bLW02HV9P0WYjN09bLW02JVYX209RHV00409^KV`2IVIT0
WIfM09bLW0<0WIfM0P2LW9`209NGU`0809VIV@2LW9`0UYJF09JFUP2HV9P0VIVI09JFUP2DU9@>0<SP
f0003038h=P206i^KP0R06UYJ@1UIFD0JVYZ06a/K01ZJVX0JFUY06ATI01XJ6P0IfMW06YZJP1[Jf/0
JVYZ06UYJ@1NGUh0IFEU069RHP1XJ6P0H61P069RHP1YJFT0IfMW06YZJP1`L700LW9b07QhN01mOGd0
PH6108V9R@2EUID0Ti>C09NGU`2KVi/0WIfM0::RXP80YZJV00<0ZJVY0:b/[02ZZZX00`2YZJT01P2_
[jl0Zj^[0:^[Z`2][Jd0Z:RX0:n_[`80[:b/01P0Zj^[0:VYZ@2YZJT0YjNW0:>SX`2MWId0VYZJ09BD
U02?Shl0R8R807inOP1dM7@0J6QX05UIF@1FEUH0CTi>04M7A`1<C4`0BTY:04e=C@1@D500De=C05IF
EP1DE5@205YJFP0A065QH@1KFe/0GUiN05aLG01OGel0GEeM065QH@1MGEd0I6AT06MWI`1MGEd0GemO
06=SH`1JFUX0IfMW069RHP1VIVH00`1QHF400`1UIFD0IVIV065QH@0206ATI003061PH01VIVH0IfMW
0080IVIV01D0Hf=S06UYJ@1WIfL0IVIV069RHP1WIfL0HV9R06=SH`1MGEd0G5aL05YJFP1FEUH0Cdm?
04];B`1SHf<0Z:RX0=SHf03Cdm<0e=CD0<W9b@2l_;`00P31`L420<[:bP0]0;Zj^P2k^k/0bl_;0<71
`@2PX:00U9BD0:ZZZP2SXj<0Q8B4075aL@21PH40VIVI09ZJVP2IVIT0NWYj08F5Q@2?Shl0VIVI07Ad
M01[Jf/0JVYZ06=SH`1ZJVX0MWIf07AdM020P800R8R8092@T02<S8`0PX:208J6QP2=SHd0QhN708J6
QP2;Rh/0Ph>307moO`1fMWH0Kfm_071`L01nOWh0Ogmo07UiN@1nOWh0QHF50080Ogmo00P0PH6107em
O@1kNg/0PH6108B4Q027QhL0O7al07MgM`80Ng]k01T0Ogmo08b<S02;Rh/0QhN708B4Q023Ph<0R8R8
08f=S@28R8P0RXZ:08R8R02?Shl0SHf=08B4Q01_Kfl0Bd];07]kN`2>SXh0QXJ607emO@1TI6@0HV9R
05eMG@1@D500A4A40080=cLg00T0>CTi03De=@0j>SX0BTY:071`L01cLg<0HV9R04e=C@0c<c<00P0a
<C40@00`<300=cLg03@d=00e=CD0>3Ph030`<00^;Rh0=cLg03`l?00b<S80;Rh^04e=C@1eMGD0MWIf
07alO01cLg<0NGUi06EUI@1NGUh0DE5A02h^;P0`<300>CTi02XZ:P0V9RH0;Bd]0410@01aLG40SXj>
05aLG00o?cl0ATI605UIF@1OGel0IVIV05mOG`1=CDd0;2`/02/[:`0S8b<09bLW02@T900[:b/0H61P
07]kN`1NGUh0J6QX02`/;00W9bL0@d=3079bLP2BTY80[Zj^0;:b/P2JVYX0QXJ607YjNP20P800RXZ:
0:2PX02_[jl0`<300<_;b`34a<@20<30`0070<71`@2l_;`0][Jf0;>c/`2h^;P0][Jf0;Bd]0030;Jf
]P0;0;bl_02k^k/0^k^k0;bl_02i^KT0^k^k0;Ng]`2n_[h0^[Zj0;bl_02h^;P00`2k^k/00`2h^;P0
][Jf0;:b/P020;Zj^P80^k^k00T0_;bl0;no_`30`<00`<300<71`@2l_;`0_[jn0<30`031`L400P2o
_kl20<;2`P030<71`@33`l<0`/;20080`l?301X0alO70<W9b@37alL0a/K60<;2`P30`<00][Jf08f=
S@1YJFT0DU9B04Q8B01>CTh0IVIV06i^KP1]KFd0J6QX07EeM@23Ph<0SHf=092@T02;Rh/0QhN708j>
SP2?Shl0Ph>308^;R`80TY:B00`0VIVI09nOW`2RXZ80Xj>S0:VYZ@2UYJD0YjNW0:RXZ02VYZH0[:b/
0:n_[`2XZ:P20:BTY0030:RXZ02][Jd0]KFe0080]KFe00D0`<300<[:bP3=cLd0[jn_05IFEP0202/[
:`0I02PX:00];Bd0<C4a02PX:00Y:BT0=3@d02h^;P0b<S80<c<c03De=@12@T80>CTi03De=@0h>3P0
=cLg034a<@0f=SH0=cLg038b<P0^;Rh0;Bd]03Hf=P0_;bl0<C4a02TY:@0202XZ:P0402/[:`0d=3@0
@41003Xj>P80=CDe01H0<S8b030`<00g=cL0<c<c034a<@12@T80IVIV07alO025QHD0TY:B09>CT`2E
UID0TI6A09:BTP2EUID0S8b<08^;R`2>SXh0VIVI09nOW`2RXZ80Y:BT0P2VYZH0202OWil0Y:BT0:FU
Y@2UYJD0WinO0:FUY@2SXj<0Z:RX0P2UYJD02P2WYjL0XZ:R0:FUY@2OWil0YJFU0:>SX`2TY:@0Xj>S
0:2PX02QXJ420::RXP060:>SX`2NWYh0WYjN09fMW@2NWYh0VYZJ0P2MWId02@2VYZH0Vi^K09jNWP2O
Wil0VIVI09jNWP2LW9`0VIVI09bLW00209ZJVP0?09nOW`2KVi/0UiNG09bLW02JVYX0W9bL09ZJVP2K
Vi/0W9bL09fMW@2LW9`0WIfM09jNWP2IVIT0WIfM0080VYZJ00H0UIFE09JFUP2JVYX0V9RH09NGU`2H
V9P>0<SPf0003038h=P206YZJP0X06][J`1XJ6P0Jf][06a/K01ZJVX0IfMW06UYJ@1WIfL0J6QX06EU
I@1ZJVX0I6AT06UYJ@1RHV80JFUY069RHP1VIVH0I6AT06IVIP1WIfL0Jf][06UYJ@1_Kfl0LW9b07Mg
M`1mOGd0PH61092@T02?Shl0TY:B09JFUP2IVIT0WIfM09jNWP2UYJD0YZJV0:NWY`2[Zj/0ZZZZ0:^[
Z`80ZJVY00D0Zj^[0:VYZ@2WYjL0[:b/0:NWY`020:VYZ@80ZZZZ01@0[Jf]0:JVYP2TY:@0XZ:R09^K
V`2JVYX0UiNG08f=S@27QhL0OWin071`L01[Jf/0FUYJ05IFEP1>CTh0CDe=04a<C01;Bd/0Cdm?05IF
EP80De=C00T0EUIF05aLG01EEED0GUiN05YJFP1PH600HF5Q05eMG@1LG5`00P1QHF404@1TI6@0H61P
06EUI@1XJ6P0GemO05QHF01TI6@0GUiN06ATI01UIFD0H61P06YZJP1QHF40GUiN05mOG`1XJ6P0Hf=S
0080HV9R00<0K6a/06EUI@1SHf<00P1SHf<206ATI008065QH@1TI6@0HV9R065QH@1NGUh0FUYJ05UI
F@1ADE4204e=C@07071`L038b<P0gmoO0<_;b`3=cLd0dM7A0<g=c@020;Zj^P080;Vi^@3<c<`0d=3@
0;2`/02g]kL0`l?30;6a/@2GUiL208b<S00J075aL@1fMWH0R8R809RHV02LW9`0R8R808B4Q02IVIT0
YZJV08j>SP1dM7@0KFe]065QH@1JFUX0KVi^07IfMP1hN7P0MgMg07emO@2:RXX0QhN708B4Q02;Rh/0
R8R808F5Q@27QhL208J6QP0608R8R01eMGD0HF5Q06m_K`1gMgL0NWYj0P20P8005023Ph<0N7Qh08:2
PP1nOWh0P82007moO`24Q8@0Ph>30820P026QXH0OGem07QhN01cLg<0MGEe08B4Q02:RXX0Rh^;08N7
Q`2=SHd0RXZ:0P29RHT03`2;Rh/0Q8B408R8R028R8P0Ph>306a/K01GEeL0QXJ608F5Q@28R8P0RHV9
07emO@1_Kfl0Hf=S05UIF@03059BDP0d03`l?00e=CD0=3@d03Ph>01:BTX0H61P06m_K`1aLG40G5aL
0492@P11@D40@T9203De=@0g=cL0=CDe03Ti>@0/;2`0;Rh^03Ti>@0k>c/0<c<c02TY:@0i>CT0I6AT
07emO@2=SHd0M7Ad079bLP23Ph<0MGEe06EUI@1<C4`0:RXZ02/[:`0Z:RX0;2`/038b<P0];Bd0@T92
07QhN023Ph<0EEEE03Ti>@0n?Sh0DE5A06UYJ@1jNWX0GUiN03/k>`0Z:RX09RHV02`/;0808b<S01<0
BDU907emO@10@400EEEE02l_;`0M7Ad08b<S03Xj>P1XJ6P0SXj>0;2`/02m_Kd0X:2P08R8R01lO7`0
Ng]k08J6QP2EUID0[:b/0080aLG500T0_Kfm0;jn_P32`/80_kno0;fm_@2g]kL0];Bd0;>c/`2d];@0
0`2e]KD40;bl_00<0;Vi^@2o_kl0_Kfm0;Vi^@2k^k/0_[jn0;bl_02o_kl0^KVi0;jn_P2h^;P0^k^k
0P2l_;`0102h^;P0^KVi0;^k^`2o_kl20;jn_P030<30`031`L40^k^k0080_Kfm00/0_kno0<30`032
`/80`l?30<;2`P33`l<0aLG50<71`@33`l<0b<S80<W9b@020<S8b0<0a/K602L0bLW90;fm_@2ZZZX0
Q8B405UIF@1;Bd/0HV9R06a/K01^KVh0HV9R07QhN021PH40S8b<08n?S`24Q8@0PH610820P01_Kfl0
KVi^075aL@1kNg/0NGUi07emO@2:RXX0Ti>C09^KV`2RXZ80X:2P0:JVYP2YZJT0YjNW0:FUY@2RXZ80
YJFU0::RXP2SXj<0Z:RX0:^[Z`2a/K400P2d];@01P2f][H0`/;20<k>cP3?cll0Z:RX059BDP80;Bd]
02X0:2PX02/[:`0];Bd0;Bd]02`/;00`<300;Rh^02d];@0^;Rh0=cLg02l_;`0h>3P0=CDe038b<P0a
<C40=cLg03Ph>00k>c/0<30`034a<@0d=3@0<30`02/[:`0W9bL0:BTY02d];@0`<300=3@d03Ti>@0l
?3`0@d=304];B`0h>3P0=cLg034a<@0f=SH0<c<c03Ti>@1HF5P0L71`08>3P`2>SXh209JFUP0D09BD
U02CTi<0UIFE08Z:RP2?Shl0S8b<09RHV02OWil0XZ:R0:NWY`2UYJD0YjNW0::RXP2TY:@0YjNW0:BT
Y02RXZ80Y:BT0:JVYP2UYJD30:BTY0090:FUY@2SXj<0Xj>S0::RXP2PX:00Xj>S0:BTY02SXj<0WinO
0080XZ:R00H0X:2P09jNWP2NWYh0Xj>S09nOW`2PX:0209^KV`0709bLW02PX:00WinO0:2PX02JVYX0
Vi^K09jNWP0209ZJVP80WIfM00P0WinO0:2PX02KVi/0VYZJ09bLW02NWYh0VIVI09^KV`80W9bL00d0
WYjN09ZJVP2LW9`0Vi^K09jNWP2IVIT0WIfM09NGU`2MWId0VIVI09FEU@2HV9P0UIFE00h0b>3H000<
0<SPf080IfMW00X0JFUY06YZJP1WIfL0Kfm_06MWI`1YJFT0J6QX06a/K01TI6@0GemO0P1TI6@01P1U
IFD0IVIV06MWI`1UIFD0HV9R06MWI`80IFEU01@0K6a/06UYJ@1/K6`0KVi^07UiN@1oOgl0Q8B408V9
R@2<S8`0U9BD09VIV@2HV9P0WinO0::RXP2WYjL0YZJV0:b/[02ZZZX0[jn_0:j^[P80Zj^[0P2/[:`0
1`2ZZZX0[:b/0:VYZ@2[Zj/0ZZZZ0:f][@2ZZZX00P2YZJT05@2XZ:P0Y:BT0::RXP2LW9`0UYJF08n?
S`24Q8@0O7al075aL@1TI6@0GUiN05IFEP1DE5@0AdM704E5A@1>CTh0BDU904m?C`1JFUX0DU9B05]K
F`0205aLG00O061PH01OGel0GUiN06=SH`1JFUX0GemO06ATI01PH600GemO069RHP1SHf<0H61P06EU
I@1PH600Hf=S06ATI01VIVH0IFEU065QH@1WIfL0HF5Q06IVIP1SHf<0HF5Q061PH01MGEd0IVIV069R
HP1UIFD0Hf=S06ATI002069RHP08061PH01SHf<0Hf=S06ATI01OGel0FEUI05QHF01FEUH204e=C@08
05=CD`24Q8@0eMGE0=oOg`3AdM40`l?30<K6aP3Bd]820<_;b`0W0;Jf]P2g]kL0dM7A0<C4a02WYjL0
[Zj^0:FUY@2TY:@0TI6A07alO01iNGT0PX:208>3P`2=SHd0Vi^K08:2PP2MWId0Y:BT0:6QX@22PX80
Ng]k07moO`1aLG40GUiN06e]K@1fMWH0LG5a07=cL`1/K6`0O7al08J6QP28R8P0RHV908B4Q02:RXX0
Ogmo0820P02:RXX0Rh^;0080OGem00<0NGUi06m_K`1eMGD00P1oOgl04022PX80O7al07emO@23Ph<0
Ng]k08:2PP28R8P0Q8B408R8R023Ph<0OGem07UiN@1eMGD0M7Ad07UiN@28R8P209:BTP0D092@T029
RHT0QXJ608R8R02<S8`0PX:208>3P`26QXH0PX:206MWI`1>CTh0Ng]k08R8R02<S8`0RHV908N7Q`26
QXH0MWIf06QXJ01GEeL205iNGP0U05ADE01=CDd0>c/k034a<@11@D40BTY:05EEE@1RHV80JVYZ06QX
J01LG5`0ADE503hn?P0g=cL0>c/k03<c<`0a<C40<c<c03De=@0f=SH0=3@d02`/;00j>SX0BTY:061P
H020P800QHF505iNGP1ZJVX0PH6106IVIP1PH600Bd];034a<@0];Bd0:BTY038b<P0202l_;`0]05YJ
FP1aLG40MWIf0492@P0h>3P0CTi>05YJFP1/K6`0I6AT05UIF@0m?Cd0=SHf03/k>`0S8b<0:BTY02h^
;P1nOWh0AdM702/[:`0X:2P07alO01hN7P0S8b<0<c<c05]KF`2<S8`0/[:b0;Vi^@2LW9`0Rh^;07em
O@1hN7P0NGUi08b<S02^[Zh0`<300;fm_@2i^KT0`L710<30`032`/80]kNg0;Bd]02a/K40/;2`0080
]kNg0P2b/[804`2k^k/0_[jn0;^k^`2n_[h0`<300;bl_02m_Kd0_;bl0;fm_@2n_[h0`<300;fm_@2o
_kl0]KFe0;Vi^@2n_[h0_Kfm0;jn_P2j^[X00P2l_;`00`2m_Kd0_[jn0;jn_P020;jn_P050<C4a032
`/80`<300<30`035aLD00P31`L401032`/80`l?30<?3``34a<@20<K6aP@0aLG50200bLW90<c<c038
b<P0`l?30;bl_02OWil0KVi^06UYJ@1WIfL0HV9R05iNGP1cLg<0QHF508f=S@24Q8@0Ogmo07emO@1^
KVh0Hf=S05iNGP1PH600IfMW065QH@1UIFD0KFe]07IfMP26QXH0SXj>08n?S`2CTi<0WinO0:JVYP80
Xj>S00H0XZ:R0:FUY@2ZZZX0ZZZZ0:b/[02a/K420;:b/P0P0;6a/@2k^k/0aLG50<[:bP3=cLd0[Zj^
05ADE00b<S80<30`02PX:00W9bL0:RXZ038b<P0^;Rh0<S8b02`/;00h>3P0;Rh^03@d=00j>SX0?Shn
03/k>`0e=CD0<c<c03Xj>P0m?Cd0;Rh^02XZ:P0_;bl0:BTY02h^;P0_;bl202`/;00:02d];@0e=CD0
?Cdm04=3@`18B4P0?3`l03@d=00l?3`0>SXj038b<P80?3`l00@0DU9B06QXJ022PX80RXZ:0P2EUID0
2`2GUiL0Ti>C09BDU02FUYH0SHf=09:BTP2DU9@0VIVI0:2PX02SXj<0YZJV0080YjNW00`0Xj>S0:6Q
X@2TY:@0XJ6Q0:BTY02SXj<0YJFU0:2PX02SXj<0XZ:R0:BTY02RXZ8209nOW`80Xj>S00<0XZ:R0:6Q
X@2QXJ400P2OWil00`2PX:00WinO09nOW`0309nOW`0309fMW@2NWYh0X:2P0080WinO00T0WIfM09^K
V`2MWId0W9bL09ZJVP2LW9`0VYZJ09bLW02OWil00P2KVi/0302GUiL0VYZJ09VIV@2MWId0W9bL09^K
V`2IVIT0VYZJ09bLW02JVYX0Vi^K09fMW@80VYZJ00H0U9BD09ZJVP2FUYH0Vi^K09JFUP2GUiL>0<SP
f0003038h=P206][J`0>06UYJ@1[Jf/0Jf][071`L01VIVH0IFEU06MWI`1XJ6P0Hf=S05mOG`1VIVH0
HV9R06EUI@1OGel206ATI00506EUI@1WIfL0Hf=S06][J`1YJFT00P1/K6`04@1^KVh0O7al07moO`20
P800QHF5096AT@2@T900UYJF09RHV02LW9`0Y:BT0:NWY`2XZ:P0[:b/0:VYZ@2a/K40[:b/0080Zj^[
02<0[jn_0:^[Z`2ZZZX0ZZZZ0:b/[02][Jd0/;2`0:b/[02YZJT0[:b/0:ZZZP2TY:@0Xj>S09fMW@2I
VIT0U9BD08b<S024Q8@0NWYj06i^KP1TI6@0F5QH05UIF@1:BTX0ADE504Q8B017AdL0C4a<05EEE@1A
DE40EUIF06IVIP1IFET0G5aL05eMG@02065QH@0M069RHP1NGUh0GemO06ATI01RHV80GUiN06=SH`1R
HV80GEeM061PH01TI6@0H61P06IVIP1ZJVX0IVIV06EUI@1TI6@0Hf=S069RHP1NGUh0H61P06IVIP1T
I6@0JVYZ06EUI@1QHF40GUiN05mOG`1QHF400P1UIFD04@1RHV80IVIV069RHP1PH600GemO05eMG@1C
De<0Bd];04m?C`1NGUh0/K6a0=CDe03EeMD0e]KF0<_;b`30`<00_[jn0080clo?02d0cLg=0;Zj^P31
`L40c<c<0;Zj^P2FUYH0TY:B09fMW@2BTY80RHV908B4Q028R8P0PX:209>CT`2ATI40RHV90:6QX@2B
TY80Rh^;08F5Q@2?Shl0Q8B407MgM`1RHV80GUiN06IVIP1aLG40MGEe06m_K`1gMgL0Ph>3096AT@25
QHD0PX:208N7Q`22PX80R8R808j>SP23Ph<0R8R808>3P`26QXH0M7Ad075aL@1kNg/00P1oOgl09@20
P800OWin07inOP1mOGd0P82008:2PP25QHD0SXj>08>3P`1nOWh0N7Qh07emO@1lO7`0MGEe08J6QP2?
Shl0TY:B08n?S`2:RXX0Ph>308Z:RP26QXH0Ph>308J6QP1oOgl0OWin06YZJP18B4P0PX:208n?S`25
QHD0QhN708V9R@24Q8@0OWin0820P01hN7P00P1SHf<0=@1QHF40D51@04a<C01FEUH0?clo03Xj>P0l
?3`0BDU904M7A`1TI6@0HF5Q059BDP1CDe<0FUYJ04E5A@0d=3@0=SHf02l_;`0^;Rh0<c<c03Ti>@0_
;bl0<c<c03lo?`1:BTX0JVYZ08^;R`1dM7@0Fe]K07=cL`1jNWX0GEeM06EUI@1<C4`0=CDe02h^;P0c
<c<0?3`l03@d=018B4P0FEUI06MWI`1/K6`0D51@04];B`1?Cdl0D51@05iNGP1[Jf/0Cdm?0451@@0f
=SH08R8R0080;bl_00<0M7Ad06YZJP0T92@00P0S8b<201lO7`0=024Q8@0Y:BT0GEeM08V9R@2XZ:P0
_kno0:f][@2KVi/0R8R8075aL@1cLg<0QhN70::RXP020;Ng]`060;no_`30`<00`l?30;fm_@2j^[X0
]kNg0`2c/k<01@2b/[80];Bd0;>c/`2j^[X0^k^k0080_kno00@0_[jn0;no_`2n_[h0_Kfm0P2o_kl2
0;jn_P0:0;Vi^@2k^k/0^KVi0;Zj^P2m_Kd0`<300;no_`2k^k/0_Kfm0<71`@80_kno00@0_[jn0;bl
_030`<00`/;20`2o_kl20<71`@030<30`031`L40a<C400<0`l?30P36a/H20<S8b00W0<O7a`39bLT0
b<S80<S8b030`<00^[Zj0:2PX01iNGT0Fe]K05EEE@1gMgL0RHV908N7Q`22PX80Ogmo07IfMP1XJ6P0
Hf=S069RHP1SHf<0H61P05IFEP1MGEd0FEUI05mOG`1XJ6P0LW9b07EeM@1lO7`0R8R809FEU@2IVIT0
WinO09fMW@2SXj<0Z:RX0:^[Z`2WYjL0[:b/0080/[:b0P2f][H07P2j^[X0`l?30<S8b03>c/h0Zj^[
061PH00c<c<0:2PX02TY:@0[:b/0;bl_02d];@0d=3@0;Bd]02l_;`0];Bd0;bl_03Hf=P0b<S80=3@d
03Hf=P0d=3@0>c/k030`<00b<S80<C4a02XZ:P0[:b/0<C4a02XZ:P<0:b/[00<0;Rh^03<c<`0a<C40
0P0c<c<07P0^;Rh0>c/k04Q8B01?Cdl0;bl_03<c<`14A4@0E5AD07AdM024Q8@0U9BD09RHV02FUYH0
UiNG09RHV02@T900TI6A08n?S`2>SXh0VYZJ09bLW02SXj<0XZ:R0:FUY@2TY:@0Xj>S0:FUY@2WYjL0
XJ6Q09nOW`80X:2P00@0YJFU0::RXP2RXZ80WinO0P2PX:001@2RXZ80WinO0:2PX02OWil0WYjN00<0
X:2P00P0WinO0:2PX02PX:00WYjN0:2PX02NWYh0WinO0:>SX`80WinO0P2PX:0209jNWP80Vi^K00P0
VIVI09jNWP2KVi/0WinO09bLW02IVIT0WIfM09^KV`<0VYZJ00T0Vi^K09ZJVP2LW9`0WIfM09^KV`2H
V9P0Vi^K09bLW02GUiL00P2HV9P0102GUiL0UIFE09BDU02IVIT>0<SPf0003038h=P206a/K00406YZ
JP1VIVH0IVIV06QXJ0<0IVIV00H0IfMW069RHP1TI6@0HF5Q05iNGP1PH60206=SH`0G05mOG`1RHV80
JFUY06MWI`1^KVh0Kfm_06a/K01XJ6P0L71`07MgM`1nOWh0Q8B408N7Q`2CTi<0TY:B09NGU`2HV9P0
WYjN09nOW`2TY:@0ZJVY0:ZZZP2/[:`00P2[Zj/20:b/[00D0:f][@2[Zj/0Zj^[0:n_[`2/[:`0[Jf]
0:^[Z`2/[:`0[Zj^0:b/[02VYZH0Z:RX0::RXP2PX:00Vi^K096AT@2=SHd0QXJ607moO`1aLG4205iN
GP80De=C00D0DU9B04Y:BP19BDT0De=C04m?C`0205IFEP0E05iNGP1JFUX0GUiN05iNGP1JFUX0H61P
065QH@1VIVH0G5aL061PH01OGel0H61P065QH@1RHV80GEeM069RHP1SHf<0H61P069RHP1TI6@0HF5Q
0080IVIV01l0I6AT05aLG01PH600HV9R061PH01RHV80JVYZ06ATI01YJFT0H61P06EUI@1SHf<0GemO
06ATI01NGUh0Hf=S065QH@1LG5`0GemO06EUI@1@D500DU9B055AD@1`L700c<c<0=[JfP34a<@0a/K6
0=;BdP3=cLd0_kno0080a<C402<0clo?0<k>cP32`/80`/;20;Zj^P2UYJD0T92@08Z:RP23Ph<0QHF5
08N7Q`2DU9@0Rh^;08f=S@27QhL0VIVI09ZJVP1jNWX0QXJ609>CT`2ATI40PH6107YjNP1XJ6P0GEeM
05mOG`1aLG40L71`07=cL`1^KVh0Ng]k08B4Q027QhL0QHF508:2PP0208b<S00?08N7Q`26QXH0QXJ6
08:2PP2;Rh/0OWin071`L01aLG40OWin0861P@1oOgl0Ph>307MgM`1mOGd0PH6100<0R8R801d0PX:2
08N7Q`23Ph<0Ph>307moO`1kNg/0NGUi08:2PP2=SHd0TI6A08j>SP25QHD0R8R808N7Q`2?Shl0Rh^;
08F5Q@1oOgl0KFe]05MGE`1kNg/0Ph>308:2PP1oOgl0OWin08F5Q@2;Rh/0RHV908J6QP0208F5Q@0^
07=cL`1TI6@0IFEU061PH01NGUh0B4Q803dm?@0n?Sh0?3`l04];B`1MGEd0Cdm?04e=C@1>CTh0Cdm?
0492@P0m?Cd0>c/k03Lg=`0k>c/0?Cdm03Xj>P0d=3@0>SXj04E5A@1GEeL0JVYZ0861P@1SHf<0GUiN
0820P01cLg<0DU9B05YJFP1HF5P0?Shn03Ph>00e=CD0?clo05]KF`1PH600DE5A05aLG021PH40GUiN
05]KF`80Bd];02@0GUiN06=SH`1QHF40Cdm?034a<@0V9RH0;Bd]07UiN@1kNg/0:2PX02DU9@0R8R80
8B4Q01dM7@0P82009BDU0410@01IFET0PX:20:ZZZP31`L40/K6a09ZJVP1mOGd0M7Ad07=cL`1mOGd0
VYZJ0;Jf]P2l_;`0`L710<K6aP34a<@0_Kfm0;^k^`2d];@20;2`/0090;Bd]02e]KD0][Jf0;Bd]02m
_Kd0`L710<30`031`L40`<300080_kno00P0_Kfm0;jn_P2o_kl0`<300<71`@2l_;`0]KFe0;Jf]P80
_;bl0P2o_kl01@2l_;`0_kno0<30`02n_[h0`<300080^[Zj00D0`/;20<G5a@32`/80`L710;jn_P04
0<C4a0@0aLG500L0alO70<C4a039bLT0a/K60<O7a`34a<@0a/K60080b<S800X0a<C40;Vi^@2;Rh/0
J6QX07inOP25QHD0PX:20861P@1nOWh0I6AT0P1QHF40101NGUh0IVIV061PH01FEUH205QHF00?05MG
E`1KFe/0GUiN065QH@1VIVH0KVi^07alO028R8P0T92@09BDU02IVIT0X:2P0:JVYP2SXj<0Z:RX0080
[Zj^0180/[:b0;Jf]P2l_;`0_[jn0<71`@38b<P0d=3@0;Zj^P1SHf<0;Rh^02XZ:P0`<300<S8b034a
<@0`<300<C4a02h^;P0e=CD2034a<@0503<c<`0e=CD0=3@d03@d=00`<3000P0c<c<00`0_;bl0;Rh^
02d];@0202TY:@0V02XZ:P0^;Rh0<S8b03Xj>P0m?Cd0?clo03hn?P11@D40@41004e=C@0d=3@0;Bd]
02l_;`0a<C40=3@d04Y:BP1YJFT0NWYj08Z:RP2@T900UIFE09NGU`2EUID0TY:B09BDU02:RXX0Rh^;
09JFUP2MWId0YJFU09jNWP2UYJD0YZJV0:BTY02VYZH0XJ6Q0:NWY`2UYJD30::RXP080:>SX`2RXZ80
WIfM0:JVYP2TY:@0Xj>S09fMW@2RXZ8209nOW`0<0::RXP2NWYh0WYjN09bLW02PX:00WIfM09nOW`2R
XZ80WIfM09bLW02KVi/0W9bL102NWYh209bLW00409ZJVP2KVi/0X:2P09bLW080WIfM00<0WYjN09nO
W`2LW9`00P2MWId0402IVIT0VYZJ09VIV@2JVYX0WYjN09bLW02HV9P0Vi^K09VIV@2MWId0VIVI09NG
U`2MWId0Vi^K09JFUP2GUiL>0<SPf0003038h=P206UYJ@0=06YZJP1[Jf/0JVYZ06MWI`1[Jf/0IfMW
06UYJ@1WIfL0IFEU06ATI01RHV80Hf=S06ATI002069RHP0506=SH`1RHV80KFe]06UYJ@1ZJVX00P1]
KFd03P1_Kfl0M7Ad07IfMP20P800QXJ608F5Q@2>SXh0Ti>C09FEU@2HV9P0WIfM0:FUY@2WYjL0ZJVY
0P2ZZZX0:`2^[Zh0ZZZZ0:b/[02/[:`0ZJVY0:^[Z`2][Jd0[jn_0;2`/02YZJT0[Jf]0:^[Z`2/[:`0
[Zj^0:ZZZP2SXj<0YJFU09fMW@2LW9`0UIFE08f=S@27QhL0Ogmo06i^KP1QHF40Fe]K05EEE@1@D500
BTY:04a<C01@D500Bd];04e=C@1DE5@0De=C05IFEP1MGEd0GUiN061PH01LG5`0GemO05aLG01JFUX0
0P1SHf<0201UIFD0I6AT069RHP1SHf<0HV9R061PH01TI6@0HV9R0P1SHf<0201RHV80KFe]06=SH`1P
H600HF5Q05iNGP1RHV80IVIV0P1TI6@0101SHf<0I6AT069RHP1MGEd205iNGP0B061PH01KFe/0HV9R
06=SH`1PH600GEeM05ADE01BDU80De=C059BDP1hN7P0e=CD0=oOg`39bLT0^[Zj0<[:bP3De=@0clo?
0P2n_[h0@033`l<0eMGE0=?Cd`2i^KT0[:b/0:JVYP2MWId0Ph>307UiN@24Q8@0Ng]k09RHV02EUID0
SXj>096AT@2MWId0RHV907QhN02:RXX0UiNG07moO`1mOGd0OWin079bLP1ZJVX0IFEU06IVIP1XJ6P0
KFe]07QhN01cLg<0P82008F5Q@23Ph<0QHF508n?S`22PX80Q8B408n?S`2;Rh/0SXj>08Z:RP22PX80
MWIf06e]K@1bLW80O7al07moO`21PH40Ng]k07emO@21PH40Rh^;08>3P`22PX80Ph>308J6QP24Q8@0
PX:208B4Q01lO7`0NWYj07UiN@24Q8@208n?S`0B08R8R02:RXX0S8b<08b<S029RHT0Q8B408>3P`1g
MgL0HV9R06=SH`1lO7`0OGem08B4Q023Ph<0Rh^;08n?S`20P800OWin0P1oOgl0501mOGd0IVIV061P
H01^KVh0M7Ad06=SH`1OGel0D51@04e=C@1>CTh0C4a<04I6AP17AdL0Cdm?04i>CP16ATH0@410038b
<P0f=SH0>CTi0P10@400?P12@T80>SXj0410@014A4@0EeMG06e]K@1/K6`0Fe]K07YjNP2CTi<0KFe]
05=CD`1TI6@0HF5Q04m?C`0g=cL0C4a<06a/K01VIVH0Fe]K04=3@`1fMWH0RHV907IfMP1VIVH0<c<c
04I6AP19BDT0Cdm?05EEE@0j>SX0;Bd]03<c<`1`L700N7Qh03Ti>@0U9BD08B4Q02@T900Q8B408R8R
02@T900/;2`0AdM705MGE`1fMWH0Z:RX0<;2`P2i^KT0WYjN08:2PP1aLG40KVi^07MgM`2KVi/0];Bd
0;no_`33`l<0a/K60<?3``31`L40^k^k0P2n_[h01P2j^[X0^KVi0;bl_02f][H0^[Zj0;fm_@80`/;2
00L0`L710<30`031`L40_Kfm0;jn_P2k^k/0_kno0080`/;200h0_;bl0;Jf]P2i^KT0^k^k0;jn_P34
a<@0`L710<?3``2k^k/0_Kfm0<;2`P2o_kl0^[Zj0;no_`D0`/;200<0`L710<?3``37alL00P32`/80
1`34a<@0`/;20<S8b034a<@0aLG50<K6aP39bLT00P34a<@04P36a/H0bLW90<_;b`3:b/X0aLG50;Zj
^P2TY:@0SHf=07emO@1iNGT0Kfm_05YJFP1NGUh0GEeM05aLG01NGUh0GEeM05aLG080FUYJ00@0G5aL
05QHF01HF5P0G5aL0P1KFe/01P1WIfL0MGEe07QhN023Ph<0RXZ:09RHV0<0WIfM0P2TY:@0102`/;00
];Bd0;jn_P31`L420<?3``060<o?c`3Cdm<0];Bd05EEE@0/;2`092@T0P0Y:BT00`0b<S80;bl_02XZ
:P0302`/;00X02h^;P0f=SH0=SHf02l_;`0e=CD0=cLg03Ph>00^;Rh0:b/[030`<00a<C40<30`02/[
:`0_;bl0<C4a038b<P0c<c<0<C4a03/k>`12@T80>CTi03Xj>P0k>c/0=cLg03De=@0d=3@0?3`l04=3
@`1NGUh0Lg=c08B4Q02ATI40UYJF092@T02HV9P0UIFE09:BTP2>SXh0Shn?096AT@80W9bL0P2TY:@0
202XZ:P0YJFU0:NWY`2UYJD0Y:BT0:>SX`2PX:00XZ:R0P2VYZH02P2RXZ80WIfM0::RXP2SXj<0WYjN
0:6QX@2NWYh0X:2P0:6QX@2UYJD209jNWP0309fMW@2RXZ80WYjN0080Vi^K0`2MWId01P2PX:00W9bL
09nOW`2MWId0WinO09bLW080Vi^K00P0WIfM09jNWP2NWYh0WinO09ZJVP2OWil0W9bL09fMW@80VYZJ
0100Vi^K09fMW@2KVi/0W9bL09fMW@2JVYX0W9bL09^KV`2IVIT0V9RH09NGU`2JVYX0VIVI09ZJVP2E
UID0UiNG3P38h=P000`0b>3H0P1WIfL01P1UIFD0JFUY065QH@1WIfL0JVYZ06QXJ080IfMW00<0HV9R
06MWI`1RHV800P1PH6004P1MGEd0H61P06IVIP1UIFD0K6a/06QXJ01ZJVX0Jf][06e]K@1dM7@0LW9b
07AdM023Ph<0QXJ608R8R02>SXh0TI6A09FEU@80WIfM00L0YJFU0:RXZ02ZZZX0ZJVY0:b/[02^[Zh0
[jn_0080Zj^[00X0[:b/0:^[Z`2_[jl0/K6a0:n_[`2/[:`0[Jf]0:ZZZP2][Jd0YJFU0P2XZ:P0302R
XZ80X:2P09bLW02ATI40RXZ:08F5Q@1mOGd0Jf][065QH@1NGUh0Cdm?04Y:BP80Bd];00l0CDe=05=C
D`1ADE40C4a<05ADE01IFET0GemO05aLG01TI6@0G5aL065QH@1MGEd0HF5Q06=SH`1VIVH00P1WIfL0
4P1PH600HV9R06EUI@1RHV80H61P05iNGP1XJ6P0Hf=S06IVIP1XJ6P0HF5Q06ATI01OGel0H61P05mO
G`1VIVH0Hf=S06ATI080HV9R00H0Hf=S05mOG`1TI6@0H61P05iNGP1MGEd205aLG00305iNGP1GEeL0
De=C0080Cdm?00T0EUIF09ZJVP3De=@0fm_K0=CDe038b<P0`L710<k>cP3EeMD00P3;bl/0402h^;P0
b<S80=_Kf`34a<@0Xj>S0:FUY@2IVIT0UIFE0820P01iNGT0Jf][07IfMP2>SXh0XJ6Q0:>SX`2HV9P2
08J6QP060:2PX029RHT0LG5a07alO01oOgl0Ng]k0P1aLG403P1[Jf/0GEeM06m_K`1kNg/0L71`07em
O@1oOgl0QhN708Z:RP2;Rh/0Ogmo08R8R02=SHd0RHV90P27QhL06`2;Rh/0R8R807MgM`1aLG40Ng]k
07inOP20P800Ng]k0861P@1oOgl0QHF50820P027QhL0QHF508>3P`26QXH0PH6107alO01oOgl0O7al
07YjNP1kNg/0QXJ608j>SP2<S8`0SHf=092@T00208Z:RP0708j>SP25QHD0MGEe07=cL`1^KVh0HF5Q
06m_K`0208>3P`0408N7Q`26QXH0Q8B408F5Q@80Q8B400d0NWYj06a/K01SHf<0M7Ad0861P@1gMgL0
MGEe06i^KP1QHF40J6QX069RHP1BDU80A4A40080>SXj00P0@D5103Ph>00b<S80?Cdm03Ti>@0h>3P0
?3`l03Lg=`80>CTi03P0>SXj04Y:BP1MGEd0KFe]06IVIP1LG5`0O7al096AT@1XJ6P0Cdm?06UYJ@1]
KFd0F5QH04a<C01VIVH0NWYj06MWI`15ADD0Fe]K07IfMP21PH40O7al03hn?P0g=cL0>3Ph04m?C`14
A4@0?3`l0410@01:BTX0IfMW07inOP0f=SH09RHV01lO7`0R8R807alO02@T900Z:RX092@T02/[:`0`
<300?Cdm07MgM`2OWil0^[Zj0;Jf]P2SXj<0RXZ:07AdM01[Jf/0Ogmo09bLW02i^KT0aLG50<K6aP80
a<C400T0_Kfm0;^k^`2k^k/0^;Rh0;Jf]P2i^KT0^[Zj0<30`02o_kl00`33`l<01`34a<@0_kno0<71
`@31`L40_kno0<?3``2o_kl00`2n_[h0302o_kl0^[Zj0;jn_P2n_[h0`<300<K6aP30`<00_[jn0<30
`02k^k/0`<300;jn_P80_kno00X0`<300<;2`P32`/80`/;20;no_`33`l<0`/;20<C4a035aLD0`l?3
0P37alL04035aLD0`l?30<[:bP3:b/X0a/K60<O7a`39bLT0bl_;0<o?c`3;bl/0c<c<0<_;b`31`L40
X:2P07moO`1QHF4205eMG@0F05aLG01OGel0GUiN069RHP1MGEd0G5aL05YJFP1LG5`0FUYJ05IFEP1B
DU80GEeM05YJFP1LG5`0Hf=S06][J`1cLg<0Ng]k08>3P`29RHT0T92@09JFUP80X:2P00h0Zj^[0;6a
/@2g]kL0`/;20<O7a`38b<P0alO70<g=c@3AdM40WinO03De=@0V9RH0:RXZ02/[:`80:RXZ00l0;Rh^
03<c<`0[:b/0;Bd]02h^;P0`<300=3@d034a<@0f=SH0;bl_03@d=00/;2`0;Bd]02l_;`0`<3000P0a
<C40200W9bL0;2`/02h^;P0];Bd0<c<c038b<P0h>3P0?3`l0P0g=cL02`0`<300;Rh^02d];@0c<c<0
>3Ph055AD@1[Jf/0P82008j>SP2GUiL0UYJF0080U9BD00X0UYJF08n?S`2=SHd0T92@09VIV@2KVi/0
X:2P0:>SX`2TY:@0YZJV0P2SXj<0102UYJD0Xj>S0::RXP2OWil20:BTY00:0:6QX@2LW9`0WYjN0:6Q
X@2NWYh0WinO0::RXP2QXJ40WYjN0:6QX@<0W9bL00@0XJ6Q09bLW02PX:00XZ:R0P2NWYh00`2MWId0
WYjN09nOW`0209bLW00609nOW`2MWId0VYZJ09^KV`2LW9`0VYZJ0P2KVi/0102NWYh0V9RH09fMW@2G
UiL309ZJVP0?09VIV@2HV9P0Vi^K09^KV`2IVIT0V9RH09^KV`2IVIT0UiNG09ZJVP2KVi/0VIVI09RH
V02GUiL0W9bL00h0b>3H000<0<SPf080HV9R0P1TI6@03@1]KFd0IVIV06EUI@1WIfL0J6QX06MWI`1X
J6P0IVIV06EUI@1LG5`0I6AT05eMG@1PH6000P1TI6@04`1_Kfl0IFEU06e]K@1ZJVX0KVi^06e]K@1c
Lg<0NGUi0820P026QXH0RHV908^;R`2GUiL0V9RH09fMW@2OWil0XZ:R0:NWY`2[Zj/00`2^[Zh01`2Z
ZZX0Zj^[0:^[Z`2/[:`0[Jf]0:NWY`2YZJT00P2^[Zh01@2[Zj/0[Zj^0:^[Z`2ZZZX0ZJVY0080YZJV
01P0WinO09ZJVP2DU9@0RHV908>3P`1kNg/0L71`06IVIP1KFe/0D51@04i>CP19BDT0ATI604m?C`1A
DE40DU9B05=CD`1EEED0G5aL06ATI01KFe/0GemO05iNGP1PH60205iNGP0K065QH@1NGUh0HV9R061P
H01NGUh0IVIV061PH01WIfL0GemO061PH01TI6@0IVIV065QH@1WIfL0JVYZ061PH01RHV80I6AT06YZ
JP1XJ6P0GUiN06MWI`1UIFD0J6QX05iNGP1VIVH0HV9R0080GemO0140Hf=S061PH01IFET0GEeM05UI
F@1ADE40De=C04m?C`1PH600^;Rh0=OGe`3<c<`0eMGE0=OGe`3<c<`0`L710<S8b0020=;BdP0:0<g=
c@2j^[X0alO70<?3``2^[Zh0UiNG09ZJVP2IVIT0QXJ607QhN080JFUY00<0P8200:>SX`2KVi/00P27
QhL08@2FUYH0V9RH07alO01_Kfl0O7al08:2PP21PH40Kfm_06e]K@1VIVH0G5aL06ATI01_Kfl0MWIf
07AdM01fMWH0PH6108J6QP24Q8@0RHV909:BTP2;Rh/0S8b<08V9R@2;Rh/0R8R808:2PP29RHT0O7al
075aL@1dM7@0O7al07inOP030820P00O08:2PP25QHD0Q8B408N7Q`28R8P0QHF508B4Q028R8P0Ogmo
08:2PP1lO7`0NWYj0861P@25QHD0RXZ:08J6QP2=SHd0RHV908j>SP2:RXX0Q8B408J6QP1jNWX0Hf=S
06e]K@1nOWh0QXJ608>3P`27QhL0QHF508R8R00208F5Q@0907alO01bLW80JFUY06UYJ@1nOWh0RHV9
08N7Q`1lO7`0MWIf0080N7Qh03H0IFEU059BDP1?Cdl0>c/k04M7A`0j>SX0?3`l03Ti>@0n?Sh0>CTi
03Lg=`0j>SX0>CTi03`l?012@T80ADE504Y:BP1OGel0JFUY06=SH`1LG5`0OGem08f=S@1RHV80FEUI
07EeM@1`L700J6QX06MWI`1oOgl0TI6A06a/K017AdL0Fe]K06m_K`27QhL0Kfm_03Ph>00_;bl0=cLg
03hn?P0^;Rh0:b/[03Ph>01TI6@0MgMg03Xj>P0`<300:RXZ02d];@0U9BD0=cLg02`/;00N7Qh2020P
800802DU9@0k>c/0J6QX096AT@2_[jl0`<300;6a/@2CTi<207=cL`0308:2PP2IVIT0^[Zj0080a<C4
00P0^k^k0;Rh^030`<00`<300;jn_P2o_kl0`<300;no_`<0`/;200H0a/K60<G5a@34a<@0`L710;fm
_@2o_kl20<71`@090;no_`2n_[h0^k^k0;Zj^P32`/80`L710;no_`2n_[h0_;bl0080`l?30P34a<@0
1032`/80`L710<71`@33`l<20;no_`060<30`031`L40`l?30<;2`P33`l<0a/K60P34a<@20<K6aP04
0<_;b`39bLT0bLW90<c<c080bl_;01H0b/[:0<S8b03:b/X0d=3@0<k>cP3Bd]80c/k>0<g=c@39bLT0
[Jf]07AdM01WIfL0GEeM05MGE`1JFUX0Fe]K06=SH`1JFUX0FEUI05iNGP1KFe/0FUYJ0P1GEeL02`1F
EUH0FEUI06EUI@1PH600IFEU06=SH`1bLW80JVYZ06a/K01hN7P0PX:20080Shn?01X0VIVI0:RXZ02_
[jl0]KFe0;no_`36a/H0c<c<0<K6aP3;bl/0a/K60861P@0g=cL0:BTY02`/;00Z:RX09bLW02PX:00[
:b/0:RXZ02l_;`0b<S80;bl_03@d=00f=SH0=3@d030`<080<S8b00D0;Bd]02`/;00[:b/0<30`03Hf
=P0202XZ:P80>3Ph01T0<c<c03Lg=`0i>CT0?Cdm03Lg=`0i>CT0<C4a02d];@0[:b/0<30`03<c<`13
@d<0Fe]K079bLP24Q8@0SHf=09FEU@2IVIT0UIFE09:BTP2>SXh0Rh^;08b<S02CTi<0UiNG0080Vi^K
01@0XJ6Q0:>SX`2TY:@0Xj>S0:6QX@2SXj<0WinO0::RXP2SXj<0XZ:R0:6QX@2NWYh0W9bL09nOW`2R
XZ80Y:BT09bLW02OWil0Xj>S0:6QX@80WYjN01@0Xj>S09nOW`2MWId0X:2P09fMW@2PX:00WIfM09bL
W02PX:00WinO09ZJVP2MWId0WinO09^KV`2MWId0WYjN09^KV`2LW9`0Vi^K09VIV@80VYZJ0P2KVi/0
3`2LW9`0Vi^K09NGU`2JVYX0VIVI09NGU`2JVYX0Vi^K09RHV02KVi/0VYZJ09NGU`2JVYX0WinO09^K
V`0209VIV@0309bLW038h=P0b>3H00`0b>3H000<0<SPf080IFEU00@0IVIV06MWI`1WIfL0IFEU0P1S
Hf<0401XJ6P0HF5Q06MWI`1TI6@0IfMW061PH01RHV80GEeM065QH@1TI6@0Jf][06YZJP1_Kfl0KFe]
06m_K`1/K6`207AdM00;07UiN@20P800QXJ608R8R02<S8`0UIFE09RHV02MWId0XJ6Q0::RXP2YZJT0
0P2[Zj/00`2][Jd0Zj^[0:^[Z`020:VYZ@030:^[Z`2/[:`0[Jf]0080[Jf]00D0[jn_0:b/[02][Jd0
[:b/0:f][@020:RXZ00C0:JVYP2QXJ40V9RH09BDU02;Rh/0QHF507]kN`1]KFd0H61P05YJFP1ADE40
Cdm?04U9B@15ADD0Bd];05=CD`1=CDd0EEEE05MGE`0205eMG@0505mOG`1PH600HF5Q06EUI@1PH600
0P1OGel02P1RHV80IFEU06ATI01XJ6P0HF5Q069RHP1XJ6P0H61P05mOG`1SHf<206IVIP0306EUI@1[
Jf/0HF5Q0080HF5Q00X0IVIV06EUI@1RHV80IVIV06MWI`1RHV80H61P065QH@1OGel0IFEU0P1QHF40
401LG5`0Fe]K05]KF`1FEUH0DE5A04m?C`1BDU80JVYZ0<[:bP3Ogml0bLW90<[:bP3@d=00eMGE0<_;
b`2k^k/20<C4a00D0=3@d03:b/X0]kNg0;fm_@2j^[X0[Zj^09NGU`29RHT0P82007]kN`1aLG40JVYZ
07EeM@2MWId0TI6A08F5Q@2<S8`0U9BD07inOP1bLW8207QhN00L08R8R01jNWX0M7Ad07IfMP1dM7@0
JVYZ061PH01YJFT0M7Ad07IfMP1bLW80OWin08B4Q027QhL0SHf=08j>SP2:RXX0Q8B408b<S02:RXX0
R8R80820P02;Rh/0QXJ6079bLP1]KFd0O7al07QhN080OGem0100O7al08J6QP29RHT0Q8B408Z:RP27
QhL0Q8B408R8R029RHT0R8R808:2PP1fMWH0M7Ad07emO@25QHD0QXJ60P2>SXh0102@T900R8R808b<
S027QhL208^;R`0808J6QP1[Jf/0IfMW0820P023Ph<0RHV908R8R026QXH207moO`0H0861P@1aLG40
Jf][05mOG`1bLW80OWin08>3P`1jNWX0MWIf07emO@20P800NWYj06m_K`1VIVH0IFEU05=CD`19BDT0
@D5104i>CP13@d<0?Cdm03Hf=P0i>CT0=SHf0P11@D403015ADD0ATI6059BDP1RHV80L71`06MWI`1J
FUX0N7Qh07moO`1IFET0HV9R061PH080GUiN01X0I6AT06UYJ@1oOgl0Kfm_03lo?`11@D40E5AD05aL
G01VIVH0DU9B03Ti>@0h>3P0=3@d02l_;`1?Cdl0GEeM06ATI00`<300;bl_030`<00f=SH0;bl_02HV
9P0X:2P06a/K020P80807alO01009RHV030`<01OGel0Q8B40;>c/`34a<@0];Bd09FEU@24Q8@0QXJ6
0861P@2IVIT0/K6a0;jn_P2k^k/0]KFe0P35aLD02032`/80`l?30<W9b@34a<@0`l?30<;2`P33`l<0
a/K60P35aLD00`31`L40`l?30<?3``020;no_`050<C4a032`/80`L710;no_`2n_[h00P33`l<01034
a<@0`l?30<30`030`<020<?3``030<C4a030`<00_[jn0080_kno00h0`<300;no_`2o_kl0_kno0<G5
a@33`l<0a<C40<K6aP32`/80a<C40<;2`P37alL0a/K60<[:bP80c<c<0240cLg=0<c<c039bLT0c<c<
0=3@d03=cLd0d];B0=?Cd`3?cll0dM7A0<g=c@2k^k/0SXj>06EUI@1LG5`0F5QH05aLG01NGUh0DU9B
05UIF@1JFUX0F5QH05EEE@1GEeL0De=C05EEE@1GEeL0Fe]K05aLG01PH600Fe]K05aLG01PH6000P1Y
JFT0<@1`L700LW9b079bLP25QHD0UiNG0::RXP2WYjL0/K6a0;Vi^@32`/80b<S80<G5a@3;bl/0`/;2
0820P00l?3`0<C4a030`<00];Bd0:BTY02PX:00V9RH0<30`02HV9P0];Bd0<c<c02l_;`0a<C40<c<c
038b<P0a<C40<c<c02h^;P0[:b/0<30`02XZ:P0^;Rh0;Bd]03Ph>00_;bl0<c<c03@d=00m?Cd0=CDe
03Xj>P0b<S80=3@d02`/;00[:b/00P0Y:BT02P0b<S80EEEE079bLP26QXH0RXZ:09>CT`2HV9P0UIFE
09:BTP2@T90208n?S`0:08j>SP2HV9P0Vi^K09fMW@2NWYh0XZ:R0:>SX`2XZ:P0Y:BT0:6QX@80Xj>S
0P2RXZ800`2OWil0WIfM0:BTY0020:>SX`0509nOW`2NWYh0Y:BT09jNWP2LW9`00P2OWil02P2QXJ40
WIfM09nOW`2JVYX0WIfM09jNWP2LW9`0VYZJ09^KV`2NWYh209fMW@0N09nOW`2KVi/0WYjN09bLW02N
WYh0WIfM09nOW`2NWYh0Vi^K09NGU`2HV9P0UiNG09ZJVP2LW9`0Vi^K09fMW@2IVIT0WIfM09bLW02G
UiL0VYZJ09RHV02KVi/0UiNG09bLW02JVYX0VIVI09ZJVP2GUiL0VYZJ3P38h=P000`0b>3H0`1SHf<0
2@1TI6@0IVIV06IVIP1YJFT0KVi^06e]K@1WIfL0IFEU06=SH`02069RHP06065QH@1NGUh0HV9R06MW
I`1]KFd0JVYZ0P1YJFT04P1XJ6P0Kfm_06][J`1cLg<0NWYj07]kN`21PH40R8R808f=S@2DU9@0UYJF
09ZJVP2RXZ80YJFU0:RXZ02^[Zh0[:b/0:f][@80Zj^[0`2][Jd01P2`/;00[:b/0:^[Z`2_[jl0[Zj^
0:ZZZP@0[Jf]00T0YJFU0:2PX02LW9`0W9bL09:BTP2:RXX0RHV907emO@1aLG400P1MGEd03`1?Cdl0
De=C04a<C019BDT0CDe=05EEE@1CDe<0E5AD059BDP1NGUh0Fe]K05aLG01QHF40IFEU05iNGP02065Q
H@0A061PH01SHf<0Hf=S069RHP1QHF40IFEU05mOG`1TI6@0GemO06EUI@1XJ6P0I6AT065QH@1TI6@0
Hf=S05mOG`1QHF400P1TI6@01@1UIFD0I6AT06ATI01ZJVX0Hf=S0080HF5Q01@0I6AT069RHP1OGel0
Fe]K06=SH`1NGUh0Fe]K05ADE01ADE40DU9B04i>CP1[Jf/0a<C40=gMg@3Cdm<0b<S80<O7a`3>c/h0
eMGE0<[:bP80_;bl03P0aLG50=3@d03;bl/0];Bd0:j^[P2a/K40YjNW0861P@1fMWH0OGem071`L01/
K6`0IfMW07]kN`26QXH0QhN708b<S021PH40Lg=c07AdM01hN7P0L71`07alO01aLG40KFe]07]kN`1h
N7P0MgMg071`L01WIfL0Jf][075aL@1hN7P0MWIf07QhN029RHT0Shn?08Z:RP28R8P0QhN708Z:RP28
R8P0QHF508B4Q02;Rh/0R8R808Z:RP27QhL0KVi^06][J`1iNGT0NWYj07inOP21PH40Ogmo08J6QP80
QhN701X0S8b<08V9R@27QhL0P82007moO`1lO7`0OWin07emO@20P800RHV908f=S@2?Shl0Rh^;08N7
Q`2:RXX0RHV908Z:RP2?Shl0Rh^;079bLP1TI6@0KVi^0820P023Ph<0PX:208>3P`80R8R800/0PX:2
07alO01mOGd0Jf][06IVIP1bLW80Ogmo08R8R01lO7`0IfMW06][J`0206a/K00<06i^KP20P800QhN7
07IfMP1KFe/0I6AT05IFEP13@d<0ADE504e=C@1KFe/0CTi>0P1@D5009@14A4@0De=C06m_K`1bLW80
L71`061PH01RHV80Jf][06EUI@19BDT0D51@04I6AP0k>c/0CDe=05IFEP1EEED0K6a/07QhN01EEED0
?Cdm0410@01:BTX0GemO05iNGP1@D500C4a<04A4A019BDT0BTY:061PH00b<S80=cLg04Q8B00/;2`0
:BTY02HV9P0U9BD00P0T92@04P0P82008B4Q024Q8@0T92@0;Rh^05EEE@2FUYH0/K6a0<71`@2d];@0
WinO08f=S@2ATI40RXZ:09RHV02RXZ80^;Rh0<30`080a/K600/0bLW90<;2`P3;bl/0bl_;0<S8b035
aLD0a<C40<?3``36a/H0aLG50<71`@020<;2`P0?0<71`@32`/80`L710;no_`32`/80`L710;no_`30
`<00`/;20<K6aP38b<P0aLG50<;2`P30`<00_kno0080`l?30P32`/80102o_kl0a<C40<G5a@31`L42
0<30`0090<G5a@37alL0alO70<?3``34a<@0`l?30<C4a037alL0a/K60080b<S801/0cLg=0<_;b`39
bLT0b<S80<[:bP3AdM40dm?C0<k>cP3?cll0dm?C0<o?c`3AdM40bl_;0:b/[01oOgl0JVYZ065QH@1J
FUX0EEEE05UIF@1GEeL0E5AD05UIF@1HF5P0EUIF05QHF01GEeL00P1QHF401@1MGEd0EeMG05aLG01M
GEd0GemO0080HF5Q0P1SHf<0;01dM7@0PH6108j>SP2IVIT0XJ6Q0:n_[`2d];@0alO70<G5a@38b<P0
clo?0<C4a02GUiL0Hf=S03lo?`0a<C409BDU02PX:00W9bL0:BTY02HV9P0Y:BT0<C4a030`<00c<c<0
>3Ph02h^;P0d=3@0<S8b030`<00d=3@0<S8b03Ph>00[:b/0<c<c03De=@0d=3@0<c<c03Ti>@0b<S80
?3`l03/k>`0e=CD0;Rh^0P0Y:BT01`0V9RH0:RXZ02l_;`10@400Hf=S07MgM`2:RXX00`2HV9P04P2B
TY80Ti>C09:BTP2ATI40T92@09RHV02CTi<0WYjN0:2PX02RXZ80Y:BT0:FUY@2QXJ40X:2P0:BTY02V
YZH0XJ6Q0:>SX`80WinO00P0XJ6Q0:2PX02TY:@0Xj>S09jNWP2QXJ40WinO0::RXP<0XJ6Q01<0WinO
09bLW02NWYh0WIfM09jNWP2PX:00W9bL09fMW@2KVi/0VYZJ09fMW@2JVYX0WYjN09bLW02OWil0W9bL
09fMW@2KVi/0W9bL00@0Vi^K0P2LW9`02@2KVi/0VYZJ09fMW@2LW9`0V9RH09VIV@2MWId0VIVI09^K
V`0209VIV@0509FEU@2GUiL0VIVI09^KV`2JVYX03P38h=P000`0b>3H0P1OGel0201VIVH0I6AT06AT
I01UIFD0JFUY06QXJ01/K6`0IVIV0P1SHf<02`1PH600Hf=S061PH01RHV80IFEU06UYJ@1TI6@0IFEU
06QXJ01/K6`0Kfm_0080KVi^0140M7Ad07IfMP1lO7`0PH6108V9R@2;Rh/0Ti>C09RHV02MWId0XJ6Q
0:>SX`2/[:`0Zj^[0:NWY`2[Zj/0/;2`0:j^[P020:b/[00K0:^[Z`2][Jd0ZJVY0:f][@2a/K40ZZZZ
0:f][@2^[Zh0[jn_0:^[Z`2YZJT0YZJV0:>SX`2OWil0W9bL09BDU02>SXh0QXJ607inOP1fMWH0I6AT
05EEE@1@D500AdM704Q8B01:BTX0C4a<0080DE5A00D0E5AD05QHF01GEeL0GUiN05eMG@0205aLG004
06=SH`1KFe/0GemO065QH@80Hf=S0P1OGel04P1QHF40G5aL069RHP1RHV80HF5Q06=SH`1WIfL0IFEU
06YZJP1PH600Hf=S06IVIP1SHf<0HF5Q069RHP1UIFD0GemO06UYJ@80J6QX01D0IFEU06=SH`1TI6@0
HF5Q061PH01KFe/0HV9R05YJFP1GEeL0DE5A04i>CP1IFET0QhN70<g=c@3Cdm<0eMGE0=7Ad@32`/80
_Kfm0<_;b`3GemL00P3;bl/0=02i^KT0b<S80<k>cP2n_[h0WYjN0:NWY`2QXJ40RHV907EeM@1fMWH0
LG5a07QhN01kNg/0M7Ad07]kN`2:RXX0Ogmo079bLP1fMWH0N7Qh07=cL`1bLW80MgMg06a/K01aLG40
LW9b07QhN022PX80Ogmo06YZJP1PH600LG5a07UiN@1cLg<0LW9b07]kN`28R8P0RXZ:08^;R`2:RXX0
QhN708>3P`29RHT0R8R808F5Q@28R8P0QXJ608Z:RP1fMWH0KVi^075aL@1jNWX208:2PP80Q8B40P25
QHD06P2;Rh/0Q8B408>3P`1oOgl0PX:208>3P`27QhL0OGem07inOP23Ph<0SXj>092@T02;Rh/0TY:B
08j>SP2<S8`0SXj>08b<S02:RXX0PX:207AdM01QHF40M7Ad07QhN01lO7`0QXJ60P2=SHd03`2<S8`0
QHF507inOP1gMgL0IFEU06QXJ01gMgL0QHF508Z:RP1oOgl0JFUY065QH@1YJFT0Jf][07moO`0208j>
SP0507MgM`1hN7P0M7Ad05EEE@10@4000P1CDe<03@1:BTX0IFEU061PH01?Cdl0Bd];05mOG`1dM7@0
OGem071`L01LG5`0D51@05=CD`18B4P00P1EEED2030`<00[04I6AP12@T80B4Q806e]K@26QXH0KFe]
0492@P0`<300?3`l04Y:BP1?Cdl0CTi>055AD@0l?3`0ATI605IFEP10@400>CTi030`<00Y:BT0:RXZ
030`<00V9RH0820P02<S8`0V9RH0:2PX02DU9@0S8b<09BDU04Y:BP23Ph<0R8R809jNWP2e]KD0^k^k
0:RXZ02PX:00RXZ:08^;R`2KVi/0X:2P0;Vi^@030<_;b`070<[:bP3?cll0c/k>0<g=c@39bLT0alO7
0<K6aP020<G5a@040<C4a032`/80_[jn0<71`@80`/;200T0_kno0<71`@2n_[h0`/;20<71`@32`/80
a<C40<30`035aLD00`34a<@00`2o_kl0`l?30<;2`P020<71`@040;no_`35aLD0a/K60<C4a080`l?3
00<0a/K60<O7a`35aLD00P35aLD03@38b<P0a/K60<K6aP36a/H0a<C40<S8b03:b/X0`L710<G5a@32
`/80clo?0=7Ad@3@d=000P3=cLd06P3?cll0dM7A0=7Ad@3AdM40a/K60;>c/`2GUiL0MWIf05mOG`1J
FUX0FEUI05IFEP1JFUX0EEEE05=CD`1IFET0F5QH05UIF@1KFe/0IFEU05MGE`1KFe/0GEeM05mOG`1N
GUh0GEeM0P1TI6@02`1XJ6P0L71`07alO025QHD0SXj>09nOW`2/[:`0_[jn0;bl_033`l<0bl_;0080
b/[:0140alO709nOW`1HF5P0;Bd]02DU9@0Z:RX0:b/[02PX:00V9RH0:b/[03<c<`0b<S80=cLg03<c
<`0h>3P0<c<c02d];@0202l_;`0Q03<c<`0f=SH0?3`l03Hf=P0_;bl0:b/[03@d=00c<c<0?Cdm03Ph
>00i>CT0<C4a02l_;`0[:b/09BDU02HV9P0];Bd0>CTi05ADE01ZJVX0QXJ608j>SP2FUYH0U9BD09>C
T`2ATI40T92@08j>SP2ATI40Shn?09>CT`2IVIT0WinO0080Xj>S00X0YJFU0::RXP2QXJ40X:2P09nO
W`2QXJ40XZ:R09jNWP2MWId0XJ6Q0P2RXZ801@2TY:@0WinO0:6QX@2NWYh0Xj>S0080X:2P00@0W9bL
09fMW@2HV9P0XJ6Q0P2MWId01P2OWil0WIfM09bLW02MWId0VYZJ09^KV`80W9bL00<0WIfM09ZJVP2K
Vi/00P2KVi/02@2NWYh0V9RH09ZJVP2NWYh0W9bL09ZJVP2LW9`0UiNG09ZJVP0309bLW00;09RHV02J
VYX0W9bL09BDU02FUYH0TI6A09FEU@2GUiL0VIVI09RHV02KVi/03P38h=P000`0b>3H0`1SHf<08P1W
IfL0Hf=S06UYJ@1VIVH0J6QX069RHP1WIfL0Hf=S06ATI01SHf<0IfMW06YZJP1LG5`0H61P06YZJP1T
I6@0Hf=S06][J`1^KVh0K6a/075aL@1^KVh0LW9b07MgM`1mOGd0Ph>309:BTP2@T900TY:B09RHV02L
W9`0XZ:R0:JVYP2UYJD20:^[Z`030:ZZZP2/[:`0/;2`0080[Zj^0200[Jf]0:j^[P2[Zj/0[Zj^0:f]
[@2/[:`0ZZZZ0:b/[02b/[80[:b/0:VYZ@2WYjL0X:2P09bLW02HV9P0UiNG08Z:RP23Ph<0NWYj07=c
L`1UIFD0FEUI055AD@1;Bd/0AdM704=3@`1:BTX0D51@059BDP1DE5@0De=C05QHF080Fe]K00d0HF5Q
06IVIP1KFe/0GEeM069RHP1WIfL0IFEU06IVIP1UIFD0HF5Q05mOG`1QHF40GUiN0080IVIV00T0H61P
06ATI01SHf<0HF5Q069RHP1PH600IVIV065QH@1WIfL00P1VIVH06@1PH600IFEU06ATI01SHf<0IfMW
06a/K01SHf<0H61P05mOG`1QHF40GUiN05MGE`1IFET0EEEE055AD@1MGEd0XJ6Q0=oOg`3=cLd0bLW9
0=?Cd`3>c/h0`L710;Vi^@3=cLd00P3EeMD05`3<c<`0][Jf0;^k^`35aLD0[Jf]09ZJVP2EUID0VIVI
08J6QP22PX80KFe]08B4Q02?Shl0S8b<0861P@27QhL0NGUi07MgM`1eMGD0M7Ad06m_K`1aLG40L71`
0080KVi^00L0L71`07QhN024Q8@0P820071`L01LG5`0IfMW0080KVi^00D0Lg=c07IfMP1oOgl0QhN7
08f=S@0208N7Q`0608n?S`26QXH0R8R808B4Q02:RXX0PH610P28R8P04027QhL0Jf][07EeM@21PH40
QHF508J6QP21PH40QXJ608B4Q02;Rh/0OWin0861P@24Q8@0QhN708b<S026QXH208:2PP0507UiN@1o
Ogl0S8b<08b<S02@T9000P2?Shl02P29RHT0SHf=08n?S`2@T900RHV9071`L01JFUX0K6a/07emO@2<
S8`2096AT@80Shn?0100PH6107alO01bLW80JFUY06YZJP1dM7@0P82008R8R024Q8@0MGEe071`L01W
IfL0MGEe08B4Q02@T900P8200P1kNg/09P1/K6`0Cdm?04Y:BP17AdL0EUIF06ATI01ZJVX0GEeM05QH
F01NGUh0M7Ad08Z:RP2<S8`0MGEe05]KF`1BDU80Bd];059BDP1WIfL0B4Q803Ph>014A4@0>3Ph03Hf
=P11@D40K6a/07QhN024Q8@0H61P04A4A00k>c/0?Shn03lo?`0j>SX0A4A405YJFP1FEUH0B4Q80P0/
;2`0600`<300:2PX02@T900U9BD08b<S02DU9@0Y:BT0AdM704Q8B00X:2P09BDU03<c<`1SHf<0GUiN
06e]K@2ATI40]kNg0;jn_P2b/[80V9RH08J6QP2=SHd0UIFE0:BTY080^[Zj0P37alL03`3;bl/0b/[:
0<_;b`3;bl/0bLW90<O7a`34a<@0aLG50<C4a031`L40_[jn0<71`@34a<@0_kno0;bl_0020<71`@80
`<300P32`/801@30`<00`l?30<;2`P36a/H0aLG50080_kno00<0_;bl0<;2`P32`/800P31`L402033
`l<0a<C40<71`@34a<@0a/K60<G5a@37alL0b<S80P36a/H20<W9b@0:0<O7a`35aLD0b<S80<[:bP33
`l<0_[jn0<C4a03;bl/0dm?C0<g=c@80c<c<01X0cLg=0<k>cP3AdM40dM7A0=3@d03=cLd0bLW90;Vi
^@2DU9@0Ph>306i^KP1QHF40FEUI05]KF`1FEUH0EeMG05IFEP1KFe/0GUiN05eMG@1IFET0F5QH05iN
GP1DE5@0F5QH05]KF`80EUIF00d0Hf=S06IVIP1_Kfl0LG5a07MgM`2=SHd0WinO0;Bd]02e]KD0^[Zj
0<;2`P36a/H0cLg=0080eMGE00`0];Bd05UIF@0];Bd09RHV034a<@0^;Rh0<30`02DU9@0Z:RX0:b/[
038b<P0_;bl203Hf=P0?02d];@0i>CT0=3@d03De=@0^;Rh0;Bd]030`<00[:b/0:BTY02h^;P0a<C40
>c/k03Hf=P0e=CD0;Rh^0080:b/[00h0=cLg02HV9P0];Bd0>3Ph04a<C01NGUh0O7al08^;R`2BTY80
Ti>C09FEU@2BTY80Ti>C09:BTP80T92@00P0U9BD09FEU@2MWId0XZ:R09nOW`2XZ:P0Xj>S09nOW`<0
X:2P00/0XZ:R0:FUY@2MWId0XZ:R09fMW@2OWil0WYjN09nOW`2SXj<0WinO0:6QX@0209jNWP090:2P
X02NWYh0W9bL09jNWP2MWId0WYjN0:2PX02OWil0WIfM0080X:2P00l0W9bL09^KV`2IVIT0VIVI09NG
U`2JVYX0V9RH09VIV@2JVYX0VIVI09bLW02KVi/0W9bL09ZJVP2IVIT00P2KVi/03P2LW9`0Vi^K09fM
W@2JVYX0W9bL09NGU`2IVIT0V9RH09bLW02KVi/0VYZJ09^KV`2JVYX0Vi^K3P38h=P000`0b>3H0P1S
Hf<01P1OGel0HV9R069RHP1/K6`0J6QX06MWI`80IFEU00/0HV9R065QH@1SHf<0Hf=S061PH01RHV80
IfMW06=SH`1UIFD0J6QX06][J`0206e]K@0A079bLP1]KFd0M7Ad07AdM01mOGd0Q8B408n?S`2BTY80
U9BD09ZJVP2KVi/0WinO0:6QX@2VYZH0Zj^[0:b/[02^[Zh00P2/[:`20:f][@0U0:^[Z`2][Jd0[Jf]
0:ZZZP2][Jd0[Zj^0:n_[`2/[:`0[Jf]0:VYZ@2[Zj/0YJFU0:JVYP2MWId0UYJF09NGU`2>SXh0QXJ6
07YjNP1cLg<0IVIV05ADE01CDe<0DE5A04m?C`12@T80Bd];04a<C01BDU80E5AD051@D01EEED0GemO
065QH@1NGUh0GEeM061PH00205mOG`0B06ATI01OGel0IFEU069RHP1PH600K6a/06MWI`1PH600Hf=S
05eMG@1QHF40J6QX06IVIP1ZJVX0HV9R061PH01QHF40Hf=S0P1TI6@06P1QHF40HV9R06EUI@1UIFD0
HV9R06IVIP1TI6@0GemO06ATI01RHV80H61P05mOG`1HF5P0EUIF059BDP1>CTh0Hf=S0;2`/03Ogml0
emOG0<C4a032`/80dM7A0<c<c02n_[h0]kNg0P3<c<`0603IfMT0aLG50;2`/02j^[X0[Zj^0:>SX`2@
T900UiNG092@T02=SHd0O7al06a/K022PX80VIVI09>CT`2:RXX0O7al07IfMP1ZJVX0IFEU06i^KP1a
LG40KFe]075aL@80M7Ad00T0Ng]k07moO`1mOGd0PH6106a/K01LG5`0HF5Q06YZJP1gMgL00P1hN7P0
1`22PX80Ti>C08f=S@2?Shl0Rh^;08>3P`28R8P00P25QHD01P27QhL0RXZ:08Z:RP2>SXh0N7Qh07Mg
M`80P82000H0QhN707moO`22PX80Q8B40861P@1nOWh208R8R00>08^;R`28R8P0RHV908F5Q@1oOgl0
MgMg07AdM029RHT0Ti>C08b<S02ATI40Ti>C08f=S@2@T90208j>SP0608N7Q`1iNGT0JVYZ06IVIP1k
Ng/0QXJ60P2;Rh/208Z:RP80RHV90500OWin075aL@1HF5P0H61P079bLP1fMWH0MgMg07QhN01TI6@0
FEUI05eMG@1aLG40MGEe07MgM`1jNWX0KVi^06MWI`1PH600J6QX05iNGP1WIfL0QHF507moO`1XJ6P0
L71`07EeM@1kNg/0P82008^;R`2<S8`0OGem06MWI`1IFET0EeMG04i>CP1<C4`0B4Q803`l?00c<c<0
=SHf03`l?018B4P0DU9B06][J`20P800OGem06MWI`0o?cl0?3`l03/k>`0j>SX0GemO04i>CP11@D40
=SHf02d];@0_;bl0;2`/02TY:@0^;Rh0:2PX02HV9P0Y:BT0;Rh^03<c<`0[:b/0:BTY02PX:00];Bd0
<30`03Ph>01NGUh0RHV90:RXZ032`/80/K6a09RHV02LW9`0UYJF09FEU@80YjNW00<0][Jf0<?3``35
aLD00P38b<P00`3:b/X0bLW90<S8b0020<G5a@<0`l?300T0a/K60<?3``33`l<0_kno0<71`@33`l<0
`L710<C4a033`l<00P35aLD01`33`l<0`/;20<71`@34a<@0`/;20<30`02k^k/00P32`/801@31`L40
aLG50<71`@34a<@0`l?30080alO700H0b<S80<C4a039bLT0b<S80<O7a`36a/H20<W9b@0=0<_;b`36
a/H0b<S80<W9b@2o_kl0`l?30<W9b@3AdM40d=3@0<c<c03;bl/0cLg=0<_;b`020<o?c`0F0=3@d03?
cll0d=3@0<o?c`38b<P0_kno0:n_[`2FUYH0O7al079bLP1SHf<0G5aL05=CD`1KFe/0E5AD05aLG01O
Gel0Fe]K05eMG@1CDe<0FUYJ05QHF080De=C01l0Fe]K065QH@1SHf<0IVIV069RHP1bLW80QhN709bL
W02WYjL0]KFe0;fm_@32`/80b/[:0=7Ad@3GemL0e=CD0:JVYP15ADD09RHV06IVIP0V9RH0;Rh^02HV
9P0^;Rh0;2`/034a<@0g=cL0;Rh^03Lg=`0d=3@0>3Ph00<0<c<c00H0<30`03Ph>00[:b/0:b/[02l_
;`0^;Rh203Ti>@0>03Ph>00b<S80<30`02h^;P0_;bl092@T02LW9`0^;Rh0?clo05aLG01hN7P0QXJ6
096AT@2JVYX209FEU@0309:BTP2@T900T92@0080SXj>00P0U9BD09NGU`2KVi/0WYjN09nOW`2SXj<0
YZJV0:6QX@80XZ:R00/0WIfM0:JVYP2PX:00XJ6Q09nOW`2PX:00WinO09jNWP2PX:00WinO0:2PX003
0:6QX@0;0:2PX02NWYh0WinO09jNWP2PX:00Vi^K09fMW@2JVYX0WIfM09jNWP2LW9`00P2IVIT209NG
U`0409bLW02GUiL0VYZJ09ZJVP<0Vi^K00@0VYZJ09VIV@2MWId0W9bL0P2IVIT00`2HV9P0VIVI09RH
V00209ZJVP0609RHV02JVYX0WYjN09ZJVP2LW9`0WYjN0P2IVIT>0<SPf0003038h=P206IVIP0D06MW
I`1SHf<0Hf=S06ATI01VIVH0I6AT06MWI`1RHV80IVIV069RHP1PH600IfMW065QH@1UIFD0I6AT069R
HP1ZJVX0JFUY06e]K@1XJ6P206YZJP0806UYJ@1iNGT0MgMg07emO@25QHD0SXj>08f=S@2DU9@209^K
V`0809nOW`2QXJ40YZJV0:b/[02][Jd0[:b/0:f][@2_[jl20:j^[P030:n_[`2][Jd0];Bd00<0[Zj^
0P2][Jd08@2a/K40ZJVY0:ZZZP2XZ:P0Xj>S09jNWP2FUYH0Ti>C08Z:RP25QHD0OGem06m_K`1VIVH0
Fe]K05=CD`1:BTX0Bd];04I6AP1;Bd/0Cdm?051@D01FEUH0DE5A059BDP1NGUh0HV9R05iNGP1KFe/0
GemO06EUI@1RHV80GUiN05mOG`02069RHP05065QH@1UIFD0Hf=S06=SH`1WIfL00P1PH60206MWI`0<
06ATI01PH600H61P06=SH`1LG5`0I6AT05mOG`1RHV80Hf=S069RHP1XJ6P0HV9R0P1SHf<04`1OGel0
GEeM069RHP1OGel0GEeM05]KF`1FEUH0De=C04a<C01_Kfl0`l?30=_Kf`3Jf]X0dM7A0;no_`2n_[h0
cLg=0<k>cP2i^KT00P2a/K400`3;bl/0b/[:0;no_`020:ZZZP0?0:b/[02QXJ40PX:207alO02?Shl0
QHF507]kN`1aLG40Ti>C0:RXZ02IVIT0QHF507IfMP1YJFT0KFe]0080JVYZ01P0Kfm_07AdM01aLG40
OGem0820P01gMgL0OWin08>3P`1gMgL0Kfm_05eMG@1PH600M7Ad07YjNP1hN7P0MgMg08J6QP2?Shl0
T92@08V9R@26QXH0RHV908F5Q@21PH4308V9R@0S096AT@2<S8`0MgMg079bLP1nOWh0Ogmo08:2PP1m
OGd0QXJ607inOP22PX80QXJ608R8R029RHT0Q8B408j>SP26QXH0Ng]k07moO`1jNWX0OGem08V9R@2=
SHd0SXj>09FEU@2DU9@0SHf=08J6QP27QhL0RHV908b<S027QhL0MWIf06ATI01hN7P00P20P800E026
QXH0Ti>C09NGU`2;Rh/0Ogmo075aL@1XJ6P0G5aL069RHP1TI6@0J6QX06i^KP1UIFD0HV9R05QHF01G
EeL0GemO06UYJ@1]KFd0HV9R05ADE019BDT0F5QH05YJFP1PH600OGem0861P@1lO7`0UIFE09VIV@2>
SXh0Q8B408N7Q`2;Rh/0QhN708F5Q@1nOWh0Kfm_04e=C@15ADD0?clo04Y:BP13@d<0B4Q804E5A@0n
?Sh0>CTi04e=C@1RHV80NWYj0820P01TI6@0>3Ph03Xj>P12@T80FUYJ0410@011@D40>3Ph03<c<`0e
=CD0<C4a03Hf=P0g=cL0;2`/02TY:@0];Bd0;Rh^02TY:@0Z:RX0;Rh^02LW9`0V9RH092@T02<S8`0[
:b/0DU9B07MgM`2^[Zh0a<C40<30`02^[Zh0UiNG096AT@80VYZJ00<0WinO0:^[Z`2m_Kd00P32`/80
4@33`l<0alO70<O7a`37alL0bLW90<C4a033`l<0`/;20<S8b034a<@0`l?30<30`031`L40`/;20<71
`@33`l<0a<C40080aLG500<0a/K60<C4a031`L400P31`L401P32`/80_Kfm0<71`@2l_;`0`L710<C4
a080`l?300<0`/;20<C4a037alL00`37alL0:@38b<P0bLW90<W9b@36a/H0bl_;0<S8b036a/H0alO7
0<W9b@38b<P0a/K60<O7a`3>c/h0cLg=0=;BdP3>c/h0clo?0<_;b`3?cll0d];B0<k>cP3AdM40clo?
0<c<c03@d=00bl_;0<c<c037alL0[Jf]09FEU@28R8P0OWin06a/K01UIFD0G5aL05UIF@1KFe/0FUYJ
05QHF01EEED0EeMG00<0F5QH0180FUYJ05iNGP1IFET0GUiN05YJFP1SHf<0MGEe08V9R@2KVi/0Zj^[
0;bl_02n_[h0a<C40<o?c`3Hf=P0f][J0=3@d023Ph<202`/;00<02PX:00/;2`09RHV02PX:00^;Rh0
<C4a02XZ:P0_;bl0<S8b034a<@0b<S80<C4a0P0];Bd01`0c<c<09bLW02`/;00f=SH0>c/k03Lg=`0d
=3@00P0e=CD04@0i>CT0;Bd]02`/;00/;2`0:RXZ02PX:00a<C40=cLg04a<C01^KVh0OWin08f=S@2C
Ti<0UIFE09:BTP2CTi<0T92@0080Shn?00L0Rh^;09:BTP2FUYH0WIfM0:>SX`2QXJ40WinO0080X:2P
0P2RXZ802`2QXJ40XZ:R09nOW`2PX:00WinO0:2PX02OWil0X:2P09bLW02QXJ40X:2P0080WYjN00P0
W9bL09nOW`2RXZ80WIfM09^KV`2OWil0WIfM09^KV`80W9bL0P2MWId02P2GUiL0V9RH09ZJVP2HV9P0
Vi^K09bLW02JVYX0WYjN09fMW@2LW9`209fMW@0:09^KV`2JVYX0Vi^K09RHV02JVYX0VIVI09ZJVP2I
VIT0UiNG09^KV`80W9bL00H0UiNG09ZJVP2KVi/0V9RH09^KV`2HV9P>0<SPf0003038h=P2069RHP05
06MWI`1TI6@0I6AT06=SH`1WIfL00P1QHF408@1OGel0IVIV06QXJ01RHV80HF5Q061PH01SHf<0IVIV
065QH@1YJFT0IfMW06QXJ01ZJVX0KFe]075aL@1`L700MWIf07alO01nOWh0Ph>308^;R`2>SXh0V9RH
09VIV@2LW9`0X:2P0:>SX`2WYjL0Z:RX0:f][@2ZZZX0[jn_0:j^[P020:b/[080Zj^[00L0/;2`0:f]
[@2^[Zh0[jn_0:j^[P2a/K40/;2`0080[:b/01<0YJFU0:6QX@2PX:00UiNG092@T02=SHd0QXJ607al
O01_Kfl0IfMW065QH@1DE5@0Bd];04m?C`16ATH0ADE504a<C01?Cdl0EUIF0080E5AD01H0Fe]K05mO
G`1KFe/0IVIV05iNGP1PH600GUiN05]KF`1TI6@0GemO065QH@1WIfL0I6AT06IVIP1SHf<0I6AT05iN
GP1PH600I6AT061PH01UIFD0GemO0P1RHV8206=SH`0306IVIP1QHF40IFEU0080Hf=S00@0IfMW06AT
I01PH600HF5Q0P1MGEd0401KFe/0H61P05IFEP1?Cdl0D51@04m?C`1nOWh0f=SH0=GEe@3?cll0f=SH
0<g=c@2j^[X0`/;20<g=c@3>c/h20;Zj^P0K0;Rh^02l_;`0aLG50;Jf]P2UYJD0/K6a0:RXZ02ATI40
Ng]k08>3P`28R8P0QhN708^;R`1nOWh0VYZJ0:JVYP2WYjL0PH6107EeM@1dM7@0IVIV06e]K@1bLW80
KVi^07MgM`22PX80OGem0080N7Qh00/0Ogmo08B4Q01oOgl0KVi^05UIF@1[Jf/0L71`07MgM`1aLG40
NGUi08J6QP0308b<S00Y08f=S@25QHD0QhN708b<S027QhL0RXZ:08f=S@2;Rh/0QHF507QhN01`L700
M7Ad07QhN01mOGd0PH6108J6QP22PX80Ogmo08R8R026QXH0QhN708V9R@23Ph<0Ogmo0820P023Ph<0
Ng]k0820P02<S8`0U9BD09fMW@2EUID0RHV908J6QP2=SHd0TI6A09BDU02CTi<0Q8B406e]K@1LG5`0
0P1hN7P05`2=SHd0UYJF09RHV02>SXh0RHV907moO`1jNWX0Jf][05aLG01JFUX0IfMW06a/K01SHf<0
KFe]05QHF01@D500Cdm?05ADE01@D500Bd];04I6AP0j>SX0?clo0080B4Q801H0NGUi096AT@2<S8`0
VIVI09bLW02KVi/0UiNG09:BTP2:RXX0Rh^;08J6QP2;Rh/0OGem075aL@1UIFD0EeMG05=CD`1QHF40
IFEU05ADE010@400?3`l0P1ADE404`1OGel0MGEe06m_K`1CDe<0@D510492@P1<C4`0@D5103hn?P0o
?cl0?Cdm04I6AP0g=cL0>SXj04E5A@0e=CD0;2`/02TY:@0b<S800P0];Bd03P0_;bl0:b/[02LW9`0V
9RH09bLW02/[:`0Z:RX0BDU908j>SP2i^KT0bLW90<S8b02`/;00UYJF0P2DU9@03@2CTi<0WYjN0:JV
YP2`/;00^KVi0;^k^`32`/80b<S80<[:bP3=cLd0alO70<C4a032`/800P36a/H02033`l<0`L710<?3
``2n_[h0`<300;no_`32`/80`l?30P35aLD04`34a<@0alO70<30`02o_kl0`<300<71`@33`l<0_kno
0;jn_P30`<00`L710<G5a@34a<@0aLG50<C4a036a/H0b<S80<W9b@37alL00P39bLT01`3:b/X0b<S8
0<G5a@38b<P0b/[:0<W9b@37alL00P38b<P02`3<c<`0c/k>0<k>cP3<c<`0bl_;0<[:bP3<c<`0clo?
0<k>cP3=cLd0d=3@0080c/k>00/0c<c<0<k>cP3Bd]80cLg=0<K6aP2b/[80WinO09>CT`2@T900P820
06][J`0205aLG00405QHF01DE5@0D51@05MGE`80EEEE01<0F5QH05IFEP1JFUX0GemO05QHF01RHV80
KVi^079bLP21PH40Ti>C0:n_[`2o_kl0`l?30<_;b`3Cdm<0e]KF0=OGe`2i^KT0D51@0080:2PX0180
:RXZ02@T900/;2`0:2PX030`<00];Bd0<S8b03Hf=P0^;Rh0<c<c030`<00/;2`0<C4a03Lg=`0Z:RX0
;2`/030`<00b<S82030`<00B03Xj>P0d=3@0?clo038b<P0a<C40:RXZ02TY:@0/;2`0<c<c038b<P1<
C4`0Hf=S07IfMP26QXH0UYJF09FEU@2IVIT0UYJF0P2DU9@01@2BTY80SXj>08b<S02BTY80VYZJ0080
WinO0P2QXJ401@2RXZ80WinO0:2PX02RXZ80WYjN00D0WinO00@0WYjN0:2PX02NWYh0Y:BT0P2PX:03
09bLW00509fMW@2JVYX0V9RH09fMW@2LW9`00P2MWId01P2NWYh0WIfM09^KV`2KVi/0VIVI09ZJVP80
Vi^K01P0VYZJ09bLW02NWYh0VYZJ09bLW02KVi/0VIVI09bLW02KVi/0UYJF09VIV@2JVYX0W9bL09^K
V`2IVIT0W9bL09fMW@2IVIT0VYZJ09VIV@2LW9`0V9RH09ZJVP2IVIT>0<SPf0003038h=P206=SH`0?
06ATI01RHV80IfMW065QH@1RHV80HF5Q069RHP1PH600IVIV06a/K01MGEd0Hf=S06ATI01[Jf/0K6a/
0080IVIV00X0JFUY06MWI`1XJ6P0J6QX06YZJP1aLG40Lg=c07alO01oOgl0R8R80P2;Rh/01@2CTi<0
VIVI09ZJVP2KVi/0WinO0080YZJV00@0[Jf]0:^[Z`2b/[80[Zj^0P2ZZZX01`2_[jl0[:b/0;2`/02`
/;00ZJVY0:j^[P2ZZZX00P2[Zj/0402/[:`0YjNW0:>SX`2VYZH0XJ6Q09NGU`2ATI40Rh^;08B4Q01d
M7@0KVi^069RHP1GEeL0E5AD04];B`18B4P204Y:BP0=051@D01>CTh0E5AD05IFEP1GEeL0GEeM069R
HP1LG5`0Fe]K05aLG01OGel0GUiN061PH00206=SH`0;05mOG`1[Jf/0IFEU06IVIP1YJFT0I6AT05iN
GP1OGel0IVIV06UYJ@1/K6`00P1SHf<04@1VIVH0HV9R06=SH`1SHf<0HF5Q069RHP1VIVH0HV9R06AT
I01SHf<0IfMW06=SH`1RHV80GUiN05QHF01IFET0EUIF0080DU9B00/0EEEE07emO@3Lg=`0eMGE0<;2
`P3AdM40emOG0<[:bP2f][H0`<300<[:bP020<_;b`0j0;bl_02_[jl0]kNg0;Jf]P2c/k<0U9BD09jN
WP2TY:@0Ti>C08:2PP1hN7P0VYZJ0:>SX`2@T900RHV90:6QX@2b/[80UIFE0861P@1_Kfl0KFe]075a
L@1WIfL0JFUY07moO`1lO7`0MGEe07AdM01bLW80NGUi08B4Q026QXH0PX:2079bLP1OGel0IVIV07Ad
M01nOWh0O7al0820P028R8P0T92@08^;R`2:RXX0T92@08R8R025QHD0RXZ:08J6QP29RHT0QXJ608^;
R`27QhL0QXJ606a/K01bLW80NWYj08B4Q080Ph>30P20P8000`25QHD0RXZ:08F5Q@0208J6QP0A0861
P@27QhL0PH6107]kN`20P800S8b<09>CT`2BTY80RXZ:08^;R`2ATI40U9BD09ZJVP2EUID0RXZ:08J6
QP1gMgL00P1cLg<09`2<S8`0T92@09BDU02EUID0Shn?08^;R`29RHT0Ogmo079bLP1WIfL0I6AT06EU
I@1VIVH0Jf][069RHP1BDU80BTY:04E5A@0n?Sh0>c/k03lo?`19BDT0A4A4038b<P10@400NGUi09BD
U02?Shl0U9BD0:>SX`2VYZH0Z:RX0::RXP2GUiL0Ph>307QhN02:RXX0QXJ607alO00208F5Q@80Ng]k
00d0MGEe06i^KP1QHF40H61P05]KF`1DE5@0DE5A05QHF01fMWH0H61P055AD@15ADD0B4Q80080DU9B
01X0DE5A05UIF@13@d<0B4Q804=3@`1@D500?3`l02l_;`0[:b/0=CDe03Hf=P0e=CD0:BTY02h^;P10
@400<c<c02HV9P0T92@0:b/[04Q8B01kNg/0Xj>S0;Fe]@37alL0aLG50;>c/`80Xj>S00P0VIVI09bL
W02PX:00WinO0:6QX@2h^;P0`l?30<;2`P80b/[:00<0aLG50<K6aP34a<@00P34a<@20<K6aP0>0<71
`@2o_kl0_[jn0;no_`34a<@0`<300<S8b036a/H0`/;20<O7a`31`L40`<300<;2`P33`l<30<;2`P03
0;jn_P30`<00`/;20080aLG500P0a<C40<?3``37alL0b<S80<W9b@37alL0aLG50<K6aP80bLW90P38
b<P01@3;bl/0alO70<K6aP3;bl/0bLW90080c/k>00P0cLg=0<k>cP3<c<`0bl_;0<g=c@3>c/h0bl_;
0<c<c080cLg=00@0bl_;0<k>cP3>c/h0d=3@0P3Bd]802`37alL0];Bd0:ZZZP2MWId0Shn?0820P01a
LG40HV9R05=CD`1ADE40EeMG0080DU9B01L0EEEE05MGE`1HF5P0G5aL05QHF01PH600IFEU06IVIP1^
KVh0Ph>309bLW02b/[80^k^k0<W9b@3De=@0eMGE0=SHf03?cll0V9RH038b<P0V9RH09BDU024Q8@03
02DU9@0:034a<@0c<c<0<30`02h^;P0d=3@0=CDe02TY:@0];Bd0=cLg02/[:`80:BTY0P0Z:RX202h^
;P0L03Hf=P0g=cL0=cLg03Hf=P0`<300;bl_02`/;00_;bl0=CDe04i>CP1GEeL0JFUY07inOP2>SXh0
Ti>C09JFUP2JVYX0TY:B092@T02ATI40T92@08n?S`2ATI40UYJF09ZJVP2MWId0XJ6Q0:>SX`<0XZ:R
00@0WinO0::RXP2UYJD0YZJV0P2NWYh01@2QXJ40X:2P09nOW`2NWYh0WIfM0080XJ6Q00<0WinO09bL
W02KVi/0102KVi/209fMW@0709bLW02MWId0W9bL09fMW@2NWYh0Vi^K09jNWP0209^KV`<0W9bL00L0
VIVI09ZJVP2LW9`0Vi^K09ZJVP2KVi/0VIVI0080VYZJ00P0W9bL09ZJVP2KVi/0VIVI09fMW@2IVIT0
VYZJ09VIV@80Vi^K00<0V9RH09VIV@38h=P03@38h=P000`0b>3H0P1SHf<0101TI6@0HF5Q061PH01Q
HF4306=SH`0506MWI`1UIFD0HV9R05mOG`1SHf<00P1RHV800`1XJ6P0I6AT065QH@0206=SH`0>06UY
J@1UIFD0JVYZ07AdM01_Kfl0MgMg07]kN`24Q8@0RHV908f=S@2ATI40UIFE09bLW02MWId20:BTY080
ZJVY00<0[:b/0:f][@2][Jd00P2ZZZX0102][Jd0/K6a0;2`/02_[jl20:f][@0B0:b/[02^[Zh0[Zj^
0:^[Z`2/[:`0YjNW0:6QX@2OWil0Vi^K09NGU`2;Rh/0Q8B407QhN01aLG40Hf=S05]KF`1@D500CDe=
0P15ADD02P1?Cdl0Bd];059BDP1ADE40De=C05ADE01MGEd0FUYJ065QH@1RHV8205mOG`0406QXJ01O
Gel0GEeM05mOG`80Hf=S00H0IFEU06=SH`1VIVH0I6AT05mOG`1SHf<306IVIP0A05mOG`1PH600J6QX
06=SH`1UIFD0H61P065QH@1WIfL0IVIV06ATI01SHf<0HV9R06EUI@1MGEd0H61P05UIF@1JFUX00P1F
EUH03@1>CTh0DE5A055AD@20P800e]KF0=cLg03<c<`0a<C40<c<c03Bd]80a/K60;^k^`2b/[800P39
bLT07@36a/H0]KFe0::RXP2b/[80^KVi0:BTY02:RXX0V9RH09jNWP2JVYX0PH6108J6QP2UYJD0WYjN
09BDU02>SXh0W9bL096AT@28R8P0NGUi07QhN01`L700Lg=c07emO@1iNGT0M7Ad07=cL`1`L700M7Ad
0080Ng]k00`0PH6108R8R023Ph<0JFUY06][J`1]KFd0Ng]k07QhN01eMGD0P82008Z:RP2@T90208n?
S`0@08R8R02<S8`0RHV908R8R027QhL0Ph>308f=S@2;Rh/0Shn?07MgM`1`L700MGEe07emO@1gMgL0
QXJ607inOP80Ph>300L0QHF508J6QP28R8P0RXZ:08^;R`2:RXX0QXJ60080P82000D0OWin08j>SP2D
U9@0Rh^;08f=S@0209BDU00509FEU@2DU9@0TI6A09BDU02<S8`00P1jNWX0>`1bLW80OWin08j>SP2D
U9@0RXZ:08b<S02>SXh0Q8B407UiN@1aLG40L71`06m_K`1ZJVX0K6a/06QXJ01MGEd0GUiN05UIF@1G
EeL0FEUI05]KF`1RHV80Bd];03Xj>P16ATH0OWin092@T02MWId0YZJV0:b/[02TY:@0X:2P0:>SX`2Q
XJ40Shn?075aL@20P800PH6108b<S025QHD0QXJ608b<S025QHD0P82008B4Q01dM7@0JFUY05ADE016
ATH0@T9204E5A@1CDe<0GEeM06m_K`1XJ6P0HV9R079bLP1WIfL0EUIF0080HF5Q01L0GemO05MGE`1H
F5P0<c<c034a<@0g=cL0@D5104I6AP0a<C40=3@d05ADE01NGUh0ATI602/[:`0R8R80;Bd]05UIF@2B
TY80UYJF09bLW02a/K40_;bl0<O7a`020;jn_P0;0:VYZ@2JVYX0WIfM0:6QX@2KVi/0X:2P0;Fe]@2f
][H0_[jn0<K6aP2o_kl00P30`<001`35aLD0`l?30<G5a@37alL0aLG50<71`@2n_[h00`32`/801036
a/H0aLG50<?3``35aLD20<?3``040<71`@33`l<0a<C40;no_`<0`<3000<0`/;20<71`@34a<@00P35
aLD03P36a/H0bLW90<W9b@38b<P0bLW90<G5a@3:b/X0alO70<S8b03;bl/0b/[:0<S8b036a/H0bLW9
0P3:b/X02`3>c/h0clo?0<o?c`3<c<`0b<S80<_;b`3=cLd0bl_;0<k>cP3=cLd0bl_;00<0cLg=00h0
clo?0=7Ad@3EeMD0eMGE0<o?c`31`L40[:b/0:>SX`2OWil0Ti>C08>3P`1YJFT0F5QH05UIF@80D51@
00H0CDe=05ADE01KFe/0Hf=S05MGE`1LG5`205mOG`0L06IVIP1jNWX0QhN709nOW`2c/k<0`L710<_;
b`3EeMD0fMWI0=[JfP3;bl/0JFUY02TY:@0];Bd0:b/[02<S8`0T92@0:RXZ02h^;P0`<300;bl_030`
<00d=3@0;Rh^02d];@0_;bl0=cLg02h^;P80:RXZ00X0:b/[02XZ:P0/;2`0=CDe03<c<`0f=SH0<c<c
02l_;`0d=3@0;Bd]0P0`<3002P0b<S80=SHf04I6AP1TI6@0MgMg08J6QP2FUYH0UiNG09VIV@2KVi/2
09FEU@0<08j>SP2?Shl0TY:B09FEU@2HV9P0XZ:R09jNWP2SXj<0WinO0:6QX@2UYJD0WinO0P2QXJ40
1`2PX:00WYjN09nOW`2NWYh0XJ6Q09nOW`2MWId0102PX:003`2OWil0WYjN09^KV`2IVIT0Vi^K09jN
WP2JVYX0W9bL09^KV`2MWId0WYjN09^KV`2JVYX0W9bL09^KV`0209bLW00809jNWP2MWId0WYjN09VI
V@2KVi/0V9RH09bLW02GUiL209^KV`0609bLW02JVYX0Vi^K09JFUP2JVYX0Vi^K0P2JVYX01P2HV9P0
VIVI09bLW02NWYh0Vi^K09RHV0h0b>3H000<0<SPf080Hf=S0P1RHV82065QH@0>069RHP1WIfL0Hf=S
06EUI@1RHV80HF5Q05iNGP1QHF40IFEU06=SH`1XJ6P0HF5Q05iNGP1RHV8306ATI00C06YZJP1/K6`0
L71`07EeM@1lO7`0Q8B408V9R@2=SHd0UIFE09JFUP2IVIT0WinO0::RXP2UYJD0ZZZZ0:j^[P2][Jd0
Zj^[0:b/[0020:n_[`0J0:j^[P2_[jl0/K6a0:f][@2[Zj/0[Jf]0:^[Z`2YZJT0[jn_0:VYZ@2XZ:P0
YjNW0:BTY02LW9`0VYZJ08j>SP2<S8`0Ph>307]kN`1_Kfl0IFEU05]KF`1@D500Bd];04A4A01<C4`2
04m?C`0<05IFEP1CDe<0E5AD05IFEP1HF5P0FEUI05eMG@1NGUh0HV9R065QH@1RHV80J6QX0P1QHF40
4@1MGEd0HF5Q06EUI@1UIFD0GEeM06ATI01MGEd0I6AT061PH01VIVH0HV9R06ATI01SHf<0IfMW06IV
IP1RHV80IVIV0080Hf=S00P0I6AT06=SH`1TI6@0HF5Q06EUI@1RHV80I6AT05aLG080F5QH00h0E5AD
04e=C@1?Cdl0D51@08^;R`3IfMT0fm_K0=WIf@38b<P0]kNg0<[:bP3Bd]80bl_;0;Bd]080]kNg01P0
`/;20;bl_02_[jl0WinO0:^[Z`2/[:`0W9bL0861P@2ATI40[Jf]09NGU`28R8P0QhN70:FUY@2SXj<0
S8b<08N7Q`25QHD0R8R807MgM`1fMWH0LG5a07MgM`20P80207IfMP0407YjNP1_Kfl0NGUi0820P080
OGem00H0RHV908N7Q`26QXH0LW9b06EUI@1iNGT307IfMP030861P@2?Shl0Ti>C0080SHf=0180SXj>
08V9R@28R8P0QHF50861P@28R8P0Rh^;08R8R024Q8@0O7al0861P@1dM7@0KVi^07moO`1nOWh0QXJ6
08:2PP26QXH308N7Q`0>08b<S02:RXX0T92@09:BTP23Ph<0NGUi08>3P`2<S8`0UYJF09RHV02FUYH0
Ti>C096AT@2DU9@209VIV@1G092@T01oOgl0Ogmo06][J`1WIfL0MgMg08J6QP2:RXX0RHV908f=S@2C
Ti<0Rh^;07alO024Q8@0OWin07alO01iNGT0N7Qh06UYJ@1]KFd0JFUY06m_K`1WIfL0GEeM05=CD`1=
CDd0>CTi05ADE020P800V9RH0:b/[02[Zj/0YZJV0:RXZ02WYjL0ZJVY0:BTY02JVYX0Q8B407UiN@22
PX80Ph>307MgM`1_Kfl0LW9b07alO01fMWH0OWin07=cL`1YJFT0I6AT05QHF01YJFT0NGUi0861P@2=
SHd0U9BD09RHV02BTY80[:b/09ZJVP2;Rh/0Ogmo06i^KP1WIfL0J6QX05aLG013@d<0DE5A069RHP1J
FUX0?clo0410@01`L700OWin075aL@1PH600<c<c02<S8`0_;bl0Ng]k0:FUY@2KVi/0U9BD09FEU@2R
XZ80/[:b00<0aLG501@0];Bd09fMW@2IVIT0Y:BT0::RXP2SXj<0Zj^[0;Jf]P2n_[h0_Kfm0;Vi^@2l
_;`0a<C40<O7a`34a<@0alO70<W9b@36a/H0`<300<;2`P80`L7100`0a<C40<?3``33`l<0`/;20<71
`@32`/80aLG50<;2`P36a/H0`L710;fm_@2o_kl30<?3``0;0<G5a@33`l<0a/K60<K6aP39bLT0a/K6
0<O7a`39bLT0b/[:0<S8b037alL00P39bLT01`3;bl/0b<S80<S8b03>c/h0bl_;0<W9b@3=cLd00P3>
c/h30<_;b`0F0<[:bP3;bl/0bl_;0<[:bP3;bl/0b/[:0<g=c@3<c<`0c/k>0=3@d03AdM40e]KF0=CD
e03Cdm<0c<c<0;fm_@2ZZZX0WYjN09JFUP2CTi<0T92@06e]K@80EUIF00L0C4a<05ADE01IFET0EeMG
05]KF`1JFUX0JVYZ0080HF5Q01`0KVi^07MgM`28R8P0Vi^K0;Fe]@37alL0e=CD0=WIf@3Jf]X0gMgM
0:n_[`12@T80:2PX024Q8@0W9bL09RHV02l_;`0m?Cd0:RXZ02d];@0^;Rh0<C4a02l_;`0];Bd0;bl_
03<c<`0b<S80;Bd]0P0[:b/04`0X:2P0;bl_03Lg=`0g=cL0=SHf03dm?@0g=cL0>CTi03@d=00_;bl0
;Bd]03De=@0i>CT0BTY:05IFEP1XJ6P0Ng]k08b<S02DU9@00P2GUiL309>CT`0E08n?S`2DU9@0UIFE
096AT@2GUiL0Vi^K09fMW@2PX:00Y:BT0:6QX@2VYZH0WinO0:6QX@2NWYh0WinO09fMW@2QXJ40X:2P
0::RXP2LW9`0XJ6Q0080X:2P00@0W9bL09jNWP2JVYX0Vi^K0P2JVYX209nOW`0609bLW02NWYh0Vi^K
09jNWP2IVIT0W9bL0`2KVi/01@2LW9`0Vi^K09jNWP2LW9`0V9RH0080VIVI00H0VYZJ09VIV@2IVIT0
W9bL09ZJVP2HV9P209ZJVP0:09VIV@2LW9`0VIVI09ZJVP2GUiL0UIFE09VIV@2KVi/0V9RH09BDU0h0
b>3H000<0<SPf080I6AT00<0IFEU065QH@1SHf<00P1RHV801@1SHf<0GemO05mOG`1PH600IFEU0080
Hf=S00L0H61P06=SH`1XJ6P0Hf=S065QH@1WIfL0IFEU0080JVYZ01<0J6QX06][J`1aLG40MGEe07Ui
N@27QhL0Rh^;08Z:RP2EUID0Ti>C09^KV`2OWil0WYjN0:FUY@2ZZZX0Zj^[0:f][@2[Zj/0[:b/0080
[jn_00P0[Zj^0:^[Z`2][Jd0[Jf]0:^[Z`2`/;00[:b/0:^[Z`80[Jf]00`0ZJVY0:JVYP2SXj<0WIfM
0:2PX02?Shl0S8b<08B4Q01iNGT0LG5a06=SH`1JFUX204m?C`0504E5A@14A4@0B4Q804m?C`1@D500
0P1JFUX01`1IFET0Fe]K05YJFP1QHF40HV9R05eMG@1UIFD00P1QHF402`1TI6@0H61P06EUI@1PH600
IfMW069RHP1XJ6P0H61P06ATI01OGel0Hf=S00<0IVIV00h0I6AT065QH@1TI6@0GUiN069RHP1TI6@0
J6QX06=SH`1VIVH0IFEU069RHP1PH600GemO065QH@80GemO00l0G5aL05ADE01>CTh0CDe=05ADE02E
UID0g]kN0=;BdP3GemL0e=CD0<;2`P2d];@0`L710=?Cd`39bLT00P2][Jd09@2YZJT0/;2`0;6a/@2P
X:00UYJF0:^[Z`2/[:`0WinO08R8R02JVYX0W9bL09fMW@2?Shl0UiNG0:RXZ02EUID0SXj>0820P024
Q8@0KVi^079bLP1kNg/0OGem07IfMP1`L700OGem07YjNP1hN7P0PX:20820P01oOgl0NWYj08:2PP29
RHT0SXj>07moO`1RHV800P1/K6`01`1gMgL0OWin07moO`22PX80R8R808n?S`2ATI400P2:RXX08@27
QhL0SHf=08V9R@2?Shl0QHF508J6QP25QHD0Shn?09:BTP1`L700KFe]075aL@1nOWh0RHV908>3P`24
Q8@0P82008N7Q`2:RXX0RHV908j>SP2QXJ40TY:B08F5Q@1mOGd0NWYj08N7Q`2DU9@0UYJF096AT@2D
U9@0UYJF09VIV@0209ZJVP0909>CT`28R8P0R8R807QhN01LG5`0F5QH06i^KP20P800Ph>30080UYJF
00D0SXj>08Z:RP25QHD0RHV907moO`0207QhN00@07UiN@1gMgL0LW9b079bLP1]KFd0De=C04];B`1<
C4`0D51@04i>CP20P800VIVI0:>SX`2ZZZX0Z:RX0:JVYP<0YJFU01T0Vi^K08j>SP1oOgl0P82007in
OP1cLg<0LG5a07EeM@1bLW80K6a/061PH01KFe/0HF5Q071`L026QXH0YZJV0:VYZ@2QXJ40WYjN0:BT
Y02VYZH0YjNW0:BTY026QXH0PX:20080J6QX01L0Ph>308b<S01gMgL0LW9b09RHV02TY:@0V9RH06EU
I@1`L700T92@08F5Q@1/K6`0B4Q802h^;P0c<c<0FEUI09>CT`2LW9`0WIfM09^KV`2:RXX0QhN70:2P
X0020;Rh^0070<C4a037alL0][Jf0;2`/02ZZZX0WYjN0:BTY0020:NWY`080;>c/`32`/80`L710;fm
_@3:b/X0d=3@0<c<c039bLT20<K6aP0;0<C4a02o_kl0_kno0<30`032`/80`l?30<;2`P33`l<0`L71
0<?3``31`L400P33`l<0202o_kl0_[jn0;jn_P31`L40`/;20<C4a033`l<0`<300P34a<@01038b<P0
bLW90<O7a`37alL30<W9b@050<S8b039bLT0bLW90<_;b`36a/H00P3=cLd01P3;bl/0c<c<0<g=c@3>
c/h0bl_;0<[:bP80cLg=0P3;bl/00`3<c<`0b/[:0<k>cP020<c<c0090<g=c@3AdM40d];B0=;BdP3E
eMD0e=CD0=KFeP3Cdm<0^[Zj00<0YJFU00P0X:2P09FEU@1jNWX0NWYj05mOG`1>CTh0Bd];051@D080
EeMG01D0HV9R05]KF`1PH600J6QX079bLP1jNWX0S8b<0:NWY`2n_[h0dM7A0=KFeP3MgMd0fm_K0=CD
e02?Shl0;bl_028R8P0P82009RHV028R8P0Y:BT00P0W9bL0400`<300;2`/03Lg=`0];Bd0;bl_03Lg
=`0b<S80;Bd]02`/;00d=3@0;2`/030`<00a<C40=3@d03<c<`0f=SH203hn?P0F03dm?@0a<C40=cLg
03Ph>00i>CT0@41004e=C@1NGUh0Lg=c08Z:RP2@T900Vi^K09>CT`2EUID0TI6A09RHV02BTY80TI6A
092@T02DU9@0VIVI09ZJVP80X:2P00d0Y:BT0::RXP2LW9`0WYjN0:6QX@2KVi/0W9bL09^KV`2OWil0
Vi^K09jNWP2RXZ80VYZJ0080WinO00L0W9bL09jNWP2JVYX0WYjN09ZJVP2KVi/0W9bL0080WYjN00L0
W9bL09fMW@2JVYX0WYjN09^KV`2MWId0VYZJ0080Vi^K0P2IVIT209^KV`0309RHV02MWId0WYjN0080
VIVI00l0WYjN09VIV@2KVi/0VIVI09bLW02JVYX0WIfM09VIV@2JVYX0UiNG09JFUP2IVIT0Vi^K09VI
V@2GUiL03P38h=P000`0b>3H0P1QHF40201UIFD0IVIV061PH01RHV80IFEU06IVIP1OGel0Hf=S0P1T
I6@0101SHf<0GUiN06=SH`1SHf<2069RHP0H06EUI@1SHf<0IVIV06QXJ01ZJVX0Jf][06YZJP1`L700
MGEe07=cL`1nOWh0QXJ608^;R`2DU9@0UIFE09ZJVP2OWil0X:2P0:JVYP2YZJT0Z:RX0:ZZZP2WYjL0
[:b/0P2][Jd30:b/[0040:ZZZP2^[Zh0[Jf]0:j^[P80[Jf]00@0ZJVY0:RXZ02[Zj/0Y:BT0P2LW9`0
2`2EUID0S8b<08F5Q@1lO7`0KVi^06ATI01JFUX0EeMG059BDP18B4P0ADE50080BDU900`0CTi>05QH
F01JFUX0FEUI05iNGP1JFUX0HV9R06=SH`1WIfL0HF5Q06ATI01OGel2065QH@0=06EUI@1QHF40H61P
061PH01UIFD0GemO06ATI01QHF40GUiN06MWI`1RHV80GUiN05mOG`02069RHP0L065QH@1PH600Hf=S
06=SH`1UIFD0HF5Q06EUI@1NGUh0HF5Q05aLG01RHV80GEeM05mOG`1NGUh0F5QH055AD@1@D500DE5A
09:BTP3Kfm/0d=3@0<c<c03AdM40d];B0<?3``2g]kL0a/K60=3@d080_[jn05@0Y:BT09VIV@2b/[80
ZZZZ09nOW`2HV9P0X:2P0::RXP2JVYX0QHF509BDU02ZZZX0WYjN08^;R`2@T900Xj>S09bLW025QHD0
Ng]k07QhN01gMgL0PH6107UiN@1gMgL0OWin0820P01hN7P0O7al08:2PP1kNg/0Ogmo07YjNP25QHD0
QhN708Z:RP26QXH0P82007]kN`1NGUh0JVYZ0820P01lO7`0M7Ad07moO`2=SHd0Ti>C08Z:RP2;Rh/0
S8b<08n?S`2BTY80Rh^;0820P027QhL0Q8B408j>SP2;Rh/0QXJ607inOP1fMWH0NGUi0861P@2:RXX0
Ng]k08B4Q027QhL0RXZ:08^;R`2BTY80VIVI08n?S`28R8P0Ogmo07YjNP23Ph<0R8R808^;R`2GUiL0
Vi^K09fMW@2NWYh0UiNG09VIV@2DU9@208b<S00]08V9R@1fMWH0G5aL05]KF`1NGUh0MgMg09JFUP2?
Shl0QhN708Z:RP2<S8`0P82007IfMP1eMGD0MWIf07MgM`1^KVh0HF5Q06MWI`1IFET0CTi>06=SH`1`
L700I6AT05IFEP20P800Rh^;09VIV@2WYjL0Y:BT0:RXZ02TY:@0Xj>S09bLW02>SXh0OWin075aL@1V
IVH0Hf=S065QH@1PH600J6QX071`L01lO7`0R8R80080RXZ:0180UIFE0::RXP2][Jd0XJ6Q09bLW02M
WId0VIVI09FEU@2MWId0Ti>C07IfMP1/K6`0JVYZ09VIV@2PX:00TY:B0861P@2JVYX20::RXP0A09FE
U@1fMWH0P82007inOP1gMgL0EUIF03De=@0h>3P0CTi>08:2PP2OWil0UiNG0:2PX02EUID0Q8B408Z:
RP2HV9P00P2QXJ40;P2^[Zh0^k^k0<?3``36a/H0/K6a0:JVYP2TY:@0/;2`0:FUY@2TY:@0^k^k0<C4
a032`/80bLW90<o?c`3;bl/0bLW90<c<c03:b/X0aLG50<71`@30`<00`/;20<K6aP34a<@0`L710<30
`032`/80`L710;fm_@31`L40_kno0<;2`P33`l<0`<300;jn_P33`l<0a<C40<;2`P33`l<0a<C40<K6
aP34a<@0bl_;0<W9b@35aLD20<K6aP80b<S80P39bLT20<S8b0060<_;b`3:b/X0bl_;0<W9b@3?cll0
c<c<0P3;bl/20<[:bP80cLg=01<0bl_;0<c<c03;bl/0bl_;0<c<c03@d=00clo?0=3@d03Bd]80dm?C
0=CDe03EeMD0e]KF0=;BdP2d];@0Xj>S0:^[Z`2PX:00U9BD0080VIVI01X0Rh^;07IfMP1GEeL0Cdm?
04Y:BP1FEUH0De=C05aLG01HF5P0HV9R06a/K01aLG40OGem09^KV`2b/[80`l?30=7Ad@3IfMT0fm_K
0=gMg@33`l<0Fe]K02HV9P0W9bL092@T02LW9`809BDU00X0:BTY02h^;P0];Bd0=CDe03@d=00[:b/0
;bl_034a<@0c<c<0:b/[0`0];Bd00`0d=3@0>SXj034a<@0203Lg=`0303@d=00`<300<c<c0080<S8b
00T0=cLg03dm?@10@400D51@06QXJ01oOgl0SHf=09:BTP2JVYX00P2IVIT04@2GUiL0TY:B09BDU02A
TI40Ti>C09NGU`2KVi/0WinO0:2PX02NWYh0X:2P0:6QX@2MWId0WYjN09nOW`2QXJ40Xj>S0080WIfM
00<0X:2P09nOW`2NWYh00P2LW9`01P2MWId0W9bL09jNWP2NWYh0X:2P09jNWP80WIfM01L0VIVI09jN
WP2LW9`0W9bL09nOW`2LW9`0WinO09RHV02LW9`0WIfM09jNWP2HV9P0WinO09fMW@2JVYX0WIfM09bL
W02OWil0Vi^K09jNWP2JVYX0VIVI09^KV`0209ZJVP0909bLW02KVi/0V9RH09NGU`2KVi/0WYjN09fM
W@2KVi/0UiNG00h0b>3H000<0<SPf080Hf=S01@0GEeM069RHP1UIFD0I6AT069RHP1SHf<0G5aL05mO
G`1SHf<0I6AT06EUI@1TI6@0IFEU069RHP1PH600IFEU06=SH`1TI6@0Jf][06YZJP80J6QX00/0Jf][
06e]K@1dM7@0NWYj07inOP28R8P0S8b<09:BTP2CTi<0VYZJ09nOW`020:6QX@050:ZZZP2^[Zh0[Zj^
0:^[Z`2/[:`00P2[Zj/00`2][Jd0[jn_0;2`/0020:f][@0L0:b/[02][Jd0ZJVY0:j^[P2[Zj/0ZZZZ
0:^[Z`2SXj<0VYZJ09FEU@2@T900Shn?0820P01hN7P0Jf][05eMG@1LG5`0De=C04];B`15ADD0BDU9
04];B`1ADE40DU9B05EEE@1DE5@0Fe]K05UIF@80FUYJ00L0Hf=S061PH01UIFD0I6AT05mOG`1MGEd0
HF5Q0080GemO00d0GUiN05mOG`1OGel0H61P06ATI01VIVH0GemO061PH01RHV80GemO06EUI@1VIVH0
I6AT0080HV9R00@0GemO069RHP1SHf<0HV9R0`1SHf<04`1OGel0GUiN065QH@1MGEd0FUYJ05ADE01=
CDd0C4a<051@D02BTY80f][J0=WIf@37alL0`/;20=;BdP3Cdm<0aLG50:n_[`2l_;`00P33`l<08@2k
^k/0WYjN0::RXP2UYJD0]KFe0:2PX02=SHd0Y:BT0:ZZZP2PX:00RXZ:0::RXP2OWil0W9bL08V9R@2S
Xj<0VIVI08R8R01`L700Hf=S07EeM@1`L700LG5a07UiN@22PX80PH6107alO01oOgl0OGem07QhN027
QhL0OGem08B4Q00208>3P`0X08f=S@2ATI40TI6A06=SH`1XJ6P0NWYj07inOP1iNGT0Ng]k08:2PP2=
SHd0TY:B08n?S`2ATI40SXj>092@T02>SXh0QhN708^;R`2=SHd0RHV908Z:RP2?Shl0UIFE08F5Q@1c
Lg<0Ng]k07alO01jNWX0R8R808F5Q@28R8P0T92@09JFUP2<S8`0Shn?08V9R@26QXH0RXZ:08b<S080
P82000L0UiNG09bLW02IVIT0UiNG09FEU@2DU9@0TY:B0080Ti>C0140UYJF08Z:RP1lO7`0K6a/05AD
E01TI6@0N7Qh07UiN@1nOWh0Q8B407emO@1eMGD0KFe]06a/K01^KVh0HF5Q05EEE@0205iNGP0L06EU
I@1/K6`0PH6108N7Q`1oOgl0H61P07=cL`27QhL0UIFE096AT@2NWYh0XZ:R0:>SX`2IVIT0S8b<07in
OP1WIfL0G5aL06i^KP26QXH0P82008>3P`2@T900WIfM0:>SX`2QXJ40VYZJ09jNWP80ZJVY00L0Y:BT
09:BTP29RHT0SXj>08f=S@2>SXh0Rh^;00<0RHV90140U9BD0:RXZ02RXZ80WYjN09ZJVP2XZ:P0YJFU
09FEU@2ATI40N7Qh06][J`1TI6@0De=C03Ph>00o?cl0Ng]k096AT@0209^KV`0609ZJVP2NWYh0SXj>
08Z:RP2KVi/0Ti>C0P2?Shl02@2ATI40ZZZZ0;Ng]`31`L40bLW90<30`02][Jd0ZZZZ0:VYZ@020:ZZ
ZP040;bl_030`<00a<C40<C4a080a/K600T0bLW90<[:bP38b<P0a/K60<C4a036a/H0alO70<?3``31
`L400P2n_[h07P2m_Kd0_[jn0;jn_P32`/80`L710<?3``30`<00a<C40<71`@33`l<0_Kfm0<;2`P34
a<@0`l?30<C4a036a/H0alO70<G5a@36a/H0b<S80<G5a@3<c<`0bLW90<O7a`36a/H0bLW90<_;b`39
bLT0c<c<0<[:bPD0cLg=00D0bLW90<c<c03<c<`0cLg=0<c<c0020<_;b`0?0<k>cP3@d=00cLg=0<o?
c`3@d=00dm?C0=CDe03Cdm<0e]KF0=;BdP3<c<`0[jn_0::RXP2WYjL0Y:BT0080VIVI00X0Ti>C09ZJ
VP2:RXX0IFEU05MGE`1ADE40DU9B055AD@1EEED0IFEU0P1TI6@02`1_Kfl0R8R809nOW`2a/K40b<S8
0=GEe@3MgMd0g]kN0=SHf02HV9P0:BTY00<08R8R00H08b<S02DU9@0T92@0;Rh^02`/;00_;bl2038b
<P0503Hf=P0d=3@0;2`/02TY:@0X:2P00P0`<3005`0b<S80=cLg038b<P0i>CT0>SXj03De=@0b<S80
;Rh^034a<@0i>CT0<C4a03`l?00g=cL0BDU905mOG`1gMgL0PX:2096AT@2JVYX0V9RH09fMW@2EUID0
Shn?0080TY:B00T0TI6A09JFUP2JVYX0UiNG09jNWP2QXJ40XZ:R09nOW`2RXZ800P2PX:001`2RXZ80
WinO09jNWP2OWil0X:2P0:6QX@2PX:000P2LW9`03@2JVYX0W9bL09bLW02IVIT0WIfM09bLW02KVi/0
WYjN09ZJVP2KVi/0WYjN09bLW02MWId00P2OWil0302JVYX0WinO09bLW02LW9`0VYZJ09fMW@2KVi/0
V9RH09VIV@2JVYX0WIfM09JFUP80Vi^K00P0WYjN09ZJVP2OWil0WYjN09bLW02JVYX0VIVI09^KV`80
VYZJ00<0VIVI09fMW@2IVIT03P38h=P000`0b>3H0P1VIVH01@1OGel0Hf=S069RHP1RHV80GUiN0080
H61P00<0GemO06ATI01OGel00P1TI6@0701OGel0HF5Q06ATI01QHF40HV9R06ATI01VIVH0K6a/06][
J`1YJFT0KFe]06i^KP1bLW80NGUi0861P@29RHT0Rh^;096AT@2EUID0VIVI0:2PX02QXJ40Y:BT0:RX
Z02YZJT0ZZZZ0:VYZ@2][Jd30:j^[P0G0:ZZZP2/[:`0[:b/0:^[Z`2ZZZX0ZJVY0:f][@2/[:`0ZJVY
0:^[Z`2VYZH0Xj>S09fMW@2IVIT0T92@08R8R021PH40N7Qh06i^KP1RHV80Fe]K05EEE@1?Cdl00P19
BDT02`18B4P0De=C04e=C@1CDe<0EeMG05UIF@1KFe/0Hf=S05UIF@1VIVH0I6AT0080HV9R00P0GemO
061PH01QHF40Hf=S069RHP1PH600GUiN05YJFP80G5aL00T0Hf=S069RHP1SHf<0H61P06ATI01OGel0
HF5Q06=SH`1NGUh00`1RHV801P1XJ6P0JFUY06EUI@1UIFD0JVYZ069RHP80H61P00`0G5aL05IFEP1D
E5@0E5AD04m?C`1EEED0WIfM0=kNgP3IfMT0e=CD0<;2`P2m_Kd20<[:bP0N0;jn_P2YZJT0Zj^[0:^[
Z`30`<00/k>c09NGU`2EUID0_Kfm0:b/[02DU9@0V9RH0:VYZ@2ZZZX0Vi^K08f=S@2CTi<0Y:BT09:B
TP2?Shl0SXj>08>3P`1mOGd0IfMW065QH@1UIFD0IfMW07MgM`21PH40Q8B40P1oOgl07@20P800PH61
08B4Q022PX80QXJ607alO01nOWh0QhN708f=S@2>SXh0NWYj06QXJ01YJFT0MgMg0861P@1oOgl0M7Ad
08:2PP2?Shl0UiNG09BDU02@T900TY:B08R8R029RHT0Shn?08^;R`29RHT0S8b<0080Rh^;01<0T92@
08>3P`1^KVh0Kfm_07inOP2;Rh/0RXZ:08R8R02=SHd0R8R808F5Q@2:RXX0SXj>09:BTP2MWId0T92@
07emO@1jNWX0SXj>0080UYJF00@0T92@09:BTP2DU9@0VIVI0P2LW9`05@2HV9P0UIFE09BDU029RHT0
LG5a069RHP1LG5`0I6AT06a/K01ZJVX0Kfm_06UYJ@1XJ6P0Fe]K05YJFP1MGEd0Fe]K06UYJ@1aLG40
MWIf08B4Q00209VIV@0A08N7Q`1bLW80MgMg096AT@2SXj<0S8b<08j>SP2DU9@0UYJF08j>SP1kNg/0
JFUY04i>CP1_Kfl0X:2P0::RXP2QXJ400P2SXj<01P2RXZ80XJ6Q0:>SX`2XZ:P0YZJV0:>SX`80WYjN
00d0T92@08N7Q`25QHD0RHV9092@T02NWYh0WIfM09jNWP2MWId0WinO0:FUY@2SXj<0YZJV0080Xj>S
00@0WIfM09JFUP2CTi<0TY:B0P2EUID03@27QhL0HV9R07YjNP2[Zj/0Z:RX0:2PX02OWil0YZJV09BD
U02;Rh/0V9RH09fMW@2DU9@00P2?Shl07P23Ph<0VIVI0:BTY02b/[80`/;20<G5a@30`<00^;Rh0;:b
/P2/[:`0XZ:R0;2`/02_[jl0^KVi0<;2`P33`l<0_Kfm0<71`@38b<P0bl_;0<O7a`34a<@0`l?30<O7
a`36a/H0`/;20;no_`2l_;`0^KVi0;bl_080_kno0P31`L400`2o_kl0_Kfm0;no_`020<71`@0;0<30
`033`l<0a<C40<C4a037alL0aLG50<O7a`36a/H0alO70<G5a@39bLT00P36a/H03038b<P0alO70<W9
b@3=cLd0bLW90<K6aP3<c<`0cLg=0<c<c03=cLd0b/[:0<g=c@<0c<c<0180bl_;0<[:bP3:b/X0bl_;
0<k>cP3=cLd0c/k>0<o?c`3AdM40e=CD0=?Cd`3De=@0dm?C0=3@d039bLT0Xj>S09^KV`2TY:@20:RX
Z00:09^KV`2FUYH0WIfM09VIV@1lO7`0IVIV059BDP1ADE40DU9B05MGE`80GEeM00`0IVIV07moO`2A
TI40WYjN0:n_[`3;bl/0f][J0=gMg@3Ng]h0^k^k04A4A00V9RH2024Q8@03020P800S8b<09BDU0080
;2`/0P0];Bd0200/;2`0<30`03Lg=`0Z:RX0;Rh^03De=@0];Bd0<30`0P0];Bd0100d=3@0=cLg03`l
?00h>3P203<c<`0:03Lg=`0d=3@0=CDe03@d=00m?Cd0C4a<05ADE01]KFd0PX:208V9R@80VIVI01D0
WIfM09JFUP2BTY80TY:B09BDU02=SHd0Ti>C09RHV02FUYH0WIfM09ZJVP2PX:00XZ:R09jNWP2OWil0
W9bL0:2PX02RXZ80WinO09jNWP2LW9`00P2PX:0209fMW@0509ZJVP2OWil0W9bL09^KV`2JVYX00P2M
WId0102KVi/0WYjN09^KV`2IVIT209^KV`0609jNWP2KVi/0VYZJ09VIV@2JVYX0WinO0P2LW9`00`2N
WYh0W9bL09^KV`0209fMW@0609ZJVP2MWId0WinO09nOW`2LW9`0WIfM0`2LW9`00`2EUID0UiNG09ZJ
VP0209VIV@0309RHV02GUiL0b>3H00d0b>3H000<0<SPf080HV9R00D0H61P06=SH`1RHV80H61P06AT
I00206EUI@0>061PH01SHf<0H61P061PH01NGUh0GemO061PH01RHV80I6AT06MWI`1SHf<0I6AT06MW
I`1[Jf/206QXJ00:079bLP1cLg<0NWYj08>3P`25QHD0RHV9092@T02DU9@0V9RH0:2PX080Xj>S00D0
YZJV0:ZZZP2[Zj/0[:b/0:j^[P030:^[Z`030:b/[02`/;00[Jf]00<0ZZZZ00L0[:b/0:^[Z`2ZZZX0
YjNW0:FUY@2RXZ80W9bL0080Ti>C00T0S8b<08R8R01gMgL0KFe]05eMG@1LG5`0DU9B055AD@1;Bd/0
0P18B4P0101<C4`0F5QH05IFEP1JFUX205]KF`0705aLG01PH600I6AT06EUI@1OGel0HF5Q061PH002
06IVIP0506=SH`1OGel0GemO05mOG`1KFe/00P1NGUh00`1UIFD0HF5Q06ATI002065QH@0905aLG01N
GUh0HF5Q061PH01UIFD0HF5Q06EUI@1SHf<0IFEU0080I6AT01@0HF5Q069RHP1OGel0HF5Q05aLG01G
EeL0EEEE051@D01>CTh0F5QH0::RXP3Ogml0dM7A0=?Cd`3>c/h0^;Rh0;Ng]`35aLD0c<c<0<?3``80
XJ6Q00/0/;2`0;6a/@2[Zj/0UIFE0:VYZ@2VYZH0XJ6Q092@T02<S8`0YJFU09VIV@0208^;R`0N0:VY
Z@2FUYH0TY:B0820P024Q8@0QXJ6075aL@1RHV80FUYJ05eMG@1cLg<0PX:208>3P`1kNg/0QHF508Z:
RP28R8P0QhN708^;R`20P800NGUi07alO023Ph<0T92@08Z:RP2>SXh0Ph>306IVIP1_Kfl0Ph>30P1o
Ogl0201gMgL0Q8B409JFUP2CTi<0SXj>08^;R`25QHD0RHV90P2<S8`02`29RHT0Shn?08N7Q`28R8P0
S8b<08^;R`1kNg/0MWIf07UiN@21PH40QHF50080Rh^;0100PH6107moO`2;Rh/0TI6A09nOW`2PX:00
T92@08R8R029RHT0PH6108B4Q02@T900RHV9096AT@2GUiL0W9bL0P2IVIT01@2QXJ40W9bL0:>SX`2N
WYh0U9BD0080S8b<01h0M7Ad06e]K@1VIVH0Jf][06UYJ@1^KVh0LW9b07EeM@1gMgL0P8200861P@23
Ph<0T92@09bLW02NWYh0VIVI096AT@20P800NGUi09BDU02MWId0Ti>C08b<S02JVYX0RXZ:07]kN`1[
Jf/0F5QH03/k>`1mOGd20::RXP050:BTY02RXZ80XJ6Q09fMW@2RXZ800P2TY:@03P2PX:00WIfM09jN
WP2HV9P0Ti>C09bLW02PX:00XJ6Q0:NWY`2PX:00Y:BT0:VYZ@2NWYh0XZ:R0`2SXj<05@2WYjL0WinO
09RHV02GUiL0W9bL09RHV02SXj<0YJFU09JFUP2>SXh0Xj>S0:VYZ@2PX:00VYZJ0:NWY`2QXJ40UIFE
09BDU02VYZH0WIfM09JFUP0208b<S00G096AT@2LW9`0UIFE09ZJVP2b/[80_;bl0<71`@3:b/X0aLG5
0:f][@2NWYh0ZZZZ0:^[Z`2][Jd0[jn_0<30`033`l<0_;bl0<K6aP3:b/X0`l?30<C4a033`l<00P38
b<P01035aLD0`L710;^k^`30`<020;no_`080;fm_@2o_kl0_kno0<30`02n_[h0_;bl0<30`031`L42
0<;2`P030<?3``31`L40a/K60080aLG500@0`l?30<G5a@32`/80b<S80P35aLD01P36a/H0b/[:0<_;
b`3;bl/0b<S80<[:bP80bLW900/0cLg=0<k>cP3;bl/0cLg=0<[:bP3<c<`0cLg=0<k>cP3;bl/0b/[:
0<g=c@020<k>cP040<c<c03@d=00clo?0=GEe@80d];B00H0dM7A0=;BdP3Bd]80`<3009BDU02JVYX2
0:FUY@0M0:b/[02MWId0TY:B09^KV`2OWil0T92@07QhN01OGel0GUiN06QXJ01TI6@0GemO05iNGP1_
Kfl0P82008f=S@2UYJD0^k^k0=KFeP3Lg=`0g]kN0=;BdP1iNGT0:BTY02XZ:P0P82008B4Q02DU9@0W
9bL00P0^;Rh0200f=SH0;bl_03@d=00/;2`0<C4a030`<00d=3@0;bl_0P0`<3004P0];Bd0;Rh^030`
<00l?3`0?Shn03`l?00e=CD0<S8b03De=@11@D40AdM703Ph>00k>c/0@41004A4A01QHF40O7al08J6
QP80V9RH00`0W9bL09RHV02DU9@0Shn?09FEU@2@T900UIFE09BDU02IVIT0W9bL09^KV`2OWil40:2P
X0070:>SX`2PX:00XJ6Q0:2PX02NWYh0W9bL0:>SX`0209fMW@0909jNWP2MWId0Vi^K09fMW@2IVIT0
Vi^K09bLW02JVYX0WIfM0080Vi^K00P0WinO09bLW02OWil0VYZJ09^KV`2PX:00W9bL09jNWP80W9bL
00H0VYZJ09fMW@2LW9`0W9bL09^KV`2MWId209bLW00=09jNWP2KVi/0Vi^K09VIV@2MWId0V9RH09^K
V`2JVYX0WIfM09ZJVP2MWId0Vi^K09VIV@0>0<SPf0003038h=P205mOG`0>061PH01QHF40HV9R05iN
GP1SHf<0HV9R06=SH`1PH600IFEU05mOG`1QHF40GUiN05mOG`1NGUh4069RHP80J6QX0P1/K6`206e]
K@0<07YjNP1hN7P0Ogmo08F5Q@2<S8`0T92@09NGU`2KVi/0XJ6Q0:2PX02TY:@0ZJVY0P2[Zj/0202]
[Jd0/K6a0:n_[`2_[jl0[:b/0:VYZ@2/[:`0[jn_0P2/[:`0902][Jd0ZZZZ0:ZZZP2XZ:P0YjNW0:>S
X`2TY:@0WIfM09JFUP2EUID0RHV908N7Q`20P800Jf][05eMG@1KFe/0DU9B04];B`19BDT0C4a<04U9
B@1>CTh0CDe=05=CD`1EEED0GEeM05iNGP1SHf<0G5aL069RHP1LG5`0HF5Q05]KF`1PH600I6AT069R
HP80HF5Q00P0Hf=S05mOG`1RHV80Fe]K05iNGP1VIVH0HF5Q06EUI@80Hf=S00P0I6AT065QH@1QHF40
J6QX069RHP1SHf<0HV9R061PH080HV9R00D0H61P06EUI@1RHV80GemO05eMG@0205mOG`0>05ADE01@
D500Cdm?05=CD`2@T900f=SH0<k>cP3:b/X0clo?0<g=c@2m_Kd0/K6a0<;2`P3>c/h20;Zj^P0>09bL
W02YZJT0][Jf0:j^[P2MWId0VIVI0:j^[P2OWil0QHF508n?S`2FUYH0Shn?092@T02HV9P209:BTP0F
0820P01hN7P0PX:206e]K@1SHf<0Fe]K05EEE@1TI6@0NGUi08Z:RP21PH40S8b<08f=S@2:RXX0QHF5
08V9R@1kNg/0NWYj0820P023Ph<0RHV908>3P`80Shn?00<0LG5a06QXJ01eMGD00P21PH403@1jNWX0
N7Qh08N7Q`2CTi<0UIFE08f=S@2<S8`0RXZ:08R8R029RHT0SXj>096AT@28R8P00P2:RXX05@2;Rh/0
SXj>09>CT`1iNGT0N7Qh0820P025QHD0Ogmo08N7Q`28R8P0SXj>09:BTP2RXZ80VIVI09:BTP2GUiL0
S8b<07YjNP1eMGD0PX:208f=S@0209JFUP0[09VIV@2RXZ80XZ:R0:RXZ02UYJD0WIfM0:2PX02MWId0
Ti>C09VIV@2NWYh0TI6A08R8R02?Shl0VIVI09NGU`2?Shl0R8R808f=S@2CTi<0U9BD09:BTP2MWId0
UiNG092@T02DU9@0TY:B07moO`1kNg/0Q8B408^;R`2?Shl0SHf=08n?S`1dM7@0Jf][065QH@1:BTX0
ATI608j>SP2XZ:P0YZJV0:>SX`0209bLW00509nOW`2VYZH0XJ6Q09jNWP2MWId00P2NWYh08`2PX:00
WinO0:BTY02QXJ40YZJV0:BTY02PX:00Y:BT0:6QX@2OWil0X:2P0:JVYP2SXj<0YZJV0::RXP2QXJ40
UYJF09bLW02SXj<0WinO0:2PX02JVYX0VIVI0:BTY02XZ:P0WinO09jNWP2QXJ40XZ:R09fMW@2HV9P0
Y:BT0:NWY`2MWId0TI6A0080S8b<01P0WIfM09jNWP2JVYX0Ti>C09NGU`2ZZZX0^k^k0<?3``3<c<`0
_kno0;Bd]02a/K40[Zj^0:f][@2/[:`0[Jf]0;Jf]P34a<@0a/K60<G5a@2k^k/0`L710<W9b@3<c<`2
0<[:bP030<C4a02k^k/0_[jn00@0_;bl00@0_[jn0;bl_02n_[h0^[Zj0P2m_Kd01@2n_[h0a<C40<G5
a@31`L40`l?300<0`/;201P0a<C40<71`@36a/H0alO70<S8b036a/H0alO70<K6aP37alL0c<c<0<_;
b`39bLT0bl_;0<W9b@3;bl/0bLW90<_;b`3:b/X0bl_;0<c<c03=cLd0bl_;0<S8b03;bl/20<g=c@0<
0<c<c03=cLd0d=3@0=;BdP3?cll0d=3@0=;BdP3@d=00e=CD0=3@d02[Zj/0Ti>C0P2JVYX0802UYJD0
[:b/09nOW`2>SXh0Shn?09jNWP2MWId0SHf=07QhN01_Kfl0IFEU05EEE@1PH600K6a/07IfMP1oOgl0
UiNG0;2`/036a/H0e]KF0=oOg`3Kfm/0ZZZZ03Hf=P0R8R809bLW02TY:@0S8b<09BDU02d];@0^;Rh0
<C4a0P0f=SH03`0l?3`0?Shn034a<@0^;Rh0<S8b03Ti>@0_;bl0<S8b02l_;`0^;Rh0>CTi04U9B@12
@T80=CDe03Ti>@02038b<P0302h^;P0a<C40=SHf0080?clo0180F5QH06YZJP1oOgl0TI6A09NGU`2M
WId0VYZJ09JFUP2CTi<0U9BD09:BTP2DU9@0TI6A09BDU02KVi/0WIfM0:6QX@2OWil20:6QX@070::R
XP2OWil0WIfM09nOW`2KVi/0X:2P09jNWP0409fMW@0:09jNWP2KVi/0W9bL09^KV`2PX:00VIVI09jN
WP2JVYX0VIVI09^KV`80WYjN00L0W9bL09fMW@2LW9`0Vi^K09ZJVP2MWId0Vi^K0080WYjN00H0Vi^K
09fMW@2KVi/0VYZJ09jNWP2KVi/209bLW00509ZJVP2LW9`0WinO09bLW02NWYh00P2GUiL01@2LW9`0
VIVI09bLW02KVi/0VIVI00h0b>3H000<0<SPf080GUiN00h0GEeM05iNGP1RHV80GEeM06=SH`1RHV80
IfMW06EUI@1QHF40GEeM05iNGP1MGEd0HV9R05iNGP80HV9R01@0HF5Q05mOG`1UIFD0Hf=S06MWI`1S
Hf<0IVIV06a/K01eMGD0N7Qh07inOP27QhL0S8b<09BDU02GUiL0Vi^K0:2PX02QXJ40Xj>S0:VYZ@80
YjNW00D0[:b/0:ZZZP2^[Zh0[Zj^0:^[Z`030:f][@040;6a/@2/[:`0[Zj^0:n_[`80Zj^[00X0YJFU
0:6QX@2SXj<0Vi^K09VIV@2GUiL0SHf=0820P01lO7`0LW9b0P1SHf<01`1EEED0Bd];04Y:BP1<C4`0
DE5A04];B`1CDe<00P1EEED0401JFUX0GEeM065QH@1NGUh0GemO05aLG01MGEd0GUiN06IVIP1QHF40
H61P05mOG`1QHF40HV9R05aLG01OGel205eMG@<0H61P00<0IfMW06EUI@1VIVH00P1TI6@3069RHP0I
05aLG01NGUh0HV9R06=SH`1WIfL0GEeM06=SH`1PH600GEeM05]KF`1MGEd0EeMG05=CD`1@D500EUIF
09ZJVP3IfMT0d];B0<W9b@34a<@0clo?0<_;b`2h^;P0[jn_0;jn_P020<S8b0090:j^[P2LW9`0/K6a
0;>c/`2WYjL0Ti>C0:VYZ@2PX:00TY:B0080PX:200P0TI6A09^KV`2EUID0S8b<09FEU@21PH40MWIf
06a/K080Jf][00X0Hf=S05YJFP1HF5P0JVYZ08f=S@28R8P0TI6A08f=S@2:RXX0QXJ60P1jNWX04023
Ph<0QhN708Z:RP1nOWh0PH6108R8R02?Shl0RXZ:07emO@1_Kfl0MWIf0820P01oOgl0N7Qh07]kN`2<
S8`209>CT`0Q092@T027QhL0QXJ608V9R@2@T900TI6A09JFUP2=SHd0QHF508N7Q`2CTi<0UYJF08R8
R01iNGT0OGem07QhN01iNGT0R8R808V9R@27QhL0UYJF09ZJVP2GUiL0VIVI09BDU028R8P0S8b<08f=
S@1mOGd0RXZ:09BDU02GUiL0WYjN0080YJFU0180XJ6Q09nOW`2MWId0VYZJ09VIV@2HV9P0WYjN0:2P
X02EUID0U9BD09nOW`2IVIT0T92@096AT@2LW9`0Vi^K09jNWP2QXJ420::RXP0<09JFUP2;Rh/0Shn?
08j>SP2;Rh/0QhN707emO@1kNg/0MGEe07emO@1aLG40JFUY0P1IFET00`1MGEd0KVi^09FEU@020:ZZ
ZP0709nOW`2KVi/0YJFU0:RXZ02UYJD0Y:BT0:FUY@020:2PX0040::RXP2TY:@0Y:BT09jNWP80YJFU
0140WIfM0::RXP2LW9`0VYZJ0:6QX@2TY:@0YJFU0:^[Z`2UYJD0XJ6Q09^KV`2JVYX0Xj>S0:ZZZP2P
X:00Vi^K0:2PX0020:>SX`0;0:BTY02PX:00YJFU0::RXP2KVi/0W9bL0:FUY@2[Zj/0XZ:R09^KV`2<
S8`00P2IVIT0102RXZ80W9bL09^KV`2GUiL209:BTP0_0:FUY@2i^KT0`/;20;jn_P35aLD0`<300;Bd
]02TY:@0XZ:R0;>c/`2`/;00^[Zj0<30`032`/80_Kfm0;^k^`3;bl/0c<c<0<k>cP3;bl/0a/K60<C4
a030`<00_Kfm0;bl_02m_Kd0^k^k0;Fe]@2j^[X0^KVi0;^k^`2j^[X0_Kfm0<30`02n_[h0`<300<;2
`P31`L40`l?30;no_`33`l<0aLG50;jn_P33`l<0aLG50<O7a`35aLD00`37alL01@39bLT0bl_;0<_;
b`3;bl/0c<c<0080bl_;00L0c/k>0<g=c@39bLT0c/k>0<c<c039bLT0b/[:0080bl_;00L0clo?0<c<
c03=cLd0c/k>0=;BdP3@d=00dM7A0080dm?C00@0e=CD0=GEe@37alL0VIVI0P2CTi<0102IVIT0YZJV
0;2`/02VYZH208b<S01>09^KV`2TY:@0YjNW09^KV`27QhL0KFe]06MWI`1/K6`0LG5a07QhN02FUYH0
Z:RX0<30`03AdM40g=cL0=oOg`33`l<0DE5A02DU9@0T92@09BDU02TY:@0Z:RX0;2`/038b<P0/;2`0
<C4a03Ti>@0g=cL0>3Ph03<c<`0d=3@0?Shn03Hf=P0l?3`0;bl_03Hf=P0g=cL0<c<c04=3@`14A4@0
>CTi03/k>`0a<C40<30`038b<P0e=CD0=SHf030`<00n?Sh0B4Q8065QH@1bLW80QhN709JFUP2HV9P0
VIVI09NGU`2EUID0U9BD09:BTP2ATI40Shn?09BDU02HV9P0WIfM09nOW`2MWId0Vi^K0:2PX02NWYh0
X:2P09nOW`2QXJ40WinO0:2PX02LW9`0X:2P0P2MWId02@2OWil0WIfM09fMW@2LW9`0VYZJ09^KV`2M
WId0WYjN09ZJVP0209^KV`0509fMW@2KVi/0X:2P09nOW`2LW9`00P2NWYh02P2OWil0W9bL09bLW02M
WId0W9bL09jNWP2JVYX0WIfM09ZJVP2MWId209nOW`0<09bLW02NWYh0W9bL09bLW02NWYh0WinO09fM
W@2KVi/0WIfM09ZJVP2LW9`0Vi^K3P38h=P000`0b>3H0P1OGel0301QHF40H61P06MWI`1QHF40Hf=S
06EUI@1PH600HV9R065QH@1OGel0J6QX05mOG`80H61P0180Hf=S05iNGP1UIFD0GemO06ATI01UIFD0
Hf=S06ATI01XJ6P0L71`07AdM01iNGT0Ph>308J6QP2>SXh0TY:B09BDU02GUiL209jNWP060:JVYP2W
YjL0[Jf]0:ZZZP2_[jl0[:b/0P2][Jd00`2/[:`0[Zj^0:n_[`020:b/[00J0:^[Z`2/[:`0[Jf]0:b/
[02ZZZX0YZJV0:BTY02SXj<0WIfM096AT@2DU9@0SHf=08F5Q@1lO7`0M7Ad06e]K@1TI6@0De=C04i>
CP1<C4`0AdM705EEE@1=CDd0E5AD05UIF@1LG5`205]KF`0>05iNGP1LG5`0HF5Q061PH01OGel0H61P
06IVIP1QHF40H61P065QH@1OGel0H61P069RHP1XJ6P205iNGP0506ATI01RHV80Hf=S069RHP1SHf<0
0P1RHV801P1SHf<0IVIV05mOG`1SHf<0IFEU06=SH`80I6AT01D0IFEU06YZJP1VIVH0IFEU05eMG@1N
GUh0FUYJ05]KF`1EEED0DU9B05UIF@2PX:00h>3P0=?Cd`39bLT0_Kfm0<30`03;bl/0`l?30;6a/@2T
Y:@00P2n_[h05`2`/;00[Jf]09ZJVP2NWYh0Z:RX0:BTY02ATI40UIFE0:6QX@2FUYH0Ogmo092@T02J
VYX0U9BD07emO@23Ph<0O7al07QhN01ZJVX0JFUY06i^KP1ZJVX0HV9R0080G5aL01d0NGUi0820P02;
Rh/0RXZ:08f=S@23Ph<0MWIf07inOP2:RXX0S8b<08J6QP23Ph<0OGem08V9R@2<S8`0TY:B096AT@1j
NWX0JVYZ07=cL`1jNWX0N7Qh07IfMP1iNGT0SHf=096AT@28R8P0S8b<08^;R`03096AT@0409ZJVP2G
UiL0Rh^;08N7Q`80S8b<01D0SHf=092@T023Ph<0K6a/07=cL`1jNWX0Q8B408R8R02DU9@0Ti>C09NG
U`2OWil0Shn?096AT@2QXJ40UiNG08>3P`22PX80Ti>C09RHV02NWYh00P2MWId04P2NWYh0XJ6Q09VI
V@2HV9P0Vi^K09bLW02PX:00V9RH09bLW02IVIT0UiNG092@T02BTY80W9bL0:VYZ@2[Zj/0YjNW09jN
WP80XJ6Q00H0YjNW09fMW@2CTi<0UYJF08b<S027QhL208>3P`0F07moO`1kNg/0Rh^;09FEU@24Q8@0
SHf=09:BTP26QXH0SXj>09bLW02JVYX0WYjN0:2PX02TY:@0X:2P0:JVYP2[Zj/0XJ6Q0:JVYP2SXj<0
YJFU0:BTY080WinO01P0Y:BT0:VYZ@2SXj<0Vi^K0:2PX02NWYh0ZZZZ0:BTY02YZJT0[Jf]0:RXZ02N
WYh0Vi^K0:FUY@2ZZZX0Y:BT09bLW02YZJT0[Jf]0:RXZ02TY:@0ZZZZ0:b/[02PX:0209ZJVP060:FU
Y@2/[:`0YZJV0::RXP2KVi/0Ti>C0P2QXJ403P2SXj<0Vi^K09JFUP2FUYH0UIFE09NGU`2JVYX0WYjN
0:n_[`2g]kL0^k^k0<W9b@37alL0]kNg0P2YZJT05`2_[jl0_;bl0;bl_02^[Zh0^[Zj0;jn_P32`/80
b/[:0<c<c03>c/h0b/[:0<S8b037alL0_kno0<;2`P30`<00^k^k0;Vi^@2j^[X0][Jf0;Bd]02g]kL0
^;Rh0080^KVi00T0^k^k0<71`@32`/80`l?30<71`@33`l<0aLG50;no_`31`L400P36a/H03`33`l<0
b<S80<K6aP37alL0bLW90<S8b03;bl/0b/[:0<_;b`3=cLd0c/k>0<[:bP3>c/h0b/[:0<_;b`020<[:
bP040<S8b03:b/X0cLg=0<[:bP80c<c<00X0cLg=0=7Ad@3Cdm<0dM7A0=;BdP3?cll0f=SH0=7Ad@3?
cll0Zj^[0P2DU9@0902IVIT0W9bL0:VYZ@2b/[80Z:RX096AT@2;Rh/0U9BD0:6QX@2YZJT0YJFU0::R
XP28R8P0NGUi07AdM01nOWh0SHf=09nOW`2b/[80aLG50=OGe`3Ng]h0eMGE07alO00W9bL092@T02PX
:00Y:BT0;Bd]02/[:`0`<300;Rh^03De=@0g=cL0=CDe03@d=080<c<c00d0;bl_03Xj>P0j>SX0;bl_
03De=@0d=3@0ATI604E5A@0n?Sh0=SHf03De=@0m?Cd0;Bd]0080>3Ph01l0;Rh^038b<P0k>c/0B4Q8
05EEE@1]KFd0P820096AT@2GUiL0W9bL09NGU`2NWYh0Ti>C09JFUP2DU9@0T92@096AT@2DU9@0VYZJ
09^KV`2QXJ40Vi^K09jNWP2QXJ40W9bL09nOW`2KVi/0WYjN0:2PX02MWId0Vi^K0080WYjN00/0W9bL
09^KV`2PX:00W9bL09jNWP2LW9`0Vi^K09bLW02MWId0W9bL09fMW@0209^KV`0309nOW`2QXJ40WYjN
0080WYjN00P0WinO09fMW@2LW9`0Vi^K09bLW02MWId0W9bL09^KV`80WYjN00h0W9bL09^KV`2QXJ40
WIfM09bLW02OWil0WYjN09bLW02KVi/0W9bL09jNWP2LW9`0VYZJ09VIV@h0b>3H000<0<SPf080Hf=S
0200HV9R061PH01UIFD0Hf=S061PH01SHf<0FEUI05]KF`1OGel0GUiN05mOG`1LG5`0HF5Q061PH01M
GEd0Fe]K05mOG`1PH600G5aL065QH@1YJFT0Hf=S06YZJP1^KVh0MGEe07inOP23Ph<0Rh^;08b<S02A
TI40UYJF09ZJVP80X:2P00H0XZ:R0:JVYP2YZJT0Z:RX0:^[Z`2^[Zh20:ZZZP080:f][@2_[jl0ZZZZ
0:RXZ02[Zj/0[Jf]0:n_[`2/[:`30:VYZ@0B0::RXP2TY:@0Vi^K096AT@2BTY80RXZ:0861P@1hN7P0
Kfm_06MWI`1NGUh0Cdm?055AD@18B4P0ATI604m?C`1@D500EeMG0P1JFUX0301IFET0G5aL05]KF`1N
GUh0Hf=S061PH01QHF40IfMW05mOG`1TI6@0HV9R05iNGP80H61P00/0Hf=S065QH@1SHf<0HV9R05mO
G`1RHV80H61P05iNGP1OGel0GUiN05aLG002069RHP0K065QH@1SHf<0HV9R065QH@1VIVH0GemO065Q
H@1SHf<0I6AT06MWI`1MGEd0HF5Q05UIF@1MGEd0EEEE055AD@1EEED0U9BD0=gMg@3;bl/0bLW90<S8
b02f][H0^KVi0;fm_@30`<00[Zj^0080Zj^[0P2YZJT04@2VYZH0T92@09fMW@2NWYh0VYZJ08b<S02T
Y:@0V9RH08R8R020P800Ti>C096AT@1jNWX0N7Qh07]kN`27QhL0Kfm_0080KFe]02<0JVYZ06][J`1Q
HF40FEUI06=SH`1^KVh0QhN708Z:RP27QhL0Ng]k0820P029RHT0Rh^;08Z:RP27QhL0Ph>308F5Q@29
RHT0R8R808j>SP2DU9@0SXj>079bLP1]KFd0LW9b07alO01jNWX0MWIf07alO028R8P0RHV909>CT`2>
SXh0Shn?08j>SP0209>CT`0J096AT@2>SXh0TI6A08j>SP29RHT0QhN709:BTP2EUID0QXJ607inOP1`
L700OWin0861P@29RHT0SHf=09JFUP2EUID0Ti>C09ZJVP2OWil0VIVI08R8R029RHT0Ph>308n?S`2G
UiL20:6QX@0W09fMW@2LW9`0UYJF0:6QX@2RXZ80VYZJ09fMW@2RXZ80W9bL09:BTP2@T900U9BD09RH
V02[Zj/0[Zj^0:RXZ02NWYh0Ti>C09:BTP2HV9P0XJ6Q09bLW02BTY80UYJF09:BTP28R8P0SXj>09NG
U`2PX:00VYZJ0:BTY02SXj<0WIfM0:VYZ@2XZ:P0WIfM09ZJVP2?Shl0Ti>C0080WIfM00@0VIVI0:VY
Z@2YZJT0Xj>S0P2TY:@02P2MWId0XZ:R0:2PX02XZ:P0Y:BT0:2PX02UYJD0WYjN0::RXP2QXJ420:RX
Z00@0:>SX`2VYZH0ZJVY0:FUY@2KVi/0WYjN0:f][@2XZ:P0V9RH0:6QX@2YZJT0YZJV0:6QX@2XZ:P0
[:b/0:JVYP80V9RH00D0Xj>S0:FUY@2VYZH0YZJV09jNWP0209nOW`80Z:RX01X0Y:BT0:6QX@2KVi/0
W9bL09jNWP2PX:00W9bL09ZJVP2DU9@0WIfM0;:b/P2j^[X0`l?30<O7a`2n_[h0/k>c0:VYZ@2a/K40
]KFe0;6a/@2[Zj/0[jn_0;fm_@36a/H0b<S80<W9b@80b/[:00<0a/K60<O7a`31`L400P30`<004`2o
_kl0_Kfm0;Ng]`2g]kL0];Bd0;Fe]@2f][H0^[Zj0;jn_P2o_kl0`<300;fm_@31`L40`/;20<K6aP35
aLD0`L710<O7a`36a/H00P34a<@01@36a/H0aLG50<G5a@3:b/X0bLW90080bl_;00<0c<c<0<g=c@3:
b/X00P3;bl/02P3<c<`0bl_;0<W9b@3:b/X0bLW90<_;b`39bLT0b/[:0<k>cP3<c<`20=3@d0070=7A
d@3Cdm<0d=3@0=CDe03AdM40c/k>0<C4a00209jNWP0Y09>CT`2HV9P0WIfM0:FUY@2b/[80[Zj^096A
T@2>SXh0TI6A09fMW@2XZ:P0[:b/0:NWY`2KVi/0Rh^;08F5Q@26QXH0Ti>C0:BTY02j^[X0clo?0=_K
f`3Ogml0[Zj^03Lg=`0[:b/0:2PX02DU9@0[:b/0:2PX02/[:`0`<300;Rh^038b<P0c<c<0=SHf030`
<00^;Rh0<c<c0410@00f=SH00P0Z:RX02`0b<S80AdM703De=@0g=cL0>SXj03@d=00g=cL0=3@d02l_
;`0c<c<0=3@d0080@d=300H0ADE5051@D01TI6@0NWYj08j>SP2FUYH209VIV@0509NGU`2CTi<0UYJF
09>CT`2<S8`00P2?Shl01@2IVIT0V9RH09fMW@2OWil0X:2P0080WinO00H0XJ6Q0:2PX02PX:00XJ6Q
0:2PX02OWil209bLW080WIfM00@0VYZJ09jNWP2IVIT0V9RH0P2NWYh02P2MWId0WYjN09jNWP2NWYh0
Y:BT0:2PX02OWil0W9bL09jNWP2MWId209bLW00909nOW`2MWId0WinO09ZJVP2MWId0W9bL09jNWP2M
WId0W9bL0080WIfM00/0V9RH09bLW02LW9`0WinO09^KV`2IVIT0VYZJ09jNWP2KVi/0WIfM09bLW00>
0<SPf0003038h=P2061PH00705iNGP1XJ6P0JFUY05aLG01KFe/0GUiN05aLG00205iNGP80Hf=S01d0
H61P06=SH`1NGUh0HF5Q05aLG01QHF40GemO05]KF`1QHF40IFEU069RHP1YJFT0KVi^079bLP1kNg/0
P82008:2PP2:RXX0T92@09JFUP2JVYX0XJ6Q0:2PX02TY:@0Z:RX0:VYZ@2][Jd0YjNW0:VYZ@030:^[
Z`0d0:b/[02UYJD0Zj^[0:f][@2/[:`0[Jf]0:^[Z`2XZ:P0ZZZZ0:b/[02RXZ80Y:BT09ZJVP2HV9P0
U9BD08n?S`24Q8@0N7Qh06e]K@1WIfL0FUYJ05ADE01BDU80B4Q804a<C01EEED0DE5A05=CD`1KFe/0
GEeM05aLG01QHF40Fe]K06=SH`1TI6@0HF5Q06=SH`1TI6@0Hf=S06ATI01VIVH0H61P069RHP1SHf<0
IFEU05eMG@1PH600I6AT06MWI`1SHf<0H61P06QXJ080GemO00L0HV9R06=SH`1RHV80H61P06ATI01R
HV80Hf=S0080HF5Q00<0IFEU06ATI01VIVH00P1VIVH0401OGel0Fe]K05]KF`1EEED0DU9B05MGE`1j
NWX0dm?C0<k>cP31`L40c<c<0<C4a02^[Zh0][Jf0<;2`P31`L420:ZZZP0h09nOW`2/[:`0WYjN09FE
U@2:RXX0Y:BT0:VYZ@2ATI40QHF508^;R`2DU9@0RHV908f=S@2MWId0PH6107YjNP1eMGD0Ph>307Yj
NP1cLg<0K6a/06UYJ@1_Kfl0Jf][06=SH`1OGel0I6AT07MgM`24Q8@0Ph>307emO@2<S8`0TY:B08j>
SP27QhL0RHV908B4Q028R8P0PX:208J6QP22PX80T92@08b<S027QhL0N7Qh06YZJP1^KVh0MWIf07Mg
M`1jNWX0NGUi08V9R@2JVYX0UiNG092@T02ATI4208b<S00J09BDU02FUYH0UiNG08j>SP25QHD0QXJ6
08b<S02?Shl0UIFE09:BTP1eMGD0Q8B407inOP24Q8@0Rh^;09>CT`2GUiL0VIVI09RHV02IVIT0TI6A
09:BTP2@T900RHV907alO02;Rh/209BDU00409JFUP2KVi/0WIfM0:BTY080W9bL00l0Y:BT0:2PX02H
V9P0TY:B09JFUP2EUID0W9bL0:ZZZP2YZJT0WYjN09NGU`2DU9@0V9RH0:2PX02QXJ400P2=SHd01@2C
Ti<0TY:B08V9R@2KVi/0Y:BT0080Xj>S0P2VYZH0102ZZZX0Z:RX0:JVYP2XZ:P20:ZZZP0^09fMW@2A
TI40R8R809JFUP2KVi/0WinO0:6QX@2SXj<0XJ6Q09nOW`2TY:@0/[:b0:j^[P2RXZ80VYZJ09nOW`2U
YJD0YjNW0:ZZZP2YZJT0ZZZZ0:NWY`2SXj<0X:2P0::RXP2PX:00Xj>S0;2`/02OWil0XJ6Q0:b/[02S
Xj<0XJ6Q0:ZZZP2[Zj/0XZ:R09NGU`2RXZ80ZZZZ0:BTY02MWId0X:2P0:>SX`2LW9`0XJ6Q0:VYZ@80
ZZZZ00@0YJFU0:2PX02MWId0XZ:R0P2TY:@09`2LW9`0UiNG092@T02BTY80X:2P0:j^[P2e]KD0_kno
0<?3``38b<P0_kno0:j^[P2VYZH0Zj^[0;Ng]`2e]KD0];Bd0;Vi^@2o_kl0aLG50<W9b@31`L40aLG5
0<[:bP35aLD0alO70<?3``35aLD0`/;20<?3``30`<00^k^k0;Vi^@2d];@0^[Zj0;jn_P33`l<0_kno
0;jn_P020;no_`060<?3``30`<00`l?30<G5a@36a/H0`/;20P33`l<00`32`/80a/K60<K6aP020<W9
b@070<O7a`3;bl/0b/[:0<[:bP3=cLd0c<c<0<g=c@020<_;b`80b/[:00H0c<c<0<[:bP3<c<`0bl_;
0<c<c03>c/h40<o?c`80dM7A01d0d=3@0<o?c`2e]KD0]KFe09NGU`2HV9P0UiNG09fMW@2WYjL0/[:b
0;6a/@2CTi<0R8R809>CT`2HV9P0YJFU0:ZZZP2/[:`0YZJV09bLW02EUID0Shn?09NGU`2/[:`0bLW9
0=SHf03Ogml0bLW9061PH00202/[:`0C02PX:00V9RH0:RXZ034a<@0h>3P0:BTY03<c<`0b<S80<C4a
030`<00e=CD0:b/[034a<@0[:b/0;Bd]030`<00e=CD0>CTi034a<@0203@d=00E03/k>`0i>CT0<C4a
02`/;00b<S80<30`03De=@17AdL0>c/k04I6AP1CDe<0KFe]0861P@2?Shl0VIVI09^KV`2IVIT0Vi^K
09FEU@2BTY80SHf=0080T92@00T0UYJF09ZJVP2PX:00XZ:R09jNWP2LW9`0XZ:R09nOW`2RXZ800`2O
Wil01@2QXJ40VYZJ09ZJVP2OWil0WYjN00@0Vi^K00/0W9bL09fMW@2KVi/0XJ6Q09bLW02NWYh0W9bL
09jNWP2OWil0Vi^K09bLW00209fMW@0609jNWP2PX:00XJ6Q09^KV`2OWil0VIVI0P2MWId209jNWP0=
09bLW02MWId0WIfM09^KV`2MWId0Vi^K09fMW@2NWYh0W9bL09jNWP2PX:00WinO09^KV`0>0<SPf000
3038h=P305iNGP06069RHP1SHf<0GUiN05eMG@1PH600GemO0P1NGUh00`1OGel0FUYJ06IVIP0205iN
GP0705aLG01JFUX0Fe]K061PH01LG5`0GUiN065QH@0206ATI00@06MWI`1^KVh0MGEe08>3P`27QhL0
SHf=08n?S`2IVIT0W9bL0:6QX@2RXZ80YZJV0:FUY@2YZJT0[:b/0:^[Z`<0ZZZZ00@0[Zj^0:f][@2W
YjL0ZZZZ0`2/[:`04@2YZJT0Zj^[0:ZZZP2[Zj/0ZJVY09jNWP2JVYX0Ti>C092@T02:RXX0PH6107Ui
N@1/K6`0Hf=S065QH@1HF5P0De=C0080CDe=00H0EEEE05=CD`1EEED0G5aL05eMG@1IFET205eMG@0D
05iNGP1PH600J6QX069RHP1SHf<0GEeM06=SH`1OGel0Hf=S05iNGP1SHf<0GemO06EUI@1NGUh0HF5Q
06ATI01QHF40I6AT06IVIP1TI6@2065QH@0>06ATI01UIFD0IfMW06QXJ01PH600Hf=S06MWI`1UIFD0
Hf=S06IVIP1UIFD0I6AT061PH01OGel205eMG@0=05YJFP1DE5@0De=C07emO@3?cll0eMGE0<71`@2o
_kl0`L710;fm_@2c/k<0/K6a0;Zj^P020;Vi^@0C0:6QX@2KVi/0U9BD09fMW@2IVIT0TY:B0:BTY02D
U9@0PH6107UiN@2DU9@0Shn?08f=S@27QhL0Ph>307alO01cLg<0MWIf07AdM00206m_K`0=06=SH`1X
J6P0IfMW06MWI`1TI6@0GemO065QH@1nOWh0Rh^;08Z:RP2DU9@0TI6A08j>SP0208^;R`0408b<S028
R8P0QHF508:2PP80QHF50140Rh^;08N7Q`2<S8`0Ph>306a/K01ZJVX0Ng]k08:2PP1hN7P0Ogmo08n?
S`2EUID0Ti>C09FEU@2:RXX0QXJ609FEU@0209VIV@0G08n?S`25QHD0QXJ608Z:RP2ATI40S8b<09BD
U02ATI40Rh^;07IfMP20P800QhN709:BTP2ATI40U9BD09jNWP2FUYH0TY:B08j>SP2HV9P0TI6A07mo
O`23Ph<00P26QXH00`2EUID0X:2P09nOW`020::RXP030:JVYP2KVi/0V9RH0080VYZJ00D0WYjN09ZJ
VP2MWId0Xj>S0::RXP0209JFUP0C09VIV@2YZJT0WYjN09nOW`2LW9`0WIfM09nOW`2LW9`0UIFE09ZJ
VP2SXj<0XZ:R0:2PX02WYjL0YZJV0:FUY@2OWil0YjNW0:JVYP020:ZZZP060:VYZ@2KVi/0Shn?09BD
U02;Rh/0TI6A0P2FUYH02@2QXJ40Z:RX0:b/[02d];@0YjNW09nOW`2RXZ80YZJV0:ZZZP020:f][@80
ZJVY01T0Y:BT09nOW`2MWId0YJFU0:ZZZP2a/K40YZJV0:BTY02b/[80[Jf]09nOW`2XZ:P0[Jf]0:BT
Y02MWId0XZ:R0:VYZ@2WYjL0XJ6Q09fMW@2LW9`0Xj>S0:6QX@2][Jd0[Zj^0080ZJVY01X0YjNW0::R
XP2LW9`0W9bL0:j^[P2VYZH0Y:BT09RHV02@T900WYjN09^KV`2OWil0WIfM0:b/[02a/K40`<300<W9
b@33`l<0]KFe0:f][@2[Zj/0[jn_0;^k^`2l_;`0Zj^[0;Jf]P<0`l?300<0b<S80<g=c@3>c/h00P3:
b/X02P38b<P0alO70<G5a@34a<@0aLG50<;2`P2o_kl0`<300;no_`34a<@20;bl_00@0;no_`31`L40
`/;20<71`@33`l<0aLG50<C4a033`l<0aLG50<K6aP35aLD0alO70<G5a@38b<P0a/K60<S8b0<0b/[:
00d0cLg=0<_;b`3<c<`0alO70<[:bP39bLT0bl_;0<c<c03;bl/0c<c<0<[:bP3>c/h0b/[:0080d=3@
0P3Bd]800`3AdM40d];B0<o?c`020<g=c@0=0:BTY02LW9`0UiNG09NGU`2NWYh0Z:RX0;Fe]@2`/;00
W9bL08^;R`2@T900UYJF0:BTY0020:VYZ@0D0:ZZZP2XZ:P0UiNG09RHV02YZJT0`<300=7Ad@3Jf]X0
emOG09>CT`0_;bl09bLW02TY:@0^;Rh0<C4a02`/;00d=3@0;2`/034a<@0`<30202l_;`0603Ph>00d
=3@0;bl_02/[:`0m?Cd0@D510P0Z:RX01P0[:b/0;bl_038b<P0g=cL0<S8b02l_;`80=CDe0140<30`
038b<P0l?3`0@T9204I6AP1;Bd/0H61P07UiN@24Q8@0UIFE09RHV02MWId0VYZJ09VIV@2?Shl0TI6A
092@T00209BDU080UiNG00X0W9bL09fMW@2NWYh0WYjN09fMW@2OWil0XZ:R0:2PX02OWil0WIfM0P2N
WYh02P2OWil0W9bL09nOW`2MWId0W9bL0:2PX02JVYX0WIfM09ZJVP2NWYh209bLW080WYjN00T0WinO
09bLW02QXJ40WinO09VIV@2NWYh0X:2P09jNWP2MWId00P2LW9`04@2NWYh0WinO09nOW`2MWId0WYjN
09^KV`2OWil0Vi^K09ZJVP2LW9`0WYjN09VIV@2MWId0WYjN09fMW@2JVYX0WinO00h0b>3H000<0<SP
f080HF5Q00<0H61P06EUI@1TI6@00P1LG5`00`1MGEd0G5aL065QH@02069RHP0:065QH@1LG5`0GUiN
05aLG01PH600GEeM061PH01RHV80IVIV05iNGP80HF5Q0180H61P06i^KP1dM7@0MGEe07moO`28R8P0
S8b<092@T02GUiL0VYZJ09jNWP2PX:00Y:BT0:NWY`2YZJT0Zj^[0:n_[`2][Jd20:b/[0050:j^[P2/
[:`0ZZZZ0:ZZZP2[Zj/00P2ZZZX08@2][Jd0ZZZZ0:b/[02ZZZX0XZ:R09nOW`2IVIT0Ti>C096AT@29
RHT0QhN707IfMP1/K6`0IVIV05aLG01HF5P0D51@04a<C01>CTh0DE5A05ADE01CDe<0EEEE05IFEP1O
Gel0GUiN05eMG@1SHf<0IFEU05aLG01RHV80Hf=S06ATI00206=SH`0506ATI01RHV80IFEU05mOG`1R
HV800P1PH6001`1VIVH0IFEU05mOG`1PH600HV9R065QH@1SHf<00P1WIfL06`1[Jf/0JVYZ06=SH`1V
IVH0J6QX06EUI@1TI6@0JVYZ05mOG`1UIFD0HF5Q05mOG`1NGUh0G5aL05UIF@1LG5`0EUIF07AdM03B
d]80fm_K0<G5a@2e]KD0/;2`0;fm_@2f][H0X:2P0:ZZZP020;Bd]0050:b/[02BTY80R8R80:VYZ@2P
X:000P2<S8`06@2BTY80R8R807]kN`1kNg/0SXj>092@T01lO7`0M7Ad07MgM`1aLG40N7Qh06e]K@1[
Jf/0KVi^06IVIP1YJFT0IfMW079bLP1^KVh0I6AT05eMG@1dM7@0PH6108F5Q@2?Shl00P2ATI4208j>
SP0[08^;R`27QhL0Rh^;08R8R026QXH0OWin08B4Q01nOWh0Ti>C09bLW01oOgl0HF5Q07EeM@23Ph<0
PX:207]kN`23Ph<0SXj>08f=S@2>SXh0TI6A08f=S@2?Shl0Ti>C09ZJVP2<S8`0QHF508R8R02:RXX0
SHf=08V9R@2;Rh/0VYZJ08j>SP27QhL0TI6A07emO@23Ph<0SHf=09BDU02EUID0U9BD096AT@0209ZJ
VP0309FEU@2?Shl0SXj>0080QhN701<0S8b<09^KV`2OWil0Xj>S0:VYZ@2PX:00Vi^K09VIV@2JVYX0
Y:BT0:6QX@2PX:00WYjN09VIV@2HV9P0UiNG0:6QX@2VYZH0YjNW0080WYjN00T0[Zj^0:NWY`2XZ:P0
X:2P09NGU`2LW9`0X:2P09jNWP2LW9`00P2PX:00102UYJD0XJ6Q0:BTY02XZ:P20:ZZZP0?0:^[Z`2N
WYh0W9bL0::RXP2TY:@0RXZ:08B4Q02>SXh0VIVI0:ZZZP2^[Zh0YjNW0:6QX@2XZ:P0[:b/0080YZJV
01D0XZ:R0:VYZ@2ZZZX0Xj>S09nOW`2LW9`0Xj>S0:j^[P2`/;00Zj^[0::RXP2^[Zh0[jn_0:VYZ@2V
YZH0Xj>S0:JVYP2PX:00ZZZZ0:j^[P2XZ:P00P2PX:001P2RXZ80XJ6Q0:JVYP2[Zj/0[Zj^0:b/[080
Zj^[01L0ZJVY0:BTY02QXJ40YjNW0:b/[02[Zj/0XJ6Q09ZJVP2HV9P0Y:BT09RHV02EUID0S8b<09RH
V02TY:@0/;2`0<30`037alL0aLG50;no_`2e]KD0YJFU0:^[Z`040;Rh^0040<30`034a<@0a/K60<[:
bP80cLg=00H0b/[:0<g=c@38b<P0bLW90<O7a`34a<@20<G5a@80`/;200H0`<300<?3``2n_[h0_kno
0<30`031`L420<;2`P070<?3``32`/80`L710<K6aP33`l<0`/;20<?3``020<O7a`050<S8b03:b/X0
bLW90<g=c@36a/H00P39bLT00`3:b/X0alO70<[:bP020<[:bP0=0<g=c@39bLT0b<S80<_;b`3=cLd0
c<c<0<o?c`3=cLd0d=3@0=?Cd`3@d=00d];B0<o?c`020=?Cd`160<30`02MWId0VIVI09VIV@2NWYh0
YZJV0;6a/@2g]kL0];Bd09ZJVP27QhL0QHF509BDU02IVIT0Xj>S0:NWY`2YZJT0YjNW0:JVYP2][Jd0
^KVi0<G5a@3Fe]H0g=cL0;Jf]P0n?Sh09RHV02DU9@0^;Rh09RHV02/[:`0Z:RX0<30`02TY:@0b<S80
<30`03De=@0^;Rh0<C4a03@d=00f=SH0ATI602XZ:P0W9bL0:b/[02h^;P0[:b/0;Rh^03<c<`0f=SH0
=CDe02l_;`0];Bd0;2`/03Hf=P0e=CD0A4A404M7A`16ATH0HF5Q071`L020P800Rh^;09JFUP2OWil0
VIVI09JFUP2EUID0U9BD092@T080TY:B00L0TI6A09JFUP2LW9`0Vi^K09nOW`2QXJ40WYjN0080XZ:R
00<0WinO0::RXP2WYjL00P2OWil02@2PX:00WYjN09VIV@2NWYh0WIfM09^KV`2LW9`0Vi^K09ZJVP02
09bLW00A09jNWP2PX:00VYZJ09jNWP2QXJ40WIfM09bLW02PX:00WYjN0:6QX@2LW9`0Vi^K09fMW@2L
W9`0VIVI0:2PX02OWil00P2MWId02P2PX:00W9bL09bLW02MWId0Vi^K09jNWP2GUiL0WIfM09ZJVP2K
Vi/209bLW0h0b>3H000<0<SPf080H61P02P0KFe]06YZJP1QHF40GemO06MWI`1OGel0GEeM05mOG`1R
HV80IFEU061PH01RHV80GEeM05]KF`1OGel0GEeM069RHP1OGel0GUiN05]KF`1QHF40IFEU06=SH`1[
Jf/0LW9b07IfMP1oOgl0Q8B408Z:RP2?Shl0UiNG09fMW@2QXJ40X:2P0:>SX`2VYZH0YjNW0:RXZ02_
[jl0[Jf]0P2ZZZX02@2^[Zh0[:b/0:b/[02][Jd0[:b/0:n_[`2YZJT0[Jf]0:^[Z`020:VYZ@0<0:BT
Y02PX:00VYZJ09NGU`2CTi<0S8b<08:2PP1fMWH0KFe]06IVIP1JFUX0EEEE0P1>CTh08@1:BTX0DE5A
05ADE01DE5@0FEUI05aLG01PH600HV9R05eMG@1PH600Hf=S061PH01UIFD0Hf=S065QH@1TI6@0GUiN
065QH@1OGel0Hf=S06ATI01PH600GEeM05iNGP1PH600GemO06ATI01RHV80HF5Q069RHP1PH600HV9R
06IVIP0206ATI00I06=SH`1ZJVX0JFUY06EUI@1MGEd0HV9R05mOG`1VIVH0H61P06ATI01LG5`0FUYJ
05QHF01EEED0DE5A06UYJ@37alL0g=cL0<c<c031`L40ZZZZ0;Zj^P2i^KT0/k>c0::RXP020:BTY003
0:VYZ@2NWYh0Shn?0080UiNG0P2DU9@02@2=SHd0TY:B08N7Q`1iNGT0QXJ609VIV@23Ph<0Lg=c06YZ
JP0207AdM00Z06ATI01QHF40K6a/06UYJ@1]KFd0K6a/06e]K@1_Kfl0KFe]06MWI`1]KFd0IfMW07Ad
M026QXH0RXZ:092@T02=SHd0Shn?08R8R02:RXX0QhN708b<S024Q8@0NGUi07YjNP23Ph<0S8b<092@
T02>SXh0OGem06e]K@1gMgL0PH6107emO@1fMWH0O7al08Z:RP2<S8`0Shn?09BDU02?Shl0U9BD0`2<
S8`04@29RHT0TI6A09:BTP2:RXX0QhN7092@T02?Shl0Ti>C09NGU`29RHT0MWIf08f=S@29RHT0PH61
08f=S@2HV9P0Xj>S0080Vi^K0P2IVIT209FEU@0O08Z:RP2>SXh0W9bL09nOW`2ATI40VYZJ09RHV02K
Vi/0Xj>S0:JVYP2UYJD0WYjN09ZJVP2@T900TY:B09jNWP2XZ:P0X:2P09fMW@2NWYh0/k>c0;Fe]@2b
/[80X:2P09jNWP2IVIT0WYjN09bLW02NWYh0W9bL0:2PX0020:BTY0080:FUY@2[Zj/0YJFU0:VYZ@2U
YJD0WinO09fMW@2QXJ420:n_[`0K0:FUY@27QhL0QhN709:BTP2IVIT0XJ6Q0:BTY02c/k<0[Zj^0:JV
YP2TY:@0WinO0:6QX@2XZ:P0YjNW0:6QX@2JVYX0ZZZZ0:VYZ@2][Jd0Zj^[0:2PX02ZZZX0/[:b0:b/
[02SXj<0Zj^[0080XJ6Q00H0YjNW0;2`/02[Zj/0YJFU0:2PX02YZJT20:ZZZP040:RXZ02WYjL0/K6a
0:f][@80YjNW01`0Xj>S0:JVYP2XZ:P0[Jf]0:b/[02VYZH0XZ:R09VIV@2XZ:P0Xj>S09ZJVP2OWil0
V9RH09fMW@2QXJ40XZ:R0:n_[`2j^[X0`L710<[:bP36a/H0]kNg0:f][@2ZZZX0Z:RX0;6a/@2k^k/0
^;Rh0P2k^k/04`35aLD0alO70<S8b039bLT0c<c<0<k>cP3?cll0c/k>0<W9b@3:b/X0b<S80<G5a@34
a<@0`/;20<30`031`L40_Kfm0;jn_P34a<@00P32`/801031`L40`/;20<30`032`/820<30`0050<71
`@37alL0a<C40<K6aP38b<P00P39bLT20<O7a`080<_;b`39bLT0bLW90<O7a`38b<P0bl_;0<W9b@3:
b/X30<c<c0040<_;b`3<c<`0cLg=0<o?c`80d=3@0P3Cdm<20=3@d00C0<o?c`2YZJT0VYZJ09^KV`2M
WId0XZ:R0:VYZ@2c/k<0^[Zj0;Rh^02DU9@0QHF508V9R@2>SXh0VYZJ09VIV@2YZJT0[:b/0:^[Z`02
0:j^[P0=0;Zj^P3=cLd0fm_K0<k>cP1]KFd09RHV02LW9`0V9RH0:b/[02PX:00_;bl0:BTY02XZ:P02
030`<00Z038b<P0_;bl0<c<c03De=@0a<C40<30`02HV9P0];Bd09RHV02XZ:P0^;Rh0;bl_03De=@0i
>CT0=3@d030`<00^;Rh0;Bd]034a<@0d=3@0>3Ph04A4A01@D500Cdm?069RHP1kNg/0Ph>3096AT@2J
VYX0WinO09RHV02DU9@0TY:B096AT@2>SXh0T92@09FEU@2HV9P0VIVI09^KV`2OWil0WYjN0P2OWil0
102NWYh0Xj>S0::RXP2RXZ8209jNWP80WinO00P0X:2P09nOW`2KVi/0Vi^K09bLW02OWil0W9bL09nO
W`80WYjN00T0Vi^K0:6QX@2OWil0X:2P09jNWP2QXJ40X:2P0:6QX@2MWId00P2LW9`01`2MWId0Vi^K
09fMW@2NWYh0WIfM09^KV`2MWId00P2OWil209^KV`0309jNWP2MWId0V9RH0080WinO0P2MWId00`2R
XZ80b>3H0<SPf00<0<SPf0003038h=P205eMG@0406ATI01XJ6P0H61P05UIF@80GemO00<0HF5Q061P
H01OGel00P1RHV82061PH004065QH@1PH600HF5Q05mOG`80H61P0100J6QX05mOG`1PH600IFEU06YZ
JP1cLg<0NGUi0861P@24Q8@0Shn?096AT@2DU9@0Vi^K09nOW`2QXJ40Xj>S0`2XZ:P0102ZZZX0[Zj^
0:b/[02/[:`20:^[Z`060:f][@2YZJT0[Zj^0:b/[02][Jd0[Zj^0P2ZZZX0502XZ:P0Y:BT0:6QX@2M
WId0UYJF09BDU02;Rh/0PH6107EeM@1]KFd0HV9R05iNGP1ADE40BDU904i>CP1@D500CTi>04e=C@1C
De<0EUIF0P1NGUh04`1MGEd0H61P05iNGP1TI6@0H61P05mOG`1QHF40I6AT06QXJ01TI6@0J6QX06AT
I01UIFD0IVIV069RHP1NGUh0GEeM061PH01RHV800P1SHf<0201OGel0IVIV06ATI01VIVH0GemO069R
HP1UIFD0Hf=S0P1XJ6P01`1TI6@0IVIV06][J`1RHV80GemO065QH@1SHf<00P1OGel03@1JFUX0FEUI
05IFEP1RHV80]KFe0>7Qh@3;bl/0b<S80;jn_P2TY:@0][Jf0;Vi^@2ZZZX00P2EUID0402XZ:P0XZ:R
0:6QX@2>SXh0QhN709VIV@2NWYh0SHf=08>3P`2ATI40T92@0861P@2GUiL0QXJ607YjNP1YJFT206][
J`1006MWI`1RHV80I6AT06a/K01[Jf/0KVi^06a/K01WIfL0LW9b06a/K01WIfL0GUiN065QH@1^KVh0
Rh^;09>CT`2@T900SXj>08n?S`2;Rh/0SHf=08Z:RP28R8P0O7al08>3P`2=SHd0Ph>308b<S02DU9@0
UYJF07IfMP1ZJVX0MWIf07=cL`1dM7@0MWIf08:2PP2=SHd0TI6A09NGU`2?Shl0SHf=08Z:RP2ATI40
Ti>C09:BTP2EUID0UiNG08>3P`26QXH0TI6A09NGU`2>SXh0RHV908b<S027QhL0X:2P08b<S01gMgL0
TY:B09bLW02IVIT0WIfM09ZJVP80WinO0P2LW9`02`2@T900QXJ608Z:RP2=SHd0TI6A09NGU`2[Zj/0
YjNW0:RXZ02VYZH0X:2P0080UIFE0P2HV9P0202RXZ80VYZJ09fMW@2VYZH0[Jf]0;6a/@2e]KD0ZZZZ
0P2RXZ80>`2QXJ40Z:RX0::RXP2PX:00WYjN09fMW@2QXJ40YJFU0:NWY`2OWil0Y:BT0::RXP2KVi/0
WYjN0:6QX@2ZZZX0/;2`0:^[Z`2VYZH0WinO09JFUP2IVIT0UYJF096AT@2WYjL0[:b/0:6QX@2RXZ80
X:2P0:BTY02OWil0YZJV0:VYZ@2UYJD0YjNW0:RXZ02[Zj/0[:b/0:JVYP2UYJD0/k>c0;6a/@2YZJT0
Z:RX0:NWY`2QXJ40Z:RX0:n_[`2ZZZX0[:b/0:BTY02^[Zh0][Jf0;2`/02^[Zh0[jn_0:NWY`2^[Zh0
ZZZZ00<0Z:RX02D0YZJV0;Jf]P2`/;00[Jf]0:BTY02OWil0Xj>S0;:b/P2TY:@0WinO0:^[Z`2WYjL0
YZJV0::RXP2MWId0UYJF0:^[Z`2_[jl0_[jn0<O7a`3=cLd0_kno0;2`/02[Zj/0XZ:R0:NWY`2h^;P0
_;bl0;Jf]P2k^k/0`l?30<S8b035aLD0bLW90=3@d03AdM40clo?0080cLg=0P3;bl/01P39bLT0alO7
0<;2`P31`L40`<300<71`@80`<3000@0`/;20<?3``33`l<0`/;20P30`<000`31`L40_kno0<C4a002
0<C4a0060<S8b035aLD0alO70<W9b@3:b/X0bl_;0P39bLT01P38b<P0alO70<K6aP3;bl/0bLW90<_;
b`80b<S800<0bLW90<c<c03<c<`00P3?cll20=3@d00F0<k>cP3=cLd0cLg=0=3@d031`L40WinO09VI
V@2HV9P0XZ:R0:BTY02ZZZX0[jn_0;Fe]@2k^k/0UYJF07inOP25QHD0RHV908j>SP2JVYX0Z:RX0:j^
[P80/k>c00H0][Jf0<O7a`3EeMD0e]KF09^KV`0^;Rh202@T900602LW9`0Y:BT09bLW02HV9P0Z:RX0
;Rh^0P0b<S807`0e=CD0<c<c02l_;`0g=cL0<30`03De=@0^;Rh0:BTY02`/;00a<C40<30`03/k>`0a
<C40;bl_038b<P0c<c<0;2`/02h^;P0`<300?3`l04=3@`16ATH0BDU905YJFP1]KFd0O7al08b<S02E
UID0W9bL09fMW@2GUiL00P2DU9@03P2?Shl0TI6A09BDU02CTi<0V9RH09jNWP2QXJ40X:2P09nOW`2M
WId0XZ:R0:>SX`2QXJ40WYjN0P2PX:001`2RXZ80XJ6Q0:>SX`2QXJ40WYjN09nOW`2PX:000P2KVi/0
102NWYh0XJ6Q09fMW@2OWil209jNWP0709nOW`2MWId0X:2P0:6QX@2OWil0XJ6Q0:2PX00309jNWP80
WIfM00L0W9bL09^KV`2IVIT0W9bL09jNWP2OWil0W9bL00<0VYZJ00D0X:2P09fMW@2OWil0Vi^K09fM
W@0>0<SPf0003038h=P3069RHP0505iNGP1KFe/0Fe]K061PH01MGEd00P1OGel0301HF5P0HF5Q05aL
G01NGUh0HF5Q05YJFP1HF5P0GemO069RHP1NGUh0G5aL05mOG`80HV9R00/0Hf=S06EUI@1_Kfl0NGUi
0861P@28R8P0RXZ:09:BTP2EUID0UYJF09jNWP020::RXP050:b/[02YZJT0Z:RX0:ZZZP2/[:`00P2Z
ZZX01@2][Jd0Zj^[0:j^[P2][Jd0Z:RX0080ZZZZ0240Zj^[0:RXZ02YZJT0YZJV0:BTY02PX:00VYZJ
09BDU02ATI40QHF507inOP1gMgL0JVYZ06MWI`1KFe/0FEUI04e=C@1;Bd/0CDe=059BDP1>CTh0DE5A
05=CD`1HF5P0GUiN05]KF`1NGUh0GemO06ATI01OGel0Hf=S061PH01TI6@00P1QHF402`1VIVH0HV9R
06ATI01RHV80HF5Q05mOG`1ZJVX0H61P05eMG@1RHV80IFEU0080Hf=S00<0HV9R061PH01RHV800P1P
H60206IVIP0G06MWI`1YJFT0IVIV06IVIP1XJ6P0IVIV061PH01TI6@0HF5Q061PH01MGEd0EEEE05QH
F01UIFD0Zj^[0=_Kf`3:b/X0`l?30<;2`P2i^KT0ZJVY0:f][@2`/;000P2][Jd01@2FUYH0TY:B0:f]
[@2/[:`0Shn?0080TY:B01<0Shn?07YjNP2>SXh0Vi^K08n?S`27QhL0OGem07IfMP1]KFd0Hf=S06a/
K01WIfL0I6AT05]KF`1MGEd0GemO075aL@1WIfL0J6QX0080JVYZ01@0K6a/06][J`1LG5`0FUYJ07Ee
M@2<S8`0Ti>C09:BTP2>SXh0SHf=08Z:RP2>SXh0R8R808:2PP2;Rh/0RHV90861P@28R8P0T92@08j>
SP80S8b<01`0NWYj06=SH`1gMgL0OWin07]kN`24Q8@0Ti>C08n?S`2<S8`0Rh^;08Z:RP2@T900TY:B
09^KV`2IVIT0TY:B08J6QP27QhL0Ti>C08n?S`2:RXX0R8R8092@T02LW9`0WYjN09VIV@1jNWX0V9RH
0P2DU9@0102GUiL0XZ:R0::RXP2MWId209bLW00:09FEU@2ATI40Q8B408J6QP2ATI40XZ:R0:VYZ@2^
[Zh0YjNW09fMW@80VYZJ00X0WinO0:JVYP2QXJ40W9bL09ZJVP2UYJD0[Zj^0:ZZZP2][Jd0/[:b0P2R
XZ800`2OWil0ZZZZ0:b/[0020:FUY@80YZJV00`0Y:BT0:6QX@2QXJ40XJ6Q09nOW`2DU9@0VYZJ0:f]
[@2^[Zh0/[:b0:ZZZP2QXJ420:>SX`090:FUY@2YZJT0YZJV09fMW@2KVi/0WIfM08n?S`2PX:00Z:RX
0080ZZZZ01`0[:b/0:RXZ02YZJT0[jn_0:j^[P2YZJT0YjNW0:JVYP2XZ:P0/k>c0:b/[02c/k<0[jn_
0:>SX`2OWil0/;2`0:b/[02VYZH0ZJVY0:j^[P2i^KT0^;Rh0;Fe]@2c/k<0[jn_0:f][@2ZZZX0ZJVY
0P2XZ:P09@2YZJT0[:b/0;2`/02][Jd0[:b/0:2PX02SXj<0[Zj^0:^[Z`2WYjL0ZZZZ0;Fe]@2][Jd0
ZJVY0:JVYP2OWil0V9RH0:6QX@2DU9@0Z:RX0;Ng]`33`l<0alO70<[:bP37alL0/k>c0:BTY02a/K40
];Bd0;no_`30`<00^[Zj0;Fe]@30`<00`l?30<C4a03=cLd00P3Bd]800`3>c/h0c<c<0<_;b`030<S8
b080a/K600H0`l?30;Vi^@2g]kL0_Kfm0<71`@32`/820<?3``040;no_`33`l<0_;bl0<;2`P80a<C4
0P35aLD01`36a/H0b/[:0<W9b@39bLT0b<S80<_;b`37alL00P38b<P30<W9b@0:0<c<c038b<P0alO7
0<[:bP3<c<`0clo?0<k>cP3?cll0cLg=0=3@d080c<c<0P3@d=00:02a/K40V9RH09>CT`2JVYX0XZ:R
0:FUY@2TY:@0/;2`0;Vi^@2j^[X0UYJF07emO@20P800Q8B4092@T02QXJ40ZJVY0:n_[`2b/[80^;Rh
0<G5a@3AdM40fm_K0;Rh^00m?Cd09RHV02XZ:P0V9RH0:BTY02HV9P0/;2`0:BTY02/[:`0d=3@0<C4a
03Ph>017AdL0>3Ph03Hf=P0`<30202h^;P0:02HV9P0[:b/0:b/[02h^;P0_;bl0=cLg03De=@0a<C40
=CDe02d];@80;2`/01<0=CDe03lo?`0o?cl0ATI605ADE01QHF40LG5a08>3P`2FUYH0UIFE09VIV@2L
W9`0U9BD09NGU`2EUID0Ti>C096AT@2CTi<0UYJF0080WIfM00D0WinO09jNWP2PX:00WinO0:>SX`02
0:6QX@80XZ:R00L0WinO0:FUY@2RXZ80WinO09VIV@2OWil0XJ6Q0080WYjN00l0WIfM09jNWP2MWId0
WIfM0:6QX@2PX:00WIfM09nOW`2QXJ40XZ:R0:6QX@2IVIT0WYjN09fMW@2JVYX00P2LW9`01P2JVYX0
Vi^K09bLW02KVi/0Y:BT09nOW`80X:2P00P0Vi^K0:2PX02LW9`0VIVI09^KV`2QXJ40VYZJ0:2PX0h0
b>3H000<0<SPf080HF5Q00D0GEeM06ATI01RHV80GEeM065QH@0205aLG00P05mOG`1QHF40G5aL05]K
F`1MGEd0HF5Q061PH01QHF40I6AT05mOG`1MGEd0HV9R06EUI@1QHF40IVIV065QH@1XJ6P0L71`07If
MP1oOgl0QHF508j>SP2EUID0VIVI09^KV`2OWil0X:2P0:BTY02XZ:P0ZZZZ0:^[Z`2][Jd30:VYZ@0:
0:b/[02YZJT0ZJVY0:ZZZP2YZJT0[:b/0:NWY`2ZZZX0[:b/0:VYZ@80Y:BT00d0WIfM09VIV@2GUiL0
T92@08N7Q`1oOgl0MGEe06a/K01TI6@0F5QH05MGE`1;Bd/0C4a<0080CTi>0100C4a<05EEE@1IFET0
Fe]K05iNGP1PH600G5aL05]KF`1TI6@0H61P05mOG`1RHV80KFe]061PH01UIFD0I6AT0P1SHf<04`1O
Gel0HV9R06=SH`1SHf<0HV9R06=SH`1QHF40IFEU065QH@1SHf<0GUiN069RHP1QHF40I6AT06=SH`1T
I6@0IFEU06UYJ@1RHV800P1TI6@04`1ZJVX0JFUY065QH@1TI6@0H61P06ATI01OGel0F5QH05IFEP1P
H600YZJV0=kNgP3?cll0^KVi0;Zj^P2n_[h0^;Rh09fMW@2d];@00P2^[Zh09P2TY:@0SHf=0;:b/P2e
]KD0YjNW08V9R@2=SHd0V9RH08R8R024Q8@0Shn?08j>SP2=SHd0OWin07QhN01`L700Jf][06QXJ01T
I6@0JFUY065QH@1MGEd0E5AD05iNGP1YJFT0Lg=c071`L01ZJVX0Kfm_075aL@1ZJVX0GemO06ATI01g
MgL0S8b<092@T02ATI40SXj>0`26QXH02`2<S8`0Rh^;08>3P`26QXH0RHV908J6QP25QHD0TY:B09^K
V`2=SHd0KVi^0080MWIf00<0LG5a07UiN@26QXH00P28R8P06@2:RXX0SXj>09>CT`2IVIT0Vi^K09NG
U`2BTY80U9BD09:BTP2?Shl0QXJ608>3P`2CTi<0UiNG09RHV02FUYH0Vi^K096AT@2LW9`0SHf=08Z:
RP2BTY80XJ6Q09bLW02PX:000P2KVi/06@2IVIT0UiNG08j>SP26QXH0R8R809jNWP2/[:`0Xj>S09FE
U@2GUiL0XZ:R0:NWY`2[Zj/0YZJV0:6QX@2VYZH0Y:BT0:NWY`2[Zj/0[jn_0:NWY`2XZ:P0YZJV0:6Q
X@2XZ:P00P2YZJT04`2XZ:P0YJFU0:b/[02][Jd0YJFU0:>SX`2PX:00VYZJ09^KV`2JVYX0XJ6Q0;Rh
^02`/;00YjNW09jNWP2PX:00YJFU0:JVYP2YZJT00P2/[:`06`2][Jd0XJ6Q09jNWP2<S8`0VIVI09nO
W`2PX:00YjNW0:FUY@2OWil0YJFU0:b/[02UYJD0Y:BT0:b/[02XZ:P0/k>c0;2`/02YZJT0/k>c0:n_
[`2OWil0YZJV0;>c/`2VYZH0Xj>S0;6a/@020;Vi^@070;Zj^P2d];@0[Jf]0;2`/02_[jl0YJFU0:JV
YP020:ZZZP0?0:n_[`2[Zj/0[jn_0;2`/02^[Zh0Y:BT0:ZZZP2^[Zh0Z:RX0:2PX02_[jl0][Jf0;6a
/@2][Jd0[:b/0080XJ6Q00l0W9bL092@T02IVIT0WIfM0:ZZZP2j^[X0`/;20<o?c`39bLT0^KVi0;Jf
]P2][Jd0/;2`0;Bd]02m_Kd00P2e]KD01@2o_kl0aLG50<O7a`37alL0c/k>0080c<c<00l0c/k>0<_;
b`3;bl/0b<S80<W9b@3;bl/0alO70<G5a@2m_Kd0^[Zj0;jn_P33`l<0`L710<G5a@2o_kl00P2n_[h2
0<71`@050<K6aP37alL0a/K60<K6aP37alL01039bLT04038b<P0c<c<0<S8b03:b/X0b<S80<W9b@3>
c/h0bLW90<O7a`3:b/X0c<c<0=3@d03?cll0c/k>0<c<c03@d=020<k>cP0>0<g=c@3AdM40alO70:BT
Y02JVYX0WYjN09RHV02KVi/0YJFU0:^[Z`2d];@0^[Zj0;jn_P2HV9P207alO00;08^;R`2FUYH0XJ6Q
0:j^[P2g]kL0^[Zj0<O7a`3<c<`0f=SH0<S8b01HF5P00P0U9BD00`0X:2P09BDU02HV9P0202TY:@0b
02XZ:P0d=3@0<30`030`<019BDT0@41003/k>`0f=SH0;Bd]02`/;00Z:RX09bLW02TY:@0c<c<0;Bd]
038b<P0f=SH0<c<c02l_;`0/;2`0;bl_03<c<`0b<S80>3Ph0492@P1:BTX0D51@05]KF`1/K6`0O7al
08R8R02?Shl0UiNG09VIV@2GUiL0TY:B09JFUP2CTi<0Shn?09FEU@2>SXh0U9BD09ZJVP2OWil0XZ:R
09nOW`2SXj<0WinO0:BTY02QXJ420:2PX0030:6QX@2OWil0WinO0080XJ6Q00d0W9bL0::RXP2PX:00
WIfM09jNWP2LW9`0WinO09fMW@2OWil0XJ6Q09bLW02OWil0X:2P0080WinO0P2LW9`04P2JVYX0W9bL
09^KV`2PX:00WYjN09^KV`2MWId0WinO0:6QX@2MWId0Vi^K0:2PX02MWId0X:2P09bLW02GUiL0Vi^K
09fMW@80W9bL3P38h=P000`0b>3H0P1UIFD03@1SHf<0IFEU061PH01QHF40GUiN06YZJP1KFe/0GUiN
06=SH`1OGel0I6AT061PH01QHF400P1NGUh05`1PH600I6AT061PH01PH600IFEU06QXJ01PH600HV9R
06ATI01[Jf/0MWIf07inOP25QHD0SHf=09>CT`2LW9`0WYjN09fMW@2SXj<0YJFU0:NWY`2ZZZX0[Zj^
0080Zj^[0P2ZZZX0202^[Zh0Zj^[0:f][@2ZZZX0[:b/0:f][@2VYZH0[Jf]0P2WYjL02`2SXj<0YJFU
0::RXP2IVIT0Ti>C092@T023Ph<0PX:207EeM@1]KFd0HF5Q0080FEUI00X0CTi>055AD@1?Cdl0Cdm?
04a<C01@D500FUYJ05EEE@1MGEd0GemO0P1QHF400`1UIFD0HF5Q06QXJ00206UYJ@0506ATI01VIVH0
GemO05iNGP1UIFD00`1TI6@00`1QHF40Hf=S06EUI@0206=SH`0506ATI01QHF40HV9R06EUI@1QHF40
0P1TI6@206IVIP0G06MWI`1XJ6P0Hf=S06UYJ@1/K6`0Hf=S05mOG`1UIFD0I6AT06=SH`1NGUh0FUYJ
05ADE01LG5`0UiNG0=oOg`3EeMD0a/K60;:b/P30`<00a<C40;2`/02IVIT00P2UYJD0:P2WYjL0WinO
09RHV02RXZ80XJ6Q09:BTP28R8P0VYZJ08b<S029RHT0PX:208J6QP2>SXh0QXJ607]kN`1hN7P0J6QX
06IVIP1TI6@0IFEU06e]K@1PH600EeMG051@D01QHF40L71`07=cL`1`L700KVi^075aL@1`L700LG5a
06QXJ01[Jf/0M7Ad08V9R@2?Shl0RHV908J6QP27QhL0RXZ:08n?S`80RXZ:01D0Rh^;08Z:RP25QHD0
QhN708b<S02@T900VIVI096AT@21PH40KVi^079bLP1gMgL0OGem08N7Q`2;Rh/0T92@08^;R`2@T900
UiNG09BDU02GUiL00P2JVYX04@2CTi<0SXj>08b<S02;Rh/0UIFE096AT@2@T900TI6A09NGU`2PX:00
XJ6Q09JFUP22PX80RHV909FEU@2HV9P0UIFE0080VIVI00`0WIfM08n?S`2DU9@0TI6A092@T02BTY80
VIVI09^KV`2CTi<0YZJV0:ZZZP2/[:`20:ZZZP0:0:VYZ@2][Jd0ZJVY0:NWY`2][Jd0YJFU0:>SX`2R
XZ80WIfM0:BTY080[:b/01<0ZZZZ0:RXZ02b/[80Zj^[0:ZZZP2[Zj/0X:2P09ZJVP2LW9`0XZ:R0:NW
Y`2^[Zh0];Bd0::RXP2PX:00WinO0:>SX`2WYjL0Z:RX0080YjNW00<0Z:RX0:f][@2ZZZX00P2QXJ40
1P2UYJD0VIVI09BDU02LW9`0VYZJ0::RXP80YZJV00D0YJFU0:ZZZP2YZJT0/[:b0;6a/@020;2`/008
0:b/[02`/;00Y:BT0:j^[P2[Zj/0YZJV0:f][@2j^[X20;^k^`060;Bd]02c/k<0/[:b0:n_[`2ZZZX0
ZJVY0`2b/[806@2`/;00[Jf]0:n_[`2_[jl0YjNW0:b/[02VYZH0YjNW0::RXP2/[:`0^;Rh0;Vi^@2g
]kL0/K6a0:b/[02UYJD0Zj^[09BDU02FUYH0YZJV09NGU`2@T900Z:RX0;Fe]@30`<000P38b<P02P35
aLD0_;bl0;:b/P2YZJT0/;2`0<30`02o_kl0`l?30<30`02o_kl20<?3``050<C4a03=cLd0clo?0<o?
c`3<c<`00P3:b/X20<K6aP0L0<G5a@33`l<0aLG50<?3``31`L40`/;20;jn_P2o_kl0`/;20;fm_@2n
_[h0`/;20<30`036a/H0a<C40<K6aP37alL0b<S80<W9b@38b<P0alO70<W9b@3;bl/0c<c<0<W9b@36
a/H0alO70<_;b`@0bLW900<0clo?0<k>cP3:b/X00P3?cll20=3@d00L0<[:bP3=cLd0dM7A0;>c/`2S
Xj<0X:2P09^KV`2IVIT0WYjN0:VYZ@2][Jd0/[:b0;bl_02n_[h0Ti>C07inOP23Ph<0SHf=09^KV`2X
Z:P0^;Rh0;Zj^P31`L40a/K60=7Ad@3Bd]80TI6A02l_;`809RHV00l0;bl_02LW9`0W9bL0:BTY02l_
;`0m?Cd0=3@d038b<P1:BTX0?3`l03De=@0a<C40<c<c02`/;00^;Rh00P0[:b/06@0Z:RX0;Bd]038b
<P0_;bl0<S8b03Lg=`0[:b/0;2`/030`<00^;Rh0>SXj03dm?@1<C4`0EEEE05IFEP1PH600LG5a07em
O@2ATI40UIFE09VIV@2EUID0V9RH09BDU02ATI400P2?Shl01P2BTY80UiNG09^KV`2OWil0X:2P09nO
W`80X:2P00P0XJ6Q0:2PX02RXZ80XZ:R0:6QX@2NWYh0X:2P09^KV`<0WinO0P2PX:001@2QXJ40WinO
0::RXP2PX:00WYjN0080WIfM01L0XJ6Q09^KV`2SXj<0WYjN09bLW02RXZ80WinO09RHV02QXJ40WYjN
09nOW`2PX:00W9bL09jNWP2KVi/0WIfM09jNWP2OWil0Vi^K09jNWP2KVi/0VIVI09fMW@0209jNWP03
09nOW`38h=P0b>3H00`0b>3H000<0<SPf080GUiN02<0HV9R05iNGP1LG5`0H61P06EUI@1WIfL0HF5Q
05eMG@1PH600Hf=S05mOG`1QHF40GUiN06EUI@1PH600Hf=S05aLG01NGUh0G5aL069RHP1VIVH0Hf=S
06MWI`1UIFD0JFUY07MgM`1nOWh0Q8B408R8R02ATI40V9RH09bLW02NWYh0XZ:R0:RXZ0020:ZZZP03
0:b/[02YZJT0[:b/0080Zj^[00T0ZJVY0:b/[02a/K40[:b/0:VYZ@2ZZZX0Zj^[0:f][@2^[Zh00P2W
YjL04P2SXj<0WIfM09^KV`2CTi<0TI6A08N7Q`24Q8@0MWIf06][J`1VIVH0FUYJ055AD@1EEED0Bd];
04m?C`1=CDd0E5AD059BDP80FEUI00h0HV9R05mOG`1NGUh0H61P05mOG`1MGEd0HV9R06ATI01SHf<0
IFEU065QH@1OGel0H61P065QH@80Hf=S01D0GemO06=SH`1TI6@0H61P06EUI@1RHV80IVIV065QH@1S
Hf<0HF5Q069RHP1SHf<0JVYZ06IVIP1TI6@0HV9R06IVIP1WIfL0IVIV06YZJP1TI6@00P1XJ6P03`1R
HV80IVIV05iNGP1PH600G5aL05iNGP2JVYX0gMgM0=WIf@39bLT0`/;20:b/[033`l<0]KFe09nOW`02
096AT@0]0:VYZ@2OWil0UiNG08V9R@2>SXh0Shn?096AT@2=SHd0QXJ608^;R`25QHD0PH6108R8R01n
OWh0OGem07UiN@1`L700JFUY05]KF`1HF5P0HF5Q06UYJ@1QHF40GemO06MWI`1TI6@0Lg=c07alO01g
MgL0M7Ad06m_K`1eMGD0Lg=c06EUI@1PH600N7Qh08J6QP2=SHd0S8b<09>CT`2?Shl0SHf=08^;R`2?
Shl0SHf=0080P82000L0R8R808^;R`25QHD0V9RH09nOW`2CTi<0MGEe0080Kfm_00`0LG5a0861P@2;
Rh/0T92@08n?S`2GUiL0UYJF09:BTP2FUYH0W9bL09NGU`2FUYH208f=S@0>08j>SP2DU9@0Ph>308f=
S@2FUYH0WYjN09RHV02MWId0X:2P09JFUP2EUID0SHf=08^;R`2>SXh208n?S`0=08b<S02>SXh0UiNG
09jNWP2TY:@0U9BD08Z:RP2;Rh/0WYjN0:JVYP2YZJT0YJFU0:^[Z`020;:b/P050:j^[P2[Zj/0Zj^[
0:>SX`2TY:@00P2UYJD07@2TY:@0YZJV0:^[Z`2ZZZX0Z:RX0:VYZ@2][Jd0YZJV0:ZZZP2TY:@0XJ6Q
09nOW`2UYJD0[:b/0:j^[P2/[:`0Xj>S09nOW`2RXZ80YJFU0:NWY`2^[Zh0Z:RX0:2PX02UYJD0Zj^[
0:VYZ@2MWId0XZ:R0080Zj^[00L0Z:RX0:VYZ@2>SXh0Ti>C09ZJVP2QXJ40Xj>S0080[:b/00H0[Jf]
0;2`/02[Zj/0[Zj^0:b/[02][Jd20;2`/0060;:b/P2YZJT0/;2`0;Fe]@2j^[X0_;bl0P2i^KT0102h
^;P0[Zj^0;2`/02^[Zh20;:b/P80/k>c0200];Bd0:n_[`2^[Zh0/;2`0:j^[P2/[:`0Xj>S0:BTY02_
[jl0/K6a0;Fe]@2j^[X0]KFe0:j^[P2][Jd0[:b/0:NWY`2EUID0YJFU0:>SX`2DU9@0WIfM0:2PX02Q
XJ40ZZZZ0;Rh^031`L40a/K60<o?c`31`L40^KVi0;Bd]080][Jf00h0^[Zj0;jn_P2k^k/0`L710<?3
``34a<@0a/K60<W9b@3=cLd0d];B0<k>cP3<c<`0a/K60<W9b@80aLG500l0bl_;0<O7a`35aLD0`L71
0;jn_P2j^[X0`<300<;2`P2n_[h0`l?30<;2`P33`l<0aLG50<71`@32`/800P38b<P04P37alL0a/K6
0<G5a@39bLT0b<S80<C4a036a/H0b<S80<W9b@3:b/X0bLW90<K6aP38b<P0cLg=0<c<c039bLT0clo?
0<k>cP80clo?0300cLg=0<W9b@3AdM40a/K60:VYZ@2UYJD0Vi^K09JFUP2IVIT0WIfM0::RXP2YZJT0
/K6a0;fm_@2h^;P0T92@07moO`2:RXX0UIFE0:JVYP2f][H0^k^k0<G5a@33`l<0c/k>0=GEe@2i^KT0
?clo02h^;P0c<c<0;Bd]02<S8`0W9bL0?3`l03Ph>015ADD0;Bd]03<c<`0_;bl0<c<c02l_;`0h>3P0
<S8b030`<00^;Rh0<C4a02PX:00c<c<202TY:@0;030`<00a<C40=cLg02d];@0/;2`0<S8b02l_;`0b
<S80>SXj0410@016ATH00P1?Cdl0201WIfL0M7Ad08J6QP2=SHd0UIFE09NGU`2EUID0V9RH0P2DU9@2
092@T00709BDU02HV9P0WinO09ZJVP2OWil0X:2P09fMW@040:6QX@0409nOW`2SXj<0XZ:R09nOW`80
VIVI00/0WinO0::RXP2QXJ40X:2P09nOW`2PX:00WYjN0::RXP2PX:00WIfM09nOW`0209jNWP0509RH
V02PX:00WYjN09jNWP2OWil00P2LW9`01P2NWYh0W9bL09nOW`2OWil0Y:BT09bLW080X:2P00P0W9bL
09ZJVP2NWYh0Vi^K09bLW02PX:00WIfM09^KV`h0b>3H000<0<SPf080H61P00P0Hf=S061PH01SHf<0
GEeM061PH01UIFD0GEeM069RHP80G5aL0P1OGel2069RHP0J05eMG@1SHf<0HV9R069RHP1NGUh0HV9R
05mOG`1QHF40IVIV06QXJ01_Kfl0MGEe07alO025QHD0S8b<09BDU02HV9P0VYZJ09bLW02RXZ80YJFU
0:ZZZP2][Jd0Zj^[0:f][@2^[Zh20;:b/P050:ZZZP2/[:`0[Jf]0:f][@2^[Zh00P2XZ:P04P2[Zj/0
[:b/0:b/[02XZ:P0YZJV09fMW@2JVYX0UYJF08j>SP26QXH0P82007IfMP1^KVh0GemO05MGE`1ADE40
D51@04i>CP80CDe=01L0DU9B05EEE@1IFET0F5QH065QH@1LG5`0H61P065QH@1SHf<0Fe]K065QH@1R
HV80I6AT069RHP1TI6@0Jf][06ATI01UIFD0Hf=S05eMG@1OGel0IVIV06ATI00206=SH`0:06ATI01Q
HF40HF5Q06=SH`1UIFD0H61P06=SH`1WIfL0IFEU069RHP80IVIV0180JFUY06MWI`1WIfL0J6QX06IV
IP1SHf<0IfMW06IVIP1TI6@0F5QH05YJFP1MGEd0V9RH0=kNgP3Hf=P0a/K60<C4a02h^;P20:b/[00J
0;6a/@2PX:00X:2P09JFUP2MWId0ZJVY09VIV@22PX80SXj>09BDU02<S8`0Q8B4096AT@2:RXX0PH61
07inOP1aLG40NWYj07IfMP1dM7@0Kfm_069RHP1GEeL0De=C05eMG@1bLW8206a/K00?065QH@1YJFT0
N7Qh07UiN@1gMgL0N7Qh07EeM@1hN7P0KVi^06MWI`1OGel0Lg=c0820P02?Shl0TI6A0080Shn?00l0
TI6A092@T02<S8`0O7al08F5Q@29RHT0QhN708R8R02>SXh0Ti>C0:6QX@2IVIT0LW9b06QXJ01]KFd0
0P1hN7P01@2=SHd0V9RH09BDU02DU9@0UYJF0080V9RH0180UYJF09BDU02DU9@0UIFE09NGU`2HV9P0
QXJ609FEU@2MWId0UIFE096AT@2HV9P0VIVI0:6QX@2OWil0Vi^K09RHV02ATI4208^;R`0K08F5Q@2>
SXh0WinO0:JVYP2SXj<0UiNG08N7Q`28R8P0UIFE0:>SX`2PX:00Zj^[0;>c/`2`/;00/[:b0:n_[`2X
Z:P0Y:BT0:JVYP2SXj<0Y:BT0:NWY`2[Zj/0[Zj^0:VYZ@2WYjL0Zj^[0080ZJVY0200[:b/0:BTY02N
WYh0WYjN0:ZZZP2[Zj/0/[:b0:b/[02WYjL0WYjN09fMW@2NWYh0YJFU0:VYZ@2ZZZX0YjNW0::RXP2W
YjL0Xj>S09^KV`2LW9`0ZJVY0:f][@2_[jl0/K6a0:j^[P2UYJD0Vi^K09jNWP2RXZ80XJ6Q0:ZZZP80
[Zj^00L0/k>c0:^[Z`2/[:`0Zj^[0:RXZ02`/;00/k>c0080[Jf]00`0][Jf0;Zj^P2h^;P0^k^k0;bl
_02g]kL0][Jf0:b/[02^[Zh0];Bd0;6a/@2d];@30;2`/00;0:n_[`2`/;00/;2`0:b/[02TY:@0YjNW
0:f][@2i^KT0]KFe0;Bd]02b/[800P2c/k<0;P2_[jl0/k>c09jNWP2JVYX0[Zj^0:BTY02GUiL0ZJVY
0::RXP2XZ:P0WYjN0:FUY@2][Jd0];Bd0<W9b@3@d=00bl_;0<C4a02m_Kd0/[:b0:RXZ02e]KD0`L71
0<?3``31`L40_[jn0<30`032`/80`L710<g=c@3?cll0c/k>0<c<c03:b/X0a/K60<[:bP39bLT0b<S8
0<O7a`34a<@0`/;20;^k^`2o_kl0`L710<30`02o_kl20<?3``060<O7a`36a/H0a<C40<;2`P35aLD0
b<S80P36a/H20<S8b00:0<W9b@34a<@0a/K60<[:bP3;bl/0bLW90<c<c038b<P0b/[:0<g=c@80bl_;
02L0clo?0<k>cP3>c/h0clo?0<S8b03;bl/0d=3@0;^k^`2_[jl0X:2P0:6QX@2KVi/0WYjN09bLW02N
WYh0YZJV0;2`/02n_[h0^[Zj09>CT`2<S8`0U9BD0:VYZ@2c/k<0_kno0<C4a037alL0clo?0=CDe03?
cll0Lg=c02d];@0/;2`09bLW02/[:`0/;2`0<C4a0410@00i>CT00P0_;bl02P0g=cL0;bl_03<c<`0g
=cL0@410038b<P0`<300<S8b02/[:`0a<C4202TY:@80;bl_01@0=3@d030`<00Y:BT0:2PX02TY:@0]
;Bd0<c<c04=3@`1<C4`0DE5A04m?C`1DE5@0JFUY07UiN@29RHT0TI6A09JFUP2GUiL0V9RH09:BTP80
Ti>C00X0SXj>092@T02FUYH0V9RH09fMW@2LW9`0WYjN09nOW`2NWYh0XJ6Q0P2OWil00`2QXJ40XZ:R
0:6QX@020:6QX@0709fMW@2PX:00X:2P09nOW`2QXJ40WYjN09^KV`020::RXP080:2PX02MWId0W9bL
09jNWP2QXJ40X:2P09nOW`2KVi/209nOW`80WYjN00T0WIfM09nOW`2NWYh0WinO0:6QX@2OWil0WYjN
09nOW`2LW9`00P2KVi/01@2MWId0WinO0:2PX02JVYX0W9bL00h0b>3H000<0<SPf080Hf=S00<0H61P
065QH@1QHF400P1QHF403`1TI6@0IFEU05mOG`1TI6@0JVYZ061PH01QHF40H61P069RHP1QHF40GUiN
06IVIP1OGel0GUiN06=SH`02069RHP0>06YZJP1XJ6P0KFe]07AdM01oOgl0Ph>308V9R@2?Shl0U9BD
09JFUP2NWYh0XZ:R0:FUY@2QXJ460:b/[0070:f][@2`/;00[jn_0:f][@2_[jl0[Jf]0:b/[0020:f]
[@0D0:j^[P2VYZH0Xj>S09jNWP2LW9`0UIFE08b<S028R8P0PX:207AdM01/K6`0HV9R05EEE@1HF5P0
CTi>055AD@1<C4`0CTi>055AD@1HF5P205YJFP03065QH@1OGel0HF5Q0080HV9R00/0GemO069RHP1T
I6@0HV9R06=SH`1XJ6P0IFEU06IVIP1PH600IfMW06EUI@02061PH00306=SH`1PH600IVIV00<0Hf=S
00`0H61P06=SH`1TI6@0HF5Q06EUI@1SHf<0I6AT06IVIP1RHV80Jf][06=SH`1QHF4206MWI`0@06QX
J01TI6@0Hf=S069RHP1IFET0FUYJ05UIF@25QHD0fMWI0=SHf03;bl/0];Bd0<C4a02f][H0YJFU0;:b
/P80[Zj^03d0ZJVY09>CT`2`/;00Zj^[08V9R@25QHD0VYZJ09fMW@27QhL0QHF508Z:RP1jNWX0MGEe
06m_K`1bLW80M7Ad06i^KP1aLG40KVi^065QH@1CDe<0EEEE06UYJ@1]KFd0LG5a06QXJ01WIfL0KFe]
07MgM`1nOWh0N7Qh07IfMP1bLW80JFUY06YZJP1VIVH0IfMW079bLP26QXH0SXj>09NGU`2BTY80Shn?
08Z:RP26QXH0R8R808n?S`2>SXh0TI6A08n?S`27QhL0SHf=09jNWP2MWId0QXJ6071`L01cLg<0MWIf
07EeM@1oOgl0U9BD0080T92@00X0UYJF09NGU`2GUiL0TY:B09BDU02ATI40VYZJ0:6QX@2IVIT0TI6A
0P2EUID208b<S00708n?S`2JVYX0VYZJ09bLW02XZ:P0Xj>S092@T00208^;R`0=08V9R@2?Shl0YZJV
0:FUY@2HV9P0UIFE09JFUP2IVIT0T92@096AT@2RXZ80[Jf]0;:b/P020:n_[`030:f][@2[Zj/0Z:RX
0080YZJV00<0YjNW0:BTY02/[:`00P2YZJT04P2XZ:P0YZJV0:NWY`2SXj<0WinO09jNWP2TY:@0Z:RX
0;Fe]@2b/[80[Jf]0:VYZ@2WYjL0XZ:R0:VYZ@2XZ:P0XZ:R0:JVYP80Xj>S00l0Y:BT0:6QX@2LW9`0
YJFU0:j^[P2/[:`0Z:RX0:n_[`2[Zj/0ZJVY0:b/[02RXZ80[Jf]0:JVYP2KVi/00P2PX:001@2ZZZX0
/[:b0:RXZ02ZZZX0[Zj^0080/k>c00`0/[:b0;6a/@2c/k<0^k^k0;fm_@2k^k/0_;bl0;Fe]@2g]kL0
[Zj^0;>c/`2e]KD20;Rh^00?0;Bd]02a/K40/K6a0;6a/@2`/;00];Bd0;2`/02^[Zh0ZJVY0:n_[`2g
]kL0^[Zj0;Jf]P2i^KT0^k^k0080][Jf0140];Bd0;:b/P2NWYh0/;2`0;6a/@2PX:00WYjN0;:b/P2[
Zj/0YZJV0::RXP2MWId0W9bL0::RXP2e]KD0a<C40<g=c@020=7Ad@090;no_`2f][H0]kNg0;2`/02i
^KT0`l?30<;2`P2k^k/0aLG50080`l?300D0b<S80<W9b@38b<P0c/k>0<W9b@020<c<c0080<W9b@3;
bl/0alO70<S8b033`l<0a/K60<;2`P36a/H20<?3``030<G5a@36a/H0a/K60080a/K600<0alO70<[:
bP39bLT00P38b<P01@36a/H0alO70<K6aP37alL0bl_;00<0b/[:00H0a/K60<[:bP3;bl/0cLg=0<c<
c03@d=020<k>cP060=3@d03;bl/0b/[:0<o?c`37alL0];Bd0P2WYjL07P2OWil0X:2P09bLW02KVi/0
X:2P0:FUY@2d];@0_kno0;^k^`2MWId0WinO0:^[Z`2d];@0`<300<W9b@3<c<`0cLg=0=;BdP3Cdm<0
XZ:R03hn?P0X:2P0;Bd]02XZ:P0X:2P0?3`l038b<P0g=cL0=SHf03Lg=`80;Rh^00<0=SHf034a<@0h
>3P00P0e=CD06@0j>SX0;bl_02d];@0/;2`0:RXZ02HV9P0[:b/0<S8b02d];@0^;Rh0;Bd]02/[:`0_
;bl0<c<c03Xj>P0k>c/0BDU90492@P15ADD0F5QH079bLP21PH40TY:B09NGU`2HV9P00P2IVIT0302B
TY80UIFE09>CT`2ATI40UIFE09JFUP2LW9`0WinO09VIV@2TY:@0XJ6Q0:>SX`80X:2P00d0XZ:R0:6Q
X@2RXZ80WIfM09nOW`2LW9`0XJ6Q09jNWP2QXJ40X:2P0:6QX@2MWId0YZJV0080X:2P0P2KVi/01@2N
WYh0Xj>S09nOW`2LW9`0WYjN0080XJ6Q00H0W9bL09VIV@2MWId0WYjN09bLW02NWYh20:2PX0030:6Q
X@2NWYh0WIfM00<0VYZJ00@0Vi^K09fMW@2NWYh0Vi^K3P38h=P000`0b>3H0P1OGel02`1VIVH0IFEU
06=SH`1XJ6P0GUiN069RHP1PH600HF5Q06ATI01RHV80Hf=S0080HV9R0P1UIFD00`1OGel0JFUY069R
HP02069RHP0?05mOG`1QHF40I6AT06MWI`1bLW80M7Ad07]kN`1nOWh0RHV908n?S`2ATI40V9RH0:>S
X`2PX:00YZJV0080YjNW00<0ZZZZ0:n_[`2^[Zh00P2_[jl0802^[Zh0[:b/0;2`/02/[:`0Zj^[0:n_
[`2/[:`0/[:b0:b/[02YZJT0Zj^[0::RXP2MWId0UiNG09BDU02>SXh0RHV907emO@1fMWH0LW9b06AT
I01KFe/0EUIF05=CD`1BDU80Cdm?055AD@1DE5@0EEEE061PH01MGEd0G5aL0`1NGUh0101OGel0Fe]K
06ATI01MGEd206IVIP0<06MWI`1UIFD0IVIV06ATI01QHF40IVIV05mOG`1PH600IFEU069RHP1UIFD0
IfMW0P1QHF40101WIfL0IFEU06=SH`1UIFD2069RHP0606UYJ@1XJ6P0JFUY06MWI`1UIFD0JVYZ0P1Y
JFT0401SHf<0IFEU06=SH`1RHV80GUiN05YJFP1NGUh0U9BD0=[JfP3Kfm/0d];B0<71`@2g]kL0_Kfm
0;Bd]02MWId20:ZZZP0E0;Ng]`2UYJD0UiNG09>CT`2>SXh0S8b<09JFUP2>SXh0P8200861P@1nOWh0
P82007IfMP1YJFT0L71`06i^KP1YJFT0KVi^06m_K`1XJ6P0I6AT0080Hf=S0340I6AT07EeM@1dM7@0
LW9b06a/K01_Kfl0MgMg07moO`1nOWh0Lg=c06a/K01VIVH0HV9R06EUI@1TI6@0LG5a08R8R02GUiL0
VIVI09>CT`24Q8@0R8R809>CT`2ATI40RHV909>CT`2>SXh0QHF508n?S`2EUID0TY:B08f=S@2ATI40
SXj>07=cL`1^KVh0O7al08B4Q027QhL0TI6A09BDU02GUiL0T92@08n?S`2=SHd0UYJF09^KV`2GUiL0
W9bL0080VIVI00X0V9RH08Z:RP2:RXX0R8R8092@T02GUiL0V9RH09bLW02MWId0UYJF0P29RHT04P2A
TI40YjNW0:>SX`2LW9`0Shn?09JFUP2YZJT0[:b/09fMW@2>SXh0UIFE09jNWP2XZ:P0ZZZZ0:JVYP2`
/;00ZZZZ0:^[Z`80[Jf]00<0/K6a0:NWY`2VYZH00P2/[:`02@2UYJD0YjNW0:NWY`2OWil0XJ6Q0:NW
Y`2d];@0][Jf0;6a/@020:f][@060:b/[02ZZZX0/;2`0;:b/P2a/K40ZZZZ0P2PX:00202EUID0VIVI
09^KV`2VYZH0/[:b0;>c/`2`/;00YjNW102VYZH01P2a/K40/k>c0;2`/02TY:@0ZZZZ0:^[Z`80Xj>S
00@0Z:RX0:j^[P2f][H0]kNg0`2a/K40302k^k/0_;bl0;fm_@2j^[X0^k^k0;6a/@2_[jl0/;2`0;Rh
^02k^k/0_;bl0;Zj^P<0^KVi00<0/k>c0;Bd]02f][H00P2`/;030;>c/`0=0;Ng]`2c/k<0/[:b0;Jf
]P2o_kl0][Jf0;Zj^P2ZZZX0Y:BT0;Vi^@2[Zj/0WIfM0:^[Z`020;:b/P0A0:j^[P2YZJT0YZJV09fM
W@2HV9P0X:2P0:JVYP2k^k/0b/[:0=3@d03>c/h0bLW90;no_`2d];@0/[:b0:n_[`2l_;`00P33`l<0
1P30`<00`/;20<?3``32`/80aLG50<S8b080c<c<00H0clo?0<c<c03<c<`0bl_;0<[:bP39bLT20<S8
b0030<[:bP35aLD0alO700@0a/K60P37alL20<W9b@060<_;b`38b<P0alO70<S8b035aLD0bLW90P38
b<P01@39bLT0a/K60<W9b@39bLT0b/[:00<0cLg=0P3<c<`02`3=cLd0clo?0<_;b`3<c<`0cLg=0;fm
_@2][Jd0ZJVY0:2PX02NWYh0XZ:R0080WinO02<0YZJV0:n_[`2l_;`0bLW90<;2`P2][Jd0]KFe0;^k
^`2l_;`0b/[:0=7Ad@3Bd]80c/k>0=CDe035aLD0GEeM02PX:00V9RH0:BTY02XZ:P0d=3@0:RXZ034a
<@0];Bd0;2`/03@d=00^;Rh0<C4a03Lg=`0a<C40;Bd]030`<00b<S80;bl_034a<@0202/[:`0I02d]
;@0a<C40;bl_02l_;`0^;Rh0<30`02/[:`0a<C40<30`03<c<`0h>3P0>SXj038b<P0n?Sh0BDU906AT
I01fMWH0PX:2096AT@2HV9P0VYZJ09^KV`2FUYH0TY:B09BDU00209>CT`0309JFUP2LW9`0W9bL0080
X:2P00d0XJ6Q09nOW`2SXj<0Xj>S0:BTY02RXZ80Y:BT0:6QX@2RXZ80WinO0::RXP2QXJ40WinO0080
WYjN00L0XJ6Q0::RXP2OWil0XZ:R09nOW`2LW9`0Vi^K0080WYjN00D0XJ6Q09VIV@2OWil0WinO09jN
WP0209^KV`0?09nOW`2JVYX0VYZJ09bLW02NWYh0WinO09bLW02MWId0Vi^K09nOW`2JVYX0W9bL09ZJ
VP2PX:00Vi^K00h0b>3H000<0<SPf080GemO0P1SHf<0201WIfL0IFEU065QH@1SHf<0G5aL06=SH`1M
GEd0H61P0P1QHF406`1LG5`0IVIV06EUI@1OGel0IfMW06=SH`1MGEd0GemO05iNGP1VIVH0Hf=S06IV
IP1aLG40Lg=c07YjNP23Ph<0S8b<096AT@2?Shl0VIVI09^KV`2OWil0Xj>S0:JVYP2YZJT0Zj^[0:b/
[0030:^[Z`040:f][@2_[jl0[:b/0:j^[P80Zj^[0140ZZZZ0:f][@2][Jd0ZZZZ0:JVYP2TY:@0Xj>S
09ZJVP2CTi<0T92@08N7Q`1nOWh0NGUi07=cL`1QHF40G5aL05IFEP0204a<C00804e=C@1@D500De=C
05IFEP1IFET0G5aL05UIF@1MGEd205iNGP0;05]KF`1NGUh0H61P065QH@1UIFD0Hf=S06ATI01RHV80
IFEU06QXJ01TI6@00`1PH6001P1VIVH0IFEU06=SH`1SHf<0HF5Q061PH080Hf=S00X0GEeM06=SH`1S
Hf<0HF5Q06MWI`1ZJVX0JFUY06MWI`1YJFT0J6QX0P1[Jf/0401WIfL0JVYZ06ATI01PH600GemO05MG
E`1OGel0VIVI0>3Ph03Kfm/0d];B0<[:bP2b/[80`<300;Vi^@2PX:0209^KV`0E0:RXZ02RXZ80QHF5
08>3P`2DU9@0TI6A08^;R`1lO7`0PX:208J6QP21PH40PX:207YjNP1YJFT0JVYZ07=cL`1TI6@0IFEU
06a/K01YJFT0J6QX0080K6a/01H0IFEU06][J`1eMGD0M7Ad06a/K01VIVH0LG5a0820P023Ph<0P820
07=cL`1UIFD0H61P06EUI@1VIVH0KVi^07UiN@2:RXX0U9BD08j>SP28R8P0Shn?0P2>SXh06@2CTi<0
V9RH08Z:RP28R8P0T92@08b<S026QXH0Ti>C09bLW02NWYh0NWYj06][J`1aLG40MWIf08:2PP2ATI40
UIFE09:BTP2DU9@0Shn?09:BTP2KVi/0VYZJ09^KV`2GUiL00P2LW9`00`2DU9@0TI6A08Z:RP0208N7
Q`05092@T02?Shl0T92@09NGU`2CTi<00P2IVIT0202PX:00Zj^[09bLW02HV9P0X:2P0:b/[02a/K40
[jn_0P2NWYh04`2EUID0Ti>C09BDU02LW9`0YZJV0;>c/`2_[jl0/K6a0;Ng]`2e]KD0/K6a0:n_[`2[
Zj/0YJFU0:JVYP2XZ:P0Y:BT09jNWP2SXj<00P2c/k<0602`/;00[jn_0:NWY`2/[:`0/[:b0:f][@2f
][H0]KFe0;>c/`2/[:`0YZJV0:BTY02UYJD0Vi^K0:>SX`2/[:`0[Jf]0;6a/@2b/[80Z:RX0:2PX02N
WYh0XZ:R0:b/[080[Jf]00P0/K6a0:j^[P2c/k<0]kNg0;Jf]P2WYjL0XZ:R0:ZZZP80/;2`00h0/K6a
0;:b/P2`/;00]kNg0;bl_02k^k/0^;Rh0;Vi^@2f][H0Zj^[0;:b/P2k^k/0_;bl0;no_`80_;bl00X0
_Kfm0;bl_02l_;`0^;Rh0;>c/`2`/;00[Zj^0;2`/02][Jd0/;2`0P2d];@08P2c/k<0]KFe0;Jf]P2l
_;`0][Jf0:^[Z`2UYJD0/K6a0;Rh^02WYjL0XZ:R0;Ng]`2d];@0/[:b0;>c/`2^[Zh0ZJVY09^KV`2S
Xj<0XJ6Q09VIV@2LW9`0/[:b0<;2`P3:b/X0clo?0=3@d034a<@0_[jn0;Fe]@2[Zj/0[jn_0;bl_02n
_[h20;Zj^P070<?3``34a<@0aLG50<K6aP3;bl/0d=3@0<k>cP020<o?c`060<[:bP3<c<`0c<c<0<_;
b`3:b/X0c<c<0P37alL02036a/H0aLG50<G5a@33`l<0alO70<K6aP38b<P0a/K61038b<P02`32`/80
a/K60<W9b@36a/H0bLW90<c<c038b<P0b/[:0<k>cP3<c<`0b/[:0080bl_;01<0b/[:0<k>cP3>c/h0
b/[:0<o?c`3:b/X0^;Rh0:j^[P2SXj<0WinO09fMW@2UYJD0XJ6Q0:RXZ02c/k<0^[Zj0<G5a@3=cLd0
a/K60080`<3000h0aLG50<g=c@3De=@0eMGE0=?Cd`3EeMD0dm?C09FEU@0Z:RX0;Rh^02d];@0U9BD0
:BTY02l_;`80;2`/00h0;Bd]02l_;`0a<C40>CTi038b<P0a<C40;2`/02l_;`0f=SH0<C4a02h^;P0e
=CD0<c<c02/[:`80;Rh^01D0<S8b02d];@0`<300<30`038b<P0`<300=CDe03@d=00a<C40<30`02d]
;@0n?Sh0DU9B06e]K@20P800T92@09FEU@2LW9`0VIVI09RHV02EUID00P2ATI401`2<S8`0U9BD09JF
UP2MWId0WinO0:2PX02RXZ800`2PX:001P2OWil0Y:BT0:6QX@2RXZ80Xj>S0:BTY080WinO00<0Vi^K
0:6QX@2OWil00P2RXZ800`2QXJ40Vi^K0:>SX`0309fMW@090:2PX02OWil0W9bL09fMW@2LW9`0X:2P
09fMW@2LW9`0WinO0080WYjN00`0Vi^K09jNWP2RXZ80XJ6Q09jNWP2KVi/0WinO09fMW@2LW9`0XZ:R
09fMW@2IVIT>0<SPf0003038h=P206=SH`0:05mOG`1PH600Hf=S06=SH`1OGel0IfMW061PH01]KFd0
JVYZ06=SH`80HF5Q00L0H61P069RHP1SHf<0H61P06EUI@1PH600Fe]K00@0HF5Q00d0I6AT06UYJ@1b
LW80OWin0820P02>SXh0SHf=096AT@2GUiL0WIfM0:2PX02TY:@0YJFU0080YZJV0P2^[Zh20:f][@04
0:ZZZP2a/K40[Jf]0:ZZZP<0[Jf]0240[jn_0:^[Z`2][Jd0YjNW0::RXP2TY:@0UiNG09>CT`2=SHd0
R8R808:2PP1hN7P0M7Ad06=SH`1IFET0D51@04a<C01>CTh0BTY:04a<C01?Cdl0CTi>05EEE@1HF5P0
G5aL05]KF`1SHf<0H61P069RHP1QHF40GemO061PH01SHf<00P1TI6@06`1QHF40IFEU06EUI@1PH600
Hf=S069RHP1SHf<0IfMW06=SH`1QHF40Hf=S05mOG`1TI6@0H61P06IVIP1QHF40Hf=S06ATI01RHV80
I6AT06MWI`1ZJVX0IVIV06=SH`1XJ6P0IVIV06][J`0206EUI@0>06QXJ01SHf<0GemO05]KF`1PH600
TI6A0=kNgP3IfMT0d=3@0<O7a`32`/80/K6a0;>c/`2a/K4208f=S@0A08b<S02NWYh0S8b<08F5Q@2;
Rh/0Shn?08R8R01eMGD0NGUi09FEU@25QHD0Ng]k07EeM@1]KFd0JVYZ06MWI`1TI6@00P1XJ6P01`1W
IfL0J6QX07QhN01aLG40J6QX06UYJ@1^KVh00P1aLG40:01ZJVX0LW9b07MgM`1mOGd0Lg=c07MgM`1a
LG40K6a/06YZJP1aLG40Kfm_06QXJ01jNWX0Q8B408V9R@2DU9@0TI6A08R8R02>SXh0V9RH09FEU@2A
TI40U9BD092@T022PX80R8R808f=S@2DU9@0V9RH09>CT`2;Rh/0MGEe06a/K01eMGD0R8R808b<S02@
T900U9BD09VIV@2HV9P209BDU00>09>CT`2OWil0VYZJ09ZJVP2IVIT0UIFE08Z:RP23Ph<0PH6108^;
R`2BTY80S8b<092@T02DU9@20::RXP0e0:f][@2VYZH0VYZJ09nOW`2d];@0/k>c0;Fe]@2XZ:P0XZ:R
0:NWY`2SXj<0VIVI08^;R`2=SHd0WYjN0:b/[02b/[80]KFe0;>c/`2a/K40/[:b0;>c/`2/[:`0ZJVY
0:^[Z`2PX:00VIVI0:>SX`2/[:`0]KFe0;Bd]02^[Zh0ZZZZ0:j^[P2`/;00/[:b0;>c/`2h^;P0];Bd
0:f][@2WYjL0[jn_0:ZZZP2_[jl0/[:b0:f][@2`/;00Zj^[0:VYZ@2/[:`0Xj>S09fMW@2WYjL00P2_
[jl01@2][Jd0YZJV0:j^[P2d];@0^KVi0080]KFe00H0/[:b0:j^[P2d];@0YjNW0:>SX`2`/;020;Jf
]P0>0;Rh^02k^k/0^KVi0;Jf]P2c/k<0[Jf]0:b/[02f][H0^[Zj0;bl_02n_[h0`<300;fm_@30`<02
0;no_`060;bl_02e]KD0]KFe0:b/[02`/;00/[:b0P2g]kL05`2d];@0^KVi0;Zj^P2h^;P0/k>c0:j^
[P2XZ:P0[Zj^0;Rh^02][Jd0Xj>S0;:b/P2h^;P0][Jf0;Bd]02h^;P0]KFe0:b/[02TY:@0[jn_0:NW
Y`2GUiL0Vi^K0080XZ:R00X0];Bd0;no_`3=cLd0c/k>0<g=c@32`/80^KVi0;Fe]@2[Zj/0ZZZZ0P2i
^KT03033`l<0a<C40<K6aP36a/H0a<C40<W9b@3<c<`0dM7A0=3@d03=cLd0c/k>0<o?c`80c<c<00D0
bl_;0<g=c@39bLT0a/K60<G5a@020<?3``030<O7a`39bLT0b<S80080b<S800H0bLW90<S8b038b<P0
b<S80<O7a`38b<P30<O7a`050<W9b@3;bl/0c<c<0<_;b`39bLT00`3=cLd07P39bLT0c<c<0<_;b`3?
cll0d];B0<K6aP2f][H0YjNW0:BTY02UYJD0YjNW0:FUY@2ZZZX0/k>c0;^k^`31`L40cLg=0=7Ad@3;
bl/0b<S80<[:bP3AdM40d];B0=_Kf`3Hf=P0dm?C0=SHf02j^[X0?Shn02d];@80:RXZ00P09RHV02XZ
:P0Z:RX0;Rh^02l_;`0];Bd0<C4a02d];@80=3@d02P0<S8b034a<@0j>SX0@D5103Xj>P0b<S809RHV
02/[:`0_;bl0=cLg02`/;00b<S80<c<c03De=@0h>3P0?Cdm03Ph>00d=3@0<C4a02XZ:P0Y:BT0=SHf
04Q8B01QHF40NGUi08J6QP2DU9@0WinO09jNWP2HV9P0UIFE09BDU02@T900Shn?09>CT`2GUiL0VIVI
09bLW02NWYh0XJ6Q0`2PX:001@2LW9`0X:2P0:6QX@2NWYh0WinO0080XJ6Q00T0WinO0:2PX02OWil0
X:2P0:FUY@2QXJ40X:2P09nOW`2RXZ800P2PX:002@2MWId0WinO0:2PX02MWId0WYjN0:6QX@2RXZ80
WIfM09bLW00209fMW@80WinO0P2NWYh01@2MWId0VIVI09fMW@2OWil0WIfM0080X:2P00<0W9bL09ZJ
VP38h=P03@38h=P000`0b>3H0P1OGel00`1RHV80GEeM05iNGP02069RHP0S06IVIP1PH600IFEU06AT
I01PH600HF5Q061PH01SHf<0HF5Q061PH01TI6@0HF5Q06IVIP1RHV80IVIV065QH@1KFe/0Hf=S06UY
J@1bLW80L71`07MgM`22PX80R8R808j>SP2CTi<0V9RH09^KV`2PX:00Xj>S0:RXZ02WYjL0[:b/0:f]
[@2a/K400P2/[:`30:f][@0U0:b/[02[Zj/0[Zj^0;2`/02_[jl0Zj^[0:ZZZP2WYjL0YZJV0::RXP2F
UYH0T92@08n?S`23Ph<0PH6107IfMP1bLW80Hf=S05aLG01FEUH0Cdm?04i>CP1<C4`0DE5A05=CD`1D
E5@0EUIF05QHF01OGel0G5aL05mOG`1KFe/0H61P05mOG`1PH600HF5Q069RHP0206ATI00306=SH`1T
I6@0HF5Q0080HF5Q00L0Hf=S06EUI@1RHV80IfMW05mOG`1WIfL0GemO0080I6AT00D0J6QX069RHP1R
HV80I6AT06=SH`0206UYJ@0406YZJP1VIVH0IfMW06IVIP<0JVYZ0P1TI6@03@1PH600Fe]K05YJFP1L
G5`0QHF50=GEe@3Kfm/0c/k>0<?3``31`L40_;bl09jNWP2d];@00P2LW9`05@2=SHd0UIFE09JFUP2:
RXX0QHF508N7Q`28R8P0M7Ad07EeM@25QHD0OWin07QhN01`L700MWIf07AdM01XJ6P0IfMW06e]K@1_
Kfl0IfMW06EUI@0206m_K`0>06e]K@1VIVH0Hf=S061PH01WIfL0Kfm_07=cL`1eMGD0QHF5075aL@1c
Lg<0Ng]k07inOP1gMgL207AdM00/06i^KP1ZJVX0Lg=c08B4Q02EUID0RXZ:08F5Q@2:RXX0TI6A092@
T02IVIT0U9BD08f=S@28R8P0Shn?08f=S@25QHD0SHf=09^KV`2TY:@0QhN707QhN01`L700LW9b08N7
Q`2@T900UIFE09VIV@2FUYH0VIVI09JFUP2GUiL0VIVI09NGU`2PX:00XJ6Q09jNWP2?Shl0QXJ608b<
S02@T900R8R808^;R`2@T9030:2PX00B09bLW02MWId0XJ6Q0:n_[`2f][H0];Bd0:b/[02WYjL0ZZZZ
0:VYZ@2[Zj/0W9bL092@T029RHT0UIFE0:6QX@2a/K40][Jf0P2c/k<0202d];@0/K6a0;6a/@2ZZZX0
WYjN09nOW`2NWYh0[Zj^0P2`/;020:b/[00J0;2`/02[Zj/0[Zj^0;Ng]`2c/k<0^;Rh0:f][@2UYJD0
Z:RX0:ZZZP2c/k<0];Bd0;2`/02[Zj/0[jn_0:VYZ@2ZZZX0[Jf]0:NWY`2XZ:P0[Jf]0:JVYP2XZ:P0
YZJV0:b/[02d];@30;>c/`0@0;Ng]`2f][H0^[Zj0;^k^`2e]KD0/;2`0;:b/P2c/k<0];Bd0;Ng]`2j
^[X0_;bl0;:b/P2`/;00[Jf]0;Zj^P80^;Rh00<0^k^k0;jn_P2o_kl00P30`<020;bl_0040;fm_@2h
^;P0];Bd0;:b/P80][Jf00h0/k>c0;Ng]`2g]kL0^[Zj0;Rh^02`/;00ZJVY0:>SX`2`/;00/[:b0:^[
Z`2WYjL0/;2`0;^k^`80]KFe01/0]kNg0;Jf]P2b/[80Xj>S0:NWY`2c/k<0ZJVY09fMW@2VYZH0YjNW
09jNWP2LW9`0Zj^[0;^k^`34a<@0b/[:0<o?c`38b<P0`<300;Zj^P2WYjL0XJ6Q0;6a/@2n_[h0`l?3
0;bl_033`l<00P37alL01P39bLT0b<S80<c<c03=cLd0dM7A0<k>cP80clo?00L0cLg=0<o?c`3>c/h0
c<c<0<K6aP33`l<0`L7100<0alO70P38b<P02@3:b/X0bLW90<K6aP37alL0bLW90<K6aP35aLD0a/K6
0<G5a@020<S8b0030<c<c03;bl/0c<c<00<0c<c<02L0cLg=0<c<c03>c/h0cLg=0<o?c`3>c/h0`<30
0:n_[`2XZ:P0ZZZZ0:JVYP2YZJT0/k>c0;^k^`31`L40_kno0<c<c03@d=00c/k>0<g=c@3<c<`0d];B
0=CDe03Jf]X0fm_K0=KFeP3IfMT0c<c<06e]K@0c<c<0;bl_02<S8`0V9RH0;2`/02TY:@0X:2P0:RXZ
02PX:00Z:RX00P0`<3004`0c<c<0<C4a03@d=00c<c<0?clo04Q8B00h>3P0;2`/02XZ:P0/;2`0<C4a
02h^;P0c<c<0=SHf03/k>`0`<300?Cdm038b<P0h>3P00P0[:b/02`0U9BD0<30`0410@01GEeL0LG5a
0861P@2=SHd0U9BD09^KV`2MWId0VYZJ0080TY:B00P0Shn?096AT@2CTi<0UiNG09fMW@2KVi/0WinO
0:>SX`80XJ6Q0P2PX:00802OWil0XZ:R0:6QX@2SXj<0WinO09fMW@2RXZ80Xj>S0:6QX@2OWil0XJ6Q
09nOW`2RXZ80WinO09jNWP2PX:00VYZJ09jNWP2PX:00WinO09fMW@2OWil0Vi^K0:6QX@2NWYh0X:2P
09nOW`2LW9`0Vi^K09jNWP2MWId0WYjN0P2KVi/01P2MWId0WinO09jNWP2RXZ80XJ6Q09ZJVPh0b>3H
000<0<SPf080IVIV00H0HV9R061PH01RHV80GemO069RHP1YJFT206IVIP0L065QH@1VIVH0GUiN061P
H01RHV80HF5Q061PH01QHF40GUiN061PH01QHF40IVIV061PH01SHf<0IFEU06][J`1bLW80M7Ad07al
O020P800QhN709NGU`2BTY80V9RH09ZJVP2MWId0Xj>S0:^[Z`80ZZZZ00T0Zj^[0:j^[P2_[jl0[jn_
0;6a/@2][Jd0[jn_0;2`/02/[:`00P2^[Zh0=02b/[80[:b/0:ZZZP2XZ:P0Y:BT0:6QX@2FUYH0U9BD
08f=S@24Q8@0Ng]k07=cL`1_Kfl0IfMW05YJFP1ADE40CTi>04U9B@1:BTX0C4a<059BDP1FEUH0E5AD
05IFEP1NGUh0FEUI069RHP1KFe/0GemO065QH@1PH600I6AT06IVIP1OGel0IFEU06=SH`1TI6@0H61P
05eMG@1QHF40Hf=S065QH@1UIFD0HV9R06MWI`1OGel0HV9R06EUI@1TI6@0GemO05aLG01TI6@206IV
IP0606MWI`1VIVH0IVIV06YZJP1WIfL0KVi^0P1WIfL0401SHf<0IfMW06UYJ@1UIFD0G5aL05]KF`1O
Gel0OWin0=7Ad@3Hf=P0d];B0<S8b02b/[80`L710;Jf]P2MWId209>CT`0H09jNWP2;Rh/0SHf=09:B
TP28R8P0QhN708B4Q01kNg/0OWin07YjNP1bLW80M7Ad075aL@1cLg<0NGUi06MWI`1XJ6P0Jf][06i^
KP1`L700HF5Q06MWI`1_Kfl0Jf][0P1]KFd03@1QHF40E5AD06MWI`1eMGD0MWIf07YjNP1aLG40L71`
07emO@1lO7`0P82007UiN@1bLW800P1cLg<01@1[Jf/0MgMg08>3P`29RHT0SHf=0080S8b<00@0UIFE
09bLW02CTi<0T92@0P2BTY807P25QHD0OGem08b<S02>SXh0VIVI0::RXP2HV9P0MgMg07]kN`21PH40
RXZ:09:BTP2HV9P0W9bL09FEU@2HV9P0VIVI09>CT`2IVIT0V9RH09fMW@2RXZ80WinO09:BTP24Q8@0
QhN708V9R@2IVIT0WYjN09RHV080U9BD02h0V9RH0:VYZ@2a/K40/k>c0;Fe]@2`/;00[Jf]0:RXZ02Z
ZZX0/K6a0:NWY`2MWId0UiNG09>CT`2HV9P0UiNG09fMW@2WYjL0]kNg0;6a/@2f][H0/k>c0:VYZ@2Q
XJ40Y:BT0::RXP2XZ:P0];Bd0:n_[`2VYZH0ZZZZ0:n_[`2/[:`0[Zj^0;6a/@2h^;P0/k>c0:f][@2V
YZH0YJFU0:VYZ@2d];@0/k>c0:f][@2^[Zh0[:b/0P2^[Zh0402ZZZX0ZJVY0;:b/P2_[jl0[:b/0:BT
Y02[Zj/0[Jf]0;6a/@2c/k<0[Jf]0;:b/P2g]kL0_;bl0;no_`2m_Kd20;Zj^P0B0;Rh^02a/K40[Jf]
0;Jf]P2h^;P0];Bd0;:b/P2[Zj/0/;2`0;Bd]02i^KT0^k^k0;Rh^02j^[X0_kno0<?3``30`<00_kno
0`2i^KT01P2h^;P0^k^k0;bl_02j^[X0]KFe0;:b/P80^KVi02T0]kNg0;2`/02YZJT0Y:BT0:ZZZP2e
]KD0Zj^[0:j^[P2b/[80^;Rh0;Vi^@2h^;P0]kNg0;Zj^P2i^KT0];Bd0:JVYP2a/K40];Bd0:JVYP2Y
ZJT0/K6a0:RXZ02QXJ40V9RH0:BTY02VYZH0/;2`0;Zj^P37alL0clo?0=3@d03<c<`0_kno0;>c/`2/
[:`0/[:b0;>c/`2l_;`0_[jn0<O7a`020<K6aP80a<C400D0b<S80<k>cP3@d=00d=3@0=7Ad@020=3@
d080c/k>00D0cLg=0<W9b@31`L40_[jn0<C4a0020<S8b0040<[:bP38b<P0a/K60<S8b080bLW900T0
alO70<;2`P32`/80a/K60<S8b037alL0b/[:0<_;b`3<c<`00`3:b/X04P3;bl/0c<c<0<g=c@3<c<`0
clo?0=3@d03=cLd0_[jn0;6a/@2e]KD0Zj^[0:b/[02i^KT0`<300<S8b031`L40cLg=0<k>cP80clo?
00D0c/k>0=?Cd`3GemL0f=SH0=[JfP020=SHf0070=KFeP2CTi<0=SHf02l_;`0S8b<09BDU02/[:`02
02d];@0_02TY:@0f=SH0;Rh^02h^;P0l?3`0=CDe02l_;`0g=cL0>3Ph03/k>`0f=SH0<S8b03@d=00/
;2`0<C4a02l_;`0/;2`0;bl_02/[:`0i>CT0=3@d03dm?@0h>3P0=CDe02h^;P0Z:RX09bLW03@d=00k
>c/0Bd];065QH@1gMgL0QXJ6096AT@2GUiL0V9RH09JFUP2HV9P0TY:B09BDU02CTi<0Shn?09>CT`2E
UID0VIVI09^KV`2NWYh00P2PX:00402RXZ80XJ6Q0:BTY02SXj<0WinO0:6QX@2LW9`0XZ:R0:>SX`2Q
XJ40Vi^K09jNWP2PX:00XZ:R0:FUY@2MWId209bLW00409jNWP2MWId0WIfM0::RXP80WinO00D0XJ6Q
09nOW`2JVYX0WIfM09jNWP0209fMW@0509jNWP2MWId0WIfM09^KV`2LW9`00P2MWId0102NWYh0X:2P
09^KV`2LW9`>0<SPf0003038h=P206YZJP0:06MWI`1PH600GemO069RHP1PH600IFEU065QH@1TI6@0
Hf=S06EUI@80HF5Q00<0HV9R065QH@1QHF400`1QHF401P1SHf<0H61P06=SH`1UIFD0JVYZ06EUI@80
LG5a00D0O7al07inOP28R8P0SHf=09>CT`0209^KV`80XJ6Q00<0ZJVY0:b/[02][Jd00P2/[:`20:n_
[`040:j^[P2`/;00/;2`0:f][@80[:b/0200Zj^[0;2`/02][Jd0[:b/0:RXZ02WYjL0WinO09VIV@2F
UYH0Rh^;08J6QP1oOgl0MGEe06m_K`1SHf<0FEUI055AD@1:BTX0AdM704e=C@1;Bd/0CTi>04a<C01G
EeL0Fe]K05aLG01GEeL0FUYJ05mOG`1RHV80Hf=S05eMG@80IVIV00<0I6AT05mOG`1NGUh00P1TI6@0
2P1OGel0IFEU06ATI01NGUh0HV9R06=SH`1TI6@0IFEU069RHP1SHf<205mOG`0506QXJ01PH600IVIV
06EUI@1QHF400P1UIFD05@1]KFd0L71`06][J`1WIfL0JVYZ06EUI@1VIVH0Jf][065QH@1MGEd0F5QH
05iNGP1kNg/0eMGE0=[JfP3De=@0cLg=0;^k^`2c/k<0`l?30;Rh^002092@T0060:6QX@2DU9@0Ti>C
08:2PP2:RXX0Ph>30P1hN7P03026QXH0Ph>307QhN01cLg<0K6a/071`L01_Kfl0Jf][06e]K@1WIfL0
J6QX06i^KP80Jf][00/0J6QX06m_K`1bLW80Ng]k06i^KP1XJ6P0Hf=S06YZJP1bLW80NWYj07UiN@02
07AdM080NWYj00X0Ogmo0820P01jNWX0NWYj07AdM01YJFT0L71`0861P@2=SHd0TY:B0`2DU9@04`2C
Ti<0VIVI09JFUP2=SHd0PH6108J6QP28R8P0Shn?08j>SP2MWId0Z:RX08R8R01jNWX0QHF50861P@28
R8P0Ti>C09bLW02FUYH00P2@T9000`2DU9@0Ti>C092@T00209RHV0080:RXZ02JVYX0P82008F5Q@2G
UiL0X:2P09ZJVP2CTi<209:BTP0L09VIV@2[Zj/0YjNW0:b/[02][Jd0Zj^[0;2`/02][Jd0/k>c0:NW
Y`2UYJD0WYjN0:2PX02XZ:P0Zj^[0:2PX02FUYH0V9RH0:JVYP2c/k<0/[:b0:b/[02SXj<0YJFU0;6a
/@2c/k<0[jn_0:ZZZP80ZJVY00H0Zj^[0:b/[02`/;00/K6a0;:b/P2c/k<30:NWY`0=0:>SX`2d];@0
^KVi0:j^[P2`/;00[:b/0:j^[P2`/;00/K6a0:VYZ@2VYZH0Zj^[0:j^[P020:ZZZP0:0;Zj^P2d];@0
[Jf]0:b/[02^[Zh0/K6a0;Vi^@30`<00_;bl0;Vi^@80];Bd0180[jn_0;6a/@2a/K40^KVi0;Zj^P2_
[jl0ZJVY0;:b/P2g]kL0]KFe0;Rh^02j^[X0]kNg0;bl_031`L40`/;20;jn_P2k^k/20;bl_00B0;Jf
]P2j^[X0_kno0<71`@2k^k/0^KVi0;Rh^02e]KD0];Bd0;6a/@2/[:`0/[:b0;Bd]02a/K40ZZZZ0:VY
Z@2][Jd0/[:b0P2h^;P03`2i^KT0^[Zj0;Rh^02l_;`0[Zj^0:^[Z`2e]KD0/k>c0:b/[02b/[80/k>c
0:f][@2UYJD0XZ:R0:NWY`020:>SX`0F0:^[Z`2k^k/0`<300<O7a`3AdM40c<c<0<?3``2n_[h0]KFe
0:j^[P2UYJD0ZJVY0;Vi^@33`l<0a/K60<S8b031`L40aLG50<K6aP3<c<`0dM7A0=;BdP80e=CD0P3A
dM401`3@d=00c/k>0<S8b02m_Kd0_kno0<K6aP37alL00P38b<P03@37alL0b<S80<S8b03:b/X0b<S8
0<K6aP34a<@0a/K60<G5a@34a<@0bLW90<c<c039bLT00P38b<P00`39bLT0c/k>0<g=c@020<_;b`0C
0<g=c@3<c<`0dM7A0<_;b`2j^[X0]kNg0;2`/02d];@0^KVi0<?3``37alL0b/[:0<k>cP3?cll0d];B
0=7Ad@3Cdm<0e=CD0=OGe`020=[JfP80f=SH01X0f][J0;Jf]P12@T80:BTY02DU9@0P82009RHV02`/
;00_;bl0<30`02TY:@0[:b/0<C4a02h^;P0b<S80;Bd]034a<@0c<c<0=cLg034a<@0f=SH0;Bd]02LW
9`0Y:BT0;Rh^02d];@80;2`/0140=3@d03Xj>P0g=cL0=CDe03Hf=P0[:b/0=3@d02PX:00_;bl0?3`l
055AD@1LG5`0KVi^07alO02@T900Ti>C09^KV`0209RHV00909JFUP2ATI40TI6A092@T02>SXh0TY:B
09FEU@2IVIT0WYjN0080X:2P00X0WYjN0:2PX02QXJ40WinO09jNWP2QXJ40WIfM0:2PX02QXJ40WIfM
0P2PX:000`2QXJ40WinO0:6QX@0309jNWP0509fMW@2QXJ40WinO0::RXP2MWId00P2NWYh02@2MWId0
WinO09jNWP2KVi/0WYjN0:2PX02OWil0WIfM09VIV@0209^KV`0609bLW02OWil0WIfM09nOW`2KVi/0
WIfM3P38h=P000`0b>3H0P1ZJVX04@1TI6@0H61P06EUI@1SHf<0HV9R06ATI01SHf<0GemO05QHF01O
Gel0HV9R05mOG`1XJ6P0GemO06EUI@1QHF40I6AT0080IVIV00h0IfMW06=SH`1UIFD0JFUY06][J`1^
KVh0MGEe07YjNP20P800RXZ:08j>SP2ATI40Vi^K09VIV@80Xj>S00D0YJFU0:RXZ02[Zj/0[jn_0:^[
Z`020:f][@040:j^[P2_[jl0/[:b0:n_[`80[Jf]02P0[:b/0:f][@2ZZZX0Zj^[0:RXZ02VYZH0X:2P
09ZJVP2DU9@0SHf=08F5Q@1kNg/0LW9b07=cL`1PH600Fe]K05=CD`1BDU80BTY:04M7A`1;Bd/0De=C
04m?C`1DE5@0EeMG05]KF`1JFUX0H61P069RHP1KFe/0GEeM05iNGP1SHf<0GemO05iNGP1RHV80IFEU
069RHP1TI6@0GUiN0P1TI6@2065QH@0C061PH01UIFD0Hf=S06ATI01SHf<0HF5Q069RHP1PH600JVYZ
05mOG`1XJ6P0Hf=S06MWI`1TI6@0Jf][06e]K@1[Jf/0J6QX06UYJ@0206EUI@0>06MWI`1QHF40Fe]K
05YJFP1PH600MWIf0<k>cP3QhN40dm?C0<[:bP37alL0[:b/0;Fe]@2l_;`209ZJVP0A08f=S@2CTi<0
Vi^K07inOP1mOGd0QHF507alO01_Kfl0Ng]k08F5Q@1dM7@0Jf][06i^KP1YJFT0HV9R06QXJ01bLW80
0P1SHf<0201[Jf/0KVi^06YZJP1eMGD0K6a/071`L01bLW80MGEe0P1aLG40<01/K6`0Lg=c07alO01j
NWX0QHF507MgM`1iNGT0NWYj07inOP1oOgl0P82007]kN`1jNWX0KVi^06IVIP1cLg<0PH6109BDU02@
T900Shn?096AT@2GUiL0Vi^K08n?S`28R8P0SHf=08R8R024Q8@0Rh^;08b<S02@T900WYjN09RHV02:
RXX0Ng]k07QhN01kNg/0RHV909:BTP2=SHd0SXj>09BDU02EUID0T92@09>CT`2HV9P0W9bL09jNWP80
TY:B0P2SXj<00`2JVYX0UYJF09BDU00209JFUP0C09bLW02SXj<0WYjN0:JVYP2TY:@0Z:RX0;2`/02c
/k<0ZZZZ09jNWP2UYJD0Zj^[0:j^[P2c/k<0[Jf]0:ZZZP2QXJ40T92@09JFUP020:FUY@0Y0:NWY`2T
Y:@0/[:b0;bl_02e]KD0][Jf0:ZZZP2YZJT0YJFU0:RXZ02b/[80/;2`0;>c/`2d];@0ZZZZ0:RXZ02T
Y:@0[Jf]0;>c/`2a/K40[Zj^0:n_[`2b/[80[jn_0:j^[P2UYJD0[:b/0:RXZ02VYZH0YJFU0:VYZ@2d
];@0^;Rh0;^k^`2c/k<0[Zj^0:f][@2`/;00]kNg0;Rh^02f][H00`2e]KD0202f][H0/[:b0;Fe]@2g
]kL0_;bl0;fm_@2b/[80/;2`0P2b/[802@2c/k<0^KVi0;fm_@2m_Kd0_kno0<G5a@32`/80_;bl0;Ng
]`020;Rh^0080;fm_@2o_kl0_kno0;jn_P2m_Kd0_kno0;Zj^P2f][H20;6a/@0;0;Ng]`2l_;`0]kNg
0:b/[02WYjL0[jn_0;:b/P2`/;00^[Zj0;^k^`2l_;`00P2i^KT02@2d];@0[Zj^0;Rh^02g]kL0][Jf
0;2`/02h^;P0^[Zj0;6a/@020:VYZ@040:BTY02UYJD0Z:RX0;6a/@80/k>c00<0^[Zj0<C4a032`/80
0P3=cLd02P38b<P0`l?30;>c/`2YZJT0Zj^[0;^k^`37alL0bLW90<?3``32`/820<?3``030<[:bP3?
cll0d];B0080dm?C00L0d];B0=7Ad@3<c<`0bl_;0<G5a@32`/80aLG500<0bLW91@38b<P01P35aLD0
a/K60<O7a`37alL0`l?30<O7a`80b/[:0P3;bl/01`39bLT0clo?0<c<c039bLT0cLg=0<[:bP3=cLd0
0P3>c/h02P35aLD0_Kfm0;Ng]`2l_;`0_[jn0<G5a@3;bl/0c<c<0<o?c`3Cdm<20=7Ad@80e=CD00@0
g]kN0=cLg03Kfm/0gMgM0P3IfMT0203;bl/0JFUY02TY:@0X:2P09RHV02@T900b<S80:b/[0P0^;Rh0
400e=CD0<30`02h^;P0/;2`0=3@d03De=@0d=3@0;bl_02h^;P0/;2`0;Rh^02XZ:P0`<3009bLW03hn
?P0a<C42030`<00E03Lg=`0h>3P0?Shn03Lg=`0c<c<0>SXj02h^;P0f=SH0>SXj051@D01>CTh0JFUY
07EeM@28R8P0T92@09BDU02LW9`0VIVI09RHV02@T900U9BD0080SHf=00@0TY:B09JFUP2LW9`0WIfM
0P2OWil01`2PX:00WYjN0:>SX`2QXJ40X:2P09nOW`2NWYh00P2PX:00202OWil0X:2P0:2PX02MWId0
WinO09jNWP2KVi/0WinO0P2LW9`03`2OWil0WIfM09nOW`2LW9`0XJ6Q09bLW02JVYX0WYjN09bLW02N
WYh0Vi^K09nOW`2JVYX0VIVI09bLW00209^KV`0609bLW02HV9P0Vi^K09fMW@2IVIT0VYZJ3P38h=P0
00`0b>3H0P1SHf<04`1TI6@0GemO061PH01SHf<0IVIV069RHP1ZJVX0JFUY05iNGP1TI6@0IfMW05iN
GP1UIFD0H61P06MWI`1UIFD0HF5Q06ATI01SHf<00P1WIfL03`1TI6@0IVIV06a/K01fMWH0LW9b07mo
O`20P800QhN708n?S`2CTi<0VIVI09nOW`2QXJ40Z:RX0:JVYP020:ZZZP0W0:^[Z`2YZJT0/;2`0;2`
/02/[:`0[jn_0;2`/02_[jl0[Jf]0:j^[P2_[jl0/;2`0:b/[02[Zj/0Z:RX0:FUY@2NWYh0W9bL09JF
UP2@T900QXJ607QhN01aLG40M7Ad06ATI01FEUH0EeMG04i>CP19BDT0Cdm?04a<C01?Cdl0D51@05=C
D`1IFET0G5aL05eMG@1LG5`0H61P00<0GemO01L0H61P05iNGP1SHf<0H61P069RHP1YJFT0Jf][06IV
IP1XJ6P0HV9R06ATI01RHV80HF5Q05iNGP1VIVH0HV9R061PH01RHV80I6AT069RHP1VIVH0I6AT05mO
G`0206=SH`0F069RHP1ZJVX0Jf][06YZJP1WIfL0I6AT06IVIP1WIfL0IFEU069RHP1QHF40G5aL05eM
G@1dM7@0aLG50=oOg`3De=@0c/k>0<[:bP2f][H0YjNW0:j^[P80W9bL00D0Ti>C08j>SP2IVIT0RXZ:
079bLP0207]kN`0@06m_K`1ZJVX0MWIf06m_K`1/K6`0KFe]06IVIP1YJFT0Hf=S06IVIP1YJFT0IVIV
06i^KP1]KFd0K6a/071`L080K6a/02h0Kfm_07AdM01kNg/0OGem07QhN01gMgL0MGEe07alO023Ph<0
PH6107inOP1fMWH0OGem0861P@27QhL0OWin07QhN01^KVh0JVYZ061PH01_Kfl0SHf=09BDU02CTi<0
Vi^K09RHV02EUID0SXj>092@T02IVIT0SXj>092@T02=SHd0T92@08b<S02CTi<0W9bL09FEU@2;Rh/0
Ng]k07MgM`1fMWH0Q8B408b<S02GUiL0UYJF0P2BTY802`2EUID0XZ:R09NGU`2CTi<0V9RH0:JVYP2_
[jl0YJFU09>CT`2>SXh0UYJF0080W9bL01X0VYZJ09^KV`2PX:00YJFU0:BTY02XZ:P0[Jf]0:RXZ02V
YZH0ZZZZ0;>c/`2f][H0^KVi0;Fe]@2g]kL0ZZZZ0::RXP2IVIT0VYZJ08n?S`2NWYh0Y:BT0:^[Z`2e
]KD0_kno0:f][@80/[:b01P0YjNW0:FUY@2][Jd0/[:b0:j^[P2[Zj/0ZZZZ0::RXP2][Jd0[Zj^0;Vi
^@2a/K40ZJVY0:j^[P2`/;00/K6a0:f][@2VYZH0[Jf]0:^[Z`2/[:`0Y:BT0:^[Z`2d];@20;Rh^00N
0;Bd]02f][H0_kno0;no_`2f][H0/;2`0;6a/@2`/;00];Bd0;Vi^@2h^;P0^KVi0;Zj^P2i^KT0/k>c
0;Vi^@2m_Kd0^;Rh0;Bd]02c/k<0/;2`0;Vi^@2m_Kd0_[jn0;Zj^P2n_[h0`<300;no_`2j^[X0^KVi
0P2l_;`08P32`/80_kno0;fm_@2l_;`0`<300<71`@2k^k/0^KVi0;fm_@2o_kl0][Jf0;Fe]@2a/K40
Zj^[0;:b/P2`/;00/[:b0;Rh^02k^k/0^KVi0;Rh^02l_;`0^[Zj0:j^[P2f][H0_Kfm0;Jf]P2c/k<0
^[Zj0;Rh^02g]kL0]KFe0;Bd]02ZZZX20:RXZ00A0;2`/02h^;P0][Jf0:n_[`2i^KT0^;Rh0;Zj^P2o
_kl0b/[:0<O7a`39bLT0alO70<C4a032`/80^[Zj0<;2`P31`L400P34a<@01P32`/80`L710<K6aP3;
bl/0c<c<0<o?c`80e=CD0P3AdM401P3;bl/0c<c<0<W9b@38b<P0bLW90<K6aP80b/[:0P39bLT00`38
b<P0b/[:0<W9b@030<K6aP80alO700P0bLW90<_;b`3<c<`0c<c<0<[:bP3=cLd0b/[:0<_;b`80c<c<
0P3=cLd02`3>c/h0cLg=0<K6aP2m_Kd0_kno0<30`035aLD0b/[:0<c<c03>c/h0dM7A0080d];B00D0
dm?C0=OGe`3Kfm/0fm_K0=cLg0020=kNgP040=gMg@3EeMD0S8b<02LW9`8092@T00L09bLW02XZ:P0Z
:RX0:RXZ038b<P0e=CD0<30`00<0;Bd]00P0=cLg034a<@0e=CD0;bl_02h^;P0`<300:b/[02TY:@<0
:b/[00H0;bl_03@d=00`<300<S8b03`l?00a<C4203Hf=P0E034a<@0b<S80>3Ph03hn?P18B4P0G5aL
06QXJ01fMWH0RHV9096AT@2IVIT0V9RH09NGU`2JVYX0UYJF096AT@2CTi<0T92@09>CT`2FUYH0VIVI
00<0WYjN00D0WinO0:6QX@2RXZ80XJ6Q0:JVYP020::RXP090:2PX02NWYh0X:2P09jNWP2MWId0WYjN
09bLW02OWil0X:2P00<0W9bL00/0WYjN09fMW@2LW9`0WinO09jNWP2KVi/0W9bL09jNWP2LW9`0Vi^K
09fMW@0209^KV`0909bLW02IVIT0Vi^K09NGU`2MWId0W9bL09fMW@2LW9`0WIfM00h0b>3H000<0<SP
f080I6AT00T0HF5Q06EUI@1TI6@0IFEU06=SH`1WIfL0J6QX065QH@1UIFD00`1QHF40101UIFD0GemO
06a/K01UIFD206=SH`0E069RHP1OGel0IFEU06MWI`1XJ6P0KVi^07AdM01eMGD0PH6108>3P`28R8P0
Shn?09FEU@2OWil0Vi^K09jNWP2QXJ40ZZZZ0:JVYP2/[:`0[Jf]00@0[:b/00D0/;2`0:n_[`2c/k<0
[Zj^0:f][@020:n_[`0K0:^[Z`2XZ:P0Zj^[0:>SX`2OWil0VIVI09>CT`2ATI40QhN707inOP1eMGD0
LG5a069RHP1HF5P0DU9B04a<C01=CDd0D51@04a<C01CDe<0Cdm?05QHF01IFET0GEeM05YJFP1MGEd0
GemO0080HF5Q00H0FEUI05iNGP1UIFD0Hf=S06MWI`1TI6@206MWI`80H61P00D0I6AT065QH@1TI6@0
HV9R06ATI00205mOG`0706ATI01UIFD0IfMW05mOG`1NGUh0IVIV069RHP02065QH@0:06ATI01ZJVX0
IVIV06a/K01cLg<0IfMW06][J`1WIfL0IFEU065QH@80GUiN00X0FUYJ06a/K02m_Kd0fm_K0=OGe`3A
dM40`<300;Fe]@2g]kL0WYjN0P2OWil04P2DU9@0S8b<08V9R@21PH40MgMg071`L01]KFd0KVi^06AT
I01VIVH0JVYZ07=cL`1bLW80KFe]06QXJ01^KVh0HV9R06ATI080J6QX02H0K6a/071`L01YJFT0L71`
075aL@1bLW80M7Ad07EeM@1kNg/0NGUi07AdM01bLW80MgMg07=cL`1`L700Ng]k07MgM`1jNWX0OGem
08F5Q@1lO7`0NWYj07EeM@1[Jf/0JVYZ06IVIP1fMWH0S8b<09FEU@2JVYX0U9BD08f=S@2@T900UiNG
09VIV@2FUYH0UiNG092@T080SHf=00d0Shn?08j>SP2CTi<0WYjN08F5Q@1iNGT0MgMg07IfMP2;Rh/0
Ti>C08n?S`2CTi<0UiNG0080VYZJ00H0UIFE08n?S`2KVi/0ZZZZ0;Bd]02ZZZX209VIV@0`09>CT`2Q
XJ40XJ6Q0:2PX02RXZ80XJ6Q09jNWP2QXJ40Z:RX0:6QX@2RXZ80[jn_0;Rh^02i^KT0^;Rh0;Bd]02l
_;`0]kNg0:6QX@2PX:00Xj>S0:NWY`2PX:00UIFE09VIV@2/[:`0]kNg0;6a/@2f][H0/K6a0:VYZ@2/
[:`0/K6a0;>c/`2`/;00[Jf]0:NWY`2VYZH0YJFU0;Bd]02i^KT0/K6a0:f][@2_[jl0[:b/0;>c/`2b
/[80[:b/0P2YZJT05P2XZ:P0YZJV0;2`/02h^;P0]kNg0;2`/02_[jl0/[:b0<;2`P36a/H0aLG50;Zj
^P2i^KT0/K6a0:b/[02a/K40][Jf0;Ng]`2h^;P0]kNg0;>c/`2e]KD20;Jf]P080;>c/`2a/K40^KVi
0<71`@2l_;`0`<300;bl_030`<020;^k^`030;Vi^@2j^[X0^k^k0080^k^k00@0`l?30<71`@2n_[h0
`L710P2k^k/03`2j^[X0`L710<30`030`<00^[Zj0;2`/02b/[80]KFe0;Rh^02e]KD0][Jf0;Rh^02i
^KT0]kNg0;Vi^@020;Zj^P050;Jf]P2l_;`0^k^k0;Bd]02e]KD00P2k^k/01P2a/K40/[:b0;Fe]@2]
[Jd0[Zj^0;6a/@80]kNg00<0];Bd0:n_[`2k^k/00P2i^KT06@2j^[X0`L710<K6aP34a<@0bLW90<k>
cP3=cLd0alO70<;2`P2h^;P0_;bl0<O7a`33`l<0`<300<71`@38b<P0alO70<S8b03;bl/0dM7A0=CD
e03?cll0cLg=0<_;b`38b<P00P3<c<`03`3:b/X0bl_;0<[:bP3:b/X0alO70<K6aP39bLT0b<S80<K6
aP37alL0`/;20<G5a@39bLT0b/[:0<W9b@020<[:bP80bLW900@0c/k>0<_;b`3<c<`0clo?0P3;bl/0
2@3>c/h0cLg=0<[:bP33`l<0`/;20<30`037alL0b<S80<o?c`040=7Ad@0E0=;BdP3De=@0fm_K0=cL
g03MgMd0g]kN0>3Ph03Ogml0fm_K0:VYZ@0d=3@0:2PX02`/;00U9BD0:b/[030`<00Z:RX0;2`/03@d
=00g=cL0<C4a0080;2`/0140<S8b03Ti>@0b<S80<C4a03Hf=P0_;bl0=CDe02h^;P0W9bL0;Rh^02TY
:@0/;2`0=cLg03<c<`0k>c/0<c<c02l_;`0203/k>`0<03dm?@12@T80?3`l0451@@1:BTX0E5AD05aL
G01`L700OWin08f=S@2DU9@0W9bL0P2HV9P01`2CTi<0U9BD096AT@2@T900Ti>C09JFUP2KVi/00P2J
VYX0102QXJ40X:2P09nOW`2PX:0209nOW`80XZ:R00X0WIfM09jNWP2OWil0X:2P0::RXP2QXJ40WinO
0:2PX02NWYh0Vi^K0`2MWId01@2OWil0W9bL09bLW02NWYh0X:2P0080Vi^K00h0W9bL09VIV@2NWYh0
VIVI09ZJVP2MWId0VYZJ09^KV`2GUiL0WIfM09bLW02PX:00WYjN09^KV`h0b>3H000<0<SPf080HV9R
00D0Hf=S065QH@1WIfL0HV9R06EUI@0206YZJP0H06UYJ@1SHf<0HF5Q05iNGP1MGEd0Hf=S06EUI@1Q
HF40HV9R061PH01QHF40IVIV069RHP1QHF40J6QX06IVIP1/K6`0Kfm_07YjNP21PH40PX:208^;R`2=
SHd0Ti>C0P2JVYX01`2OWil0XJ6Q0:>SX`2VYZH0ZJVY0:^[Z`2_[jl00P2/[:`0:`2][Jd0[Zj^0:f]
[@2^[Zh0ZZZZ0:n_[`2[Zj/0[Jf]0:j^[P2/[:`0ZZZZ0:BTY02PX:00WIfM09>CT`2@T900QHF507em
O@1eMGD0KVi^06QXJ01KFe/0E5AD051@D01:BTX0AdM704];B`1>CTh0Cdm?05ADE01EEED0E5AD05eM
G@1JFUX0GEeM05aLG01RHV80GUiN06=SH`1RHV80HF5Q069RHP1PH6000P1VIVH01@1WIfL0HF5Q06AT
I01UIFD0H61P0080HV9R01X0I6AT069RHP1SHf<0HF5Q06MWI`1VIVH0HV9R06=SH`1TI6@0Jf][06MW
I`1YJFT0IVIV06UYJ@1WIfL0JVYZ06UYJ@1XJ6P0JVYZ06EUI@1VIVH0HV9R05MGE`1IFET0I6AT0:JV
YP80fm_K00D0d=3@0<K6aP2d];@0]KFe0:NWY`0209JFUP0X08n?S`2=SHd0Ph>30820P01jNWX0M7Ad
06YZJP1aLG40IFEU06ATI01ZJVX0KVi^06UYJ@1_Kfl0Jf][06a/K01UIFD0H61P06=SH`1/K6`0KVi^
06][J`1`L700K6a/075aL@1eMGD0LW9b07AdM01cLg<0L71`07=cL`1kNg/0N7Qh07EeM@1_Kfl0K6a/
07QhN01mOGd0Ng]k08F5Q@80Ogmo01T0OWin07UiN@1cLg<0KFe]06YZJP1gMgL0RHV909VIV@2ATI40
SHf=09BDU02EUID0UiNG09FEU@2MWId0UYJF096AT@2@T900R8R808J6QP2<S8`0SXj>09:BTP2KVi/0
VYZJ0080Ng]k00P0OWin09>CT`2FUYH0WYjN09JFUP2ATI40T92@09jNWP80Xj>S00D0YjNW0:6QX@2X
Z:P0YjNW0:2PX00209ZJVP0;0:FUY@2WYjL0XJ6Q09^KV`2PX:00V9RH09jNWP2[Zj/0/;2`0;6a/@2g
]kL00P2b/[80102f][H0ZZZZ09nOW`2PX:020;2`/00=0:n_[`2LW9`0TY:B09nOW`2RXZ80[:b/0;>c
/`2^[Zh0/K6a0;:b/P2f][H0[jn_0:FUY@020:JVYP0F0:f][@2i^KT0]KFe0;>c/`2b/[80];Bd0:b/
[02][Jd0/;2`0:f][@2`/;00[jn_0:j^[P2TY:@0ZJVY0;Vi^@2g]kL0/k>c0:^[Z`2][Jd0_Kfm0<;2
`P80`L7100P0_kno0<G5a@30`<00^KVi0;6a/@2/[:`0/;2`0:n_[`80/k>c0100[Zj^0;2`/02c/k<0
];Bd0;Jf]P2n_[h0`<300;jn_P30`<00_Kfm0<30`02i^KT0]KFe0;Zj^P2m_Kd0_;bl0P30`<00A02o
_kl0`<300<;2`P34a<@0^k^k0;Ng]`34a<@0`L710<30`02m_Kd0^k^k0;Jf]P2i^KT0^k^k0;bl_02i
^KT0/[:b0;Fe]@2g]kL0^KVi0;Zj^P2l_;`0_[jn0;Zj^P2m_Kd0^[Zj0;6a/@2j^[X0_[jn0;fm_@2f
][H0^KVi0;Rh^02`/;00/k>c0;no_`2m_Kd0]kNg0;Rh^02k^k/0_[jn0;Zj^P2m_Kd0`/;20<K6aP2m
_Kd0_kno0<K6aP3<c<`0clo?0=7Ad@39bLT0a/K60;Vi^@2l_;`0_[jn0<C4a032`/80^KVi0;jn_P33
`l<0alO70<[:bP3@d=00dM7A0=;BdP3=cLd0c<c<0P3=cLd00`3>c/h0cLg=0<_;b`020<W9b@060<[:
bP3;bl/0b/[:0<S8b03;bl/0`/;20P35aLD20<S8b080alO700@0bLW90<c<c03>c/h0cLg=0P3>c/h0
3P3<c<`0b/[:0<g=c@3<c<`0dM7A0<O7a`33`l<0`/;20<?3``34a<@0c/k>0=CDe03Bd]80e=CD0P3C
dm<0303EeMD0gMgM0=kNgP3Ng]h0fm_K0>3Ph03QhN40g]kN0<?3``1;Bd/09BDU02@T9080;2`/02L0
:BTY02PX:00b<S80;Bd]02LW9`0];Bd0<C4a038b<P0g=cL0AdM703Lg=`0o?cl0>3Ph02l_;`0b<S80
<c<c02TY:@0X:2P0:BTY03@d=00`<300;Bd]02/[:`0];Bd0<C4a03Lg=`0b<S80>3Ph0492@P0o?cl0
ADE504i>CP19BDT0F5QH06a/K01hN7P0Q8B4096AT@2FUYH00P2IVIT00`2EUID0Ti>C096AT@0208n?
S`0609>CT`2HV9P0Vi^K09^KV`2MWId0W9bL0P2PX:003@2QXJ40Xj>S0::RXP2QXJ40XZ:R0:>SX`2O
Wil0XZ:R09fMW@2LW9`0X:2P09nOW`2NWYh00P2LW9`209nOW`0309jNWP2KVi/0WYjN0080WYjN00<0
WIfM09^KV`2IVIT00P2MWId01P2LW9`0WIfM09^KV`2GUiL0WIfM09JFUP80VYZJ0P2MWId00`2IVIT0
b>3H0<SPf00<0<SPf0003038h=P206ATI00506MWI`1VIVH0IFEU06IVIP1TI6@00P1SHf<05`1UIFD0
JFUY06ATI01XJ6P0IVIV06MWI`1SHf<0IVIV06EUI@1RHV80Hf=S065QH@1WIfL0HF5Q069RHP1UIFD0
KFe]075aL@1eMGD0NWYj08F5Q@2:RXX0Shn?0080UYJF00P0WIfM0::RXP2RXZ80YjNW0:BTY02VYZH0
Z:RX0:b/[080ZJVY00@0ZZZZ0:j^[P2XZ:P0[Zj^0P2[Zj/06P2][Jd0Zj^[0:j^[P2/[:`0ZZZZ0:JV
YP2TY:@0WIfM08n?S`2CTi<0RHV907alO01cLg<0L71`06IVIP1KFe/0DU9B04Y:BP1=CDd0DU9B04Y:
BP1>CTh0E5AD05IFEP1GEeL0HV9R0P1KFe/03@1IFET0Fe]K05eMG@1PH600I6AT06EUI@1WIfL0IVIV
06EUI@1TI6@0IfMW06=SH`1QHF400P1RHV801`1TI6@0Hf=S06=SH`1RHV80G5aL06ATI01OGel00P1S
Hf<0101VIVH0HV9R06ATI01ZJVX206IVIP0406QXJ01ZJVX0JVYZ06][J`80IfMW00l0J6QX06EUI@1S
Hf<0HF5Q05]KF`1IFET0G5aL09>CT`3Cdm<0eMGE0=?Cd`39bLT0]kNg09jNWP2f][H00P2UYJD03`29
RHT0S8b<08Z:RP1jNWX0P82007MgM`1fMWH0IfMW06EUI@1/K6`0I6AT06=SH`1YJFT0Kfm_06QXJ002
06][J`0406QXJ01VIVH0IfMW06i^KP80MWIf0P1TI6@0401]KFd0NGUi079bLP1/K6`0JFUY06][J`1l
O7`0PH6107YjNP1aLG40Kfm_06e]K@1kNg/0OGem0820P01jNWX208>3P`80OWin00/0Lg=c06][J`1Z
JVX0MGEe08j>SP2=SHd0TI6A092@T02EUID0T92@09VIV@0209RHV00=09VIV@2CTi<0R8R808F5Q@24
Q8@0Rh^;09RHV02RXZ80Y:BT08R8R01dM7@0NGUi08R8R00209FEU@0609>CT`2FUYH0VIVI0:FUY@2Q
XJ40WYjN0P2MWId00`2NWYh0[Jf]0:n_[`0209nOW`0K0:2PX02FUYH0WIfM09VIV@2HV9P0WIfM0:VY
Z@2[Zj/0Z:RX0:n_[`2^[Zh0];Bd0;>c/`2][Jd0Z:RX0:>SX`2][Jd0]KFe0;Jf]P2_[jl0VIVI09BD
U02JVYX0UIFE0:6QX@2XZ:P0/k>c0080^;Rh02P0/;2`0:f][@2WYjL0YZJV0:n_[`2f][H0/K6a0:j^
[P2`/;00/[:b0;Bd]02_[jl0Z:RX0:NWY`2`/;00][Jf0;6a/@2XZ:P0ZJVY0;Fe]@2g]kL0/K6a0:^[
Z`2/[:`0^;Rh0;jn_P2j^[X0]kNg0;^k^`2o_kl0`L710;fm_@2n_[h0`/;20;Jf]P2YZJT0ZZZZ0:j^
[P2`/;00/[:b0P2l_;`0202m_Kd0_;bl0;bl_031`L40_[jn0;Rh^02k^k/0]kNg0P2`/;000`2g]kL0
_Kfm0<30`0020<30`00:0;no_`32`/80a/K60<71`@2k^k/0`/;20<O7a`35aLD0_Kfm0<;2`P80_kno
0P30`<00102k^k/0^KVi0;:b/P2c/k<20;Zj^P070;^k^`2l_;`0^k^k0;^k^`2o_kl0]KFe0;Ng]`02
0;jn_P0E0;bl_02h^;P0^k^k0;Fe]@2b/[80_;bl0<71`@2k^k/0^KVi0;Zj^P2h^;P0^k^k0;Rh^030
`<00a/K60<O7a`2k^k/0YJFU0;6a/@31`L40b<S80080e=CD0240dm?C0<_;b`30`<00/k>c0:j^[P2n
_[h0`<300;Vi^@2a/K40`L710<W9b@3:b/X0d=3@0<k>cP3@d=00clo?0<k>cP3=cLd0c/k>0<c<c03=
cLd0bl_;0<c<c03;bl/0bLW90<O7a`38b<P0b/[:0<O7a`36a/H0b<S80<W9b@3:b/X00P39bLT01@3;
bl/0b/[:0<g=c@3=cLd0c<c<0080clo?00H0c/k>0<g=c@3;bl/0cLg=0<[:bP39bLT30<K6aP0F0<_;
b`3AdM40dm?C0=;BdP3De=@0dm?C0=OGe`3Jf]X0gmoO0>7Qh@3Kfm/0gmoO0>3Ph03Ogml0d=3@06AT
I00Q8B409BDU02XZ:P0];Bd0<C4a030`<080<C4a02T0;Rh^03Lg=`0d=3@0=CDe030`<00d=3@0<30`
03De=@0f=SH0<30`02`/;00Z:RX0;Rh^02/[:`0Z:RX0=3@d02/[:`0d=3@0<30`02l_;`0c<c<0=CDe
03Hf=P0i>CT0@D5103Ti>@0n?Sh0@41004E5A@1;Bd/0GEeM06][J`20P800Shn?09NGU`2FUYH0V9RH
09JFUP2EUID0TI6A09:BTP02096AT@0609BDU02HV9P0V9RH09ZJVP2NWYh0W9bL0`2QXJ400`2PX:00
WinO09jNWP020:2PX080WinO00<0XJ6Q09nOW`2KVi/00P2LW9`03@2OWil0WIfM09^KV`2KVi/0X:2P
09jNWP2MWId0VYZJ09fMW@2GUiL0W9bL09fMW@2JVYX00P2KVi/00`2IVIT0VYZJ09NGU`0209NGU`04
09ZJVP2NWYh0VIVI09RHV0h0b>3H000<0<SPf080I6AT00T0IfMW065QH@1SHf<0Hf=S069RHP1WIfL0
JVYZ065QH@1VIVH00P1QHF402P1SHf<0HV9R065QH@1WIfL0IFEU06ATI01UIFD0I6AT061PH01OGel2
06EUI@0?06QXJ01bLW80NGUi07emO@25QHD0Rh^;08j>SP2DU9@0W9bL09jNWP2OWil0YZJV0::RXP2V
YZH0ZJVY0080ZZZZ0P2YZJT01@2ZZZX0[jn_0:b/[02][Jd0[Zj^0080[:b/00l0];Bd0:b/[02/[:`0
YjNW0:VYZ@2OWil0VYZJ09BDU02;Rh/0R8R808:2PP1bLW80IfMW06=SH`1MGEd00P1BDU805@18B4P0
Cdm?051@D01ADE40EeMG05aLG01^KVh0IfMW05iNGP1HF5P0G5aL05mOG`1RHV80HF5Q06=SH`1UIFD0
HF5Q069RHP1UIFD0HF5Q06IVIP02069RHP0<06IVIP1SHf<0I6AT06=SH`1WIfL0HV9R061PH01SHf<0
IfMW065QH@1VIVH0JVYZ0P1TI6@02@1YJFT0IfMW06a/K01XJ6P0IfMW06][J`1VIVH0JFUY06m_K`02
06YZJP0<06IVIP1QHF40FEUI05iNGP1QHF40Ph>30=;BdP3Hf=P0eMGE0<S8b033`l<0WinO0`2VYZH0
3P2;Rh/0Q8B40861P@24Q8@0Lg=c06][J`1^KVh0I6AT06EUI@1[Jf/0IFEU061PH01WIfL0JVYZ0P1X
J6P00`1_Kfl0KVi^06i^KP0206MWI`0706a/K01cLg<0JFUY065QH@1XJ6P0LG5a071`L002079bLP0H
06i^KP1`L700NWYj07]kN`1iNGT0LG5a06][J`1/K6`0Lg=c07moO`1jNWX0OGem0861P@22PX80OWin
07YjNP1`L700JVYZ06UYJ@1mOGd0R8R809BDU02IVIT0Ti>C0P2GUiL02@2CTi<0W9bL09fMW@2DU9@0
SHf=08Z:RP27QhL0RHV909BDU00209FEU@0?09^KV`2FUYH0Ogmo07QhN029RHT0SXj>09bLW02QXJ40
Y:BT0:>SX`2KVi/0VIVI09RHV02MWId0YJFU0080Zj^[0P2b/[802P2NWYh0UiNG09>CT`2FUYH0YJFU
0:f][@2YZJT0Y:BT0:JVYP2YZJT20:n_[`040:VYZ@2VYZH0YjNW0;:b/P80^;Rh00h0[Jf]09nOW`2I
VIT0YjNW0:f][@2JVYX0U9BD09ZJVP2[Zj/0/[:b0;2`/02][Jd0[:b/0:j^[P80]KFe0P2`/;00402d
];@0/k>c0;:b/P2e]KD0/;2`0:ZZZP2_[jl0][Jf0;2`/02XZ:P0Zj^[0;Bd]02g]kL0/K6a0:f][@2a
/K420;^k^`0A0;Fe]@2ZZZX0[Zj^0;Vi^@31`L40^k^k0;Ng]`2i^KT0_[jn0<;2`P2f][H0Y:BT09jN
WP2XZ:P0];Bd0;Vi^@2j^[X00P2h^;P02@2e]KD0_;bl0;bl_02f][H0]kNg0:^[Z`2SXj<0Zj^[0;Jf
]P020<30`0<0_kno0140aLG50<30`02m_Kd0_;bl0<C4a038b<P0`l?30<71`@30`<00_[jn0<;2`P35
aLD0`/;20;jn_P2l_;`0^;Rh0;Jf]P020;Rh^080_kno00X0`L710;no_`2n_[h0^KVi0<30`02l_;`0
_Kfm0;Zj^P2m_Kd0^KVi0P2e]KD20;no_`0T0;fm_@2j^[X0]kNg0;jn_P2l_;`0_[jn0<K6aP3:b/X0
`l?30:RXZ02?Shl0UYJF0:b/[02h^;P0bLW90=GEe@3Cdm<0dM7A0<W9b@2o_kl0]KFe0:j^[P35aLD0
alO70<71`@2k^k/0^[Zj0<C4a03<c<`0cLg=0<k>cP3?cll0d];B0=7Ad@3Bd]80d=3@103=cLd20<W9
b@030<S8b037alL0c<c<0080bLW900<0bl_;0<W9b@38b<P00P38b<P01@39bLT0bl_;0<k>cP3>c/h0
cLg=0080c/k>00D0cLg=0<W9b@3:b/X0c<c<0<[:bP020<S8b0030<O7a`3:b/X0c/k>0080d];B0P3D
e=@00`3Hf=P0f][J0=kNgP020=gMg@0H0=kNgP3QhN40gmoO0=7Ad@1oOgl0;2`/02LW9`0/;2`0<C4a
03Ph>00c<c<0=cLg03Hf=P0i>CT0@41003Hf=P0d=3@0;2`/03Lg=`0l?3`0>CTi03Hf=P0c<c<0;Rh^
0P0c<c<07@0];Bd0:RXZ02l_;`0_;bl0<c<c034a<@0^;Rh0;2`/02d];@0d=3@0<30`02l_;`0a<C40
?clo0410@011@D40ADE504Y:BP1IFET0Kfm_0820P02<S8`0UIFE09RHV02IVIT0UYJF09RHV02ATI40
SXj>0080TY:B0`2FUYH00`2KVi/0WYjN0:2PX0020:2PX080XZ:R00@0WYjN09nOW`2MWId0WinO0P2N
WYh02@2PX:00WYjN09fMW@2LW9`0WinO09jNWP2KVi/0WIfM09bLW00209jNWP0;09bLW02MWId0V9RH
09VIV@2HV9P0Vi^K09VIV@2LW9`0Vi^K09ZJVP2PX:000P2JVYX0102KVi/0VIVI09ZJVP2LW9`>0<SP
f0003038h=P206MWI`0;06IVIP1SHf<0IFEU061PH01QHF40I6AT065QH@1TI6@0Hf=S065QH@1SHf<0
0P1TI6@206IVIP0E06][J`1RHV80I6AT065QH@1OGel0HF5Q06MWI`1VIVH0KFe]079bLP1eMGD0Ogmo
0861P@2;Rh/0Shn?09>CT`2KVi/0WYjN0:BTY02SXj<0Y:BT0080YZJV00`0ZJVY0:b/[02/[:`0[:b/
0;:b/P2/[:`0[Jf]0:b/[02XZ:P0[Jf]0;:b/P2][Jd20:j^[P0H0:^[Z`2UYJD0X:2P09ZJVP2CTi<0
RHV908N7Q`1nOWh0MGEe06e]K@1OGel0H61P04e=C@1?Cdl0CTi>051@D01ADE40EeMG05EEE@1KFe/0
GEeM065QH@1JFUX0Fe]K0P1QHF401P1NGUh0IfMW06EUI@1QHF40IFEU065QH@80I6AT00<0IVIV05mO
G`1RHV800P1VIVH206ATI00R06EUI@1TI6@0H61P061PH01VIVH0HF5Q06ATI01VIVH0J6QX06UYJ@1U
IFD0J6QX06YZJP1^KVh0IfMW06e]K@1[Jf/0KFe]06QXJ01YJFT0Jf][06EUI@1RHV80HF5Q05iNGP1J
FUX0MGEe0<o?c`3MgMd0d];B0<[:bP2i^KT0[Jf]09bLW080UiNG00L0S8b<08N7Q`1jNWX0P82007]k
N`1]KFd0HF5Q0080IfMW00@0K6a/06QXJ01SHf<0J6QX0P1_Kfl0<@1aLG40K6a/06e]K@1`L700KFe]
06=SH`1RHV80Jf][06YZJP1bLW80Kfm_071`L01YJFT0MWIf07MgM`1aLG40L71`07=cL`1gMgL0QHF5
07YjNP1`L700K6a/079bLP1aLG40NWYj08>3P`20P800OWin08:2PP1mOGd0Ng]k07IfMP1aLG40KVi^
07]kN`2BTY80UYJF09ZJVP2HV9P0Shn?09JFUP2MWId0W9bL09BDU02?Shl0S8b<08V9R@2FUYH00P2<
S8`04P2ATI40YZJV0:NWY`29RHT0M7Ad07UiN@25QHD0UiNG09^KV`2OWil0Vi^K09ZJVP2MWId0VIVI
0::RXP2TY:@0WinO0:^[Z`80[jn_00L0ZJVY09jNWP2FUYH0ZJVY0;:b/P2^[Zh0ZZZZ0080YjNW00L0
Zj^[0:VYZ@2PX:00ZJVY0:>SX`2WYjL0][Jf0080]kNg00l0YJFU09fMW@2/[:`0_;bl0;2`/02SXj<0
WinO09VIV@2HV9P0WYjN0:NWY`2^[Zh0/;2`0;Vi^@2c/k<00P2_[jl06P2^[Zh0/;2`0:f][@2_[jl0
[Jf]0:j^[P2d];@0/k>c0;:b/P2ZZZX0Zj^[0;Ng]`2h^;P0[:b/0:VYZ@2c/k<0`<300;Ng]`2f][H0
[Zj^0:RXZ02^[Zh0^KVi0<30`02l_;`0/k>c0P2l_;`0302o_kl0[Jf]0:JVYP2YZJT0VYZJ09bLW02/
[:`0]KFe0;:b/P2d];@0/k>c0;Vi^@<0_[jn00H0^KVi0::RXP2b/[80/;2`0;Jf]P2d];@20;Ng]`0=
0;jn_P2m_Kd0_;bl0;^k^`2o_kl0`l?30<O7a`33`l<0_[jn0;no_`31`L40alO70<S8b0020<;2`P0<
0<30`02o_kl0]kNg0;Vi^@2l_;`0_[jn0;no_`2n_[h0`/;20;^k^`2n_[h0`/;20P2o_kl04@2m_Kd0
_kno0;Vi^@2d];@0^KVi0;jn_P2l_;`0^KVi0;bl_030`<00_[jn0<30`032`/80bLW90<K6aP2g]kL0
TY:B0080T92@0200U9BD09nOW`2/[:`0aLG50<W9b@3;bl/0c<c<0=3@d03;bl/0_;bl0;no_`2k^k/0
a/K60<[:bP35aLD0_[jn0;Ng]`2n_[h0alO70<S8b03=cLd0dm?C0=GEe@3Cdm<0d=3@0<o?c`3;bl/0
c/k>0<g=c@39bLT0a/K60<S8b080b/[:00<0b<S80<[:bP3:b/X00P3:b/X02039bLT0b/[:0<_;b`39
bLT0bl_;0<c<c03=cLd0c/k>0P3=cLd0203<c<`0bl_;0<c<c03=cLd0bLW90<S8b039bLT0b/[:0P3B
d]820=?Cd`050=OGe`3Jf]X0fm_K0=_Kf`3MgMd00P3Ng]h03@3Ph>00e]KF08n?S`0d=3@0;Bd]030`
<00^;Rh0;2`/034a<@0`<300=cLg034a<@0k>c/00`0e=CD00`0c<c<0=3@d03Ph>003038b<P80;Rh^
00@09bLW02PX:00b<S80;Rh^0P0d=3@01@0^;Rh0<c<c03Xj>P0d=3@0<c<c0080>CTi00l0>SXj03lo
?`0j>SX0ATI604M7A`1FEUH0IFEU07=cL`25QHD0Ti>C09NGU`2EUID0UYJF09:BTP2CTi<00P2@T900
2`2BTY80UiNG09NGU`2HV9P0VIVI09nOW`2NWYh0XJ6Q0::RXP2MWId0W9bL0080X:2P0200Xj>S09bL
W02NWYh0WinO0::RXP2PX:00WIfM09ZJVP2OWil0W9bL09jNWP2KVi/0WIfM09nOW`2NWYh0W9bL09fM
W@2IVIT0Vi^K09ZJVP2MWId0VYZJ09VIV@2MWId0Vi^K09NGU`2KVi/0UYJF09NGU`2LW9`0Vi^K09VI
V@h0b>3H000<0<SPf080Hf=S00P0IFEU065QH@1XJ6P0HV9R06ATI01VIVH0HF5Q06ATI080Hf=S00/0
IfMW05mOG`1RHV80HV9R06IVIP1WIfL0HF5Q05iNGP1UIFD0GemO05eMG@0206MWI`80KFe]00l0MgMg
08>3P`25QHD0RHV908j>SP2EUID0VYZJ09^KV`2NWYh0XZ:R0:JVYP2TY:@0YjNW0:RXZ02YZJT00P2Z
ZZX0202][Jd0Zj^[0:f][@2[Zj/0[:b/0:ZZZP2/[:`0[Jf]0P2/[:`03P2VYZH0Xj>S09fMW@2JVYX0
UIFE08j>SP25QHD0PH6107=cL`1XJ6P0H61P05UIF@1@D500DE5A0P1?Cdl03`1<C4`0Cdm?05ADE01G
EeL0Fe]K05UIF@1SHf<0FEUI061PH01MGEd0H61P06EUI@1WIfL0GemO06ATI002065QH@0306ATI01V
IVH0J6QX0080IVIV01D0Hf=S06IVIP1TI6@0IfMW05mOG`1NGUh0HF5Q06IVIP1QHF40IFEU06=SH`1T
I6@0J6QX06IVIP1YJFT0K6a/071`L01ZJVX0KVi^06][J`1^KVh00P1ZJVX03P1XJ6P0JVYZ06YZJP1P
H600GemO05UIF@1XJ6P0]KFe0=cLg03Bd]80b/[:0;Ng]`2`/;00XZ:R0P2;Rh/03`2?Shl0QhN707]k
N`1nOWh0Ng]k06][J`1QHF40Jf][071`L01[Jf/0JFUY06a/K01[Jf/0JFUY06m_K`02071`L00306=S
H`1VIVH0JFUY0080JFUY00T0IVIV06QXJ01^KVh0MGEe071`L01/K6`0Hf=S075aL@1eMGD00P1jNWX0
3@1fMWH0Ogmo07inOP1mOGd0NGUi06][J`1_Kfl0Lg=c07AdM021PH40N7Qh07inOP1mOGd00P1jNWX0
2@1iNGT0Kfm_06e]K@1mOGd0Ti>C0:2PX02FUYH0Shn?096AT@0209JFUP0B09BDU02=SHd0U9BD09BD
U02?Shl0RXZ:096AT@2DU9@0VIVI09nOW`2CTi<0U9BD08B4Q01jNWX0PX:209>CT`2HV9P0Vi^K0`2Q
XJ420:>SX`0=0:RXZ02QXJ40YZJV0:JVYP2/[:`0Y:BT0;6a/@2f][H0Zj^[0:VYZ@2][Jd0ZJVY0:ZZ
ZP020:RXZ00E0:NWY`2VYZH0Z:RX0:j^[P2d];@0]KFe0:FUY@2SXj<0ZJVY0;jn_P2h^;P0[Jf]0:j^
[P2b/[80[:b/09JFUP2BTY80WYjN0:j^[P2b/[80]KFe0080/K6a01`0/;2`0:ZZZP2_[jl0/;2`0:VY
Z@2][Jd0/[:b0;Fe]@2/[:`0/;2`0;Fe]@2k^k/0]kNg0:n_[`2XZ:P0/K6a0;Rh^02n_[h0];Bd0:ZZ
ZP2YZJT0Z:RX0;Jf]P2l_;`0^k^k0;Fe]@2d];@0^[Zj0P2n_[h01`2g]kL0];Bd0;Jf]P2][Jd0W9bL
0:2PX02XZ:P00P2][Jd00`2b/[80];Bd0;Vi^@020;jn_P060<71`@2h^;P0^k^k0;2`/02b/[80[:b/
0P2f][H01@2g]kL0];Bd0;Ng]`2m_Kd0^k^k0080`<3000@0_[jn0;bl_030`<00b<S80P36a/H03`35
aLD0a/K60;no_`2g]kL0^KVi0<30`033`l<0_kno0;jn_P2m_Kd0^[Zj0<30`02m_Kd0a<C40<;2`P02
0<30`00]0;jn_P2f][H0^k^k0;Zj^P2n_[h0^k^k0;Rh^02g]kL0`L710<?3``34a<@0bLW90<[:bP2m
_Kd0X:2P08n?S`2@T900VYZJ09BDU02JVYX0VIVI0:ZZZP2k^k/0aLG50<K6aP3>c/h0e]KF0<g=c@33
`l<0_kno0<30`032`/80`l?30<[:bP31`L40]KFe0;Zj^P36a/H0aLG50<c<c03Cdm<0e=CD0=GEe@3A
dM40c/k>0080cLg=00<0c<c<0<W9b@35aLD00`37alL0203;bl/0bLW90<[:bP3:b/X0bLW90<O7a`3:
b/X0b<S80P3;bl/0703=cLd0c/k>0<k>cP3;bl/0cLg=0<W9b@3=cLd0d=3@0<[:bP3>c/h0c<c<0<g=
c@3Cdm<0dM7A0=?Cd`3EeMD0fMWI0=gMg@3Kfm/0g]kN0=oOg`3Lg=`0g]kN0=oOg`3Kfm/0WYjN030`
<00e=CD2030`<003038b<P0d=3@0<c<c0080=3@d00P0=cLg03Hf=P0j>SX0<S8b02d];@0g=cL0=SHf
02`/;080<30`00`0:RXZ02/[:`0Y:BT09bLW02PX:00];Bd0=3@d03<c<`0/;2`0<C4a03<c<`0e=CD2
030`<00303Lg=`0h>3P0>c/k0080@d=300T0A4A404U9B@1IFET0JVYZ0820P02ATI40Ti>C09NGU`2E
UID00P2DU9@209:BTP08096AT@2?Shl0Shn?09>CT`2KVi/0WinO09VIV@2QXJ420::RXP0A09nOW`2N
WYh0WYjN0::RXP2LW9`0Xj>S0:2PX02SXj<0WYjN0:2PX02NWYh0X:2P09bLW02PX:00Vi^K09bLW02O
Wil00P2PX:00202OWil0WIfM09fMW@2JVYX0Vi^K09ZJVP2FUYH0V9RH0P2KVi/01P2IVIT0UiNG09VI
V@2LW9`0VIVI09ZJVPh0b>3H000<0<SPf080IfMW01l0IFEU06IVIP1SHf<0Hf=S065QH@1NGUh0I6AT
061PH01TI6@0HV9R06IVIP1RHV80I6AT05mOG`1VIVH0JFUY065QH@1OGel0Hf=S065QH@1PH600J6QX
06=SH`1`L700LW9b07EeM@20P800QHF508b<S02@T900UiNG0080V9RH00<0Vi^K0:2PX02TY:@00P2U
YJD20:NWY`80ZJVY0P2/[:`09`2[Zj/0[Zj^0:f][@2YZJT0ZZZZ0:b/[02XZ:P0ZJVY0:NWY`2SXj<0
XJ6Q09ZJVP2BTY80SHf=08J6QP1mOGd0M7Ad06i^KP1PH600GEeM04];B`1@D500C4a<04];B`19BDT0
CDe=05YJFP1MGEd0F5QH05YJFP1SHf<0EUIF061PH01RHV80IVIV069RHP1XJ6P0Hf=S069RHP0206=S
H`0H065QH@1VIVH0J6QX06=SH`1PH600IfMW06EUI@1YJFT0J6QX06IVIP1YJFT0IfMW061PH01[Jf/0
IVIV05mOG`1UIFD0J6QX06=SH`1ZJVX0Jf][06i^KP1ZJVX0Jf][0P1]KFd0401XJ6P0JFUY06e]K@1W
IfL0Jf][05mOG`1IFET0IFEU06IVIP2NWYh0fMWI0=KFeP3=cLd0`l?30:JVYP2NWYh209RHV00B08J6
QP1jNWX0PH6107moO`1eMGD0J6QX06IVIP1YJFT0KFe]06m_K`1VIVH0KVi^06a/K01RHV80I6AT06UY
J@1]KFd0HF5Q0P1JFUX01@1_Kfl0LG5a06i^KP1UIFD0H61P0080LG5a02/0JFUY06EUI@1PH600K6a/
07IfMP1kNg/0NGUi07MgM`1dM7@0N7Qh07alO01dM7@0LG5a079bLP1XJ6P0KFe]07alO01jNWX0Ng]k
07alO01hN7P0MGEe07IfMP1`L700KFe]0820P02DU9@0V9RH09FEU@2ATI40VYZJ09BDU02?Shl0UYJF
09^KV`2EUID0Ti>C08j>SP2CTi<0T92@096AT@2?Shl0V9RH0080XZ:R00@0QhN707UiN@1nOWh0UiNG
0P2PX:001@2VYZH0XZ:R0:>SX`2WYjL0Y:BT00<0Vi^K0380X:2P0;:b/P2l_;`0/k>c0;:b/P2VYZH0
[:b/0:j^[P2TY:@0ZJVY0:RXZ02UYJD0Xj>S0:NWY`2/[:`0[Jf]0:BTY02WYjL0[Jf]0<30`02n_[h0
/;2`0;:b/P2m_Kd0^;Rh0;6a/@2OWil0UYJF09BDU02SXj<0ZJVY0;>c/`2k^k/0^;Rh0;>c/`2[Zj/0
ZJVY0:^[Z`2`/;00/K6a0:n_[`2[Zj/0[jn_0;Zj^P2o_kl0]kNg0:n_[`2[Zj/0/[:b0;>c/`80];Bd
00X0/[:b0:JVYP2WYjL0]kNg0;fm_@2f][H0/[:b0;2`/02^[Zh0/k>c0P32`/801`2o_kl0`l?30;fm
_@2j^[X0[:b/0;>c/`2d];@00P2a/K402`2[Zj/0Z:RX0;2`/02f][H0^k^k0;jn_P2k^k/0_[jn0;no
_`2j^[X0^KVi0080_;bl00X0]kNg0;>c/`2f][H0^;Rh0;Ng]`2o_kl0`/;20;jn_P2m_Kd0`<300P35
aLD04034a<@0aLG50<G5a@2l_;`0^KVi0<71`@32`/80`L710;no_`2l_;`0^k^k0<C4a033`l<0`L71
0<S8b035aLD20<;2`P0a0<30`02e]KD0_kno0<71`@30`<00_Kfm0;^k^`2j^[X0`/;20<O7a`38b<P0
cLg=0<W9b@2a/K40UIFE08j>SP2GUiL0TY:B09RHV02FUYH0UIFE09NGU`2IVIT0[:b/0;no_`34a<@0
b/[:0=7Ad@3GemL0eMGE0<_;b`2n_[h0];Bd0;Jf]P38b<P0alO70;Rh^02b/[80^;Rh0<G5a@3:b/X0
e=CD0=GEe@3Cdm<0d];B0=3@d03>c/h0cLg=0<c<c0020<W9b@040<K6aP38b<P0b/[:0<S8b080bLW9
0`38b<P00`37alL0b/[:0<_;b`020<_;b`060<g=c@3?cll0c/k>0<W9b@3:b/X0c/k>0P3=cLd01`3@
d=00d];B0=CDe03Cdm<0e=CD0=GEe@3GemL00P3Kfm/00`3Ogml0g]kN0=kNgP030=kNgP0e0;Ng]`12
@T80:2PX02TY:@0`<300;bl_03<c<`0`<300=3@d03Xj>P0c<c<0>3Ph03@d=00a<C40<c<c03Lg=`0b
<S80;bl_034a<@0^;Rh0;bl_02/[:`0/;2`0:BTY02DU9@0Z:RX0;Bd]03De=@0b<S80<c<c03@d=00g
=cL0=SHf03<c<`0i>CT0?Cdm03De=@0h>3P0?clo0410@016ATH0CTi>061PH01gMgL0QhN7092@T02D
U9@0UiNG09ZJVP2FUYH0UIFE09>CT`2BTY800P2ATI400`2BTY80UiNG09VIV@0209nOW`080:6QX@2M
WId0XJ6Q0:6QX@2RXZ80Y:BT09nOW`2PX:0209bLW00<09nOW`2NWYh0W9bL09fMW@2LW9`0XJ6Q0::R
XP2LW9`0XZ:R0:2PX02NWYh0WinO0P2JVYX02`2HV9P0W9bL09VIV@2GUiL0WinO09^KV`2JVYX0V9RH
09VIV@2JVYX0VIVI0080UiNG3P38h=P000`0b>3H0P1QHF409P1WIfL0Hf=S05mOG`1WIfL0HF5Q06IV
IP1TI6@0IfMW06IVIP1PH600IVIV065QH@1WIfL0Hf=S06MWI`1RHV80GemO05eMG@1PH600IVIV05aL
G01TI6@0Jf][06a/K01_Kfl0MgMg0820P027QhL0RHV908n?S`2EUID0V9RH09VIV@2LW9`0WIfM0:>S
X`2VYZH0YjNW0P2VYZH20:b/[0050:VYZ@2ZZZX0ZJVY0:f][@2[Zj/00`2/[:`04@2[Zj/0ZZZZ0:JV
YP2RXZ80Vi^K09ZJVP2EUID0SHf=08F5Q@20P800MWIf06a/K01SHf<0GemO051@D01:BTX0CTi>00<0
CDe=0140De=C05IFEP1JFUX0Fe]K06=SH`1JFUX0G5aL05eMG@1OGel0I6AT05mOG`1XJ6P0HV9R06=S
H`1RHV80IfMW06][J`0406=SH`0E06MWI`1SHf<0IVIV06EUI@1RHV80IFEU06=SH`1RHV80Hf=S06IV
IP1UIFD0J6QX06=SH`1[Jf/0JVYZ06QXJ01/K6`0KFe]06a/K01ZJVX0JFUY0080Jf][00<0Kfm_06i^
KP1RHV800P1QHF401`1SHf<0TI6A0=SHf03IfMT0dM7A0<C4a02KVi/00`2EUID01P2@T900Ogmo0820
P01oOgl0MWIf06YZJP80Jf][01/0JFUY06e]K@1XJ6P0IVIV06i^KP1WIfL0Hf=S05iNGP1VIVH0IfMW
06UYJ@1PH600G5aL06UYJ@1bLW80IfMW05iNGP1WIfL0Lg=c07EeM@1`L700J6QX05]KF`1UIFD0LW9b
07]kN`1iNGT00P1gMgL0;`1hN7P0P82007emO@1kNg/0Lg=c06i^KP1/K6`0MWIf0820P01kNg/0Lg=c
079bLP1dM7@0LG5a07AdM01bLW80O7al08n?S`2EUID0UiNG08n?S`2<S8`0U9BD09nOW`2MWId0UIFE
09fMW@2JVYX0SXj>08n?S`2>SXh0UIFE09>CT`2LW9`0Zj^[0:JVYP2;Rh/0P82007moO`2?Shl0W9bL
09fMW@2UYJD0Zj^[0:FUY@2OWil0UiNG0080VYZJ00L0Z:RX0;2`/02^[Zh0]KFe0;Jf]P2b/[80^;Rh
0080YZJV00D0Y:BT0:ZZZP2UYJD0YJFU0:n_[`020:2PX00409nOW`2ZZZX0^[Zj0;Zj^P80]KFe0P30
`<00202l_;`0/;2`0:RXZ02SXj<0VYZJ09VIV@2NWYh0/[:b0P2i^KT0602c/k<0/;2`0;>c/`2b/[80
/K6a0;:b/P2XZ:P0[jn_0;jn_P31`L40^KVi0;Bd]02b/[80]kNg0;>c/`2d];@0/;2`0;:b/P2_[jl0
[:b/0;Bd]02o_kl0_;bl0;>c/`80[:b/01P0/k>c0;bl_031`L40a<C40<O7a`36a/H0a<C40<71`@2k
^k/0`l?30<O7a`33`l<0`<300;Ng]`2VYZH0Y:BT0:n_[`2n_[h0`<300;fm_@34a<@0aLG50;fm_@31
`L420;no_`090<30`02g]kL0_kno0;jn_P2k^k/0_kno0<G5a@32`/80_Kfm0080`/;200/0aLG50<C4
a031`L40_kno0<;2`P38b<P0a<C40<;2`P2n_[h0`L710;jn_P020<G5a@0Z0<C4a035aLD0a/K60<G5
a@34a<@0`/;20;Zj^P2n_[h0_kno0<C4a030`<00_[jn0;no_`32`/80a/K60<W9b@3=cLd0dM7A0<C4
a02PX:00Shn?09JFUP2HV9P0UYJF09RHV02FUYH0UiNG09>CT`2?Shl0SHf=09^KV`2][Jd0_kno0<O7
a`3?cll0f=SH0=7Ad@3;bl/0a/K60;Zj^P2k^k/0]kNg0P31`L40202_[jl0/k>c0<30`037alL0clo?
0=CDe03Bd]80dm?C0P3@d=001`3=cLd0clo?0<c<c03;bl/0c<c<0<[:bP36a/H00`38b<P01P39bLT0
b<S80<_;b`39bLT0bl_;0<c<c080cLg=00@0c<c<0<k>cP3:b/X0bl_;0`3=cLd0103@d=00d];B0=?C
d`3Fe]H20=CDe0030=OGe`3Hf=P0f][J0080f][J00T0gMgM0=kNgP3Ng]h0gMgM0<S8b01CDe<0;Bd]
02TY:@0`<3000P0c<c<06014A4@0=SHf03Lg=`0e=CD0=SHf03De=@0`<300=CDe034a<@0i>CT0<C4a
030`<00h>3P0;2`/02/[:`0e=CD0:RXZ02PX:00Y:BT0:2PX02LW9`0];Bd0;bl_038b<P80=CDe0P0d
=3@0100g=cL0<C4a03Hf=P0e=CD203Lg=`0<04M7A`1DE5@0JVYZ07inOP2=SHd0Ti>C09VIV@2MWId0
UIFE09JFUP2CTi<0U9BD0P2EUID01`2@T900TY:B09JFUP2LW9`0Vi^K09jNWP2RXZ80102QXJ401@2O
Wil0XZ:R0:2PX02OWil0Vi^K0080WYjN00D0WinO09fMW@2PX:00WinO09VIV@0209fMW@0609jNWP2M
WId0W9bL09^KV`2LW9`0WIfM0P2LW9`209^KV`0709fMW@2HV9P0VYZJ09ZJVP2LW9`0UYJF09bLW00>
0<SPf0003038h=P206ATI004061PH01QHF40JFUY06QXJ0<0IfMW00D0I6AT06EUI@1YJFT0Hf=S06AT
I00206=SH`0J06QXJ01VIVH0GemO06ATI01RHV80Hf=S065QH@1XJ6P0JFUY06i^KP1aLG40NGUi07mo
O`24Q8@0SHf=08n?S`2BTY80V9RH09FEU@2KVi/0WYjN09fMW@2UYJD0YZJV0:BTY02VYZH20:ZZZP0J
0:VYZ@2ZZZX0/K6a0:ZZZP2[Zj/0ZZZZ0:VYZ@2ZZZX0[:b/0:j^[P2YZJT0WYjN09ZJVP2FUYH0UIFE
08^;R`21PH40O7al07IfMP1]KFd0HF5Q05UIF@1>CTh0CDe=051@D01;Bd/2055AD@80EEEE00L0EUIF
05]KF`1SHf<0Fe]K069RHP1PH600G5aL0080Hf=S00L0GEeM061PH01SHf<0IFEU06a/K01UIFD0I6AT
0080J6QX02D0I6AT06IVIP1OGel0IfMW06QXJ01SHf<0I6AT069RHP1UIFD0H61P06ATI01SHf<0IVIV
06EUI@1/K6`0KFe]06YZJP1YJFT0Jf][06e]K@1/K6`0KVi^06e]K@1_Kfl0KVi^06][J`1ZJVX0Hf=S
05iNGP1QHF40Q8B40=SHf03Jf]X0cLg=0<K6aP2LW9`0X:2P0080SHf=00<0QhN708Z:RP1hN7P00P1h
N7P0=01^KVh0I6AT06e]K@1TI6@0Hf=S06a/K01YJFT0IFEU06YZJP1XJ6P0IVIV05]KF`1UIFD0M7Ad
06QXJ01JFUX0FEUI06][J`1^KVh0Lg=c06i^KP1_Kfl0Lg=c07YjNP1fMWH0Kfm_06=SH`1VIVH0KFe]
07UiN@20P800OGem0820P021PH40P82008J6QP1nOWh0MGEe06YZJP1[Jf/0M7Ad07YjNP1gMgL0MWIf
07=cL`1eMGD0Lg=c07MgM`1ZJVX0MgMg08b<S02ATI4208b<S00609NGU`2IVIT0UiNG09bLW02RXZ80
XJ6Q0P2=SHd04@2@T900Ti>C09:BTP2GUiL0Vi^K0:JVYP2SXj<0QXJ607IfMP1jNWX0SXj>0::RXP2U
YJD0Y:BT0:NWY`2NWYh0W9bL0080YZJV0P2[Zj/03P2^[Zh0[jn_0;:b/P2g]kL0/k>c0;6a/@2VYZH0
Zj^[0;2`/02WYjL0[Jf]0:BTY02NWYh0XJ6Q0P2][Jd07@2`/;00[Zj^0;6a/@33`l<0a<C40;fm_@2e
]KD0[Jf]0:b/[02b/[80ZJVY09ZJVP2MWId0XZ:R0:n_[`2c/k<0/K6a0;Jf]P2g]kL0/[:b0:f][@2/
[:`0/;2`0;bl_02n_[h0^k^k0;>c/`2f][H0];Bd0080]KFe00`0/K6a0:VYZ@2/[:`0][Jf0;bl_02m
_Kd0][Jf0;Fe]@2][Jd0[:b/0;>c/`2m_Kd20<71`@0?0<;2`P31`L40`/;20<?3``2o_kl0aLG50<[:
bP3;bl/0b/[:0<W9b@35aLD0^KVi0:>SX`2OWil0/;2`0080_Kfm00@0_;bl0;no_`30`<00`<300P2o
_kl06P2k^k/0_Kfm0<;2`P35aLD0`/;20<?3``36a/H0alO70<;2`P34a<@0`l?30<G5a@34a<@0`/;2
0;bl_038b<P0alO70<G5a@34a<@0a/K60<G5a@36a/H0b<S80<O7a`35aLD0alO70P33`l<01036a/H0
`<300;^k^`32`/820<G5a@0Z0<?3``32`/80a/K60<_;b`3>c/h0c<c<0=7Ad@3@d=00a<C409ZJVP2G
UiL0VIVI09RHV02IVIT0UiNG09BDU02EUID0TY:B08f=S@2:RXX0SXj>092@T02OWil0^k^k0<;2`P3<
c<`0eMGE0=OGe`3Bd]80cLg=0<;2`P2d];@0[jn_0<71`@38b<P0^k^k0;Bd]02l_;`0alO70<g=c@3@
d=00e=CD0P3Cdm<00`3Bd]80clo?0<k>cP020<k>cP040<g=c@39bLT0bLW90<W9b@80b/[:00D0b<S8
0<[:bP38b<P0aLG50<W9b@040<g=c@80bl_;0P3<c<`00`3>c/h0dM7A0=?Cd`020=CDe0060=OGe`3D
e=@0e]KF0=SHf03Jf]X0fm_K0P3MgMd04P3Ogml0g=cL0=kNgP3?cll0JFUY02PX:00Z:RX0;2`/02HV
9P0Z:RX0<C4a03Hf=P0d=3@0;bl_03Ti>@0k>c/0;Rh^02l_;`80<S8b00@0;Rh^038b<P0h>3P0;Rh^
0P0b<S801@0X:2P0;Bd]02XZ:P0_;bl0:b/[0080;2`/00L0<C4a03De=@0^;Rh0=SHf02h^;P0f=SH0
<30`0080<S8b00P0<30`02l_;`0j>SX0BTY:065QH@1cLg<0QHF508n?S`<0VYZJ00<0UiNG09JFUP2B
TY800`2DU9@01P2@T900U9BD09JFUP2OWil0W9bL0::RXP80X:2P00T0XJ6Q0:2PX02RXZ80X:2P09bL
W02SXj<0WinO0:2PX02NWYh00`2OWil04@2NWYh0Vi^K09VIV@2NWYh0W9bL09jNWP2LW9`0VIVI09^K
V`2NWYh0X:2P09bLW02KVi/0VYZJ09^KV`2IVIT0UIFE0080Vi^K00<0VYZJ09VIV@38h=P03@38h=P0
00`0b>3H0P1SHf<04@1XJ6P0HV9R06MWI`1TI6@0IVIV06ATI01VIVH0HV9R065QH@1SHf<0HF5Q06AT
I01RHV80HF5Q06QXJ01QHF40HV9R00<0Hf=S00d0HF5Q06=SH`1SHf<0IfMW06i^KP1fMWH0OGem08:2
PP2<S8`0Rh^;09FEU@2DU9@0UYJF0080V9RH00D0X:2P0:RXZ02TY:@0YZJV0:RXZ0020:JVYP050:ZZ
ZP2[Zj/0Z:RX0:b/[02XZ:P00P2ZZZX05@2XZ:P0ZZZZ0:VYZ@2[Zj/0XJ6Q09VIV@2JVYX0T92@08b<
S023Ph<0O7al07=cL`1`L700Hf=S05YJFP1=CDd0D51@04e=C@1?Cdl0DU9B04i>CP0205IFEP0:05YJ
FP1IFET0GEeM05]KF`1NGUh0GEeM065QH@1PH600I6AT06EUI@80IVIV0100HF5Q06MWI`1UIFD0IFEU
06IVIP1WIfL0Hf=S065QH@1RHV80IfMW06EUI@1YJFT0I6AT061PH01WIfL0HV9R0P1XJ6P06@1ZJVX0
HV9R06MWI`1WIfL0KFe]06m_K`1[Jf/0JVYZ06e]K@1eMGD0KFe]06a/K01YJFT0J6QX06IVIP1SHf<0
GUiN05mOG`1`L700`<300=kNgP3Bd]80`<300;:b/P2HV9P00P2;Rh/01`1nOWh0Q8B408B4Q01fMWH0
M7Ad071`L01RHV800P1YJFT0:P1QHF40Hf=S06a/K01WIfL0JFUY06m_K`1YJFT0IVIV069RHP1UIFD0
JFUY06MWI`1OGel0FUYJ06EUI@1eMGD0MWIf079bLP1hN7P0MGEe07QhN01jNWX0MWIf071`L01]KFd0
MgMg0820P01oOgl0O7al07inOP24Q8@0P82007alO01jNWX0MWIf06m_K`1]KFd0LW9b07alO01nOWh0
MGEe07UiN@80LG5a01<0JFUY06YZJP1dM7@0PX:208N7Q`2BTY80WIfM09NGU`2JVYX0ZZZZ0:BTY02K
Vi/0TI6A09BDU02@T900U9BD09JFUP2BTY80U9BD0080WIfM00X0VYZJ08n?S`2<S8`0QXJ6096AT@2H
V9P0Vi^K09fMW@2SXj<0[:b/0P2b/[803P2][Jd0Zj^[0:RXZ02[Zj/0/K6a0:j^[P2e]KD0/[:b0;>c
/`2j^[X0YjNW0:^[Z`2YZJT0XZ:R0P2^[Zh0102][Jd0Z:RX0:BTY02^[Zh20<30`00H0;^k^`2b/[80
[:b/0:j^[P2h^;P0][Jf0:VYZ@2b/[80];Bd0::RXP2PX:00YZJV0;>c/`2g]kL0]KFe0;6a/@2_[jl0
^;Rh0;bl_02k^k/0]KFe0;fm_@2g]kL0/[:b0P2g]kL03`2d];@0[jn_0;6a/@2h^;P0`l?30<71`@2l
_;`0^;Rh0;>c/`2`/;00][Jf0<30`031`L40_[jn0;fm_@020;jn_P040<?3``2m_Kd0_kno0<W9b@80
b/[:0P3<c<`02@3:b/X0aLG50;fm_@2c/k<0ZJVY0:BTY02/[:`0/K6a0;Bd]0020;fm_@80_[jn00P0
^k^k0<?3``38b<P0alO70<G5a@37alL0b<S80<K6aP80aLG50P36a/H02035aLD0`/;20<C4a039bLT0
b<S80<C4a037alL0b<S80P37alL05`35aLD0bLW90<G5a@38b<P0aLG50<K6aP32`/80`L710<;2`P31
`L40bLW90<C4a033`l<0a<C40<S8b03=cLd0d=3@0<_;b`3De=@0c/k>0;Vi^@2BTY80U9BD0080UiNG
0P2JVYX209FEU@0309JFUP2CTi<0Ti>C0080T92@01H0Shn?09JFUP2][Jd0`L710<W9b@3De=@0gMgM
0=OGe`3Bd]80bl_;0;jn_P2h^;P0^KVi0<G5a@32`/80Zj^[0;>c/`31`L40b<S80<c<c03Bd]80eMGE
0P3Bd]801@3@d=00clo?0<o?c`3>c/h0clo?0080c<c<00T0bl_;0<S8b03;bl/0b/[:0<_;b`39bLT0
alO70<[:bP3<c<`00P3:b/X20<_;b`070<c<c03;bl/0clo?0=;BdP3AdM40d];B0=GEe@030=SHf00C
0=WIf@3Jf]X0f][J0=kNgP3MgMd0g]kN0=cLg03Ogml0e]KF0820P00_;bl0:RXZ02h^;P0Z:RX0:b/[
02d];@0f=SH0=3@d030`<002034a<@0X030`<00];Bd0;Rh^030`<00g=cL0<30`03Hf=P0j>SX0<c<c
034a<@0b<S80;Bd]034a<@0];Bd0;bl_02DU9@0];Bd0<S8b03<c<`0g=cL0=SHf03<c<`0a<C40<30`
03@d=00];Bd0:RXZ02h^;P0d=3@0>3Ph04a<C01RHV80NWYj08^;R`2EUID0UYJF09ZJVP2LW9`0VIVI
09NGU`80Ti>C01H0SXj>08n?S`2DU9@0UYJF09VIV@2NWYh0W9bL0:FUY@2SXj<0XJ6Q09fMW@2OWil0
X:2P09fMW@2NWYh0W9bL09jNWP2JVYX0W9bL09jNWP2MWId0WinO0P2KVi/04P2NWYh0Vi^K09bLW02M
WId0WinO09bLW02IVIT0Vi^K09bLW02JVYX0WinO09NGU`2MWId0UiNG09ZJVP2MWId0VYZJ09bLW0h0
b>3H000<0<SPf080IVIV00T0JFUY061PH01RHV80HF5Q05mOG`1YJFT0Jf][06UYJ@1RHV800P1SHf<0
2P1UIFD0IVIV06=SH`1SHf<0H61P06=SH`1QHF40I6AT065QH@1KFe/206=SH`0A06QXJ01^KVh0M7Ad
07YjNP24Q8@0SXj>08^;R`2EUID0UYJF09VIV@2NWYh0WIfM0:2PX02SXj<0XZ:R0:NWY`2UYJD00P2X
Z:P20:VYZ@0N0:b/[02XZ:P0ZJVY0:RXZ02UYJD0ZJVY0:RXZ02WYjL0XZ:R0:2PX02LW9`0VYZJ09>C
T`2:RXX0R8R807UiN@1fMWH0LG5a06MWI`1IFET0Cdm?051@D01:BTX0BDU904m?C`1BDU80De=C05MG
E`1IFET0EEEE0P1NGUh0<`1KFe/0Hf=S06IVIP1TI6@0JFUY06a/K01VIVH0J6QX06IVIP1TI6@0IfMW
06ATI01UIFD0IVIV06YZJP1QHF40GemO06YZJP1[Jf/0IFEU06QXJ01OGel0IFEU061PH01VIVH0IFEU
06ATI01XJ6P0K6a/06QXJ01]KFd0Kfm_06QXJ01aLG40Kfm_071`L01]KFd0L71`06i^KP1/K6`0JFUY
06QXJ01RHV80GUiN06UYJ@2_[jl0gmoO0=OGe`39bLT0^[Zj09jNWP0208:2PP0908Z:RP1iNGT0Ng]k
07MgM`1^KVh0JVYZ06EUI@1LG5`0Hf=S0080IVIV00L0JVYZ06a/K01XJ6P0K6a/071`L01[Jf/0JFUY
0080H61P0P1^KVh01P1VIVH0GUiN06ATI01]KFd0LW9b07MgM`80MGEe00H0M7Ad07UiN@1hN7P0MgMg
07QhN01eMGD307]kN`0K07emO@1oOgl0PH6108:2PP1nOWh0OGem07UiN@1`L700LW9b07alO022PX80
OGem07EeM@1dM7@0KFe]06a/K01[Jf/0LW9b08J6QP2DU9@0VIVI09NGU`2SXj<0ZJVY0::RXP2IVIT0
WYjN0080Vi^K0100UiNG096AT@2>SXh0Ti>C08^;R`2:RXX0TY:B0:n_[`2^[Zh0T92@08V9R@27QhL0
TI6A09fMW@2XZ:P0ZZZZ0P2][Jd0:@2a/K40[Jf]0:b/[02/[:`0[Jf]0;6a/@2c/k<0/K6a0;Rh^02i
^KT0[:b/0:JVYP2XZ:P0[Jf]0;Bd]02_[jl0ZZZZ0:RXZ02][Jd0]kNg0;bl_02b/[80[Jf]0:n_[`2`
/;00][Jf0;Rh^02/[:`0/[:b0<71`@2n_[h0[Zj^0:6QX@2IVIT0Xj>S0:^[Z`2][Jd0/K6a0;Zj^P2o
_kl0_[jn0080]kNg01@0^[Zj0;Bd]02c/k<0^KVi0;Rh^02g]kL0_[jn0;no_`30`<00^k^k0;bl_02k
^k/0^KVi0;Zj^P31`L40_kno0;fm_@2o_kl0^[Zj0;no_`80`L7101<0^KVi0<30`036a/H0bLW90<K6
aP3;bl/0c<c<0<S8b03:b/X0a/K60<S8b037alL0][Jf09fMW@2JVYX0Y:BT0;>c/`2j^[X0`L710080
a<C40P2o_kl20<71`@070<?3``36a/H0alO70<C4a038b<P0a/K60<W9b@020<O7a`090<G5a@39bLT0
c<c<0<O7a`38b<P0bLW90<S8b036a/H0b/[:0080alO700d0a/K60<G5a@36a/H0a<C40<71`@35aLD0
a/K60<G5a@39bLT0aLG50<S8b03;bl/0cLg=0080clo?02@0cLg=0=KFeP3;bl/0Z:RX09:BTP2GUiL0
V9RH09VIV@2LW9`0Ti>C09^KV`2FUYH0U9BD092@T02IVIT0TY:B092@T02>SXh0Rh^;08f=S@2JVYX0
^;Rh0<G5a@3>c/h0dM7A0=WIf@3Hf=P0d=3@0<O7a`2i^KT0]KFe0;fm_@33`l<0]kNg0:j^[P2j^[X2
0<O7a`040<o?c`3Bd]80dm?C0=?Cd`80d];B00D0dM7A0=3@d03AdM40dM7A0<g=c@020<W9b@060<[:
bP3<c<`0bl_;0<_;b`39bLT0alO70P39bLT01@3;bl/0c<c<0<c<c03;bl/0c<c<0080clo?00<0d];B
0=GEe@3De=@00`3GemL0;`3Hf=P0f][J0=cLg03Lg=`0h^;R0=kNgP3Ogml0fMWI09BDU00[:b/09bLW
02XZ:P0Y:BT0;bl_03Hf=P0_;bl0>c/k03dm?@0c<c<0<30`034a<@0_;bl0=3@d034a<@0`<300<c<c
030`<00e=CD0=SHf02l_;`0W9bL0:RXZ02TY:@0/;2`0:RXZ02`/;00];Bd0<c<c038b<P0_;bl0>3Ph
03@d=00_;bl0=3@d02PX:00[:b/0;Bd]00809bLW00/0;Rh^0410@01ADE40Kfm_07moO`2<S8`0UiNG
09^KV`2LW9`0Vi^K09NGU`0209>CT`80T92@00P0UIFE09NGU`2HV9P0Vi^K09fMW@2QXJ40Xj>S0:6Q
X@80WinO00@0X:2P0:>SX`2QXJ40WinO0P2NWYh0402OWil0WIfM09jNWP2OWil0X:2P09jNWP2HV9P0
WYjN0:2PX02OWil0WYjN09fMW@2LW9`0VIVI09^KV`2LW9`309RHV00509ZJVP2KVi/0Vi^K09VIV@2L
W9`03P38h=P000`0b>3H0P1UIFD00`1RHV80Hf=S06=SH`0206=SH`0706IVIP1TI6@0I6AT06=SH`1U
IFD0Hf=S06IVIP0206=SH`0406ATI01ZJVX0HF5Q061PH080Hf=S0P1OGel04P1UIFD0HV9R06m_K`1d
M7@0OGem08B4Q02<S8`0RXZ:096AT@2DU9@0V9RH09fMW@2RXZ80Y:BT0:FUY@2WYjL0YJFU0:VYZ@80
YZJV00H0Z:RX0:^[Z`2/[:`0ZJVY0:NWY`2YZJT20:NWY`80Y:BT01D0Z:RX09nOW`2LW9`0V9RH096A
T@2>SXh0QHF507]kN`1gMgL0Kfm_06EUI@1IFET0DU9B04U9B@1:BTX0CTi>055AD@1=CDd0D51@05QH
F01JFUX00P1GEeL205iNGP0N05eMG@1QHF40J6QX06IVIP1UIFD0HV9R065QH@1XJ6P0IFEU06QXJ01U
IFD0I6AT06=SH`1XJ6P0IfMW06ATI01SHf<0JVYZ06MWI`1SHf<0HF5Q06=SH`1KFe/0J6QX06EUI@1/
K6`0KFe]06a/K01YJFT0JVYZ0P1]KFd04P1/K6`0KVi^071`L01_Kfl0M7Ad071`L01/K6`0Kfm_06IV
IP1PH600GEeM06UYJ@2f][H0hn?S0=OGe`3?cll0_;bl0;:b/P80T92@00T0Ogmo07IfMP1/K6`0MgMg
07AdM01WIfL0Hf=S05iNGP1LG5`00P1WIfL04P1NGUh0J6QX06a/K01/K6`0J6QX06e]K@1iNGT0LG5a
06ATI01SHf<0L71`07IfMP1_Kfl0Hf=S069RHP1YJFT0MWIf07YjNP80MWIf03D0LW9b07IfMP1kNg/0
Ng]k07UiN@1gMgL0NGUi07alO01oOgl0Ph>308B4Q01oOgl0PH6108^;R`26QXH0O7al07=cL`1aLG40
N7Qh07YjNP1iNGT0MgMg07AdM01/K6`0IVIV06][J`1cLg<0R8R8092@T02JVYX0Xj>S09fMW@2NWYh0
Vi^K09fMW@2QXJ40Y:BT09fMW@2DU9@0Shn?08b<S02=SHd0SXj>09JFUP2UYJD0ZZZZ09jNWP2?Shl0
PH6108R8R02IVIT0YJFU0:VYZ@030:n_[`80/K6a0180Zj^[0:f][@2[Zj/0/K6a0;>c/`2_[jl0/[:b
0;6a/@2b/[80^k^k0;Jf]P2b/[80YjNW0:ZZZP2e]KD0^;Rh0;>c/`2_[jl20:VYZ@030:b/[02g]kL0
^;Rh0080/K6a00d0_kno0;bl_02f][H0[Zj^0:^[Z`2UYJD0UIFE09jNWP2OWil0]KFe0<30`02o_kl0
_[jn0080^;Rh00D0];Bd0;2`/02c/k<0/[:b0;fm_@020<71`@80_Kfm0180]kNg0;Zj^P2j^[X0^[Zj
0<71`@34a<@0_kno0;bl_02k^k/0_Kfm0<?3``32`/80_Kfm0;Zj^P2o_kl0aLG50<[:bP39bLT20<S8
b080alO70P39bLT0203:b/X0`l?30;Fe]@2FUYH0UIFE0:NWY`2g]kL0_[jn0P33`l<0502n_[h0_Kfm
0;no_`2n_[h0a<C40<K6aP34a<@0b/[:0<_;b`38b<P0a/K60<_;b`39bLT0b<S80<_;b`3<c<`0alO7
0<_;b`39bLT0b/[:0P37alL00`39bLT0a/K60<O7a`020<C4a0040<30`033`l<0a/K60<S8b080bLW9
00H0bl_;0<k>cP3?cll0d=3@0<o?c`3@d=020=;BdP040;jn_P2FUYH0Shn?09FEU@<0VYZJ0240UIFE
09BDU02HV9P0TY:B09FEU@2HV9P0Ti>C09NGU`2DU9@0SXj>08V9R@25QHD0Rh^;09bLW02e]KD0`/;2
0<o?c`3Hf=P0fm_K0=?Cd`3@d=00a/K60;Rh^02k^k/0`L710<30`02a/K40^k^k0<?3``38b<P0clo?
0=GEe@3Fe]H00P3Cdm<00`3Bd]80dM7A0=3@d0030=3@d0060<_;b`38b<P0bLW90<g=c@3?cll0bl_;
0P3:b/X00`36a/H0b<S80<_;b`020<c<c00=0<S8b03<c<`0c/k>0=;BdP3De=@0dm?C0=KFeP3Hf=P0
e]KF0=SHf03GemL0g=cL0=gMg@020>3Ph080g]kN02l0[Zj^03De=@0Z:RX0;bl_02/[:`0a<C40;Rh^
03De=@0f=SH0<c<c02`/;00_;bl0<S8b02h^;P0f=SH0=CDe03<c<`0h>3P0=SHf03<c<`0`<300;Rh^
030`<00^;Rh0:BTY02h^;P0];Bd0:RXZ02l_;`0e=CD0<c<c034a<@0e=CD0=SHf03Lg=`0i>CT0=cLg
03<c<`0X:2P07alO02<S8`0V9RH0;2`/03`l?01OGel0M7Ad08J6QP0209NGU`0309bLW02IVIT0UiNG
0080UYJF00`0UiNG096AT@2=SHd0Ti>C09JFUP2JVYX0XJ6Q0:BTY02PX:00Y:BT09nOW`2MWId20:6Q
X@0:0:2PX02MWId0W9bL09jNWP2PX:00Vi^K09bLW02OWil0W9bL09^KV`80W9bL00L0WIfM09bLW02L
W9`0W9bL09RHV02KVi/0WIfM0080W9bL0`2JVYX0102LW9`0VYZJ09NGU`2KVi/>0<SPf0003038h=P2
069RHP09065QH@1SHf<0Hf=S06ATI01RHV80JVYZ061PH01VIVH0IfMW0080I6AT00L0Hf=S06ATI01Z
JVX0Hf=S06ATI01ZJVX0GemO0080GEeM00/0H61P06=SH`1LG5`0I6AT06YZJP1aLG40OWin0820P028
R8P0S8b<09>CT`0209ZJVP0709fMW@2OWil0XJ6Q0:FUY@2TY:@0YjNW0:VYZ@030:NWY`0Y0:JVYP2X
Z:P0YjNW0:BTY02UYJD0Zj^[0:JVYP2[Zj/0YJFU0:BTY02NWYh0WIfM09JFUP2EUID0Shn?07moO`1m
OGd0M7Ad06YZJP1RHV80Fe]K05IFEP1<C4`0BTY:059BDP1?Cdl0E5AD051@D01GEeL0E5AD05EEE@1G
EeL0H61P05iNGP1OGel0G5aL06EUI@1RHV80I6AT069RHP1TI6@00P1RHV801P1UIFD0HF5Q06IVIP1U
IFD0HV9R06UYJ@80Jf][00h0HV9R06YZJP1UIFD0IFEU06ATI01SHf<0I6AT06EUI@1XJ6P0Kfm_07=c
L`1[Jf/0KVi^06e]K@80Kfm_00@0L71`075aL@1]KFd0Lg=c0P1aLG402`1bLW80KFe]06ATI01VIVH0
J6QX0:VYZ@3Ogml0dm?C0=GEe@38b<P0][Jf0080XJ6Q04/0Ng]k07EeM@1dM7@0Lg=c07AdM01VIVH0
H61P06=SH`1HF5P0G5aL06=SH`1PH600I6AT06UYJ@1bLW80KVi^075aL@1eMGD0Lg=c06][J`1VIVH0
JVYZ075aL@1iNGT0JVYZ05mOG`1KFe/0IfMW07alO01fMWH0M7Ad07EeM@1XJ6P0JFUY07MgM`1lO7`0
Ogmo0861P@1mOGd0Ogmo08:2PP21PH40P82008>3P`1lO7`0Ogmo08F5Q@1gMgL0LG5a06e]K@1`L700
N7Qh07UiN@1kNg/0MgMg06UYJ@1RHV80IVIV06m_K`22PX80V9RH09^KV`2DU9@0Vi^K09VIV@2SXj<0
Y:BT09nOW`2PX:00TY:B08f=S@2?Shl0TI6A09VIV@2LW9`00P2FUYH01`2SXj<0YjNW09JFUP2CTi<0
T92@09VIV@2XZ:P00P2ZZZX02`2d];@0/k>c0:j^[P2ZZZX0[Jf]0:VYZ@2_[jl0[Jf]0:n_[`2[Zj/0
ZJVY0080_kno0280^[Zj0:n_[`2ZZZX0^[Zj0;no_`2g]kL0[Zj^0;>c/`2][Jd0YjNW0;2`/02e]KD0
];Bd0;2`/02h^;P0_;bl0;6a/@2f][H0/k>c0;Fe]@2b/[80Z:RX09>CT`2LW9`0/K6a0;Jf]P2g]kL0
_;bl0;Vi^@2f][H0];Bd0;>c/`2a/K40^KVi0P30`<005@2n_[h0_Kfm0;Zj^P2i^KT0]KFe0;^k^`2l
_;`0_Kfm0<C4a02n_[h0_;bl0<71`@33`l<0aLG50<?3``31`L40_Kfm0<?3``37alL0c<c<0<W9b@02
0<G5a@0<0<;2`P36a/H0cLg=0<C4a036a/H0b/[:0<G5a@2`/;00ZJVY09ZJVP2XZ:P0/[:b0P2j^[X2
0;^k^`030;jn_P33`l<0a<C40080a/K600/0bLW90<[:bP39bLT0bLW90<_;b`3=cLd0bLW90<S8b039
bLT0c<c<0<_;b`020<[:bP80b<S80`35aLD20<C4a0070<;2`P38b<P0b<S80<c<c039bLT0cLg=0<o?
c`020=7Ad@0<0=CDe03Cdm<0eMGE0=?Cd`3;bl/0ZZZZ08n?S`2BTY80V9RH09^KV`2LW9`0Vi^K0P2I
VIT07`2HV9P0UiNG096AT@2FUYH0UiNG09FEU@2?Shl0T92@08^;R`24Q8@0Ph>307moO`24Q8@0Ti>C
0:b/[034a<@0dM7A0=WIf@3Kfm/0f][J0<c<c034a<@0]kNg0;no_`2l_;`0_Kfm0;Jf]P30`<00b<S8
0<k>cP3De=@00P3Fe]H01@3AdM40d];B0=?Cd`3Cdm<0dM7A0080d=3@00/0cLg=0<W9b@3:b/X0c<c<
0<k>cP3=cLd0b/[:0<O7a`39bLT0alO70<_;b`020<c<c0030<_;b`3>c/h0d];B0080d=3@00<0dm?C
0=KFeP3Hf=P00P3Jf]X05P3Kfm/0g]kN0>3Ph03QhN40g=cL0=oOg`2j^[X0?clo02PX:00a<C40;Bd]
02XZ:P0[:b/0;2`/03<c<`0d=3@0;Bd]038b<P0a<C40<c<c03Hf=P0d=3@203Lg=`0603@d=00h>3P0
>3Ph038b<P0_;bl0;2`/0P0Z:RX202d];@06030`<00e=CD0?3`l034a<@0f=SH0=cLg0P0e=CD03@0d
=3@0<c<c02PX:00U9BD07alO02DU9@0X:2P0=3@d05=CD`1[Jf/0OWin08b<S02EUID00P2KVi/03@2H
V9P0Vi^K09^KV`2GUiL0TI6A08b<S02@T900UYJF09NGU`2MWId0WinO0:2PX02TY:@00P2OWil0502T
Y:@0WYjN09jNWP2NWYh0WIfM09bLW02PX:00XJ6Q09^KV`2LW9`0VYZJ09VIV@2JVYX0Vi^K09jNWP2L
W9`0VYZJ09fMW@2NWYh0Vi^K0P2MWId0202IVIT0UYJF09ZJVP2IVIT0Vi^K09RHV02IVIT0VYZJ3P38
h=P000`0b>3H0P1SHf<01P1QHF40Hf=S06ATI01TI6@0IFEU06=SH`<0I6AT01T0Hf=S06MWI`1VIVH0
HV9R06ATI01QHF40H61P065QH@1PH600GemO069RHP1QHF40GUiN065QH@1TI6@0JVYZ071`L01iNGT0
Ph>308V9R@2;Rh/0UiNG09BDU02JVYX0WIfM0080XZ:R00<0Y:BT0:NWY`2YZJT00`2WYjL0:@2YZJT0
ZZZZ0:VYZ@2WYjL0Xj>S0:RXZ02YZJT0ZZZZ0:RXZ02UYJD0Xj>S09nOW`2KVi/0U9BD09:BTP2>SXh0
Ph>307]kN`1bLW80JVYZ061PH01HF5P0Cdm?04i>CP1;Bd/0Cdm?051@D01BDU80DE5A05]KF`1EEED0
EeMG05]KF`1PH600GUiN065QH@1OGel0I6AT05mOG`1TI6@0HV9R0080IVIV00`0IFEU06QXJ01RHV80
IVIV06UYJ@1ZJVX0IVIV06][J`1YJFT0Jf][06ATI01VIVH206=SH`80I6AT0P1XJ6P03P1ZJVX0M7Ad
06UYJ@1]KFd0K6a/075aL@1/K6`0M7Ad06m_K`1/K6`0MgMg06m_K`1cLg<0LG5a0P1ZJVX206MWI`06
08n?S`3De=@0d];B0=3@d03>c/h0/K6a0P2CTi<01P2=SHd0MgMg07MgM`1_Kfl0IVIV06EUI@80GEeM
00<0Hf=S05iNGP1TI6@00P1XJ6P00`1QHF40IFEU06i^KP0206i^KP0/071`L01bLW80Kfm_075aL@1^
KVh0Kfm_07IfMP1bLW80JFUY061PH01[Jf/0N7Qh08B4Q01eMGD0LG5a06EUI@1ZJVX0Ng]k07inOP20
P800Ogmo07IfMP1gMgL0OWin0861P@23Ph<0O7al07IfMP21PH40QXJ60861P@1kNg/0Lg=c075aL@1j
NWX0P82008F5Q@1lO7`0KFe]06IVIP1OGel0L71`07emO@2=SHd209RHV00D09nOW`2VYZH0WinO0:NW
Y`2VYZH0UYJF092@T02BTY80WinO09fMW@2LW9`0Shn?096AT@2GUiL0XZ:R0;Bd]02b/[80V9RH09:B
TP2GUiL20::RXP0<0;>c/`2][Jd0][Jf0:f][@2ZZZX0ZJVY0:ZZZP2[Zj/0ZZZZ0;2`/02f][H0^[Zj
0P2e]KD02P2f][H0_;bl0;no_`2o_kl0/[:b0:ZZZP2^[Zh0[:b/0:n_[`2f][H20;6a/@0Y0;no_`2j
^[X0]KFe0:f][@2d];@0]kNg0;Fe]@2f][H0[Zj^0:f][@2SXj<0V9RH0:RXZ02`/;00]kNg0;Bd]02e
]KD0/[:b0;2`/02f][H0_kno0<71`@2n_[h0^;Rh0;bl_02m_Kd0]KFe0;:b/P2n_[h0`/;20;jn_P30
`<00`L710<C4a035aLD0`l?30<K6aP34a<@0_kno0;^k^`36a/H00`38b<P03P35aLD0`l?30<G5a@37
alL0bl_;0<?3``37alL0bl_;0<W9b@36a/H0a<C40:j^[P2HV9P0WinO0P2YZJT05P2g]kL0a<C40<?3
``33`l<0b<S80<O7a`3:b/X0b<S80<O7a`39bLT0b/[:0<g=c@3<c<`0b<S80<C4a038b<P0bLW90<c<
c03:b/X0bl_;0<[:bP38b<P20<O7a`080<C4a032`/80alO70<K6aP3<c<`0bl_;0<[:bP3=cLd20=7A
d@0G0=CDe03Cdm<0fMWI0=OGe`3IfMT0c/k>0;^k^`2GUiL0Shn?096AT@2EUID0VIVI09ZJVP2KVi/0
VIVI09JFUP2HV9P0VIVI09RHV02FUYH0U9BD09RHV02DU9@00P2<S8`208J6QP0H0820P01gMgL0L71`
07UiN@2BTY80][Jf0<O7a`3Cdm<0gMgM0=OGe`3?cll0b<S80;jn_P2f][H0_Kfm0;no_`2a/K40_;bl
0<K6aP3>c/h0dM7A0=KFeP3EeMD0e=CD0P3EeMD20=;BdP070=7Ad@3@d=00bl_;0<[:bP3=cLd0d=3@
0<c<c0020<[:bP040<W9b@38b<P0b<S80<W9b@80cLg=01H0b/[:0<k>cP3?cll0d=3@0=;BdP3EeMD0
f=SH0=_Kf`3Jf]X0fm_K0=gMg@3Ph>00hN7Q0=kNgP3MgMd0b/[:05YJFP0];Bd0;bl_02XZ:P0W9bL0
9RHV0P0_;bl00`0b<S80<30`02l_;`0202h^;P0T03@d=00n?Sh0=SHf03Ph>012@T80=cLg03Hf=P0e
=CD0<30`034a<@0c<c<0;bl_02h^;P0e=CD0<C4a03<c<`0a<C40<S8b02d];@0g=cL0=3@d034a<@0h
>3P0=3@d02`/;00X:2P08b<S024Q8@0R8R80;2`/03Xj>P1MGEd0MWIf08B4Q02ATI40WIfM0P2LW9`2
09VIV@0509JFUP2DU9@0Shn?08n?S`2BTY800P2JVYX00`2MWId0WYjN0:6QX@020:6QX@060::RXP2O
Wil0XJ6Q0:6QX@2OWil0Vi^K0P2OWil03P2TY:@0W9bL09VIV@2OWil0WIfM09^KV`2OWil0W9bL09fM
W@2LW9`0WIfM09ZJVP2IVIT0W9bL0`2NWYh01@2GUiL0WIfM09RHV02NWYh0Vi^K00h0b>3H000<0<SP
f080Hf=S00D0IFEU061PH01SHf<0HV9R05eMG@0306EUI@80Hf=S00@0I6AT06=SH`1PH600IFEU0P1Q
HF404P1PH600GUiN06EUI@1MGEd0F5QH05aLG01PH600IFEU06UYJ@1`L700OWin08B4Q027QhL0S8b<
096AT@2EUID0W9bL09VIV@80Y:BT00@0XZ:R0:RXZ02TY:@0Z:RX0P2TY:@0102YZJT0YJFU0:FUY@2Y
ZJT20:ZZZP0D0:b/[02YZJT0YjNW0:VYZ@2TY:@0WYjN09^KV`2FUYH0T92@08Z:RP1oOgl0NGUi07=c
L`1[Jf/0H61P05QHF01EEED0Cdm?04Y:BP1?Cdl2055AD@0W051@D01GEeL0F5QH05]KF`1RHV80HF5Q
05iNGP1MGEd0IFEU06ATI01XJ6P0IVIV069RHP1TI6@0IVIV06QXJ01/K6`0JFUY06][J`1SHf<0IfMW
06QXJ01UIFD0KFe]06QXJ01ZJVX0IfMW065QH@1VIVH0IFEU06YZJP1VIVH0KFe]06m_K`1^KVh0Lg=c
075aL@1[Jf/0KFe]0080Kfm_00<0M7Ad07IfMP1aLG400P1dM7@02`1_Kfl0KFe]06YZJP1TI6@0Hf=S
08:2PP3?cll0f=SH0<[:bP3@d=00`l?30080UYJF01`0TY:B08B4Q01hN7P0LW9b06a/K01UIFD0GEeM
05aLG01RHV80I6AT065QH@1RHV80IfMW06ATI01QHF40GUiN06a/K01`L700KVi^075aL@1bLW80NGUi
07EeM@1/K6`0LG5a07moO`1mOGd0Lg=c0P1^KVh08`1nOWh0QHF50820P01fMWH0Kfm_06IVIP1aLG40
P82007emO@1kNg/0NGUi07QhN01mOGd0PX:208B4Q01kNg/0PH6108b<S022PX80Q8B407emO@1jNWX0
MGEe07emO@1kNg/0Ph>307EeM@1WIfL0G5aL05mOG`1TI6@0Ng]k09BDU02LW9`0Z:RX0080XZ:R00L0
WYjN09fMW@2JVYX0X:2P0:f][@2WYjL0WYjN0080UIFE00P0TY:B092@T02LW9`0/;2`0;Jf]P2^[Zh0
Xj>S08n?S`80Ti>C00@0WinO0:f][@2/[:`0Zj^[0P2][Jd20:^[Z`0l0;2`/02k^k/0^;Rh0:j^[P2`
/;00[Jf]0;Zj^P2m_Kd0_kno0;Zj^P2a/K40ZJVY0:^[Z`2`/;00/[:b0;Fe]@2c/k<0_[jn0;fm_@2a
/K40[Zj^0;2`/02f][H0^;Rh0;Bd]02a/K40^KVi0;fm_@2[Zj/0VIVI0:2PX02YZJT0[Jf]0;Fe]@2`
/;00]kNg0;^k^`31`L40`l?30;no_`2n_[h0][Jf0;Vi^@2e]KD0][Jf0;^k^`31`L40`<300;jn_P2l
_;`0`l?30<K6aP37alL0aLG50<;2`P35aLD0`<300<G5a@33`l<0a/K60P33`l<01`36a/H0a<C40<[:
bP37alL0`l?30<;2`P3:b/X00P3;bl/01@3=cLd0bLW90;Zj^P2PX:00VYZJ0080W9bL01H0]KFe0<G5
a@35aLD0bLW90<c<c036a/H0b/[:0<W9b@36a/H0bLW90<S8b03;bl/0c<c<0<S8b035aLD0alO70<W9
b@3;bl/0b/[:0<S8b037alL0bLW90P3:b/X03039bLT0alO70<W9b@38b<P0cLg=0<_;b`3<c<`0dm?C
0=GEe@3Fe]H0d];B0=GEe@80f][J00H0eMGE0<71`@2MWId0R8R808f=S@2ATI4209NGU`0:09VIV@2H
V9P0UYJF09RHV02IVIT0V9RH09ZJVP2DU9@0V9RH09ZJVP80U9BD01/0SHf=08V9R@29RHT0Ogmo07Ad
M01aLG40H61P06ATI01bLW80WIfM0;Zj^P3=cLd0emOG0=_Kf`3EeMD0bl_;0;no_`2b/[80`<300;Vi
^@2a/K40/[:b0<C4a03:b/X0d=3@0=OGe`3IfMT00P3Fe]H30=?Cd`070=3@d03?cll0clo?0<k>cP3=
cLd0c/k>0<c<c0020<_;b`040<W9b@35aLD0b<S80<S8b0<0bl_;01<0clo?0=3@d03De=@0e]KF0=WI
f@3GemL0f][J0=_Kf`3Ng]h0hN7Q0>?Sh`3Ogml0gMgM0<g=c@1]KFd09bLW02`/;00Y:BT0:RXZ0080
<C4a00P0<S8b03<c<`0e=CD0=3@d03<c<`0e=CD0=3@d04I6AP80<C4a0280<30`03<c<`0c<c<0<30`
02h^;P0];Bd0=3@d02h^;P0f=SH0;Bd]034a<@0g=cL0>CTi03Lg=`0h>3P0>CTi03Hf=P0i>CT0>c/k
03@d=00`<300;Rh^02<S8`0P82007QhN02DU9@0a<C40C4a<06=SH`1oOgl0SHf=09JFUP2GUiL0Vi^K
0P2HV9P02`2FUYH0U9BD08b<S02?Shl0SHf=092@T02EUID0VYZJ09nOW`2RXZ80WinO0080X:2P0180
WinO0:6QX@2MWId0X:2P09fMW@2LW9`0Vi^K09nOW`2LW9`0VYZJ09nOW`2NWYh0Vi^K09jNWP2JVYX0
VIVI09^KV`2NWYh209fMW@0509bLW02MWId0Vi^K09ZJVP2MWId00P2JVYX00`2IVIT0W9bL0<SPf00=
0<SPf0003038h=P205iNGP0;06EUI@1PH600Hf=S06=SH`1QHF40GUiN06ATI01SHf<0IfMW06e]K@1S
Hf<00`1RHV801@1SHf<0HF5Q069RHP1LG5`0HF5Q0080H61P00P0GUiN05mOG`1WIfL0K6a/075aL@1n
OWh0Q8B408:2PP80TI6A00H0UiNG09^KV`2MWId0WYjN0::RXP2YZJT20:NWY`040:FUY@2VYZH0YZJV
0:JVYP<0ZZZZ0P2UYJD0702WYjL0Z:RX0:RXZ02UYJD0Y:BT09bLW02FUYH0Vi^K09>CT`2<S8`0QhN7
07YjNP1_Kfl0K6a/06=SH`1GEeL0E5AD04i>CP1:BTX0C4a<051@D01=CDd0De=C055AD@1JFUX0Fe]K
061PH01QHF4205aLG080HV9R00<0I6AT06IVIP1RHV800P1QHF403@1ZJVX0IfMW069RHP1VIVH0HV9R
06IVIP1ZJVX0IfMW075aL@1WIfL0J6QX06MWI`1TI6@00P1UIFD02`1VIVH0IfMW06e]K@1_Kfl0Jf][
06a/K01[Jf/0L71`06e]K@1/K6`0L71`0080LG5a00h0Kfm_07EeM@1bLW80L71`06UYJ@1WIfL0I6AT
06=SH`1gMgL0c/k>0=_Kf`3;bl/0a/K60<W9b@80WYjN00T0U9BD07emO@1oOgl0IfMW06i^KP1KFe/0
HV9R065QH@1OGel00P1TI6@0301WIfL0IFEU06YZJP1XJ6P0Hf=S05iNGP1YJFT0K6a/075aL@1eMGD0
OGem07MgM`80LG5a00d0MWIf07UiN@1bLW80LG5a07AdM01cLg<0NWYj07inOP1lO7`0MgMg06UYJ@1W
IfL0L71`0080NWYj02`0O7al07moO`1iNGT0MgMg07]kN`23Ph<0QXJ608R8R023Ph<0Q8B408F5Q@1n
OWh0Ogmo0861P@1kNg/0Ph>307moO`1jNWX0KFe]05aLG01KFe/0L71`07emO@2JVYX0WinO0:>SX`2P
X:00U9BD09RHV02OWil0/K6a0;Fe]@2][Jd0WYjN08n?S`2@T900U9BD09^KV`2LW9`0WinO0:RXZ02d
];@0^k^k0:f][@80WIfM00`0TI6A09fMW@2TY:@0Zj^[0:j^[P2a/K40[:b/0;>c/`2n_[h0^[Zj0;2`
/02c/k<20:j^[P070;Ng]`2j^[X0_;bl0;Ng]`2j^[X0ZJVY0;Fe]@020;>c/`040;Rh^030`<00_kno
0;Ng]`80]KFe0100_;bl0;Vi^@2b/[80[Zj^0;Rh^02n_[h0]kNg0:j^[P2a/K40];Bd09fMW@2SXj<0
ZJVY0;6a/@2n_[h0`l?30P2m_Kd02P30`<00_[jn0;Vi^@2e]KD0][Jf0;Rh^031`L40`l?30<;2`P33
`l<20<C4a0050<;2`P37alL0a/K60<S8b036a/H00P34a<@04P31`L40`/;20<C4a030`<00aLG50<S8
b037alL0`l?30;fm_@33`l<0bl_;0<W9b@3=cLd0bl_;0<O7a`2o_kl0^;Rh0:VYZ@80VIVI00@0Z:RX
0:f][@30`<00a/K60P3:b/X02038b<P0bLW90<G5a@35aLD0alO70<g=c@3<c<`0bLW90P38b<P0103;
bl/0bLW90<W9b@38b<P20<[:bP030<c<c03=cLd0c<c<0080bl_;00H0b<S80<c<c03=cLd0d=3@0=KF
eP3De=@20=GEe@0=0=SHf03IfMT0e]KF0<;2`P2QXJ40RHV908F5Q@2?Shl0Ti>C09JFUP2CTi<0UiNG
09JFUP0209VIV@0509NGU`2KVi/0VYZJ09bLW02HV9P00P2FUYH05P2EUID0U9BD08b<S02<S8`0Q8B4
07YjNP1aLG40IFEU05UIF@1FEUH0Fe]K07MgM`2UYJD0`L710=?Cd`3MgMd0eMGE0<o?c`3:b/X0_kno
0:n_[`2d];@20:b/[0040<30`03<c<`0dM7A0=KFeP80emOG00@0eMGE0=KFeP3Fe]H0d];B0P3?cll0
1P3Bd]80e=CD0=7Ad@3?cll0cLg=0<c<c080bLW900@0b<S80<[:bP3:b/X0bl_;0P3<c<`04P3@d=00
e=CD0=GEe@3Fe]H0emOG0=[JfP3Kfm/0gmoO0>?Sh`3Rh^80hN7Q0=oOg`3AdM40O7al02LW9`0`<300
:2PX02d];@80<S8b0100;Bd]03<c<`0c<c<0<c<c03@d=00f=SH0?3`l03Ph>00g=cL0<30`02l_;`0e
=CD0<c<c038b<P0a<C40;Rh^0P0`<3006P0^;Rh0:RXZ02TY:@0/;2`0=cLg030`<00g=cL0?Shn038b
<P0f=SH0>3Ph03hn?P0`<300:BTY020P800T92@08B4Q02@T900Y:BT0@D5105EEE@1[Jf/0QXJ6092@
T02EUID0W9bL0P2JVYX209JFUP0;09:BTP2ATI40SXj>08n?S`2BTY80Vi^K09fMW@2QXJ40WinO0::R
XP2SXj<00P2RXZ804P2PX:00WIfM0:2PX02PX:00WIfM09bLW02OWil0WYjN09bLW02OWil0WIfM09bL
W02NWYh0WIfM09ZJVP2KVi/0WYjN09nOW`80WYjN00@0UiNG09VIV@2JVYX0W9bL0P2KVi/00`2QXJ40
b>3H0<SPf00<0<SPf0003038h=P305mOG`0506EUI@1NGUh0Hf=S061PH01RHV800P1SHf<02`1OGel0
IFEU06EUI@1SHf<0HV9R06EUI@1PH600IFEU06=SH`1OGel0HF5Q0080GUiN00<0GEeM05aLG01SHf<0
0P1`L7002P1lO7`0Ph>308f=S@2?Shl0TY:B09>CT`2HV9P0WinO0:2PX02TY:@20:RXZ00:0:VYZ@2Z
ZZX0ZJVY0:VYZ@2VYZH0Z:RX0:NWY`2TY:@0YJFU0:JVYP80Y:BT01<0Z:RX0:>SX`2RXZ80WinO09fM
W@2JVYX0U9BD08Z:RP25QHD0NWYj071`L01[Jf/0IFEU05QHF01DE5@0EUIF04U9B@1>CTh0D51@0080
E5AD01/0De=C05QHF01JFUX0G5aL065QH@1MGEd0H61P05aLG01RHV80Hf=S06IVIP1UIFD0I6AT06MW
I`1XJ6P0I6AT06MWI`1PH600GemO06=SH`1^KVh0IFEU06QXJ01QHF40IfMW06IVIP1UIFD00P1WIfL0
0`1VIVH0Jf][06][J`0206QXJ00706YZJP1^KVh0Kfm_071`L01^KVh0KFe]06m_K`02075aL@0=079b
LP1aLG40L71`06a/K01[Jf/0IFEU06IVIP1`L700][Jf0=WIf@3De=@0b<S80<O7a`020:^[Z`1D09fM
W@26QXH0MgMg07EeM@1XJ6P0Hf=S06ATI01WIfL0JFUY06EUI@1OGel0K6a/06][J`1YJFT0IfMW06YZ
JP1VIVH0FUYJ061PH01[Jf/0MGEe07QhN01jNWX0N7Qh07AdM01eMGD0KVi^07MgM`1nOWh0Q8B407em
O@1fMWH0NWYj07inOP1oOgl0NWYj07IfMP1dM7@0LG5a07alO023Ph<0OWin07alO01hN7P0KFe]07]k
N`24Q8@0QHF508:2PP25QHD0Q8B408f=S@2FUYH0S8b<08:2PP21PH40QXJ608:2PP1nOWh0KVi^065Q
H@1RHV80JFUY0861P@2CTi<0VYZJ09JFUP2EUID0W9bL0:^[Z`2b/[80[jn_0:RXZ02UYJD0UiNG092@
T02QXJ40XZ:R09nOW`2KVi/0Xj>S0:BTY02e]KD0^[Zj0P2/[:`0?@2@T900Shn?09bLW02QXJ40[:b/
0:^[Z`2d];@0_[jn0;Ng]`2f][H0/K6a0;>c/`2f][H0[jn_0;Ng]`2e]KD0[Zj^0;:b/P2f][H0_;bl
0;Zj^P2d];@0][Jf0<71`@30`<00/k>c0;Rh^02j^[X0]kNg0;Vi^@2`/;00[jn_0;Zj^P30`<00]KFe
0;:b/P2g]kL0`L710;Fe]@2ZZZX0Z:RX09fMW@2[Zj/0_Kfm0;^k^`2d];@0_[jn0<?3``2m_Kd0];Bd
0;Jf]P30`<00`l?30<30`032`/80alO70<_;b`36a/H0`l?30<C4a037alL00`33`l<01030`<00_kno
0<G5a@35aLD20<?3``0>0<G5a@38b<P0a<C40<30`031`L40b<S80<W9b@3<c<`0bl_;0<S8b037alL0
`<300;no_`2g]kL20;Zj^P0:0;Jf]P2UYJD0[jn_0<71`@39bLT0b/[:0<G5a@36a/H0`l?30<C4a0<0
c<c<00T0bLW90<_;b`3<c<`0c<c<0<_;b`36a/H0cLg=0<k>cP3;bl/00P3=cLd01`3;bl/0d=3@0<g=
c@3<c<`0cLg=0=?Cd`3EeMD00P3GemL04`3De=@0f=SH0=KFeP3=cLd0`<3009jNWP26QXH0Q8B408J6
QP2DU9@0UIFE09ZJVP2FUYH0UiNG09bLW02FUYH0VYZJ09fMW@2IVIT00P2KVi/06P2JVYX0V9RH09VI
V@2EUID0TI6A09>CT`2@T900QHF507alO01hN7P0IVIV05YJFP1@D500A4A404];B`1QHF40U9BD0;Rh
^039bLT0d];B0=cLg03Hf=P0clo?0<71`@2f][H0/;2`0P2ZZZX00`2m_Kd0bl_;0<o?c`020=CDe00>
0=OGe`3Lg=`0f=SH0=KFeP3De=@0d=3@0=?Cd`3Bd]80dM7A0=;BdP3=cLd0clo?0<[:bP38b<P20<[:
bP0=0<g=c@3<c<`0cLg=0<_;b`3=cLd0d=3@0=?Cd`3De=@0e]KF0=[JfP3Lg=`0gMgM0>7Qh@020>;R
hP030>3Ph03Cdm<0QXJ60080:2PX00@09BDU02TY:@0Y:BT0;bl_0P0g=cL00`0f=SH0<c<c03Ph>002
03Lg=`0303Xj>P0h>3P0:BTY00<0<S8b01l0:RXZ02h^;P0[:b/0;Bd]02`/;00[:b/0:BTY02XZ:P0/
;2`0;Bd]034a<@0e=CD0<S8b03Ph>00b<S80=SHf03<c<`0a<C40<30`02PX:00T92@08R8R024Q8@0U
9BD0;Bd]04M7A`1JFUX0MgMg08j>SP2GUiL0VIVI0080W9bL00l0V9RH09FEU@2EUID0T92@096AT@2@
T900SHf=09JFUP2KVi/0WinO0:2PX02QXJ40XZ:R0:BTY02RXZ800P2OWil209jNWP050:>SX`2OWil0
WYjN09jNWP2LW9`00P2MWId0102PX:00XJ6Q09fMW@2RXZ8309^KV`0909bLW02KVi/0UYJF09BDU02H
V9P0VYZJ09bLW02OWil0Vi^K00h0b>3H000<0<SPf080GemO00@0H61P05eMG@1NGUh0GUiN0P1QHF40
2`1TI6@0GUiN06=SH`1QHF40IfMW06ATI01RHV80HF5Q061PH01VIVH0GemO0080HV9R00X0GemO069R
HP1OGel0GemO06IVIP1]KFd0L71`07MgM`20P800Rh^;0P2?Shl0202FUYH0VYZJ09bLW02PX:00YJFU
0:BTY02UYJD0[:b/0`2ZZZX05@2VYZH0Zj^[0:VYZ@2ZZZX0YjNW0:RXZ02QXJ40YZJV0:FUY@2RXZ80
X:2P09fMW@2LW9`0TI6A092@T02:RXX0Ogmo07]kN`1bLW80JFUY06=SH`0205ADE00404i>CP1?Cdl0
BTY:04];B`80CTi>00h0EUIF05QHF01HF5P0GEeM05UIF@1OGel0HV9R05mOG`1XJ6P0H61P06QXJ01P
H600GemO06=SH`80I6AT01D0GUiN06YZJP1UIFD0IFEU06=SH`1RHV80JVYZ06IVIP1WIfL0I6AT065Q
H@1PH600I6AT06][J`1]KFd0JVYZ06a/K01^KVh0J6QX06i^KP1]KFd00P1[Jf/04@1cLg<0KFe]079b
LP1cLg<0L71`06m_K`1^KVh0Jf][06i^KP1XJ6P0Hf=S06i^KP2PX:00fMWI0=;BdP3De=@0^KVi0080
^;Rh00L0WinO08b<S01hN7P0Kfm_06][J`1OGel0IFEU0080JVYZ00`0J6QX065QH@1SHf<0LG5a06UY
J@1ZJVX0I6AT06EUI@1QHF40DU9B05IFEP1]KFd207=cL`06075aL@1jNWX0N7Qh06i^KP1bLW80P820
0P21PH4207UiN@0F07EeM@1iNGT0OWin08>3P`1hN7P0MgMg07YjNP1hN7P0O7al07inOP1iNGT0MgMg
079bLP1oOgl0R8R808Z:RP24Q8@0PX:208J6QP27QhL0UIFE08Z:RP80QHF500`0PH6107UiN@1fMWH0
Kfm_06IVIP1RHV80JVYZ07QhN029RHT0TI6A09fMW@2VYZH20:b/[0030:>SX`2UYJD0[Jf]0080YZJV
00P0Xj>S09fMW@2RXZ80X:2P09nOW`2XZ:P0ZJVY0:RXZ080[Jf]00d0Z:RX0;2`/02RXZ80VIVI0:6Q
X@2YZJT0_;bl0;Rh^02b/[80]kNg0;Bd]02j^[X0][Jf0080/k>c0P2[Zj/01`2/[:`0/k>c0;fm_@2m
_Kd0]KFe0<;2`P2n_[h00P2d];@01`2h^;P0_;bl0;Rh^02g]kL0/[:b0;Vi^@2o_kl00P2a/K402`2l
_;`0_[jn0;Zj^P2a/K40^[Zj0;Vi^@2WYjL0WIfM0:JVYP2YZJT0];Bd0080`l?300L0_[jn0;Zj^P2m
_Kd0`<300;bl_032`/80a<C40080b<S80140a/K60<[:bP39bLT0alO70<;2`P2l_;`0_Kfm0;no_`30
`<00alO70<?3``36a/H0aLG50<O7a`31`L40_Kfm0<;2`P030<[:bP070<g=c@38b<P0aLG50<G5a@32
`/80_[jn0<?3``020<o?c`0>0<g=c@32`/80^;Rh0;Bd]02n_[h0a<C40<?3``36a/H0_Kfm0<K6aP3>
c/h0c<c<0<_;b`3<c<`20<g=c@80c<c<00h0a<C40=3@d03>c/h0cLg=0<_;b`3?cll0d=3@0<k>cP3?
cll0dM7A0<g=c@3@d=00emOG0=KFeP80emOG00`0e]KF0<O7a`2ZZZX0T92@08>3P`21PH40QHF508f=
S@2CTi<0U9BD09NGU`2KVi/309NGU`0409^KV`2OWil0Vi^K09ZJVP80Vi^K00<0V9RH09NGU`2EUID0
0P2DU9@03`2?Shl0QhN708>3P`1hN7P0K6a/05mOG`1BDU80AdM703Ti>@0m?Cd0BDU907=cL`2PX:00
^[Zj0=3@d0020=[JfP080=;BdP3;bl/0a<C40;>c/`2[Zj/0ZJVY0;Vi^@39bLT20<c<c0040=;BdP3I
fMT0fMWI0=OGe`80eMGE01@0dm?C0=OGe`3AdM40e=CD0=7Ad@3@d=00cLg=0<_;b`36a/H0aLG50<[:
bP3<c<`0b/[:0<W9b@3;bl/0d=3@0=7Ad@3De=@0emOG0=[JfP80gMgM0P3Rh^801@3Ti>@0h^;R0=?C
d`2>SXh09RHV00809BDU00<0:2PX02/[:`0/;2`00P0^;Rh0:@0b<S80=cLg03/k>`0j>SX0@T9203hn
?P0c<c<0=3@d038b<P0^;Rh0<S8b02d];@0`<300;Bd]02XZ:P0[:b/0;2`/02l_;`0Y:BT0:RXZ03Hf
=P0b<S80;2`/03Ph>00e=CD0<C4a03<c<`0`<300<c<c03Ph>00Z:RX0:b/[02HV9P0R8R809RHV03Ti
>@0g=cL0BTY:06MWI`21PH40TI6A00@0VIVI00L0Vi^K09>CT`2@T900TI6A08j>SP2?Shl0TI6A0080
VYZJ00D0XJ6Q0:2PX02PX:00XZ:R0:>SX`0209nOW`0309jNWP2PX:00WIfM0080WinO00`0WYjN09nO
W`2OWil0W9bL09fMW@2LW9`0X:2P09fMW@2OWil0WIfM09jNWP2JVYX209bLW00609ZJVP2KVi/0W9bL
0::RXP2LW9`0Vi^K3P38h=P000`0b>3H0P1LG5`205mOG`0;06ATI01JFUX0H61P069RHP1MGEd0GemO
06YZJP1PH600IfMW069RHP1PH6000P1QHF406@1UIFD0GemO069RHP1PH600Hf=S05eMG@1IFET0H61P
06=SH`1[Jf/0MgMg07alO022PX80PH6108f=S@2BTY80U9BD09VIV@2PX:00XJ6Q0:NWY`2UYJD0YjNW
0:JVYP2WYjL00P2YZJT00`2VYZH0Zj^[0:ZZZP020:RXZ00F0:JVYP2XZ:P0YZJV0:JVYP2TY:@0XZ:R
09fMW@2JVYX0TI6A092@T02=SHd0Ogmo07]kN`1`L700KFe]06=SH`1LG5`0EEEE04Q8B01<C4`0CTi>
04a<C080DE5A00h0E5AD05=CD`1FEUH0Fe]K05QHF01KFe/0GEeM05mOG`1PH600HV9R065QH@1RHV80
Hf=S069RHP80IfMW00<0IFEU06QXJ01UIFD00P1TI6@02P1UIFD0Hf=S06EUI@1RHV80IFEU06QXJ01U
IFD0IfMW06][J`1XJ6P206a/K00306MWI`1]KFd0KVi^0080K6a/0180JVYZ06e]K@1_Kfl0LG5a079b
LP1^KVh0LW9b07QhN01/K6`0JFUY06IVIP1OGel0HV9R09FEU@3IfMT0e]KF0<o?c`2l_;`20:^[Z`0P
0:ZZZP2FUYH0RHV9075aL@1VIVH0GUiN065QH@1SHf<0JVYZ06i^KP1XJ6P0Jf][06MWI`1_Kfl0JFUY
06a/K01ZJVX0KFe]069RHP1DE5@0H61P06YZJP1eMGD0Kfm_075aL@1dM7@0Lg=c07IfMP1mOGd0NWYj
07emO@21PH4207inOP0<07]kN`1bLW80Ng]k08:2PP1kNg/0N7Qh07AdM01WIfL0MWIf07emO@1nOWh0
Ogmo0P1nOWh06P22PX80R8R808:2PP23Ph<0OGem07]kN`27QhL0Ph>308:2PP25QHD0QhN707]kN`20
P800LW9b06a/K01]KFd0I6AT075aL@2:RXX0Xj>S0:ZZZP2XZ:P0Xj>S0:6QX@2XZ:P0Zj^[0P2b/[80
1P2XZ:P0YZJV0:6QX@2RXZ80ZZZZ0:>SX`80WYjN0P2MWId01P2YZJT0^;Rh0;Fe]@2WYjL0UiNG0:FU
Y@80/[:b01H0][Jf0;Fe]@2f][H0];Bd0;Zj^P2f][H0/K6a0;2`/02ZZZX0YjNW0:b/[02g]kL0/[:b
0;jn_P33`l<0^k^k0;Fe]@2l_;`0_kno0;Bd]02][Jd0/k>c0P2n_[h0802b/[80];Bd0;bl_030`<00
^k^k0;Bd]02n_[h0`<300;Vi^@2_[jl0ZZZZ0:FUY@2PX:00/k>c0;no_`30`<00`/;20<?3``31`L40
_[jn0;bl_034a<@0bLW90<S8b037alL0a/K60<_;b`39bLT0alO70;bl_02j^[X0`<300P38b<P02036
a/H0alO70<S8b033`l<0`<300;fm_@2o_kl0bLW90`3:b/X01`3<c<`0a/K60<G5a@35aLD0alO70<C4
a03=cLd00P3Cdm<02`3>c/h0cLg=0<[:bP30`<00_[jn0<71`@35aLD0`L710;no_`37alL0b<S80080
c<c<00X0clo?0<g=c@3<c<`0bl_;0<[:bP39bLT0c<c<0=3@d03?cll0cLg=0P3?cll04@3=cLd0d=3@
0=;BdP3?cll0e]KF0=[JfP3IfMT0fm_K0=;BdP34a<@0XZ:R07inOP1hN7P0MgMg0861P@28R8P0T92@
0080U9BD0P2FUYH01P2IVIT0W9bL09ZJVP2LW9`0WinO09bLW080Vi^K01l0VYZJ09bLW02LW9`0U9BD
09JFUP2?Shl0SHf=08V9R@28R8P0M7Ad06a/K01SHf<0H61P05MGE`18B4P0;bl_02d];@0j>SX0EeMG
08B4Q02][Jd0a/K60=GEe@3Jf]X0emOG0=3@d038b<P0^[Zj0:j^[P2TY:@0[jn_0080`L7100T0bl_;
0=7Ad@3EeMD0f=SH0=GEe@3Fe]H0eMGE0=OGe`3EeMD00P3Cdm<03P3De=@0d=3@0=3@d039bLT0_[jn
0<?3``39bLT0c<c<0<_;b`3<c<`0cLg=0=3@d03De=@0e]KF0P3Jf]X04@3MgMd0h^;R0>?Sh`3Zj^X0
iNGU0=CDe02BTY80:RXZ02LW9`0V9RH0:RXZ02TY:@0c<c<0>3Ph03<c<`0b<S80=SHf0080>CTi01`0
<S8b03`l?00[:b/0<30`02/[:`0^;Rh0:BTY02l_;`0X:2P0:BTY02/[:`0f=SH0<c<c034a<@0];Bd0
<c<c034a<@0f=SH0;Bd]02l_;`0b<S80>c/k038b<P0f=SH0<c<c03Ph>00^;Rh0;2`/0P0W9bL0200[
:b/0<C4a03@d=012@T80EeMG071`L026QXH0UIFE0P2JVYX02P2OWil0Vi^K09RHV02EUID0TY:B096A
T@2<S8`0T92@09FEU@2IVIT209fMW@0309nOW`2RXZ80WinO0080WinO00X0WIfM0::RXP2OWil0W9bL
09fMW@2OWil0X:2P09jNWP2LW9`0WinO0P2MWId02P2LW9`0WinO09jNWP2KVi/0WIfM09bLW02MWId0
W9bL09^KV`2NWYh209nOW`0309fMW@38h=P0b>3H00`0b>3H000<0<SPf080GEeM00H0GemO05UIF@1R
HV80GUiN069RHP1QHF4205mOG`0<06=SH`1QHF40I6AT05aLG01QHF40GUiN061PH01SHf<0GEeM061P
H01[Jf/0GUiN0P1SHf<01@1RHV80HF5Q06e]K@1dM7@0O7al0080QHF500D0SHf=096AT@2EUID0W9bL
09fMW@0209nOW`040:JVYP2UYJD0ZJVY0:f][@<0Z:RX0P2YZJT08@2XZ:P0YJFU0:NWY`2YZJT0YJFU
0::RXP2SXj<0W9bL09fMW@2IVIT0TY:B09FEU@2<S8`0OWin07MgM`1_Kfl0J6QX05iNGP1DE5@0Cdm?
04e=C@1:BTX0CDe=04i>CP1ADE40ADE5055AD@1FEUH0FUYJ05]KF`1NGUh0H61P05aLG002061PH004
069RHP1OGel0GemO06=SH`80HV9R00D0Hf=S061PH01UIFD0IFEU06YZJP0206EUI@80Hf=S00X0IVIV
061PH01YJFT0Hf=S06a/K01[Jf/0IfMW06e]K@1_Kfl0J6QX0P1ZJVX0501/K6`0L71`06m_K`1/K6`0
L71`06m_K`1aLG40MWIf071`L01^KVh0JVYZ06=SH`1YJFT0HF5Q06QXJ027QhL0eMGE0=OGe`39bLT0
`l?30P2][Jd05`2/[:`0Zj^[08n?S`1^KVh0IFEU05aLG01PH600J6QX06MWI`1TI6@0HF5Q06e]K@1Z
JVX0Kfm_075aL@1_Kfl0Hf=S06a/K01[Jf/0Kfm_05aLG01GEeL0IfMW0080LG5a00D0NGUi07IfMP1i
NGT0NWYj07EeM@0207UiN@0W07inOP24Q8@0Ogmo07MgM`1aLG40NWYj07moO`21PH40NWYj06m_K`1b
LW80Kfm_07UiN@1oOgl0P82007inOP20P800QXJ608Z:RP29RHT0Ogmo07]kN`1eMGD0NGUi08F5Q@26
QXH0RHV90861P@1kNg/0Lg=c07MgM`1^KVh0IfMW06YZJP1jNWX0TI6A0:2PX02QXJ40WinO0080X:2P
00@0[jn_0;Fe]@2^[Zh0/K6a0P2[Zj/01@2ZZZX0Xj>S0:BTY02JVYX0VIVI0080VYZJ02X0Xj>S0:j^
[P2g]kL0]KFe0:b/[02NWYh0WinO0:RXZ02`/;00^[Zj0;Rh^02g]kL0^[Zj0;Jf]P2e]KD0[Zj^0:n_
[`2c/k<0/K6a0:f][@2b/[80`<300<71`@2k^k/0^[Zj0<C4a02m_Kd0[jn_0;Fe]@31`L40_[jn0;Fe
]@2`/;00`/;20<?3``2k^k/0^;Rh0;no_`32`/80]kNg0;>c/`2f][H20;Vi^@040;Jf]P2][Jd0[Zj^
0;Fe]@80`L710P2n_[h03036a/H0b<S80<S8b035aLD0b<S80<G5a@37alL0b<S80<71`@2n_[h0`/;2
0<O7a`80b<S800T0alO70<G5a@34a<@0_;bl0;Vi^@32`/80b<S80<W9b@3:b/X00P38b<P01036a/H0
aLG50<O7a`39bLT20<[:bP0E0<o?c`3Bd]80d];B0=3@d03AdM40b<S80<o?c`3>c/h0bl_;0<W9b@37
alL0_[jn0<71`@33`l<0b<S80<W9b@37alL0b/[:0<_;b`3>c/h0cLg=0080c/k>00@0clo?0<g=c@3>
c/h0c/k>0P3?cll0103@d=00d];B0=CDe03Fe]H20=SHf00A0=OGe`34a<@0VIVI075aL@1[Jf/0MWIf
07inOP23Ph<0QXJ6092@T02DU9@0V9RH09NGU`2HV9P0Vi^K09bLW02GUiL00`2MWId209VIV@0O09jN
WP2LW9`0V9RH09ZJVP2CTi<0UiNG08n?S`2:RXX0QXJ607]kN`1aLG40JVYZ05]KF`1ADE40?clo03@d
=00[:b/0:2PX02`/;00o?cl0IFEU09NGU`32`/80d=3@0=[JfP3IfMT0dm?C0<o?c`30`<00YjNW09VI
V@020:BTY0030;Jf]P37alL0c<c<0080f=SH00D0emOG0=GEe@3Hf=P0f=SH0=OGe`020=KFeP0Y0=;B
dP3@d=00c/k>0<[:bP33`l<0bLW90=;BdP3<c<`0bl_;0<c<c03@d=00dm?C0=CDe03Fe]H0f=SH0=cL
g03Ph>00h^;R0>OWi`3Shn<0e]KF09BDU00X:2P0:RXZ02HV9P0Z:RX0:BTY02`/;00^;Rh0;Bd]03@d
=00g=cL0=SHf03lo?`0d=3@0>CTi03Hf=P0`<300;Rh^03@d=00Y:BT00P0[:b/01@0];Bd0;bl_03@d
=00_;bl0;Rh^0080;2`/00@09bLW030`<00[:b/0;Bd]0P0a<C401@0`<300<c<c03dm?@0g=cL0>3Ph
0080<c<c00T0;Rh^02XZ:P0Z:RX0<c<c03De=@1=CDd0IFEU07alO02>SXh00`2GUiL04@2LW9`0VYZJ
09>CT`2EUID0TI6A092@T02<S8`0TY:B09BDU02JVYX0WinO09jNWP2QXJ40WinO0:6QX@2OWil0X:2P
0080XZ:R00<0X:2P09fMW@2NWYh00P2OWil02@2MWId0WinO0:6QX@2LW9`0Vi^K0:6QX@2OWil0WIfM
09VIV@0209^KV`80W9bL00@0WIfM0:2PX02PX:00WYjN3P38h=P000`0b>3H0P1MGEd01P1OGel0FEUI
069RHP1NGUh0HV9R065QH@80GemO00`0Hf=S065QH@1TI6@0G5aL065QH@1NGUh0H61P06=SH`1MGEd0
H61P06][J`1NGUh206=SH`05069RHP1QHF40KFe]07AdM01lO7`00P25QHD01@2=SHd0TI6A09FEU@2L
W9`0WIfM0080WinO00@0YZJV0:FUY@2YZJT0[Jf]0`2XZ:P20:VYZ@0Q0:RXZ02UYJD0YjNW0:VYZ@2U
YJD0XZ:R0:>SX`2LW9`0WIfM09VIV@2BTY80UIFE08b<S01nOWh0MgMg06m_K`1XJ6P0GUiN05ADE01?
Cdl0CDe=04Y:BP1=CDd0CTi>055AD@15ADD0DE5A05IFEP1JFUX0Fe]K05iNGP1PH600G5aL0080H61P
00@0HV9R05mOG`1OGel0Hf=S0P1RHV801@1SHf<0H61P06EUI@1UIFD0JVYZ0080IFEU0P1SHf<02P1V
IVH0H61P06UYJ@1SHf<0K6a/06][J`1WIfL0KFe]06m_K`1XJ6P206YZJP0D06a/K01`L700Kfm_06a/
K01`L700Kfm_075aL@1fMWH0L71`06i^KP1ZJVX0Hf=S06UYJ@1QHF40J6QX08N7Q`3EeMD0emOG0<W9
b@33`l<20:f][@0G0:b/[02[Zj/0Shn?06i^KP1UIFD0G5aL061PH01XJ6P0IfMW06ATI01QHF40KFe]
06YZJP1_Kfl0LG5a06m_K`1SHf<0K6a/06][J`1_Kfl0G5aL05MGE`1WIfL00P1aLG401@1iNGT0MWIf
07UiN@1jNWX0MGEe0080NGUi02L0OWin08B4Q01oOgl0MgMg075aL@1jNWX0Ogmo0861P@1jNWX0Kfm_
079bLP1_Kfl0NGUi07moO`20P800OWin0820P026QXH0RXZ:08V9R@1oOgl0Ng]k07EeM@1iNGT0QHF5
08J6QP29RHT0PH6107]kN`1cLg<0MgMg06i^KP1WIfL0JVYZ07YjNP2ATI40X:2P0:6QX@2OWil00P2P
X:00102_[jl0]KFe0:j^[P2a/K420:^[Z`050:ZZZP2SXj<0Y:BT09ZJVP2IVIT00P2JVYX0:P2SXj<0
[Zj^0;Ng]`2e]KD0[:b/09jNWP2OWil0Z:RX0;2`/02j^[X0^;Rh0;Ng]`2j^[X0][Jf0;Fe]@2^[Zh0
[jn_0;>c/`2a/K40[Jf]0;:b/P30`<00`L710;^k^`2j^[X0a<C40;fm_@2_[jl0]KFe0<71`@2n_[h0
]KFe0;2`/032`/80`l?30;^k^`2h^;P0_kno0<;2`P2g]kL0/k>c0;Jf]P80^KVi00@0][Jf0:f][@2^
[Zh0]KFe0P31`L420;jn_P0<0<K6aP38b<P0b<S80<G5a@38b<P0aLG50<O7a`38b<P0`L710;jn_P32
`/80alO70P38b<P02@37alL0aLG50<C4a02l_;`0^KVi0<;2`P38b<P0bLW90<[:bP020<S8b0040<K6
aP35aLD0alO70<W9b@80b/[:01D0clo?0=;BdP3Bd]80d=3@0=7Ad@38b<P0clo?0<k>cP3;bl/0bLW9
0<O7a`2n_[h0`L710<?3``38b<P0bLW90<O7a`3:b/X0bl_;0<k>cP3=cLd00P3>c/h0103?cll0cLg=
0<k>cP3>c/h20<o?c`040=3@d03Bd]80e=CD0=KFeP80f=SH0140emOG0<C4a02IVIT0LG5a06][J`1f
MWH0OWin08>3P`26QXH0T92@09BDU02HV9P0UiNG09RHV02KVi/0W9bL09NGU`0309fMW@80VIVI01l0
WYjN09bLW02HV9P0VYZJ09>CT`2GUiL0Shn?08Z:RP26QXH0Ng]k075aL@1ZJVX0Fe]K055AD@0o?cl0
=3@d02/[:`0X:2P0;2`/03lo?`1UIFD0UiNG0<;2`P3@d=00f][J0=WIf@3Cdm<0clo?0<30`02WYjL0
VIVI0080Y:BT00<0][Jf0<O7a`3<c<`00P3Hf=P01@3GemL0eMGE0=SHf03Hf=P0emOG0080e]KF02T0
d];B0=3@d03>c/h0b/[:0<?3``39bLT0d];B0<c<c03;bl/0c<c<0=3@d03Cdm<0e=CD0=KFeP3Hf=P0
g=cL0>3Ph03Rh^80inOW0>?Sh`3Fe]H0U9BD02PX:00Z:RX09RHV02XZ:P0Y:BT0;2`/02h^;P0];Bd0
=3@d03Lg=`0f=SH0?clo03@d=00i>CT0=SHf030`<00^;Rh0=3@d02TY:@0202/[:`0502d];@0_;bl0
=3@d02l_;`0^;Rh00P0/;2`0100W9bL0<30`02/[:`0];Bd2034a<@05030`<00c<c<0?Cdm03Lg=`0h
>3P00P0c<c<02@0^;Rh0:RXZ02XZ:P0c<c<0=CDe04e=C@1UIFD0O7al08j>SP0309NGU`0A09bLW02J
VYX0Ti>C09FEU@2ATI40T92@08b<S02BTY80U9BD09ZJVP2OWil0WYjN0:6QX@2OWil0XJ6Q09nOW`2P
X:000P2RXZ800`2PX:00WIfM09jNWP0209nOW`0909fMW@2OWil0XJ6Q09bLW02KVi/0XJ6Q09nOW`2M
WId0VIVI0080Vi^K0P2LW9`0102MWId0X:2P0:2PX02NWYh>0<SPf0003038h=P205mOG`0605aLG01M
GEd0FEUI061PH01JFUX0G5aL0P1MGEd3061PH00@069RHP1MGEd0GemO061PH01QHF40H61P05iNGP1S
Hf<0GemO05UIF@1KFe/0GEeM06=SH`1/K6`0Lg=c07inOP80Q8B400H0RXZ:096AT@2DU9@0V9RH09^K
V`2QXJ420:BTY0030:ZZZP2WYjL0YJFU0080Z:RX00<0YZJV0:NWY`2YZJT00`2WYjL20:VYZ@0N0:>S
X`2OWil0VIVI09NGU`2JVYX0TI6A08n?S`27QhL0P82007EeM@1aLG40K6a/061PH01HF5P0CDe=04I6
AP15ADD0BDU904M7A`1>CTh0Cdm?05ADE01@D500FEUI05QHF01MGEd0G5aL05eMG@1QHF40HV9R0P1T
I6@03P1QHF40Hf=S06EUI@1QHF40Hf=S06IVIP1RHV80I6AT06QXJ01TI6@0IFEU06ATI01XJ6P0JFUY
0P1TI6@0501SHf<0IVIV06IVIP1VIVH0JVYZ06MWI`1ZJVX0J6QX06][J`1_Kfl0K6a/06e]K@1`L700
KFe]06][J`1_Kfl0Lg=c06a/K01^KVh0Kfm_0P1/K6`01`1VIVH0J6QX07alO036a/H0emOG0<o?c`30
`<000P2l_;`20::RXP0608:2PP1[Jf/0GEeM05YJFP1QHF40GemO0P1SHf<05@1TI6@0IVIV06ATI01]
KFd0K6a/071`L01[Jf/0K6a/075aL@1bLW80Kfm_061PH01IFET0HF5Q06][J`1dM7@0MWIf06m_K`1d
M7@0MWIf07moO`0207]kN`80Q8B400D0OWin07QhN01mOGd0OGem0820P00207moO`0Z07AdM01]KFd0
J6QX079bLP1mOGd0Ogmo0820P02;Rh/0SXj>096AT@2=SHd0PH6107EeM@1aLG40MGEe08:2PP28R8P0
PX:207moO`1cLg<0LG5a07EeM@1[Jf/0IfMW06][J`1dM7@0R8R809ZJVP2SXj<0WinO0:>SX`2b/[80
[Zj^0:n_[`2c/k<0];Bd0;Jf]P2YZJT0Z:RX0:2PX02OWil0Xj>S0P2PX:00=P2VYZH0ZJVY0:VYZ@2d
];@0/[:b0;6a/@2WYjL0V9RH0::RXP2a/K40][Jf0;^k^`2e]KD0^KVi0;6a/@2/[:`0[jn_0;Fe]@2b
/[80[jn_0;Jf]P2h^;P0]kNg0;Jf]P2l_;`0`L710;Fe]@2b/[80b<S80<G5a@2i^KT0]KFe0;no_`33
`l<0`L710;Ng]`2f][H0^;Rh0;Fe]@2c/k<0^KVi0;Ng]`2i^KT0a<C40<;2`P2`/;00Xj>S0:n_[`2f
][H0^KVi0;^k^`37alL0b/[:0<_;b`D0b<S800h0`L710;no_`35aLD0b<S80<G5a@36a/H0b<S80<C4
a02m_Kd0^k^k0;Rh^02m_Kd0b<S80<W9b@80c<c<0P38b<P01@35aLD0bLW90<_;b`3;bl/0c<c<0080
cLg=0P3<c<`20<_;b`0:0<c<c03@d=00cLg=0=3@d03AdM40c/k>0<[:bP38b<P0b/[:0<G5a@80b<S8
0`37alL0A03=cLd0clo?0<k>cP3?cll0bl_;0=7Ad@3@d=00clo?0=7Ad@3Bd]80dm?C0=GEe@3GemL0
fMWI0=SHf03AdM40ZJVY06a/K01OGel0KVi^07MgM`1lO7`0Ph>308R8R02?Shl0UYJF09NGU`2JVYX0
Vi^K09bLW02IVIT0VYZJ09bLW02KVi/0WIfM09VIV@2JVYX0Vi^K09bLW02MWId0X:2P09FEU@2CTi<0
SHf=09BDU029RHT0P820079bLP1aLG40G5aL05EEE@16ATH0<S8b02d];@0Y:BT09BDU02LW9`0_;bl0
CDe=08J6QP2g]kL0bl_;0=SHf03MgMd0fMWI0<g=c@30`<00[:b/0P2IVIT0302FUYH0[Jf]0<K6aP3>
c/h0eMGE0=SHf03GemL0f][J0=WIf@3Jf]X0f=SH0=CDe080d];B0`3AdM400`3>c/h0dm?C0=3@d002
0<c<c00I0<S8b03>c/h0clo?0=KFeP3Hf=P0g=cL0=gMg@3Ti>@0j>SX0>GUi@3Fe]H0TY:B02`/;00X
:2P09bLW02PX:00W9bL0:b/[038b<P0`<300<S8b03<c<`0^;Rh0<S8b03<c<`02034a<@0803Hf=P0h
>3P0=CDe02l_;`0`<300;Bd]02h^;P0c<c<2030`<00=03De=@0Z:RX0;bl_02/[:`0^;Rh09RHV030`
<00^;Rh0=3@d02`/;00a<C40;Rh^03<c<`0203Ph>00:03Hf=P0e=CD0;Bd]02l_;`0/;2`0;bl_03lo
?`1FEUH0L71`08>3P`80T92@00<0VYZJ0:2PX02KVi/00P2IVIT209:BTP0:092@T02?Shl0TY:B09>C
T`2HV9P0W9bL09fMW@2SXj<0XJ6Q0:2PX0@0WYjN00D0WinO09bLW02IVIT0X:2P09bLW00209nOW`05
09fMW@2LW9`0WinO09^KV`2NWYh00P2LW9`0102OWil0WYjN09bLW02MWId20:2PX0030:6QX@38h=P0
b>3H00`0b>3H000<0<SPf080FUYJ00P0GEeM05]KF`1PH600Fe]K05aLG01PH600Hf=S05UIF@<0GEeM
00P0HF5Q061PH01PH600Hf=S05aLG01SHf<0H61P05mOG`80EUIF00l0FEUI05mOG`1XJ6P0Jf][06a/
K01iNGT0OWin08Z:RP2<S8`0UIFE09BDU02IVIT0WYjN0::RXP2SXj<00P2[Zj/00`2/[:`0YZJV0:NW
Y`020:NWY`0c0:ZZZP2XZ:P0YZJV0:BTY02UYJD0Y:BT0:NWY`2TY:@0Xj>S09bLW02KVi/0UYJF09BD
U02<S8`0Q8B408>3P`1lO7`0Lg=c06a/K01MGEd0De=C04m?C`19BDT0C4a<04e=C@1;Bd/0BDU904m?
C`1BDU80Cdm?05QHF01EEED0G5aL05]KF`1OGel0GEeM069RHP1NGUh0I6AT06IVIP1QHF40Hf=S069R
HP1SHf<0H61P06QXJ01WIfL0IFEU06UYJ@1RHV80IVIV0080I6AT00l0HV9R06EUI@1XJ6P0JFUY06IV
IP1UIFD0IVIV06MWI`1VIVH0J6QX06i^KP1[Jf/0LG5a079bLP1aLG400P1cLg<03P1]KFd0M7Ad07=c
L`1bLW80LG5a07YjNP1_Kfl0JVYZ06UYJ@1`L700/K6a0=WIf@3Bd]80_kno0P2h^;P08@2b/[80SHf=
08B4Q01bLW80GemO05iNGP1LG5`0I6AT061PH01^KVh0JVYZ06EUI@1WIfL0JFUY06YZJP1VIVH0L71`
07=cL`1gMgL0Kfm_07EeM@1bLW80IFEU05UIF@1SHf<0Kfm_07moO`1`L700Jf][06e]K@1jNWX0P820
0861P@0307inOP0`08:2PP27QhL0QHF507UiN@1dM7@0O7al07MgM`1lO7`0MWIf079bLP1cLg<0MWIf
07emO@26QXH0QhN708b<S02;Rh/0QHF50861P@1iNGT0MGEe079bLP1hN7P0R8R808V9R@1oOgl0MWIf
075aL@1_Kfl0MWIf06m_K`1YJFT0JVYZ08V9R@2DU9@0X:2P0:VYZ@2[Zj/0[:b/0;2`/02_[jl0^k^k
0;:b/P2_[jl0ZJVY0:RXZ02TY:@0WinO0P2XZ:P0=P2RXZ80XJ6Q0:FUY@2SXj<0[jn_0;Rh^02j^[X0
[:b/0:6QX@2SXj<0/;2`0:n_[`2j^[X0/;2`0:n_[`2c/k<0]KFe0;>c/`2i^KT0^;Rh0;Ng]`2][Jd0
[jn_0:j^[P2f][H0^KVi0;Bd]02n_[h0alO70<71`@2j^[X0`/;20<G5a@32`/80_Kfm0;6a/@2d];@0
^k^k0;Jf]P2k^k/0^KVi0;bl_034a<@0`l?30;Zj^P2`/;00^;Rh0;bl_02_[jl0Zj^[0;Bd]033`l<0
alO70<_;b`80bLW900D0bl_;0<W9b@33`l<0`/;20<?3``020<O7a`0=0<;2`P35aLD0a/K60<30`02l
_;`0^KVi0;fm_@34a<@0bLW90<c<c03;bl/0b<S80<W9b@030<O7a`040<_;b`3:b/X0b/[:0<g=c@<0
b<S800`0cLg=0<[:bP3=cLd0bl_;0<c<c03@d=00e=CD0=3@d03>c/h0d=3@0<k>cP3AdM420=3@d008
0<k>cP3;bl/0bl_;0<W9b@3;bl/0c<c<0<[:bP3=cLd20=3@d00C0<k>cP3AdM40eMGE0=OGe`3EeMD0
fm_K0>3Ph03Fe]H0a/K608V9R@1BDU80F5QH06QXJ01hN7P0OWin08J6QP2>SXh0Ti>C09:BTP0209NG
U`0:09^KV`2IVIT0UiNG09VIV@2LW9`0X:2P09jNWP2KVi/0WIfM09ZJVP80Vi^K01`0VYZJ09BDU02F
UYH0TI6A092@T02:RXX0PX:207IfMP1]KFd0JVYZ061PH01RHV80>c/k02/[:`0V9RH08B4Q01lO7`0W
9bL0:b/[04=3@`1aLG40YjNW0<W9b@3Cdm<0g=cL0=[JfP3Bd]80b/[:0P2d];@0202LW9`0U9BD0;:b
/P35aLD0c<c<0=GEe@3Kfm/0gMgM0P3Kfm/01@3Hf=P0emOG0=GEe@3Cdm<0dM7A0080dm?C00D0d];B
0=SHf03De=@0clo?0=3@d0020<[:bP0;0<k>cP3De=@0e]KF0=kNgP3Ogml0i^KV0>WYj@3Shn<0dm?C
09>CT`0_;bl00P0];Bd01P0Z:RX0:BTY02`/;00_;bl0:b/[02h^;P80<30`00<0<C4a03Ph>00h>3P0
0P0b<S8203`l?00603/k>`0a<C40;bl_02h^;P0_;bl0:b/[0P0`<3004@0b<S80;2`/02l_;`0V9RH0
:2PX034a<@0b<S80=3@d038b<P0e=CD0<30`03dm?@0f=SH0=cLg03<c<`0g=cL0=CDe0080;bl_00D0
<c<c03Ph>016ATH0HF5Q071`L00208V9R@07096AT@2IVIT0W9bL09VIV@2EUID0SHf=09:BTP0208n?
S`0508j>SP2BTY80UIFE09fMW@2LW9`00P2PX:002`2QXJ40WIfM09fMW@2NWYh0WinO0:6QX@2NWYh0
WinO09jNWP2OWil0XJ6Q0080WIfM0P2PX:002`2NWYh0W9bL09ZJVP2OWil0Vi^K09bLW02NWYh0Vi^K
09jNWP2OWil0WYjN00h0b>3H000<0<SPf080HF5Q01D0G5aL05UIF@1GEeL0GemO05MGE`1KFe/0GemO
05UIF@1OGel0GUiN061PH01MGEd0Hf=S06EUI@1PH600GEeM05]KF`1MGEd0FUYJ05EEE@1?Cdl00P1L
G5`01`1SHf<0JFUY06e]K@1jNWX0P82008Z:RP2>SXh00P2FUYH0202JVYX0Vi^K0:6QX@2VYZH0Z:RX
0:NWY`2ZZZX0YZJV0P2YZJT0702VYZH0ZZZZ0:NWY`2XZ:P0YJFU0:NWY`2XZ:P0YJFU0:6QX@2RXZ80
WIfM09ZJVP2IVIT0UYJF08Z:RP23Ph<0Q8B407QhN01aLG40IVIV05aLG01ADE40BTY:055AD@1=CDd0
BTY:051@D01ADE4204i>CP0604a<C01GEeL0EeMG05eMG@1KFe/0HF5Q0P1PH6001P1VIVH0J6QX06AT
I01QHF40KFe]06=SH`@0I6AT00<0Hf=S06UYJ@1OGel00P1TI6@02`1SHf<0IVIV06IVIP1TI6@0HF5Q
06=SH`1XJ6P0IfMW06UYJ@1XJ6P0JVYZ00@0Jf][0140Kfm_06a/K01`L700Lg=c079bLP1dM7@0NGUi
07AdM01cLg<0JVYZ06][J`1WIfL0KFe]0:f][@3MgMd0dm?C0<W9b@020;bl_0080:b/[02BTY80P820
07EeM@1RHV80HF5Q05iNGP1MGEd206UYJ@0306YZJP1/K6`0IFEU0080JFUY03D0Jf][06YZJP1_Kfl0
MWIf075aL@1YJFT0Lg=c07YjNP1/K6`0GUiN06IVIP1fMWH0OGem07EeM@1YJFT0Jf][07QhN024Q8@0
PH6107moO`1jNWX0Q8B408>3P`2;Rh/0PH6107UiN@1fMWH0NWYj0861P@27QhL0NGUi071`L01XJ6P0
MGEe07YjNP20P800PH6108B4Q023Ph<0Rh^;08R8R01oOgl0OGem07QhN01jNWX0Ph>308:2PP1nOWh0
LW9b06YZJP1`L700M7Ad075aL@0206IVIP0>08:2PP2KVi/0Z:RX0:ZZZP2_[jl0YjNW0;Fe]@2b/[80
[Zj^0;:b/P2h^;P0];Bd0:FUY@2[Zj/20::RXP070:NWY`2QXJ40ZJVY0:BTY02YZJT0YJFU0:n_[`02
0;Ng]`0=0:JVYP2GUiL0YZJV0:RXZ02^[Zh0]KFe0;Zj^P2g]kL0^k^k0;no_`2g]kL0/K6a0:n_[`02
0:b/[00O0:^[Z`2`/;00^[Zj0<O7a`34a<@0^k^k0;jn_P33`l<0`L710;bl_02a/K40/k>c0;Vi^@2k
^k/0_Kfm0;Rh^02l_;`0`/;20;no_`2j^[X0]kNg0<30`039bLT0_kno0;bl_02g]kL0[Jf]0;Bd]02k
^k/0`l?30<O7a`020<[:bP050<C4a030`<00aLG50<W9b@34a<@00P36a/H04@38b<P0a<C40;jn_P32
`/80`l?30<C4a037alL0cLg=0<_;b`39bLT0a/K60<C4a037alL0b<S80<W9b@3:b/X0bLW90080b<S8
02h0alO70<K6aP36a/H0clo?0<c<c039bLT0bl_;0<c<c03?cll0d=3@0=;BdP3?cll0c<c<0=3@d03A
dM40d];B0=3@d03AdM40dm?C0<k>cP3=cLd0d=3@0<o?c`3<c<`0cLg=0<o?c`3Bd]80e=CD0=7Ad@3I
fMT0g=cL0=[JfP3Ph>00fm_K0<o?c`2/[:`0JFUY04i>CP1JFUX0LG5a07QhN020P800R8R808b<S02=
SHd0TY:B0P2LW9`0102NWYh0VIVI09ZJVP2IVIT309jNWP0Q09^KV`2PX:00VYZJ09ZJVP2MWId0WYjN
09NGU`2FUYH0U9BD08^;R`2:RXX0Ph>307inOP1`L700JVYZ069RHP1IFET0?clo02l_;`0];Bd08b<S
02@T900R8R808b<S02XZ:P0i>CT0GUiN0:>SX`33`l<0d=3@0=KFeP3Jf]X0d];B0080bl_;00L0^k^k
09jNWP2KVi/0/;2`0<30`037alL0eMGE00@0fm_K00D0f=SH0=OGe`3Fe]H0e=CD0=?Cd`020=;BdP0G
0=GEe@3Fe]H0emOG0=CDe03?cll0bLW90<[:bP3De=@0eMGE0=oOg`3QhN40j>SX0>[ZjP3Ph>00c/k>
08j>SP0/;2`0:BTY02XZ:P0];Bd0:b/[02h^;P0[:b/00P0`<300200b<S80<C4a03<c<`0g=cL0>3Ph
02l_;`0h>3P0<C4a0`0b<S801P0_;bl0;Bd]02d];@0b<S80<c<c030`<080<S8b00<0;Rh^02HV9P0[
:b/00P0_;bl0300i>CT0=SHf030`<00i>CT0?Cdm03/k>`0h>3P0?3`l038b<P0a<C40=cLg030`<080
;Rh^00<0?clo04e=C@1ZJVX00P1oOgl0102:RXX0UYJF09fMW@2NWYh209JFUP0>09BDU02<S8`0TI6A
08b<S02=SHd0U9BD09RHV02IVIT0WYjN0:6QX@2OWil0WYjN0:6QX@2LW9`209nOW`0A09ZJVP2KVi/0
WYjN09jNWP2MWId0XJ6Q09nOW`2QXJ40WIfM0:2PX02NWYh0WIfM09jNWP2KVi/0WIfM09nOW`2KVi/0
0P2OWil00`2NWYh0b>3H0<SPf00<0<SPf0003038h=P205YJFP03065QH@1FEUH0GUiN0080H61P00D0
GEeM05aLG01JFUX0GUiN061PH00205aLG00L05mOG`1PH600H61P05iNGP1KFe/0G5aL05UIF@1KFe/0
EeMG05]KF`1JFUX0IFEU071`L01_Kfl0N7Qh07moO`26QXH0Rh^;096AT@2CTi<0V9RH09bLW02OWil0
XZ:R0:FUY@2VYZH0YjNW0:ZZZP80YjNW01P0ZJVY0:FUY@2TY:@0Y:BT0:JVYP2RXZ80YZJV0:FUY@2T
Y:@0X:2P09fMW@2HV9P0UiNG09:BTP2<S8`0QhN707alO01hN7P0KFe]06UYJ@1QHF40EEEE04m?C`1C
De<204Q8B00B04];B`1:BTX0C4a<04E5A@1@D500EeMG05ADE01CDe<0G5aL065QH@1KFe/0GUiN065Q
H@1SHf<0HF5Q06ATI01VIVH0Hf=S0P1PH6002P1QHF40Hf=S06QXJ01SHf<0GemO06IVIP1TI6@0HV9R
06EUI@1XJ6P206ATI00K06=SH`1VIVH0IVIV06IVIP1YJFT0IfMW06IVIP1[Jf/0Kfm_06MWI`1XJ6P0
KVi^071`L01aLG40LW9b07=cL`1aLG40MGEe07QhN01YJFT0Hf=S06IVIP1YJFT0V9RH0=_Kf`3EeMD0
cLg=0080`l?30100XZ:R09VIV@2:RXX0MGEe06MWI`1PH600Hf=S069RHP1TI6@0IFEU06MWI`1YJFT0
J6QX06MWI`1VIVH0Jf][0P1]KFd0101[Jf/0M7Ad07IfMP1kNg/2075aL@80JFUY00<0L71`07moO`1i
NGT00P1cLg<01`1XJ6P0LW9b07emO@1mOGd0P82008Z:RP20P8000P27QhL02`21PH40OWin07MgM`1b
LW80NWYj07alO01oOgl0NWYj06i^KP1_Kfl0NWYj0080Ogmo01l0QhN708Z:RP28R8P0R8R808J6QP20
P800NWYj07MgM`1lO7`0QHF507UiN@1dM7@0Jf][06e]K@1_Kfl0Jf][05YJFP1VIVH0Q8B409jNWP2X
Z:P0Y:BT0:n_[`2^[Zh0Y:BT0:n_[`2d];@0^[Zj0;Rh^02_[jl0YjNW0080Zj^[02l0ZJVY0:JVYP2]
[Jd0Y:BT0:>SX`2QXJ40V9RH0:RXZ02m_Kd0/[:b0:FUY@2[Zj/0W9bL0:BTY02b/[80/K6a0;^k^`33
`l<0^k^k0;>c/`2e]KD0^;Rh0;>c/`2YZJT0YJFU0;6a/@32`/80_[jn0;^k^`2o_kl0`l?30<K6aP2n
_[h0];Bd0;Vi^@34a<@0`/;20;Vi^@2g]kL0^[Zj0<K6aP2o_kl0^;Rh0;Ng]`35aLD0b<S80<C4a002
0<;2`P0;0<O7a`31`L40/K6a0:ZZZP2k^k/0`L710<K6aP35aLD0_Kfm0<?3``3:b/X00P37alL02`3:
b/X0b<S80<G5a@32`/80`l?30<O7a`35aLD0b<S80<_;b`3=cLd0b/[:0080b<S800<0a<C40<W9b@3;
bl/00P3:b/X01038b<P0`l?30<C4a039bLT20<S8b00:0<W9b@38b<P0a<C40<[:bP3>c/h0cLg=0<o?
c`3Cdm<0c<c<0<S8b080d=3@00L0clo?0=;BdP3AdM40d];B0<o?c`3Bd]80dM7A0080d=3@01l0dM7A
0<o?c`3GemL0emOG0=_Kf`3Ph>00gmoO0=cLg03Ogml0dm?C0;^k^`1lO7`0C4a<059BDP1LG5`0Kfm_
07YjNP21PH40R8R808Z:RP2>SXh0V9RH09ZJVP2NWYh0WIfM09bLW02OWil0V9RH09nOW`2NWYh0WinO
00<0WYjN01h0VYZJ09^KV`2PX:00VIVI09NGU`2KVi/0Ti>C08^;R`29RHT0PH6107IfMP1XJ6P0H61P
051@D016ATH0<30`02/[:`0T92@08R8R02@T900R8R808b<S02HV9P0`<300DU9B09FEU@2l_;`0bLW9
0=CDe03Jf]X20=SHf00?0<k>cP31`L40Zj^[09RHV02JVYX0^;Rh0<[:bP3Cdm<0f][J0=gMg@3Kfm/0
fMWI0=SHf03GemL0e]KF0080e=CD00`0dm?C0=SHf03IfMT0f=SH0=WIf@3EeMD0e]KF0=7Ad@3Fe]H0
fm_K0=kNgP3Shn<20>WYj@030=oOg`3;bl/0Lg=c0080;2`/02<0:RXZ02`/;00X:2P0<30`02`/;00^
;Rh0=cLg02l_;`0^;Rh0<S8b034a<@0d=3@0<30`03/k>`0d=3@0>c/k03De=@0d=3@0>3Ph034a<@0d
=3@0;bl_038b<P0^;Rh0<c<c02/[:`0];Bd0;2`/02XZ:P0T92@0:b/[03Lg=`0];Bd0<30`038b<P03
03Ti>@0:03/k>`0j>SX0>3Ph03Ph>00c<c<0>3Ph02h^;P0h>3P0ADE505QHF080L71`0180QXJ608Z:
RP2KVi/0UIFE09VIV@2GUiL0UIFE092@T02ATI40SXj>08^;R`2?Shl0UYJF09VIV@2PX:00WIfM0:2P
X02NWYh20::RXP030:>SX`2OWil0WinO0080X:2P00H0Y:BT09nOW`2QXJ40XZ:R09jNWP2OWil20:2P
X0050::RXP2MWId0WIfM09jNWP2OWil00P2NWYh00`2JVYX0W9bL0<SPf00=0<SPf0003038h=P205YJ
FP0R05mOG`1HF5P0GEeM05]KF`1HF5P0I6AT065QH@1KFe/0GUiN065QH@1MGEd0Fe]K06IVIP1QHF40
GemO069RHP1LG5`0EeMG05]KF`1LG5`0FEUI05=CD`1JFUX0HF5Q06e]K@1dM7@0NGUi08B4Q029RHT0
SHf=09FEU@2BTY80VYZJ09^KV`80XJ6Q00@0XZ:R0:FUY@2WYjL0ZJVY0`2XZ:P0102VYZH0Y:BT0:NW
Y`2VYZH20::RXP0R0:2PX02TY:@0XJ6Q09jNWP2KVi/0VIVI096AT@2<S8`0Ph>308:2PP1fMWH0KFe]
06IVIP1KFe/0EeMG059BDP15ADD0AdM704Y:BP15ADD0C4a<04Y:BP19BDT0CDe=051@D01GEeL0F5QH
05iNGP1TI6@0GemO05YJFP1LG5`0HV9R05mOG`80Hf=S00/0HV9R061PH01SHf<0I6AT06IVIP1QHF40
IVIV06EUI@1TI6@0Hf=S069RHP0206ATI00406=SH`1UIFD0HF5Q06ATI0<0JVYZ00L0K6a/06UYJ@1U
IFD0Jf][06a/K01ZJVX0L71`0080LW9b00d0KFe]079bLP1bLW80K6a/07QhN01YJFT0J6QX06=SH`1W
IfL0PX:20<_;b`3Hf=P0dM7A0080`/;200l0]kNg09NGU`27QhL0MGEe06YZJP1UIFD0IfMW06EUI@1R
HV80HF5Q06YZJP1[Jf/0J6QX06YZJP1aLG400P1YJFT0@`1_Kfl0K6a/06m_K`1iNGT0Ogmo07MgM`1/
K6`0KVi^06a/K01cLg<0L71`07AdM01cLg<0OWin07AdM01[Jf/0KVi^07MgM`21PH40QHF507alO020
P800RHV908B4Q027QhL0QHF507IfMP1_Kfl0M7Ad07emO@23Ph<0Ogmo07AdM01SHf<0Kfm_07IfMP23
Ph<0RHV908J6QP22PX80RXZ:08N7Q`20P800PX:207moO`1kNg/0PX:207inOP1jNWX0LG5a06YZJP1`
L700LW9b06IVIP1YJFT0R8R809VIV@2UYJD0Zj^[0:2PX02TY:@0ZJVY0;Bd]02h^;P0_Kfm0:b/[02a
/K400P2_[jl07P2/[:`0Zj^[0:BTY02VYZH0YJFU09bLW02PX:00YjNW0:JVYP2`/;00_Kfm0<?3``2/
[:`0YJFU0:JVYP2_[jl0^k^k0;Zj^P2f][H0/K6a0;Ng]`2f][H0[Jf]0:NWY`2[Zj/0]kNg0;Zj^P2f
][H0^k^k0<30`080`/;200L0^k^k0;Bd]02o_kl0`/;20<71`@2i^KT0_kno0080`L7100@0^[Zj0;Jf
]P34a<@0b/[:0P32`/802`35aLD0`l?30<?3``31`L40^;Rh0;:b/P2l_;`0][Jf0;Vi^@2l_;`0_Kfm
0080b<S801D0alO70<_;b`3:b/X0alO70<W9b@38b<P0bLW90<?3``36a/H0b/[:0<g=c@3<c<`0cLg=
0<[:bP36a/H0a<C40<O7a`3:b/X0bLW90<O7a`36a/H00P32`/800`3;bl/0bLW90<W9b@020<K6aP0:
0<C4a03=cLd0b/[:0<c<c03@d=00cLg=0<_;b`3:b/X0c<c<0<k>cP80clo?0P3>c/h20=7Ad@050=?C
d`3Bd]80cLg=0<k>cP3AdM400P3Hf=P30=oOg`0C0=kNgP3Kfm/0bLW909RHV01JFUX0BDU905IFEP1Q
HF40LG5a07]kN`1oOgl0Q8B408Z:RP2?Shl0SHf=09fMW@2TY:@0XJ6Q09RHV00309^KV`80WYjN00<0
VYZJ09fMW@2NWYh00`2JVYX03@2DU9@0UYJF096AT@2EUID0Rh^;08V9R@1mOGd0NGUi06m_K`1JFUX0
F5QH04A4A00c<c<00P0[:b/0300V9RH092@T020P800X:2P092@T02XZ:P0`<300B4Q80861P@2f][H0
c<c<0=CDe080fMWI00/0e]KF0=3@d039bLT0];Bd09JFUP2JVYX0^k^k0<g=c@3De=@0emOG0=gMg@02
0=cLg0<0fMWI00L0f=SH0=OGe`3Hf=P0f=SH0=KFeP3De=@0fMWI0080f][J01T0gMgM0=cLg03MgMd0
i^KV0>[ZjP3YjNT0gmoO0<G5a@1OGel0;2`/02XZ:P0];Bd09BDU02LW9`0/;2`0:b/[02l_;`0d=3@0
=CDe03`l?00d=3@0>c/k0410@00c<c<0=3@d0080=cLg00H0;Rh^038b<P0j>SX0<c<c034a<@0/;2`2
038b<P0703`l?00f=SH0=CDe030`<00Y:BT0:2PX02`/;002034a<@0803@d=00b<S80<S8b03Xj>P0e
=CD0=SHf03Ti>@0h>3P2038b<P0502l_;`0^;Rh0>CTi03dm?@17AdL00P1XJ6P02P1iNGT0RXZ:096A
T@2FUYH0V9RH09JFUP2EUID0TY:B08j>SP2@T90208Z:RP09092@T02FUYH0WinO09fMW@2PX:00WIfM
09jNWP2QXJ40Y:BT0080WYjN0P2OWil01@2QXJ40X:2P0:2PX02QXJ40WYjN0080W9bL00D0X:2P09^K
V`2QXJ40VYZJ09fMW@0209nOW`0309jNWP2PX:00Vi^K00h0b>3H000<0<SPf080FUYJ00D0EEEE05QH
F01KFe/0F5QH05EEE@0405]KF`80FUYJ00<0GemO05iNGP1JFUX00P1PH6000`1OGel0EEEE05YJFP02
05YJFP0C05QHF01MGEd0HV9R06QXJ01eMGD0OWin07moO`25QHD0RXZ:09BDU02FUYH0VIVI09bLW02R
XZ80YJFU0::RXP2UYJD0ZJVY0:BTY0020:ZZZP0:0:VYZ@2XZ:P0Z:RX0:NWY`2UYJD0Xj>S0:JVYP2S
Xj<0X:2P0:6QX@80WIfM0180V9RH09>CT`2<S8`0QHF508>3P`1lO7`0MGEe06EUI@1IFET0EUIF04e=
C@1:BTX0@T9204A4A019BDT0AdM704];B`1ADE42051@D080FUYJ00@0GEeM05mOG`1OGel0Fe]K0P1N
GUh0301VIVH0HV9R069RHP1XJ6P0Hf=S069RHP1SHf<0J6QX069RHP1QHF40Hf=S061PH080Hf=S00`0
I6AT06QXJ01SHf<0GemO06IVIP1UIFD0IVIV06YZJP1UIFD0KFe]06UYJ@1WIfL206UYJ@0506YZJP1Y
JFT0LG5a07=cL`1bLW800P1_Kfl02P1`L700J6QX06QXJ01XJ6P0IFEU06MWI`1kNg/0[:b/0=GEe@3B
d]820<30`0080;:b/P2WYjL0QXJ607MgM`1ZJVX0Hf=S06YZJP1RHV8206EUI@0N061PH01YJFT0HF5Q
06UYJ@1`L700K6a/06EUI@1WIfL0JVYZ06m_K`1gMgL0OWin07=cL`1]KFd0Jf][06a/K01gMgL0MWIf
06i^KP1[Jf/0NGUi07alO01hN7P0Jf][071`L01^KVh0P82007moO`1nOWh0QHF50P23Ph<0702>SXh0
PH6107alO01eMGD0KVi^07alO023Ph<0P820075aL@1[Jf/0GEeM07EeM@21PH40QHF508j>SP28R8P0
Rh^;08f=S@24Q8@0RHV908>3P`1lO7`0P82008:2PP20P800NWYj079bLP1_Kfl206i^KP0:06][J`1h
N7P0UIFE0:6QX@2SXj<0WinO0:NWY`2/[:`0^[Zj0;Rh^080];Bd0P2f][H06@2c/k<0[Jf]0:VYZ@2P
X:00WinO0::RXP2WYjL0Xj>S0:JVYP2c/k<0^;Rh0<71`@2o_kl0];Bd0:JVYP2RXZ80[Jf]0:j^[P2d
];@0^KVi0;Zj^P2e]KD0Zj^[0;:b/P2j^[X00P2d];@02P2j^[X0_[jn0;fm_@2o_kl0_Kfm0;Rh^02o
_kl0_[jn0;no_`2j^[X20<C4a0060<;2`P2i^KT0]KFe0;no_`39bLT0aLG50P32`/800`35aLD0a/K6
0<30`0020;jn_P040<G5a@31`L40^[Zj0;Ng]`80][Jf00D0`L710<G5a@3;bl/0bl_;0<O7a`020<W9
b@030<k>cP3<c<`0alO70080bLW900D0cLg=0<[:bP3;bl/0c/k>0<[:bP020<S8b0070<W9b@37alL0
aLG50<;2`P37alL0b/[:0<c<c0020<K6aP0A0<G5a@36a/H0alO70<o?c`3<c<`0d=3@0<o?c`3;bl/0
b/[:0<k>cP3:b/X0c<c<0=3@d03<c<`0bl_;0<[:bP3;bl/00P3Cdm<09P3@d=00c/k>0<k>cP3EeMD0
f=SH0=gMg@3Rh^80hN7Q0=kNgP3MgMd0dm?C0;:b/P1[Jf/0CDe=04];B`1FEUH0J6QX071`L01lO7`0
PX:208^;R`2@T900Rh^;09:BTP2JVYX0XJ6Q09^KV`2FUYH0V9RH09fMW@2LW9`0VYZJ09jNWP2LW9`0
V9RH09^KV`2IVIT0V9RH0P2IVIT03@2FUYH0VIVI092@T02>SXh0QXJ608:2PP1kNg/0Kfm_06UYJ@1J
FUX0B4Q803Ph>00[:b/00P0W9bL0100X:2P08B4Q02@T900R8R8202@T900502`/;014A4@0K6a/0;:b
/P37alL00P3AdM40403Fe]H0emOG0=KFeP3=cLd0^k^k0:6QX@2MWId0^;Rh0<o?c`3EeMD0e=CD0=WI
f@3Jf]X0g=cL0=_Kf`3Hf=P30=[JfP0C0=_Kf`3IfMT0f=SH0=cLg03Ng]h0g=cL0=gMg@3Ng]h0h^;R
0>[ZjP3YjNT0inOW0=oOg`2f][H0@T9202LW9`0[:b/0:RXZ02d];@0202`/;00>02TY:@0];Bd0=CDe
02h^;P0_;bl0<C4a03Hf=P0b<S80<c<c03Ti>@0l?3`0ATI602h^;P0];Bd2030`<00903Lg=`0b<S80
:b/[02d];@0c<c<0=CDe03Xj>P0m?Cd0>SXj0080<30`0140;Bd]03Ti>@0^;Rh0<30`03@d=00e=CD0
=3@d03De=@0d=3@0=SHf034a<@0g=cL0;Bd]030`<00e=CD0<S8b04E5A@0205QHF00A06QXJ021PH40
R8R808j>SP2HV9P0UYJF09ZJVP2GUiL0SXj>096AT@2:RXX0RHV908^;R`2DU9@0UIFE09bLW02NWYh0
0P2QXJ401@2SXj<0XJ6Q0:BTY02RXZ80X:2P0080XJ6Q0100XZ:R0:2PX02OWil0WinO09fMW@2PX:00
XJ6Q09jNWP2MWId0WinO09ZJVP2MWId0WYjN09nOW`2LW9`0WIfM3P38h=P000`0b>3H0P1GEeL02@1E
EED0FEUI05MGE`1MGEd0Fe]K05UIF@1NGUh0GEeM05mOG`0205iNGP0305mOG`1MGEd0HV9R0080GemO
01P0FUYJ05QHF01HF5P0Fe]K05ADE01IFET0FUYJ069RHP1]KFd0Lg=c07YjNP24Q8@0QXJ608f=S@2@
T900UYJF09VIV@2MWId0XJ6Q0::RXP2SXj<0Z:RX0:BTY02YZJT20:ZZZP80YJFU01h0XZ:R0:NWY`2S
Xj<0Xj>S0:JVYP2RXZ80Y:BT0:6QX@2LW9`0WIfM09^KV`2@T900Shn?08B4Q021PH40OWin07AdM01Z
JVX0GEeM05QHF01>CTh0A4A40492@P19BDT0BTY:04a<C01>CTh0E5AD059BDP1DE5@205MGE`0705iN
GP1JFUX0GEeM05]KF`1SHf<0H61P069RHP02065QH@0;069RHP1PH600HF5Q065QH@1RHV80HF5Q06EU
I@1QHF40HV9R06EUI@1SHf<00`1QHF404@1XJ6P0H61P06ATI01WIfL0KFe]06MWI`1/K6`0IVIV06YZ
JP1YJFT0JVYZ06][J`1^KVh0KFe]07AdM01aLG40Lg=c0080KVi^00T0K6a/071`L01ZJVX0HV9R06=S
H`1/K6`0X:2P0=OGe`3@d=000P33`l<0502][Jd0Zj^[0:2PX021PH40LW9b06IVIP1WIfL0JFUY069R
HP1/K6`0IFEU06ATI01[Jf/0KFe]079bLP1_Kfl0LW9b06][J`1SHf<0K6a/0P1fMWH0101dM7@0LG5a
06a/K01aLG4207EeM@0707MgM`1bLW80MGEe07MgM`1hN7P0NGUi07emO@02075aL@0X07]kN`2:RXX0
Ph>307emO@1nOWh0Ph>308Z:RP26QXH0P82007YjNP1hN7P0MgMg08F5Q@26QXH0OWin07=cL`1UIFD0
LW9b08F5Q@26QXH0SHf=08Z:RP2<S8`0Ph>308Z:RP27QhL0PH6107alO01hN7P0O7al08F5Q@1kNg/0
LG5a06YZJP1_Kfl0KFe]06IVIP1fMWH0SXj>09ZJVP80YZJV00D0[Zj^0;2`/02_[jl0][Jf0;Fe]@02
0;Zj^P80^k^k00<0[:b/0::RXP2RXZ800P2SXj<00`2/[:`0];Bd0;2`/0020;:b/P070;Ng]`2e]KD0
^KVi0:b/[02QXJ40X:2P0:ZZZP020;6a/@0]0;>c/`2e]KD0^;Rh0;bl_02a/K40]kNg0;no_`2j^[X0
^k^k0;bl_02k^k/0_[jn0<;2`P2k^k/0^[Zj0;fm_@36a/H0_Kfm0<;2`P2m_Kd0_kno0<W9b@33`l<0
_kno0<;2`P34a<@0aLG50<?3``2i^KT0_Kfm0<W9b@34a<@0_[jn0;fm_@32`/80^k^k0;Jf]P2h^;P0
_;bl0<71`@36a/H0b<S80<[:bP3=cLd0d=3@00<0bLW900L0b/[:0<_;b`39bLT0bl_;0=7Ad@3@d=00
b/[:0080bLW900<0a<C40<?3``37alL00P3?cll02`3<c<`0alO70<O7a`31`L40alO70<_;b`3<c<`0
cLg=0<k>cP3?cll0b/[:0080cLg=00@0bl_;0<g=c@3<c<`0bLW90P38b<P00`3;bl/0c/k>0<o?c`02
0=3@d00H0=GEe@3IfMT0fm_K0>3Ph03QhN40h>3P0=gMg@3IfMT0_[jn0820P01=CDd0BDU904];B`1D
E5@0JVYZ079bLP20P800Ph>308R8R02ATI40VIVI09^KV`2GUiL0VYZJ0P2IVIT00`2MWId0VIVI09jN
WP0209VIV@0409nOW`2LW9`0Vi^K09^KV`80VIVI01@0Vi^K09ZJVP2FUYH0Ti>C08n?S`26QXH0Ogmo
07MgM`1[Jf/0J6QX05iNGP1EEED0A4A4030`<00c<c<0;2`/02/[:`0T92@0:BTY020P808092@T00D0
9BDU02PX:00b<S80HF5Q09bLW0020;bl_00F0<k>cP3De=@0fm_K0=WIf@3Cdm<0a/K60:^[Z`2PX:00
/;2`0<[:bP3Bd]80dm?C0=WIf@3Ng]h0fMWI0=gMg@3Lg=`0g]kN0>3Ph03Ogml0g]kN0=cLg080gMgM
00@0gmoO0>7Qh@3Rh^80iNGU0P3Zj^X01@3UiND0fm_K0:2PX00d=3@0:2PX0080:b/[00`0:2PX02TY
:@0];Bd0;bl_02`/;00b<S80<C4a030`<00a<C40<S8b03De=@0k>c/303Hf=P0P03Xj>P0b<S80<c<c
02h^;P0];Bd0:RXZ02l_;`0b<S80;bl_03Ti>@0^;Rh0=SHf03<c<`0_;bl0<S8b02l_;`0/;2`0;bl_
02h^;P0k>c/0=3@d03`l?00o?cl0=CDe03Xj>P0];Bd0=CDe02d];@0`<300;bl_03<c<`0b<S8204E5
A@0505MGE`1aLG40Q8B408^;R`2EUID00`2IVIT01@2CTi<0TY:B096AT@25QHD0S8b<0080TY:B00l0
V9RH09^KV`2NWYh0XZ:R09nOW`2NWYh0XZ:R09nOW`2QXJ40X:2P0::RXP2PX:00WinO0:FUY@2QXJ40
102PX:001P2NWYh0WinO0:2PX02LW9`0VYZJ0:2PX080WIfM3P38h=P000`0b>3H0P1GEeL01@1IFET0
GUiN05UIF@1EEED0Fe]K0080FUYJ01@0GemO05iNGP1OGel0EeMG05aLG01JFUX0GUiN05aLG01MGEd0
GUiN05eMG@1GEeL0FEUI051@D01DE5@0Fe]K06ATI01^KVh0LW9b07alO080QXJ600/0SXj>096AT@2E
UID0VYZJ0:2PX02OWil0X:2P0:>SX`2UYJD0YZJV0:NWY`020::RXP030:NWY`2TY:@0YJFU00<0Xj>S
00<0XZ:R0:BTY02SXj<00P2OWil03`2JVYX0UIFE08j>SP2>SXh0QHF507QhN01iNGT0LW9b06][J`1M
GEd0Cdm?04i>CP1<C4`0ATI604E5A@0204U9B@0704i>CP1<C4`0Cdm?05=CD`1IFET0FUYJ05aLG002
05]KF`0605mOG`1NGUh0Hf=S06=SH`1PH600HV9R0P1SHf<0601OGel0HV9R06=SH`1TI6@0IFEU05eM
G@1PH600HV9R06MWI`1VIVH0HV9R06IVIP1UIFD0H61P06a/K01WIfL0J6QX06MWI`1UIFD0KVi^06][
J`1ZJVX0KFe]06YZJP80Kfm_00`0KVi^06m_K`1_Kfl0Lg=c06a/K01[Jf/0Kfm_06QXJ01VIVH0Hf=S
06][J`2BTY820=SHf080a<C400X0/k>c0:ZZZP2LW9`0Q8B4079bLP1YJFT0HF5Q061PH01XJ6P0JFUY
0P1[Jf/0101VIVH0JFUY06e]K@1aLG4206m_K`0506QXJ01WIfL0Lg=c07AdM01fMWH00P1aLG404P1j
NWX0Kfm_06e]K@1dM7@0OGem07]kN`1`L700LW9b07MgM`1nOWh0NWYj07IfMP1cLg<0QHF508B4Q01l
O7`0Ng]k07moO`80QXJ600d0PH6108R8R021PH40Ph>307UiN@2<S8`0Rh^;08J6QP1gMgL0KVi^06YZ
JP1fMWH0QHF50080RHV901P0QXJ608F5Q@2@T900QhN70861P@1kNg/0N7Qh08J6QP2;Rh/0OWin07If
MP1[Jf/0KFe]06][J`1ZJVX0L71`08Z:RP2RXZ80[:b/0:n_[`2VYZH0[Jf]0:ZZZP2`/;020;>c/`0F
0<30`02m_Kd0[jn_0:VYZ@2UYJD0Z:RX0;6a/@2j^[X0]KFe0:n_[`2/[:`0Z:RX0:f][@2_[jl0^;Rh
0;no_`2g]kL0WYjN09^KV`2RXZ80ZJVY0:^[Z`80_[jn00d0_;bl0;jn_P2m_Kd0_Kfm0;>c/`2d];@0
][Jf0<30`02o_kl0^k^k0;Fe]@2l_;`0`/;200<0a<C400D0_kno0<71`@34a<@0a<C40<?3``020<G5
a@070;no_`2m_Kd0`<300<G5a@37alL0_[jn0;fm_@020<?3``0D0<30`031`L40`L710;Zj^P2d];@0
_kno0<G5a@36a/H0bl_;0<c<c03:b/X0bLW90<[:bP38b<P0b/[:0<c<c03:b/X0d=3@0<o?c`39bLT3
0<S8b0050<_;b`3?cll0clo?0<c<c03;bl/00P37alL01@36a/H0b/[:0<g=c@3=cLd0clo?0080c/k>
00T0clo?0=7Ad@3>c/h0clo?0<k>cP3;bl/0b/[:0<W9b@3;bl/00P3<c<`05P3>c/h0dM7A0=?Cd`3I
fMT0emOG0=gMg@3Ti>@0hN7Q0=oOg`3Kfm/0cLg=0:2PX01NGUh0?clo0492@P1HF5P0FUYJ06e]K@1d
M7@0Ng]k08>3P`27QhL209:BTP0509JFUP2EUID0UIFE09^KV`2GUiL00P2FUYH02@2LW9`0VIVI09fM
W@2LW9`0V9RH09ZJVP2GUiL0VIVI09ZJVP0209VIV@0I09NGU`2CTi<0Ti>C08V9R@23Ph<0NGUi06m_
K`1TI6@0GEeM05=CD`13@d<0=3@d02d];@0^;Rh09RHV02XZ:P0W9bL0:2PX03<c<`0U9BD08R8R02@T
900X:2P0<C4a04e=C@0208Z:RP030;Vi^@3<c<`0e=CD0080gMgM01H0eMGE0<g=c@2i^KT0Xj>S0:NW
Y`34a<@0dM7A0=?Cd`3GemL0f][J0=gMg@3Ng]h0gmoO0>;RhP3Ph>00gmoO0>3Ph03Ogml0hN7Q0>;R
hP3Ti>@0iNGU0P3Zj^X04@3Xj>P0i>CT0=CDe01nOWh0:RXZ02TY:@0_;bl0:BTY02`/;00b<S80;Rh^
02/[:`0/;2`0<C4a030`<00_;bl0=3@d0080>CTi00/0=3@d03Lg=`0g=cL0>SXj03Hf=P0d=3@0>3Ph
03<c<`0f=SH0<C4a030`<00302h^;P0F03De=@0b<S80<30`03Ph>00b<S80<30`02`/;00c<c<0=3@d
034a<@0h>3P0>c/k03<c<`0d=3@0<C4a03hn?P0f=SH0<S8b02d];@0[:b/0:RXZ03dm?@80@d=300D0
Bd];06MWI`1eMGD0PX:2092@T00209RHV00=09BDU02GUiL0U9BD09:BTP2?Shl0S8b<08Z:RP2>SXh0
TY:B09RHV02MWId0WinO0::RXP040:>SX`070:BTY02PX:00X:2P09fMW@2OWil0X:2P09nOW`020:2P
X00309jNWP2PX:00Vi^K0080WinO0P2LW9`00`2MWId0WinO0<SPf00=0<SPf0003038h=P205mOG`0K
05MGE`1IFET0G5aL05YJFP1HF5P0EUIF05YJFP1GEeL0FUYJ05]KF`1JFUX0G5aL05YJFP1IFET0F5QH
05YJFP1IFET0EUIF05EEE@1FEUH0EEEE05QHF01FEUH0GemO06QXJ01bLW80OGem0080QHF500T0Rh^;
096AT@2GUiL0W9bL09jNWP2QXJ40Xj>S0:BTY02UYJD0102SXj<01@2UYJD0Xj>S0::RXP2SXj<0Y:BT
0080Xj>S00H0YjNW0:JVYP2UYJD0WinO09VIV@2DU9@208f=S@0H08J6QP25QHD0NWYj07AdM01XJ6P0
GemO05ADE01ADE40ADE504Y:BP15ADD0CTi>04U9B@1ADE40CTi>05YJFP1CDe<0EEEE05YJFP1DE5@0
GUiN05]KF`1OGel0GUiN0P1PH6006@1VIVH0HF5Q065QH@1RHV80GemO05eMG@1PH600GEeM069RHP1O
Gel0GUiN05YJFP1RHV80GUiN06EUI@1TI6@0IFEU06ATI01XJ6P0K6a/06UYJ@1ZJVX0KVi^06][J`1/
K6`00P1ZJVX04@1XJ6P0JVYZ06YZJP1/K6`0M7Ad06YZJP1^KVh0Kfm_07=cL`1[Jf/0J6QX06IVIP1W
IfL0KFe]07UiN@33`l<0f][J0080c<c<01<0][Jf0:NWY`2>SXh0OGem06m_K`1XJ6P0I6AT05iNGP1Q
HF40Jf][06IVIP1ZJVX0Jf][06UYJ@1bLW80LG5a06QXJ01_Kfl0M7Ad0080Jf][00L0KFe]07QhN01d
M7@0LG5a079bLP1eMGD0M7Ad0080MGEe01`0NGUi07=cL`1gMgL0Lg=c07UiN@20P800Ng]k07=cL`1l
O7`0PX:207]kN`20P800Ph>308B4Q022PX80Ng]k08F5Q@26QXH0QhN708J6QP1oOgl0PX:208B4Q02:
RXX0PH6107QhN01cLg<0NGUi0P26QXH308R8R00E08Z:RP2?Shl0QXJ607emO@1iNGT0O7al08B4Q023
Ph<0N7Qh06i^KP1UIFD0Jf][06UYJ@1`L700QhN70:2PX02OWil0Zj^[0:VYZ@2TY:@0YZJV0080[Zj^
0P2k^k/0302m_Kd0]kNg0:JVYP2f][H0_kno0;Ng]`2`/;00ZZZZ0:b/[02a/K40/[:b0;>c/`80];Bd
01P0/k>c0;2`/02`/;00WinO0:6QX@2/[:`0^;Rh0;Vi^@2j^[X0`l?30<71`@2m_Kd0]kNg0;Jf]P2o
_kl0_;bl0;>c/`2b/[80^KVi0<;2`P33`l<0`L710<K6aP33`l<20<30`00L0<;2`P34a<@0a/K60<O7
a`30`<00^k^k0<71`@36a/H0alO70<30`031`L40a<C40<71`@35aLD0b<S80<G5a@36a/H0`/;20;bl
_02n_[h0^k^k0<;2`P34a<@0bLW90<O7a`38b<P0bLW90<S8b080c<c<00<0clo?0<k>cP3@d=000P39
bLT01@3;bl/0clo?0<o?c`3=cLd0c/k>00@0b/[:00D0c/k>0<g=c@3?cll0d=3@0<o?c`020<c<c008
0<o?c`3@d=00d];B0=3@d03?cll0bl_;0<[:bP3?cll20=;BdP0Y0<o?c`3Cdm<0dm?C0=KFeP3Hf=P0
fMWI0>3Ph03Rh^80hn?S0=oOg`3Hf=P0_kno07=cL`12@T80@d=304i>CP1FEUH0HV9R06YZJP1aLG40
P82008J6QP24Q8@0SXj>09JFUP2CTi<0UIFE09NGU`2IVIT0UiNG09JFUP2HV9P0WIfM09^KV`2IVIT0
UiNG09RHV02GUiL0WYjN09bLW02HV9P00`2FUYH03@2EUID0S8b<08Z:RP21PH40MgMg06e]K@1RHV80
G5aL04i>CP13@d<0>SXj034a<@0^;Rh00P0[:b/00`0Y:BT0:2PX02LW9`02028R8P0402PX:00V9RH0
:BTY02/[:`80@4100180N7Qh0;6a/@37alL0d];B0=[JfP3Ogml0f][J0=7Ad@34a<@0Zj^[0;6a/@30
`<00clo?0=?Cd`3@d=00emOG0=gMg@3Ph>020>;RhP0U0>?Sh`3Ph>00i>CT0>CTi03UiND0inOW0>SX
j03WinL0i^KV0>?Sh`3Ogml0_[jn04m?C`0R8R80:RXZ02d];@0Y:BT0;Rh^02LW9`0/;2`0=SHf02l_
;`0/;2`0;bl_03/k>`0g=cL0?3`l03dm?@0i>CT0<C4a03@d=00a<C40=CDe03dm?@0g=cL0<c<c03Ti
>@02034a<@0A038b<P0^;Rh0<c<c03@d=00h>3P0<c<c03Ph>00b<S80<30`02h^;P0];Bd0>SXj03De
=@0m?Cd0;Rh^03Ph>00g=cL00`0f=SH0100l?3`0;2`/034a<@0W9bL302/[:`0703dm?@1<C4`0JVYZ
07UiN@2>SXh0Ti>C09^KV`0209RHV00=09JFUP2@T900SXj>08b<S02=SHd0S8b<08j>SP2FUYH0VIVI
09jNWP2PX:00ZJVY0:2PX0030:>SX`070::RXP2OWil0XJ6Q09nOW`2RXZ80XJ6Q09fMW@0209nOW`03
09bLW02NWYh0WIfM0080WYjN00<0XJ6Q09^KV`2LW9`03P38h=P000`0b>3H0P1QHF40101KFe/0FEUI
05YJFP1GEeL205eMG@0R05]KF`1IFET0E5AD05QHF01EEED0F5QH05YJFP1IFET0Fe]K05YJFP1HF5P0
EUIF05EEE@1BDU80FUYJ051@D01DE5@0I6AT06QXJ01`L700OWin08B4Q026QXH0SHf=09BDU02IVIT0
VYZJ09jNWP2PX:00XZ:R0:>SX`2VYZH0XJ6Q0:NWY`80Xj>S00H0Y:BT0:NWY`2SXj<0XJ6Q0:>SX`2O
Wil20:BTY00A0:6QX@2PX:00X:2P09VIV@2GUiL0TI6A08n?S`28R8P0PX:207MgM`1`L700K6a/065Q
H@1CDe<0Cdm?04I6AP14A4@00P1;Bd/03P1@D500E5AD05MGE`1BDU80EUIF05QHF01LG5`0EUIF05QH
F01MGEd0HF5Q05aLG01PH600FUYJ0P1RHV805@1NGUh0HF5Q05iNGP1RHV80Hf=S05iNGP1QHF40GUiN
061PH01OGel0IFEU069RHP1VIVH0HF5Q06EUI@1RHV80JFUY06IVIP1UIFD0JVYZ06MWI`0306UYJ@0<
06a/K01XJ6P0K6a/06YZJP1_Kfl0L71`06m_K`1[Jf/0KFe]06a/K01]KFd0IFEU0P1TI6@0101YJFT0
K6a/0:>SX`3MgMd20=?Cd`0<0;fm_@2KVi/0Ti>C07UiN@1]KFd0JVYZ061PH01VIVH0JVYZ06=SH`1T
I6@0Jf][0P1YJFT02`1WIfL0Lg=c06i^KP1[Jf/0JVYZ079bLP1cLg<0MWIf071`L01]KFd0MGEe0080
L71`00<0Lg=c07UiN@1eMGD00P1`L700101nOWh0P82007IfMP1]KFd207YjNP0507emO@1nOWh0O7al
0861P@28R8P00P25QHD20820P00608F5Q@2IVIT0RHV908b<S028R8P0NGUi0P2:RXX01`28R8P0PH61
07inOP1bLW80Ogmo08b<S02;Rh/00P2:RXX02P2;Rh/0R8R808^;R`1oOgl0LG5a06][J`1`L700NGUi
07alO01_Kfl2065QH@0806QXJ01/K6`0OGem092@T02WYjL0Z:RX0:6QX@2SXj<20:b/[00:0;Jf]P2h
^;P0^KVi0;Ng]`2][Jd0^k^k0<S8b02h^;P0[jn_0:f][@80/[:b01<0]KFe0;2`/02][Jd0Z:RX0:n_
[`2g]kL0`<300;Rh^02d];@0Z:RX0:^[Z`2_[jl0^k^k0<30`031`L40_;bl0;^k^`31`L40^k^k0080
]KFe0380_Kfm0<30`02n_[h0_kno0<K6aP35aLD0a<C40;jn_P33`l<0`L710<?3``34a<@0_kno0;^k
^`34a<@0cLg=0<O7a`34a<@0_kno0<71`@32`/80alO70<K6aP37alL0a<C40<K6aP37alL0bl_;0<S8
b02n_[h0^k^k0;bl_031`L40`/;20<K6aP39bLT0bl_;0=3@d03?cll0cLg=0<k>cP3?cll0alO70<W9
b@3?cll0dM7A0<o?c`3@d=00bl_;0<O7a`<0b/[:00l0cLg=0<k>cP3?cll0d];B0<g=c@3>c/h0dm?C
0=7Ad@3Bd]80clo?0=3@d03Bd]80c<c<0<o?c`3Cdm<00P3AdM401`3Cdm<0e=CD0=GEe@3Cdm<0f][J
0>3Ph03Shn<00P3QhN404@3Lg=`0c/k>09jNWP1>CTh0>CTi0492@P1;Bd/0De=C05eMG@1_Kfl0NWYj
07alO022PX80Rh^;08j>SP2BTY80TI6A0080UIFE00T0UYJF09VIV@2IVIT0Vi^K09ZJVP2LW9`0Vi^K
09RHV02IVIT00`2KVi/04`2IVIT0W9bL09^KV`2HV9P0TI6A08j>SP29RHT0Ph>307MgM`1_Kfl0IFEU
06=SH`1?Cdl0@41003Ti>@0c<c<0;Rh^02/[:`0Y:BT00P0[:b/01`0U9BD0:b/[02@T900T92@09RHV
02LW9`0S8b<00P0];Bd05@0e=CD0Jf][0:>SX`35aLD0clo?0=[JfP3Ph>00f][J0=7Ad@3;bl/0_kno
0;>c/`2j^[X0b/[:0<o?c`3>c/h0e]KF0=SHf03MgMd0hN7Q0>;RhP020>CTi0050>GUi@3YjNT0j>SX
0>KViP3Shn<00P3Lg=`0103GemL0WinO030`<00Z:RX202PX:00I02d];@0/;2`0<S8b02`/;00_;bl0
;Rh^030`<00c<c<0=SHf03`l?00n?Sh0=3@d03Hf=P0e=CD0<C4a03Hf=P0b<S80?Cdm03Lg=`0n?Sh0
>CTi03Hf=P0j>SX0>c/k038b<P0303<c<`05030`<00g=cL0=3@d03/k>`0e=CD00P0`<3003@0c<c<0
;bl_03Xj>P0g=cL0=3@d03Ti>@0c<c<0=cLg03De=@0`<300;Bd]02LW9`0Y:BT00P0Z:RX0200^;Rh0
A4A405MGE`1]KFd0P82008Z:RP2DU9@0VIVI0P2DU9@0802ATI40T92@096AT@2:RXX0Rh^;08b<S02@
T900U9BD09VIV@2OWil0YjNW09nOW`2WYjL0Xj>S0:RXZ02RXZ80X:2P0:6QX@2PX:00WinO09jNWP2L
W9`0XJ6Q09jNWP2LW9`0WinO09^KV`2JVYX0WYjN0:2PX02OWil0X:2P3P38h=P000`0b>3H0P1FEUH0
101HF5P0FEUI05QHF01FEUH205eMG@0;05YJFP1KFe/0Fe]K05YJFP1IFET0GEeM05aLG01NGUh0G5aL
069RHP1MGEd00P1DE5@05@1?Cdl0EUIF055AD@1FEUH0H61P06][J`1eMGD0NGUi08:2PP2<S8`0Rh^;
09:BTP2IVIT0VYZJ09^KV`2QXJ40XZ:R0:FUY@2VYZH0YJFU0:JVYP020:BTY00S0:2PX02VYZH0Y:BT
0:JVYP2TY:@0Xj>S0:BTY02QXJ40XZ:R09nOW`2QXJ40UiNG09RHV02@T900S8b<08R8R021PH40N7Qh
07=cL`1WIfL0HF5Q05aLG01@D500ATI60492@P13@d<0BTY:051@D01?Cdl0De=C05ADE01HF5P0Fe]K
05YJFP1EEED00P1HF5P0101KFe/0H61P05iNGP1MGEd205mOG`0505iNGP1QHF40Fe]K05mOG`1QHF40
0P1OGel0401QHF40GUiN05mOG`1TI6@0HV9R06EUI@1OGel0IVIV06UYJ@1]KFd0J6QX06MWI`1XJ6P0
IFEU06][J`1WIfL206YZJP0706m_K`1YJFT0Jf][06e]K@1/K6`0Kfm_06a/K002071`L00806YZJP1W
IfL0IFEU065QH@1TI6@0Hf=S08^;R`3GemL20=SHf00=0<W9b@2UYJD0TY:B07]kN`1]KFd0IVIV061P
H01WIfL0KVi^06UYJ@1VIVH0I6AT06MWI`0206e]K@80KVi^02<0LW9b06a/K01`L700N7Qh07alO01a
LG40IfMW06m_K`1/K6`0MGEe075aL@1gMgL0M7Ad06m_K`1YJFT0MGEe07]kN`1jNWX0M7Ad06i^KP1Y
JFT0NWYj08B4Q01lO7`0PX:207inOP1oOgl0RHV90861P@24Q8@0R8R809BDU02>SXh0S8b<08F5Q@02
07inOP0N08:2PP2ATI40TI6A08N7Q`20P800MWIf07alO023Ph<0Rh^;08N7Q`2:RXX0QhN7096AT@2:
RXX0OGem07QhN01^KVh0Kfm_07UiN@1kNg/0LG5a079bLP1^KVh0Lg=c075aL@1fMWH0RXZ:09VIV@2N
WYh0Zj^[0P2^[Zh0202c/k<0/K6a0;6a/@2/[:`0[jn_0<30`039bLT0`L710P2j^[X00`2a/K40^KVi
0:b/[0020:ZZZP0:0:^[Z`2`/;00/[:b0;Vi^@31`L40alO70;bl_02][Jd0[jn_0;2`/080^KVi00`0
^k^k0<G5a@33`l<0][Jf0;Fe]@31`L40_[jn0;^k^`2l_;`0aLG50<K6aP33`l<30<C4a0070<O7a`38
b<P0a<C40;Vi^@2k^k/0b<S80<_;b`020<G5a@040<71`@32`/80a<C40<S8b080a/K601@0`/;20<K6
aP3>c/h0c<c<0<W9b@36a/H0`l?30<30`02o_kl0`<300<;2`P34a<@0cLg=0=3@d03>c/h0dM7A0<g=
c@39bLT0b/[:0<o?c`80d=3@00@0c/k>0<S8b033`l<0b<S80`3<c<`02P3@d=00clo?0<k>cP3?cll0
c/k>0=7Ad@3Bd]80d=3@0=7Ad@3>c/h20=;BdP070=7Ad@3Cdm<0dM7A0=;BdP3?cll0dm?C0=GEe@02
0=KFeP030=kNgP3Ti>@0g]kN0080h>3P0180f=SH0<?3``1hN7P0@41003dm?@19BDT0C4a<05UIF@1Q
HF40KVi^07IfMP1oOgl0RHV908R8R02BTY80UIFE09RHV02JVYX209JFUP80UiNG00@0VYZJ09fMW@2J
VYX0Vi^K0P2JVYX209bLW080UiNG01H0W9bL09FEU@2FUYH0UiNG08j>SP28R8P0Ogmo07UiN@1^KVh0
Jf][065QH@1FEUH0BDU903/k>`0b<S80:RXZ02l_;`0Y:BT0;Rh^02PX:00Y:BT09bLW0P0U9BD00`0T
92@09bLW024Q8@0202DU9@0E02PX:00^;Rh0Cdm?09NGU`30`<00c/k>0=WIf@3Kfm/0g=cL0=GEe@3A
dM40bLW90;Ng]`2f][H0_kno0<O7a`3>c/h0d=3@0=;BdP3EeMD0fm_K0080gmoO103QhN401@3Jf]X0
dm?C0=CDe038b<P0L71`00809RHV00H0:RXZ030`<00/;2`0;Bd]02PX:00a<C4202l_;`04030`<00a
<C40<S8b03@d=0<0=cLg00@0=3@d03Lg=`0`<300<c<c0P11@D402P1=CDd0=cLg03<c<`0/;2`0<c<c
03@d=00a<C40=CDe03Hf=P0d=3@203Hf=P0403Ph>00c<c<0=CDe038b<P80<30`00/0=CDe03Lg=`14
A4@0>CTi03`l?011@D40>CTi03Hf=P0Z:RX0<C4a02XZ:P0202`/;00902d];@0d=3@0ADE505eMG@1f
MWH0Q8B4092@T02DU9@0UiNG0080V9RH00P0Ti>C08n?S`2<S8`0SHf=08Z:RP2;Rh/0Shn?09ZJVP80
WIfM00T0XJ6Q0:>SX`2WYjL0ZJVY0:FUY@2PX:00WinO0:6QX@2OWil00P2PX:000`2NWYh0X:2P09^K
V`0309fMW@0409nOW`2MWId0WinO09^KV`h0b>3H000<0<SPf0<0F5QH00<0G5aL05]KF`1NGUh00P1H
F5P03@1OGel0EEEE05mOG`1HF5P0EUIF05UIF@1FEUH0Fe]K05EEE@1OGel0FUYJ05MGE`1CDe<00P1H
F5P0201DE5@0FEUI06ATI01YJFT0Kfm_07UiN@21PH40S8b<0P2@T9002@2IVIT0WYjN09^KV`2RXZ80
Xj>S0:BTY02UYJD0YZJV0:RXZ0020:BTY0060:JVYP2QXJ40Z:RX0:BTY02QXJ40XZ:R0P2SXj<08P2U
YJD0Xj>S0:2PX02FUYH0V9RH09:BTP2<S8`0QhN707moO`1jNWX0M7Ad06e]K@1RHV80H61P05ADE018
B4P0ATI604M7A`1=CDd0Cdm?051@D01?Cdl0EEEE05QHF01LG5`0EEEE05]KF`1HF5P0GEeM05YJFP1O
Gel0HV9R05QHF01TI6@305eMG@08065QH@1RHV80H61P05mOG`1NGUh0Hf=S05mOG`1QHF4206IVIP0N
06QXJ01PH600GUiN06EUI@1WIfL0Hf=S06EUI@1XJ6P0JVYZ06i^KP1ZJVX0K6a/071`L01]KFd0KVi^
079bLP1gMgL0LG5a06i^KP1aLG40KVi^079bLP1^KVh0KFe]06QXJ01UIFD0K6a/069RHP1iNGT0_[jn
0P3IfMT0:`3:b/X0]kNg09bLW01eMGD0Jf][05eMG@1TI6@0IfMW06e]K@1UIFD0JVYZ065QH@1/K6`0
JVYZ06UYJ@1^KVh0J6QX06a/K01aLG40MWIf07=cL`1hN7P0MGEe06m_K`1aLG40JFUY07UiN@1fMWH0
K6a/06][J`1`L700N7Qh07IfMP1^KVh0NGUi07]kN`1iNGT0MGEe079bLP1oOgl0Q8B408F5Q@24Q8@0
0P21PH402`27QhL0Rh^;08J6QP2?Shl0QHF508J6QP28R8P0RHV908R8R026QXH0S8b<0080SHf=00L0
QHF507inOP1nOWh0Ng]k08:2PP26QXH0R8R80080S8b<00X0SXj>08^;R`27QhL0OGem06i^KP1aLG40
N7Qh07alO01nOWh0N7Qh0P1aLG401@1`L700Kfm_07inOP2CTi<0[Zj^0080Zj^[00L0/[:b0:j^[P2U
YJD0ZZZZ0;2`/036a/H0alO70080`L7100T0_Kfm0;^k^`2b/[80[Jf]0:RXZ02_[jl0/;2`0:b/[02e
]KD00P2m_Kd07P36a/H0`/;20<;2`P2n_[h0ZZZZ0:JVYP2[Zj/0]KFe0;^k^`2h^;P0]kNg0<G5a@30
`<00^;Rh0;Vi^@32`/80_kno0<30`031`L40a<C40<G5a@36a/H0bLW90<[:bP34a<@0_[jn0<G5a@3:
b/X0aLG50<?3``80alO700H0a/K60<W9b@33`l<0`l?30<71`@35aLD20<c<c00H0<g=c@3;bl/0bLW9
0<?3``37alL0c<c<0<G5a@2n_[h0_;bl0<G5a@3;bl/0cLg=0=3@d03:b/X0b<S80=3@d03EeMD0d];B
0<o?c`38b<P0aLG50<S8b03;bl/0cLg=0P3@d=002@3?cll0d=3@0<o?c`3?cll0d];B0=?Cd`3AdM40
cLg=0<S8b0020=3@d0050=CDe03Bd]80d=3@0<g=c@3Bd]800P3EeMD20=OGe`040=_Kf`3Ph>00h^;R
0=kNgP80h>3P0140f][J0:j^[P1DE5@0=CDe03lo?`17AdL0DE5A05]KF`1XJ6P0LG5a07]kN`21PH40
QhN708Z:RP2@T900TI6A09JFUP0209RHV00409NGU`2IVIT0WYjN09RHV080Vi^K00H0UiNG09^KV`2K
Vi/0VYZJ09bLW02NWYh209RHV080Vi^K00l0Ti>C08b<S02<S8`0OWin07moO`1_Kfl0K6a/06MWI`1B
DU80AdM703Xj>P0_;bl0<S8b02h^;P0];Bd00P0_;bl01`0];Bd0;Rh^02LW9`0X:2P0:RXZ02PX:00V
9RH00P0c<c<04P0V9RH09bLW02d];@16ATH0QHF50;bl_03Cdm<0eMGE0=cLg03Ng]h0fm_K0=GEe@3?
cll0a<C40;^k^`2h^;P0`L710<g=c@80d=3@00L0dM7A0=GEe@3Hf=P0f=SH0=KFeP3IfMT0f=SH0080
f][J02@0d];B0;Rh^01@D5008R8R02<S8`0U9BD0:2PX02l_;`0[:b/0<C4a02h^;P0a<C40<S8b03@d
=00Z:RX0<C4a03Ti>@0e=CD0?Shn0451@@0m?Cd0=3@d03Xj>P0h>3P0>CTi03hn?P0^;Rh0<C4a03Lg
=`0`<300=SHf03@d=00_;bl0?Cdm03De=@0i>CT203Lg=`0403Ti>@0l?3`0=3@d03@d=080<30`00/0
=CDe03<c<`0l?3`0=SHf04E5A@0n?Sh0=CDe02h^;P0[:b/09bLW02DU9@0202XZ:P80;Bd]00/0?Shn
05QHF01YJFT0N7Qh08Z:RP2ATI40U9BD09VIV@2FUYH0UIFE096AT@0208n?S`0508^;R`27QhL0SHf=
09:BTP2IVIT00P2LW9`01`2QXJ40XZ:R0:NWY`2QXJ40WinO0:6QX@2OWil00P2QXJ400`2PX:00XZ:R
0:2PX00209jNWP80WIfM00@0WinO09fMW@2MWId0X:2P3P38h=P000`0b>3H0P1LG5`0101PH600EUIF
05QHF01NGUh205QHF00<05aLG01JFUX0EeMG05QHF01DE5@0EUIF05]KF`1MGEd0E5AD05IFEP1CDe<0
E5AD0P1EEED0501DE5@0EEEE05YJFP1RHV80JVYZ07=cL`1oOgl0P82008Z:RP2?Shl0UIFE09RHV02N
WYh0W9bL0:BTY02NWYh0XJ6Q0:BTY02YZJT0YZJV0P2QXJ40702SXj<0YZJV0:FUY@2QXJ40X:2P0:6Q
X@2RXZ80XJ6Q09nOW`2TY:@0XJ6Q09ZJVP2EUID0Ti>C08f=S@2:RXX0P82007alO01iNGT0L71`06IV
IP1JFUX0DU9B051@D019BDT0BTY:055AD@1BDU82051@D00505=CD`1GEeL0G5aL05aLG01NGUh00P1M
GEd00`1KFe/0GemO061PH002061PH080Hf=S0140HF5Q061PH01NGUh0GemO05aLG01RHV80H61P06=S
H`1QHF40GemO061PH01QHF40IFEU06QXJ01VIVH0Hf=S06QXJ00206MWI`0406][J`1aLG40Jf][06e]
K@80Kfm_00D0Jf][071`L01`L700MgMg06YZJP03071`L00806m_K`1]KFd0KFe]06a/K01[Jf/0I6AT
06a/K02OWil20=?Cd`070<o?c`2o_kl0XJ6Q07alO01ZJVX0GemO065QH@0206UYJ@0;06EUI@1[Jf/0
J6QX06MWI`1UIFD0Jf][06=SH`1/K6`0JFUY079bLP1fMWH00P1aLG404P1eMGD0LW9b06m_K`1[Jf/0
K6a/071`L01_Kfl0JFUY06IVIP1`L700NGUi07YjNP1aLG40KVi^07alO020P800NGUi07alO080OGem
02X0QhN708J6QP21PH40PH6108N7Q`28R8P0RXZ:08V9R@20P800PX:208>3P`2@T900SHf=096AT@2@
T900SXj>08n?S`2:RXX0R8R808F5Q@1oOgl0PH6108R8R02:RXX0Shn?08f=S@26QXH0SXj>08f=S@23
Ph<0KVi^06ATI01/K6`0OGem07moO`1hN7P0LW9b071`L01aLG40K6a/07MgM`2DU9@20:BTY00;0;2`
/02YZJT0WIfM09nOW`2e]KD0`/;20<30`032`/80_[jn0<71`@2l_;`00P2_[jl05@2i^KT0];Bd0:n_
[`2_[jl0_kno0<G5a@2l_;`0`/;20<71`@36a/H0aLG50;Fe]@2TY:@0WIfM0:JVYP2][Jd0[:b/0;bl
_032`/80^k^k0;fm_@030<71`@0<0<30`035aLD0aLG50<K6aP37alL0b/[:0<C4a030`<00a/K60<_;
b`3:b/X0a<C40P31`L400`3:b/X0b<S80<[:bP020<C4a00:0<_;b`3<c<`0bl_;0<_;b`3<c<`0bl_;
0<O7a`35aLD0c/k>0<c<c0@0a/K600T0`/;20<G5a@36a/H0alO70<_;b`3Cdm<0d];B0<o?c`3<c<`0
0P36a/H20<g=c@@0d=3@0100c<c<0=7Ad@3De=@0dM7A0=CDe03?cll0alO70<S8b03<c<`0d];B0=?C
d`3AdM40d=3@0=7Ad@3Bd]80eMGE0P3GemL00`3Lg=`0gmoO0>;RhP020>;RhP0A0>3Ph03Ng]h0dm?C
09BDU013@d<0>SXj0451@@1>CTh0De=C05UIF@1[Jf/0MgMg07alO022PX80RHV908^;R`2BTY800P2D
U9@409NGU`0609^KV`2FUYH0VYZJ09RHV02GUiL0Vi^K0P2HV9P0102IVIT0WYjN09FEU@2GUiL209VI
V@0H09NGU`2;Rh/0QhN70820P01kNg/0Lg=c06UYJ@1NGUh0DU9B04U9B@0d=3@0=SHf030`<00_;bl0
<C4a02/[:`0];Bd0<C4a02TY:@0/;2`0:b/[02LW9`0X:2P092@T0P0U9BD02P0S8b<08R8R02LW9`0b
<S80@D5107alO02h^;P0d=3@0=;BdP3Hf=P20>7Qh@0?0=GEe@3Fe]H0d=3@0<C4a02i^KT0_Kfm0<?3
``3=cLd0dM7A0=CDe03GemL0f=SH0=GEe@3Hf=P0g=cL0080gMgM00<0b/[:09BDU00o?cl00P0Z:RX0
4@0X:2P0:b/[02`/;00^;Rh0:RXZ02/[:`0Z:RX0;Bd]02h^;P0Z:RX0;bl_02`/;00d=3@0>SXj03/k
>`0c<c<0<C4a00<0=SHf00H0<c<c03De=@0b<S80<C4a03De=@0c<c<203Ph>00F030`<00a<C40=SHf
03Hf=P0d=3@0>3Ph03Hf=P0a<C40;2`/03De=@0^;Rh0=cLg034a<@0f=SH0=CDe03`l?00h>3P0;bl_
02h^;P0[:b/0:2PX02DU9@809bLW01D0<S8b03Lg=`0h>3P0CTi>05QHF01/K6`0OWin08^;R`2@T900
VIVI09JFUP2DU9@0TY:B092@T02ATI40Rh^;08V9R@27QhL0SXj>09NGU`2IVIT00P2OWil03@2RXZ80
Xj>S0:BTY02QXJ40Y:BT0:>SX`2OWil0X:2P09bLW02OWil0X:2P0:6QX@2KVi/00P2OWil0102PX:00
VIVI0:2PX02QXJ4>0<SPf0003038h=P205YJFP04065QH@1SHf<0Fe]K05QHF080Fe]K00X0GUiN05YJ
FP1JFUX0G5aL05IFEP1GEeL0FEUI05EEE@1GEeL0E5AD0P1FEUH0501CDe<0EEEE05=CD`1GEeL0Fe]K
06IVIP1[Jf/0MWIf08:2PP23Ph<0Rh^;092@T02DU9@0UYJF09NGU`2LW9`0WinO0:6QX@2UYJD0Y:BT
0P2VYZH20:FUY@0K0::RXP2TY:@0X:2P0:FUY@2QXJ40YZJV0:2PX02TY:@0Z:RX0::RXP2TY:@0VYZJ
09BDU02CTi<0RXZ:08f=S@20P800OWin07alO01]KFd0J6QX05iNGP1HF5P0De=C04I6AP1@D500Bd];
0080DU9B00D0De=C05]KF`1MGEd0GUiN05UIF@02061PH080GUiN01<0G5aL05]KF`1QHF40HV9R06IV
IP1OGel0J6QX06a/K01RHV80Hf=S06ATI01YJFT0HV9R06EUI@1RHV80GUiN069RHP1UIFD0JVYZ0080
JFUY00d0N7Qh075aL@1`L700JVYZ06i^KP1/K6`0Jf][06UYJ@1XJ6P0Kfm_06][J`1aLG40KVi^0080
Kfm_00P0M7Ad079bLP1_Kfl0Kfm_075aL@1bLW80K6a/06][J`80JVYZ0100Q8B40<G5a@35aLD0dm?C
0<;2`P2VYZH0UiNG07=cL`1UIFD0HV9R06ATI01`L700Kfm_06YZJP1TI6@0J6QX0P1ZJVX03@1]KFd0
KVi^06e]K@1cLg<0KFe]06MWI`1`L700M7Ad06m_K`1cLg<0MWIf06e]K@1YJFT00`1/K6`0501TI6@0
L71`07emO@1kNg/0MGEe07=cL`1eMGD0Ogmo0820P01nOWh0MgMg07alO026QXH0Q8B407YjNP22PX80
PH6108N7Q`29RHT0P8200P21PH407`23Ph<0Q8B4092@T02>SXh0RXZ:08R8R023Ph<0RHV908b<S02=
SHd0PX:207moO`1fMWH0SXj>08^;R`29RHT0RXZ:092@T02>SXh0OWin07emO@1dM7@0KVi^08J6QP20
P800OWin07UiN@1dM7@0KFe]06][J`1bLW800P26QXH01`2KVi/0WinO0:BTY02[Zj/0^KVi0;:b/P2i
^KT00P2m_Kd02032`/80][Jf0;2`/02j^[X0`l?30;Bd]02c/k<0];Bd0P2n_[h20;fm_@0=0;jn_P2o
_kl0_kno0;Ng]`2b/[80];Bd0:RXZ02RXZ80ZJVY0;Jf]P2e]KD0^[Zj0<G5a@020;jn_P0W0<;2`P33
`l<0`l?30<K6aP39bLT0aLG50<C4a031`L40`l?30<_;b`39bLT0alO70<G5a@2n_[h0`l?30<c<c03:
b/X0bl_;0<G5a@3<c<`0c/k>0<g=c@3<c<`0b<S80<_;b`36a/H0bLW90<[:bP3=cLd0b<S80<K6aP3=
cLd0clo?0<_;b`38b<P0a<C40<G5a@34a<@0alO70080bl_;00<0bLW90<S8b03<c<`00P3;bl/02`3=
cLd0d=3@0=3@d03@d=00cLg=0<c<c03Bd]80eMGE0=?Cd`3AdM40c<c<0080b/[:00L0dM7A0=GEe@3E
eMD0clo?0=3@d03Cdm<0eMGE0080e]KF00H0fMWI0>7Qh@3Rh^80hN7Q0>?Sh`3Rh^820=oOg`0D0<C4
a01XJ6P0<c<c03De=@13@d<0BTY:05]KF`1NGUh0Jf][06e]K@1mOGd0Ph>308Z:RP2=SHd0SXj>09>C
T`2GUiL0V9RH09JFUP2DU9@209NGU`0709>CT`2KVi/0VYZJ09VIV@2LW9`0Vi^K09RHV00209VIV@80
V9RH01X0VIVI09^KV`2DU9@0S8b<08j>SP20P800PH6107MgM`1SHf<0GemO05EEE@18B4P0>CTi03De
=@0c<c<0:2PX02TY:@0];Bd0;Rh^02d];@0/;2`0:b/[02h^;P0];Bd09RHV028R8P809RHV01T08b<S
02@T900S8b<09RHV038b<P19BDT0LG5a0:n_[`37alL0cLg=0=?Cd`3Jf]X0hN7Q0=_Kf`3Hf=P0dm?C
0<o?c`3=cLd0`l?30<;2`P36a/H0cLg=0=?Cd`3IfMT0emOG0080fMWI00P0f=SH0<o?c`2`/;00LG5a
04I6AP0_;bl0:RXZ02/[:`80;2`/00L0<c<c02XZ:P0Z:RX0>3Ph04=3@`0g=cL0:RXZ0080<c<c0140
?Cdm03/k>`0j>SX0=SHf03De=@0g=cL0=CDe03<c<`0d=3@0>3Ph03De=@0j>SX0?Shn04=3@`12@T80
>3Ph03@d=002038b<P0>03/k>`0h>3P0=CDe03Xj>P0c<c<0;Rh^034a<@0^;Rh0;Bd]03<c<`0f=SH0
<S8b03Hf=P0l?3`203Lg=`03034a<@0`<300;2`/00<0:b/[00P0;Rh^03Lg=`0k>c/0C4a<05]KF`1c
Lg<0PH6108R8R080UiNG01H0UYJF09FEU@2CTi<0TI6A08j>SP2;Rh/0R8R808V9R@2@T900TY:B09^K
V`2HV9P0WinO0:6QX@2RXZ80Xj>S0:6QX@2SXj<0X:2P09fMW@2RXZ80XJ6Q0P2NWYh01@2OWil0X:2P
09bLW02MWId0WYjN0080WinO3P38h=P000`0b>3H0P1QHF401@1JFUX0HF5Q05YJFP1MGEd0F5QH0080
GUiN01D0FEUI05]KF`1JFUX0Fe]K05iNGP1KFe/0G5aL05UIF@1FEUH0FEUI05aLG01EEED0Cdm?055A
D@1GEeL0FUYJ06=SH`1YJFT0M7Ad0861P@2;Rh/00P2ATI401P2GUiL0UYJF09ZJVP2MWId0X:2P0:>S
X`80XZ:R00d0Y:BT0:JVYP2SXj<0Xj>S0:BTY02XZ:P0X:2P0:JVYP2SXj<0YJFU0:>SX`2UYJD0X:2P
0080Y:BT01L0VYZJ09NGU`2@T900TY:B08Z:RP1oOgl0NWYj07AdM01^KVh0IFEU05YJFP1ADE40Cdm?
04i>CP1:BTX0C4a<051@D01DE5@0EeMG05QHF01FEUH0GUiN061PH00205eMG@0606=SH`1JFUX0G5aL
065QH@1MGEd0GUiN0P1QHF4206EUI@0;061PH01TI6@0IVIV06e]K@1WIfL0HV9R06EUI@1YJFT0I6AT
06MWI`1]KFd00P1WIfL03P1^KVh0Kfm_06i^KP1[Jf/0KVi^06IVIP1`L700Jf][06e]K@1bLW80KFe]
075aL@1_Kfl0MWIf0P1dM7@00`1eMGD0LW9b06m_K`0206a/K00506][J`1`L700IVIV06a/K01iNGT0
0P2d];@03P3EeMD0b<S80:f][@2<S8`0N7Qh065QH@1SHf<0J6QX079bLP1ZJVX0Jf][06QXJ01SHf<0
IfMW0P1ZJVX02P1YJFT0Lg=c06i^KP1/K6`0JVYZ06m_K`1bLW80Kfm_079bLP1cLg<2071`L00606e]
K@1/K6`0N7Qh07MgM`1^KVh0MWIf0P1oOgl0101eMGD0MWIf07EeM@20P80207emO@80P82001l0Ph>3
07moO`28R8P0RHV908B4Q026QXH0RHV908f=S@29RHT0QHF508>3P`22PX80QhN708j>SP26QXH0RXZ:
07alO022PX80TI6A08R8R027QhL0PH6108V9R@2?Shl0R8R808V9R@2BTY80Rh^;08n?S`2ATI40QhN7
0080O7al00L0NWYj0820P01mOGd0OGem06i^KP1XJ6P0IfMW0080K6a/0100Ng]k092@T02ZZZX0^;Rh
0;Jf]P2b/[80][Jf0;Vi^@30`<00^k^k0;Jf]P2j^[X0`L710;bl_02g]kL0`<300P2n_[h04P2a/K40
^k^k0;fm_@2o_kl0^k^k0;Ng]`2i^KT0`/;20<C4a02h^;P0/;2`0;6a/@2/[:`0[Jf]0;Rh^02k^k/0
_[jn0;no_`80alO700<0b<S80<[:bP36a/H00P33`l<05P34a<@0b/[:0<S8b033`l<0`/;20;jn_P2m
_Kd0alO70<[:bP3<c<`0b<S80<[:bP3=cLd0d=3@0<k>cP3@d=00cLg=0<S8b039bLT0b<S80<g=c@3;
bl/30<c<c0080<_;b`3:b/X0bLW90<g=c@3>c/h0b<S80<G5a@37alL20<30`0050<K6aP3=cLd0cLg=
0<c<c03=cLd00`3@d=020=;BdP080=GEe@3Cdm<0clo?0<c<c03>c/h0dM7A0<c<c03AdM420=?Cd`80
d];B01X0eMGE0=KFeP3Cdm<0e=CD0=gMg@3Ph>00gmoO0>7Qh@3Shn<0h>3P0>7Qh@3MgMd0/[:b05QH
F00f=SH0?clo04=3@`1;Bd/0De=C05mOG`1YJFT0L71`07inOP22PX80QHF508V9R@80TI6A01`0VYZJ
09VIV@2FUYH0UIFE09RHV02DU9@0UiNG09bLW02KVi/0UiNG09^KV`2JVYX0UYJF09NGU`2LW9`0V9RH
09^KV`2LW9`0UiNG09BDU02<S8`0QhN70861P@1nOWh0MWIf06MWI`1MGEd0DU9B0P0o?cl03@0b<S80
:b/[02l_;`0_;bl0;Bd]030`<00];Bd09bLW030`<00[:b/0:BTY02`/;00V9RH00P0X:2P00`0Y:BT0
8b<S02PX:00202h^;P0<03hn?P1>CTh0JFUY09^KV`30`<00bl_;0<W9b@3Cdm<0fMWI0=kNgP3Jf]X0
e]KF0P3EeMD04P3?cll0bLW90;no_`2i^KT0a/K60<_;b`3Bd]80c<c<0<71`@2YZJT0Ti>C0861P@1I
FET0@41002l_;`0^;Rh0;Bd]02h^;P80:RXZ00H0;2`/034a<@0`<300<S8b02h^;P0Y:BT2034a<@0U
03Hf=P0h>3P0<S8b03Ph>00d=3@0>3Ph03Ti>@0f=SH0=cLg03Ph>00j>SX0@4100492@P0k>c/0>SXj
03Lg=`0a<C40?3`l03Ti>@0e=CD0=3@d030`<00^;Rh0=SHf030`<00/;2`0<S8b02l_;`0`<300<c<c
03Ti>@0h>3P0?3`l03Ti>@0b<S80<30`02d];@0202h^;P0<02l_;`0/;2`0;2`/02/[:`0g=cL0C4a<
065QH@1bLW80QHF508n?S`2CTi<0W9bL0P2GUiL0102@T900S8b<08N7Q`29RHT208Z:RP0508f=S@2F
UYH0Vi^K09fMW@2TY:@01@2QXJ40302SXj<0XJ6Q09nOW`2NWYh0XJ6Q0:2PX02NWYh0WIfM0:2PX02M
WId0WYjN0:6QX@h0b>3H000<0<SPf080F5QH00H0I6AT05eMG@1GEeL0GUiN05eMG@1GEeL205eMG@0P
061PH01RHV80GUiN05]KF`1PH600GEeM05aLG01MGEd0EeMG05eMG@1BDU80E5AD05QHF01FEUH0G5aL
06=SH`1YJFT0MGEe07inOP26QXH0SHf=08b<S02BTY80UiNG09ZJVP2NWYh0WinO0::RXP2VYZH0YJFU
0:RXZ02VYZH20:BTY00N0:JVYP2TY:@0YJFU0:FUY@2RXZ80Y:BT0:>SX`2XZ:P0Xj>S0:BTY02QXJ40
VYZJ09fMW@2?Shl0S8b<08N7Q`1mOGd0MgMg07=cL`1^KVh0GemO05]KF`1@D500DE5A04U9B@17AdL0
DE5A05EEE@1ADE40EeMG0P1HF5P205UIF@0;06EUI@1PH600GemO061PH01NGUh0HF5Q05iNGP1KFe/0
HF5Q06ATI01SHf<00P1RHV802P1SHf<0Jf][06YZJP1WIfL0Hf=S06EUI@1VIVH0HF5Q06=SH`1RHV82
06UYJ@0E06QXJ01^KVh0L71`06][J`1XJ6P0K6a/06e]K@1`L700LW9b06m_K`1/K6`0KFe]07AdM01e
MGD0M7Ad07=cL`1hN7P0Kfm_071`L01]KFd0LG5a0080Kfm_00<0Jf][06m_K`1aLG400P2?Shl0203<
c<`0c/k>0;Jf]P2@T900LW9b06ATI01UIFD0IfMW0P1ZJVX04`1WIfL0Jf][06][J`1YJFT0K6a/06i^
KP1WIfL0L71`06][J`1XJ6P0LG5a07=cL`1aLG40JVYZ06i^KP1dM7@0Kfm_075aL@1iNGT00P1`L700
101jNWX0MWIf07EeM@1fMWH207YjNP0@07QhN01_Kfl0M7Ad07QhN024Q8@0QHF507emO@1kNg/0OGem
07inOP26QXH0QhN708J6QP24Q8@0U9BD09>CT`80RHV900X0Ph>307alO01oOgl0R8R8092@T024Q8@0
O7al08>3P`27QhL0S8b<0P2=SHd03`24Q8@0QhN708N7Q`2EUID0TY:B08V9R@20P800S8b<08N7Q`26
QXH0NWYj07EeM@20P800Q8B407]kN`0206][J`80MGEe00P0IfMW07]kN`2@T900YZJV0:j^[P2l_;`0
];Bd0;Jf]P80/K6a00T0^;Rh0<C4a031`L40][Jf0<C4a03:b/X0aLG50;Jf]P2b/[800P2i^KT07@2h
^;P0][Jf0;6a/@2o_kl0`l?30;jn_P2g]kL0`L710<;2`P2e]KD0[Zj^0:FUY@2^[Zh0^k^k0<;2`P35
aLD0alO70<c<c034a<@0`L710<30`03:b/X0bLW90<S8b033`l<0`<300<71`@30`<00b/[:0080alO7
00L0a/K60<W9b@3=cLd0c<c<0<g=c@3>c/h0cLg=0080clo?01L0bl_;0<G5a@36a/H0bl_;0=?Cd`3=
cLd0c/k>0<c<c039bLT0d=3@0=;BdP3?cll0bl_;0<c<c03;bl/0_kno0;fm_@32`/80alO70<W9b@3:
b/X0bl_;0<g=c@020<o?c`0>0=KFeP3De=@0dm?C0=7Ad@3>c/h0clo?0<c<c03?cll0c/k>0=?Cd`3D
e=@0dm?C0=KFeP3EeMD20=CDe0030=?Cd`3GemL0g]kN0080gmoO00l0hN7Q0>CTi03Ti>@0g]kN0<O7
a`29RHT0?Shn03Hf=P0n?Sh0@d=304];B`1IFET0HF5Q06i^KP1fMWH00P20P800;`28R8P0QhN7092@
T02DU9@0V9RH09VIV@2EUID0U9BD09JFUP2HV9P0UYJF09VIV@2HV9P0VYZJ09JFUP2MWId0UiNG09^K
V`2OWil0W9bL09^KV`2PX:00UiNG092@T02=SHd0QHF50861P@1mOGd0LG5a06a/K01SHf<0DU9B04A4
A00n?Sh0>3Ph03<c<`0];Bd0;2`/02TY:@0X:2P0;bl_030`<00Z:RX0;2`/02HV9P0a<C40:RXZ0080
9BDU00/0:2PX02DU9@0X:2P0;Bd]03De=@13@d<0Cdm?05IFEP1UIFD0QXJ60:NWY`020<?3``0G0<W9
b@3Bd]80f][J0=[JfP3Kfm/0fMWI0=3@d033`l<0ZZZZ09bLW02[Zj/0/k>c0<K6aP35aLD0Zj^[09FE
U@2BTY80RHV9079bLP1LG5`0=SHf02`/;00[:b/00P0W9bL08`0[:b/0;bl_02d];@0[:b/0>c/k03@d
=00e=CD0<c<c02l_;`0g=cL0=SHf030`<00h>3P0>SXj03Hf=P0g=cL0<S8b034a<@0^;Rh0=cLg03@d
=00h>3P0>CTi03dm?@0h>3P0=3@d02l_;`0i>CT0<30`034a<@0k>c/0>3Ph03@d=00f=SH0;Bd]0080
;bl_0P0g=cL01@0e=CD0?Cdm03@d=00a<C40=cLg0080<S8b0P0e=CD0:P0a<C40;Rh^02HV9P0X:2P0
;Bd]03`l?01@D500IVIV07]kN`27QhL0Shn?09JFUP2GUiL0UYJF096AT@2=SHd0RXZ:08^;R`26QXH0
R8R808J6QP2>SXh0Ti>C09ZJVP2MWId0XJ6Q09nOW`2MWId0Xj>S0:6QX@2SXj<0WinO0:2PX02RXZ80
WinO09VIV@2KVi/0X:2P09jNWP2QXJ40XZ:R0:2PX0h0b>3H000<0<SPf080GUiN00T0GEeM05]KF`1K
Fe/0FEUI05aLG01MGEd0HF5Q05YJFP1HF5P00P1MGEd04@1KFe/0FUYJ05iNGP1NGUh0GEeM05QHF01I
FET0EeMG05]KF`1MGEd0EUIF05]KF`1UIFD0Jf][075aL@1mOGd0Q8B40080S8b<00<0TY:B09FEU@2G
UiL00P2NWYh00`2PX:00XJ6Q0:FUY@020:FUY@<0YZJV02d0YJFU0:>SX`2UYJD0X:2P0:FUY@2PX:00
XZ:R0:VYZ@2UYJD0XZ:R09^KV`2JVYX0TY:B08Z:RP28R8P0P82007]kN`1cLg<0JVYZ06=SH`1LG5`0
DE5A04i>CP18B4P0BTY:051@D01ADE40Cdm?05UIF@1KFe/0DU9B05EEE@1FEUH0HF5Q05mOG`1NGUh0
HF5Q069RHP1TI6@0HV9R061PH01QHF40Hf=S069RHP1WIfL00P1SHf<0301TI6@0J6QX06UYJ@1UIFD0
Jf][06EUI@1VIVH0IFEU06IVIP1UIFD0JVYZ06IVIP80KFe]00D0Kfm_06i^KP1cLg<0KFe]06i^KP02
06a/K00:075aL@1_Kfl0Kfm_075aL@1bLW80K6a/07=cL`1bLW80M7Ad06m_K`80K6a/00@0Jf][06QX
J01ZJVX0Kfm_0P1gMgL03@2[Zj/0clo?0;no_`2TY:@0MGEe069RHP1[Jf/0HF5Q069RHP1UIFD0J6QX
06MWI`1XJ6P00P1]KFd01@1/K6`0Kfm_06][J`1^KVh0L71`0080KFe]01d0LW9b06MWI`1WIfL0KVi^
07AdM01bLW80Lg=c07EeM@1aLG40N7Qh08:2PP1nOWh0NWYj07]kN`1gMgL0M7Ad0861P@1kNg/0N7Qh
07IfMP1lO7`0Ogmo0820P01gMgL0N7Qh07moO`27QhL0QHF508N7Q`0208^;R`0:096AT@2<S8`0TY:B
08N7Q`1mOGd0NWYj08Z:RP28R8P0P82008>3P`80PX:200l0QXJ609>CT`2<S8`0QHF508B4Q028R8P0
T92@08n?S`23Ph<0QXJ608N7Q`29RHT0Ph>307YjNP1gMgL00P25QHD07@1hN7P0Kfm_06a/K01/K6`0
Kfm_079bLP1^KVh0Ogmo09fMW@2^[Zh0]kNg0:j^[P2SXj<0[Jf]0;bl_032`/80]kNg0<30`03;bl/0
b<S80<30`02j^[X0_Kfm0<;2`P2d];@0/k>c0;Fe]@2g]kL0`/;20080_;bl01P0`l?30<K6aP32`/80
_Kfm0;Rh^02c/k<0/[:b0:^[Z`2d];@0_kno0<K6aP37alL0`l?30<30`036a/H0bl_;0<G5a@33`l<0
^k^k0<30`035aLD0b<S80<W9b@36a/H20<?3``040<k>cP3@d=00c<c<0<k>cP80bl_;00D0c<c<0<o?
c`35aLD0`/;20<W9b@020=7Ad@0B0<_;b`39bLT0a/K60<W9b@3>c/h0c<c<0<_;b`3<c<`0clo?0<_;
b`36a/H0bl_;0<O7a`38b<P0a<C40<O7a`35aLD0c<c<0P3Bd]803@3Cdm<0dM7A0<k>cP3>c/h0d];B
0<g=c@3<c<`0b/[:0=;BdP3De=@0d];B0=CDe03EeMD00P3Fe]H00`3Cdm<0f=SH0=kNgP020=oOg`0I
0>7Qh@3Ti>@0hN7Q0=gMg@3=cLd0XZ:R065QH@0i>CT0>3Ph04E5A@17AdL0D51@05UIF@1RHV80Kfm_
07alO020P800PX:208N7Q`2;Rh/0SHf=09>CT`2GUiL0W9bL09JFUP0209ZJVP0409NGU`2HV9P0VYZJ
09^KV`80VIVI00D0Vi^K09ZJVP2HV9P0Vi^K09ZJVP0209VIV@0A09BDU02ATI40S8b<08R8R024Q8@0
Ng]k071`L01/K6`0GemO05=CD`1<C4`0@D51034a<@0e=CD0<30`02d];@0`<3000P0Z:RX01P0c<c<0
;Bd]02`/;00Z:RX0:BTY02HV9P80:BTY01409bLW02PX:00^;Rh0?3`l04=3@`1@D500Fe]K05mOG`1W
IfL0KVi^07alO02CTi<0[:b/0;:b/P2i^KT0`L710<C4a0020<S8b00H0;fm_@2RXZ80RXZ:08f=S@2?
Shl0SXj>0:FUY@2/[:`0XZ:R09:BTP2FUYH0Ti>C08R8R01aLG40BTY:030`<00[:b/0:RXZ02l_;`0a
<C40;2`/02XZ:P0f=SH0<c<c0P0/;2`03@0^;Rh0<30`038b<P0h>3P0>c/k03Ti>@0l?3`0@41003Hf
=P0b<S80<C4a030`<00k>c/00P0e=CD05@0j>SX0>3Ph03De=@0f=SH0<C4a03Ph>00d=3@0<C4a030`
<00j>SX0<S8b03De=@0j>SX0<S8b02d];@0_;bl0=CDe03Ph>00g=cL0<c<c03/k>`0203Ti>@0603@d
=00b<S80<S8b02l_;`0Y:BT0:RXZ0P0S8b<0200`<300>c/k05aLG01XJ6P0OGem08j>SP2BTY80VIVI
0P2EUID01P2DU9@0SHf=096AT@28R8P0PX:208J6QP80SHf=00P0UYJF09bLW02NWYh0X:2P0:6QX@2T
Y:@0X:2P0::RXP80Xj>S00T0XJ6Q0:2PX02SXj<0Xj>S0:6QX@2PX:00XJ6Q09fMW@2QXJ403P38h=P0
00`0b>3H0P1LG5`0201IFET0GemO05]KF`1JFUX0G5aL05eMG@1QHF40F5QH0P1JFUX07P1IFET0Fe]K
061PH01OGel0FEUI05]KF`1GEeL0EUIF059BDP1JFUX0F5QH05ADE01OGel0IFEU06m_K`1fMWH0PH61
08F5Q@2?Shl0UIFE09JFUP2HV9P0WinO0:2PX02RXZ80X:2P0::RXP2SXj<0YJFU0:BTY0<0YZJV00<0
Y:BT0:VYZ@2QXJ400`2RXZ801P2SXj<0YZJV0::RXP2PX:00VYZJ09JFUP80TY:B01h0SXj>07inOP1n
OWh0MGEe06][J`1UIFD0EEEE05MGE`1<C4`0CTi>04a<C01=CDd0D51@05QHF01GEeL0De=C05IFEP1H
F5P0Fe]K065QH@1OGel0Fe]K05mOG`1PH600HV9R061PH01VIVH0HF5Q069RHP1VIVH206EUI@0406AT
I01RHV80IVIV06=SH`80IVIV0P1SHf<02P1UIFD0I6AT06QXJ01PH600IfMW06EUI@1]KFd0KVi^06][
J`1aLG42071`L00A06i^KP1`L700Lg=c079bLP1aLG40LW9b07EeM@1`L700M7Ad07IfMP1cLg<0MgMg
07EeM@1cLg<0LG5a06][J`1ZJVX00`1`L7003`2CTi<0a/K60<O7a`2YZJT0Ogmo06QXJ01RHV80JFUY
06MWI`1TI6@0LW9b07EeM@1RHV80IVIV06UYJ@0206][J`0506a/K01[Jf/0Jf][075aL@1eMGD00P1[
Jf/01@1gMgL0K6a/07AdM01cLg<0M7Ad0080L71`00h0N7Qh07MgM`1gMgL0NWYj07UiN@1cLg<0Ng]k
07EeM@1gMgL0P82007]kN`1fMWH0Q8B40861P@80Q8B400/0NGUi07YjNP24Q8@0Ph>308Z:RP2<S8`0
R8R8092@T02DU9@0UYJF08b<S00207alO00E08>3P`29RHT0QhN708j>SP25QHD0M7Ad08F5Q@2GUiL0
TY:B08j>SP28R8P0Rh^;08n?S`2DU9@0S8b<07emO@1nOWh0Q8B408R8R022PX80O7al0080Ph>302h0
Ng]k075aL@1aLG40IfMW079bLP1`L700KFe]07QhN02FUYH0[Zj^0:NWY`2][Jd0/;2`0;Vi^@2e]KD0
][Jf0<C4a039bLT0a/K60;no_`2l_;`0`<300;no_`2c/k<0^[Zj0;bl_02m_Kd0][Jf0;Zj^P35aLD0
`l?30<;2`P2n_[h0`<300<C4a036a/H0_kno0;2`/02[Zj/0^;Rh0;jn_P30`<00_kno0<G5a@36a/H0
alO70P35aLD02@30`<00alO70<[:bP3:b/X0bLW90<G5a@38b<P0bl_;0<g=c@020<_;b`0:0<k>cP3;
bl/0cLg=0=3@d03>c/h0`<300<[:bP3Bd]80dM7A0<k>cP80alO700`0c<c<0<o?c`3=cLd0bLW90<_;
b`3>c/h0bl_;0<[:bP3>c/h0cLg=0<c<c03;bl/20<c<c00>0<[:bP3<c<`0cLg=0<g=c@3:b/X0bLW9
0<_;b`3>c/h0clo?0<c<c03>c/h0d];B0=KFeP3De=@20=GEe@0G0=[JfP3IfMT0emOG0=KFeP3Lg=`0
gmoO0>3Ph03Rh^80i>CT0>7Qh@3Ogml0cLg=0:FUY@1^KVh0BDU903Ph>00o?cl0B4Q804];B`1CDe<0
EEEE069RHP1]KFd00P1iNGT01024Q8@0R8R808b<S02?Shl209:BTP0409FEU@2HV9P0UYJF09ZJVP80
UiNG00`0WIfM09bLW02JVYX0W9bL09nOW`2IVIT0W9bL09VIV@2KVi/0VIVI09JFUP2DU9@208n?S`0F
08>3P`22PX80OGem06m_K`1YJFT0Fe]K05ADE017AdL0>SXj03Lg=`0`<300;Rh^02`/;00`<300<S8b
02l_;`0X:2P0;2`/02PX:00U9BD0:2PX02TY:@80:2PX01L0:RXZ03@d=00g=cL0A4A404i>CP1LG5`0
HV9R06][J`1bLW80MgMg07inOP1oOgl0Q8B408f=S@2HV9P0WYjN09bLW02KVi/0WYjN09BDU02<S8`0
QHF508Z:RP0208b<S00Z092@T02EUID0VYZJ096AT@2GUiL0UYJF09:BTP1oOgl0J6QX0492@P0a<C40
:b/[02`/;00X:2P0:BTY02`/;00`<300:2PX02XZ:P0^;Rh0<S8b030`<00b<S80=3@d02l_;`0c<c<0
?clo03`l?00h>3P0<C4a03<c<`0d=3@0>3Ph03Hf=P0h>3P0>SXj03Hf=P0_;bl0=CDe038b<P0[:b/0
=3@d0P0f=SH03P0j>SX0>3Ph03Ti>@0j>SX0;bl_02XZ:P0c<c<0;bl_02h^;P0f=SH0=cLg03Ph>00l
?3`0>c/k0`0a<C40800`<300;Bd]02HV9P0Q8B40:2PX02h^;P0b<S80ADE505aLG01cLg<0PH6108f=
S@2DU9@0UiNG09JFUP2EUID0T92@08n?S`2ATI40S8b<08N7Q`29RHT0RXZ:09JFUP2KVi/0WYjN09nO
W`2NWYh0WIfM0:2PX02VYZH0Xj>S0P2RXZ8209nOW`80X:2P0`2RXZ800`2QXJ40b>3H0<SPf00<0<SP
f0003038h=P205UIF@0805QHF01IFET0F5QH05YJFP1PH600IFEU05YJFP1LG5`2061PH080Fe]K01H0
GEeM05YJFP1IFET0Fe]K05UIF@1HF5P0EUIF05QHF01FEUH0E5AD05mOG`1UIFD0L71`07UiN@1jNWX0
QHF508f=S@2@T900U9BD09VIV@2OWil0WIfM0P2PX:00102UYJD0Y:BT0:RXZ02VYZH20:BTY0060:NW
Y`2UYJD0Xj>S0:BTY02RXZ80YZJV0P2SXj<0602WYjL0Xj>S09jNWP2LW9`0UYJF09>CT`2>SXh0QHF5
07moO`1hN7P0L71`06UYJ@1QHF40GUiN05QHF01>CTh0ADE504I6AP1@D500EUIF05ADE01CDe<0EeMG
05YJFP80FEUI00<0GUiN05]KF`1NGUh00P1TI6@0901PH600IfMW06IVIP1QHF40I6AT069RHP1QHF40
IFEU065QH@1TI6@0JVYZ06ATI01UIFD0HF5Q06EUI@1QHF40J6QX06ATI01WIfL0HV9R06IVIP1UIFD0
K6a/06][J`1YJFT0K6a/06YZJP1/K6`0KVi^075aL@1eMGD0Lg=c07IfMP1^KVh0MWIf07AdM080Lg=c
00@0MGEe079bLP1fMWH0Lg=c0`1_Kfl08`1cLg<0KFe]06e]K@20P800^[Zj0<O7a`2XZ:P0SHf=06m_
K`1SHf<0FUYJ06QXJ01ZJVX0KFe]06YZJP1cLg<0KFe]06ATI01/K6`0M7Ad06i^KP1bLW80J6QX06a/
K01gMgL0LG5a06UYJ@1bLW80KVi^07=cL`1_Kfl0M7Ad071`L01]KFd0KVi^0080LW9b00l0MWIf079b
LP1mOGd0Ng]k07YjNP1bLW80Ng]k0820P01oOgl0OWin07YjNP1iNGT0Q8B408:2PP1lO7`00P1kNg/0
5P28R8P0RHV908J6QP2<S8`0RXZ:08f=S@2FUYH0S8b<07moO`1mOGd0NWYj08>3P`2:RXX0TI6A08J6
QP1mOGd0Ph>308f=S@2CTi<0Rh^;08J6QP27QhL2092@T00908F5Q@22PX80Ng]k08V9R@2<S8`0OWin
07]kN`1dM7@0NGUi0080Ph>301T0M7Ad07QhN01dM7@0OGem06m_K`1hN7P0QhN70:>SX`2][Jd0][Jf
0;6a/@2][Jd0_kno0<O7a`30`<00^[Zj0;fm_@2l_;`0`l?30;Vi^@2c/k<0alO70<;2`P2h^;P0]KFe
0080`L7100/0_;bl0<30`030`<00`L710<O7a`33`l<0^[Zj0;Bd]033`l<0`/;20;>c/`020;Jf]P0=
0<71`@30`<00`/;20<;2`P35aLD0bLW90<O7a`39bLT0bl_;0<?3``36a/H0cLg=0=7Ad@020<[:bP0@
0<c<c03>c/h0c/k>0=7Ad@3Cdm<0b/[:0<C4a03Cdm<0d];B0<k>cP37alL0`<300<c<c03Bd]80d=3@
0<c<c080clo?0P3=cLd02@3>c/h0d=3@0<g=c@3=cLd0c/k>0=3@d03?cll0d=3@0<k>cP020<g=c@80
alO700<0b/[:0<_;b`35aLD00P3;bl/0<@3AdM40d=3@0=?Cd`3EeMD0e]KF0=[JfP3EeMD0emOG0=WI
f@3MgMd0g]kN0>3Ph03Rh^80gmoO0=kNgP3AdM40YJFU07]kN`1QHF40DE5A03Ph>016ATH0Bd];04a<
C01CDe<0F5QH05iNGP1^KVh0MWIf07alO021PH40QhN708f=S@2?Shl0TI6A09NGU`2JVYX0V9RH09ZJ
VP2MWId0VIVI09NGU`2KVi/0XZ:R09^KV`2IVIT0W9bL09NGU`2MWId00P2IVIT209RHV00I09FEU@2@
T900RXZ:08N7Q`21PH40Ng]k075aL@1YJFT0GEeM05MGE`11@D40>SXj038b<P0_;bl0;Rh^02d];@0^
;Rh0;2`/02h^;P0_;bl0:BTY02`/;00V9RH0:BTY02`/;00302h^;P0<03De=@17AdL0CTi>05UIF@1Q
HF40JFUY07AdM01hN7P0O7al08>3P`26QXH0RHV90`2>SXh00`2;Rh/0RXZ:08^;R`0208Z:RP0T08J6
QP2>SXh0T92@08^;R`2=SHd0T92@09FEU@2CTi<0UIFE09RHV02DU9@0RHV907UiN@1PH600>3Ph02d]
;@0Y:BT0:RXZ02/[:`0_;bl0:b/[02d];@0a<C40:b/[034a<@0];Bd0=CDe034a<@0b<S80=CDe03Ti
>@0g=cL0<C4a030`<00];Bd0<C4a0P0e=CD06@0b<S80<c<c03Hf=P0j>SX0<C4a02l_;`0`<300;Bd]
02l_;`0f=SH0<c<c03De=@0i>CT0>SXj03De=@0b<S80=SHf02`/;00];Bd0=CDe02l_;`0g=cL0=SHf
03/k>`0h>3P00P0b<S801P0h>3P0<C4a02h^;P0X:2P0:BTY02l_;`80>CTi01@0C4a<06IVIP1jNWX0
QXJ609>CT`2EUID0V9RH09VIV@2FUYH0Ti>C08n?S`2BTY80RXZ:08J6QP21PH40Shn?09>CT`2JVYX0
W9bL09^KV`80XJ6Q0P2TY:@0102OWil0YJFU09jNWP2OWil30::RXP030:JVYP2SXj<0XZ:R00h0b>3H
000<0<SPf080GUiN00P0FUYJ05MGE`1MGEd0GEeM05aLG01IFET0HF5Q05]KF`80GUiN00P0F5QH05YJ
FP1DE5@0F5QH05UIF@1OGel0Fe]K05YJFP80FEUI00h0FUYJ05MGE`1TI6@0IFEU079bLP1hN7P0PH61
08:2PP2<S8`0SXj>09FEU@2GUiL0WIfM09bLW080X:2P00@0XJ6Q0:BTY02WYjL0YZJV0P2TY:@0102S
Xj<0Y:BT0:BTY02TY:@20:>SX`0G0:JVYP2SXj<0X:2P0:>SX`2QXJ40Vi^K09JFUP2>SXh0S8b<08J6
QP24Q8@0NWYj071`L01_Kfl0I6AT061PH01IFET0C4a<051@D01<C4`0Cdm?05=CD`1@D5000P1HF5P2
05aLG00905mOG`1LG5`0FEUI05mOG`1QHF40H61P06MWI`1QHF40IFEU0080H61P00T0IVIV06EUI@1U
IFD0HV9R06EUI@1VIVH0Hf=S06IVIP1RHV800P1SHf<02@1TI6@0H61P06MWI`1UIFD0JVYZ06EUI@1Z
JVX0IFEU06UYJ@0206][J`0406i^KP1]KFd0KVi^07IfMP80Lg=c00X0MWIf07QhN01cLg<0LG5a07Ad
M01]KFd0Kfm_07=cL`1dM7@0MgMg0P1aLG402P1^KVh0LW9b079bLP1cLg<0VIVI0<K6aP2ZZZX0UIFE
07IfMP1TI6@306=SH`0<06MWI`1XJ6P0KFe]075aL@1UIFD0J6QX071`L01cLg<0M7Ad071`L01]KFd0
LW9b0P1`L7002`1/K6`0LG5a07=cL`1]KFd0LG5a07UiN@1eMGD0Jf][06m_K`1fMWH0MGEe0080LW9b
00<0LG5a07moO`1hN7P00P1jNWX01P20P800Ph>307emO@1/K6`0MGEe0861P@80Q8B401H0PH6108F5
Q@29RHT0Ph>308Z:RP2@T900Rh^;09BDU02HV9P0T92@08Z:RP25QHD0MWIf07AdM02;Rh/0U9BD08j>
SP25QHD0Ogmo092@T02FUYH0T92@0P29RHT01P25QHD0TI6A08j>SP21PH40OGem08J6QP80RXZ:01D0
NWYj07IfMP20P800P82008>3P`24Q8@0PX:207]kN`1iNGT0O7al07QhN02;Rh/0XJ6Q0:j^[P2][Jd0
][Jf0<G5a@2o_kl0^;Rh0;Fe]@2d];@00P2o_kl02@2h^;P0_[jn0<S8b033`l<0_Kfm0<?3``36a/H0
_;bl0;^k^`020<71`@0G0<G5a@2n_[h0^;Rh0;Bd]030`<00b<S80<71`@2m_Kd0^k^k0:n_[`2i^KT0
];Bd0;Vi^@2k^k/0`l?30<K6aP37alL0bLW90<O7a`35aLD0b/[:0<g=c@3:b/X00`3>c/h20<g=c@04
0<k>cP37alL0alO70<k>cP80e=CD00H0d];B0<K6aP2j^[X0d];B0<k>cP3<c<`20=;BdP080<g=c@3;
bl/0cLg=0=7Ad@3Bd]80dM7A0<c<c03>c/h20<g=c@030=3@d03=cLd0cLg=0080cLg=00X0c<c<0<k>
cP3?cll0bl_;0<S8b03:b/X0c/k>0<o?c`3AdM40e]KF0P3Hf=P08P3GemL0eMGE0=oOg`3Lg=`0f][J
0=oOg`3Ng]h0gmoO0>3Ph033`l<0LG5a05EEE@1JFUX0EeMG04M7A`12@T80AdM704m?C`1GEeL0HV9R
06UYJ@1]KFd0M7Ad07alO020P800QXJ6092@T02>SXh0Ti>C09BDU02HV9P0VYZJ09VIV@2KVi/309ZJ
VP0809VIV@2KVi/0W9bL09ZJVP2GUiL0WIfM09bLW02HV9P309FEU@0<09>CT`29RHT0R8R808J6QP1j
NWX0LW9b06][J`1MGEd0E5AD04=3@`0l?3`0=SHf0P0[:b/02P0^;Rh0;2`/02XZ:P0];Bd0:BTY02@T
900W9bL092@T02DU9@0Z:RX2030`<00>03Lg=`12@T80Cdm?05UIF@1SHf<0Kfm_07IfMP1lO7`0OGem
0820P027QhL0R8R808^;R`2>SXh2096AT@0:092@T02;Rh/0QhN708^;R`29RHT0R8R808Z:RP2=SHd0
SXj>08n?S`<0U9BD00`0UYJF09NGU`2KVi/0Vi^K08J6QP1cLg<0C4a<038b<P0Y:BT0;bl_02PX:00/
;2`202/[:`0702XZ:P0Y:BT0:b/[02`/;00k>c/0=3@d02l_;`02038b<P0P03/k>`0c<c<0>3Ph03Lg
=`0e=CD0>SXj03Ph>00k>c/0<C4a03Hf=P0b<S80?clo038b<P0_;bl0:BTY030`<00c<c<0=3@d03dm
?@0i>CT0>SXj03dm?@0e=CD0<S8b030`<00b<S80=CDe03@d=00f=SH0=3@d03lo?`0m?Cd203/k>`0Z
03Hf=P0`<300=SHf02PX:00W9bL0;2`/02h^;P0f=SH0CTi>05MGE`1YJFT0MWIf08R8R02BTY80U9BD
09ZJVP2EUID0Ti>C09:BTP2?Shl0SXj>08V9R@20P800Ph>308f=S@2CTi<0UiNG09bLW02OWil0X:2P
0:>SX`2RXZ80X:2P0::RXP2TY:@0XJ6Q0:>SX`2MWId0Xj>S0:NWY`2TY:@0YJFU3P38h=P000`0b>3H
0P1HF5P0501LG5`0E5AD05UIF@1QHF40G5aL06=SH`1KFe/0GemO05EEE@1MGEd0FUYJ05aLG01PH600
GemO05aLG01NGUh0FEUI05]KF`1JFUX0G5aL0P1IFET04P1QHF40IfMW079bLP1fMWH0PH6108B4Q029
RHT0Shn?09:BTP2EUID0XZ:R09ZJVP2KVi/0WinO0::RXP2TY:@0Xj>S0:FUY@80X:2P01X0XZ:R0:>S
X`2RXZ80YjNW0::RXP2NWYh0XJ6Q0::RXP2SXj<0X:2P09^KV`2LW9`0UYJF092@T02=SHd0R8R808:2
PP1gMgL0LG5a06YZJP1QHF40FEUI05ADE01=CDd0C4a<04e=C@80Bd];00D0E5AD05UIF@1HF5P0H61P
05iNGP0205]KF`0>061PH01OGel0GemO065QH@1PH600GUiN06=SH`1MGEd0HV9R06YZJP1UIFD0J6QX
06=SH`1UIFD206IVIP0>06EUI@1PH600HV9R065QH@1TI6@0J6QX06EUI@1VIVH0IFEU06MWI`1UIFD0
J6QX06][J`1YJFT206e]K@0:06][J`1`L700MGEe06e]K@1bLW80LG5a07IfMP1cLg<0LW9b07QhN080
L71`00H0Lg=c075aL@1bLW80Kfm_075aL@1[Jf/206m_K`0907=cL`27QhL0_Kfm0;Rh^02@T900N7Qh
06MWI`1UIFD0J6QX0080JFUY0140Jf][06e]K@1[Jf/0IFEU071`L01ZJVX0Kfm_07=cL`1bLW80JVYZ
079bLP1dM7@0K6a/07=cL`1/K6`0LG5a07AdM003079bLP0807IfMP1cLg<0KVi^06i^KP1aLG40L71`
06e]K@1`L70207]kN`0@07alO01hN7P0Q8B40820P01lO7`0L71`07UiN@22PX80S8b<096AT@2:RXX0
Q8B407inOP24Q8@0Shn?096AT@80T92@00@0TY:B096AT@2@T900PX:20P1eMGD02P27QhL0UYJF08n?
S`26QXH0QhN709>CT`2JVYX0SXj>08R8R029RHT2092@T00709:BTP27QhL0Ng]k08>3P`28R8P0Ogmo
07UiN@0207EeM@050820P029RHT0R8R807inOP1fMWH00P1nOWh04021PH40OGem08j>SP2SXj<0_Kfm
0<?3``2m_Kd0^[Zj0:f][@2f][H0];Bd0;Zj^P2m_Kd0alO70<S8b02l_;`20<[:bP0>0<?3``2l_;`0
_Kfm0<C4a035aLD0`/;20;Zj^P2f][H0a<C40<G5a@31`L40_;bl0;no_`32`/820<71`@050;6a/@2/
[:`0][Jf0;bl_033`l<00P35aLD01@37alL0c<c<0<o?c`3@d=00c<c<0080clo?00H0bLW90<g=c@3>
c/h0bLW90<G5a@39bLT20<o?c`0<0=;BdP3?cll0aLG50<G5a@3@d=00bl_;0<[:bP3AdM40c/k>0<[:
bP3>c/h0d=3@0P3AdM401@3De=@0clo?0<k>cP3<c<`0clo?0080c/k>0`3?cll01P3=cLd0clo?0=7A
d@3=cLd0b/[:0<g=c@80e=CD00X0dm?C0=GEe@3EeMD0e]KF0=WIf@3Fe]H0gMgM0=[JfP3EeMD0f][J
0P3IfMT0503GemL0/K6a05MGE`0o?cl0?3`l0451@@12@T80@d=304a<C01BDU80FUYJ05eMG@1SHf<0
KFe]07IfMP1oOgl0PH6108N7Q`2<S8`0SXj>0P2FUYH0302GUiL0VYZJ09ZJVP2IVIT0VYZJ09VIV@2L
W9`0VIVI09^KV`2LW9`0Vi^K09ZJVP<0VIVI0180Vi^K09FEU@2FUYH0Ti>C08f=S@29RHT0PH6107in
OP1dM7@0Jf][05iNGP1BDU80@D5103/k>`0b<S80;bl_02d];@0a<C4202d];@0702l_;`0W9bL0<30`
02XZ:P0X:2P0;Rh^02`/;00202l_;`050492@P18B4P0E5AD05YJFP1]KFd00P1fMWH01@1nOWh0PX:2
08>3P`2<S8`0RXZ:0080Shn?00P0UYJF09>CT`2<S8`0S8b<08V9R@2<S8`0RXZ:08^;R`80SXj>03P0
Rh^;08f=S@2EUID0TI6A09BDU02EUID0V9RH09bLW02IVIT0U9BD0861P@1XJ6P0@d=303Hf=P0Y:BT0
:b/[030`<00];Bd0;2`/02d];@0^;Rh0:RXZ034a<@0[:b/0:2PX034a<@0^;Rh0=CDe03Hf=P0a<C40
>c/k03Ph>00d=3@0<S8b03/k>`0i>CT0<c<c03Hf=P0a<C40=cLg038b<P0f=SH0;Rh^03@d=00^;Rh0
=3@d034a<@0e=CD0=SHf03Lg=`0c<c<0<S8b030`<00Z:RX0<C4a030`<080=SHf01X0=3@d03/k>`0g
=cL0=cLg03<c<`0_;bl0;Rh^03@d=00];Bd0:b/[02h^;P0j>SX0?3`l04U9B@1EEED0JFUY07alO026
QXH0SHf=09VIV@2MWId0UiNG08n?S`2DU9@0S8b<08Z:RP80QHF500D0Ph>308b<S02FUYH0VIVI0:2P
X0020:6QX@80XZ:R102SXj<01@2TY:@0Xj>S0:JVYP2SXj<0YJFU00h0b>3H000<0<SPf0<0E5AD00@0
De=C05MGE`1KFe/0FUYJ0P1NGUh01@1MGEd0GemO061PH01LG5`0HF5Q0080GemO0P1NGUh02`1JFUX0
GEeM05IFEP1LG5`0FUYJ065QH@1VIVH0JFUY071`L01dM7@0PX:20080R8R800<0SXj>09:BTP2GUiL0
0P2LW9`0102PX:00Y:BT0:BTY02TY:@40:>SX`050:BTY02XZ:P0XZ:R0:b/[02TY:@00P2PX:020:BT
Y080WinO00X0Vi^K09FEU@2CTi<0SHf=08Z:RP25QHD0MgMg079bLP1[Jf/0GemO0P1GEeL04@1ADE40
Bd];04m?C`1:BTX0D51@05=CD`1GEeL0E5AD05UIF@1MGEd0HV9R05iNGP1QHF40H61P05mOG`1LG5`0
GUiN0080IVIV00h0H61P065QH@1TI6@0IFEU06IVIP1XJ6P0H61P069RHP1SHf<0GemO06=SH`1TI6@0
H61P05eMG@80IFEU00T0I6AT06IVIP1XJ6P0IfMW06a/K01ZJVX0JFUY06a/K01]KFd00P1`L7003P1_
Kfl0MGEe06m_K`1^KVh0LW9b071`L01gMgL0N7Qh07MgM`1cLg<0LG5a07MgM`1kNg/0KFe]0P1eMGD2
075aL@0T079bLP1mOGd0/[:b0<C4a02=SHd0OGem06e]K@1UIFD0I6AT06YZJP1VIVH0J6QX06a/K01X
J6P0I6AT06YZJP1YJFT0K6a/06m_K`1aLG40L71`075aL@1bLW80LG5a07AdM01]KFd0Kfm_071`L01[
Jf/0L71`079bLP1ZJVX0Lg=c075aL@1^KVh0Jf][0P1dM7@00`1bLW80Jf][07YjNP0207emO@0K07If
MP1hN7P0Q8B407IfMP1jNWX0O7al07emO@25QHD0R8R808V9R@23Ph<0Ng]k08F5Q@2?Shl0SHf=08j>
SP2@T900QXJ608b<S02CTi<0Q8B408:2PP21PH40Q8B408b<S02BTY80Shn?0080SXj>00/0Ti>C08j>
SP2?Shl0S8b<08^;R`2@T900R8R808F5Q@24Q8@0OWin08b<S0030861P@0A07=cL`1lO7`0RHV908F5
Q@1oOgl0NGUi07]kN`21PH40Ng]k07MgM`2;Rh/0Zj^[0;Jf]P2m_Kd0^k^k0;6a/@2^[Zh00P2`/;00
6@33`l<0aLG50<;2`P34a<@0c/k>0<S8b031`L40`<300<71`@33`l<0`<300;Vi^@2n_[h0a/K60<O7
a`2m_Kd0]KFe0;Ng]`2j^[X0`/;20<S8b037alL0`<300;>c/`2m_Kd00P2k^k/0102l_;`0_[jn0<C4
a03<c<`20<[:bP0F0<g=c@3@d=00cLg=0<c<c03=cLd0b/[:0<;2`P38b<P0clo?0=?Cd`3@d=00c/k>
0<W9b@36a/H0c<c<0=3@d03:b/X0bLW90=3@d03;bl/0b<S80<c<c080clo?00P0d=3@0=GEe@3>c/h0
clo?0<g=c@3Fe]H0e=CD0=?Cd`80dM7A00X0d];B0=7Ad@3@d=00clo?0<g=c@3;bl/0clo?0=WIf@3J
f]X0emOG0P3Hf=P00`3GemL0f][J0=SHf0020=gMg@0H0=?Cd`3Lg=`0g]kN0=[JfP35aLD0RHV904E5
A@0l?3`0@T920410@014A4@0B4Q804m?C`1BDU80F5QH065QH@1[Jf/0L71`07YjNP23Ph<0Q8B408N7
Q`2>SXh0TI6A0P2CTi<309ZJVP0W09^KV`2IVIT0VYZJ09ZJVP2KVi/0WYjN09VIV@2JVYX0UiNG09ZJ
VP2KVi/0V9RH09ZJVP2CTi<0UiNG092@T02?Shl0QhN708:2PP1nOWh0Lg=c06YZJP1NGUh0EEEE04=3
@`0h>3P0<30`02XZ:P0];Bd0:BTY030`<00c<c<09RHV02`/;00V9RH0:RXZ02PX:00/;2`0<C4a0080
@41000P0BDU905EEE@1NGUh0GemO07=cL`1gMgL0OWin08>3P`80R8R80P2>SXh04`2ATI40UIFE09>C
T`2CTi<0SXj>08f=S@2?Shl0S8b<08R8R02:RXX0SHf=08b<S02;Rh/0SXj>096AT@2BTY80UiNG09BD
U02KVi/00P2HV9P01`2IVIT0QHF507IfMP1GEeL0=cLg02LW9`0^;Rh00P0/;2`202TY:@80;2`/00H0
:2PX02TY:@0g=cL0:BTY02h^;P0d=3@203Hf=P0903Ti>@0b<S80=CDe03@d=00g=cL0?clo0410@00d
=3@0?clo0080=cLg01<0<c<c02h^;P0/;2`0;2`/02h^;P0[:b/0=3@d03lo?`0j>SX0>3Ph03<c<`0h
>3P0:b/[02h^;P0`<300<c<c02d];@0m?Cd0=3@d0080=CDe0P0`<3003@0a<C40=SHf030`<00];Bd0
=3@d03Lg=`0j>SX0>c/k04E5A@1LG5`0Kfm_07YjNP29RHT00P2EUID01`2FUYH0V9RH092@T02<S8`0
RXZ:08N7Q`26QXH00P28R8P0102@T900UIFE09VIV@2RXZ820:6QX@0:0:BTY02VYZH0XZ:R0:BTY02U
YJD0YZJV0:>SX`2VYZH0XZ:R0:>SX`h0b>3H000<0<SPf080EEEE0180EUIF05EEE@1@D500GUiN05]K
F`1NGUh0GemO05aLG01PH600GUiN05UIF@1LG5`0GEeM05UIF@1NGUh0Fe]K05IFEP1JFUX205MGE`80
GUiN00P0GemO06=SH`1eMGD0OGem0861P@24Q8@0R8R8092@T080Ti>C00H0Vi^K09nOW`2LW9`0Y:BT
0::RXP2VYZH40:NWY`040:6QX@2VYZH0Xj>S0:JVYP80XZ:R01H0XJ6Q0:>SX`2OWil0WYjN09fMW@2H
V9P0UiNG096AT@2=SHd0QHF50820P01iNGT0KVi^06QXJ01LG5`0GUiN05YJFP1=CDd0C4a<04m?C`18
B4P0Bd];0P1BDU8205eMG@0@05iNGP1QHF40Fe]K065QH@1OGel0Hf=S065QH@1UIFD0GEeM06=SH`1O
Gel0J6QX06ATI01[Jf/0JFUY06QXJ080I6AT00@0H61P06=SH`1RHV80IFEU0P1RHV80101TI6@0K6a/
06ATI01RHV8206MWI`0806QXJ01bLW80Jf][06a/K01_Kfl0KFe]06a/K01cLg<206m_K`0507=cL`1e
MGD0M7Ad07MgM`1dM7@00P1iNGT0101fMWH0NWYj07MgM`1eMGD206m_K`<0Lg=c01<0LW9b08n?S`2l
_;`0VYZJ07alO01bLW80IVIV06EUI@1NGUh0KVi^06YZJP1VIVH0HV9R06][J`1/K6`0Hf=S06][J`1`
L700Kfm_0080Lg=c03T0MGEe07=cL`1fMWH0K6a/06YZJP1dM7@0Kfm_06][J`1cLg<0L71`079bLP1d
M7@0N7Qh07AdM01/K6`0KFe]07MgM`1cLg<0N7Qh07MgM`1mOGd0MgMg07IfMP1hN7P0OWin08Z:RP24
Q8@0OWin07alO025QHD0T92@08n?S`2:RXX0QHF508N7Q`2>SXh0UYJF092@T02>SXh0QXJ608b<S02B
TY80SXj>08V9R@25QHD0QXJ608j>SP2EUID0Shn?092@T029RHT0QXJ609BDU02BTY80SXj>0861P@22
PX800P29RHT00`25QHD0Q8B408N7Q`0208Z:RP0I08N7Q`1iNGT0Ph>308^;R`28R8P0S8b<08:2PP21
PH40PX:208B4Q021PH40Ph>3092@T02^[Zh0/;2`0;>c/`2b/[80];Bd0;Ng]`34a<@0`<300<?3``39
bLT0b/[:0<O7a`020<K6aP080<S8b031`L40]kNg0;Vi^@35aLD0alO70<;2`P2l_;`20;Zj^P090;fm
_@35aLD0`l?30<?3``2o_kl0_[jn0<O7a`34a<@0`<300080^k^k00l0`/;20<O7a`37alL0c/k>0=7A
d@3>c/h0cLg=0<k>cP3=cLd0`l?30<S8b03AdM40d];B0=3@d03=cLd00P36a/H0103?cll0dm?C0<g=
c@3=cLd20=;BdP050<k>cP3=cLd0bl_;0=3@d03;bl/00P3@d=020<_;b`040<[:bP3Cdm<0d=3@0=?C
d`80d=3@02D0e]KF0=7Ad@3Bd]80dM7A0<o?c`3AdM40dm?C0=[JfP3GemL0e]KF0=OGe`3Fe]H0f=SH
0=?Cd`3Bd]80fMWI0=[JfP3GemL0g=cL0>;RhP3Fe]H0YjNW05]KF`0k>c/0>CTi03`l?012@T80ATI6
04a<C01@D500EUIF05mOG`1PH600KFe]079bLP1iNGT0Ogmo0080QHF500@0RXZ:096AT@2CTi<0VIVI
0P2FUYH0202GUiL0WIfM09VIV@2GUiL0VIVI09NGU`2KVi/0W9bL0P2IVIT04@2JVYX0VIVI09ZJVP2L
W9`0Vi^K09BDU02BTY80S8b<08V9R@24Q8@0OGem07IfMP1/K6`0GemO05]KF`13@d<0>c/k0080;Bd]
00<0;Rh^02TY:@0/;2`00P0[:b/01P0U9BD0:b/[02LW9`0];Bd0<C4a03Lg=`80@D5100@0Bd];05]K
F`1UIFD0LW9b0P1kNg/01P20P800QHF508n?S`2>SXh0Shn?096AT@80Ti>C00L0T92@08n?S`2@T900
Shn?08b<S02@T900QXJ600<0Rh^;01l0SXj>096AT@2DU9@0TI6A09>CT`2DU9@0UIFE09NGU`2KVi/0
W9bL09:BTP26QXH0Lg=c05ADE00_;bl0:RXZ02`/;00[:b/0;Bd]02PX:00[:b/0<S8b02/[:`0^;Rh0
=3@d02h^;P0a<C40=CDe034a<@0k>c/0=CDe0080=3@d00<0<c<c03Lg=`0i>CT00P0d=3@05P0k>c/0
=cLg03Hf=P0a<C40=3@d038b<P0^;Rh0;2`/02d];@0d=3@0?Cdm03`l?00m?Cd0;bl_034a<@0/;2`0
;Bd]02/[:`0Y:BT0<C4a03@d=00b<S8203<c<`0T030`<00b<S80ADE503Hf=P0b<S80;Rh^038b<P0d
=3@0;Rh^03/k>`0m?Cd0C4a<06MWI`1gMgL0PH6108f=S@2BTY80UiNG09JFUP2BTY80TI6A08f=S@2A
TI40SXj>08Z:RP28R8P0RHV9096AT@2EUID0VIVI09jNWP2QXJ40ZJVY0:NWY`2YZJT0X:2P0P2VYZH0
102TY:@0Xj>S0:6QX@2TY:@>0<SPf0003038h=P205EEE@0Q05aLG01HF5P0GemO05iNGP1KFe/0GEeM
05iNGP1MGEd0FUYJ05iNGP1PH600FUYJ065QH@1NGUh0FEUI05YJFP1OGel0GEeM05UIF@1FEUH0EeMG
069RHP1QHF40I6AT06e]K@1gMgL0Ogmo08N7Q`2<S8`0U9BD096AT@2FUYH0WYjN0080WinO00@0XJ6Q
09nOW`2SXj<0YZJV0`2WYjL01@2YZJT0YJFU0:RXZ02VYZH0Xj>S0080YJFU01H0Y:BT0:6QX@2OWil0
WIfM09bLW02EUID0TY:B08b<S026QXH0Ph>307YjNP1bLW80K6a/05iNGP1TI6@0E5AD04e=C@1:BTX0
CDe=04i>CP1ADE40DU9B0`1IFET205mOG`04065QH@1LG5`0H61P05mOG`80H61P00l0G5aL05iNGP1Q
HF40JVYZ06EUI@1WIfL0IFEU065QH@1UIFD0IfMW061PH01VIVH0IFEU069RHP1TI6@00P1WIfL01@1R
HV80H61P06][J`1UIFD0IfMW0080J6QX00H0JFUY06][J`1aLG40KFe]06QXJ01/K6`2075aL@80MGEe
00X0LW9b07MgM`1dM7@0MGEe07IfMP1iNGT0NWYj07QhN01dM7@0MWIf0`1eMGD0301bLW80M7Ad07al
O02CTi<0VYZJ07YjNP1cLg<0LW9b071`L01ZJVX0GemO06MWI`80I6AT00/0IVIV06YZJP1WIfL0K6a/
07EeM@1lO7`0M7Ad07IfMP1gMgL0Kfm_079bLP0206m_K`0B075aL@1hN7P0LW9b07EeM@1iNGT0MWIf
07UiN@1_Kfl0MGEe06m_K`1cLg<0LW9b07]kN`1hN7P0LW9b06i^KP1jNWX0N7Qh0`1oOgl06`26QXH0
Rh^;07alO01gMgL0OWin08R8R02>SXh0Rh^;08F5Q@28R8P0Ti>C09JFUP2DU9@0SHf=08j>SP28R8P0
QhN708^;R`29RHT0SXj>08N7Q`2=SHd0Ti>C096AT@2>SXh0Ph>308J6QP0208j>SP0708b<S023Ph<0
QXJ608b<S02:RXX0S8b<08B4Q00208Z:RP0L08j>SP26QXH0QHF508^;R`2:RXX0S8b<096AT@27QhL0
OGem07inOP2:RXX0P82007moO`29RHT0W9bL0:VYZ@2d];@0][Jf0<C4a032`/80`<300<C4a038b<P0
a<C40<W9b@36a/H0bLW90<G5a@80_;bl0P34a<@03P30`<00_[jn0;bl_02m_Kd0`/;20<?3``32`/80
_[jn0;fm_@2k^k/0`l?30<S8b035aLD0alO70P33`l<01031`L40_;bl0<?3``3:b/X20<c<c0040<k>
cP3@d=00b<S80<O7a`80d=3@00/0dM7A0<_;b`36a/H0`l?30<g=c@3GemL0c/k>0<g=c@3>c/h0dm?C
0<g=c@020<k>cP0:0<o?c`3Bd]80c<c<0=?Cd`3@d=00cLg=0<W9b@38b<P0cLg=0<k>cP<0d=3@00d0
dm?C0<o?c`3>c/h0c<c<0<k>cP3Fe]H0e=CD0=KFeP3EeMD0e=CD0=3@d03Bd]80e]KF0080dm?C01X0
emOG0>3Ph03Ogml0g]kN0=KFeP2e]KD0LW9b03hn?P0e=CD0=SHf03lo?`16ATH0AdM704a<C01DE5@0
FUYJ05UIF@1UIFD0KFe]07=cL`1lO7`0Ogmo08B4Q025QHD0Rh^;096AT@<0UiNG00D0VYZJ09RHV02J
VYX0VIVI09^KV`0309VIV@0G09^KV`2HV9P0V9RH09VIV@2HV9P0W9bL09ZJVP2HV9P0Ti>C09:BTP2<
S8`0RHV90820P01fMWH0LG5a06EUI@1JFUX0Cdm?04I6AP0c<c<0;bl_02`/;00X:2P00P0[:b/0200U
9BD09RHV02HV9P0];Bd0:BTY02l_;`0e=CD0>SXj0P1<C4`05@1HF5P0GUiN06UYJ@1kNg/0NGUi0861
P@23Ph<0QHF508b<S02>SXh0TY:B09>CT`2BTY80TI6A09FEU@2@T900Rh^;08b<S028R8P0SXj>08V9
R@0208b<S080Rh^;00<0TI6A09BDU02?Shl00`2DU9@0202GUiL0Vi^K09NGU`2MWId0Ti>C08:2PP1S
Hf<0@4100P0^;Rh0200/;2`0:2PX02TY:@0];Bd0;Rh^030`<00Z:RX0:BTY0P0];Bd03P0e=CD0;Rh^
038b<P0b<S80>CTi03@d=00k>c/0=cLg03De=@0_;bl0<c<c03@d=00f=SH0B4Q80P0d=3@2030`<00:
02`/;00c<c<0<S8b03De=@0d=3@0?3`l038b<P0c<c<0;Bd]02`/;080:RXZ00<0;bl_030`<00a<C40
0P0d=3@01P0b<S80?clo0410@00g=cL0=3@d02l_;`@0<c<c00T0>c/k04I6AP1EEED0IfMW07YjNP24
Q8@0SHf=096AT@2FUYH00P2CTi<05@2?Shl0SHf=08n?S`2<S8`0R8R808J6QP2:RXX0S8b<09BDU02K
Vi/0WinO0:6QX@2UYJD0YZJV0:BTY02SXj<0Y:BT0:>SX`2WYjL0XJ6Q0:>SX`0>0<SPf0003038h=P2
05YJFP0W05MGE`1IFET0EeMG05mOG`1MGEd0GemO05]KF`1NGUh0GEeM05UIF@1MGEd0Fe]K069RHP1K
Fe/0EUIF05QHF01MGEd0F5QH05EEE@1JFUX0Fe]K05aLG01RHV80IfMW06a/K01cLg<0P82008J6QP29
RHT0TI6A09BDU02EUID0VIVI09jNWP2MWId0Y:BT0:JVYP2TY:@0ZZZZ00D0YZJV0440ZZZZ0:FUY@2T
Y:@0Z:RX0:>SX`2TY:@0XZ:R09nOW`2NWYh0Vi^K09BDU02>SXh0RXZ:08B4Q01nOWh0O7al06i^KP1/
K6`0HV9R06=SH`1GEeL0CTi>04U9B@16ATH0C4a<059BDP1ADE40EUIF059BDP1KFe/0GEeM05]KF`1P
H600Fe]K05iNGP1SHf<0I6AT05iNGP1TI6@0IFEU06=SH`1YJFT0IVIV06EUI@1VIVH0I6AT06IVIP1X
J6P0HV9R06IVIP1SHf<0I6AT06MWI`1SHf<0J6QX061PH01TI6@0IfMW06ATI01XJ6P0Jf][06YZJP1[
Jf/0KVi^079bLP0206i^KP04071`L01cLg<0MGEe079bLP<0MGEe00L0Lg=c07MgM`1hN7P0M7Ad07Yj
NP1iNGT0M7Ad0080Lg=c0P1dM7@04P1gMgL0N7Qh07UiN@1oOgl0TY:B08V9R@1hN7P0MgMg06a/K01[
Jf/0LW9b06m_K`1ZJVX0J6QX06ATI01YJFT0KFe]06i^KP<0MWIf00`0LW9b06i^KP1aLG40N7Qh071`
L01^KVh0L71`07=cL`1eMGD0MgMg079bLP1YJFT2075aL@0806m_K`1fMWH0MWIf079bLP1]KFd0NGUi
07alO01aLG4207IfMP0407moO`22PX80PX:20861P@<0QHF50200Ogmo07UiN@1jNWX0SXj>08b<S029
RHT0SXj>08V9R@2CTi<0U9BD092@T02<S8`0RXZ:08R8R02;Rh/0Ti>C09JFUP28R8P0PX:208V9R@2C
Ti<0Rh^;07inOP24Q8@0SHf=08j>SP2=SHd0PX:20861P@2:RXX0SXj>08Z:RP<0O7al00H0R8R808f=
S@2?Shl0RHV908n?S`2ATI4208n?S`0@07EeM@20P800Shn?08N7Q`1kNg/0Q8B409:BTP2OWil0^k^k
0<?3``2o_kl0`L710<C4a035aLD0alO70<?3``80alO700D0`L710;Vi^@3=cLd0b/[:0<C4a0020;bl
_0040;Zj^P32`/80`l?30<;2`P@0_kno0P34a<@02P36a/H0aLG50<_;b`38b<P0bLW90<K6aP38b<P0
`L710;jn_P35aLD30<W9b@070<o?c`3Cdm<0dM7A0<_;b`31`L40a<C40<c<c0020=?Cd`030<g=c@3?
cll0dM7A00<0cLg=00`0c/k>0=;BdP3>c/h0dM7A0=?Cd`3>c/h0d=3@0<_;b`3>c/h0clo?0=7Ad@3@
d=020<o?c`080=?Cd`3Bd]80d=3@0<_;b`39bLT0dm?C0=CDe03EeMD20=CDe00]0=7Ad@3@d=00e=CD
0=KFeP3Cdm<0g=cL0>CTi03Shn<0fMWI0<?3``1mOGd0C4a<03dm?@12@T80?3`l04A4A017AdL0Bd];
04e=C@1FEUH0FEUI05iNGP1VIVH0Jf][07IfMP1kNg/0Ph>30861P@28R8P0Rh^;092@T02DU9@0UiNG
09RHV02QXJ40VYZJ09JFUP2JVYX0UiNG09ZJVP2NWYh0VYZJ09VIV@2JVYX0V9RH0080VIVI01`0WYjN
09^KV`2IVIT0TI6A092@T02>SXh0RXZ:0861P@1iNGT0L71`06IVIP1MGEd0Cdm?0492@P0d=3@0;2`/
03De=@0b<S80:RXZ02/[:`0V9RH09bLW02h^;P0`<300:b/[03De=@0o?cl0CDe=0P1JFUX0401LG5`0
GemO06m_K`20P800PX:208B4Q029RHT0S8b<08n?S`2BTY80UIFE09JFUP2@T900TY:B09>CT`2@T902
08j>SP0308b<S02;Rh/0SXj>0080S8b<00<0SHf=08b<S02DU9@00`2BTY80102ATI40U9BD09NGU`2I
VIT209fMW@0:09FEU@2=SHd0MGEe05IFEP0d=3@0:b/[02TY:@0Z:RX092@T02h^;P<0:RXZ01D0:b/[
03<c<`0/;2`0<S8b02`/;00a<C40=CDe03/k>`0g=cL0>3Ph038b<P0a<C40=cLg03<c<`0f=SH0=CDe
03Xj>P0g=cL0<c<c030`<00/;2`00P0[:b/03@0g=cL0<30`03De=@0i>CT0=SHf03<c<`0e=CD0<C4a
02PX:00^;Rh0;Bd]038b<P0i>CT00P0g=cL01P0d=3@0=CDe038b<P0c<c<0>3Ph034a<@80=SHf00h0
<C4a03Ti>@0e=CD0?clo051@D01DE5@0JFUY07emO@23Ph<0Rh^;096AT@2CTi<0SXj>092@T080Shn?
00<0TI6A09:BTP2@T9000P2;Rh/00`2ATI40VYZJ0::RXP020:BTY0080:JVYP2TY:@0Xj>S0:>SX`2V
YZH0YJFU09nOW`2QXJ4>0<SPf0003038h=P205UIF@0C05]KF`1ADE40De=C05aLG01IFET0G5aL061P
H01LG5`0FEUI069RHP1JFUX0GUiN05eMG@1JFUX0GUiN05mOG`1LG5`0EeMG05IFEP0205QHF00;05YJ
FP1LG5`0IVIV06m_K`1bLW80OGem08B4Q02<S8`0TI6A09:BTP2GUiL00P2NWYh00`2RXZ80YZJV0:FU
Y@050:JVYP0X0:VYZ@2XZ:P0[:b/0:NWY`2YZJT0Z:RX0:>SX`2RXZ80X:2P09nOW`2LW9`0VIVI09JF
UP2BTY80RHV908B4Q01mOGd0OWin079bLP1_Kfl0Hf=S05mOG`1GEeL0CTi>04Y:BP18B4P0CDe=04m?
C`1CDe<0EUIF05MGE`1LG5`0GEeM05mOG`1PH600GemO065QH@1VIVH0Hf=S05mOG`80Hf=S00D0GemO
05iNGP1SHf<0GemO069RHP0206IVIP0:065QH@1RHV80I6AT06ATI01UIFD0IfMW06QXJ01WIfL0HF5Q
06=SH`80J6QX00<0IFEU06MWI`1`L7000P1]KFd01@1/K6`0LG5a071`L01_Kfl0LG5a0080MWIf00`0
MgMg07EeM@1fMWH0NGUi07EeM@1gMgL0M7Ad07QhN01eMGD0NGUi07IfMP1kNg/207YjNP0k07MgM`1i
NGT0N7Qh07YjNP20P800SHf=08:2PP1kNg/0MGEe06a/K01_Kfl0M7Ad071`L01VIVH0JVYZ06m_K`1`
L700KVi^079bLP1dM7@0LW9b06m_K`1dM7@0KFe]071`L01aLG40K6a/07EeM@1aLG40JFUY071`L01c
Lg<0LG5a06e]K@1aLG40Lg=c07EeM@1dM7@0MgMg07AdM01aLG40MWIf07UiN@1nOWh0MgMg075aL@1l
O7`0Q8B408N7Q`2;Rh/0Ph>308R8R026QXH0QhN707QhN01iNGT0QhN708V9R@2<S8`00P25QHD05`2?
Shl0UIFE09BDU02@T900QHF50820P02ATI40Ti>C08n?S`29RHT0PX:208Z:RP2IVIT0Rh^;08F5Q@29
RHT0Rh^;08Z:RP27QhL0Ph>308F5Q@21PH40RXZ:0080QHF500D0OWin0820P02;Rh/0RHV909:BTP02
08B4Q00>09:BTP2CTi<0S8b<08:2PP23Ph<0U9BD09FEU@25QHD0PX:208N7Q`2WYjL0];Bd0<30`038
b<P20<K6aP0=0<O7a`34a<@0a<C40<?3``2g]kL0`/;20<_;b`35aLD0`L710;fm_@33`l<0alO70<K6
aP030<;2`P80alO700<0aLG50<O7a`33`l<00P35aLD07P36a/H0alO70<S8b03>c/h0bl_;0<C4a02k
^k/0alO70<G5a@32`/80a/K60<g=c@3>c/h0b/[:0<?3``35aLD0c/k>0=3@d03Bd]80dM7A0<g=c@3?
cll0cLg=0<c<c03=cLd0d=3@0<o?c`3=cLd0d];B0=7Ad@<0d=3@00<0c/k>0=;BdP3AdM400P3AdM42
0=3@d0060=GEe@3Cdm<0e]KF0<k>cP3?cll0e=CD0P3Fe]H01@3De=@0f=SH0=CDe03De=@0fMWI0080
fm_K0240h>3P0>KViP3Lg=`0aLG509NGU`1QHF40@D510410@014A4@0@d=304M7A`19BDT0Cdm?04i>
CP1GEeL0FEUI05mOG`1SHf<0Jf][07=cL`20P800Q8B408V9R@2:RXX0SHf=096AT@2FUYH0VIVI09^K
V`2LW9`0VYZJ09^KV`2IVIT00P2JVYX08`2KVi/0V9RH09FEU@2MWId0UiNG09ZJVP2HV9P0XZ:R09RH
V02JVYX0U9BD08n?S`2<S8`0R8R807inOP1hN7P0KFe]06IVIP1LG5`0D51@0451@@0d=3@0;Bd]02/[
:`0a<C40:RXZ02PX:00T92@0:2PX02XZ:P0^;Rh0<30`03Ph>016ATH0EeMG0080FUYJ00P0JVYZ06QX
J01fMWH0P8200861P@24Q8@0RXZ:08n?S`80UIFE00d0UiNG09:BTP2FUYH0Ti>C09:BTP2@T900TI6A
08f=S@2;Rh/0SHf=08^;R`2<S8`0SXj>0080TI6A00@0SXj>092@T02DU9@0V9RH0P2EUID03`2FUYH0
V9RH09^KV`2KVi/0UiNG09>CT`29RHT0LG5a04Q8B00];Bd0<c<c02PX:00S8b<0:BTY02DU9@0202/[
:`0902LW9`0[:b/0:BTY03Lg=`0_;bl0=CDe02l_;`0e=CD0@T920080=cLg01T0>CTi03<c<`0e=CD0
<30`03Lg=`0h>3P0>SXj03Hf=P0`<300;bl_03<c<`0^;Rh0<S8b02h^;P0g=cL0?3`l03Xj>P10@400
AdM703/k>`0f=SH0;Rh^02`/;00^;Rh0>CTi0080?Cdm00X0<C4a03@d=00e=CD0<c<c03@d=00c<c<0
=cLg03@d=00b<S80=SHf0P0h>3P03@0n?Sh0CDe=05]KF`1aLG40NWYj08F5Q@2CTi<0SHf=09:BTP2?
Shl0SXj>08f=S@2ATI400P2CTi<02`2@T900S8b<092@T02BTY80VYZJ09jNWP2RXZ80Xj>S0:JVYP2T
Y:@0Z:RX0080Y:BT00<0Xj>S0::RXP38h=P03@38h=P000`0b>3H0P1JFUX305EEE@0405YJFP1IFET0
FEUI05eMG@<0Fe]K0P1JFUX00`1KFe/0G5aL05mOG`0205UIF@0B05IFEP1DE5@0F5QH05MGE`1JFUX0
H61P06ATI01aLG40M7Ad07moO`23Ph<0SHf=09>CT`2@T900UiNG09ZJVP2OWil0X:2P0P2TY:@00`2V
YZH0X:2P0:FUY@030:BTY0030:RXZ02UYJD0Xj>S0080YZJV01L0X:2P0:BTY02TY:@0X:2P09jNWP2J
VYX0UIFE092@T02=SHd0QXJ607alO01iNGT0LW9b06a/K01RHV80GEeM05=CD`1@D500Bd];04e=C@19
BDT0CDe=05IFEP0205YJFP0=05EEE@1KFe/0HV9R05aLG01PH600GUiN05YJFP1UIFD0IfMW06EUI@1Q
HF40HV9R06ATI002061PH0<0I6AT0180HF5Q06=SH`1UIFD0J6QX05mOG`1VIVH0J6QX06a/K01`L700
IFEU06IVIP1TI6@0IfMW06YZJP1YJFT0K6a/06e]K@1_Kfl206i^KP0=06m_K`1aLG40LG5a07=cL`1h
N7P0LW9b07IfMP1dM7@0LW9b07IfMP1dM7@0MWIf07AdM00207EeM@0B07UiN@1nOWh0OWin07AdM01e
MGD0MWIf07alO01hN7P0RHV908^;R`22PX80M7Ad071`L01ZJVX0JFUY06YZJP1^KVh0JFUY0P1^KVh0
2`1dM7@0NGUi07UiN@1`L700KVi^07MgM`1cLg<0L71`06i^KP1]KFd0Kfm_0080KFe]03H0Kfm_07=c
L`1dM7@0NWYj075aL@1bLW80L71`07IfMP1dM7@0L71`07YjNP1kNg/0Kfm_07EeM@1lO7`0Lg=c075a
L@1jNWX0RXZ:08:2PP28R8P0OWin07moO`2>SXh0PH6107alO01hN7P0P82008>3P`2<S8`0Q8B40861
P@24Q8@0Rh^;08n?S`2>SXh0Shn?08>3P`24Q8@0T92@08R8R02;Rh/0R8R809>CT`2GUiL0Rh^;08f=
S@2:RXX0SXj>08R8R029RHT0SXj>07moO`24Q8@208f=S@0408:2PP27QhL0QHF508V9R@80Shn?0200
QXJ608j>SP2FUYH0UIFE09JFUP2ATI40VIVI09jNWP2EUID0S8b<07emO@20P800Vi^K0:n_[`2n_[h0
alO70<S8b037alL0a<C40;jn_P2l_;`0_[jn0<S8b034a<@0_[jn0<71`@3;bl/0clo?0<W9b@35aLD0
`<300<C4a080b/[:00/0alO70<S8b038b<P0a/K60<G5a@36a/H0`l?30<;2`P3:b/X0c/k>0<_;b`02
0<K6aP040=;BdP37alL0^KVi0<71`@80aLG500<0`/;20<71`@3;bl/00`3?cll00`3<c<`0c/k>0<g=
c@020<c<c0060<g=c@3@d=00c/k>0<o?c`3@d=00cLg=0P3?cll00`3<c<`0d];B0=?Cd`020=3@d003
0<o?c`3Cdm<0dm?C00@0dm?C00D0e=CD0=KFeP3GemL0f=SH0=OGe`020=[JfP0R0=_Kf`3Ogml0h>3P
0>7Qh@3Ph>00g=cL0<G5a@2LW9`0N7Qh05EEE@13@d<0ATI604Q8B019BDT0B4Q804m?C`1BDU80CTi>
05EEE@1FEUH0GemO06QXJ01^KVh0M7Ad07YjNP1lO7`0R8R808Z:RP2@T900U9BD09FEU@2HV9P0VIVI
09^KV`80W9bL0P2JVYX0602NWYh0VIVI09VIV@2GUiL0VIVI09NGU`2MWId0UiNG09jNWP2GUiL0Vi^K
09ZJVP2ATI40Rh^;08Z:RP23Ph<0N7Qh079bLP1ZJVX0FEUI04m?C`11@D40=CDe03dm?@80<S8b00X0
:b/[02TY:@0R8R80:BTY02/[:`0e=CD0=3@d03dm?@1?Cdl0EeMG0P1RHV802P1XJ6P0M7Ad07emO@20
P800QHF508N7Q`2:RXX0Shn?09BDU02BTY8209FEU@07092@T02ATI40Ti>C08n?S`2=SHd0Shn?08Z:
RP0208^;R`05092@T02ATI40S8b<08j>SP2<S8`00P2ATI406P2DU9@0UYJF09BDU02EUID0UYJF09VI
V@2FUYH0Vi^K09RHV02BTY80OWin065QH@0o?cl0;Rh^02DU9@0S8b<09RHV02LW9`0Y:BT0:b/[02DU
9@0X:2P0;Bd]02`/;00^;Rh0;Bd]0P0_;bl01P0e=CD0?3`l03/k>`0i>CT0>3Ph03Lg=`80>3Ph00D0
=CDe03Lg=`0g=cL0<c<c03De=@0202d];@0602`/;00^;Rh0;Rh^038b<P0g=cL0>3Ph0P0f=SH01@0c
<c<0;Bd]02h^;P0b<S80<c<c0080<C4a00<0;Rh^02l_;`0h>3P00P0d=3@0600e=CD0?clo03/k>`0`
<300>c/k03<c<`0j>SX0>CTi03hn?P1@D500GEeM06][J`1kNg/0QXJ608b<S02BTY80TI6A08j>SP2@
T900SXj>09>CT`2EUID0UiNG09>CT`80S8b<00<0UIFE09jNWP2TY:@00`2TY:@01@2SXj<0Y:BT0:BT
Y02TY:@0Xj>S00h0b>3H000<0<SPf080EeMG00<0CTi>05UIF@1ADE400P1NGUh08@1MGEd0EeMG05UI
F@1LG5`0GUiN05QHF01IFET0FUYJ05IFEP1KFe/0HV9R05iNGP1GEeL0EUIF05UIF@1DE5@0FUYJ05eM
G@1RHV80JFUY07IfMP1jNWX0PH6108^;R`2?Shl0TY:B09BDU02QXJ40X:2P09jNWP2QXJ40Xj>S0:JV
YP020:NWY`80ZZZZ01P0Xj>S0:JVYP2UYJD0YZJV0:BTY02ZZZX0Z:RX0:FUY@2QXJ40Y:BT09jNWP2H
V9P0U9BD092@T02=SHd0QHF508:2PP1hN7P0Lg=c06][J`1OGel0F5QH055AD@1;Bd/204a<C00904m?
C`1>CTh0DE5A05MGE`1FEUH0G5aL061PH01MGEd0GemO0080Hf=S00<0H61P06IVIP1[Jf/00P1TI6@0
1@1YJFT0Hf=S06IVIP1RHV80IFEU0080IVIV00<0HV9R06=SH`1WIfL00P1SHf<206IVIP0406YZJP1V
IVH0IVIV06MWI`80IVIV01@0K6a/06UYJ@1`L700KFe]06i^KP1_Kfl0K6a/06i^KP1_Kfl0LW9b07Ad
M01gMgL0LW9b07=cL`1bLW80LG5a07IfMP1kNg/0N7Qh07UiN@80MGEe0180N7Qh08:2PP22PX80Lg=c
07EeM@1kNg/0N7Qh07YjNP22PX80S8b<092@T01iNGT0Kfm_06YZJP1/K6`0LW9b06a/K01]KFd206i^
KP0507EeM@1dM7@0MGEe06][J`1^KVh00P1[Jf/00`1ZJVX0KVi^06e]K@02079bLP0C071`L01lO7`0
M7Ad07AdM01cLg<0O7al06i^KP1]KFd0OGem07UiN@1gMgL0NWYj07alO01kNg/0MGEe075aL@20P800
NWYj075aL@0207YjNP0E08>3P`25QHD0OWin07]kN`1nOWh0Ph>308B4Q021PH40L71`08V9R@2?Shl0
Q8B408R8R025QHD0SXj>08^;R`2:RXX0RHV908:2PP24Q8@0S8b<0080TY:B00D0Shn?08F5Q@2@T900
SHf=08j>SP0308V9R@03092@T029RHT0OWin0080PX:202l0QHF508f=S@2:RXX0QXJ60861P@2=SHd0
SXj>08V9R@26QXH0TI6A09ZJVP2IVIT0Xj>S0:ZZZP2KVi/0XZ:R09BDU020P800PX:209:BTP2[Zj/0
`L710<C4a035aLD0`L710;fm_@2o_kl0aLG50<71`@30`<00_kno0<C4a03<c<`0clo?0<W9b@35aLD0
a<C40<c<c03@d=00cLg=0<o?c`3=cLd0bl_;0<[:bP36a/H0_;bl0<K6aP020<S8b0080<W9b@34a<@0
_kno0<g=c@3Cdm<0a/K60;Zj^P38b<P30<G5a@0>0<S8b037alL0alO70<[:bP3<c<`0b/[:0<_;b`39
bLT0b/[:0<g=c@3AdM40c/k>0<_;b`3AdM420<c<c0070=3@d03=cLd0clo?0=GEe@3Cdm<0d];B0=3@
d0040=?Cd`0g0=3@d03Bd]80e=CD0=CDe03Fe]H0emOG0=SHf03Jf]X0fm_K0=WIf@3MgMd0i>CT0>7Q
h@3Shn<0g=cL0<71`@2BTY80KVi^06a/K01CDe<0?Shn04E5A@18B4P0CDe=055AD@1BDU80DE5A05IF
EP1HF5P0GUiN065QH@1XJ6P0Jf][079bLP1lO7`0OWin08J6QP2;Rh/0SXj>09>CT`2JVYX0UiNG09RH
V02NWYh0VIVI09ZJVP2KVi/0UiNG09jNWP2IVIT0V9RH09ZJVP2HV9P0UYJF09^KV`0209bLW00K09fM
W@2ZZZX0VIVI09:BTP2;Rh/0QhN708B4Q01iNGT0KFe]06IVIP1IFET0E5AD03hn?P0`<300:2PX02XZ
:P0V9RH09bLW02`/;00[:b/0:2PX038b<P0`<300?Shn04I6AP1@D500GEeM0080IFEU00/0LW9b07Mg
M`1mOGd0P82008J6QP28R8P0RXZ:09>CT`2GUiL0Ti>C09FEU@0209:BTP0909>CT`2ATI40SXj>092@
T02>SXh0SHf=08^;R`2>SXh0TI6A0080T92@01/0U9BD08Z:RP2BTY80T92@096AT@2CTi<0UIFE09JF
UP2EUID0V9RH09VIV@2LW9`0Vi^K09JFUP27QhL0MWIf05UIF@0d=3@0:b/[02DU9@0[:b/0:2PX02DU
9@0X:2P09RHV02TY:@0_;bl00`0[:b/02@0a<C40?Cdm03Lg=`0b<S80=3@d03/k>`0g=cL0A4A403Xj
>P0203Ph>080<S8b00X0=3@d03Ti>@0g=cL0:b/[02`/;00W9bL0<30`038b<P0h>3P0@T920P0j>SX0
1@0f=SH0<30`02d];@0[:b/0<C4a0080>SXj01/0;bl_02`/;00j>SX0=cLg03Hf=P0k>c/0<S8b03Hf
=P0g=cL0?3`l03/k>`0o?cl0@D5104=3@`18B4P0D51@05YJFP1]KFd0OWin08Z:RP28R8P0TY:B09>C
T`2@T900SHf=09:BTP2GUiL00P2IVIT01P2>SXh0Rh^;092@T02DU9@0WinO0:6QX@80Xj>S00D0YZJV
0:FUY@2SXj<0XZ:R0:NWY`0>0<SPf0003038h=P205YJFP0X05ADE01CDe<0E5AD05YJFP1DE5@0FEUI
05]KF`1IFET0EeMG05mOG`1MGEd0HF5Q05]KF`1JFUX0FEUI061PH01KFe/0FUYJ05EEE@1FEUH0De=C
05MGE`1LG5`0Jf][06YZJP1hN7P0NWYj08:2PP27QhL0SXj>09VIV@2DU9@0VIVI09jNWP2QXJ40X:2P
0::RXP2WYjL0YZJV0:NWY`80YZJV00P0Xj>S0:NWY`2SXj<0YjNW0:6QX@2SXj<0Y:BT0::RXP<0WinO
01`0VIVI09JFUP2?Shl0RHV908J6QP1mOGd0NGUi075aL@1ZJVX0HF5Q061PH01CDe<0BTY:04Q8B01;
Bd/0BTY:04i>CP1<C4`0EEEE05mOG`1GEeL0G5aL061PH01OGel0IFEU05eMG@1RHV80GemO0P1RHV80
2@1TI6@0H61P06=SH`1XJ6P0HF5Q05mOG`1TI6@0HF5Q05iNGP0306=SH`0;065QH@1TI6@0IFEU065Q
H@1XJ6P0HV9R06a/K01XJ6P0K6a/06QXJ01UIFD00`1/K6`03`1aLG40KFe]06a/K01bLW80LG5a07If
MP1eMGD0Lg=c075aL@1bLW80NWYj071`L01bLW80L71`07UiN@0207AdM00507IfMP1gMgL0MgMg07in
OP1kNg/00P1iNGT207inOP0808R8R02@T900N7Qh07QhN01`L700JVYZ07=cL`1/K6`206e]K@0C079b
LP1gMgL0MGEe07EeM@1aLG40L71`06e]K@1`L700KFe]07=cL`1`L700MGEe07AdM01bLW80MGEe07Mg
M`1jNWX0MGEe07IfMP02079bLP0P07UiN@1hN7P0OGem07YjNP1lO7`0NWYj07alO01fMWH0MGEe07Mg
M`1iNGT0N7Qh079bLP1jNWX0RHV908Z:RP25QHD0N7Qh07emO@24Q8@0RHV907UiN@1lO7`0Ph>308J6
QP2?Shl0S8b<09:BTP2@T900R8R808j>SP2DU9@208B4Q00=08f=S@2CTi<0U9BD08^;R`26QXH0Shn?
08f=S@2>SXh0RXZ:08:2PP2=SHd0T92@08^;R`0208:2PP0@07YjNP27QhL0SHf=08N7Q`26QXH0S8b<
09^KV`2ATI40T92@08N7Q`2;Rh/0VYZJ09^KV`2YZJT0ZZZZ0:2PX080W9bL00D0Rh^;07]kN`24Q8@0
XZ:R0;^k^`020;no_`0=0;bl_038b<P0aLG50;jn_P32`/80b/[:0<_;b`39bLT0b/[:0<C4a031`L40
c<c<0=3@d0030=7Ad@0N0<o?c`3:b/X0a/K60<71`@33`l<0b/[:0<o?c`3;bl/0b<S80;no_`2n_[h0
bLW90<g=c@33`l<0_kno0<k>cP37alL0cLg=0=;BdP3@d=00b<S80<K6aP31`L40a/K60<W9b@33`l<0
aLG50<S8b03?cll0dM7A0P3;bl/01@3>c/h0b<S80<c<c03?cll0dM7A0080dm?C00@0d];B0=3@d03D
e=@0e=CD0P3Cdm<09P3De=@0dM7A0=CDe03De=@0eMGE0=OGe`3Fe]H0f=SH0=cLg03Kfm/0gMgM0>;R
hP3QhN40g]kN0=WIf@32`/80T92@05mOG`1>CTh0DU9B04i>CP14A4@0AdM704a<C01CDe<0CDe=05AD
E01>CTh0DU9B05QHF01SHf<0HF5Q06UYJ@1^KVh0MWIf07alO01oOgl0RHV90P2=SHd02`2DU9@0Ti>C
09BDU02KVi/0VYZJ09RHV02MWId0VIVI09JFUP2LW9`0Vi^K0080W9bL00<0VIVI09NGU`2IVIT00P2I
VIT06`2LW9`0WYjN09NGU`2ATI40Shn?08Z:RP23Ph<0O7al075aL@1TI6@0F5QH05=CD`0k>c/0<c<c
02h^;P0];Bd0;2`/02h^;P0Z:RX08R8R02/[:`0`<300<c<c03lo?`1FEUH0FEUI069RHP0206a/K00B
07IfMP1kNg/0Ogmo08>3P`28R8P0SXj>092@T02EUID0V9RH09NGU`2EUID0Ti>C096AT@2EUID0SHf=
08j>SP2BTY80Shn?0P2<S8`02@2>SXh0S8b<08f=S@2@T900S8b<092@T02ATI40Ti>C092@T00209:B
TP0509BDU02GUiL0UiNG09^KV`2IVIT00P2LW9`05`2CTi<0QhN706a/K01<C4`0>3Ph02`/;00^;Rh0
;Bd]02DU9@0Z:RX09BDU02LW9`0Y:BT09bLW02`/;00a<C40;Bd]03Xj>P0b<S80>CTi03/k>`0n?Sh0
=cLg0080>SXj00X0>CTi03Lg=`0g=cL0=cLg03De=@0`<300;bl_02XZ:P0[:b/09RHV0P0^;Rh02@0a
<C40<S8b03/k>`0n?Sh0?3`l03De=@0`<300:b/[030`<00202`/;008034a<@0`<300<C4a03@d=00j
>SX0<c<c03Lg=`0_;bl203Lg=`0M03Xj>P10@400?3`l04A4A00o?cl0A4A4059BDP1SHf<0LG5a0861
P@2:RXX0TY:B09>CT`2BTY80Ti>C09:BTP2EUID0UYJF09RHV02CTi<0T92@08R8R02@T900Vi^K0::R
XP2SXj<0YJFU0::RXP2SXj<00`2VYZH>0<SPf0003038h=P2065QH@0F05MGE`1ADE40EEEE05MGE`1H
F5P0EEEE05QHF01JFUX0G5aL069RHP1LG5`0H61P05]KF`1LG5`0FUYJ05iNGP1KFe/0F5QH05IFEP1I
FET0EEEE05UIF@80IfMW00`0Jf][07IfMP20P800Q8B408R8R02@T900Ti>C09RHV02JVYX0X:2P0:6Q
X@2RXZ820:BTY0040:FUY@2ZZZX0YZJV0:JVYP80YjNW00H0ZJVY0:NWY`2TY:@0Xj>S0:6QX@2TY:@2
09nOW`0I09jNWP2HV9P0U9BD08Z:RP26QXH0Ph>307emO@1kNg/0Kfm_06UYJ@1QHF40FUYJ05=CD`1>
CTh0C4a<04];B`1>CTh0CDe=04i>CP1HF5P0FEUI065QH@1OGel0H61P05mOG`02065QH@0806ATI01X
J6P0H61P06YZJP1RHV80IVIV06ATI01WIfL2065QH@80Hf=S01@0H61P06ATI01SHf<0Hf=S06QXJ01W
IfL0JFUY06=SH`1^KVh0J6QX06UYJ@1WIfL0JVYZ06UYJ@1aLG40Jf][06MWI`1]KFd0Kfm_06a/K080
M7Ad00h0LW9b07]kN`1fMWH0OGem07AdM01gMgL0Lg=c07AdM01cLg<0LG5a07]kN`1eMGD0O7al07Ui
N@80OGem01<0NWYj07MgM`1lO7`0MgMg07UiN@1jNWX0Ogmo08V9R@28R8P0NGUi071`L01aLG40LW9b
071`L01bLW80M7Ad07UiN@1fMWH0Kfm_0080KVi^00D0Kfm_075aL@1/K6`0Kfm_071`L00306m_K`0L
07AdM01fMWH0Kfm_079bLP1kNg/0M7Ad06][J`1`L700OGem075aL@1iNGT0LW9b07]kN`1hN7P0Jf][
07moO`1mOGd0LW9b06e]K@21PH40OGem07YjNP1gMgL0P82008Z:RP25QHD0Ng]k07inOP80RHV901T0
Q8B407YjNP1hN7P0RXZ:08V9R@2CTi<0QHF507inOP28R8P0TI6A08^;R`23Ph<0OWin08F5Q@2GUiL0
SXj>08B4Q021PH40Shn?09JFUP2DU9@0S8b<08F5Q@2=SHd0TI6A0080S8b<01l0SHf=08Z:RP2?Shl0
Shn?096AT@2=SHd0SXj>09NGU`2FUYH0VIVI08^;R`2@T900V9RH0:NWY`2[Zj/0[jn_0:BTY02MWId0
UIFE08Z:RP1lO7`0NWYj09^KV`2_[jl0]kNg0<C4a037alL0`L710<K6aP3;bl/0c/k>0080bLW900`0
a/K60<30`035aLD0bLW90<g=c@3?cll0d=3@0=7Ad@3>c/h0b/[:0<C4a033`l<20<_;b`0@0<W9b@35
aLD0`l?30;no_`32`/80a/K60<;2`P31`L40a/K60<c<c036a/H0c/k>0=CDe03@d=00bLW90<g=c@80
a<C40180bl_;0<K6aP35aLD0`/;20<C4a036a/H0alO70<[:bP38b<P0b/[:0<W9b@3=cLd0d];B0=3@
d03Cdm<0dM7A0=;BdP3De=@30=?Cd`0H0=7Ad@3EeMD0e=CD0=?Cd`3Fe]H0f=SH0=OGe`3Kfm/0g=cL
0=oOg`3Shn<0h^;R0=gMg@3=cLd0];Bd09:BTP1QHF40AdM704A4A013@d<0B4Q804Y:BP1<C4`0BDU9
0P1GEeL0501CDe<0EeMG05EEE@1HF5P0GemO06=SH`1UIFD0Kfm_07MgM`1mOGd0Ph>308B4Q02:RXX0
SHf=08n?S`2EUID0UYJF09^KV`2NWYh0VIVI0P2KVi/01@2JVYX0W9bL0:>SX`2KVi/0V9RH0080VYZJ
01h0VIVI09NGU`2JVYX0V9RH09>CT`2FUYH0UIFE096AT@2:RXX0Ph>307alO01bLW80I6AT05UIF@1C
De<0=cLg03<c<`0Z:RX0;Bd]02PX:00];Bd0?Cdm03/k>`0c<c<0<30`03/k>`1?Cdl0GEeM061PH01X
J6P207YjNP0:07UiN@1lO7`0Ph>308V9R@2=SHd0T92@096AT@2CTi<0UYJF09BDU080Ti>C00<0TY:B
09>CT`2>SXh00P2@T9007@2>SXh0Shn?08^;R`2@T900SXj>08Z:RP2@T900SHf=096AT@2>SXh0TI6A
09:BTP2FUYH0T92@096AT@2CTi<0U9BD09VIV@2JVYX0VIVI09^KV`2DU9@0Shn?0861P@1XJ6P0?Cdm
02LW9`0Y:BT09BDU0080:BTY00D09BDU02PX:00X:2P09bLW030`<002038b<P0302h^;P0m?Cd0A4A4
00<0=cLg0180=SHf03De=@0f=SH0>CTi03<c<`0g=cL0<S8b03Ti>@0a<C40;Bd]02h^;P0_;bl0:b/[
038b<P0];Bd0<C4a03Lg=`0o?cl203Ti>@0303@d=00_;bl0<30`00<0:RXZ00P0<c<c03Ph>00i>CT0
<S8b03@d=00i>CT0=3@d03<c<`80>3Ph00@0=cLg03Xj>P0m?Cd0?Cdm0P16ATH01@1HF5P0J6QX07Qh
N023Ph<0RXZ:0080Shn?0180TI6A09>CT`2EUID0VYZJ09NGU`2FUYH0T92@08^;R`29RHT0Ti>C09ZJ
VP2NWYh0XZ:R0:VYZ@2OWil0Xj>S0:FUY@2SXj<>0<SPf0003038h=P206=SH`0305]KF`1EEED0E5AD
0080EeMG00T0De=C05MGE`1HF5P0Fe]K05mOG`1MGEd0Fe]K05mOG`1KFe/00P1MGEd04P1GEeL0EUIF
05=CD`1BDU80Fe]K05aLG01KFe/0IFEU06YZJP1jNWX0OWin08F5Q@2:RXX0S8b<09:BTP2GUiL0VYZJ
09nOW`80XZ:R00@0ZJVY0:BTY02VYZH0ZJVY0P2XZ:P02@2VYZH0Z:RX0:NWY`2XZ:P0Xj>S0:FUY@2S
Xj<0Z:RX0:>SX`0209nOW`0G09JFUP2IVIT0SXj>08^;R`28R8P0Ph>307alO01^KVh0Jf][065QH@1I
FET0D51@04m?C`1;Bd/0Cdm?051@D01<C4`0De=C05mOG`1MGEd0F5QH05mOG`1RHV800P1QHF401`1U
IFD0Hf=S06ATI01QHF40IfMW05YJFP1XJ6P00P1TI6@02@1SHf<0HF5Q06=SH`1MGEd0IfMW06QXJ01P
H600Hf=S069RHP0206ATI00506UYJ@1VIVH0JVYZ06UYJ@1WIfL00P1ZJVX0301YJFT0K6a/06e]K@1Z
JVX0LW9b06m_K`1aLG40L71`07AdM01bLW80OGem07YjNP80Lg=c00D0MgMg07=cL`1cLg<0NGUi07Ee
M@0307MgM`80NGUi00X0MgMg07alO01hN7P0Ng]k07MgM`1eMGD0OWin08:2PP27QhL0O7al0P1cLg<0
8`1jNWX0M7Ad06m_K`1fMWH0Kfm_06i^KP1jNWX0Jf][06UYJ@1_Kfl0LG5a06i^KP1cLg<0Kfm_06YZ
JP1_Kfl0NGUi07=cL`1dM7@0NWYj07AdM01`L700N7Qh06m_K`1YJFT0KVi^079bLP1aLG40KVi^07em
O@1jNWX0LG5a07]kN`20P800NWYj0080M7Ad00h0PX:207UiN@1lO7`0O7al07UiN@21PH40QHF507]k
N`1iNGT0PX:208>3P`28R8P0Ogmo07emO@80SXj>00D0RXZ:0861P@1fMWH0QhN7096AT@0208^;R`06
07emO@2>SXh0VIVI08f=S@2;Rh/0TI6A0P2DU9@0102BTY80QhN707moO`2;Rh/209^KV`0R08n?S`2@
T900RHV908^;R`2ATI40Ti>C08n?S`29RHT0Rh^;09fMW@2IVIT0U9BD096AT@2UYJD0[:b/0:VYZ@2b
/[80ZJVY09^KV`2JVYX0UYJF0861P@1oOgl0UIFE0:JVYP2o_kl0_[jn0;^k^`3:b/X0c/k>0<_;b`39
bLT0b/[:0<O7a`80bLW900D0b/[:0<c<c03=cLd0bl_;0<g=c@020<c<c00M0<W9b@3?cll0clo?0<O7
a`32`/80aLG50<[:bP39bLT0a/K60<71`@2l_;`0a<C40<G5a@34a<@0aLG50<k>cP3Cdm<0cLg=0<[:
bP3Cdm<0a/K60<c<c03Cdm<0cLg=0<S8b037alL0`l?30<O7a`36a/H00`34a<@01039bLT0d=3@0<g=
c@3<c<`20<o?c`030=?Cd`3@d=00dm?C0080dm?C03D0e=CD0=OGe`3Fe]H0dm?C0=CDe03Fe]H0f][J
0=gMg@3Ogml0g]kN0=WIf@3>c/h0^;Rh09VIV@1nOWh0JVYZ05EEE@1<C4`0AdM704];B`1:BTX0Bd];
04a<C01=CDd0E5AD05=CD`1KFe/0FEUI05IFEP1LG5`0HF5Q05mOG`1[Jf/0KFe]07alO01mOGd0PX:2
08J6QP2;Rh/0SXj>09>CT`2DU9@0V9RH09bLW02IVIT0VYZJ09^KV`2IVIT0Vi^K09RHV02LW9`0UYJF
09^KV`0309VIV@0M09^KV`2HV9P0UiNG09>CT`2FUYH0UIFE096AT@29RHT0PH6108:2PP1dM7@0I6AT
05IFEP1<C4`0>c/k034a<@0];Bd0:RXZ02<S8`0Y:BT0>CTi0451@@0n?Sh0>c/k05ADE01KFe/0GEeM
06ATI01^KVh00P1dM7@01P20P800R8R808>3P`28R8P0T92@096AT@80Ti>C00<0UYJF09NGU`2EUID0
0P2BTY80102?Shl0TI6A08b<S02@T90208j>SP0A08n?S`2=SHd0SHf=09:BTP2=SHd0T92@08b<S02C
Ti<0T92@09BDU02EUID0TI6A09BDU02@T900U9BD09ZJVP2IVIT00`2JVYX01P2IVIT0Rh^;07IfMP1J
FUX0=3@d02TY:@80;2`/00h092@T02DU9@0Y:BT09bLW02HV9P0W9bL0:2PX02`/;00^;Rh0>3Ph03<c
<`0j>SX0>c/k03Ph>080?3`l01@0=CDe02d];@0d=3@0=3@d03Hf=P0a<C40;bl_02`/;00];Bd0<c<c
030`<00Y:BT0:RXZ038b<P0k>c/0?Shn03/k>`0g=cL0>CTi034a<@<0;2`/00<0;Bd]02h^;P0e=CD0
0P0e=CD06P0g=cL0>c/k03Xj>P0k>c/0?3`l03lo?`10@400@T920410@00j>SX0?Shn04I6AP1BDU80
I6AT06i^KP1oOgl0PH6108R8R02>SXh0TY:B09BDU02EUID0V9RH09FEU@2FUYH0Ti>C0P27QhL02@2=
SHd0T92@09ZJVP2IVIT0WYjN0::RXP2TY:@0XZ:R0:FUY@0>0<SPf0003038h=P206][J`0306IVIP1E
EED0D51@0080De=C00<0Fe]K05QHF01GEeL00P1KFe/0701JFUX0F5QH05eMG@1KFe/0FUYJ05]KF`1F
EUH0FUYJ05MGE`1@D500F5QH05ADE01NGUh0I6AT06m_K`1gMgL0PX:208J6QP2<S8`0TI6A09:BTP2F
UYH0WIfM09nOW`2NWYh0XZ:R0:>SX`2VYZH20:BTY080YjNW00D0ZJVY0:RXZ02WYjL0YjNW0:FUY@02
0:BTY00F0:FUY@2RXZ80WYjN09fMW@2JVYX0WIfM092@T02:RXX0SHf=07inOP1gMgL0LW9b06a/K01g
MgL0FEUI059BDP18B4P0AdM7051@D01GEeL0EUIF05iNGP80FEUI02`0GemO061PH01PH600IFEU05UI
F@1NGUh0HV9R06QXJ01UIFD0J6QX05aLG01SHf<0HF5Q06ATI01SHf<0HV9R06IVIP1OGel0I6AT065Q
H@1VIVH0Jf][06QXJ01SHf<0IVIV06QXJ01QHF40IFEU06YZJP1WIfL0I6AT06IVIP1UIFD0JVYZ06a/
K01^KVh0L71`06m_K`1dM7@0KFe]075aL@1eMGD0MWIf07YjNP80NGUi00@0Kfm_079bLP1bLW80M7Ad
0P1eMGD02@1gMgL0NGUi07MgM`1gMgL0NWYj07UiN@1gMgL0NWYj07UiN@0207alO00607inOP22PX80
QHF507MgM`1eMGD0N7Qh0P1cLg<06P1^KVh0Jf][079bLP1jNWX0Kfm_06][J`1eMGD0MWIf075aL@1`
L700MWIf06][J`1`L700Lg=c07AdM01eMGD0N7Qh07YjNP1dM7@0NGUi07alO01hN7P0LG5a079bLP1c
Lg<0MGEe0P1_Kfl0301aLG40LW9b079bLP1cLg<0NGUi07alO01gMgL0MWIf07]kN`24Q8@0O7al07=c
L`80Rh^;01/0O7al07YjNP1hN7P0R8R808^;R`22PX80PH6108V9R@2:RXX0Rh^;08J6QP1jNWX0Q8B4
096AT@2FUYH0Ti>C08F5Q@2@T900U9BD09:BTP2CTi<0U9BD09>CT`2GUiL0U9BD08R8R024Q8@00P20
P8007`2:RXX0Rh^;092@T025QHD0P82008n?S`2EUID0U9BD08N7Q`2LW9`0WIfM09jNWP2IVIT0U9BD
09^KV`2XZ:P0[Jf]0;6a/@2g]kL0YJFU09^KV`2@T900TI6A08V9R@2;Rh/0WYjN0:b/[02m_Kd0bl_;
0<W9b@38b<P00P3>c/h0203;bl/0b/[:0<W9b@3:b/X0bLW90<[:bP3;bl/0bLW90P38b<P06@3?cll0
dm?C0=3@d039bLT0alO70<o?c`3AdM40cLg=0<S8b037alL0b/[:0<W9b@32`/80`l?30<S8b03=cLd0
c<c<0<C4a039bLT0c/k>0<K6aP3AdM40dm?C0=7Ad@39bLT00P3<c<`0303De=@0dM7A0<o?c`3<c<`0
bLW90<o?c`37alL0b/[:0<_;b`3<c<`0cLg=0<o?c`80cLg=0P3AdM401@3EeMD0dm?C0=?Cd`3Fe]H0
f=SH0080fMWI00P0g=cL0=oOg`3Fe]H0^;Rh09jNWP1jNWX0GemO05IFEP80D51@00<0C4a<04Y:BP1A
DE400P1=CDd01@1EEED0F5QH05ADE01MGEd0FEUI0080De=C01<0EUIF05mOG`1QHF40Jf][071`L01e
MGD0O7al08:2PP28R8P0RHV908b<S02BTY80UIFE09NGU`2KVi/0WIfM09ZJVP2HV9P0VIVI0080Vi^K
00P0WYjN09RHV02FUYH0Vi^K09JFUP2MWId0Vi^K09FEU@80UiNG01H0U9BD092@T02>SXh0Rh^;0820
P01nOWh0M7Ad06=SH`1HF5P0Bd];03/k>`0_;bl09bLW02l_;`10@400=CDe02`/;00Z:RX0>SXj04m?
C`1LG5`0H61P0P1ZJVX02`1dM7@0Ogmo07moO`21PH40QHF508B4Q02=SHd0Shn?09>CT`2GUiL0UIFE
0080U9BD00H0TI6A092@T02CTi<0S8b<08f=S@2>SXh308f=S@0N08j>SP2<S8`0Rh^;08f=S@2>SXh0
T92@09BDU02@T900TY:B08n?S`2CTi<0TI6A09FEU@2BTY80Ti>C09VIV@2DU9@0WIfM09ZJVP2KVi/0
W9bL09FEU@27QhL0K6a/04];B`0i>CT0=SHf02d];@0V9RH08b<S0P0U9BD02`0[:b/0<30`02/[:`0/
;2`0<C4a02l_;`0a<C40>c/k03Hf=P0h>3P0=SHf0080?clo00L0=SHf03<c<`0a<C40>CTi03@d=00b
<S80;2`/0080;Bd]00<0:b/[02HV9P0U9BD00P0a<C401P0e=CD0>CTi03`l?00l?3`0<c<c02d];@<0
:b/[0200<S8b03Ph>00e=CD0=3@d03De=@0`<300=CDe03Lg=`0h>3P0@41004Q8B00k>c/0?Cdm03Lg
=`10@400ATI604m?C`1EEED0Hf=S07EeM@1jNWX0P82008b<S02@T900UIFE09:BTP2EUID0UiNG09JF
UP2ATI40S8b<092@T080S8b<00L0Ti>C09RHV02MWId0WinO0:6QX@2TY:@0YJFU00h0b>3H000<0<SP
f080M7Ad00h0JFUY05iNGP1DE5@0EUIF055AD@1IFET0F5QH05YJFP1LG5`0GemO05eMG@1LG5`0FEUI
05]KF`80F5QH01P0GEeM05MGE`1ADE40EeMG05IFEP1IFET0HF5Q069RHP1[Jf/0NGUi08>3P`29RHT0
RXZ:09BDU02EUID0UiNG09^KV`2MWId0XJ6Q0:FUY@2WYjL0Y:BT0:VYZ@2ZZZX20:NWY`030:^[Z`2U
YJD0ZZZZ0080YjNW00@0Y:BT0:FUY@2UYJD0X:2P0P2NWYh03P2KVi/0UYJF092@T02<S8`0Q8B407in
OP1cLg<0LG5a06ATI01PH600FUYJ05=CD`1<C4`0AdM70P1=CDd02`1>CTh0EeMG05EEE@1IFET0Hf=S
05mOG`1TI6@0HF5Q05mOG`1QHF40LG5a0080Hf=S00T0HF5Q06ATI01PH600HV9R06IVIP1TI6@0HV9R
06IVIP1UIFD00P1SHf<03`1WIfL0JVYZ06EUI@1VIVH0IfMW06ATI01RHV80IfMW06QXJ01/K6`0IfMW
06EUI@1[Jf/0JFUY06YZJP0206][J`03079bLP1^KVh0K6a/0080M7Ad00H0LW9b07QhN01iNGT0MgMg
07EeM@1aLG4207AdM080MWIf00l0M7Ad079bLP1gMgL0MgMg07EeM@1bLW80N7Qh07UiN@1lO7`0OWin
0861P@1lO7`0OWin08:2PP1gMgL0101bLW801`1^KVh0K6a/06YZJP1]KFd0K6a/07EeM@1fMWH00P1_
Kfl0301bLW80Jf][06e]K@1gMgL0Kfm_075aL@1fMWH0MgMg07IfMP1cLg<0MWIf07EeM@80NGUi01<0
L71`06][J`1]KFd0M7Ad06a/K01SHf<0IfMW06e]K@1`L700LG5a07moO`1dM7@0N7Qh079bLP1gMgL0
QHF507alO01hN7P0Ph>30080QXJ600L0NGUi07emO@28R8P0Q8B408>3P`21PH40P8200080S8b<0100
QhN707inOP25QHD0Shn?09RHV02ATI40S8b<08Z:RP2DU9@0S8b<09FEU@2ATI40U9BD09RHV02DU9@0
SXj>0P1lO7`0BP1nOWh0T92@09FEU@2=SHd0P82008J6QP2CTi<0UiNG09>CT`2ATI40V9RH09bLW02R
XZ80YjNW0:BTY02HV9P0YJFU0;Bd]02l_;`0]kNg0:^[Z`2CTi<0VIVI09bLW02ATI40QhN709BDU02_
[jl0_[jn0;fm_@34a<@0d];B0=3@d03=cLd0b/[:0<g=c@3?cll0c<c<0<g=c@3:b/X0aLG50<;2`P3:
b/X0c/k>0=7Ad@3=cLd0b/[:0=OGe`3EeMD0cLg=0<_;b`3:b/X0d=3@0<_;b`39bLT0a<C40<W9b@38
b<P0a/K60<;2`P2m_Kd0`<300<;2`P34a<@0d=3@0=?Cd`3?cll0b<S80=;BdP3<c<`0emOG0=CDe03H
f=P0e]KF0P3Cdm<0203;bl/0d=3@0<o?c`3@d=00cLg=0<o?c`3>c/h0d];B0P3@d=005@3GemL0dm?C
0=OGe`3Lg=`0g]kN0=oOg`3Lg=`0h>3P0=gMg@35aLD0QHF506UYJ@1IFET0CTi>04a<C01;Bd/0ATI6
059BDP1ADE40DU9B04i>CP0205ADE00305=CD`1FEUH0E5AD0080F5QH01<0FEUI061PH01RHV80IfMW
06UYJ@1bLW80N7Qh07inOP1oOgl0RHV908^;R`2=SHd0TI6A09FEU@2GUiL0VYZJ09bLW02HV9P0W9bL
0080VIVI00H0WYjN09^KV`2GUiL0UiNG09ZJVP2FUYH209bLW00L09ZJVP2GUiL0Vi^K096AT@2@T900
TY:B08R8R021PH40NGUi06i^KP1TI6@0EUIF04e=C@0n?Sh0<30`02HV9P0T92@0;2`/02d];@0a<C40
=CDe04A4A01?Cdl0I6AT065QH@1VIVH0MGEe07UiN@80Ogmo00L0R8R808V9R@28R8P0TI6A092@T02D
U9@0TY:B0080UYJF00H0V9RH096AT@2ATI40Shn?092@T02ATI4208f=S@0T08n?S`2@T900RXZ:08b<
S02?Shl0SXj>09>CT`2ATI40T92@08f=S@2BTY80Shn?096AT@2EUID0TY:B096AT@2@T900UYJF09:B
TP2FUYH0V9RH09ZJVP2MWId0W9bL08f=S@1oOgl0I6AT03lo?`0[:b/0:BTY02XZ:P0V9RH08b<S02TY
:@0`<300:RXZ0P0/;2`2030`<080<C4a00X0=cLg03/k>`0b<S80=CDe03Xj>P0g=cL0>3Ph03<c<`0i
>CT0=SHf0P0e=CD03@0b<S809RHV02h^;P0Y:BT09BDU02PX:00];Bd0<30`03Ph>00l?3`0=cLg03/k
>`0b<S800P0a<C40100Y:BT0;2`/02TY:@0d=3@202l_;`80<c<c00P0<30`034a<@0j>SX0=CDe03dm
?@0g=cL0>c/k0410@080BTY:0100DE5A05]KF`1YJFT0LW9b07YjNP23Ph<0Shn?092@T02FUYH0UIFE
09ZJVP2DU9@0TY:B096AT@2DU9@0TI6A0P28R8P00`2BTY80VYZJ0:2PX0030:>SX`h0b>3H000<0<SP
f080NWYj01d0KVi^069RHP1FEUH0De=C055AD@1EEED0EUIF05=CD`1IFET0JFUY06=SH`1KFe/0GEeM
05]KF`1LG5`0Fe]K05MGE`1HF5P0De=C05IFEP1DE5@0EUIF06=SH`1RHV80L71`07AdM01oOgl0QXJ6
08^;R`0209:BTP0909VIV@2JVYX0W9bL09fMW@2QXJ40Xj>S0:FUY@2YZJT0Zj^[00@0YjNW01`0Y:BT
0:ZZZP2UYJD0Z:RX0:NWY`2PX:00XJ6Q0:2PX02LW9`0Vi^K09NGU`2@T900RHV908F5Q@1oOgl0NWYj
06a/K01ZJVX0HF5Q05MGE`1CDe<0Cdm?04a<C01EEED0CTi>055AD@1DE5@0G5aL0P1NGUh00`1UIFD0
HF5Q06=SH`0206ATI00506IVIP1RHV80IVIV069RHP1VIVH00P1OGel08@1XJ6P0HF5Q065QH@1PH600
IfMW06QXJ01WIfL0GUiN061PH01[Jf/0IVIV06=SH`1RHV80H61P06MWI`1ZJVX0K6a/06e]K@1YJFT0
J6QX06][J`1^KVh0Jf][06i^KP1]KFd0NGUi07MgM`1]KFd0MGEe071`L01cLg<0M7Ad07=cL`02079b
LP0607UiN@1dM7@0N7Qh07IfMP1hN7P0MgMg0P1jNWX04@1iNGT0Ng]k07]kN`1lO7`0OGem07]kN`1j
NWX0OGem07alO023Ph<0Ogmo07UiN@1eMGD0MgMg075aL@1ZJVX0K6a/0080JVYZ00<0Kfm_079bLP1l
O7`00P1bLW8206e]K@0406i^KP1kNg/0LW9b079bLP80M7Ad00<0NGUi07IfMP1bLW800`1dM7@0;P1i
NGT0LW9b06=SH`1`L700MWIf07=cL`1YJFT0Kfm_071`L01aLG40KVi^07QhN01mOGd0NGUi07IfMP24
Q8@0RHV908B4Q01mOGd0MWIf08F5Q@27QhL0P82007]kN`28R8P0Shn?08j>SP29RHT0Q8B4096AT@2@
T900Shn?08F5Q@23Ph<0Shn?09:BTP2EUID0SXj>092@T02CTi<0TI6A09ZJVP2DU9@0SXj>096AT@2J
VYX208N7Q`0807UiN@25QHD0UIFE08^;R`2@T900QXJ608Z:RP2CTi<209FEU@0=08b<S02ATI40XJ6Q
0:BTY02][Jd0YjNW09VIV@2SXj<0/[:b0;Ng]`2`/;00Zj^[0:b/[0020:2PX00709VIV@2<S8`0PX:2
0:2PX02ZZZX0`L710<g=c@020<o?c`0:0<g=c@3?cll0d=3@0=3@d03=cLd0bLW90<C4a038b<P0bLW9
0<c<c080bl_;02@0c<c<0=WIf@3Hf=P0d=3@0<o?c`3AdM40d];B0<g=c@3:b/X0c<c<0<W9b@38b<P0
a/K60<;2`P34a<@0`<300<?3``39bLT0b<S80<_;b`38b<P0a/K60=3@d03?cll0fm_K0=KFeP3Jf]X0
f=SH0=KFeP3De=@0d=3@0=OGe`3Fe]H0eMGE0<o?c`3Cdm<20=GEe@80f][J0P3Kfm/02`3Ph>00i>CT
0>CTi03Ng]h0gmoO0>?Sh`3Fe]H0Z:RX061PH01EEED0DU9B0080BTY:0P18B4P2055AD@0605IFEP1?
Cdl0F5QH05QHF01GEeL0GemO0P1JFUX03P1IFET0EeMG061PH01OGel0IfMW06UYJ@1aLG40MWIf08:2
PP20P800QXJ608n?S`2@T900TY:B0P2GUiL0202HV9P0W9bL09ZJVP2NWYh0VYZJ09VIV@2LW9`0VIVI
0P2HV9P02`2NWYh0W9bL09^KV`2MWId0UiNG09^KV`2DU9@0TY:B08n?S`2>SXh0QhN70080P82000H0
LG5a061PH01HF5P0CTi>03`l?00_;bl202DU9@0;02@T900/;2`0=cLg03dm?@1:BTX0D51@06ATI01W
IfL0LW9b07QhN01jNWX00P1oOgl02P28R8P0SXj>08b<S02BTY80T92@09FEU@2IVIT0UIFE09BDU02G
UiL209:BTP0:092@T02DU9@0SHf=08f=S@2<S8`0TI6A092@T02?Shl0SXj>09JFUP80Shn?00H0SHf=
096AT@2;Rh/0T92@09:BTP2>SXh2096AT@0309:BTP2CTi<0TY:B0080U9BD00T0UIFE09RHV02KVi/0
WIfM09RHV02@T900LG5a055AD@0h>3P00P0X:2P03@0U9BD09bLW02DU9@0/;2`0;Rh^02/[:`0Y:BT0
;2`/02XZ:P0d=3@0<30`034a<@0d=3@00P0h>3P0200g=cL0<S8b034a<@0e=CD0@41003`l?00e=CD0
=SHf0P0b<S80100_;bl0;2`/02<S8`0Y:BT202`/;00503De=@0f=SH0?3`l03dm?@11@D400P0i>CT0
3P0_;bl0:b/[034a<@0`<300<S8b034a<@0g=cL0<S8b034a<@0d=3@0=cLg038b<P0h>3P0>CTi0P12
@T802`1ADE40CDe=04e=C@1ADE40GemO06UYJ@1aLG40NGUi08N7Q`2=SHd0TI6A0080UIFE00<0TI6A
09:BTP2EUID00P2EUID0202?Shl0Ph>308N7Q`2ATI40VIVI0:2PX02TY:@0XZ:R3P38h=P000`0b>3H
0P1kNg/01@1hN7P0JVYZ06=SH`1HF5P0EUIF0080EEEE0240De=C05iNGP1LG5`0GEeM065QH@1KFe/0
EUIF05YJFP1LG5`0Fe]K05QHF01KFe/0F5QH05ADE01GEeL0FEUI06ATI01_Kfl0Ng]k0820P023Ph<0
SHf=09BDU02CTi<0W9bL0:6QX@2PX:00YJFU0::RXP2UYJD0Xj>S0:ZZZP2YZJT00P2WYjL01@2ZZZX0
Y:BT0::RXP2SXj<0XJ6Q0080Xj>S0P2TY:@09@2PX:00WYjN09VIV@2GUiL0T92@08V9R@25QHD0MgMg
07UiN@1_Kfl0IFEU05mOG`1MGEd0E5AD04i>CP18B4P0CDe=055AD@1FEUH0F5QH05YJFP1LG5`0GEeM
061PH01RHV80GemO065QH@1TI6@0IfMW06=SH`1NGUh0Fe]K06IVIP1NGUh0HV9R06EUI@1QHF400P1P
H600501UIFD0IVIV06ATI01JFUX0Hf=S06EUI@1SHf<0I6AT06=SH`1ZJVX0IVIV06QXJ01]KFd0JFUY
06QXJ01UIFD0K6a/06UYJ@1^KVh0MGEe0P1aLG400`1dM7@0KVi^07UiN@0207AdM00:07IfMP1dM7@0
MGEe07AdM01eMGD0MWIf07YjNP1gMgL0Lg=c07YjNP80M7Ad0140MgMg07]kN`1jNWX0NWYj07IfMP1j
NWX0N7Qh07UiN@1mOGd0Ng]k08>3P`1oOgl0M7Ad06e]K@1_Kfl0Jf][06YZJP0206e]K@0506m_K`1^
KVh0Lg=c06e]K@1dM7@00P1_Kfl0101gMgL0Kfm_071`L01/K6`307IfMP0?07YjNP1dM7@0Lg=c07Yj
NP1fMWH0Ng]k07MgM`1fMWH0Lg=c07EeM@1cLg<0MWIf06m_K`1YJFT0KFe]0080MGEe01T0L71`07in
OP1nOWh0NWYj08B4Q023Ph<0QhN707moO`1fMWH0Ph>308J6QP25QHD0P82008>3P`2=SHd0Ti>C096A
T@27QhL0SHf=08n?S`2BTY80SHf=08b<S02:RXX0TI6A0080Ti>C00L0SXj>08Z:RP2EUID0UYJF09>C
T`2=SHd0Ti>C0080U9BD00@0RHV908Z:RP29RHT0QhN70P2>SXh02@2:RXX0Rh^;092@T02GUiL0V9RH
08Z:RP2ATI40XJ6Q0:2PX0020:b/[00@0:JVYP2SXj<0YjNW0;Jf]P2^[Zh0^[Zj0;6a/@2TY:@0W9bL
09RHV02GUiL0TI6A09JFUP2a/K40a<C40<W9b@80cLg=0P3?cll02P3=cLd0bLW90<O7a`3:b/X0c/k>
0<_;b`35aLD0a/K60<O7a`3=cLd20=?Cd`0@0=CDe03GemL0eMGE0<k>cP3AdM40d=3@0<[:bP38b<P0
b/[:0<O7a`36a/H0b/[:0<K6aP3;bl/0bLW90<S8b080a/K60P39bLT0303;bl/0dM7A0=7Ad@3Fe]H0
f=SH0=[JfP3@d=00e=CD0=SHf03IfMT0dm?C0=GEe@<0f=SH0P3Ng]h20=oOg`0Q0>CTi03Ph>00h>3P
0=gMg@3Ogml0f][J0;jn_P22PX80CDe=04M7A`1;Bd/0C4a<04i>CP1?Cdl0Bd];05EEE@1DE5@0EEEE
05ADE01JFUX0EEEE05QHF01OGel0G5aL05]KF`1IFET0Fe]K065QH@1RHV80IfMW06UYJ@1bLW80MWIf
0080Ogmo00T0Rh^;08b<S02@T900T92@09JFUP2HV9P0VYZJ09^KV`2NWYh00P2JVYX0102FUYH0WIfM
09^KV`2HV9P209NGU`0909bLW02HV9P0VIVI09VIV@2KVi/0TY:B092@T02?Shl0SHf=0080QhN701@0
OWin07QhN01ZJVX0GEeM04Y:BP0f=SH0<C4a02TY:@0U9BD0;2`/034a<@0h>3P0>CTi059BDP1PH600
GemO06QXJ01[Jf/0MgMg07alO080Ogmo00l0S8b<08^;R`2?Shl0TY:B09BDU02FUYH0U9BD09FEU@2D
U9@0TY:B08n?S`2CTi<0TI6A08j>SP2ATI400P2>SXh0402@T900TY:B09>CT`2<S8`0SXj>08n?S`2B
TY80TI6A08f=S@2>SXh0Shn?09:BTP2?Shl0Ti>C096AT@2@T902096AT@0509BDU02GUiL0UYJF09JF
UP2MWId00P2PX:00:P2HV9P0RHV906ATI011@D40:RXZ02PX:00`<3009RHV02XZ:P0^;Rh09bLW03<c
<`0];Bd09RHV02XZ:P0Y:BT0<30`02XZ:P0f=SH0=3@d03<c<`0f=SH0=3@d03Lg=`0d=3@0;Rh^03<c
<`0h>3P0=3@d03<c<`0`<300;Rh^02l_;`0];Bd0;bl_02d];@0a<C40<S8b03De=@0j>SX0?Cdm04A4
A080@T920P0^;Rh0600`<300<S8b03De=@0j>SX0<S8b03De=@0_;bl0<C4a03<c<`0_;bl0=3@d0492
@P0m?Cd0@d=304Q8B01:BTX0D51@055AD@1DE5@0F5QH06ATI01`L700NWYj08F5Q@80SXj>00h0TY:B
09BDU02BTY80UIFE09RHV02IVIT0UYJF08V9R@25QHD0S8b<09JFUP2MWId0WinO0:>SX`h0b>3H000<
0<SPf080PX:201T0O7al07AdM01VIVH0GUiN04m?C`1DE5@0F5QH05aLG01GEeL0Fe]K05eMG@1LG5`0
FUYJ05IFEP1NGUh0FUYJ059BDP1CDe<0FUYJ05IFEP1HF5P0FUYJ05eMG@1XJ6P0LG5a0080OGem00`0
Q8B408n?S`2ATI40VIVI09NGU`2JVYX0WYjN0::RXP2UYJD0YZJV0:FUY@2TY:@30:RXZ0030:^[Z`2T
Y:@0YjNW0080YJFU01l0Z:RX0:JVYP2RXZ80XJ6Q09jNWP2PX:00VIVI09FEU@2?Shl0RHV908F5Q@1m
OGd0Ng]k071`L01SHf<0HV9R05aLG01@D500C4a<04i>CP17AdL0Bd];05ADE01HF5P0E5AD05MGE`1J
FUX0H61P065QH@1OGel0HF5Q0080H61P00P0GUiN05eMG@1SHf<0HV9R05eMG@1RHV80J6QX065QH@80
HV9R01<0Hf=S06ATI01WIfL0Hf=S06MWI`1SHf<0GemO06ATI01QHF40J6QX06=SH`1UIFD0Jf][06YZ
JP1[Jf/0JFUY06a/K01[Jf/0JVYZ0080KVi^0100Jf][07AdM01/K6`0M7Ad07EeM@1dM7@0Lg=c07Ee
M@1bLW80M7Ad07EeM@1fMWH0N7Qh07IfMP1hN7P0NGUi0P1mOGd05P1fMWH0OGem07alO01jNWX0MWIf
07QhN01iNGT0O7al07UiN@1mOGd0NWYj0820P01nOWh0M7Ad06YZJP1[Jf/0Kfm_071`L01WIfL0J6QX
06m_K`1^KVh2075aL@0Z07UiN@1^KVh0LG5a079bLP1dM7@0LG5a06a/K01fMWH0N7Qh07IfMP1jNWX0
N7Qh07AdM01eMGD0M7Ad07EeM@1fMWH0NWYj07IfMP1/K6`0NWYj07QhN01[Jf/0I6AT06MWI`1dM7@0
LW9b07=cL`1nOWh0PX:20861P@1jNWX0OGem08R8R01mOGd0MWIf08:2PP26QXH0Ph>307moO`21PH40
SHf=0P2>SXh04025QHD0Ph>3096AT@2EUID0Ti>C08V9R@26QXH0Rh^;09BDU02<S8`0Q8B408J6QP2F
UYH0TY:B09NGU`2<S8`209:BTP0309FEU@2BTY80UIFE0080RHV900H0Rh^;092@T02@T900R8R809>C
T`2FUYH209FEU@0F09jNWP2PX:00YZJV0;6a/@2g]kL0];Bd0:j^[P2YZJT0]kNg0;Jf]P2g]kL0/k>c
0:b/[02SXj<0YjNW0:6QX@2GUiL0Shn?0:VYZ@2m_Kd0a/K60<W9b@80c<c<00T0alO70<W9b@3=cLd0
clo?0<k>cP3<c<`0alO70<c<c03>c/h00P3:b/X0203?cll0dM7A0=OGe`3Cdm<0c/k>0=3@d03;bl/0
bLW90P3=cLd01036a/H0c<c<0<g=c@3?cll30<c<c0030<g=c@3:b/X0b/[:0080bLW900/0alO70<_;
b`3AdM40d=3@0=CDe03?cll0emOG0=SHf03IfMT0eMGE0=[JfP020=WIf@0B0=_Kf`3QhN40hN7Q0>;R
hP3Ti>@0i^KV0>7Qh@3MgMd0g=cL0=_Kf`31`L40SXj>05UIF@1;Bd/0C4a<04i>CP19BDT0EUIF0P1B
DU806@1EEED0F5QH05YJFP1HF5P0FUYJ05EEE@1HF5P0FEUI05YJFP1KFe/0GEeM061PH01NGUh0I6AT
06UYJ@1WIfL0M7Ad07MgM`1lO7`0PH6108F5Q@2;Rh/0T92@09BDU02FUYH00P2JVYX07P2LW9`0X:2P
09NGU`2KVi/0VYZJ09VIV@2HV9P0W9bL09^KV`2LW9`0V9RH09fMW@2HV9P0VYZJ09RHV02BTY80V9RH
09:BTP2DU9@0SHf=08J6QP1lO7`0N7Qh06MWI`1MGEd0CTi>0410@00`<300;Bd]02TY:@80;Bd]00T0
>SXj04I6AP1DE5@0HV9R06=SH`1ZJVX0Lg=c07IfMP23Ph<00P24Q8@0502>SXh0TI6A096AT@2BTY80
UIFE09NGU`2HV9P0UYJF096AT@2CTi<0S8b<09RHV02@T900TY:B08n?S`2ATI40S8b<09:BTP2?Shl0
T92@0P2=SHd02@2?Shl0TI6A096AT@2;Rh/0UYJF09:BTP2@T900U9BD09>CT`02096AT@0308n?S`2B
TY80Ti>C0080UIFE00X0UiNG09VIV@2MWId0WIfM09nOW`2>SXh0MWIf05YJFP0n?Sh0:b/[0P0c<c<0
0`0[:b/0:RXZ034a<@0202d];@0@02h^;P0];Bd0;Bd]02TY:@0^;Rh0<C4a02l_;`0d=3@0=cLg038b
<P0c<c<0>3Ph030`<00d=3@0=CDe03@d=080>CTi00/0>3Ph030`<00`<300:b/[02d];@0/;2`0;bl_
03<c<`0m?Cd0>3Ph03/k>`0203<c<`0;030`<00_;bl0;bl_02l_;`0];Bd0=3@d02l_;`0d=3@0=cLg
038b<P0a<C400P0e=CD04`0l?3`0?Cdm04U9B@0o?cl0ADE5051@D01;Bd/0EEEE055AD@1HF5P0Hf=S
06e]K@1iNGT0Ph>308b<S02>SXh0TI6A09VIV@2DU9@00P2FUYH0202HV9P0U9BD08J6QP24Q8@0SXj>
09NGU`2MWId0X:2P3P38h=P000`0b>3H0P28R8P01`22PX80MgMg06m_K`1RHV80Fe]K059BDP1FEUH0
0P1CDe<02@1MGEd0F5QH05iNGP1GEeL0FEUI05]KF`1JFUX0EeMG05IFEP0205QHF00@059BDP1FEUH0
HF5Q06EUI@1`L700Lg=c07emO@25QHD0S8b<08n?S`2CTi<0VIVI09^KV`2PX:00Y:BT0::RXP<0YJFU
00L0Zj^[0:VYZ@2YZJT0YjNW0:FUY@2VYZH0XZ:R0080Y:BT0P2QXJ40702UYJD0X:2P09fMW@2JVYX0
UiNG08n?S`2=SHd0Q8B40820P01iNGT0Lg=c06i^KP1QHF40G5aL04m?C`19BDT0B4Q804e=C@1>CTh0
D51@05IFEP1HF5P0GEeM05YJFP1PH600GEeM069RHP1UIFD2069RHP09061PH01QHF40IFEU06YZJP1O
Gel0IFEU06UYJ@1TI6@0GUiN0080IFEU00L0IVIV06QXJ01WIfL0GUiN06EUI@1TI6@0HF5Q0080IfMW
01T0Hf=S06MWI`1]KFd0JFUY06][J`1YJFT0K6a/06YZJP1_Kfl0L71`06YZJP1aLG40Lg=c06e]K@1a
LG40LW9b07UiN@1dM7@0MgMg07=cL`1aLG40Lg=c07QhN01jNWX0MgMg0080NGUi0P1kNg/06@1hN7P0
NGUi07]kN`1eMGD0Lg=c0820P01lO7`0NGUi07inOP1iNGT0Ogmo07emO@24Q8@0Ng]k06i^KP1[Jf/0
KFe]07=cL`1[Jf/0JVYZ06][J`1_Kfl0KVi^06m_K`1cLg<00P1]KFd2075aL@0g07EeM@1aLG40JFUY
07AdM01jNWX0O7al08>3P`1fMWH0M7Ad079bLP1lO7`0M7Ad07EeM@1kNg/0LW9b07UiN@1hN7P0NGUi
079bLP1VIVH0JVYZ07QhN01eMGD0NGUi07inOP22PX80N7Qh07UiN@1oOgl0QHF507inOP1jNWX0Lg=c
07UiN@20P800QXJ608>3P`2;Rh/0TY:B08b<S026QXH0Ogmo08f=S@2>SXh0TI6A08V9R@24Q8@0RHV9
08f=S@2:RXX0R8R808j>SP2@T900Ti>C09NGU`0308f=S@05092@T02ATI40UIFE09:BTP2?Shl00P2I
VIT03`2FUYH0S8b<09NGU`2GUiL0WIfM0:ZZZP2OWil0UiNG0:NWY`2XZ:P0/[:b0;^k^`2e]KD0[Zj^
0:RXZ0020;Jf]P0E0;2`/02a/K40_Kfm0:f][@2PX:00UYJF096AT@2KVi/0[jn_0;^k^`32`/80a/K6
0<[:bP3>c/h0d];B0=7Ad@3>c/h0bl_;0=?Cd`3De=@0c<c<0080b<S800l0c<c<0<k>cP3=cLd0bl_;
0<k>cP3AdM40cLg=0=3@d03<c<`0alO70<_;b`3?cll0d=3@0=?Cd`3@d=000P3>c/h00`3@d=00c<c<
0<c<c0020<W9b@040<[:bP3?cll0c/k>0<_;b`80c/k>00P0e=CD0=OGe`3Hf=P0eMGE0=[JfP3De=@0
fMWI0=kNgP80hN7Q00<0i>CT0>KViP3Ti>@00P3Lg=`0403Jf]X0c<c<09jNWP1VIVH0D51@04Y:BP1A
DE40Cdm?055AD@1CDe<0DE5A05IFEP1DE5@0FEUI05MGE`1KFe/205eMG@0@05QHF01NGUh0GEeM05iN
GP1KFe/0EeMG05aLG01VIVH0J6QX06UYJ@1`L700MgMg07alO022PX80QHF508J6QP80Shn?00P0UIFE
09RHV02LW9`0W9bL09jNWP2JVYX0WIfM09jNWP80W9bL00D0WIfM09RHV02HV9P0VIVI09RHV00209ZJ
VP0>09bLW02IVIT0U9BD09FEU@2CTi<0RHV908J6QP1mOGd0LW9b06IVIP1KFe/0Cdm?03Ti>@0/;2`2
02PX:00:034a<@0];Bd0?Cdm04];B`1EEED0HV9R06][J`1aLG40MGEe07YjNP<0QHF50100SXj>09>C
T`2BTY80TI6A09NGU`2EUID0UYJF09NGU`2?Shl0TY:B08n?S`2ATI40U9BD08n?S`2>SXh0TY:B0P2>
SXh03`2=SHd0TI6A092@T02>SXh0T92@08j>SP2@T900RXZ:08f=S@2EUID0TI6A092@T02DU9@0SXj>
096AT@0309>CT`0C09JFUP2HV9P0V9RH09FEU@2JVYX0Xj>S09^KV`2EUID0QHF506][J`19BDT0<c<c
02TY:@0`<300<C4a059BDP1FEUH0>c/k03hn?P0203Ti>@0402h^;P0[:b/0;2`/038b<P80=CDe00H0
<c<c03Lg=`0e=CD0<c<c03@d=00a<C4203Hf=P0=03Ph>00k>c/0=cLg034a<@0_;bl0;2`/02l_;`0]
;Bd0:BTY034a<@0d=3@0=SHf03Ph>00203Xj>P0Z03Ph>00f=SH0<S8b02/[:`0a<C40;Bd]030`<00h
>3P0=3@d030`<00^;Rh0>3Ph03lo?`0h>3P0?clo0492@P13@d<0Bd];04i>CP1:BTX0Bd];04E5A@1B
DU80G5aL06ATI01`L700NGUi08J6QP2?Shl0TY:B09BDU02CTi<0UIFE09^KV`2JVYX0V9RH08n?S`21
PH40QHF508V9R@2FUYH0Vi^K3P38h=P000`0b>3H0P28R8P01P26QXH0OGem079bLP1SHf<0Fe]K05UI
F@80De=C00H0EUIF05MGE`1EEED0FUYJ05UIF@1GEeL205YJFP0C05]KF`1GEeL0EUIF05UIF@1EEED0
FUYJ065QH@1ZJVX0L71`07UiN@1mOGd0RHV908f=S@2CTi<0V9RH09FEU@2MWId0Vi^K0:BTY0020:FU
Y@030:VYZ@2WYjL0Zj^[0080ZJVY0P2UYJD00`2WYjL0YZJV0:RXZ0020:FUY@0A0:NWY`2SXj<0WIfM
09^KV`2FUYH0Ti>C08n?S`29RHT0PX:20820P01dM7@0Kfm_06][J`1PH600FUYJ051@D01?Cdl00P19
BDT02P1=CDd0E5AD05QHF01NGUh0FUYJ05mOG`1MGEd0GUiN061PH01OGel2065QH@0905iNGP1MGEd0
I6AT06UYJ@1RHV80IfMW06QXJ01UIFD0H61P0080JVYZ00@0J6QX06MWI`1XJ6P0HV9R0P1VIVH01P1P
H600IfMW06EUI@1RHV80IVIV06UYJ@80KFe]01@0Kfm_071`L01ZJVX0JVYZ06][J`1`L700KVi^079b
LP1aLG40NGUi079bLP1cLg<0M7Ad07EeM@1^KVh0M7Ad07IfMP1bLW80NWYj07IfMP80OWin0P1mOGd0
1P1jNWX0Ng]k07QhN01iNGT0Lg=c07alO080NGUi00h0MWIf07EeM@1lO7`0O7al0861P@22PX80Ng]k
07AdM01XJ6P0Kfm_06][J`1WIfL0JVYZ06m_K`80JFUY0340L71`06YZJP1[Jf/0M7Ad06m_K`1aLG40
M7Ad075aL@1[Jf/0MWIf07UiN@1mOGd0NWYj07QhN01aLG40MGEe07MgM`1bLW80KVi^07IfMP1mOGd0
MgMg06m_K`1aLG40Lg=c079bLP1]KFd0N7Qh07YjNP1lO7`0MWIf07MgM`1kNg/0OGem0861P@28R8P0
Ogmo07]kN`1bLW80OGem08^;R`28R8P0QHF508V9R@2BTY80RXZ:07moO`22PX80QXJ60080TI6A00T0
Rh^;08V9R@2=SHd0TY:B096AT@2>SXh0Rh^;08j>SP2<S8`00P2BTY80502?Shl0Rh^;09RHV02FUYH0
VYZJ09:BTP2<S8`0Ti>C096AT@2CTi<0UYJF09^KV`2JVYX0YJFU0:RXZ02GUiL0UIFE0:FUY@2/[:`0
/k>c0P2m_Kd00`2/[:`0[Jf]0;Bd]0020;:b/P0=0<30`02o_kl0/K6a09nOW`2NWYh0Vi^K09RHV02P
X:00[Jf]0;Fe]@34a<@0clo?0=3@d0020<o?c`040=3@d03Hf=P0emOG0=3@d080clo?00X0bl_;0<W9
b@38b<P0bl_;0<k>cP3@d=00dM7A0=3@d036a/H0alO70`3@d=020<k>cP0>0<o?c`3=cLd0clo?0<k>
cP3;bl/0bLW90<k>cP3@d=00dM7A0<k>cP3:b/X0c<c<0<o?c`3Bd]820=7Ad@050=GEe@3Hf=P0e=CD
0=OGe`3Kfm/00P3Ng]h0303Rh^80hN7Q0=kNgP3Jf]X0gMgM0=SHf02`/;00L71`05ADE01>CTh0Cdm?
051@D080E5AD00<0FEUI05]KF`1JFUX00P1IFET01P1JFUX0IVIV06ATI01RHV80I6AT05mOG`80HF5Q
01<0GUiN05mOG`1RHV80GemO06IVIP1XJ6P0L71`07=cL`1mOGd0PH6108J6QP29RHT0RXZ:096AT@2E
UID0V9RH09VIV@2LW9`0WYjN0080VYZJ00D0W9bL09ZJVP2MWId0VIVI09NGU`0209VIV@0709RHV02G
UiL0V9RH09FEU@2GUiL0UIFE092@T00208V9R@0E0820P01lO7`0Lg=c06EUI@1MGEd0DE5A03Ti>@0c
<c<0:BTY02XZ:P0];Bd0=3@d04=3@`1<C4`0Fe]K06IVIP1/K6`0LG5a07YjNP1oOgl0QXJ60080RHV9
00@0TY:B09FEU@2DU9@0T92@0P2GUiL0102CTi<0TI6A08n?S`2>SXh3096AT@0A08n?S`2ATI40Shn?
08n?S`2>SXh0RXZ:092@T02?Shl0S8b<092@T02ATI40U9BD08j>SP2ATI40SHf=09>CT`2BTY800P2A
TI401P2?Shl0U9BD09>CT`2CTi<0V9RH096AT@80UiNG01/0W9bL09ZJVP2LW9`0Vi^K092@T01nOWh0
IVIV04I6AP0`<300:RXZ02LW9`0l?3`0?Cdm04U9B@16ATH0>c/k02TY:@0/;2`0:RXZ02/[:`0];Bd0
=3@d03/k>`0f=SH0?clo03Lg=`0e=CD00P0f=SH02P0h>3P0>CTi03/k>`0a<C40=cLg03@d=00f=SH0
;bl_02d];@0c<c<202h^;P0302`/;00h>3P0=cLg0080>CTi01h0?Cdm03<c<`0e=CD0;bl_03<c<`0Z
:RX0;2`/02d];@0`<300;Bd]02TY:@0g=cL0?clo03Ti>@0k>c/0>SXj03`l?015ADD0CDe=04i>CP1;
Bd/0Cdm?055AD@1@D500FUYJ06ATI01cLg<0PX:208F5Q@2ATI4209FEU@0:09RHV02GUiL0VYZJ09FE
U@2;Rh/0QhN70820P027QhL0U9BD09VIV@h0b>3H000<0<SPf080Shn?00l0Rh^;08:2PP1kNg/0LW9b
06EUI@1IFET0EEEE04m?C`1FEUH0F5QH05MGE`1HF5P0Fe]K05EEE@1KFe/00P1HF5P0301CDe<0EUIF
05QHF01EEED0G5aL05mOG`1ZJVX0KVi^07]kN`21PH40SHf=08j>SP80UIFE00T0UYJF0:6QX@2OWil0
XZ:R0:JVYP2UYJD0Z:RX0:FUY@2YZJT00P2ZZZX00`2VYZH0Xj>S0:JVYP020:NWY`80YZJV01P0YJFU
0:2PX02OWil0Vi^K09NGU`2CTi<0UIFE08V9R@22PX80Ph>307AdM01aLG40JVYZ05mOG`1FEUH0E5AD
04i>CP1;Bd/0BTY:04e=C@1BDU80F5QH05EEE@1HF5P205aLG00/05UIF@1QHF40HF5Q06=SH`1QHF40
H61P05iNGP1VIVH0H61P065QH@1UIFD0KFe]06EUI@1PH600IfMW06=SH`1]KFd0IVIV06MWI`1ZJVX0
I6AT06EUI@1WIfL0HF5Q06MWI`1RHV80IfMW06ATI01/K6`0Jf][06m_K`1aLG40JVYZ06m_K`1^KVh0
JFUY06m_K`1fMWH0L71`07MgM`1iNGT0L71`07=cL`1eMGD207IfMP80M7Ad00@0MgMg07YjNP1hN7P0
MWIf0P1jNWX207QhN00707alO01kNg/0OWin07emO@1kNg/0MgMg07UiN@0307]kN`1808F5Q@20P800
P82007MgM`1]KFd0K6a/07=cL`1`L700IVIV06m_K`1VIVH0IfMW075aL@1/K6`0Kfm_071`L01cLg<0
MGEe07=cL`1fMWH0K6a/071`L01]KFd0NWYj07AdM01gMgL0NGUi07EeM@1gMgL0LG5a07=cL`1]KFd0
LG5a0820P01kNg/0K6a/07=cL`1oOgl0M7Ad071`L01aLG40MWIf07MgM`1cLg<0NWYj0861P@1mOGd0
O7al08F5Q@28R8P0Ogmo07AdM026QXH0QhN708j>SP25QHD0QXJ6092@T028R8P0RHV907alO020P800
SXj>08f=S@2BTY80Ogmo08N7Q`2;Rh/0TI6A09NGU`26QXH0QHF50P2;Rh/00`2?Shl0SHf=08^;R`02
09JFUP0409VIV@2>SXh0Q8B4096AT@80VIVI01D0UiNG08^;R`2NWYh0Xj>S0:VYZ@2TY:@0V9RH0:BT
Y02][Jd0/;2`0;Rh^02i^KT0/[:b0:ZZZP2^[Zh0[jn_0;Rh^02n_[h0`<300:f][@2UYJD00P2OWil0
1P2PX:00VYZJ0:FUY@2h^;P0`l?30<O7a`80bl_;00<0e=CD0=OGe`3De=@00P3De=@03P3?cll0c/k>
0<o?c`3>c/h0d=3@0<k>cP3=cLd0clo?0<[:bP37alL0clo?0=3@d03Bd]80clo?0P3=cLd01`3?cll0
c/k>0=7Ad@39bLT0b/[:0<k>cP3?cll00P3>c/h0303@d=00c<c<0=;BdP3EeMD0d=3@0<g=c@3<c<`0
e=CD0=KFeP3AdM40e=CD0=SHf080hN7Q01<0i>CT0=oOg`3Lg=`0g]kN0=WIf@35aLD0U9BD05aLG01:
BTX0DU9B04e=C@1?Cdl0EEEE05QHF01FEUH0EeMG05aLG01RHV80GemO0080GUiN02H0GEeM05iNGP1M
GEd0GemO05iNGP1QHF40GemO069RHP1WIfL0H61P06QXJ01^KVh0LG5a07AdM01iNGT0Ogmo08J6QP29
RHT0SXj>09>CT`2FUYH0V9RH09VIV@2KVi/0V9RH09^KV`2JVYX0W9bL09^KV`2LW9`0VYZJ09RHV02E
UID0UYJF09FEU@2JVYX0UiNG09FEU@80U9BD01P0TI6A08F5Q@24Q8@0OGem07]kN`1]KFd0Jf][05=C
D`19BDT0@41003@d=00^;Rh0<30`03De=@0k>c/0AdM705MGE`1PH600K6a/079bLP1gMgL0P82008F5
Q@29RHT208j>SP0?092@T02DU9@0U9BD09NGU`2HV9P0UIFE09:BTP2@T900TY:B08n?S`2EUID0TI6A
08n?S`2DU9@0TY:B0080Shn?0180TI6A08j>SP2?Shl0Shn?09:BTP2?Shl0TI6A092@T02?Shl0Ti>C
092@T02DU9@0UIFE096AT@2@T900Rh^;092@T02EUID3096AT@0409>CT`2FUYH0UYJF09ZJVP80W9bL
01h0VIVI08f=S@20P800FUYJ03dm?@0b<S80=CDe02`/;00W9bL0<C4a02TY:@0W9bL09RHV02`/;00^
;Rh0:b/[034a<@0^;Rh0=CDe03/k>`0m?Cd0>SXj03<c<`0e=CD0>CTi030`<00m?Cd0=3@d03Hf=P0h
>3P2038b<P0402l_;`0];Bd0<30`02h^;P80:b/[0180=CDe03`l?00n?Sh0?Shn03/k>`0j>SX0=3@d
03<c<`0b<S80;2`/02d];@0c<c<0<30`03<c<`0`<300?Shn03Hf=P0j>SX203`l?00J03hn?P11@D40
AdM704=3@`1;Bd/0D51@04U9B@1:BTX0CDe=05QHF01XJ6P0Lg=c07moO`29RHT0T92@09JFUP2IVIT0
UiNG09bLW02DU9@0SXj>08f=S@29RHT0R8R808f=S@2?Shl>0<SPf0003038h=P209:BTP0=08n?S`23
Ph<0O7al079bLP1ZJVX0GemO05YJFP1GEeL0D51@055AD@1GEeL0FEUI05MGE`0205]KF`0>05UIF@1L
G5`0De=C05=CD`1?Cdl0EEEE05]KF`1TI6@0JFUY06e]K@1nOWh0PH6108R8R02=SHd209FEU@0909jN
WP2OWil0Xj>S0::RXP2XZ:P0YZJV0:NWY`2/[:`0YZJV0080YjNW00D0YZJV0:VYZ@2RXZ80ZJVY0:FU
Y@020:VYZ@0@0:BTY02RXZ80WIfM09^KV`2JVYX0Ti>C08b<S029RHT0QXJ608:2PP1lO7`0LW9b06YZ
JP1PH600FEUI05QHF080CTi>00l0B4Q804e=C@1>CTh0DE5A05ADE01GEeL0GUiN05mOG`1JFUX0GemO
05iNGP1QHF40G5aL061PH01NGUh00P1QHF403P1VIVH0I6AT06MWI`1WIfL0J6QX06MWI`1YJFT0J6QX
06MWI`1RHV80IVIV06QXJ01WIfL0HV9R0P1WIfL04P1VIVH0JFUY06ATI01[Jf/0LG5a06a/K01[Jf/0
K6a/06m_K`1cLg<0J6QX06][J`1aLG40Kfm_07AdM01bLW80Lg=c07AdM080MGEe00D0Lg=c06i^KP1g
MgL0MGEe07MgM`0207YjNP80NGUi0180MGEe07QhN01jNWX0NWYj07IfMP1kNg/0N7Qh07UiN@21PH40
MgMg07emO@1kNg/0OWin0861P@25QHD0O7al07EeM@1dM7@206i^KP0506e]K@1aLG40K6a/06UYJ@1_
Kfl00P1XJ6P0101bLW80Kfm_075aL@1dM7@206i^KP0@07QhN01`L700KFe]07MgM`21PH40NGUi07al
O01kNg/0Lg=c07QhN01cLg<0M7Ad07YjNP23Ph<0OGem07EeM@80LW9b00<0N7Qh07=cL`1_Kfl00P1e
MGD0301fMWH0OWin08F5Q@1jNWX0Ng]k08F5Q@24Q8@0OGem07inOP21PH40PX:208^;R`<0RHV900d0
SXj>08^;R`20P800OWin08V9R@2:RXX0R8R808>3P`1mOGd0T92@09JFUP2>SXh0Q8B400<0SHf=00@0
SXj>08n?S`27QhL0S8b<0`2JVYX08`2>SXh0VYZJ0::RXP2PX:00UYJF09ZJVP2SXj<0YjNW0:n_[`2`
/;00YZJV0:>SX`2[Zj/0][Jf0;>c/`2l_;`0^KVi0;:b/P2WYjL0/K6a0;Rh^02m_Kd0`L710;Zj^P2a
/K40ZZZZ0;2`/02XZ:P0W9bL09VIV@2][Jd0_kno0<;2`P3:b/X0d];B0080dM7A00L0emOG0=GEe@3C
dm<0e=CD0=OGe`3De=@0clo?0080cLg=0P38b<P01`3;bl/0c/k>0=7Ad@3@d=00cLg=0<c<c03>c/h0
0P3@d=001P3<c<`0bl_;0<g=c@3>c/h0clo?0<g=c@80d=3@00H0eMGE0=CDe03Cdm<0c/k>0<W9b@3?
cll20=CDe0030=;BdP3Fe]H0fm_K00<0hN7Q00l0gmoO0=gMg@3IfMT0a/K609ZJVP1XJ6P0DE5A04a<
C01=CDd0E5AD05IFEP1ADE40Fe]K05aLG01KFe/00P1QHF405P1RHV80HF5Q05mOG`1RHV80I6AT05eM
G@1UIFD0HV9R061PH01NGUh0G5aL061PH01VIVH0JFUY06a/K01dM7@0MGEe07alO01oOgl0R8R808^;
R`2>SXh209FEU@0409ZJVP2LW9`0WIfM09VIV@80VYZJ01T0UiNG09^KV`2LW9`0V9RH09VIV@2JVYX0
W9bL09BDU02FUYH0V9RH09BDU02ATI40UYJF09:BTP2:RXX0QXJ608:2PP1lO7`0LG5a06IVIP1HF5P0
ATI603`l?00c<c<0;Rh^0080>3Ph00X0@D51059BDP1GEeL0IFEU07EeM@1dM7@0Ng]k08:2PP2<S8`0
RHV90P2>SXh01@2BTY80V9RH09:BTP2HV9P0UiNG0080Ti>C00`0Shn?096AT@2@T900TY:B08n?S`2B
TY80Shn?09BDU02BTY80Shn?08j>SP2=SHd2092@T00708j>SP2ATI40SXj>092@T02=SHd0T92@08j>
SP02092@T00509:BTP2<S8`0SXj>09:BTP2>SXh00`2ATI401@2DU9@0VIVI09BDU02LW9`0VYZJ0080
W9bL01`0UiNG08f=S@1`L700D51@03@d=00X:2P0;2`/02LW9`0V9RH0:b/[02l_;`0c<c<09bLW02d]
;@0Y:BT0:b/[034a<@0^;Rh0<30`03De=@0l?3`0>c/k03`l?00d=3@0=CDe03Xj>P0e=CD0>SXj0P0h
>3P02@0f=SH0<S8b03@d=00a<C40:RXZ034a<@0W9bL0;Rh^038b<P0203/k>`0F03Ti>@0n?Sh0=CDe
034a<@0_;bl0:RXZ02`/;00U9BD0:2PX02`/;00^;Rh0;Bd]03De=@14A4@0@D5103lo?`0m?Cd0ATI6
04M7A`14A4@0Bd];05EEE@80Bd];0100@d=3055AD@1JFUX0Jf][07alO01oOgl0SHf=09BDU02FUYH0
VIVI09RHV02DU9@0Shn?08f=S@2?Shl0SXj>0P2=SHd>0<SPf0003038h=P209JFUP0Q09>CT`2=SHd0
Q8B407alO01bLW80JFUY05QHF01DE5@0De=C059BDP1GEeL0FUYJ05MGE`1KFe/0FEUI05]KF`1NGUh0
FEUI05IFEP1CDe<0FUYJ05iNGP1RHV80Jf][07AdM01kNg/0P82008F5Q@28R8P0T92@09NGU`2HV9P0
XZ:R0080Y:BT00D0YJFU0:BTY02YZJT0ZZZZ0:JVYP020:BTY0090:VYZ@2VYZH0Y:BT0::RXP2VYZH0
YjNW0:FUY@2TY:@0XJ6Q0080WinO0P2FUYH04@2@T900RXZ:08F5Q@20P800O7al07AdM01]KFd0HV9R
05]KF`1CDe<0CTi>04a<C01CDe<0DE5A059BDP1CDe<0GEeM0080FUYJ00D0G5aL05mOG`1LG5`0HF5Q
05iNGP02069RHP0506ATI01PH600IFEU06IVIP1TI6@00P1UIFD06@1OGel0Hf=S06][J`1UIFD0Jf][
06MWI`1UIFD0Hf=S06ATI01QHF40Hf=S06IVIP1TI6@0IFEU06MWI`1VIVH0KFe]06i^KP1]KFd0Jf][
06m_K`1/K6`0KVi^07AdM01_Kfl00P1dM7@02@1`L700LG5a07=cL`1dM7@0MgMg06i^KP1bLW80NGUi
07EeM@0207IfMP0:07UiN@1kNg/0Ng]k07QhN01eMGD0N7Qh07=cL`1kNg/0NWYj07IfMP80Ogmo00<0
Ng]k07alO01iNGT00P1mOGd0?P1kNg/0OWin07inOP1mOGd0LW9b071`L01[Jf/0JVYZ06UYJ@1UIFD0
K6a/06MWI`1[Jf/0LW9b07=cL`1`L700MWIf07EeM@1aLG40NWYj07IfMP1[Jf/0KFe]07alO01kNg/0
Ogmo07alO01fMWH0NWYj07=cL`1mOGd0NWYj07MgM`1iNGT0NWYj07=cL`1[Jf/0MGEe07emO@1dM7@0
KFe]07IfMP1gMgL0NGUi07IfMP1oOgl0PH6107emO@24Q8@0RXZ:08^;R`20P800MgMg08b<S02ATI40
TY:B08R8R024Q8@0Shn?08V9R@2<S8`0RHV90P28R8P01P2>SXh0R8R80820P02?Shl0TY:B09RHV080
T92@01l0RXZ:092@T02ATI40TI6A08>3P`27QhL0VYZJ09JFUP2LW9`0UIFE09ZJVP2NWYh0W9bL0:BT
Y02UYJD0Y:BT0:f][@2`/;00];Bd0:j^[P2b/[80/k>c0:n_[`2e]KD0]kNg0;jn_P2c/k<0[Jf]0;6a
/@2f][H0^[Zj0080`<3000/0_kno0;^k^`2ZZZX0WinO09bLW02PX:00YZJV0:n_[`2m_Kd0alO70<W9
b@040=CDe080f=SH0`3AdM40303<c<`0aLG50<_;b`3;bl/0c<c<0=3@d03>c/h0d=3@0=7Ad@3@d=00
d];B0<g=c@80c<c<00@0d=3@0<c<c03<c<`0clo?0P3De=@02P3Fe]H0dm?C0<_;b`3>c/h0dm?C0=OG
e`3Hf=P0e]KF0=SHf03Ng]h30=oOg`0A0=gMg@3Ng]h0fMWI0<O7a`2QXJ40KFe]04e=C@1;Bd/0DE5A
051@D01DE5@0F5QH05]KF`1JFUX0GEeM061PH01VIVH00P1QHF401`1RHV80Hf=S06EUI@1OGel0G5aL
06=SH`1QHF400P1NGUh0401KFe/0HV9R06EUI@1VIVH0KFe]079bLP1dM7@0Ng]k0820P024Q8@0RHV9
08n?S`2@T900UYJF09FEU@2JVYX209VIV@0609bLW02IVIT0U9BD09NGU`2IVIT0V9RH0P2IVIT209ZJ
VP0M09^KV`2HV9P0UIFE09:BTP2@T900SHf=08j>SP2:RXX0P82007]kN`1/K6`0HF5Q055AD@13@d<0
?3`l03Ph>00_;bl0<c<c03Xj>P1>CTh0FEUI069RHP1_Kfl0MGEe07UiN@2:RXX0Ph>308Z:RP2>SXh0
0P2@T900302GUiL0UYJF09FEU@2FUYH0Ti>C09:BTP2CTi<0Shn?096AT@2?Shl0TY:B092@T080Ti>C
00H0T92@08b<S02?Shl0Rh^;092@T02CTi<2096AT@0908j>SP2ATI40T92@08f=S@2>SXh0Shn?09>C
T`2?Shl0SHf=0080S8b<0`2?Shl0202@T900TI6A09:BTP2DU9@0Ti>C09^KV`2HV9P0VYZJ0P2NWYh0
1`2BTY80QhN706e]K@18B4P0=CDe02`/;00a<C400P0V9RH0100W9bL0:b/[02TY:@0X:2P302TY:@0A
02`/;00b<S80;bl_03Lg=`0j>SX0?3`l03@d=00h>3P0<C4a02l_;`0g=cL0>3Ph038b<P0c<c<0>SXj
03@d=00b<S800P0^;Rh202PX:00Y034a<@0h>3P0>3Ph03<c<`0f=SH0>c/k03@d=00g=cL0;Bd]030`
<00];Bd0;Rh^02/[:`0/;2`0<30`02h^;P0h>3P0?3`l04M7A`15ADD0D51@04=3@`11@D40A4A405IF
EP18B4P0@T9204E5A@13@d<0C4a<05YJFP1YJFT0MWIf08:2PP2=SHd0TI6A09^KV`2GUiL0U9BD09:B
TP2@T9000P2BTY800`2FUYH0TI6A0<SPf00=0<SPf0003038h=P209FEU@0:09BDU02@T900RXZ:0820
P01dM7@0KVi^06EUI@1HF5P0Cdm?055AD@80EEEE00@0EUIF05MGE`1IFET0H61P0P1GEeL04@1DE5@0
DE5A05aLG01LG5`0FEUI06EUI@1`L700MWIf0820P02;Rh/0Shn?09:BTP2HV9P0VYZJ0:6QX@2PX:00
Y:BT00<0ZJVY00H0YjNW0:ZZZP2[Zj/0Zj^[0:ZZZP2YZJT20:NWY`0K0:JVYP2UYJD0YZJV0::RXP2W
YjL0WIfM09ZJVP2KVi/0UYJF092@T02<S8`0QXJ60861P@1hN7P0Lg=c06YZJP1QHF40FUYJ05EEE@1@
D500C4a<05EEE@1;Bd/0DE5A05MGE`1LG5`0F5QH0080GEeM00@0F5QH05aLG01LG5`0Fe]K0P1QHF40
3@1UIFD0HV9R065QH@1VIVH0Hf=S065QH@1UIFD0HV9R06=SH`1VIVH0KFe]06QXJ01WIfL00P1UIFD0
2`1WIfL0I6AT069RHP1UIFD0IVIV06MWI`1VIVH0JFUY06a/K01YJFT0K6a/0080JVYZ00@0KVi^075a
L@1_Kfl0L71`0P1aLG40301dM7@0LW9b079bLP1eMGD0M7Ad079bLP1cLg<0MGEe07=cL`1eMGD0MWIf
07MgM`80NGUi00H0N7Qh07YjNP1iNGT0OGem07MgM`1iNGT207]kN`0<07alO01iNGT0OGem08F5Q@1j
NWX0Ng]k07emO@1oOgl0PH6108:2PP1eMGD0M7Ad0P1YJFT04@1ZJVX0IVIV06e]K@1/K6`0JFUY079b
LP1[Jf/0LW9b071`L01kNg/0LG5a07UiN@1eMGD0LG5a071`L01cLg<0LW9b0080Ogmo02/0NGUi07in
OP1iNGT0Lg=c07YjNP1kNg/0MGEe07alO01iNGT0N7Qh07EeM@1hN7P0OGem07EeM@1aLG40Kfm_07Yj
NP21PH40O7al08>3P`27QhL0Q8B40861P@23Ph<0R8R807moO`1nOWh0R8R808f=S@2EUID0Ph>30861
P@29RHT0SXj>08n?S`23Ph<0QhN708R8R02?Shl0PH6108:2PP2:RXX0SHf=0080Ti>C01T0QXJ608N7
Q`2<S8`0TY:B096AT@22PX80TY:B09^KV`2MWId0YjNW09BDU02EUID0WIfM0:FUY@2[Zj/0WYjN09fM
W@2][Jd0[:b/0;fm_@34a<@0]KFe0:NWY`2UYJD0/K6a0080_;bl02D0_kno0;Jf]P2k^k/0/k>c0;^k
^`32`/80`L710<?3``2h^;P0YJFU09nOW`2[Zj/0ZJVY0:FUY@2YZJT0]KFe0;jn_P39bLT0cLg=0<o?
c`3@d=00fm_K0=SHf03Bd]80emOG0=;BdP3Cdm<0clo?0<k>cP3<c<`0dM7A0=3@d03?cll0d=3@0=CD
e03Cdm<0d=3@00<0clo?00@0c<c<0<g=c@3@d=00d];B0P3De=@02`3Cdm<0bl_;0<_;b`3>c/h0eMGE
0=OGe`3Kfm/0emOG0>3Ph03Rh^80hN7Q0080gmoO00T0hN7Q0>3Ph03Bd]80Z:RX06e]K@1GEeL0BTY:
051@D01?Cdl00P1FEUH05@1QHF40FUYJ05eMG@1SHf<0H61P069RHP1OGel0GUiN05mOG`1RHV80JVYZ
06IVIP1NGUh0HV9R065QH@1MGEd0HV9R05UIF@1PH600I6AT06UYJ@02071`L00;079bLP1mOGd0PH61
08F5Q@2;Rh/0SHf=09:BTP2GUiL0VYZJ09RHV02PX:000`2JVYX209RHV00E09bLW02KVi/0VYZJ09ZJ
VP2KVi/0UiNG09ZJVP2IVIT0UiNG096AT@2BTY80SXj>08^;R`24Q8@0PH6107MgM`1VIVH0HF5Q04m?
C`11@D40=CDe0080>CTi00`0>c/k0492@P1FEUH0GEeM079bLP1`L700NWYj07emO@25QHD0R8R808^;
R`2?Shl209>CT`@0U9BD00H0TI6A08n?S`2ATI40Shn?096AT@2@T90209:BTP0409BDU02FUYH0T92@
08f=S@80SXj>00D0SHf=096AT@2FUYH0TY:B08^;R`0408n?S`0;096AT@2EUID0UIFE092@T02>SXh0
TY:B096AT@2>SXh0Shn?09FEU@2=SHd00P2ATI402`2CTi<0U9BD09RHV02JVYX0WIfM09jNWP2KVi/0
T92@0820P01NGUh0>3Ph0080:RXZ0P0T92@06P0V9RH0:2PX02TY:@0V9RH0:BTY02LW9`0U9BD0;Rh^
02TY:@0_;bl0;Bd]03@d=00b<S80=CDe03lo?`0c<c<0@T9203Hf=P0h>3P0=CDe03Ti>@0g=cL0=CDe
03<c<`0/;2`0:BTY0P0V9RH01P0^;Rh0<S8b038b<P0d=3@0=SHf03De=@80>3Ph01@0;Rh^030`<00^
;Rh0:BTY03De=@0h>3P0;2`/03<c<`0k>c/0@T9204e=C@19BDT0?3`l03lo?`12@T80ADE505=CD`1K
Fe/0?Cdm04M7A`80?3`l00l0BDU9051@D01WIfL0N7Qh08B4Q02=SHd0TI6A09RHV02GUiL0TI6A09>C
T`2BTY80Ti>C09FEU@2MWId03P38h=P000`0b>3H0P2JVYX04`2FUYH0U9BD08j>SP29RHT0OWin07If
MP1YJFT0GUiN05IFEP1ADE40D51@05=CD`1GEeL0FEUI05IFEP1EEED0Fe]K05=CD`1HF5P00P1FEUH0
4`1LG5`0GemO06MWI`1`L700MWIf07emO@29RHT0SXj>08n?S`2GUiL0Vi^K09jNWP2RXZ80Y:BT0:NW
Y`2YZJT0YjNW0:VYZ@2/[:`00P2WYjL01P2ZZZX0YjNW0:NWY`2WYjL0Y:BT0:NWY`80Y:BT02/0XJ6Q
09fMW@2KVi/0VIVI09BDU02?Shl0S8b<08V9R@1lO7`0MGEe075aL@1YJFT0IFEU05eMG@1GEeL0De=C
04];B`1?Cdl0DE5A05=CD`1FEUH0E5AD05MGE`1IFET0GUiN05eMG@1OGel0Hf=S05mOG`1MGEd0Hf=S
06ATI01SHf<0IVIV065QH@1WIfL0GUiN069RHP1UIFD0GEeM06EUI@1ZJVX0Kfm_0080J6QX00<0JFUY
06EUI@1XJ6P00P1VIVH01P1QHF40JVYZ06i^KP1WIfL0JFUY06e]K@80KVi^00L0L71`06m_K`1bLW80
L71`07=cL`1fMWH0MGEe0080Lg=c00X0Kfm_07EeM@1fMWH0Lg=c07EeM@1iNGT0Lg=c07EeM@1fMWH0
OWin0P1cLg<05`1gMgL0NWYj07YjNP1mOGd0MgMg07UiN@1jNWX0N7Qh07inOP1kNg/0O7al07emO@1n
OWh0P82007]kN`1hN7P0PX:208B4Q01mOGd0MgMg06i^KP1UIFD0K6a/0080KFe]02l0IfMW075aL@1a
LG40JFUY06e]K@1^KVh0KFe]06a/K01dM7@0OGem07=cL`1hN7P0NGUi07IfMP1]KFd0O7al07inOP22
PX80O7al07emO@1dM7@0N7Qh07moO`1lO7`0Ng]k07emO@1hN7P0O7al079bLP1hN7P0P82007=cL`1[
Jf/0PX:207inOP21PH40Ogmo08:2PP25QHD0Ng]k08B4Q026QXH0PH6108N7Q`22PX80U9BD08j>SP02
08F5Q@0:08R8R02;Rh/0U9BD07emO@1kNg/0S8b<08j>SP25QHD0OWin08F5Q@80UiNG01@0Shn?08N7
Q`24Q8@0RXZ:09:BTP2EUID0SHf=08j>SP2GUiL0YJFU0:VYZ@2FUYH0VIVI0:JVYP2WYjL0[Zj^0:VY
Z@2TY:@0ZZZZ0;Bd]080`<3000D0^[Zj0;6a/@2ZZZX0^KVi0;bl_0020;no_`80a<C402@0^k^k0;fm
_@2l_;`0_kno0;jn_P2k^k/0]KFe0:j^[P2YZJT0[Zj^0:f][@2ZZZX0ZJVY0;>c/`2m_Kd0a<C40<O7
a`3@d=00dm?C0=CDe03EeMD0dm?C0=OGe`3@d=00d];B0=7Ad@3@d=00dM7A0<k>cP3@d=00d];B0=7A
d@3=cLd0d];B0=7Ad@3?cll20=3@d00?0=7Ad@3Cdm<0e]KF0<k>cP3=cLd0c/k>0=3@d03Cdm<0f=SH
0=WIf@3Fe]H0g=cL0>7Qh@3Rh^80g]kN00<0h^;R01T0fMWI0;^k^`1gMgL0EEEE04m?C`1ADE40EeMG
05IFEP1GEeL0G5aL061PH01KFe/0G5aL05eMG@1VIVH0HV9R065QH@1TI6@0HV9R06EUI@1VIVH0IFEU
06=SH`1QHF40GemO00<0Hf=S00T0HV9R065QH@1YJFT0Jf][079bLP1aLG40Ogmo0861P@22PX800P2:
RXX02P2@T900V9RH09FEU@2IVIT0X:2P09bLW02NWYh0VIVI09RHV02GUiL209RHV00;09NGU`2NWYh0
W9bL09VIV@2HV9P0UiNG09JFUP2BTY80Shn?08j>SP2=SHd00P1oOgl01`1iNGT0JFUY05mOG`1CDe<0
AdM703Xj>P10@4000P0n?Sh02`1>CTh0FUYJ06EUI@1]KFd0MgMg07moO`25QHD0Ph>308b<S02?Shl0
T92@00D0Ti>C00D0TI6A09NGU`2?Shl0S8b<092@T00209FEU@0;09:BTP2GUiL0TI6A09>CT`2?Shl0
T92@08n?S`2BTY80T92@09>CT`2>SXh00P2=SHd0102>SXh0Shn?08n?S`2=SHd209>CT`0>092@T02>
SXh0S8b<09BDU02?Shl0SXj>09:BTP2EUID0TY:B09BDU02FUYH0W9bL09NGU`2HV9P209ZJVP0>09bL
W02NWYh0UiNG08^;R`1dM7@0EEEE03Hf=P0[:b/0:RXZ02@T900Y:BT0:RXZ02`/;00X:2P202TY:@03
02PX:00/;2`0:b/[0080;Rh^00X0?3`l03Ph>00d=3@0?3`l03Hf=P0g=cL0>CTi03Ph>00b<S80=SHf
0P0g=cL203@d=080;Rh^00@09BDU02XZ:P0];Bd0;Bd]0P0c<c<0300e=CD0=cLg03/k>`0h>3P0<c<c
038b<P0Y:BT0;2`/02h^;P0[:b/0;bl_02h^;P<0=3@d01T0<c<c03lo?`0m?Cd0ATI604m?C`1BDU80
D51@04=3@`10@400>3Ph03dm?@1;Bd/0Fe]K06YZJP1gMgL0QXJ608b<S02EUID0UYJF09:BTP2EUID0
UYJF09RHV02EUID0XJ6Q00h0b>3H000<0<SPf0<0VIVI02@0UYJF092@T02?Shl0Ph>307alO01eMGD0
IVIV061PH01IFET0Cdm?04a<C01FEUH0DU9B05QHF01DE5@0EEEE05IFEP1EEED0FEUI05QHF01KFe/0
HV9R06i^KP1cLg<0OGem07inOP22PX80SHf=09FEU@2GUiL0VYZJ09bLW02NWYh0YJFU0:JVYP2WYjL2
0:VYZ@0H0:RXZ02YZJT0ZJVY0:ZZZP2WYjL0YZJV0:NWY`2XZ:P0YjNW0:>SX`2RXZ80X:2P09bLW02K
Vi/0VYZJ09BDU02>SXh0SHf=08F5Q@1mOGd0MWIf06e]K@1aLG40J6QX0P1CDe<01`19BDT0B4Q804Y:
BP19BDT0CTi>05EEE@1HF5P00`1LG5`0101TI6@0GemO05mOG`1OGel206ATI080HV9R00P0IfMW05eM
G@1VIVH0Hf=S06QXJ01SHf<0H61P06ATI0<0JVYZ00D0IFEU06=SH`1OGel0Hf=S06QXJ00206=SH`0=
06QXJ01VIVH0I6AT06=SH`1WIfL0L71`06m_K`1`L700Kfm_06i^KP1aLG40MgMg07EeM@02071`L00;
07=cL`1aLG40O7al07AdM01`L700Lg=c07IfMP1kNg/0LG5a07UiN@1hN7P00P1iNGT03@1lO7`0Ng]k
07MgM`1lO7`0Lg=c07UiN@1jNWX0OGem07moO`1jNWX0NGUi07moO`1lO7`00P1iNGT02`1kNg/0Ph>3
0861P@2:RXX0OGem075aL@1`L700KFe]06i^KP1ZJVX0I6AT0080KVi^00h0L71`06m_K`1]KFd0L71`
07MgM`1fMWH0O7al07YjNP1eMGD0LW9b07MgM`1dM7@0LW9b07IfMP80Ng]k0280N7Qh07UiN@1dM7@0
LG5a07QhN01jNWX0M7Ad07]kN`1jNWX0M7Ad06i^KP1jNWX0OGem07IfMP1dM7@0O7al07YjNP1fMWH0
OGem08B4Q025QHD0NWYj08J6QP29RHT0RXZ:08V9R@20P800UIFE08f=S@2:RXX0Q8B408b<S02ATI40
SHf=0P1kNg/208f=S@0308^;R`21PH40S8b<0080S8b<01@0SHf=08B4Q021PH40SHf=09FEU@2IVIT0
SHf=08N7Q`2IVIT0XZ:R09jNWP2GUiL0V9RH0:JVYP2][Jd0[:b/0;Fe]@2WYjL0ZZZZ0;6a/@80_Kfm
00h0`L710;Zj^P2m_Kd0]kNg0;2`/02m_Kd0_[jn0<K6aP38b<P0`/;20;Fe]@2c/k<0_Kfm0<;2`P80
_kno00D0^KVi0;Ng]`2a/K40Zj^[0:f][@020:ZZZP040:n_[`2d];@0`l?30<S8b080dM7A0P3De=@0
2P3?cll0eMGE0=CDe03EeMD0e=CD0=;BdP3AdM40c<c<0<o?c`3Bd]820=?Cd`070=3@d03?cll0d=3@
0=;BdP3Cdm<0d=3@0<[:bP020<o?c`090=?Cd`3GemL0f=SH0=SHf03Jf]X0h>3P0>7Qh@3Rh^80gmoO
0080i>CT0200h>3P0<[:bP2BTY80FEUI05=CD`1GEeL0DE5A05MGE`1FEUH0G5aL05eMG@1QHF40Hf=S
05eMG@1TI6@0IFEU069RHP1QHF40HV9R06EUI@1NGUh0I6AT069RHP1QHF40HV9R06EUI@1RHV80HF5Q
05aLG01QHF40IFEU06i^KP80Kfm_00D0MgMg07inOP20P800QHF508b<S002092@T00;09BDU02FUYH0
VIVI0:2PX02MWId0UiNG09ZJVP2FUYH0VIVI09ZJVP2IVIT00P2GUiL209VIV@0309^KV`2GUiL0UIFE
0080TI6A01P0SHf=08Z:RP25QHD0OWin07AdM01ZJVX0FUYJ05EEE@1CDe<0@41004A4A013@d<0AdM7
05=CD`1KFe/0Jf][07IfMP1kNg/0PH6108F5Q@27QhL0S8b<09>CT`2@T90209JFUP0709BDU02ATI40
V9RH09BDU02CTi<0SXj>096AT@0209>CT`0609FEU@2CTi<0U9BD096AT@2BTY80TI6A0P2=SHd02P2C
Ti<0SXj>09BDU02?Shl0SHf=092@T02=SHd0S8b<09>CT`2ATI4209:BTP0>092@T02>SXh0Rh^;096A
T@2?Shl0UIFE096AT@2@T900Ti>C09FEU@2CTi<0V9RH09BDU02GUiL209FEU@0<09fMW@2LW9`0VYZJ
09FEU@1oOgl0Jf][059BDP0b<S80<C4a02XZ:P0^;Rh092@T0`0S8b<04@0X:2P0:RXZ030`<00g=cL0
;2`/02d];@0a<C40=3@d03Lg=`0a<C40=3@d03Ph>00f=SH0=cLg02h^;P0a<C40>CTi00<0<30`00@0
<S8b034a<@0];Bd0:b/[0P0^;Rh0:P0e=CD0;2`/034a<@0a<C40=CDe034a<@0h>3P0<S8b034a<@0^
;Rh0;Bd]02l_;`0b<S80;Rh^034a<@0e=CD0<c<c03@d=00g=cL0?Shn04I6AP1:BTX0B4Q804a<C012
@T80@D510492@P0m?Cd0?clo04I6AP1BDU80IfMW07QhN02:RXX0SHf=09ZJVP2EUID0UYJF09ZJVP2F
UYH0WIfM09jNWPh0b>3H000<0<SPf080XZ:R02D0V9RH09^KV`2EUID0Shn?08Z:RP20P800MgMg075a
L@1RHV80H61P05ADE01?Cdl0De=C051@D01DE5@0G5aL05IFEP1BDU80C4a<05ADE01FEUH0EEEE05mO
G`1YJFT0LW9b07UiN@25QHD0QhN708j>SP2CTi<0UiNG09ZJVP2MWId0XZ:R0:6QX@2UYJD0ZJVY0080
Z:RX00X0YZJV0:ZZZP2ZZZX0YjNW0:ZZZP2XZ:P0YJFU0:>SX`2XZ:P0YJFU0P2PX:006@2QXJ40W9bL
09JFUP2DU9@0Shn?08Z:RP28R8P0Ng]k07MgM`1^KVh0JVYZ05eMG@1BDU80DE5A04Q8B01;Bd/0Cdm?
04U9B@1BDU80EEEE05QHF01KFe/0FEUI05mOG`1QHF401@1PH6002@1SHf<0JVYZ06IVIP1PH600IfMW
06EUI@1SHf<0H61P05iNGP0206MWI`0606=SH`1OGel0IVIV05mOG`1UIFD0I6AT0P1XJ6P206MWI`0I
06YZJP1WIfL0JVYZ06e]K@1_Kfl0LW9b06i^KP1hN7P0JVYZ07EeM@1bLW80Lg=c075aL@1`L700LG5a
079bLP1cLg<0Kfm_075aL@1bLW80N7Qh07IfMP1eMGD0NWYj07MgM`0207emO@0R07QhN01gMgL0N7Qh
07alO01jNWX0Ng]k07YjNP1mOGd0N7Qh07UiN@1jNWX0OGem07]kN`1lO7`0N7Qh0861P@1oOgl0OWin
08F5Q@1nOWh0NGUi07AdM01_Kfl0JVYZ06QXJ01ZJVX0K6a/075aL@1cLg<0KFe]06m_K`1`L700Kfm_
07AdM080N7Qh0180M7Ad07emO@1eMGD0OWin07IfMP1eMGD0K6a/07inOP1mOGd0NGUi07alO01oOgl0
Kfm_07AdM022PX80NGUi07MgM`1lO7`207=cL`0L07alO01oOgl0NGUi06a/K01^KVh0O7al0820P01k
Ng/0Q8B408:2PP24Q8@0Ogmo08^;R`2BTY80QHF507inOP25QHD0SXj>08N7Q`1kNg/0Q8B408f=S@29
RHT0PX:207moO`29RHT0SXj>08Z:RP80QhN700X0RXZ:08j>SP2>SXh0PX:208B4Q026QXH0UiNG09ZJ
VP27QhL0R8R80P2QXJ403`2UYJD0WYjN09bLW02VYZH0Xj>S0:b/[02e]KD0][Jf0;Zj^P2a/K40]kNg
0;^k^`2l_;`0`L710<;2`P020;>c/`090;Rh^02k^k/0`L710<K6aP32`/80]kNg0:j^[P2c/k<0^[Zj
0080`l?300l0a<C40;fm_@2c/k<0[Zj^0;>c/`2b/[80ZZZZ0:FUY@2^[Zh0_;bl0<G5a@3:b/X0bl_;
0=3@d03De=@00P3EeMD01P3GemL0eMGE0=CDe03AdM40cLg=0=7Ad@80d];B00<0dm?C0<o?c`3@d=00
0P3EeMD02P3Bd]80clo?0=7Ad@3Bd]80e]KF0=SHf03Fe]H0emOG0=[JfP3Ng]h30>;RhP0C0>7Qh@3L
g=`0g=cL0<g=c@2TY:@0IfMW04i>CP1@D500De=C05IFEP1IFET0Fe]K06=SH`1UIFD0H61P06ATI01U
IFD0HV9R06IVIP0306EUI@0@065QH@1SHf<0I6AT065QH@1SHf<0IFEU061PH01SHf<0GEeM05UIF@1L
G5`0IFEU06][J`1bLW80LG5a07=cL`80P8200P2:RXX0:@2=SHd0UYJF09FEU@2FUYH0U9BD09ZJVP2I
VIT0W9bL09VIV@2GUiL0V9RH09ZJVP2IVIT0Vi^K09JFUP2IVIT0UYJF09jNWP2JVYX0UIFE09:BTP2C
Ti<0SXj>08R8R027QhL0Ogmo07IfMP1/K6`0GUiN05EEE@1>CTh0D51@05=CD`1?Cdl0DU9B05MGE`1V
IVH0LG5a07AdM020P800Ph>30080RXZ:00<0TI6A08j>SP2ATI400P2LW9`0502ATI40Ti>C09>CT`2C
Ti<0Shn?08f=S@2CTi<0TY:B09FEU@2DU9@0UIFE092@T02?Shl0Ti>C08f=S@2@T900SHf=092@T02=
SHd0TY:B0P2>SXh208n?S`0408Z:RP2@T900Rh^;092@T080Ti>C00P0Vi^K096AT@2ATI40Shn?096A
T@2@T900TY:B092@T080TY:B00@0UYJF09:BTP2FUYH0U9BD0`2KVi/209bLW00909:BTP20P800J6QX
0451@@0d=3@0;Rh^034a<@0V9RH0:2PX00809bLW00@08b<S02HV9P0X:2P0:b/[0P0Y:BT0400[:b/0
<30`038b<P0`<300=cLg03Ti>@0f=SH0=CDe03Ph>00o?cl0=3@d038b<P0d=3@0<C4a02h^;P0_;bl2
02XZ:P<0;2`/01/0:2PX02l_;`0b<S80>CTi03De=@0l?3`0<S8b034a<@0/;2`09bLW02h^;P0b<S80
:b/[034a<@0];Bd0<C4a030`<00e=CD0>c/k0492@P13@d<0ADE504];B`11@D40C4a<04I6AP0k>c/0
0P0`<3002@14A4@0DU9B06e]K@1mOGd0QXJ6096AT@2EUID0V9RH09bLW00209jNWP030:2PX038h=P0
b>3H00`0b>3H000<0<SPf080Xj>S00`0WYjN09fMW@2HV9P0TI6A08Z:RP24Q8@0O7al07=cL`1YJFT0
H61P04m?C`1ADE4205=CD`06055AD@1BDU80EEEE05ADE01HF5P0DU9B0P1GEeL04P1NGUh0JVYZ06i^
KP1mOGd0Q8B408J6QP2?Shl0TI6A09NGU`2KVi/0WYjN0:6QX@2TY:@0ZJVY0:^[Z`2WYjL0YZJV0:NW
Y`80YZJV00L0[:b/0:ZZZP2WYjL0Y:BT0:RXZ02VYZH0Xj>S0080XZ:R00h0WYjN09fMW@2KVi/0UiNG
092@T02:RXX0RHV907moO`1kNg/0Lg=c06QXJ01KFe/0EeMG059BDP80CDe=00/0Bd];04e=C@1@D500
EUIF05UIF@1HF5P0Fe]K05mOG`1NGUh0GemO065QH@0205eMG@0506=SH`1VIVH0JVYZ075aL@1NGUh0
0P1RHV801@1XJ6P0IVIV05eMG@1VIVH0H61P0080Hf=S0P1TI6@03P1SHf<0IfMW06=SH`1XJ6P0IfMW
06][J`1XJ6P0JVYZ06i^KP1XJ6P0Jf][06m_K`1/K6`0KVi^101_Kfl03@1aLG40M7Ad07EeM@1aLG40
MWIf07EeM@1bLW80MWIf06m_K`1eMGD0MWIf07UiN@1hN7P0101gMgL09@1eMGD0NGUi07YjNP1kNg/0
O7al07inOP1cLg<0NGUi07=cL`1iNGT0OGem07alO01jNWX0OGem07YjNP1oOgl0Ng]k08J6QP20P800
Ng]k07IfMP1_Kfl0K6a/079bLP1^KVh0JVYZ06m_K`1XJ6P0M7Ad06i^KP1cLg<0L71`07AdM01gMgL0
Lg=c07QhN01mOGd00P1fMWH0101iNGT0Lg=c06m_K`1iNGT307emO@80MGEe00@0OWin07YjNP1mOGd0
NWYj0P1hN7P207IfMP0J08>3P`1oOgl0LW9b07emO@22PX80OGem07IfMP1lO7`0R8R807moO`1iNGT0
Rh^;08f=S@24Q8@0MgMg07moO`29RHT0Q8B407alO024Q8@0QhN708n?S`26QXH0NGUi08Z:RP2?Shl2
09:BTP0Q08j>SP23Ph<0RXZ:08f=S@2;Rh/0OWin09:BTP2EUID0WIfM09RHV02?Shl0XJ6Q0:f][@2[
Zj/0[Jf]09^KV`2VYZH0[Jf]0;Fe]@2o_kl0a/K60;Zj^P2ZZZX0Z:RX0;Bd]02k^k/0`<300<71`@2l
_;`0]KFe0:ZZZP2i^KT0`<300080`/;200D0_;bl0;Bd]02][Jd0][Jf0;jn_P020<;2`P0<0<C4a030
`<00^;Rh0;6a/@2b/[80^;Rh0;>c/`2b/[80/;2`0;Vi^@2k^k/0b<S80P3?cll03P3Bd]80eMGE0=GE
e@3GemL0d];B0=7Ad@3De=@0dM7A0=?Cd`3AdM40d=3@0=GEe@3GemL0e=CD0P3Bd]800`3De=@0e]KF
0=OGe`030=OGe`060=cLg03QhN40h>3P0>;RhP3Ti>@0g]kN0P3?cll06`2[Zj/0MGEe055AD@1;Bd/0
EEEE05UIF@1HF5P0GUiN06ATI01SHf<0IfMW06=SH`1TI6@0JFUY06EUI@1SHf<0JVYZ06EUI@1TI6@0
HV9R06=SH`1XJ6P0IfMW06=SH`1WIfL0IFEU06=SH`02065QH@0;061PH01ZJVX0JFUY06a/K01`L700
LG5a0820P025QHD0SHf=08V9R@2@T9000P2BTY802@2CTi<0VYZJ09RHV02JVYX0Vi^K09JFUP2GUiL0
WYjN09bLW00209ZJVP0609RHV02JVYX0VIVI09^KV`2JVYX0UIFE0P2ATI40602CTi<0Rh^;08B4Q01k
Ng/0MgMg06YZJP1JFUX0FEUI059BDP1FEUH0DU9B05MGE`1IFET0H61P06a/K01aLG40N7Qh08B4Q026
QXH0Rh^;08j>SP2@T900Ti>C09NGU`80UIFE00L0U9BD096AT@2@T900TY:B092@T02<S8`0T92@0080
TY:B00H0T92@09FEU@2BTY80TY:B08n?S`2>SXh208f=S@0=096AT@2=SHd0TY:B092@T02=SHd0Ti>C
092@T02=SHd0TY:B096AT@2BTY80Shn?096AT@03092@T080TY:B01<0UIFE09:BTP2EUID0Ti>C09VI
V@2DU9@0UIFE09ZJVP2DU9@0TY:B09fMW@2NWYh0WIfM09jNWP2EUID0SHf=07=cL`1HF5P0=cLg0080
:RXZ01T0:2PX030`<00X:2P09bLW02PX:00Y:BT0;bl_02XZ:P0/;2`0;bl_02XZ:P0c<c<0;Rh^02l_
;`0e=CD0<C4a03Hf=P0c<c<0>SXj03<c<`0`<300=SHf038b<P0g=cL0=3@d0080<S8b01D0:b/[02h^
;P0^;Rh0<C4a02/[:`0/;2`0<30`03@d=00k>c/0>3Ph03Ti>@0k>c/0<c<c02h^;P0_;bl0=cLg02d]
;@0e=CD0;bl_02h^;P0_;bl00P0g=cL05P0m?Cd0@T9203`l?01>CTh0AdM704e=C@1<C4`0@41003Ti
>@0`<300<C4a03`l?01DE5@0K6a/07moO`2:RXX0UIFE09VIV@2KVi/0XJ6Q0:2PX02WYjL>0<SPf000
3038h=P209jNWP0>0:BTY02JVYX0UiNG09NGU`2BTY80QHF508B4Q01iNGT0LG5a06][J`1IFET0De=C
051@D01BDU8205=CD`0C05ADE01@D500E5AD05IFEP1DE5@0FEUI06=SH`1ZJVX0LG5a07inOP22PX80
QXJ6092@T02GUiL0UYJF09^KV`2LW9`0Y:BT0::RXP020:FUY@030:RXZ02YZJT0YjNW0080YZJV0P2W
YjL0302[Zj/0YjNW0:BTY02WYjL0Xj>S0:FUY@2SXj<0WinO09bLW02KVi/0V9RH09BDU080RXZ:00L0
OWin07QhN01cLg<0J6QX05YJFP1GEeL0D51@0080Bd];0240A4A404];B`1@D500EEEE05YJFP1GEeL0
G5aL05eMG@1NGUh0FEUI05iNGP1TI6@0HF5Q069RHP1QHF40IfMW06IVIP1NGUh0G5aL05iNGP1QHF40
JFUY06=SH`1YJFT0HF5Q06IVIP1XJ6P0IfMW065QH@1ZJVX0IVIV06=SH`1RHV800`1XJ6P02P1ZJVX0
Jf][06i^KP1^KVh0LG5a071`L01/K6`0KVi^071`L01^KVh207=cL`80LW9b0P1_Kfl0201bLW80LG5a
07UiN@1hN7P0NWYj079bLP1lO7`0PX:20P1mOGd0701jNWX0Ng]k07]kN`1oOgl0MgMg07UiN@1gMgL0
O7al07YjNP1hN7P0NWYj07MgM`1fMWH0Ng]k07MgM`1lO7`0OWin07moO`1nOWh0Q8B408b<S01nOWh0
MGEe07AdM01ZJVX0KFe]071`L01XJ6P206e]K@0@079bLP1]KFd0KVi^071`L01^KVh0N7Qh079bLP1e
MGD0MgMg0861P@1lO7`0LW9b07=cL`1`L700Kfm_07MgM`80PH6101L0NWYj07QhN01kNg/0O7al07Qh
N01lO7`0LW9b07IfMP1nOWh0O7al07AdM026QXH0PX:20820P01oOgl0PX:20861P@1gMgL0NWYj08B4
Q023Ph<0Ogmo08R8R00208N7Q`0607]kN`26QXH0QhN708f=S@23Ph<0OGem0P2:RXX00`26QXH0O7al
08Z:RP0209NGU`0[0:6QX@2=SHd0OGem08Z:RP2ATI40TY:B09FEU@2FUYH0WIfM0:JVYP2TY:@0SXj>
08n?S`2SXj<0ZJVY0:j^[P2YZJT0ZZZZ0:b/[02e]KD0^k^k0<;2`P2n_[h0/K6a0:b/[02g]kL0^;Rh
0;Zj^P31`L40a/K60;Jf]P2[Zj/0];Bd0;Vi^@2j^[X0a<C40<G5a@2n_[h0^KVi0;Bd]02h^;P0`/;2
0<C4a0020<K6aP040;jn_P2h^;P0]kNg0;^k^`80_Kfm00d0][Jf0;6a/@2h^;P0`/;20<?3``39bLT0
dm?C0=;BdP3GemL0dm?C0=SHf03De=@0dm?C0080d];B00<0emOG0=KFeP3Fe]H00P3Cdm<03@3EeMD0
e]KF0=OGe`3Jf]X0emOG0=SHf03Lg=`0h>3P0>?Sh`3Rh^80i>CT0>7Qh@3Ng]h00P2m_Kd03`23Ph<0
FUYJ04Y:BP1CDe<0FUYJ05]KF`1LG5`0Hf=S065QH@1TI6@0IVIV06QXJ01UIFD0Jf][06IVIP0206=S
H`80J6QX0P1VIVH206ATI008065QH@1UIFD0IfMW05mOG`1NGUh0Fe]K065QH@1WIfL206m_K`0@075a
L@1dM7@0P82008B4Q027QhL0RHV908n?S`2EUID0U9BD09JFUP2IVIT0Vi^K09bLW02JVYX0VIVI09NG
U`80W9bL0180VIVI09RHV02KVi/0Vi^K09ZJVP2LW9`0VIVI09JFUP2CTi<0Shn?08j>SP26QXH0PH61
07YjNP1aLG40IFEU065QH@1NGUh205aLG00>05EEE@1IFET0HV9R06m_K`1]KFd0MgMg08>3P`26QXH0
Rh^;08b<S02CTi<0TI6A09JFUP2CTi<209JFUP0709:BTP2DU9@0SXj>08n?S`2=SHd0TI6A08j>SP02
096AT@0409>CT`2DU9@0TY:B096AT@80T92@01<0SHf=092@T02ATI40SHf=09>CT`2?Shl0S8b<096A
T@2CTi<0Rh^;09>CT`2DU9@0T92@08f=S@2DU9@0TY:B092@T02EUID0Shn?0080Ti>C01/0TY:B09>C
T`2DU9@0UIFE09:BTP2DU9@0V9RH09JFUP2ATI40VIVI09NGU`2NWYh0WIfM09^KV`2CTi<0PH6106m_
K`1?Cdl0=SHf02/[:`0Z:RX0<S8b03<c<`0X:2P0;2`/03Ti>@0V9RH00P0/;2`02P0U9BD0>SXj02/[
:`0a<C40;Rh^03<c<`0a<C40>c/k03Ti>@0g=cL2038b<P0703Hf=P0d=3@0>3Ph03Lg=`0f=SH0;bl_
02h^;P0202l_;`0702h^;P0W9bL0:BTY030`<00e=CD0@D5103Hf=P0203`l?00703Lg=`0a<C40;Bd]
02PX:00a<C40<S8b030`<00202/[:`0603<c<`0a<C40>3Ph03dm?@14A4@0CTi>0P1ADE40401?Cdl0
ATI603dm?@0_;bl09bLW034a<@0l?3`0F5QH06i^KP24Q8@0TI6A09BDU02IVIT0X:2P0:FUY@2ZZZX>
0<SPf0003038h=P20::RXP0A0:>SX`2OWil0V9RH09NGU`2CTi<0SXj>08R8R01nOWh0MGEe06i^KP1P
H600GemO055AD@1=CDd0E5AD05=CD`1EEED00P1FEUH03P1HF5P0DE5A05MGE`1NGUh0JVYZ07=cL`1n
OWh0QHF508V9R@2@T900TI6A09RHV02JVYX0WinO0`2TY:@0102YZJT0YZJV0:FUY@2[Zj/40:NWY`80
Z:RX0P2TY:@09P2UYJD0Xj>S0:6QX@2SXj<0WYjN09ZJVP2EUID0TY:B08b<S02;Rh/0OGem07]kN`1b
LW80Jf][05eMG@1HF5P0EUIF04e=C@1;Bd/0@d=304a<C01=CDd0E5AD059BDP1CDe<0FUYJ05aLG01O
Gel0GUiN05mOG`1PH600G5aL069RHP1PH600Fe]K06=SH`1QHF40Hf=S0P1WIfL2069RHP0406ATI01N
GUh0HF5Q06=SH`80IVIV00@0JVYZ06EUI@1VIVH0HV9R0P1VIVH206UYJ@<0K6a/01@0J6QX075aL@1_
Kfl0KVi^075aL@1/K6`0L71`07=cL`1fMWH0MgMg06m_K`1gMgL0N7Qh06m_K`1eMGD0M7Ad07alO01j
NWX0MgMg07UiN@80Ng]k00`0N7Qh07MgM`1gMgL0OWin07moO`1iNGT0OGem07MgM`22PX80Ng]k07em
O@1fMWH307MgM`0>07YjNP22PX80OWin07alO020P800S8b<08J6QP1lO7`0NWYj07=cL`1]KFd0JVYZ
06m_K`1ZJVX206i^KP0A06UYJ@1ZJVX0L71`06m_K`1]KFd0Kfm_07=cL`1eMGD0M7Ad07moO`1bLW80
LG5a07=cL`1gMgL0LW9b06m_K`1lO7`00P1oOgl00`21PH40Ng]k07inOP0207emO@0907QhN01oOgl0
QXJ607UiN@1gMgL0QHF508>3P`1lO7`0NWYj0080OWin00P0N7Qh07moO`29RHT0QhN707alO021PH40
R8R808j>SP80Q8B400P0U9BD09FEU@1oOgl0N7Qh08F5Q@27QhL0QXJ608:2PP80QhN701`0VYZJ09VI
V@2:RXX0RXZ:09BDU02ATI40X:2P09:BTP2EUID0WinO0:VYZ@2TY:@0U9BD08f=S@2][Jd0[jn_0;Ng
]`2d];@0/;2`0:b/[02b/[80_[jn0;no_`34a<@0`L710;Rh^02a/K40[Jf]0P2l_;`02@2o_kl0_Kfm
0;Jf]P2`/;00];Bd0;no_`2m_Kd0`L710<;2`P020;no_`0C0<30`02k^k/0_kno0<;2`P34a<@0`l?3
0<71`@2h^;P0][Jf0<30`02o_kl0^k^k0;Ng]`2f][H0/;2`0;Ng]`30`<00bLW90=3@d0020=?Cd`0B
0=;BdP3Cdm<0d];B0=KFeP3Jf]X0e]KF0=CDe03Cdm<0d];B0=KFeP3GemL0e]KF0=OGe`3IfMT0fm_K
0=oOg`3Shn<0h^;R0P3Vi^H09@3Ti>@0eMGE0:>SX`2SXj<0Hf=S05=CD`1=CDd0DE5A05IFEP1MGEd0
HF5Q06ATI01SHf<0JFUY06QXJ01WIfL0HV9R06EUI@1XJ6P0IfMW06IVIP1TI6@0IVIV06MWI`1XJ6P0
Hf=S06EUI@1XJ6P0IFEU06IVIP1OGel0IVIV06ATI01ZJVX0J6QX06e]K@1bLW800P1cLg<02@23Ph<0
PH6108R8R029RHT0T92@09>CT`2DU9@0UiNG09bLW00209VIV@80WIfM00/0UiNG09fMW@2KVi/0VYZJ
09fMW@2IVIT0UiNG09VIV@2HV9P0WIfM09JFUP02092@T00H08Z:RP28R8P0P82007QhN01`L700K6a/
06MWI`1MGEd0HF5Q05YJFP1SHf<0IFEU06QXJ01bLW80NGUi0861P@22PX80Ph>308R8R02=SHd0TI6A
09NGU`2JVYX0UYJF0P2CTi<01@2DU9@0UIFE092@T02?Shl0SXj>0080T92@00D0TI6A08b<S02ATI40
U9BD09>CT`02092@T00508j>SP2@T900T92@08j>SP2=SHd00P2@T9003`2ATI40Shn?092@T02@T900
UYJF08n?S`2ATI40U9BD09>CT`2?Shl0S8b<096AT@2;Rh/0UIFE096AT@0208n?S`0E096AT@2BTY80
UIFE09:BTP2HV9P0UYJF092@T02GUiL0UYJF09VIV@2MWId0WYjN09RHV02>SXh0Q8B406e]K@18B4P0
;Rh^02TY:@0];Bd0<30`0080;2`/00<0;Bd]034a<@0Y:BT00P0Z:RX04P0_;bl0=CDe03De=@0^;Rh0
<C4a02d];@0a<C40>SXj03hn?P0^;Rh0<C4a038b<P0l?3`0<30`03@d=00b<S80=CDe03<c<`80>3Ph
00X0;Rh^02d];@0X:2P0:RXZ02h^;P0c<c<0=3@d03Ti>@0g=cL0>SXj0P0`<3007P0];Bd0<S8b02l_
;`0_;bl0;Rh^02`/;00b<S80<C4a03<c<`0f=SH0?Shn04E5A@1;Bd/0FUYJ059BDP19BDT0?Cdm03@d
=00[:b/0;2`/034a<@13@d<0F5QH071`L025QHD0TI6A09NGU`2OWil0YZJV0:VYZ@h0b>3H000<0<SP
f080YjNW01l0XZ:R09jNWP2KVi/0V9RH09NGU`2>SXh0RHV908N7Q`1iNGT0LW9b06QXJ01JFUX0DE5A
051@D01HF5P0EEEE05MGE`1JFUX0E5AD059BDP1:BTX0F5QH065QH@1WIfL0KFe]07alO01oOgl0Q8B4
08f=S@2EUID0U9BD0080WIfM00@0XJ6Q0:FUY@2ZZZX0YJFU0`2XZ:P20:ZZZP030:b/[02[Zj/0ZJVY
0080YZJV01X0Xj>S0:BTY02QXJ40WinO0::RXP2MWId0VYZJ09RHV02ATI40T92@08f=S@22PX80NWYj
07AdM01XJ6P0H61P05MGE`1@D500BTY:04a<C01:BTX0DE5A05ADE01CDe<0FEUI05YJFP80F5QH00T0
GUiN06EUI@1VIVH0HV9R06YZJP1RHV80GemO06MWI`1PH6000P1SHf<02@1VIVH0J6QX069RHP1LG5`0
IFEU06IVIP1TI6@0HV9R06=SH`0206MWI`80I6AT01`0IVIV06MWI`1VIVH0IVIV06][J`1/K6`0J6QX
06UYJ@1bLW80KVi^07=cL`1_Kfl0NGUi079bLP1eMGD0Ng]k07inOP1aLG40Kfm_079bLP1dM7@0LG5a
07=cL`1^KVh0NGUi075aL@1cLg<0L71`0`1lO7`207MgM`0507alO01hN7P0MGEe07emO@1nOWh00P1i
NGT03@1kNg/0O7al07MgM`1iNGT0O7al07]kN`1oOgl0OGem07]kN`1oOgl0PX:208n?S`29RHT00P1f
MWH0801bLW80LG5a071`L01^KVh0Jf][06e]K@1TI6@0IfMW06YZJP1eMGD0L71`06UYJ@1aLG40O7al
07MgM`1lO7`0NGUi07IfMP1eMGD0Lg=c07QhN01aLG40Jf][07]kN`22PX80Ng]k07emO@1kNg/0Q8B4
07YjNP1fMWH0NGUi0P23Ph<03P28R8P0NWYj08:2PP25QHD0PH6107QhN01gMgL0Ph>308:2PP24Q8@0
S8b<08^;R`27QhL0O7al0P2<S8`02@24Q8@0OWin08J6QP2=SHd0QHF508>3P`2>SXh0RHV908^;R`02
08Z:RP0@08f=S@2FUYH0U9BD09>CT`2=SHd0RXZ:09JFUP2MWId0TY:B08V9R@2NWYh0Xj>S0:ZZZP2R
XZ80W9bL0:JVYP80[Zj^00<0]kNg0;Jf]P2^[Zh00P2d];@02@2l_;`0`L710<71`@31`L40^[Zj0;Fe
]@2f][H0]KFe0;jn_P020<30`00D0;^k^`2c/k<0/[:b0;Zj^P30`<00`l?30<O7a`36a/H0`/;20;Fe
]@2h^;P0a<C40<g=c@36a/H0a<C40;jn_P2i^KT0_Kfm0<;2`P35aLD20;fm_@040;:b/P2/[:`0]KFe
0;fm_@80b<S800D0clo?0=3@d03EeMD0e]KF0=OGe`020=CDe0030=KFeP3IfMT0fMWI00<0f=SH00T0
g=cL0=kNgP3Rh^80hn?S0>CTi03Vi^H0i>CT0=cLg02m_Kd00P1kNg/01@1FEUH0DU9B05=CD`1CDe<0
FUYJ0080HF5Q00@0IFEU06UYJ@1YJFT0JFUY0P1UIFD08@1QHF40IfMW06=SH`1TI6@0Hf=S06EUI@1S
Hf<0JFUY06MWI`1XJ6P0IFEU06QXJ01TI6@0HF5Q05iNGP1SHf<0IfMW06UYJ@1/K6`0KFe]06a/K01g
MgL0OGem08F5Q@29RHT0RXZ:09:BTP2DU9@0UiNG09FEU@2FUYH0WYjN09ZJVP0209^KV`0409NGU`2M
WId0WYjN09RHV080VIVI00L0UiNG09JFUP2HV9P0VIVI09NGU`2ATI40TY:B0080RHV900l0O7al07Mg
M`1cLg<0KVi^06IVIP1QHF40IVIV06UYJ@1WIfL0J6QX06m_K`1hN7P0Ng]k0820P027QhL00P2<S8`0
0`2>SXh0UIFE09FEU@0209JFUP<0U9BD00<0TY:B092@T02?Shl00P2BTY800`2CTi<0TY:B09>CT`02
09:BTP0309FEU@2@T900Ti>C0080SXj>00`0Shn?09:BTP2>SXh0Shn?092@T02BTY80TI6A08f=S@2@
T900TI6A08Z:RP2>SXh208n?S`80T92@00d0SXj>092@T02?Shl0TY:B09>CT`2?Shl0TY:B09FEU@2F
UYH0UiNG09FEU@2DU9@0Ti>C0080UiNG00/0V9RH09fMW@2MWId0WinO09bLW02ATI40O7al05]KF`0o
?cl0>CTi02h^;P0202d];@<0:b/[0P0];Bd02`0U9BD09RHV02l_;`0b<S80;Bd]02h^;P0a<C40=CDe
03@d=00c<c<0=CDe0080=3@d0P0c<c<0100d=3@0<C4a03<c<`0/;2`202XZ:P0?02TY:@0^;Rh0:BTY
02XZ:P0[:b/0=SHf030`<00h>3P0?clo03Xj>P0a<C40;Bd]038b<P0h>3P0;bl_0080<C4a00h0;Rh^
034a<@0`<300<30`03Hf=P0j>SX0@D5104Q8B01?Cdl0EUIF04e=C@0k>c/0<c<c02TY:@809BDU00T0
<C4a03hn?P1FEUH0K6a/08>3P`2GUiL0X:2P0:>SX`2[Zj/03P38h=P000`0b>3H0P2UYJD03P2RXZ80
Y:BT09jNWP2NWYh0W9bL09BDU02?Shl0SHf=0861P@1kNg/0KFe]05iNGP1BDU80CTi>0P1@D50305EE
E@0>051@D01ADE40FEUI05aLG01WIfL0MWIf07QhN022PX80QhN708f=S@2BTY80VYZJ09VIV@2NWYh2
0:>SX`040:RXZ02YZJT0ZJVY0:b/[0<0ZJVY00<0YjNW0:^[Z`2VYZH00P2VYZH0;`2TY:@0XJ6Q0:BT
Y02QXJ40WinO09jNWP2LW9`0VYZJ096AT@2?Shl0RXZ:08>3P`1jNWX0M7Ad071`L01PH600FUYJ051@
D016ATH0BTY:04m?C`1@D500C4a<05IFEP1PH600FUYJ05EEE@1JFUX0Fe]K05mOG`1QHF40J6QX079b
LP1TI6@0Hf=S06IVIP1RHV80Hf=S06UYJ@1QHF40JVYZ05mOG`1QHF40IVIV069RHP1YJFT0I6AT0080
HV9R00<0JFUY06EUI@1UIFD00P1UIFD02`1/K6`0IfMW06][J`1UIFD0Jf][071`L01_Kfl0KVi^071`
L01bLW80KVi^0080MWIf00D0LW9b07AdM01bLW80LW9b07=cL`0206m_K`06075aL@1eMGD0LW9b07Ui
N@1bLW80MgMg0P1hN7P01`1jNWX0N7Qh07EeM@1iNGT0Lg=c07QhN01jNWX00P1kNg/03`1lO7`0NWYj
07YjNP1hN7P0Ng]k07EeM@1jNWX0OGem07UiN@1kNg/0O7al07emO@2IVIT0Y:BT07inOP0206m_K`0=
07UiN@1_Kfl0KFe]06][J`1/K6`0KVi^06][J`1XJ6P0Kfm_06a/K01]KFd0Kfm_07EeM@0207IfMP03
07QhN01eMGD0LW9b0080Lg=c02H0MgMg07AdM01ZJVX0OWin08B4Q01jNWX0Lg=c08R8R01nOWh0MWIf
07UiN@1lO7`0MGEe08N7Q`29RHT0P82007UiN@23Ph<0R8R807moO`1nOWh0Q8B408>3P`25QHD0R8R8
08b<S022PX80PH6108b<S02@T900RHV907MgM`25QHD0TY:B09JFUP2<S8`0RXZ:08R8R080Shn?01@0
T92@096AT@2BTY80SXj>09nOW`2?Shl0SXj>09RHV02LW9`0V9RH09JFUP2PX:00Xj>S0:VYZ@2][Jd0
ZJVY09bLW02YZJT0][Jf0;Zj^P80_kno0P2`/;007P2k^k/0^[Zj0;fm_@34a<@0`l?30;:b/P2YZJT0
][Jf0;jn_P30`<00`/;20;^k^`2e]KD0/k>c0;fm_@30`<00_;bl0<;2`P39bLT0a/K60;Jf]P2e]KD0
`L710<G5a@36a/H0b<S80<O7a`2m_Kd0^[Zj0;no_`80`/;200@0a<C40;fm_@2g]kL0];Bd0P2i^KT0
0`30`<00a/K60=7Ad@020=;BdP80e=CD00<0e]KF0=SHf03IfMT00`3Kfm/02@3Ph>00hn?S0>?Sh`3U
iND0hn?S0>GUi@3MgMd0bl_;09>CT`0205eMG@0@05YJFP1IFET0FEUI05UIF@1MGEd0IFEU06YZJP1W
IfL0IVIV06YZJP1/K6`0KFe]06QXJ01UIFD0IVIV06=SH`80IVIV0`1XJ6P04@1YJFT0JVYZ06EUI@1X
J6P0IFEU06YZJP1QHF40H61P06][J`1ZJVX0JFUY071`L01]KFd0MgMg08:2PP21PH40Rh^;0080T92@
0`2EUID0202DU9@0WYjN0:2PX02JVYX0Vi^K09ZJVP2MWId0W9bL0P2KVi/0802JVYX0UYJF09fMW@2I
VIT0W9bL09FEU@2DU9@0Rh^;08Z:RP23Ph<0PH6107]kN`1fMWH0N7Qh06YZJP1[Jf/0K6a/071`L01c
Lg<0Kfm_07EeM@1lO7`0OWin08B4Q02:RXX0T92@08f=S@2@T900TY:B09VIV@2FUYH0UIFE0P2@T900
4@2BTY80T92@096AT@2ATI40T92@09>CT`2>SXh0Ti>C096AT@2FUYH0U9BD09:BTP2ATI40Shn?08j>
SP2?Shl0S8b<0080TY:B00H0TI6A08f=S@2=SHd0TY:B08b<S02=SHd208n?S`80TY:B0P2@T900102C
Ti<0S8b<08j>SP2ATI4209>CT`0P09:BTP2ATI40Ti>C09BDU02GUiL0U9BD09JFUP2GUiL0V9RH09ZJ
VP2HV9P0WIfM09RHV02NWYh0WinO09NGU`2<S8`0MgMg05QHF00k>c/0<c<c038b<P0Y:BT0:b/[02l_
;`0`<300=3@d02d];@0W9bL0:RXZ02`/;00i>CT202LW9`0=02/[:`0^;Rh0=3@d038b<P0a<C40=SHf
03@d=00e=CD0=3@d03De=@0c<c<0;Rh^038b<P0302`/;009030`<00[:b/0;Rh^02/[:`0b<S80<30`
03/k>`0i>CT0=CDe0080>3Ph00L0=cLg03Hf=P0_;bl0;bl_02d];@0`<300>3Ph0080<S8b01D0=3@d
03`l?00i>CT0>CTi04M7A`1?Cdl0BTY:03hn?P0g=cL09bLW02DU9@0Y:BT0;2`/034a<@0k>c/0FUYJ
07IfMP29RHT0VYZJ0:>SX`2XZ:P03P38h=P000`0b>3H0P2WYjL20:FUY@0Q0:6QX@2PX:00W9bL09JF
UP2CTi<0S8b<08B4Q01nOWh0MgMg06EUI@1MGEd0D51@059BDP1_Kfl0D51@04m?C`1>CTh0BDU9051@
D01JFUX0HV9R06IVIP1aLG40NWYj08:2PP26QXH0RXZ:09>CT`2IVIT0Vi^K0:6QX@2UYJD0Xj>S00@0
YZJV0240ZJVY0:ZZZP2ZZZX0ZJVY0:FUY@2VYZH0Y:BT0:JVYP2QXJ40XZ:R0:2PX02TY:@0XJ6Q0:2P
X02JVYX0VIVI09JFUP2@T900QXJ60820P01mOGd0LW9b06QXJ01OGel0EUIF04m?C`1:BTX0CDe=04Y:
BP1<C4`0De=C051@D01FEUH00`1HF5P01P1NGUh0GemO05iNGP1LG5`0K6a/06ATI080HV9R00H0IFEU
05mOG`1RHV80GemO069RHP1OGel206ATI005069RHP1VIVH0IFEU06ATI01VIVH00P1SHf<02`1VIVH0
HV9R06][J`1TI6@0IVIV06YZJP1VIVH0KFe]071`L01YJFT0KFe]0080L71`00`0K6a/07=cL`1dM7@0
L71`07=cL`1hN7P0MWIf07MgM`1_Kfl0MGEe075aL@1_Kfl2079bLP0?07YjNP1iNGT0M7Ad07AdM01f
MWH0NWYj07EeM@1kNg/0NWYj07alO01fMWH0Ng]k07emO@1kNg/0NWYj0080MWIf00l0NWYj07]kN`20
P800Ph>307]kN`1jNWX0OGem07]kN`2>SXh0ZZZZ08f=S@1dM7@0Kfm_07=cL`1aLG400P1bLW80301Z
JVX0KFe]06i^KP1`L700Jf][06QXJ01/K6`0LG5a07=cL`1aLG40NWYj07emO@80MGEe01X0N7Qh075a
L@1jNWX0MgMg07]kN`1bLW80Ng]k08R8R021PH40Ph>30861P@1kNg/0MWIf07inOP1hN7P0P82008:2
PP2;Rh/0QXJ607emO@20P800RXZ:0861P@1iNGT0PH6108f=S@80RXZ:00`0SHf=08N7Q`23Ph<0QHF5
08f=S@26QXH0Ng]k08J6QP2BTY80U9BD0861P@1eMGD208F5Q@0F08Z:RP2KVi/0TY:B08R8R02BTY80
UIFE09>CT`2?Shl0V9RH09fMW@2RXZ80X:2P08^;R`2KVi/0YZJV0;Jf]P2e]KD0Z:RX0:VYZ@2][Jd0
]KFe0;Zj^P80]kNg0P2b/[802P2d];@0_;bl0<;2`P33`l<0^[Zj0;Fe]@2b/[80]KFe0;^k^`2n_[h2
0<30`00@0;bl_02f][H0]KFe0;no_`34a<@0a/K60<30`02m_Kd0`L710<?3``2o_kl0b<S80<O7a`36
a/H0aLG50<?3``<0_[jn00@0a<C40<?3``32`/80`<300P2e]KD01@2`/;00_;bl0<K6aP39bLT0d=3@
0080d];B00H0emOG0=SHf03MgMd0fm_K0=oOg`3Rh^820>CTi0060>?Sh`3Rh^80g]kN0<_;b`2RXZ80
Jf][0P1FEUH04`1IFET0Fe]K05]KF`1UIFD0IVIV06a/K01^KVh0KFe]06YZJP1]KFd0Jf][06m_K`1V
IVH0IfMW06UYJ@1UIFD0HF5Q06][J`1XJ6P00P1/K6`206MWI`0P06EUI@1VIVH0IVIV06MWI`1UIFD0
H61P069RHP1XJ6P0Jf][06e]K@1dM7@0MgMg08J6QP23Ph<0R8R808j>SP2@T900TY:B09NGU`2IVIT0
UiNG09fMW@2LW9`0VYZJ09bLW02MWId0WYjN09^KV`2JVYX0V9RH09ZJVP2EUID209VIV@0509FEU@2D
U9@0SXj>08f=S@2:RXX00P20P8003P1iNGT0MgMg07EeM@1bLW80Kfm_07=cL`1fMWH0LW9b07IfMP1m
OGd0P82008B4Q029RHT0S8b<0P2@T9001@2CTi<0VIVI09>CT`2DU9@0TY:B00<0Shn?00X0Ti>C096A
T@2CTi<0Ti>C096AT@2BTY80UiNG09RHV02FUYH0TY:B0P2ATI4208f=S@0O08n?S`2>SXh0Shn?096A
T@2>SXh0Shn?096AT@2@T900S8b<08n?S`2ATI40T92@09:BTP2CTi<0TI6A08j>SP2@T900SXj>096A
T@2>SXh0U9BD09>CT`2ATI40Shn?096AT@2@T900UYJF09BDU02ATI40V9RH09NGU`0409VIV@<0WYjN
00T0UYJF08R8R01`L700EEEE03Hf=P0/;2`0;bl_02PX:00Z:RX00P0`<30302PX:00502`/;00Y:BT0
:b/[02PX:00/;2`00P0c<c<0100j>SX0;bl_03<c<`0f=SH303Ph>00303Hf=P0a<C40<30`0080<S8b
00D0<C4a02XZ:P0Y:BT0;2`/02d];@02030`<00=03De=@0l?3`0<c<c03Xj>P0k>c/0<c<c034a<@0c
<c<0;bl_03De=@0`<300<S8b03De=@02034a<@0403@d=00f=SH0>3Ph0451@@80CDe=00<0@41003Ph
>00Z:RX00P0V9RH02@0R8R808b<S02/[:`17AdL0Hf=S07emO@2EUID0X:2P0:RXZ00>0<SPf0003038
h=P20:b/[00R0:JVYP2UYJD0X:2P0:BTY02MWId0VYZJ09RHV02?Shl0SXj>07moO`1gMgL0KFe]065Q
H@1FEUH0DE5A04e=C@1BDU80F5QH04i>CP1@D500DU9B05EEE@1MGEd0Jf][079bLP1kNg/0P82008J6
QP29RHT0UIFE09JFUP2HV9P0X:2P0:BTY080YZJV00@0Z:RX0:ZZZP2VYZH0YZJV0P2YZJT01`2VYZH0
YjNW0:VYZ@2SXj<0XZ:R0:6QX@2XZ:P00`2PX:00502LW9`0VYZJ09FEU@2BTY80SHf=08R8R020P800
OWin07=cL`1VIVH0GEeM05ADE018B4P0CDe=04Q8B019BDT0CTi>05=CD`1ADE40E5AD0P1GEeL05`1E
EED0HF5Q06EUI@1MGEd0IVIV06EUI@1VIVH0GemO05iNGP1QHF40H61P06IVIP1QHF40I6AT061PH01U
IFD0HV9R06EUI@1SHf<0IFEU06=SH`1UIFD0I6AT0080IfMW00X0Hf=S06EUI@1ZJVX0IFEU071`L01X
J6P0I6AT06][J`1YJFT0LG5a0`1[Jf/03`1aLG40LW9b06e]K@1cLg<0MWIf07EeM@1hN7P0KVi^07Ee
M@1fMWH0MGEe07IfMP1hN7P0OWin07QhN00207YjNP0<07IfMP1hN7P0Kfm_07QhN01eMGD0MgMg079b
LP1nOWh0MgMg07UiN@1kNg/0MWIf0P1kNg/00`1hN7P0Ng]k07moO`0207alO00H07YjNP1fMWH0PH61
09bLW02[Zj/0Ph>306i^KP1bLW80M7Ad07EeM@1gMgL0KVi^06UYJ@1ZJVX0KVi^06MWI`1YJFT0KVi^
06e]K@1bLW80KVi^07EeM@1iNGT0MWIf0P1hN7P09`1bLW80MWIf07YjNP21PH40N7Qh07MgM`1dM7@0
OWin08B4Q01nOWh0NWYj07inOP1mOGd0O7al08B4Q023Ph<0P82008R8R02<S8`0Ng]k07YjNP24Q8@0
QHF508J6QP24Q8@0SHf=096AT@2>SXh0S8b<09:BTP2=SHd0RHV908n?S`24Q8@0QHF507alO02:RXX0
Shn?08>3P`0208F5Q@0K08Z:RP2ATI40X:2P09NGU`2CTi<0TI6A09NGU`2LW9`0T92@08f=S@2NWYh0
Z:RX09nOW`2IVIT0UiNG0:ZZZP2a/K40];Bd0:b/[02XZ:P0[Zj^0;Fe]@2h^;P0]kNg0;^k^`2j^[X0
][Jf0080]KFe00@0_;bl0;no_`31`L40_[jn0P2c/k<20;jn_P050<71`@34a<@0a<C40;jn_P2h^;P0
0P2l_;`02@32`/80bLW90<K6aP36a/H0_kno0<?3``31`L40`l?30<G5a@020<O7a`0E0<?3``2k^k/0
^k^k0;no_`32`/80aLG50<K6aP2n_[h0]kNg0;6a/@2e]KD0^[Zj0;Vi^@31`L40a<C40<g=c@3AdM40
e=CD0=OGe`3Kfm/0fMWI0080e]KF00H0d=3@0<g=c@30`<00WYjN079bLP1NGUh205ADE00@05QHF01O
Gel0H61P06=SH`1WIfL0K6a/06][J`1ZJVX0K6a/06m_K`1TI6@0LG5a06a/K01[Jf/0IVIV06UYJ@80
IVIV00H0JVYZ06MWI`1XJ6P0KFe]06a/K01^KVh206QXJ00706EUI@1WIfL0HV9R06EUI@1bLW80Kfm_
075aL@0207AdM00307inOP25QHD0Rh^;0080TY:B00d0UYJF09NGU`2JVYX0VIVI09fMW@2JVYX0W9bL
09VIV@2KVi/0X:2P09^KV`2MWId0VIVI00<0V9RH01D0Vi^K09NGU`2DU9@0SHf=08b<S027QhL0Ph>3
0820P01oOgl0N7Qh07YjNP1gMgL0LW9b07MgM`1fMWH0MgMg07YjNP22PX80Ph>308J6QP28R8P00P2?
Shl0102CTi<0UYJF09FEU@2GUiL409>CT`0308j>SP2CTi<0SXj>0080TI6A00h0Ti>C092@T02GUiL0
U9BD09RHV02ATI40U9BD09>CT`2ATI40Rh^;092@T02=SHd0Shn?08f=S@80Shn?00/0SXj>08f=S@2@
T900Shn?092@T02>SXh0TI6A08n?S`2@T900TI6A092@T00309:BTP80Ti>C01D0TI6A08j>SP2ATI40
T92@096AT@2BTY80Ti>C09JFUP2CTi<0UIFE09JFUP2EUID0VIVI09bLW02IVIT0X:2P09nOW`2EUID0
Ogmo06UYJ@17AdL0100];Bd05P0[:b/0;2`/02d];@0X:2P0=CDe030`<00Y:BT0;2`/02LW9`0Y:BT0
<30`038b<P0g=cL0=SHf03<c<`0g=cL0<S8b03De=@0b<S80>CTi03dm?@0e=CD203Lg=`0@03@d=00`
<300;Bd]02d];@0/;2`0:b/[030`<00/;2`0=SHf03Lg=`0e=CD0>3Ph04A4A00f=SH0<c<c038b<P80
;Bd]01P0;2`/03<c<`0b<S80<30`034a<@0g=cL0=CDe03dm?@13@d<0AdM70492@P0h>3P0;bl_02PX
:00W9bL092@T02<S8`0W9bL0;bl_04];B`1_Kfl0QXJ609NGU`2WYjL>0<SPf0003038h=P30:ZZZP0>
0:NWY`2RXZ80Y:BT09fMW@2LW9`0Vi^K09:BTP2ATI40QXJ607alO01dM7@0K6a/05aLG01EEED204i>
CP07051@D01;Bd/0CDe=05IFEP1EEED0Fe]K06QXJ00207MgM`080820P029RHT0RHV9096AT@2NWYh0
Vi^K0:BTY02QXJ420:RXZ0040:JVYP2[Zj/0YZJV0:NWY`80Z:RX00P0YjNW0:^[Z`2TY:@0XZ:R0:JV
YP2UYJD0YjNW0:FUY@80XJ6Q00<0WYjN09NGU`2HV9P00P2@T9004P2;Rh/0P82007]kN`1aLG40IfMW
069RHP1DE5@0CDe=04Y:BP17AdL0Bd];04a<C01BDU80De=C05ADE01JFUX0IFEU05QHF0<0H61P00T0
Hf=S06EUI@1UIFD0IVIV06ATI01QHF40JFUY06QXJ01VIVH00P1SHf<0301XJ6P0IVIV06MWI`1RHV80
IFEU06QXJ01TI6@0H61P06EUI@1RHV80IFEU06IVIP80I6AT01P0J6QX06][J`1[Jf/0K6a/06m_K`1/
K6`0Kfm_06QXJ01cLg<0KVi^075aL@1bLW80M7Ad079bLP1cLg<0L71`06e]K@1bLW80L71`07=cL`1i
NGT0M7Ad07IfMP1kNg/207UiN@0707QhN01fMWH0MGEe07UiN@1eMGD0N7Qh07AdM00207]kN`0407in
OP1jNWX0MgMg07alO080OWin0100O7al07]kN`1lO7`0NWYj07]kN`1nOWh0Ogmo09NGU`36a/H0ZJVY
07AdM01`L700LW9b071`L01bLW80M7Ad0P1bLW802P1dM7@0Kfm_075aL@1ZJVX0J6QX075aL@1dM7@0
LW9b07MgM`1jNWX207MgM`0?07EeM@1fMWH0Ng]k07QhN023Ph<0P82007]kN`1^KVh0OGem08N7Q`1o
Ogl0O7al07emO@1hN7P0NWYj0080P8200140N7Qh08B4Q02?Shl0PH6107inOP26QXH0TY:B08b<S021
PH40S8b<092@T01oOgl0S8b<09BDU02;Rh/0R8R808N7Q`0208j>SP0308>3P`26QXH0TY:B0080UIFE
00D0QXJ608:2PP2>SXh0WinO09ZJVP0208j>SP0d09ZJVP2QXJ40V9RH09FEU@2MWId0YZJV0:j^[P2P
X:00UYJF09^KV`2[Zj/0[jn_0;bl_02i^KT0/k>c0;:b/P2XZ:P0]kNg0;Zj^P2l_;`0_[jn0;:b/P2]
[Jd0_;bl0;jn_P30`<00`L710<30`02o_kl0_;bl0;Vi^@30`<00`l?30<C4a035aLD0^[Zj0;fm_@2n
_[h0`L710<S8b039bLT0bl_;0<S8b02n_[h0^[Zj0<C4a035aLD0b<S80<O7a`33`l<0_Kfm0<;2`P80
_kno01L0a/K60<W9b@35aLD0a/K60<30`02i^KT0][Jf0;Fe]@2k^k/0`L710<W9b@3<c<`0dM7A0=;B
dP2k^k/0[Jf]0:ZZZP2SXj<0VYZJ08Z:RP1YJFT0FEUI05]KF`0205iNGP0705eMG@1PH600JFUY06MW
I`1_Kfl0KVi^071`L00206e]K@0_079bLP1/K6`0JVYZ06MWI`1XJ6P0KVi^06e]K@1YJFT0J6QX06YZ
JP1VIVH0JVYZ06UYJ@1[Jf/0J6QX06EUI@1TI6@0HF5Q06ATI01SHf<0H61P06UYJ@1/K6`0L71`07Ad
M01fMWH0O7al08N7Q`2;Rh/0Ti>C09RHV02FUYH0U9BD09ZJVP2IVIT0VYZJ09VIV@2KVi/0VYZJ09fM
W@2NWYh0XJ6Q09bLW02KVi/0V9RH09BDU02FUYH00P2EUID04@2CTi<0Shn?08f=S@2:RXX0QHF508J6
QP22PX80OWin07QhN020P800MgMg07IfMP1kNg/0O7al07inOP22PX80PH610080SHf=00L0T92@08j>
SP2CTi<0UYJF09RHV02@T900Ti>C00<0TY:B00X0SXj>08f=S@2@T900T92@096AT@2DU9@0Ti>C09JF
UP2CTi<0VYZJ0P2DU9@03@2CTi<0SHf=08f=S@2=SHd0Shn?08f=S@2>SXh0Ti>C08^;R`2@T900SHf=
096AT@2=SHd00P2>SXh01`2ATI40TY:B09BDU02>SXh0Shn?09>CT`2?Shl00`2BTY803P2HV9P0UIFE
09JFUP2ATI40Ti>C09FEU@2DU9@0UYJF09BDU02EUID0V9RH09JFUP2IVIT0UYJF0P2JVYX0702OWil0
VYZJ092@T01kNg/0EUIF0451@@0_;bl0;Rh^02d];@0Z:RX0:BTY02LW9`0_;bl0:RXZ02`/;00d=3@0
:BTY02HV9P0Y:BT0:b/[02`/;00`<300<C4a03<c<`0g=cL0=CDe03@d=00g=cL203De=@0503Hf=P0_
;bl0;bl_03@d=00^;Rh00P0/;2`202h^;P0802PX:00Z:RX0;bl_030`<00c<c<0=CDe03<c<`0i>CT2
03Hf=P0;02l_;`0`<300;bl_02d];@0b<S80<C4a038b<P0f=SH0=3@d0410@00n?Sh00P13@d<03@17
AdL0?3`l03<c<`0`<3009BDU028R8P0M7Ad08R8R02l_;`1CDe<0L71`08^;R`2PX:003P38h=P000`0
b>3H0P2_[jl0402[Zj/0[:b/0:NWY`2RXZ80XJ6Q09nOW`2NWYh0TY:B092@T02<S8`0P82007UiN@1a
LG40I6AT05UIF@1@D50204e=C@80CTi>00L0Cdm?05UIF@1SHf<0J6QX07AdM01iNGT0Ogmo0080RXZ:
00/0Shn?09VIV@2KVi/0X:2P0::RXP2TY:@0YjNW0:^[Z`2XZ:P0YjNW0:JVYP020:RXZ0090:JVYP2S
Xj<0YJFU0::RXP2TY:@0Xj>S0:JVYP2TY:@0XJ6Q0080WYjN0200V9RH09>CT`2CTi<0SHf=08N7Q`21
PH40OWin07UiN@1^KVh0Fe]K05IFEP18B4P0D51@04Y:BP18B4P0CTi>05=CD`1BDU80EeMG05QHF01G
EeL0FUYJ05eMG@1QHF40Fe]K05aLG01MGEd0Hf=S065QH@1LG5`0Hf=S06EUI@80IVIV0P1SHf<0201Z
JVX0IFEU06EUI@1MGEd0IVIV06EUI@1WIfL0HF5Q0P1SHf<01P1RHV80IFEU06][J`1XJ6P0K6a/06e]
K@80JVYZ01@0Kfm_06e]K@1`L700KFe]07AdM01aLG40Lg=c071`L01dM7@0L71`07MgM`1dM7@0L71`
07=cL`1`L700Lg=c079bLP1dM7@0N7Qh07IfMP80MgMg00P0OWin07QhN01hN7P0N7Qh07MgM`1iNGT0
OGem07alO080NGUi0P1mOGd01P1kNg/0NGUi07]kN`1nOWh0OGem07alO0<0NGUi00H0NWYj08R8R02e
]KD0];Bd07alO01/K6`206m_K`0C075aL@1dM7@0MWIf071`L01bLW80K6a/06e]K@1aLG40JVYZ06m_
K`1]KFd0LW9b075aL@1bLW80MWIf07EeM@1iNGT0MWIf08>3P`020820P00?08V9R@21PH40NWYj071`
L01nOWh0SHf=08J6QP22PX80NGUi07AdM01iNGT0Rh^;08N7Q`23Ph<0RHV90080Rh^;00d0Ogmo08f=
S@2@T900QXJ607YjNP1iNGT0QhN708V9R@24Q8@0Ti>C08f=S@1oOgl0OWin0080TI6A00d0PX:20861
P@2@T900T92@09FEU@2;Rh/0P82009FEU@2NWYh0VYZJ08j>SP2=SHd0Vi^K0080YJFU0140TY:B09bL
W02QXJ40ZJVY0:b/[02NWYh0X:2P0:FUY@2XZ:P0]kNg0;Vi^@2g]kL0[:b/0:n_[`2f][H0];Bd0;Zj
^P020;bl_0030;Vi^@2c/k<0];Bd0080`<3000h0`l?30<C4a02o_kl0_[jn0;>c/`2m_Kd0`l?30<C4
a035aLD0`l?30;bl_02n_[h0`l?30<W9b@80alO70P36a/H20<30`0050<;2`P31`L40a<C40<G5a@38
b<P00P36a/H04`33`l<0a<C40<O7a`39bLT0aLG50<W9b@34a<@0`/;20<S8b036a/H0bLW90<_;b`39
bLT0V9RH079bLP1^KVh0KFe]06][J`1SHf<00P1JFUX02@1RHV80GemO05mOG`1UIFD0HF5Q06MWI`1X
J6P0IFEU075aL@0306a/K080L71`0P1_Kfl0101]KFd0Jf][06YZJP1ZJVX206a/K00606YZJP1UIFD0
JVYZ079bLP1WIfL0J6QX0`1WIfL02`1QHF40IfMW06EUI@1ZJVX0L71`06e]K@1bLW80Ogmo08:2PP27
QhL0Ti>C0080U9BD00H0UiNG09ZJVP2HV9P0VYZJ09NGU`2JVYX209jNWP0<09VIV@2MWId0V9RH09ZJ
VP2FUYH0Ti>C09BDU02FUYH0UIFE09NGU`2?Shl0RXZ:0P27QhL04@25QHD0Ph>307inOP1nOWh0P820
07emO@1jNWX0P82007emO@22PX80QhN708J6QP2=SHd0SXj>092@T02FUYH0V9RH0080UIFE0P2BTY80
102@T900TY:B09:BTP2?Shl208j>SP0408n?S`2CTi<0UYJF096AT@<0U9BD00L0UYJF09>CT`2EUID0
SHf=08Z:RP2<S8`0SXj>0080T92@00H0SXj>08Z:RP2<S8`0SHf=096AT@2=SHd208j>SP0h092@T02?
Shl0U9BD08n?S`2>SXh0TY:B092@T02BTY80TI6A09>CT`2BTY80VYZJ09:BTP2ATI40UYJF09BDU02A
TI40V9RH09FEU@2DU9@0Ti>C09FEU@2FUYH0VIVI09jNWP2LW9`0WIfM09^KV`2EUID0R8R8075aL@1@
D500>c/k030`<00^;Rh0;bl_034a<@0^;Rh0;2`/02LW9`0V9RH0<30`02TY:@0^;Rh0:2PX02TY:@0Z
:RX0<C4a03<c<`0e=CD0?3`l03dm?@14A4@0>SXj03Hf=P0a<C4303<c<`0302l_;`0a<C40<C4a0080
;2`/00X0:RXZ02LW9`0Y:BT0:BTY030`<00g=cL0=CDe03Hf=P0i>CT0>3Ph0P0i>CT06@0l?3`0<C4a
02l_;`0g=cL0=CDe034a<@0d=3@0=SHf03Lg=`0d=3@0?Cdm04A4A013@d<0A4A403Ph>00`<3009RHV
028R8P0N7Qh0820P02HV9P0c<c<0EUIF07YjNP2DU9@03P38h=P000`0b>3H0P2[Zj/04@2][Jd0ZZZZ
0:RXZ02WYjL0XZ:R09fMW@2LW9`0UYJF09BDU02;Rh/0Q8B407emO@1hN7P0KFe]061PH01CDe<0E5AD
0080Bd];0140B4Q8055AD@1HF5P0HV9R06ATI01]KFd0N7Qh0861P@26QXH0S8b<09:BTP2GUiL0VYZJ
09nOW`2SXj<0Z:RX0:VYZ@020:ZZZP80ZJVY0P2ZZZX0;@2VYZH0ZJVY0:JVYP2TY:@0Xj>S0::RXP2S
Xj<0XZ:R09jNWP2RXZ80WIfM09bLW02FUYH0Ti>C08Z:RP2=SHd0Ph>307]kN`1iNGT0K6a/05iNGP1E
EED0CDe=04a<C018B4P0ATI604Q8B01?Cdl0DE5A05MGE`1NGUh0EUIF05YJFP1MGEd0I6AT061PH01T
I6@0IVIV05mOG`1WIfL0I6AT06MWI`1MGEd0GemO06IVIP02065QH@0D06IVIP1TI6@0HV9R05iNGP1Q
HF40IfMW061PH01SHf<0IFEU06IVIP1PH600IFEU06QXJ01WIfL0J6QX06e]K@1[Jf/0K6a/06YZJP1]
KFd206a/K00:07EeM@1]KFd0LG5a06i^KP1aLG40MgMg07AdM01fMWH0L71`07AdM080MGEe00@0Lg=c
07EeM@1iNGT0MWIf0P1gMgL01P1mOGd0MWIf07UiN@1gMgL0NGUi07YjNP<0NGUi00<0O7al07QhN01j
NWX00P1mOGd00`1jNWX0Ng]k07inOP0207UiN@0>07alO01oOgl0MGEe07]kN`2:RXX0Xj>S08R8R01f
MWH0JVYZ06m_K`1fMWH0L71`079bLP1iNGT207IfMP04075aL@1_Kfl0M7Ad06a/K080L71`00P0MWIf
079bLP1bLW80MgMg07=cL`1fMWH0NGUi07emO@<0O7al00h0PX:207alO01eMGD0OGem08R8R029RHT0
NGUi07=cL`1nOWh0Q8B40861P@2;Rh/0RXZ:08F5Q@80Q8B40100RXZ:0861P@2?Shl0SHf=07]kN`1n
OWh0R8R808:2PP24Q8@0TY:B08N7Q`24Q8@0RHV909JFUP2EUID0Ph>30P24Q8@209JFUP0D09>CT`29
RHT0S8b<09NGU`2SXj<0W9bL096AT@2LW9`0Z:RX0:b/[02TY:@0V9RH0:6QX@2[Zj/0]KFe0;Bd]02V
YZH0W9bL0:6QX@2e]KD20;fm_@80^;Rh00@0[jn_0;:b/P2i^KT0_;bl0P30`<001@2l_;`0`<300;fm
_@2l_;`0`L710080aLG500X0_[jn0;Rh^02i^KT0`<300<G5a@37alL0aLG50<71`@2j^[X0`L710P35
aLD03036a/H0bLW90<K6aP34a<@0_Kfm0;bl_033`l<0aLG50<S8b037alL0b/[:0<S8b080`/;200D0
b<S80<c<c03:b/X0bl_;0<c<c0020<_;b`0<0<?3``2e]KD0XJ6Q071`L01MGEd0GemO05aLG01OGel0
GUiN05aLG01NGUh0IVIV0P1RHV803P1TI6@0IVIV06UYJ@1/K6`0Jf][07AdM01_Kfl0K6a/06UYJ@1^
KVh0Kfm_071`L01^KVh0JVYZ0P1XJ6P00`1TI6@0K6a/06m_K`0206a/K00C071`L01^KVh0JFUY06e]
K@1VIVH0J6QX06IVIP1TI6@0IfMW06QXJ01[Jf/0KVi^07IfMP1hN7P0O7al08F5Q@27QhL0Shn?092@
T00209>CT`0909FEU@2IVIT0W9bL09RHV02IVIT0V9RH09ZJVP2MWId0WYjN0080V9RH00P0VYZJ09FE
U@2DU9@0U9BD09:BTP2@T900SXj>08Z:RP80R8R800L0QXJ608F5Q@27QhL0QhN708B4Q01nOWh0P820
00<0PX:20P28R8P02@2<S8`0T92@09FEU@2CTi<0VIVI09FEU@2DU9@0UYJF096AT@0308j>SP04092@
T02BTY80T92@08n?S`80TI6A0P2BTY801P2ATI40UYJF09BDU02BTY80TI6A08n?S`80SXj>0P2?Shl2
096AT@0308f=S@2<S8`0TY:B0080SXj>00H0S8b<096AT@2@T900T92@096AT@2BTY8208n?S`0908j>
SP2DU9@0Shn?08n?S`2BTY80Ti>C096AT@2;Rh/0U9BD0080UYJF00<0UIFE09BDU02DU9@00`2EUID0
7P2@T900VYZJ09fMW@2KVi/0WYjN0:BTY02HV9P0QhN706i^KP1@D500=3@d03<c<`0/;2`0;bl_030`
<00b<S809bLW02/[:`0];Bd0;bl_02PX:00_;bl0=3@d034a<@0c<c<0:RXZ034a<@0d=3@0=CDe03Hf
=P80=3@d01<0=cLg038b<P0e=CD0=CDe03Hf=P0a<C40:b/[030`<00b<S80;Rh^02`/;00[:b/0:2PX
02`/;00_;bl0=SHf03/k>`0j>SX0=cLg0080<S8b00<0;Bd]03hn?P0c<c<00P0^;Rh2030`<080=SHf
0100=cLg03Ti>@10@400ADE50451@@16ATH0?3`l02XZ:P0V9RH09BDU01`L700P820092@T03@d=01N
GUh0PH613P38h=P000`0b>3H0`2/[:`07@2[Zj/0ZZZZ0:RXZ02SXj<0WYjN0:6QX@2KVi/0UIFE096A
T@2;Rh/0QHF507inOP1cLg<0IVIV05]KF`1ADE40Bd];04a<C018B4P0Cdm?05QHF01PH600IFEU06i^
KP1gMgL0PH6108F5Q@2=SHd0TI6A0080VIVI00L0XZ:R0:2PX02VYZH0YJFU0:JVYP2ZZZX0[:b/00<0
YjNW0P2UYJD01@2VYZH0YjNW0::RXP2RXZ80Y:BT0080XJ6Q01h0Y:BT09bLW02JVYX0UIFE096AT@2;
Rh/0RXZ:08>3P`1iNGT0Lg=c06UYJ@1OGel0DU9B04a<C01@D500B4Q804M7A`1>CTh0D51@05=CD`1G
EeL0E5AD05mOG`1LG5`0F5QH05eMG@1OGel0GUiN06IVIP1UIFD206=SH`0M061PH01SHf<0KVi^079b
LP1WIfL0HV9R06ATI01SHf<0GUiN065QH@1PH600IFEU06MWI`1RHV80I6AT06IVIP1NGUh0HV9R065Q
H@1YJFT0IVIV06UYJ@1ZJVX0Kfm_071`L01_Kfl0KFe]06m_K`1`L7000P1bLW80101`L700LW9b07]k
N`1eMGD207=cL`0707IfMP1eMGD0L71`079bLP1kNg/0LG5a07AdM00207YjNP0<07QhN01eMGD0NWYj
075aL@1fMWH0NGUi07QhN01iNGT0O7al07MgM`1jNWX0OGem0P1kNg/07P1mOGd0OWin07emO@1gMgL0
O7al07]kN`1dM7@0N7Qh07]kN`1nOWh0SHf=09JFUP1lO7`0KVi^07=cL`1bLW80Kfm_075aL@1eMGD0
N7Qh07AdM01iNGT0Lg=c07AdM01bLW80KVi^06][J`1/K6`0NWYj07QhN080MgMg00<0MGEe07YjNP1n
OWh00P1kNg/20861P@0?08F5Q@1mOGd0NGUi07MgM`2:RXX0QHF507emO@1oOgl0QHF507inOP1iNGT0
RXZ:08f=S@1mOGd0Ogmo0080SHf=00`0RXZ:08n?S`2@T900QhN707YjNP1gMgL0Ph>308B4Q02>SXh0
TI6A08R8R02<S8`209>CT`80U9BD00L0SHf=09:BTP2FUYH0VIVI08b<S025QHD0VYZJ0080Xj>S00L0
VYZJ09nOW`2TY:@0/k>c0;2`/02QXJ40WinO0080Zj^[0P2c/k<0102_[jl0ZJVY0;6a/@2d];@20;bl
_0060;jn_P2i^KT0[jn_0:n_[`2c/k<0`<300P33`l<0602n_[h0^;Rh0;Rh^02n_[h0_kno0<G5a@38
b<P0`<300;Zj^P2m_Kd0_kno0<C4a038b<P0`l?30<;2`P33`l<0`L710<?3``36a/H0aLG50<O7a`36
a/H0alO70<71`@80_;bl00@0a<C40<G5a@38b<P0b<S80P3<c<`00`38b<P0alO70<K6aP020<c<c00=
0<[:bP2e]KD0TY:B07=cL`1RHV80F5QH05eMG@1NGUh0HV9R06=SH`1LG5`0IFEU06IVIP0206MWI`09
06EUI@1/K6`0KFe]06UYJ@1aLG40Lg=c071`L01^KVh0LG5a0080LW9b00D0JVYZ06i^KP1/K6`0K6a/
06UYJ@0206YZJP0E06a/K01]KFd0L71`079bLP1`L700JVYZ06a/K01XJ6P0IfMW06EUI@1TI6@0IFEU
06][J`1ZJVX0KVi^071`L01fMWH0P82008>3P`27QhL0S8b<0080TI6A00L0TY:B09FEU@2HV9P0W9bL
09VIV@2GUiL0VYZJ0080V9RH00@0VIVI09FEU@2DU9@0V9RH0P2DU9@0602?Shl0TY:B08n?S`2?Shl0
Rh^;08b<S025QHD0RHV908F5Q@26QXH0PH6108V9R@24Q8@0Ph>308F5Q@23Ph<0QhN708R8R02:RXX0
SHf=08n?S`2BTY80UiNG09FEU@80TY:B00<0Ti>C096AT@2BTY800P2ATI4208b<S00?08n?S`2>SXh0
TY:B08j>SP2?Shl0U9BD09NGU`2DU9@0TI6A09:BTP2ATI40SHf=09>CT`2>SXh0TI6A00<0Shn?00T0
RXZ:08f=S@2>SXh0SHf=092@T02ATI40S8b<08j>SP2BTY800P2@T900302ATI40TY:B08j>SP2DU9@0
TI6A092@T02ATI40UiNG09BDU02@T900TI6A09:BTP80U9BD00D0UiNG09RHV02CTi<0UYJF09>CT`02
09VIV@0409bLW02IVIT0Vi^K0:2PX080WinO00<0UiNG07EeM@1:BTX00P0b<S8202TY:@0402d];@0b
<S80=3@d02d];@80:BTY00d0;2`/02d];@0^;Rh0<S8b03<c<`0e=CD0<C4a030`<00c<c<0=SHf034a
<@0b<S80<30`0080>SXj0P0g=cL08P0a<C40?Cdm03Ti>@0c<c<0<S8b02XZ:P0X:2P0:BTY02l_;`0c
<c<0?Cdm03hn?P0h>3P0<c<c03Hf=P0^;Rh0<c<c02/[:`0/;2`0<C4a02`/;00[:b/0>SXj03Hf=P0_
;bl0>CTi03lo?`15ADD0BTY:04Q8B014A4@0=SHf038b<P0/;2`2020P800401hN7P0R8R80=3@d069R
HPh0b>3H000<0<SPf080[jn_00P0ZZZZ0:VYZ@2/[:`0YjNW0:JVYP2TY:@0XJ6Q09^KV`80UIFE00P0
Shn?08R8R025QHD0MWIf06YZJP1OGel0DU9B04Q8B080Bd];00h0DE5A05QHF01MGEd0IfMW071`L01e
MGD0PH6108J6QP2=SHd0Shn?09BDU02IVIT0WIfM0:>SX`80YjNW00@0Z:RX0:ZZZP2VYZH0Z:RX102T
Y:@00`2UYJD0YjNW0:>SX`020:BTY0070:>SX`2RXZ80X:2P09^KV`2IVIT0UYJF092@T00208Z:RP05
08B4Q01nOWh0M7Ad06i^KP1NGUh00P1ADE401`17AdL0BDU904Y:BP1<C4`0DE5A05QHF01GEeL00P1H
F5P04P1EEED0G5aL05aLG01NGUh0GemO06EUI@1XJ6P0JVYZ069RHP1QHF40I6AT065QH@1/K6`0GUiN
065QH@1VIVH0J6QX065QH@80I6AT00<0Hf=S06UYJ@1TI6@00P1UIFD03@1QHF40JVYZ065QH@1WIfL0
K6a/06][J`1/K6`0KFe]06m_K`1/K6`0KFe]06m_K`1`L7000`1gMgL01@1[Jf/0KFe]06e]K@1_Kfl0
LG5a0080MGEe00D0L71`07MgM`1eMGD0NGUi07MgM`0207QhN00907IfMP1gMgL0N7Qh07QhN01fMWH0
NWYj07UiN@1nOWh0NGUi0080N7Qh00X0O7al07emO@1hN7P0Ng]k0861P@1jNWX0O7al07YjNP1iNGT0
OGem0P1lO7`03`1kNg/0Ogmo09jNWP27QhL0LG5a06a/K01^KVh0M7Ad079bLP1cLg<0KVi^079bLP1k
Ng/0MWIf07QhN00207MgM`03079bLP1_Kfl0OGem0080Ng]k00D0NGUi079bLP1kNg/0Ogmo07emO@02
07inOP0807emO@1iNGT0N7Qh07emO@21PH40Q8B408j>SP2?Shl208N7Q`0F08:2PP1kNg/0PX:208V9
R@28R8P0Q8B408Z:RP28R8P0U9BD08^;R`26QXH0RHV908:2PP1iNGT0Ng]k0861P@2:RXX0T92@08f=
S@26QXH0PH610820P080Ti>C02P0UiNG08Z:RP27QhL0W9bL0:6QX@2ATI40UYJF0:2PX02TY:@0[jn_
0:RXZ02KVi/0ZJVY0:f][@2e]KD0/[:b0:ZZZP2RXZ80Zj^[0;6a/@2m_Kd0^k^k0:j^[P2VYZH0[Zj^
0;6a/@2h^;P0`L710;Vi^@2`/;00YjNW0:n_[`2e]KD0^k^k0<30`035aLD0a<C40;Vi^@2d];@0`<30
0P35aLD03P34a<@0_;bl0;Zj^P2i^KT0`l?30<C4a035aLD0bLW90<C4a033`l<0`L710;no_`33`l<0
a<C40P39bLT01P38b<P0`L710<71`@2o_kl0`<300<K6aP80cLg=0P39bLT02@38b<P0bl_;0<K6aP2d
];@0TI6A06a/K01QHF40GemO069RHP0206ATI00506EUI@1XJ6P0IfMW06IVIP1]KFd00P1/K6`00`1[
Jf/0Kfm_079bLP02075aL@80MWIf00/0Kfm_075aL@1aLG40L71`079bLP1^KVh0LW9b06UYJ@1`L700
J6QX06e]K@0206UYJ@0406a/K01XJ6P0KVi^06e]K@80Jf][01@0KFe]06UYJ@1QHF40I6AT06a/K01W
IfL0L71`075aL@1jNWX0Ng]k07moO`26QXH0Rh^;08b<S02?Shl0UIFE09JFUP2GUiL0VYZJ09NGU`80
VYZJ0P2IVIT209NGU`0509bLW02FUYH0UIFE09FEU@2HV9P00P2ATI40102@T900R8R808b<S026QXH2
08Z:RP80RHV900D0QXJ608V9R@25QHD0QXJ608Z:RP0208^;R`0408b<S02ATI40UIFE09>CT`80U9BD
00D0Ti>C09:BTP2BTY80Ti>C08f=S@03092@T00:08f=S@2<S8`0TI6A096AT@2=SHd0SXj>092@T02A
TI40Ti>C092@T080TY:B00T0Rh^;08j>SP2?Shl0SXj>08f=S@2BTY80TI6A08n?S`2;Rh/00P2<S8`0
1P2@T900S8b<08f=S@2DU9@0TI6A08n?S`<0T92@00h0TI6A092@T02?Shl0SXj>096AT@2BTY80UIFE
09BDU02CTi<0UYJF09>CT`2ATI40UYJF09BDU080TI6A01/0U9BD09ZJVP2FUYH0Vi^K09ZJVP2FUYH0
WIfM0;>c/`2m_Kd0][Jf0:>SX`1oOgl0De=C03Hf=P0^;Rh0;2`/02/[:`0];Bd0<c<c02`/;00Z:RX0
:b/[02XZ:P0_;bl0:b/[02d];@0c<c<00P0/;2`01P0b<S80<30`02PX:00d=3@0<S8b034a<@80<30`
02X0<S8b03dm?@0l?3`0<S8b034a<@0d=3@0<c<c030`<00^;Rh0;Bd]034a<@0c<c<0@41003De=@0h
>3P0=SHf03@d=00^;Rh0=CDe030`<00b<S80<c<c02TY:@0[:b/0<c<c03@d=00a<C40;Rh^038b<P0d
=3@0ADE504=3@`1=CDd0@41003`l?00^;Rh092@T01XJ6P0I6AT07QhN02<S8`0g=cL>0<SPf0003038
h=P30:^[Z`80[:b/00<0ZZZZ0:FUY@2SXj<00P2PX:005@2HV9P0VYZJ096AT@29RHT0Q8B407EeM@1f
MWH0IFEU05IFEP1ADE40C4a<04U9B@1:BTX0DU9B05MGE`1WIfL0LW9b07QhN023Ph<0Q8B408b<S002
09:BTP0909VIV@2PX:00YJFU0:BTY02XZ:P0YZJV0:RXZ02YZJT0ZZZZ0080Y:BT00h0YJFU0:>SX`2V
YZH0ZZZZ0:FUY@2WYjL0YZJV0:NWY`2SXj<0XZ:R09^KV`2LW9`0U9BD08b<S080RXZ:01X0Q8B407in
OP1dM7@0K6a/06=SH`1ADE40EEEE055AD@15ADD0A4A404];B`1>CTh0DE5A05ADE01OGel0EUIF05]K
F`1QHF40F5QH05eMG@1TI6@0HV9R06UYJ@1[Jf/0IVIV06UYJ@80K6a/0140IfMW069RHP1XJ6P0IFEU
06MWI`1RHV80JFUY069RHP1PH600I6AT06IVIP1TI6@0IVIV06UYJ@1]KFd0JVYZ06MWI`0206a/K004
06][J`1]KFd0IfMW06][J`80LG5a00H0MWIf07=cL`1dM7@0N7Qh06i^KP1_Kfl2079bLP80M7Ad101e
MGD0801fMWH0M7Ad07]kN`1kNg/0MGEe07YjNP1fMWH0MgMg07IfMP1hN7P0MgMg07emO@1jNWX0O7al
07moO`20P800OGem0820P021PH40P82007MgM`1oOgl0N7Qh07alO024Q8@0O7al07moO`1lO7`0Ng]k
08J6QP22PX80Lg=c0P1]KFd0401/K6`0LW9b07EeM@1]KFd0K6a/07AdM01fMWH0MgMg07]kN`1lO7`0
NGUi07=cL`1iNGT0Lg=c07YjNP1oOgl207QhN0040861P@1lO7`0MGEe07EeM@80N7Qh00<0OWin0820
P022PX800P24Q8@05@27QhL0Ph>308Z:RP21PH40Ng]k08Z:RP26QXH0O7al07moO`25QHD0PH6108R8
R02@T900RHV90861P@29RHT0QhN707moO`21PH40Ph>308^;R`0208N7Q`0@08:2PP1eMGD0QHF508F5
Q@2BTY80UiNG09>CT`2=SHd0W9bL09jNWP2QXJ40XZ:R09bLW02MWId0[:b/0:j^[P80ZZZZ00h0ZJVY
0;2`/02k^k/0^;Rh0:RXZ02TY:@0ZJVY0;Zj^P2m_Kd0]kNg0:j^[P2VYZH0XJ6Q0;Rh^080_kno01L0
^[Zj0;>c/`2][Jd0[Zj^0;Zj^P30`<00_kno0<;2`P2n_[h0_;bl0;Vi^@2o_kl0a/K60<G5a@33`l<0
_Kfm0;Zj^P2l_;`0a<C40<K6aP38b<P0b/[:0<_;b`020<G5a@80`L7100L0a/K60<C4a034a<@0alO7
0<S8b036a/H0a<C40080bLW90P3<c<`03038b<P0`l?30:b/[02=SHd0Kfm_065QH@1UIFD0I6AT065Q
H@1RHV80J6QX06a/K080J6QX00L0KFe]06][J`1^KVh0KVi^06][J`1ZJVX0L71`0080LG5a00d0L71`
079bLP1^KVh0Lg=c07AdM01^KVh0Kfm_06e]K@1aLG40K6a/071`L01]KFd0LW9b0080JVYZ01@0K6a/
06][J`1[Jf/0KVi^06YZJP1VIVH0IfMW069RHP1PH600JFUY06][J`1^KVh0LG5a071`L01kNg/0OWin
07moO`29RHT0Shn?08f=S@80U9BD0P2FUYH01@2HV9P0UYJF09JFUP2FUYH0U9BD0080UiNG00/0UIFE
09VIV@2DU9@0UiNG092@T02EUID0TI6A092@T02<S8`0SHf=08^;R`0208b<S007096AT@2<S8`0RHV9
08j>SP2:RXX0QHF508Z:RP0208b<S00<08j>SP2ATI40TY:B09JFUP2EUID0UYJF09:BTP2DU9@0TY:B
096AT@2>SXh0SHf=0P2<S8`2092@T00>096AT@2@T900TI6A092@T02BTY80U9BD092@T02CTi<0U9BD
09:BTP2DU9@0Shn?096AT@2=SHd308j>SP0408f=S@2>SXh0Shn?096AT@<0Shn?00T0R8R808n?S`2?
Shl0T92@096AT@2CTi<0SHf=096AT@2CTi<00P2>SXh01`2@T900Ti>C09>CT`2BTY80T92@096AT@2@
T9000`2BTY804`2CTi<0TY:B09:BTP2JVYX0UiNG09ZJVP2GUiL0V9RH0:2PX02h^;P0alO70<c<c031
`L40[Zj^08V9R@1CDe<0<C4a02d];@0W9bL00P0_;bl0400[:b/0;Bd]030`<00`<300:b/[02h^;P0_
;bl0;2`/02d];@0_;bl0=SHf038b<P0g=cL0<30`034a<@0d=3@203De=@80<30`00H0=SHf03De=@0f
=SH0<c<c03De=@0b<S8202`/;00@034a<@0];Bd0>SXj034a<@0h>3P0=SHf03Ti>@10@400>CTi03De
=@0g=cL0=CDe03<c<`0/;2`0;bl_02h^;P<0<C4a00d0=CDe03dm?@0o?cl0?clo04I6AP0k>c/0<C4a
02HV9P0P82006QXJ01`L700S8b<092@T00h0b>3H000<0<SPf080[:b/00H0[jn_0:j^[P2][Jd0[:b/
0:RXZ02QXJ420:2PX00M09jNWP2JVYX0UYJF08n?S`25QHD0Ogmo07]kN`1/K6`0GUiN05=CD`1?Cdl0
C4a<04Y:BP1ADE40FEUI06=SH`1aLG40MgMg0820P021PH40RXZ:08n?S`2EUID0VYZJ0::RXP2UYJD0
Xj>S0:NWY`2UYJD00P2ZZZX0102WYjL0Xj>S0:>SX`2TY:@30:FUY@80XZ:R0P2UYJD05@2RXZ80X:2P
09fMW@2LW9`0V9RH08f=S@29RHT0R8R808>3P`1mOGd0Lg=c06][J`1OGel0De=C05MGE`17AdL0BDU9
04I6AP1ADE40CTi>05EEE@0205UIF@0A05aLG01FEUH0G5aL05]KF`1JFUX0HV9R05iNGP1OGel0Hf=S
06EUI@1QHF40IFEU065QH@1TI6@0GemO06=SH`1QHF400P1RHV80201SHf<0IFEU06=SH`1YJFT0IfMW
06EUI@1SHf<0J6QX0P1UIFD0101^KVh0Jf][06a/K01[Jf/2071`L00?06e]K@1aLG40KFe]071`L01e
MGD0LW9b06m_K`1^KVh0Lg=c07EeM@1aLG40L71`07AdM01eMGD0Lg=c00<0N7Qh0`1eMGD00`1gMgL0
N7Qh07UiN@0207QhN00607IfMP1hN7P0P82007emO@20P800OWin0P1jNWX03P1oOgl0PX:207alO01n
OWh0OGem07alO01mOGd0Ogmo07alO01mOGd0P82007moO`1hN7P0Ng]k0P20P8001P1cLg<0KFe]075a
L@1cLg<0L71`07=cL`80N7Qh00@0MWIf07]kN`1oOgl0OGem0P1fMWH06P1eMGD0MgMg0820P01kNg/0
Ogmo0820P01iNGT0O7al071`L01kNg/0NWYj07moO`1nOWh0QHF507emO@1nOWh0QHF508:2PP28R8P0
Q8B407moO`22PX80RXZ:0820P021PH40Ogmo0P26QXH03@29RHT0T92@09>CT`27QhL0QXJ608F5Q@2:
RXX0Ph>308J6QP28R8P0RHV908n?S`2>SXh00P2;Rh/0702:RXX0T92@09NGU`2HV9P0UYJF09NGU`2K
Vi/0ZJVY0:BTY02EUID0W9bL0:^[Z`2b/[80^[Zj0:b/[02TY:@0/k>c0;Ng]`2f][H0/[:b0:RXZ02[
Zj/0^;Rh0;Bd]02h^;P0^[Zj0;>c/`2b/[820;Jf]P030;Rh^02o_kl0_[jn00<0/k>c00D0]kNg0;^k
^`35aLD0aLG50;fm_@020;Zj^P0:0;bl_02o_kl0`L710;no_`2n_[h0`l?30;fm_@31`L40a<C40<G5
a@<0b/[:00P0`l?30<;2`P2l_;`0`L710<O7a`3;bl/0bLW90<G5a@80bLW900d0a/K60<S8b02m_Kd0
ZJVY08J6QP1aLG40IVIV06MWI`1^KVh0K6a/06YZJP1YJFT0Jf][0080JFUY00<0Jf][06YZJP1[Jf/0
0P1`L703079bLP06071`L01dM7@0Lg=c06m_K`1cLg<0LW9b0P1aLG40101cLg<0K6a/071`L01/K6`2
06m_K`06071`L01/K6`0JFUY06a/K01_Kfl0J6QX0P1ZJVX06P1XJ6P0JFUY065QH@1WIfL0J6QX06i^
KP1_Kfl0LG5a07=cL`1fMWH0Ogmo08F5Q@2;Rh/0SHf=08j>SP2@T900Ti>C09JFUP2HV9P0Vi^K09ZJ
VP2EUID0V9RH092@T02FUYH0V9RH0P2EUID0202@T900TY:B092@T02@T900U9BD08f=S@2>SXh0Shn?
0P2=SHd01@2>SXh0TY:B092@T029RHT0Shn?0080RXZ:00H0S8b<08j>SP2;Rh/0SXj>092@T02EUID2
09NGU`0709ZJVP2CTi<0Shn?08n?S`2EUID0T92@08b<S00308j>SP04092@T02>SXh0TI6A09>CT`80
T92@00<0TY:B09BDU02ATI400P2DU9@00`2@T900TI6A08n?S`0208n?S`0;08f=S@2?Shl0Shn?08n?
S`2ATI40Shn?08f=S@2>SXh0Rh^;08V9R@2ATI400P2?Shl0302ATI40Shn?08j>SP2@T900TI6A08n?
S`2CTi<0Shn?09FEU@2;Rh/0Shn?08j>SP80TY:B00@0TI6A08n?S`2DU9@0Ti>C0P2DU9@0402FUYH0
V9RH09BDU02EUID0VIVI0:FUY@2o_kl0b/[:0=GEe@3Bd]80c<c<0;Rh^02DU9@0FUYJ03Hf=P0W9bL2
02/[:`80:RXZ0P0];Bd0300/;2`0;Rh^02XZ:P0Z:RX0:BTY02l_;`0/;2`0<S8b02d];@0l?3`0<c<c
02h^;P80<S8b00P0=cLg038b<P0d=3@0<c<c03Hf=P0g=cL0>3Ph03Ti>@80<30`0180<S8b02d];@0a
<C40=3@d03<c<`0b<S80>3Ph03Lg=`0d=3@0>c/k03Lg=`0_;bl0:b/[02`/;00b<S80<C4a02`/;00a
<C4202l_;`0<03De=@0k>c/0?3`l0410@00c<c<0>3Ph02/[:`0N7Qh07alO01`L700N7Qh08B4Q3P38
h=P000`0b>3H0`2XZ:P09`2^[Zh0Zj^[0:j^[P2VYZH0Zj^[0:BTY02NWYh0Vi^K09VIV@2FUYH0TI6A
08b<S027QhL0PH6107IfMP1]KFd0FUYJ051@D01:BTX0Bd];04m?C`1DE5@0I6AT06m_K`1gMgL0Q8B4
08V9R@2=SHd0TI6A09NGU`2JVYX0YZJV0:>SX`2RXZ80YZJV0:^[Z`2UYJD0ZJVY0:JVYP020;Fe]@0;
0:>SX`2VYZH0Y:BT0:FUY@2OWil0YJFU0:BTY02UYJD0XJ6Q0::RXP2NWYh00P2IVIT0=@2ATI40SXj>
08F5Q@26QXH0OWin07EeM@1]KFd0Hf=S05IFEP1EEED0D51@04Q8B015ADD0C4a<05IFEP1BDU80De=C
05EEE@1JFUX0GemO05iNGP1LG5`0GEeM06ATI01OGel0HF5Q06ATI01OGel0IfMW065QH@1RHV80H61P
069RHP1SHf<0I6AT06IVIP1XJ6P0GemO069RHP1UIFD0IVIV06QXJ01WIfL0HV9R06ATI01UIFD0I6AT
06QXJ01UIFD0Jf][06e]K@1/K6`0KFe]0080Kfm_00/0L71`075aL@1_Kfl0M7Ad07=cL`1bLW80LG5a
07=cL`1/K6`0LG5a07QhN00207=cL`0407IfMP1gMgL0M7Ad07AdM080NGUi00T0OGem07]kN`1gMgL0
N7Qh07AdM01mOGd0MgMg07QhN01lO7`00P1jNWX0101lO7`0MgMg07emO@1iNGT207alO00C07emO@1l
O7`0O7al07inOP1jNWX0O7al07QhN01nOWh0OGem07YjNP2GUiL0/K6a08J6QP1YJFT0H61P06IVIP1_
Kfl0Lg=c07EeM@0207AdM00;07MgM`1lO7`0OGem07IfMP1iNGT0Ng]k07IfMP1kNg/0O7al08B4Q022
PX800P1iNGT0301dM7@0NGUi07=cL`1eMGD0NWYj07emO@21PH40OWin08B4Q025QHD0QhN708:2PP80
Ogmo00D0NGUi07]kN`29RHT0OWin07moO`0208N7Q`0<08:2PP28R8P0Shn?08f=S@1kNg/0PH6108Z:
RP2<S8`0SHf=092@T02CTi<0UIFE0P2@T9009`2ATI40Rh^;08R8R02HV9P0X:2P09bLW02@T900WinO
0:^[Z`2ZZZX0YJFU0:BTY02VYZH0/[:b0;Ng]`2b/[80[:b/0:FUY@2YZJT0^;Rh0;Ng]`2h^;P0/K6a
0:^[Z`2^[Zh0^[Zj0;Vi^@2l_;`0^k^k0;:b/P2f][H0^KVi0;Ng]`2l_;`0`l?30;no_`2f][H0];Bd
0;Vi^@030<;2`P070;fm_@2f][H0^[Zj0;no_`33`l<0a<C40<K6aP020<G5a@040<?3``30`<00`l?3
0<S8b080alO700L0aLG50<;2`P2l_;`0`L710;jn_P33`l<0alO70080b<S80180`l?30;^k^`2QXJ40
Ph>306e]K@1TI6@0IVIV06MWI`1ZJVX0L71`06UYJ@1ZJVX0IfMW06YZJP1^KVh0KFe]07EeM@1_Kfl2
07=cL`0607EeM@1^KVh0Lg=c07EeM@1cLg<0M7Ad0`1bLW800`1aLG40MWIf07AdM002071`L00M06YZ
JP1_Kfl0KVi^075aL@1_Kfl0JVYZ06QXJ01]KFd0JVYZ06][J`1^KVh0K6a/06EUI@1YJFT0IfMW06YZ
JP1XJ6P0Jf][07AdM01bLW80MWIf0820P025QHD0QXJ608^;R`2?Shl0UYJF09FEU@2BTY800P2GUiL0
202FUYH0VYZJ09RHV02FUYH0U9BD09JFUP2EUID0Ti>C0P2BTY8209>CT`03092@T02>SXh0U9BD0080
SHf=00@0T92@09BDU02?Shl0S8b<0`2=SHd03P29RHT0SXj>08f=S@2@T900Ti>C092@T02FUYH0VIVI
09>CT`2FUYH0T92@096AT@2DU9@0Shn?0P2@T90208^;R`0908b<S02>SXh0S8b<08j>SP2?Shl0TI6A
092@T02?Shl0UIFE0080U9BD00`0Shn?09>CT`2=SHd0SHf=08j>SP2ATI40Ti>C08f=S@2;Rh/0Shn?
092@T02=SHd208j>SP0=08f=S@2;Rh/0RXZ:09:BTP2=SHd0SXj>08n?S`2<S8`0T92@096AT@2=SHd0
T92@09BDU00308n?S`0J09:BTP2CTi<0TY:B08n?S`2DU9@0Ti>C092@T02?Shl0UIFE09BDU02FUYH0
T92@096AT@2GUiL0[Zj^0<C4a03AdM40f=SH0=_Kf`3GemL0clo?0;no_`2LW9`0HV9R034a<@0/;2`2
02HV9P0902XZ:P0];Bd0;Rh^02l_;`0Y:BT0;2`/02d];@0[:b/0;bl_0080;2`/00@0<C4a03De=@0b
<S80<C4a0P0e=CD0100b<S80;bl_03Hf=P0j>SX203Lg=`0T03Hf=P0d=3@0>3Ph02h^;P0/;2`0;Bd]
02l_;`0^;Rh0;Bd]02h^;P0a<C40<S8b03Lg=`0b<S80=CDe02d];@0^;Rh0;2`/02d];@0Y:BT0:RXZ
030`<00[:b/0;Bd]03<c<`0j>SX0=CDe03`l?00n?Sh0>SXj03/k>`0X:2P092@T020P800K6a/07AdM
3P38h=P000`0b>3H0P2ZZZX08P2c/k<0[:b/0;2`/02a/K40[:b/0:^[Z`2ZZZX0X:2P09jNWP2LW9`0
UIFE096AT@2BTY80RXZ:08:2PP1nOWh0L71`06IVIP1MGEd0FEUI04Q8B01?Cdl0FUYJ06EUI@1bLW80
NGUi08F5Q@2<S8`0Shn?09FEU@2HV9P0W9bL09jNWP2VYZH20:BTY0040:RXZ02WYjL0YjNW0:FUY@80
ZJVY02@0ZZZZ0:FUY@2WYjL0WinO0:FUY@2VYZH0XZ:R0:2PX02UYJD0Xj>S09fMW@2KVi/0Ti>C092@
T02>SXh0QhN708V9R@21PH40MgMg06i^KP1UIFD0FUYJ059BDP1CDe<0BTY:04M7A`1>CTh0Bd];04m?
C`1BDU80EUIF05MGE`1MGEd0G5aL065QH@1KFe/205eMG@0505mOG`1SHf<0GemO05mOG`1PH6000P1R
HV801P1PH600IFEU06MWI`1QHF40Hf=S065QH@80Hf=S00X0H61P06MWI`1YJFT0Hf=S06ATI01XJ6P0
HV9R06EUI@1_Kfl0IfMW0P1ZJVX0101VIVH0JVYZ06][J`1dM7@2079bLP0;075aL@1cLg<0MWIf071`
L01bLW80LG5a079bLP1aLG40M7Ad079bLP1aLG400P1fMWH02P1gMgL0PH610861P@22PX80O7al07in
OP1kNg/0N7Qh07]kN`1oOgl207alO00<0861P@1iNGT0OGem07alO01iNGT0Ng]k07emO@1kNg/0OGem
07YjNP1nOWh0NGUi0P1kNg/207=cL`0H07YjNP1lO7`0XJ6Q0<o?c`2YZJT0IfMW069RHP1KFe/0KVi^
07=cL`1nOWh0NGUi07QhN01kNg/0Q8B407UiN@1hN7P0NGUi07inOP1jNWX0MWIf07=cL`20P800NWYj
0P1hN7P0201lO7`0MgMg07IfMP1dM7@0Ogmo07emO@1oOgl0P8200P22PX801`23Ph<0QhN707MgM`1j
NWX0RXZ:07alO020P8001025QHD03026QXH0QhN708N7Q`2ATI40Rh^;0820P02@T900UYJF09>CT`25
QHD0QXJ609RHV080RXZ:02h0Shn?09fMW@2BTY80TY:B09^KV`2MWId0YJFU09ZJVP2IVIT0Y:BT0;6a
/@2h^;P0[Jf]09fMW@2[Zj/0/k>c0;Jf]P2e]KD0[jn_0:^[Z`2e]KD0^[Zj0;Vi^@2j^[X0]kNg0:n_
[`2YZJT0]kNg0;bl_02o_kl0`L710;Rh^02XZ:P0][Jf0<30`034a<@0`L710;fm_@2c/k<0]kNg0;Zj
^P2o_kl0`/;20<71`@2o_kl0`L710P2m_Kd05@33`l<0b<S80<W9b@38b<P0`l?30;no_`32`/80`l?3
0<;2`P33`l<0a<C40<K6aP34a<@0_Kfm0;jn_P34a<@0`l?30<30`02YZJT0Shn?07IfMP0206EUI@08
065QH@1ZJVX0JFUY06YZJP1_Kfl0KFe]075aL@1_Kfl2079bLP0306e]K@1cLg<0L71`0080LW9b01D0
Lg=c06m_K`1dM7@0MWIf07=cL`1dM7@0MGEe07=cL`1eMGD0M7Ad07=cL`1`L700Kfm_06i^KP1`L700
JVYZ06e]K@1/K6`0Kfm_06a/K01]KFd00P1/K6`03P1ZJVX0Jf][06QXJ01YJFT0I6AT06IVIP1XJ6P0
K6a/07AdM01aLG40NGUi07YjNP1kNg/0QhN70P2<S8`05`2;Rh/0TY:B096AT@2DU9@0UIFE09JFUP2G
UiL0Ti>C09BDU02CTi<0V9RH09FEU@2BTY80TI6A09>CT`2DU9@0SXj>09:BTP2CTi<0S8b<092@T02B
TY80Shn?00<0T92@00d0Shn?08b<S02>SXh0Rh^;09FEU@2@T900Shn?09:BTP2DU9@0UIFE09RHV02F
UYH0W9bL0080TY:B00D0Rh^;08f=S@2>SXh0Rh^;08f=S@0208n?S`0708b<S02>SXh0S8b<08b<S02@
T900TY:B08f=S@05096AT@0:092@T02ATI40SHf=08b<S02?Shl0TY:B08n?S`2@T900SHf=08b<S080
Shn?0`2<S8`01@29RHT0Ti>C08j>SP2=SHd0T92@0080SXj>00/0TI6A08n?S`2?Shl0Shn?096AT@2B
TY80S8b<096AT@2@T900UYJF08n?S`02092@T00I09BDU02=SHd0Shn?092@T02?Shl0TY:B09BDU02P
X:00^KVi0<c<c03Cdm<0g=cL0=oOg`3Kfm/0emOG0=?Cd`2o_kl0UIFE05MGE`0c<c<0:RXZ02TY:@0[
:b/09BDU02`/;00202/[:`80;bl_00P0;Rh^02PX:00];Bd0:b/[03@d=00b<S80<30`03Ti>@80>3Ph
0100=cLg03/k>`0`<300=SHf03<c<`0i>CT0>c/k03Lg=`0d=3@0=CDe03@d=00b<S80:2PX02LW9`0[
:b/0;Bd]0`0c<c<01@0f=SH0<S8b03Ti>@0d=3@0;bl_0080:RXZ00<0;Rh^030`<00Z:RX00P0`<300
2@0h>3P0=cLg03Hf=P0j>SX0>3Ph03Hf=P0[:b/09bLW02@T900201hN7Ph0b>3H000<0<SPf080YjNW
00@0ZZZZ0:f][@2`/;00[Zj^0P2ZZZX01P2WYjL0X:2P0:6QX@2QXJ40VYZJ09NGU`80TY:B01H0QhN7
0861P@1eMGD0JFUY05mOG`1FEUH0DE5A051@D01HF5P0J6QX06e]K@1hN7P0Ph>308B4Q02>SXh0UIFE
09JFUP2NWYh0XZ:R0:VYZ@2VYZH0ZZZZ0P2VYZH02`2XZ:P0YJFU0:BTY02TY:@0YZJV0:NWY`2VYZH0
XJ6Q0:>SX`2RXZ80Xj>S0080YJFU0P2PX:00402KVi/0UiNG09BDU02?Shl0Rh^;08B4Q01lO7`0M7Ad
079bLP1OGel0EUIF04m?C`1>CTh0BTY:04M7A`1=CDd2055AD@0605IFEP1GEeL0FUYJ05YJFP1KFe/0
GemO0P1MGEd0201NGUh0G5aL06=SH`1LG5`0HV9R065QH@1PH600HF5Q0P1OGel3069RHP0H06IVIP1/
K6`0HF5Q06EUI@1XJ6P0HV9R06QXJ01^KVh0JVYZ06QXJ01WIfL0IFEU06i^KP1WIfL0JVYZ06UYJ@1U
IFD0KFe]071`L01^KVh0LW9b07EeM@1aLG40MWIf0P1cLg<00`1hN7P0NWYj07QhN002079bLP04075a
L@1fMWH0N7Qh07EeM@80NWYj00H0PH6107UiN@1kNg/0NWYj07UiN@1oOgl207alO00=07emO@1iNGT0
OWin07UiN@20P800NGUi07alO020P800O7al07inOP1mOGd0PH6107UiN@0207YjNP0<07UiN@1gMgL0
OGem07UiN@2<S8`0_[jn0:RXZ01]KFd0Fe]K05MGE`1ZJVX0KFe]0P1hN7P07`1mOGd0MWIf07YjNP1l
O7`0LG5a07]kN`1mOGd0NGUi07=cL`1iNGT0OGem07YjNP1iNGT0NWYj07EeM@1kNg/0NWYj075aL@1n
OWh0OGem08J6QP2<S8`0Ph>30861P@22PX80RXZ:08N7Q`25QHD0OWin07emO@23Ph<00P26QXH03@27
QhL0Rh^;08V9R@21PH40R8R808^;R`2<S8`0QXJ608N7Q`23Ph<0SHf=09FEU@2=SHd00`2ATI403P2F
UYH0XJ6Q09FEU@2MWId0UiNG08Z:RP2HV9P0WinO09ZJVP2KVi/0YJFU0;Bd]02j^[X0/;2`0P2UYJD0
102RXZ80[:b/0;Zj^P2c/k<20:j^[P040;Zj^P2k^k/0_kno0;bl_080/K6a01<0^k^k0;fm_@2n_[h0
`<300;bl_02g]kL0/;2`0;Rh^033`l<0_kno0<71`@2m_Kd0/K6a0:f][@2e]KD0_[jn0<71`@37alL0
a<C40080_[jn00D0`/;20<G5a@38b<P0aLG50<S8b0020<O7a`030<;2`P33`l<0`/;20080`<3001L0
aLG50<C4a031`L40^[Zj0:>SX`1mOGd0KVi^06UYJ@1XJ6P0KFe]06QXJ01]KFd0JVYZ075aL@1_Kfl0
Lg=c07inOP1bLW80L71`07=cL`1`L700MgMg07=cL`0207EeM@0307=cL`1eMGD0Ng]k0080MgMg00L0
MGEe079bLP1dM7@0MgMg079bLP1_Kfl0Lg=c0080L71`01L0M7Ad06][J`1[Jf/0KFe]071`L01[Jf/0
Kfm_06][J`1ZJVX0Jf][06UYJ@1SHf<0IfMW06ATI01RHV80IFEU06a/K01^KVh0L71`075aL@1mOGd0
PX:20861P@0208V9R@0508^;R`2?Shl0TY:B09BDU02EUID00P2FUYH02@2EUID0VIVI09JFUP2EUID0
TY:B096AT@2CTi<0TY:B08n?S`02092@T00409>CT`2?Shl0UIFE08f=S@80TI6A00/0Shn?096AT@2A
TI40SHf=08n?S`2>SXh0U9BD08f=S@2ATI40UIFE09JFUP0209NGU`0909JFUP2HV9P0Ti>C096AT@2<
S8`0TY:B08f=S@2>SXh0R8R80080RXZ:01L0S8b<08n?S`2>SXh0SHf=08n?S`2>SXh0SHf=09>CT`2B
TY80TI6A09>CT`2BTY80TI6A08n?S`2>SXh0Rh^;08j>SP2?Shl0T92@08n?S`2<S8`0SHf=092@T002
08n?S`0408b<S02>SXh0SHf=092@T080SXj>00X0RXZ:08f=S@2@T900SHf=092@T02CTi<0Shn?09:B
TP2@T900Rh^;0P2ATI40202?Shl0TI6A08b<S02>SXh0T92@09:BTP2ATI40SHf=0P2@T9004`2FUYH0
ZZZZ0<_;b`3EeMD0emOG0=kNgP3QhN40hn?S0=kNgP3IfMT0dm?C0;no_`2IVIT0EUIF034a<@0T92@0
;2`/02<S8`0W9bL00P0];Bd02P0[:b/0:RXZ02XZ:P0Y:BT0:b/[02h^;P0f=SH0;Bd]03<c<`0i>CT2
03De=@0<03/k>`0i>CT0<S8b03Hf=P0m?Cd0=SHf03Ph>00d=3@0?3`l03Ph>00f=SH0=CDe0P0];Bd0
1P0_;bl0:b/[02l_;`0];Bd0=3@d03<c<`80=cLg00D0<S8b02h^;P0Y:BT0;bl_02`/;00202l_;`0=
02h^;P0a<C40;Rh^02l_;`0h>3P0=CDe03Hf=P0k>c/0=SHf02d];@0W9bL08R8R020P800>0<SPf000
3038h=P20:BTY0060:VYZ@2^[Zh0[jn_0:j^[P2][Jd0[:b/0P2YZJT0802MWId0X:2P09^KV`2FUYH0
UIFE09>CT`28R8P0Ph>307UiN@1]KFd0IFEU05eMG@1CDe<0DE5A05IFEP1SHf<0L71`07QhN020P800
R8R808b<S02DU9@0VIVI09fMW@2OWil0X:2P0:JVYP2TY:@0Z:RX0:>SX`2YZJT0YJFU0P2VYZH00`2X
Z:P0YZJV0:FUY@020:>SX`80YJFU00@0YZJV0::RXP2SXj<0XZ:R0P2JVYX04P2FUYH0S8b<08b<S022
PX80P82007EeM@1/K6`0H61P05UIF@1?Cdl0BTY:04];B`1:BTX0D51@05EEE@1GEeL0D51@05EEE@80
EUIF00@0F5QH05YJFP1NGUh0H61P0P1OGel03P1NGUh0H61P05iNGP1PH600HV9R06IVIP1QHF40GUiN
06UYJ@1RHV80Hf=S06IVIP1WIfL0H61P0P1XJ6P06@1WIfL0I6AT06UYJ@1XJ6P0JVYZ06UYJ@1[Jf/0
JFUY075aL@1_Kfl0JFUY06][J`1cLg<0LG5a06e]K@1eMGD0Lg=c07EeM@1mOGd0LW9b07=cL`1jNWX0
MWIf07QhN01bLW800P1dM7@00`1gMgL0MWIf07=cL`0207]kN`0S07emO@1lO7`0Ng]k07alO01jNWX0
OGem07]kN`1iNGT0O7al07QhN01mOGd0OWin0820P01lO7`0OWin07moO`20P800OWin07UiN@20P800
OWin07]kN`1iNGT0O7al07YjNP1iNGT0NWYj0861P@2HV9P0/K6a09>CT`1YJFT0IVIV06e]K@1oOgl0
0P1lO7`00`1kNg/0M7Ad07]kN`0207QhN00:0861P@1eMGD0MWIf07]kN`1jNWX0N7Qh07emO@1lO7`0
MWIf08:2PP@0NWYj01`0MgMg08F5Q@2;Rh/0RHV908:2PP26QXH0QhN708B4Q026QXH0Ogmo07EeM@1i
NGT0Ph>308^;R`22PX80SHf=08n?S`22PX80SHf=08^;R`2:RXX0QHF5092@T02BTY80RXZ:09FEU@2G
UiL0Shn?0P28R8P02`2>SXh0XZ:R09>CT`2ATI40Y:BT09nOW`2FUYH0Ti>C09jNWP2XZ:P0YjNW0080
X:2P02@0[Jf]0;Fe]@2b/[80XZ:R0:6QX@2^[Zh0/K6a0;2`/02h^;P0][Jf0;Vi^@2g]kL0^k^k0;jn
_P2m_Kd0^[Zj0;:b/P2ZZZX0^KVi0;fm_@2n_[h0^k^k0;Bd]02j^[X0_;bl0<71`@32`/80_kno0;^k
^`2g]kL0[Zj^0;Bd]032`/80a<C40<?3``32`/820<71`@0A0<30`031`L40aLG50<?3``39bLT0alO7
0<K6aP34a<@0`/;20<71`@32`/80_kno0;2`/02IVIT0Ogmo06e]K@1XJ6P00P1[Jf/02P1]KFd0Kfm_
06][J`1cLg<0MGEe07AdM01eMGD0P820079bLP1eMGD207IfMP07079bLP1gMgL0MGEe07EeM@1gMgL0
MWIf07MgM`0207IfMP0=07EeM@1gMgL0Lg=c07QhN01gMgL0LW9b07=cL`1dM7@0L71`07AdM01aLG40
MGEe079bLP02075aL@0L071`L01XJ6P0K6a/06YZJP1/K6`0IFEU06YZJP1XJ6P0JFUY06IVIP1YJFT0
K6a/06m_K`1^KVh0NWYj07moO`22PX80Q8B408N7Q`2<S8`0TI6A092@T02BTY80U9BD09JFUP2IVIT0
V9RH09FEU@80U9BD01@0TY:B09>CT`2@T900SXj>09>CT`2ATI40SHf=092@T02ATI40Ti>C08f=S@2A
TI40Shn?09>CT`2BTY80Ti>C092@T02BTY80T92@096AT@80Ti>C00d0VYZJ09NGU`2IVIT0VYZJ092@
T02GUiL0TY:B08n?S`2ATI40S8b<08n?S`28R8P0Rh^;0080RXZ:00<0Shn?092@T02@T9000P2=SHd0
202<S8`0Shn?08j>SP2ATI40V9RH09FEU@2?Shl0T92@0P2=SHd01@2@T900SHf=08j>SP2=SHd0Shn?
0080SXj>00D0Shn?08b<S02<S8`0RXZ:08b<S00308j>SP0508Z:RP2;Rh/0Rh^;08b<S02>SXh00P2A
TI401`2BTY80SHf=092@T02?Shl0TY:B08n?S`2BTY800P2=SHd208j>SP0<08f=S@2?Shl0S8b<09:B
TP2DU9@0Y:BT0;Rh^03>c/h0f=SH0=[JfP3Ogml0hn?S0P3Ti>@03@3Ph>00f][J0=7Ad@2k^k/0Rh^;
04A4A00W9bL09RHV028R8P0Z:RX0:b/[02`/;00W9bL00P0Y:BT01`0[:b/0;Rh^02/[:`0b<S80;Rh^
034a<@0b<S800P0g=cL01@0l?3`0?Cdm03De=@0g=cL0=SHf0080=3@d00T0?3`l03De=@0j>SX0<S8b
02d];@0/;2`0:2PX02/[:`0/;2`00P0Y:BT0200`<300<S8b02h^;P0i>CT0<c<c038b<P0_;bl0=cLg
0P0_;bl03P0[:b/0;Bd]02l_;`0Y:BT0;Rh^030`<00a<C40;bl_03Lg=`0c<c<0<C4a02d];@0X:2P0
92@T3P38h=P000`0b>3H0P2VYZH01P2XZ:P0ZJVY0:j^[P2a/K40[:b/0:f][@80ZZZZ00X0Xj>S0:6Q
X@2NWYh0W9bL09FEU@2DU9@0SXj>08Z:RP1jNWX0MGEe0P1YJFT0501JFUX0G5aL05]KF`1SHf<0Kfm_
07QhN01oOgl0QXJ608f=S@2FUYH0VIVI09bLW02RXZ80WinO0:JVYP2YZJT0YJFU0:JVYP2XZ:P0YZJV
0P2SXj<05P2VYZH0Y:BT0:>SX`2SXj<0ZZZZ0:>SX`2ZZZX0YJFU0:>SX`2XZ:P0XJ6Q09nOW`2HV9P0
UiNG09:BTP2?Shl0Q8B407emO@1fMWH0JVYZ065QH@1NGUh2055AD@0J04Q8B01;Bd/0CTi>04];B`1@
D500DU9B05IFEP1GEeL0Fe]K061PH01LG5`0Hf=S05iNGP1PH600GemO06=SH`1OGel0Fe]K061PH01O
Gel0J6QX06=SH`1TI6@0HV9R065QH@1SHf<206ATI00?069RHP1VIVH0IfMW06MWI`1[Jf/0JVYZ06MW
I`1XJ6P0JVYZ06][J`1ZJVX0KVi^06e]K@1XJ6P0K6a/0080KVi^00<0MWIf07UiN@1cLg<00P1gMgL2
075aL@0907UiN@1aLG40NWYj07MgM`1kNg/0MgMg07]kN`1dM7@0NGUi0080OGem00T0NWYj07UiN@1h
N7P0O7al07emO@1kNg/0N7Qh07MgM`1oOgl00P1jNWX02P1oOgl0PX:207]kN`1lO7`0Ng]k07emO@1k
Ng/0NWYj07]kN`1nOWh207]kN`80O7al01<0NWYj07emO@1mOGd0QhN70:n_[`36a/H0SHf=06m_K`1a
LG40OGem07alO01kNg/0NWYj08:2PP1mOGd0P82007emO@1nOWh0NWYj0080MWIf0140OGem07YjNP1j
NWX0MgMg07UiN@1mOGd0Ogmo07UiN@1nOWh0QHF507emO@20P800Q8B408^;R`23Ph<0QXJ608>3P`02
0820P00C08F5Q@20P800PX:208V9R@2=SHd0S8b<08F5Q@2:RXX0Shn?08V9R@2:RXX0QhN7092@T02?
Shl0U9BD09VIV@2CTi<0SXj>08Z:RP02092@T00E09ZJVP2NWYh0WYjN09bLW02OWil0Z:RX0:2PX02J
VYX0TY:B09>CT`2UYJD0[Jf]09JFUP2NWYh0[Zj^0;>c/`2f][H0/;2`0:FUY@2VYZH0[Jf]0080^;Rh
00P0_Kfm0;jn_P2l_;`0^k^k0;Zj^P2n_[h0_kno0;Fe]@80/K6a01H0]kNg0;bl_02n_[h0`<300;Zj
^P2g]kL0`<300;bl_031`L40alO70<30`02i^KT0]KFe0;fm_@30`<00`/;20<S8b039bLT0alO70<30
`034a<@0_kno0P33`l<04034a<@0c<c<0<W9b@33`l<0]kNg0:2PX01oOgl0L71`06YZJP1^KVh0JVYZ
06a/K01^KVh0L71`06i^KP1aLG4307AdM00407IfMP1jNWX0MgMg079bLP80N7Qh00d0M7Ad07YjNP1j
NWX0NWYj07MgM`1fMWH0MGEe07IfMP1gMgL0MGEe07IfMP1bLW80Lg=c0080MGEe01@0Lg=c075aL@1`
L700K6a/079bLP1]KFd0KVi^06a/K01]KFd0L71`06UYJ@1ZJVX0KFe]06i^KP1WIfL0JFUY06ATI01V
IVH0JVYZ06i^KP80LG5a00L0M7Ad07QhN021PH40PH6108J6QP2<S8`0R8R80080T92@00<0U9BD09FE
U@2DU9@00P2CTi<2092@T00709:BTP2ATI40TY:B08n?S`2@T900U9BD09>CT`02092@T00909FEU@2A
TI40Shn?09BDU02CTi<0T92@09>CT`2DU9@0Ti>C0080TY:B00X0Ti>C09:BTP2GUiL0VYZJ09FEU@2J
VYX0V9RH09BDU02EUID0U9BD0P2<S8`0102;Rh/0TI6A09:BTP2;Rh/308j>SP0708b<S02?Shl0SHf=
08n?S`2DU9@0S8b<092@T002096AT@0E092@T02>SXh0T92@092@T02?Shl0T92@08f=S@2ATI40Ti>C
08j>SP2EUID0Shn?08f=S@2;Rh/0S8b<08N7Q`2:RXX0SHf=092@T02=SHd0Rh^;0080RXZ:00H0SXj>
08n?S`2CTi<0T92@096AT@2>SXh209>CT`0709NGU`2?Shl0TI6A08n?S`2<S8`0SHf=08j>SP0208Z:
RP0;08^;R`2@T900WinO0;>c/`39bLT0clo?0=KFeP3Kfm/0hN7Q0>?Sh`3Ti>@00P3UiND04`3QhN40
fm_K0=7Ad@2g]kL0NWYj03@d=00R8R809bLW02XZ:P0X:2P092@T02DU9@0W9bL0:b/[02`/;00[:b/0
<c<c038b<P0/;2`00P0d=3@202l_;`0403@d=00h>3P0=CDe03@d=080<C4a00P0;bl_03/k>`0m?Cd0
=3@d03De=@0h>3P0<c<c02TY:@80;Rh^00D0;Bd]02h^;P0/;2`0;Rh^03@d=00203Hf=P0C03<c<`0h
>3P0<30`02l_;`0];Bd0:b/[02TY:@0^;Rh0:RXZ02l_;`0Y:BT0<C4a03@d=00f=SH0>3Ph03Lg=`0d
=3@0<S8b034a<@0>0<SPf0003038h=P20:BTY0<0YZJV0P2/[:`00`2`/;00YZJV0:ZZZP020:JVYP0F
09jNWP2LW9`0UiNG09FEU@2?Shl0SXj>0820P01jNWX0LW9b06QXJ01WIfL0Fe]K05aLG01XJ6P0L71`
07YjNP24Q8@0QXJ609FEU@2DU9@0VIVI09ZJVP80WinO0P2YZJT0102WYjL0YJFU0:NWY`2UYJD30:JV
YP0b0::RXP2YZJT0Xj>S0:JVYP2XZ:P0Y:BT0:>SX`2WYjL0Y:BT09jNWP2MWId0VYZJ09JFUP2CTi<0
RXZ:08N7Q`20P800Lg=c06a/K01RHV80Fe]K05ADE01>CTh0BTY:05=CD`1>CTh0E5AD05EEE@1GEeL0
EEEE05YJFP1HF5P0GUiN05UIF@1MGEd0HF5Q069RHP1MGEd0GemO061PH01QHF40HV9R05mOG`1SHf<0
IFEU061PH01RHV80GemO06IVIP1QHF4206MWI`0C06=SH`1YJFT0HV9R06MWI`1XJ6P0IfMW06UYJ@1T
I6@0JFUY06YZJP1_Kfl0JVYZ079bLP1`L700KVi^07=cL`1aLG40NGUi071`L00207EeM@0307=cL`1`
L700MgMg0080N7Qh00H0MGEe0820P01jNWX0Ng]k079bLP1jNWX207alO00607moO`1hN7P0N7Qh0820
P01hN7P0OGem0P1hN7P0101iNGT0O7al07emO@1lO7`207emO@040861P@1mOGd0Ogmo07alO080Ogmo
02h0OGem07alO01jNWX0N7Qh07alO01iNGT0NWYj07moO`1nOWh0TY:B0;:b/P2HV9P0NGUi07]kN`20
P800O7al07emO@1nOWh0RHV908R8R020P800PH6107inOP20P800Ng]k07QhN020P800OWin07emO@1k
Ng/0O7al07inOP1mOGd0Ng]k07inOP1lO7`0Ogmo07alO023Ph<0R8R808F5Q@24Q8@0PX:208>3P`2=
SHd0Q8B40P20P8004026QXH0P8200861P@2CTi<0Rh^;08F5Q@24Q8@0TI6A08B4Q02>SXh0UIFE09ZJ
VP2:RXX0VYZJ0:6QX@2GUiL209FEU@040:>SX`2UYJD0X:2P09^KV`80Y:BT01L0UiNG0:>SX`2SXj<0
UiNG0:2PX02`/;00YJFU0:b/[02][Jd0YJFU0:NWY`2b/[80]kNg0;Rh^02d];@0]KFe0;2`/02a/K40
_;bl0<71`@30`<00];Bd0;Ng]`020;fm_@0E0<30`02g]kL0[Zj^0:f][@2g]kL0_kno0<71`@33`l<0
^;Rh0;2`/02j^[X0_Kfm0<30`034a<@0aLG50<71`@2k^k/0_Kfm0<C4a037alL0bLW90080b/[:00d0
alO70<;2`P2m_Kd0aLG50<K6aP37alL0^KVi09:BTP1oOgl0K6a/06UYJ@1/K6`0KVi^0080Kfm_00H0
L71`07=cL`1gMgL0MWIf07EeM@1dM7@207EeM@0707QhN01jNWX0O7al07QhN01jNWX0N7Qh07alO004
07QhN00507emO@1iNGT0NWYj07MgM`1iNGT00P1eMGD0201gMgL0M7Ad07AdM01bLW80LG5a06i^KP1c
Lg<0LG5a0P1_Kfl05@1XJ6P0KFe]06YZJP1[Jf/0J6QX06UYJ@1/K6`0JVYZ061PH01SHf<0KVi^06e]
K@1[Jf/0Kfm_07EeM@1hN7P0P82008>3P`27QhL0Rh^;08R8R00208n?S`07096AT@2CTi<0UYJF09BD
U02FUYH0Ti>C08n?S`02096AT@0409:BTP2>SXh0TI6A09BDU080TI6A00D0U9BD09FEU@2CTi<0Ti>C
09NGU`0309BDU00B096AT@2BTY80UYJF09VIV@2EUID0U9BD09FEU@2CTi<0V9RH09JFUP2OWil0V9RH
09JFUP2BTY80UYJF08n?S`2>SXh0T92@0P2=SHd308b<S003092@T02>SXh0Shn?0080TI6A00X0SXj>
09FEU@2@T900S8b<092@T02>SXh0T92@096AT@2EUID0T92@0P2?Shl00`2DU9@0Ti>C096AT@0208n?
S`0608b<S02>SXh0Rh^;08b<S02;Rh/0T92@0P2>SXh0;02?Shl0RXZ:08j>SP2=SHd0TI6A08j>SP2B
TY80Shn?096AT@2@T900TY:B08j>SP2;Rh/0S8b<08j>SP2:RXX0Shn?08j>SP2=SHd0T92@09NGU`2`
/;00_kno0<_;b`3EeMD0f][J0=_Kf`3Ng]h0h^;R0>?Sh`3Vi^H0inOW0>CTi03Rh^80f][J0<c<c02V
YZH0Fe]K02@T900X:2P0:BTY02PX:00Y:BT0;Bd]0P0/;2`01@0Z:RX0;Bd]038b<P0Z:RX09bLW00@0
;bl_00L0=SHf03@d=00d=3@0=CDe03Lg=`0i>CT0<c<c0080=cLg00T0>3Ph03De=@0f=SH0<C4a02d]
;@0_;bl0:b/[02d];@0`<3000P0];Bd05P0c<c<0=3@d03Ph>00g=cL0<c<c034a<@0`<300:b/[02`/
;00];Bd0;2`/030`<00^;Rh0;Bd]038b<P0^;Rh0<c<c03@d=00f=SH0?3`l03Xj>P0d=3@>0<SPf000
3038h=P20:6QX@0:0:>SX`2WYjL0ZZZZ0:VYZ@2[Zj/0[Zj^0:b/[02YZJT0YJFU0:6QX@80WYjN01L0
UYJF09FEU@2BTY80SHf=08N7Q`1oOgl0MGEe06i^KP1UIFD0Hf=S06EUI@1VIVH0Lg=c07emO@22PX80
QXJ608f=S@2EUID0Vi^K09VIV@2OWil0XJ6Q0:BTY0020:JVYP030:^[Z`2VYZH0Z:RX0080XZ:R00D0
[:b/0:NWY`2VYZH0Xj>S0::RXP030:FUY@0m0:>SX`2UYJD0WYjN09jNWP2HV9P0U9BD096AT@28R8P0
Q8B407moO`1hN7P0L71`06ATI01HF5P0EeMG05=CD`1:BTX0CDe=04m?C`1BDU80De=C05eMG@1JFUX0
F5QH05EEE@1NGUh0FEUI05aLG01OGel0H61P065QH@1SHf<0HF5Q06=SH`1OGel0Fe]K06=SH`1PH600
Hf=S05mOG`1UIFD0I6AT061PH01UIFD0Jf][06QXJ01RHV80Hf=S06MWI`1VIVH0JFUY06QXJ01ZJVX0
LW9b06][J`1eMGD0K6a/06i^KP1`L700M7Ad07EeM@0207=cL`0507IfMP1jNWX0LG5a075aL@1lO7`0
0P1eMGD207QhN00507UiN@1fMWH0NGUi07=cL`1hN7P0101iNGT01@1jNWX0Ng]k07emO@1kNg/0OWin
0080OGem01d0Ogmo07emO@1kNg/0O7al07]kN`1mOGd0Ng]k0861P@1nOWh0OGem0820P01kNg/0Ogmo
07]kN`1mOGd0O7al0820P01kNg/0NGUi07alO01nOWh0QhN707inOP1jNWX0PX:208N7Q`25QHD0Ph>3
08n?S`0208b<S00908Z:RP27QhL0QXJ608B4Q01mOGd0MWIf0820P01mOGd0Ph>30080NGUi00@0MGEe
07QhN01hN7P0N7Qh0P1iNGT04`1nOWh0RHV908R8R02;Rh/0SHf=08N7Q`25QHD0QhN708>3P`1lO7`0
NGUi0820P028R8P0QXJ608^;R`2CTi<0QXJ607inOP2<S8`00P2=SHd01P2@T900U9BD09ZJVP2MWId0
V9RH09nOW`80UIFE00<0T92@096AT@2PX:000P2TY:@02@2[Zj/0XZ:R0:>SX`2XZ:P0X:2P0:>SX`2^
[Zh0Vi^K09nOW`020;2`/00@0:f][@2VYZH0Zj^[0:n_[`2e]KD0`<300:ZZZP2SXj<0/k>c0;Rh^02l
_;`0_[jn0;Fe]@2a/K40[jn_0;fm_@80`<3000D0]kNg0:RXZ02_[jl0_Kfm0<G5a@020<30`0070;Zj
^P2c/k<0^k^k0<71`@35aLD0alO70<?3``020<;2`P80`l?300X0a<C40<W9b@3>c/h0b/[:0<K6aP33
`l<0^;Rh0:FUY@2=SHd0NGUi0P1bLW800`1eMGD0Kfm_071`L002071`L00?07MgM`1kNg/0MWIf07Qh
N01fMWH0N7Qh07EeM@1fMWH0MgMg07alO01kNg/0NGUi07EeM@1kNg/0NGUi0080N7Qh00<0M7Ad07Ui
N@1dM7@00`1gMgL0101eMGD0MgMg07EeM@1fMWH307=cL`06071`L01^KVh0LG5a071`L01YJFT0Jf][
0P1/K6`02P1^KVh0KFe]06EUI@1YJFT0IFEU06IVIP1SHf<0J6QX06UYJ@1_Kfl2079bLP0=07QhN01i
NGT0PH6108>3P`2:RXX0R8R808^;R`2>SXh0T92@08n?S`2CTi<0UIFE09>CT`0209BDU00909:BTP2@
T900TY:B09:BTP2@T900Shn?092@T02BTY80UIFE0080Ti>C00<0UIFE096AT@2CTi<00P2CTi<0202D
U9@0UIFE09>CT`2EUID0V9RH09>CT`2FUYH0VIVI0P2HV9P02P2KVi/0U9BD09RHV02CTi<0TI6A09:B
TP2@T900TI6A092@T02=SHd308b<S00308j>SP2@T900TI6A0080TY:B00@0T92@09:BTP2ATI40UiNG
0P2DU9@0202ATI40SXj>08f=S@2ATI40S8b<08f=S@2:RXX0SXj>0P2ATI40202@T900Rh^;08n?S`2<
S8`0Rh^;092@T02<S8`0T92@0P2>SXh01@2<S8`0SHf=08n?S`2>SXh0T92@0080SXj>01L0S8b<092@
T02BTY80SXj>092@T02<S8`0Rh^;08j>SP2<S8`0Shn?08V9R@2=SHd0U9BD0:VYZ@2j^[X0alO70<o?
c`3EeMD0f=SH0=_Kf`3Ng]h0h^;R0>CTi0030>GUi@0:0>OWi`3Rh^80fMWI0<?3``25QHD0>3Ph02<S
8`0X:2P0:b/[02TY:@80:b/[00P0:BTY02l_;`0Y:BT0:RXZ02l_;`0`<300<C4a03<c<`80<S8b00@0
=CDe03<c<`0g=cL0=cLg0P0e=CD01`0c<c<0=CDe03Hf=P0d=3@0=CDe03Hf=P0e=CD00P0^;Rh03`0/
;2`0;Bd]02XZ:P0_;bl0:b/[03<c<`0a<C40>CTi03`l?00`<300=3@d030`<00/;2`0;bl_030`<002
02/[:`0702d];@0^;Rh0;Rh^02d];@0[:b/0=3@d03Ph>00203Ti>@0303<c<`38h=P0b>3H00`0b>3H
000<0<SPf080XZ:R01D0WinO0:FUY@2/[:`0YjNW0:VYZ@2ZZZX0[:b/0:f][@2YZJT0Z:RX0:6QX@2O
Wil0WIfM09bLW02GUiL0UYJF08^;R`27QhL0NWYj07UiN@1^KVh00P1ZJVX0101UIFD0K6a/07EeM@1n
OWh208R8R00;09BDU02GUiL0VIVI09bLW02PX:00WinO0:ZZZP2YZJT0YJFU0:JVYP2TY:@00`2WYjL0
1@2UYJD0XZ:R0:>SX`2WYjL0Xj>S00<0YJFU0280XZ:R0:2PX02QXJ40W9bL09RHV02BTY80SHf=08b<
S020P800Ng]k071`L01QHF40GEeM05IFEP1IFET0De=C04Y:BP1;Bd/0C4a<05ADE01JFUX0DE5A05MG
E`1EEED0G5aL05iNGP1LG5`0I6AT065QH@1VIVH0KVi^06YZJP1QHF40GEeM0`1TI6@0401SHf<0HV9R
06MWI`1PH600IFEU065QH@1[Jf/0IVIV06UYJ@1VIVH0IfMW06=SH`1ZJVX0JFUY06QXJ01[Jf/306m_
K`0=071`L01_Kfl0LG5a075aL@1nOWh0Lg=c07IfMP1bLW80NGUi07]kN`1gMgL0MGEe07QhN00207]k
N`0507IfMP1hN7P0NGUi07YjNP1iNGT00`1jNWX0D`1iNGT0Ogmo0861P@1mOGd0NWYj07alO020P800
NGUi07YjNP1kNg/0Ogmo0820P021PH40OGem07inOP1lO7`0PX:207emO@20P800O7al08:2PP21PH40
OGem08B4Q01oOgl0O7al07IfMP1lO7`0NGUi0820P01lO7`0MgMg08R8R02ATI40YjNW0:b/[02FUYH0
Shn?09NGU`2CTi<0TI6A092@T028R8P0RHV908B4Q026QXH0OWin07alO025QHD0NWYj07]kN`1jNWX0
Ogmo07MgM`1jNWX0Ng]k07EeM@26QXH0RHV908Z:RP1oOgl0SHf=08N7Q`24Q8@0O7al07YjNP23Ph<0
Q8B40861P@2=SHd0TI6A09>CT`2<S8`0QHF508^;R`1nOWh0T92@09^KV`2ATI40SHf=0:BTY02GUiL0
Ti>C0080TY:B0340WIfM09RHV02>SXh0X:2P0:f][@2ZZZX0WYjN09RHV02VYZH0X:2P0:FUY@2d];@0
/[:b0:FUY@2QXJ40XZ:R0:NWY`2a/K40ZZZZ0:f][@2ZZZX0^k^k0;bl_02g]kL0/;2`0:NWY`2UYJD0
]kNg0<71`@2o_kl0/k>c0;:b/P2f][H0_;bl0<30`031`L40][Jf0;:b/P2e]KD0`<300<71`@33`l<0
`/;20;fm_@31`L40_[jn0<30`02o_kl0aLG500<0b<S800X0`/;20<C4a035aLD0bLW90<K6aP2g]kL0
WinO08:2PP1ZJVX0Lg=c0P1dM7@03`1/K6`0MGEe07=cL`1_Kfl0LG5a07=cL`1aLG40N7Qh07YjNP1i
NGT0OGem07QhN01iNGT0MWIf07QhN00207YjNP0307MgM`1jNWX0NGUi0080MGEe00<0N7Qh07YjNP1i
NGT00P1jNWX207IfMP0307MgM`1fMWH0Lg=c0080MGEe00@0Lg=c07EeM@1aLG40LW9b0P1`L700201a
LG40L71`06a/K01`L700KVi^06e]K@1[Jf/0JFUY0`1WIfL0101`L700K6a/071`L01`L70207EeM@05
07emO@23Ph<0QhN708J6QP28R8P00P2?Shl209:BTP80U9BD00<0UIFE09>CT`2?Shl00P2ATI401@2?
Shl0TY:B08j>SP2>SXh0Ti>C0080U9BD00<0UYJF09FEU@2CTi<00P2@T9001`2EUID0TI6A09RHV02G
UiL0Ti>C09FEU@2DU9@00P2GUiL02@2IVIT0VYZJ09ZJVP2EUID0UiNG092@T02?Shl0S8b<08j>SP02
092@T00308j>SP2?Shl0SXj>0080SXj>00H0Shn?096AT@2?Shl0Shn?09>CT`2BTY82092@T009096A
T@2DU9@0SHf=092@T02ATI40Shn?08j>SP2=SHd0TI6A00<0SHf=00@0SXj>08b<S02>SXh0Shn?0P2;
Rh/0102=SHd0SXj>08f=S@2?Shl208b<S00:08n?S`2=SHd0Shn?08j>SP2=SHd0Ti>C08n?S`2>SXh0
T92@08n?S`80SHf=0P2:RXX208N7Q`0<08j>SP2CTi<0/K6a0<;2`P39bLT0d=3@0=CDe03GemL0fm_K
0=gMg@3Ph>00h^;R0P3Ti>@03P3Vi^H0inOW0>GUi@3Ogml0emOG0;Vi^@1`L700:BTY02HV9P0T92@0
;Bd]02PX:00Y:BT0:RXZ0P0^;Rh01@0];Bd0:BTY030`<00c<c<0:2PX0080;Bd]00H0<c<c03De=@0c
<c<0=cLg03Ti>@0k>c/203Hf=P0303De=@0h>3P0=3@d0080?Cdm01d0>c/k034a<@0/;2`0;bl_02d]
;@0_;bl0:b/[02d];@0a<C40=CDe038b<P0c<c<0=SHf03De=@0b<S80=SHf02`/;00W9bL0:RXZ038b
<P0d=3@0=SHf02XZ:P0];Bd0:b/[030`<00g=cL0<S8b034a<@0>0<SPf0003038h=P20:2PX0050:FU
Y@2QXJ40ZZZZ0:VYZ@2ZZZX00`2/[:`0702YZJT0Z:RX0::RXP2QXJ40W9bL09ZJVP2IVIT0UYJF08j>
SP28R8P0P82007QhN01dM7@0L71`06e]K@1WIfL0L71`07MgM`20P800QhN708Z:RP2JVYX0UYJF09^K
V`2MWId0YJFU0::RXP2YZJT20:RXZ00N0:>SX`2VYZH0ZZZZ0:ZZZP2TY:@0YJFU0:6QX@2TY:@0YJFU
0::RXP2PX:00YZJV0:FUY@2QXJ40WYjN09nOW`2LW9`0UIFE08Z:RP2>SXh0QHF508:2PP1gMgL0JVYZ
061PH01IFET0E5AD051@D01>CTh0DU9B0P1FEUH02P1OGel0I6AT05]KF`1NGUh0G5aL061PH01OGel0
I6AT06QXJ01ZJVX206=SH`06065QH@1UIFD0IFEU069RHP1OGel0HV9R0P1VIVH2069RHP0>06ATI01U
IFD0I6AT06=SH`1XJ6P0KFe]06IVIP1[Jf/0KVi^06a/K01ZJVX0Jf][06e]K@1_Kfl3071`L006079b
LP1[Jf/0N7Qh079bLP1mOGd0L71`0P1dM7@02P1hN7P0LG5a07MgM`1gMgL0Ng]k07moO`1gMgL0NGUi
07MgM`1kNg/207EeM@0407QhN01iNGT0MgMg0861P@80NGUi00P0OWin07emO@1iNGT0O7al07QhN01n
OWh0NWYj07inOP80Ng]k00<0O7al08>3P`1oOgl00P1nOWh01021PH40OGem07alO020P80307alO00D
07emO@1lO7`0OWin07alO01iNGT0O7al08Z:RP2^[Zh0];Bd09ZJVP2@T900V9RH0:>SX`2KVi/0UYJF
09>CT`2ATI40SXj>08J6QP1oOgl20861P@0J07alO01jNWX0OWin07emO@1gMgL0N7Qh07emO@1hN7P0
Q8B407moO`26QXH0R8R808F5Q@2=SHd0QHF508J6QP24Q8@0R8R808F5Q@23Ph<0P82008^;R`2KVi/0
SXj>092@T02IVIT2092@T0060:2PX02HV9P0UIFE09FEU@2GUiL0WIfM0P2HV9P0702EUID0VIVI0:2P
X02GUiL0U9BD0:NWY`2_[jl0Y:BT0:^[Z`2PX:00ZJVY0:j^[P2XZ:P0ZJVY0:f][@2OWil0Vi^K0:^[
Z`2^[Zh0^KVi0;:b/P2a/K40[Zj^0;Jf]P2g]kL0/;2`0:VYZ@2/[:`20;^k^`0E0<30`02o_kl0]KFe
0;Bd]02j^[X0_kno0;jn_P32`/80_[jn0;^k^`2l_;`0_kno0<?3``37alL0bLW90<?3``2n_[h0_Kfm
0<71`@2o_kl0a/K600<0b/[:00L0`/;20;Zj^P2UYJD0Q8B4071`L01_Kfl0KVi^0080NGUi00@0N7Qh
075aL@1cLg<0NWYj0`1gMgL0201eMGD0OGem07UiN@1fMWH0N7Qh07emO@1kNg/0M7Ad0P1jNWX0101o
Ogl0MWIf07alO01iNGT207YjNP0M07alO01iNGT0Ng]k07QhN01lO7`0NWYj07UiN@1cLg<0MWIf075a
L@1dM7@0LW9b071`L01bLW80L71`07IfMP1`L700LG5a06e]K@1_Kfl0JFUY06YZJP1]KFd0JFUY06a/
K01TI6@0IVIV06=SH`1YJFT00P1/K6`03P1`L700M7Ad07EeM@1iNGT0P82008J6QP24Q8@0RXZ:08j>
SP2CTi<0SHf=09:BTP2ATI40Ti>C0P2ATI402P2BTY80TI6A08b<S02DU9@0T92@08n?S`2>SXh0TY:B
096AT@2EUID309>CT`0<096AT@2DU9@0TY:B09JFUP2BTY80VYZJ09NGU`2MWId0VYZJ09FEU@2IVIT0
VYZJ0P2FUYH0102KVi/0UIFE09NGU`2DU9@208j>SP0508n?S`2CTi<0TY:B092@T02BTY800P2@T900
1`2=SHd0TI6A08j>SP2BTY80TI6A09:BTP2@T9000P2CTi<04`2EUID0T92@092@T02ATI40Ti>C08^;
R`2?Shl0T92@08f=S@2@T900Shn?08j>SP2=SHd0T92@08^;R`2<S8`0QhN708^;R`2>SXh00`2=SHd0
1P2:RXX0T92@08j>SP29RHT0S8b<08n?S`80SXj>00D0Shn?08f=S@2ATI40SHf=08b<S00308^;R`09
08Z:RP2;Rh/0Ti>C0:ZZZP32`/80alO70<o?c`3De=@0f][J0080g=cL01X0g]kN0>3Ph03Ti>@0iNGU
0>CTi03WinL0iNGU0>;RhP3Ph>00e]KF0;Bd]01`L700;bl_02@T900Q8B40:RXZ02HV9P0X:2P092@T
02PX:00Y:BT0;Bd]030`<00^;Rh0<30`03<c<`80<C4a00T0:BTY02h^;P0d=3@0>SXj03De=@0c<c<0
<S8b03<c<`0`<3000`0c<c<02@0e=CD0=3@d03<c<`0^;Rh0<30`02d];@0^;Rh0;Bd]030`<002038b
<P06034a<@1=CDd0=cLg03@d=00b<S80=CDe0P0_;bl02`0/;2`0=cLg03Hf=P0h>3P0;Rh^02d];@0^
;Rh0>CTi03<c<`0b<S80>3Ph00h0b>3H000<0<SPf080XZ:R02<0Xj>S0:6QX@2SXj<0YjNW0:^[Z`2Y
ZJT0/;2`0:n_[`2WYjL0Zj^[0:FUY@2NWYh0XJ6Q09ZJVP2EUID0UiNG08n?S`2;Rh/0QHF507alO01i
NGT0Lg=c07MgM`1eMGD0LW9b07QhN023Ph<0S8b<09RHV02FUYH0VYZJ09fMW@2NWYh0Xj>S0:NWY`02
0:FUY@030:BTY02UYJD0Z:RX00<0YJFU00/0Y:BT0::RXP2PX:00YJFU0:JVYP2UYJD0Y:BT0:>SX`2O
Wil0WYjN09nOW`0209NGU`0J09:BTP2@T900Q8B40820P01bLW80JVYZ06=SH`1JFUX0EEEE04e=C@1>
CTh0C4a<04e=C@1?Cdl0EeMG06EUI@1WIfL0Fe]K06ATI01UIFD0Hf=S05mOG`1QHF40GUiN05mOG`1S
Hf<206EUI@0306=SH`1RHV80J6QX0080HV9R00@0IVIV069RHP1SHf<0I6AT0`1SHf<0101VIVH0JVYZ
06YZJP1VIVH306YZJP0=06a/K01]KFd0KFe]07AdM01aLG40KVi^07EeM@1bLW80NGUi07IfMP1eMGD0
M7Ad07MgM`0207EeM@0307UiN@1kNg/0MgMg0080MgMg00@0NGUi07MgM`1kNg/0Ng]k0P1jNWX01`1l
O7`0NWYj07moO`1lO7`0MgMg07QhN01gMgL00P1hN7P01@1nOWh0OGem08B4Q01oOgl0OGem00<0Ogmo
00<0OWin08>3P`1nOWh00P1nOWh01P20P800Ng]k08:2PP1nOWh0Ogmo0820P080OGem01<0Ng]k07in
OP1kNg/0NGUi07moO`24Q8@0Shn?08:2PP1oOgl0RHV909nOW`2VYZH0WinO09JFUP2HV9P0Ti>C09:B
TP26QXH0PH610080OWin00P0MGEe07=cL`1iNGT0Ng]k07emO@28R8P0O7al08J6QP80QhN700@0SHf=
08F5Q@27QhL0Rh^;0P28R8P04@23Ph<0RXZ:08B4Q02;Rh/0R8R809NGU`2QXJ40V9RH096AT@2BTY80
UIFE09ZJVP2>SXh0Ti>C09FEU@2=SHd0VIVI0080ZZZZ00@0XZ:R09:BTP2FUYH0YjNW0P2QXJ420;2`
/00Y0:b/[02LW9`0X:2P0:b/[02UYJD0ZJVY0;2`/02/[:`0ZJVY0:BTY02OWil0[:b/0;Vi^@2h^;P0
[:b/0:^[Z`2/[:`0/;2`0;bl_02c/k<0Zj^[0;2`/02j^[X0`/;20<G5a@2n_[h0][Jf0;6a/@2m_Kd0
`l?30<K6aP33`l<0_Kfm0;Zj^P2k^k/0`<300<K6aP37alL0`l?30<S8b033`l<00P2n_[h01`37alL0
bLW90<O7a`2a/K40VIVI07moO`1^KVh00P1]KFd03`1bLW80MgMg07IfMP1iNGT0MGEe07IfMP1gMgL0
MWIf07UiN@1gMgL0N7Qh07inOP1kNg/0N7Qh07YjNP0307QhN00507YjNP1nOWh0Ogmo07IfMP1jNWX0
0`1kNg/04`1oOgl0O7al07]kN`1kNg/0MgMg07QhN01cLg<0LW9b07=cL`1aLG40MgMg07IfMP1gMgL0
Lg=c075aL@1dM7@0Kfm_079bLP1aLG400P1^KVh0101_Kfl0KVi^06UYJ@1YJFT206MWI`0C06][J`1X
J6P0KFe]075aL@1/K6`0Lg=c07EeM@1dM7@0OGem0861P@26QXH0RHV908Z:RP2=SHd0Rh^;092@T02F
UYH0TI6A09:BTP0309BDU00808f=S@2DU9@0Ti>C08n?S`2ATI40U9BD096AT@2BTY8209>CT`0;09ZJ
VP2DU9@0TI6A09FEU@2DU9@0UYJF09FEU@2IVIT0Vi^K09ZJVP2GUiL00P2IVIT209JFUP0509NGU`2A
TI40TI6A09FEU@2ATI400P2>SXh0102HV9P0TY:B09>CT`2DU9@2092@T00;08n?S`2@T900TI6A09:B
TP2ATI40UIFE092@T02CTi<0TY:B09>CT`2DU9@00`2@T9000`2;Rh/0T92@092@T00208j>SP0308f=
S@2<S8`0SXj>0080SXj>01l0Rh^;08f=S@2<S8`0RXZ:08b<S02:RXX0SHf=08^;R`29RHT0R8R808^;
R`2ATI40SHf=092@T02;Rh/0SHf=08n?S`2@T900UYJF08f=S@2;Rh/0RXZ:08R8R02:RXX0SHf=0:6Q
X@2h^;P0b/[:0<k>cP3Cdm<0f=SH0080g=cL00<0gMgM0>3Ph03Shn<00`3Shn<20>CTi0060>;RhP3O
gml0emOG0;^k^`23Ph<0@d=30P0/;2`02`0W9bL0:b/[02/[:`0W9bL0:BTY02`/;00b<S80:b/[030`
<00e=CD0:b/[0080<C4a00`0:RXZ030`<00];Bd0=3@d03Lg=`0e=CD0=SHf03Lg=`0`<300<S8b03Lg
=`0f=SH203@d=080=CDe00L0<c<c02`/;00];Bd0;Rh^03De=@0`<300;bl_0080<c<c00/0;Rh^034a
<@0`<300;Bd]02l_;`0a<C40;Rh^03Xj>P0`<300>3Ph038b<P0202/[:`0402PX:00_;bl0<30`03De
=@h0b>3H000<0<SPf080X:2P0P2RXZ800`2SXj<0YJFU0:>SX`020:RXZ080[Zj^01l0YjNW0:ZZZP2R
XZ80XZ:R09jNWP2KVi/0UIFE09NGU`2>SXh0T92@08F5Q@1mOGd0O7al07UiN@1eMGD0N7Qh07MgM`1m
OGd0RHV908b<S02BTY80V9RH09ZJVP2KVi/0X:2P0:6QX@2SXj<0Y:BT0:RXZ02VYZH0Y:BT0080ZJVY
00T0Z:RX0::RXP2UYJD0Xj>S0:FUY@2WYjL0X:2P0:FUY@2QXJ400P2PX:00102KVi/0UiNG09NGU`2A
TI4208N7Q`0:07inOP1bLW80JFUY069RHP1HF5P0EEEE04i>CP1=CDd0CTi>05MGE`80EEEE00<0F5QH
05aLG01RHV800P1PH6006@1SHf<0G5aL069RHP1RHV80IFEU069RHP1TI6@0IFEU06=SH`1YJFT0J6QX
06=SH`1NGUh0IVIV065QH@1YJFT0IVIV06=SH`1RHV80GemO06EUI@1/K6`0KVi^06a/K01]KFd00P1Z
JVX0201YJFT0Kfm_06m_K`1bLW80LG5a07=cL`1gMgL0LG5a0P1dM7@0101jNWX0MWIf07IfMP1hN7P3
07]kN`0507UiN@1hN7P0OWin07UiN@1mOGd00P1lO7`207inOP0H07YjNP1dM7@0Ng]k07alO01jNWX0
PH6107QhN01gMgL0O7al0861P@1nOWh0O7al07]kN`1mOGd0Ng]k07moO`22PX80P82007alO01oOgl0
O7al07emO@22PX80OWin0`20P800<@1nOWh0Ogmo08:2PP1lO7`0OGem07inOP1gMgL0N7Qh07YjNP1l
O7`0Ng]k07MgM`1iNGT0RXZ:08n?S`2=SHd0VIVI09BDU02EUID0WIfM09BDU02;Rh/0RHV90861P@1j
NWX0MWIf07AdM01hN7P0NWYj08^;R`21PH40QHF508j>SP24Q8@0RXZ:08R8R02@T900RXZ:09RHV02E
UID0S8b<09FEU@2FUYH0RXZ:08b<S02>SXh0Shn?09RHV02QXJ400P2?Shl01P2RXZ80UiNG08b<S02J
VYX0WIfM09BDU080Ti>C0P2SXj<0602?Shl0WYjN0:2PX02ZZZX0YjNW09NGU`2WYjL0[Jf]0:JVYP2T
Y:@0XJ6Q0:NWY`2e]KD0/K6a0:n_[`2/[:`0[Jf]0:JVYP2/[:`0/K6a0;Vi^@2k^k/0ZZZZ0:6QX@80
];Bd01H0_[jn0;Vi^@2`/;00[:b/0;bl_033`l<0`/;20;Vi^@2b/[80^;Rh0;jn_P30`<00`L710<G5
a@32`/80_kno0<?3``2o_kl0`L710<C4a038b<P0a/K60P33`l<02@2n_[h0ZJVY08V9R@1fMWH0LW9b
06i^KP1]KFd0Lg=c07EeM@0207alO00B07YjNP1kNg/0NWYj07emO@1lO7`0OGem08J6QP21PH40Ogmo
07]kN`1fMWH0N7Qh07MgM`1hN7P0P82007alO01nOWh0O7al0P1kNg/01`1jNWX0Ogmo07moO`1mOGd0
O7al07UiN@1jNWX00P1hN7P0101dM7@0MWIf07EeM@1eMGD207=cL`08075aL@1]KFd0L71`071`L01/
K6`0Kfm_07=cL`1]KFd206a/K00@06e]K@1ZJVX0JFUY06MWI`1YJFT0K6a/06UYJ@1_Kfl0LG5a07=c
L`1aLG40Lg=c07]kN`20P800OWin08:2PP80RHV90P2ATI404P2CTi<0U9BD09BDU02BTY80T92@08f=
S@2ATI40Shn?09>CT`2@T900TI6A092@T02?Shl0VIVI092@T02BTY80U9BD09NGU`80Ti>C00h0UIFE
09>CT`2GUiL0UiNG09VIV@2HV9P0UYJF09FEU@2LW9`0VIVI09RHV02GUiL0U9BD09FEU@80Ti>C0P2D
U9@01@2ATI40UiNG08n?S`2EUID0Ti>C0080Shn?02H0TY:B08n?S`2=SHd0U9BD09>CT`2@T900TY:B
09NGU`2@T900Shn?092@T02=SHd0Shn?08f=S@2@T900TY:B08^;R`2@T900SHf=08n?S`2=SHd0SXj>
08f=S@2;Rh/0S8b<08f=S@2>SXh0QhN708b<S02:RXX0SXj>08b<S02:RXX0RHV908j>SP2?Shl0RHV9
08^;R`80S8b<00D0SHf=08^;R`2;Rh/0Rh^;08N7Q`0308V9R@0=09JFUP2/[:`0`<300<k>cP3Cdm<0
e]KF0=_Kf`3Lg=`0gMgM0=kNgP3Ph>00hN7Q0>;RhP020>?Sh`090>CTi03Rh^80gmoO0=WIf@3=cLd0
^;Rh08B4Q01=CDd0<30`0080;Rh^0`0Z:RX01`0V9RH0;Rh^03<c<`0W9bL0:b/[02TY:@0c<c<00P0^
;Rh01P0Y:BT0:b/[03Hf=P0d=3@0=SHf03Ph>080<C4a00<0>CTi03Lg=`0h>3P00P0a<C402@0f=SH0
?Shn03<c<`0l?3`0?Cdm03Hf=P0d=3@0<c<c03Ti>@0202h^;P07030`<00f=SH0>c/k03<c<`0d=3@0
;bl_02h^;P02034a<@0902/[:`0X:2P0;2`/02h^;P0/;2`0;Rh^038b<P0];Bd0<c<c00h0b>3H000<
0<SPf0<0WYjN00@0X:2P0:6QX@2VYZH0Y:BT0P2WYjL0102/[:`0[jn_0:b/[02ZZZX20:FUY@090:2P
X02NWYh0V9RH09FEU@2ATI40SHf=08N7Q`22PX80PH610080Ng]k00`0NWYj07moO`1nOWh0QhN708Z:
RP2ATI40UYJF09ZJVP2MWId0XJ6Q0:FUY@2WYjL20:BTY00>0:FUY@2VYZH0YZJV0:JVYP2TY:@0XJ6Q
0:FUY@2WYjL0YZJV0:RXZ02TY:@0Z:RX0:BTY02RXZ8209nOW`0E09VIV@2FUYH0UIFE08F5Q@28R8P0
OWin07QhN01[Jf/0GUiN05YJFP1FEUH0CDe=051@D01>CTh0DU9B05IFEP1HF5P0De=C05mOG`1LG5`0
GUiN0080Hf=S00H0HF5Q05iNGP1OGel0GUiN05mOG`1SHf<206ATI00305mOG`1VIVH0J6QX0080I6AT
00H0Hf=S06EUI@1UIFD0HV9R06EUI@1VIVH206QXJ00506m_K`1^KVh0IfMW06IVIP1YJFT00`1]KFd0
0`1bLW80M7Ad07=cL`02075aL@0=07MgM`1dM7@0MGEe07MgM`1iNGT0N7Qh07]kN`1iNGT0N7Qh07Yj
NP1iNGT0O7al07inOP0307YjNP<0Ogmo01@0NWYj07UiN@1lO7`0NWYj07moO`1lO7`0OGem07inOP1o
Ogl0OGem07]kN`21PH40NWYj07]kN`1jNWX0P82007moO`1kNg/0Ogmo0861P@80O7al00/0Ogmo07al
O020P800OWin07alO028R8P0Ogmo07]kN`1lO7`0PH6107emO@0207]kN`0Y07emO@1lO7`0NGUi07mo
O`1nOWh0Q8B40820P023Ph<0QXJ608F5Q@2ATI40W9bL092@T02FUYH0Shn?08Z:RP21PH40NGUi07Yj
NP1nOWh0Ph>308V9R@2?Shl0UiNG09FEU@2?Shl0S8b<08j>SP2HV9P0SXj>096AT@2CTi<0R8R809BD
U02=SHd0Rh^;092@T02EUID0R8R809jNWP2OWil00P2DU9@01@2JVYX0UIFE09>CT`2BTY80U9BD0080
VIVI02<0T92@09jNWP2WYjL0WinO092@T02FUYH0ZJVY0:JVYP2OWil0XZ:R0:VYZ@2][Jd0XZ:R0:RX
Z02b/[80]KFe0;>c/`2^[Zh0YjNW0;Jf]P2_[jl0YZJV0:j^[P2l_;`0^k^k0;:b/P2UYJD0Xj>S0;Ng
]`30`<00_Kfm0;6a/@2/[:`0][Jf0;Zj^P020;bl_0060;Zj^P2k^k/0^KVi0;^k^`33`l<0a<C40P38
b<P02@35aLD0`L710;no_`34a<@0a/K60<?3``2d];@0WYjN0820P002075aL@0L071`L01]KFd0MWIf
071`L01dM7@0OWin07moO`1lO7`0OGem07]kN`1jNWX0Ogmo07inOP22PX80OGem07inOP1lO7`0Ogmo
07YjNP1lO7`0NGUi07moO`1mOGd0PX:20861P@1lO7`0NGUi07emO@80NGUi00h0P82007emO@1jNWX0
MgMg07emO@1kNg/0N7Qh07YjNP1cLg<0LW9b075aL@1_Kfl0MGEe06m_K`80LW9b00l0LG5a07AdM01a
LG40L71`06m_K`1`L700MWIf06YZJP1]KFd0LW9b06i^KP1]KFd0Jf][06YZJP1_Kfl00P1`L7001`1j
NWX0N7Qh07moO`23Ph<0QHF508Z:RP2<S8`00P2=SHd0102?Shl0Ti>C09:BTP2DU9@209JFUP80T92@
0P2BTY82096AT@0>092@T02CTi<0U9BD09BDU02GUiL0U9BD09>CT`2FUYH0V9RH09JFUP2IVIT0V9RH
09JFUP2HV9P309JFUP0309fMW@2EUID0U9BD0080UIFE00H0TY:B09NGU`2BTY80U9BD09>CT`2ATI42
09:BTP<0TI6A00<0U9BD09NGU`2BTY800P2CTi<01P2ATI40SXj>09>CT`2CTi<0SXj>09:BTP80Shn?
00`0TI6A08n?S`2@T900Rh^;096AT@2=SHd0S8b<092@T02=SHd0QXJ608^;R`29RHT308^;R`0508V9
R@2>SXh0S8b<08f=S@2:RXX00P2>SXh0502=SHd0SXj>08f=S@2=SHd0S8b<08n?S`2<S8`0SXj>08R8
R02=SHd0QHF508Z:RP2<S8`0Y:BT0;Ng]`36a/H0dM7A0=?Cd`3Jf]X0gMgM0P3Ng]h0103MgMd0h>3P
0>7Qh@3Shn<30>CTi00D0>;RhP3Jf]X0dm?C0<O7a`2VYZH0N7Qh05QHF011@D40<c<c02`/;00Z:RX0
;Rh^02LW9`0X:2P0;2`/02HV9P0/;2`09bLW02h^;P0Z:RX202l_;`03030`<00e=CD0>3Ph0080>CTi
01@0>SXj03Ph>00l?3`0<S8b03De=@0m?Cd0=SHf03Ti>@0c<c<0=SHf034a<@0c<c<0=CDe03Lg=`0a
<C40<S8b03<c<`0/;2`0<S8b030`<080=cLg00<0?3`l03Xj>P0`<3000P0_;bl0200i>CT0;Bd]02PX
:00Z:RX0;2`/02d];@0^;Rh0<S8b0P0^;Rh>0<SPf0003038h=P20::RXP080:>SX`2LW9`0WinO0:6Q
X@2SXj<0YZJV0:VYZ@2][Jd20:^[Z`0?0:ZZZP2VYZH0YJFU0:6QX@2NWYh0W9bL09VIV@2GUiL0T92@
08V9R@27QhL0R8R80861P@1mOGd0OWin0080Ogmo00d0QXJ608b<S02@T900Ti>C09RHV02KVi/0WYjN
0:6QX@2SXj<0YZJV0:FUY@2WYjL0Xj>S0080YjNW00H0Xj>S0::RXP2TY:@0YjNW0:RXZ02VYZH30:FU
Y@80XZ:R00`0Xj>S09VIV@2@T900Shn?08Z:RP25QHD0PH6107QhN01/K6`0GemO05aLG01EEED2051@
D00904i>CP1BDU80EeMG05EEE@1HF5P0FEUI05eMG@1RHV80Hf=S0080GemO00`0IFEU06QXJ01UIFD0
IFEU06IVIP1[Jf/0Hf=S06ATI01UIFD0Hf=S06EUI@1[Jf/206QXJ00:06UYJ@1WIfL0IFEU06YZJP1W
IfL0J6QX06UYJ@1ZJVX0JFUY06IVIP80Kfm_00@0Jf][06m_K`1cLg<0Ng]k0`1cLg<307QhN00<07Mg
M`1kNg/0MgMg07MgM`1iNGT0NWYj07]kN`1eMGD0MgMg0820P021PH40NGUi0`1nOWh01@21PH40OWin
07emO@1jNWX0PH610080Ng]k01P0P82007inOP1oOgl0NWYj0861P@25QHD0OGem07inOP1oOgl0PH61
07alO020P800Q8B407inOP1lO7`0Q8B40861P@25QHD0Ph>307alO023Ph<0PX:207moO`21PH430820
P00507UiN@1nOWh0O7al08:2PP1jNWX00P22PX80101mOGd0OWin07inOP21PH420820P00508F5Q@26
QXH0Q8B408R8R02;Rh/00P25QHD01@1nOWh0OGem07YjNP28R8P0SXj>0080UYJF00/0TI6A08f=S@25
QHD0U9BD092@T02>SXh0Vi^K096AT@2@T900Rh^;09RHV00209BDU00:09JFUP2DU9@0S8b<096AT@2R
XZ80S8b<08J6QP2MWId0VYZJ09>CT`80WIfM0P2LW9`06@2MWId0X:2P0:ZZZP2IVIT0VYZJ0:FUY@2]
[Jd0XJ6Q09JFUP2XZ:P0]KFe0;Jf]P2e]KD0Z:RX0;Vi^@2g]kL0Z:RX0;Rh^02l_;`0^;Rh0:b/[02V
YZH0YjNW0;Zj^P2l_;`00P2^[Zh03`2`/;00]KFe0;^k^`2l_;`0/K6a0:VYZ@2f][H0^k^k0<?3``34
a<@0`L710;Ng]`2n_[h0_kno0<30`0020<W9b@0A0<_;b`35aLD0_kno0;Rh^02YZJT0T92@07UiN@1b
LW80Kfm_07AdM01cLg<0MgMg07UiN@1cLg<0MGEe07YjNP1lO7`00P1nOWh00`1mOGd0NWYj08N7Q`02
07moO`0:0820P01oOgl0NWYj08B4Q01oOgl0Ng]k07inOP1jNWX0NGUi07emO@80OWin00L0OGem07]k
N`1kNg/0Ng]k07emO@1iNGT0N7Qh0080O7al00@0Ng]k07IfMP1kNg/0MgMg0P1hN7P0101eMGD0MgMg
07EeM@1ZJVX207=cL`0M079bLP1cLg<0Kfm_075aL@1dM7@0L71`06a/K01^KVh0L71`06][J`1ZJVX0
IFEU079bLP1lO7`0KFe]07=cL`1kNg/0OGem07moO`21PH40RXZ:08n?S`2<S8`0UYJF08f=S@2;Rh/0
T92@08j>SP2BTY800P2@T9002@2>SXh0SHf=092@T02@T900TI6A09>CT`2DU9@0UIFE09BDU00209FE
U@0609BDU02BTY80UiNG09^KV`2FUYH0VYZJ0P2IVIT209RHV080VYZJ00<0VIVI09FEU@2GUiL00P2D
U9@00`2BTY80Ti>C09NGU`0209FEU@0409>CT`2GUiL0UYJF092@T080SHf=00D0Ti>C09JFUP2ATI40
TY:B09BDU00209:BTP03092@T02CTi<0TY:B0080Shn?00@0TI6A092@T02DU9@0T92@0P2?Shl01@2:
RXX0TI6A08f=S@29RHT0S8b<0080SXj>00@0Rh^;08Z:RP2;Rh/0RXZ:0P2=SHd00`2<S8`0SXj>08n?
S`0308j>SP0E08f=S@2:RXX0S8b<08b<S02=SHd0Shn?08V9R@28R8P0RXZ:08b<S02IVIT0/k>c0<;2
`P3;bl/0e=CD0=OGe`3Lg=`0gMgM0=oOg`3Ng]h0gmoO0080hN7Q0P3Ti>@04@3Rh^80hn?S0=gMg@3G
emL0c<c<0;Ng]`2CTi<0N7Qh06QXJ01CDe<0@d=302`/;00Y:BT0:RXZ02h^;P0Y:BT0;Bd]0080:RXZ
00<092@T034a<@0d=3@00P0Y:BT0100Z:RX0;Rh^02h^;P0d=3@203De=@0303<c<`0f=SH0=3@d0080
=3@d00P0=cLg03De=@0`<300=CDe03@d=00f=SH0<c<c03@d=080;bl_00H0;2`/02/[:`0`<300>3Ph
03Lg=`0e=CD2038b<P08030`<00^;Rh0;Bd]02XZ:P0Y:BT0=SHf02PX:00Y:BT202h^;P0303Lg=`0`
<300;2`/00h0b>3H000<0<SPf080WYjN00H0XZ:R0:>SX`2QXJ40Xj>S0:NWY`2VYZH20:RXZ0070:ZZ
ZP2WYjL0Zj^[0:JVYP2WYjL0XZ:R0:6QX@0209jNWP0B09RHV02CTi<0SHf=08R8R02:RXX0Ph>30861
P@1oOgl0Ph>308J6QP27QhL0RHV908n?S`2ATI40UiNG09bLW02RXZ80XJ6Q0`2UYJD01`2TY:@0XZ:R
0:>SX`2SXj<0Y:BT0:2PX02SXj<00P2RXZ820:NWY`0E0::RXP2UYJD0Xj>S0:>SX`2QXJ40V9RH09BD
U02=SHd0S8b<08J6QP1oOgl0MgMg071`L01RHV80FUYJ05EEE@1:BTX0Cdm?05=CD`1GEeL0F5QH00<0
FEUI00L0G5aL05mOG`1PH600GemO05iNGP1SHf<0IFEU0080IVIV00h0J6QX06IVIP1PH600HV9R06MW
I`1VIVH0IFEU06=SH`1WIfL0J6QX06IVIP1WIfL0J6QX071`L080J6QX00H0IfMW06YZJP1VIVH0IfMW
071`L01aLG42071`L080NGUi0100MWIf07EeM@1dM7@0NGUi07MgM`1kNg/0MWIf07UiN@1eMGD0NGUi
07IfMP1kNg/0NWYj07inOP1iNGT0Ng]k0P1oOgl01@1mOGd0OWin07inOP20P800Ng]k0080OWin0100
O7al07emO@1oOgl0P82007YjNP1mOGd0Ogmo07inOP25QHD0Ph>308B4Q025QHD0PH6107YjNP21PH40
Ph>3101nOWh03`1mOGd0NWYj0820P023Ph<0Ogmo07inOP1oOgl0PH6107inOP1mOGd0Ng]k0861P@23
Ph<0N7Qh07YjNP0207inOP090820P024Q8@0PX:208J6QP22PX80Ogmo0820P021PH40OGem0080PH61
01h0OGem08B4Q025QHD0Q8B407inOP24Q8@0Ph>3092@T02JVYX0TY:B09>CT`25QHD0Rh^;09FEU@2A
TI40UIFE09^KV`2LW9`0Ti>C08n?S`2GUiL0T92@08b<S028R8P0SXj>092@T02RXZ80X:2P09:BTP2F
UYH20:2PX080W9bL0180V9RH0:ZZZP2RXZ80T92@0:FUY@2^[Zh0ZJVY09^KV`2XZ:P0/k>c0:f][@2S
Xj<0Z:RX0;^k^`2o_kl0]KFe0;:b/P2^[Zh20;:b/P0@0:RXZ02b/[80]kNg0;6a/@2UYJD0Z:RX0;6a
/@2l_;`0`<300;6a/@2UYJD0[jn_0;Ng]`2o_kl0]kNg0;>c/`80^;Rh00@0_Kfm0<;2`P33`l<0aLG5
0P2o_kl0:031`L40a/K60<G5a@2l_;`0[jn_09fMW@1oOgl0LG5a06m_K`1cLg<0MGEe07alO01cLg<0
M7Ad07IfMP1dM7@0Ng]k07alO01nOWh0OGem07moO`1nOWh0Ng]k07YjNP21PH40PX:207inOP1oOgl0
P82008>3P`1lO7`0OWin07moO`1lO7`0NWYj08:2PP1nOWh0PX:20820P01jNWX207IfMP0707emO@1n
OWh0NWYj07]kN`1jNWX0OGem07YjNP0207IfMP0607alO01fMWH0MWIf07UiN@1lO7`0Kfm_0P1aLG40
201eMGD0Lg=c07AdM01`L700LG5a079bLP1[Jf/0LG5a0P1[Jf/0401/K6`0JVYZ06][J`1lO7`0KFe]
07AdM01gMgL0O7al07inOP25QHD0R8R808b<S02:RXX0SHf=08b<S02DU9@2096AT@0;09JFUP2@T900
Shn?08j>SP2ATI40SXj>09>CT`2?Shl0SXj>09BDU02CTi<00P2DU9@0502FUYH0UIFE09RHV02LW9`0
VIVI09RHV02LW9`0VIVI09ZJVP2IVIT0V9RH09^KV`2IVIT0Ti>C09bLW02EUID0UiNG09>CT`2IVIT0
UYJF0P2IVIT0102EUID0UYJF09>CT`2ATI4309BDU00509:BTP2CTi<0Ti>C09>CT`2BTY800`2DU9@2
09:BTP0309>CT`2@T900TY:B0080Shn?00l0TI6A09>CT`2?Shl0SHf=08j>SP2<S8`0QhN708b<S02;
Rh/0Shn?08^;R`2=SHd0Shn?08Z:RP2=SHd00P2>SXh208f=S@0708n?S`2=SHd0SHf=08j>SP2;Rh/0
SXj>08b<S00208j>SP80RXZ:00T0RHV909>CT`2[Zj/0_[jn0<[:bP3?cll0dm?C0=OGe`3Jf]X00P3N
g]h20>3Ph00F0>7Qh@3Rh^80hn?S0>?Sh`3Rh^80g]kN0=OGe`3@d=00_kno0:BTY025QHD0NWYj075a
L@1SHf<0Fe]K03dm?@0d=3@0;bl_03Hf=P0U9BD0:b/[02TY:@80:2PX00T0=SHf03Lg=`0/;2`0;2`/
034a<@0`<300=3@d038b<P0c<c<00P0a<C40200g=cL0=CDe03Lg=`0h>3P0=SHf03Ph>00j>SX0<S8b
0P0d=3@01@0e=CD0=3@d03Hf=P0];Bd0<30`0080:b/[00L0;Bd]030`<00c<c<0=CDe03Ti>@0k>c/0
<30`0080<C4a00@0;2`/030`<00`<300:BTY0P0[:b/00`0/;2`0;Rh^03<c<`0>0<SPf0003038h=P3
0:2PX00=0:6QX@2OWil0WYjN0::RXP2TY:@0YJFU0:VYZ@2WYjL0ZJVY0:^[Z`2YZJT0YjNW0:ZZZP02
0:6QX@0309fMW@2LW9`0Ti>C0080T92@00D0SHf=08B4Q024Q8@0PH610820P00208N7Q`0<08Z:RP2=
SHd0TY:B09BDU02KVi/0WinO09jNWP2TY:@0XZ:R0:BTY02UYJD0Xj>S0P2VYZH03@2QXJ40Y:BT0:BT
Y02SXj<0Y:BT0:>SX`2VYZH0XZ:R0:JVYP2PX:00W9bL0:6QX@2FUYH00P2@T90208V9R@0807YjNP1f
MWH0KFe]065QH@1NGUh0EUIF059BDP1DE5@205QHF00:05IFEP1KFe/0Hf=S069RHP1LG5`0HV9R06QX
J01PH600IfMW06=SH`80IVIV01@0Jf][06QXJ01XJ6P0HV9R05mOG`1/K6`0IFEU06MWI`1YJFT0J6QX
06ATI01XJ6P0I6AT06UYJ@1/K6`0JVYZ06IVIP1SHf<0JFUY06QXJ080K6a/00X0KFe]07=cL`1aLG40
MGEe07YjNP1fMWH0MGEe07=cL`1dM7@0NGUi0P1jNWX0101hN7P0MgMg07moO`1jNWX307]kN`80N7Qh
0P1mOGd02P1nOWh0NWYj07YjNP1oOgl0P82007moO`23Ph<0Ogmo07inOP1lO7`207moO`0L07YjNP1n
OWh0OWin0861P@20P800PX:20861P@23Ph<0Rh^;07inOP1oOgl0Ng]k07moO`21PH40P8200861P@22
PX80Ogmo08>3P`24Q8@0NWYj0820P021PH40P82007emO@1kNg/0P82007inOP80NWYj00@0Ogmo08>3
P`21PH40OGem0P1lO7`30820P00C07inOP1lO7`0NWYj07moO`1lO7`0Ogmo0820P01nOWh0P82008>3
P`21PH40RXZ:092@T02HV9P0U9BD08R8R02@T900S8b<08j>SP0209:BTP080::RXP2EUID0QhN709>C
T`27QhL0SXj>08J6QP2=SHd209BDU00509:BTP2GUiL0VYZJ08n?S`2GUiL00P2ZZZX05P2/[:`0Xj>S
0:6QX@2QXJ40WinO0:6QX@2/[:`0[Jf]0:RXZ02YZJT0/k>c0;Zj^P2/[:`0/;2`0;>c/`2i^KT0^k^k
0:^[Z`2_[jl0[Zj^0;:b/P2[Zj/20:RXZ00M0;Jf]P2_[jl0YJFU0:b/[02i^KT0_;bl0;^k^`2e]KD0
[Zj^0;Jf]P2j^[X0_kno0<C4a02n_[h0]KFe0;Rh^031`L40alO70<30`034a<@0`L710<30`02d];@0
WinO08B4Q01fMWH0LW9b071`L01eMGD00P1cLg<07@1fMWH0MGEe07alO01fMWH0N7Qh07emO@1kNg/0
O7al07]kN`21PH40OGem07alO01oOgl0OGem07alO021PH40O7al08>3P`22PX80O7al07emO@1nOWh0
Ogmo07YjNP1gMgL0P82007emO@21PH40Ogmo0080Ng]k0P1lO7`0101kNg/0MgMg07alO01kNg/207Yj
NP0:07MgM`1iNGT0N7Qh07IfMP1dM7@0MgMg06a/K01`L700Lg=c07EeM@80Kfm_00<0KFe]06m_K`1b
LW800P1cLg<04`1^KVh0JFUY06YZJP1VIVH0JVYZ071`L01]KFd0M7Ad07YjNP1kNg/0OGem08B4Q026
QXH0QHF508^;R`2=SHd0Shn?09:BTP2@T9000P2BTY802P2;Rh/0Shn?096AT@2ATI40TY:B092@T02?
Shl0U9BD09FEU@2CTi<409FEU@0309JFUP2JVYX0UiNG0080VIVI0180VYZJ09RHV02NWYh0VIVI09^K
V`2IVIT0VYZJ09JFUP2EUID0U9BD09NGU`2IVIT0UiNG09^KV`2EUID0U9BD09JFUP2EUID209>CT`80
TI6A01`0U9BD09NGU`2IVIT0U9BD09:BTP2DU9@0UIFE09>CT`2ATI40Ti>C092@T02=SHd0T92@08n?
S`2>SXh0UIFE09>CT`2DU9@0T92@08b<S02;Rh/0S8b<092@T02<S8`0SHf=08V9R@27QhL0RXZ:0P2=
SHd01@2:RXX0Shn?08n?S`2=SHd0Rh^;00<0SXj>0100RXZ:08j>SP2<S8`0SHf=09:BTP2:RXX0R8R8
08Z:RP2KVi/0];Bd0<G5a@3<c<`0dM7A0=KFeP3IfMT0g=cL0P3Ng]h0103Ph>00g]kN0>3Ph03Shn<2
0>CTi00>0=kNgP3Jf]X0dM7A0<S8b02a/K40TI6A07QhN01iNGT0OWin06m_K`1RHV80DE5A0410@00a
<C4202LW9`0602d];@0a<C40:RXZ02h^;P0Y:BT0;Bd]0P0^;Rh0100e=CD0<C4a02l_;`0_;bl203De
=@06030`<00h>3P0>3Ph03Xj>P0g=cL0=SHf0P0h>3P02@0a<C40>3Ph02h^;P0g=cL0>3Ph038b<P0e
=CD0;Bd]03<c<`0202TY:@0A02h^;P0d=3@0=SHf03<c<`0e=CD0;bl_03De=@0a<C40;bl_030`<00_
;bl0;Rh^03<c<`0b<S80:b/[030`<00c<c<03P38h=P000`0b>3H0P2RXZ800`2QXJ40WYjN0:6QX@02
0:6QX@080:>SX`2UYJD0Z:RX0:RXZ02YZJT0ZZZZ0:RXZ02WYjL20:FUY@0;0::RXP2KVi/0VYZJ09RH
V02CTi<0TY:B08j>SP29RHT0QXJ608R8R029RHT00P2:RXX02@25QHD0T92@08j>SP2GUiL0VYZJ09nO
W`2TY:@0XZ:R0:>SX`020:BTY0040:NWY`2SXj<0Xj>S0:6QX@80Xj>S00@0XZ:R0:FUY@2VYZH0YZJV
0P2SXj<209nOW`0309bLW02FUYH0Ti>C0080S8b<00/0Ph>307inOP1fMWH0J6QX06IVIP1OGel0EEEE
05ADE01ADE40Cdm?05YJFP0205MGE`0<05mOG`1MGEd0GEeM061PH01VIVH0HV9R06IVIP1SHf<0IfMW
06e]K@1XJ6P0Jf][0P1VIVH01@1ZJVX0Jf][069RHP1ZJVX0Jf][0080IVIV0P1YJFT07P1VIVH0IFEU
06YZJP1YJFT0JVYZ06a/K01`L700Kfm_06][J`1/K6`0KVi^06e]K@1eMGD0LW9b07AdM01gMgL0LW9b
07IfMP1hN7P0Ng]k07QhN01jNWX0OWin07UiN@1kNg/0MgMg07IfMP1hN7P0MgMg0861P@80OGem00L0
Ng]k0861P@21PH40O7al08:2PP1kNg/0OGem0080OWin0`1lO7`207inOP0F08:2PP1mOGd0Ogmo07in
OP1oOgl0QhN70820P022PX80Ogmo07alO022PX80PH6107moO`1jNWX0P82008>3P`21PH40Ph>307mo
O`20P800Ogmo0861P@80Ph>300L0PX:207inOP1jNWX0PH6108:2PP23Ph<0OWin0080P82000<0PH61
07inOP1kNg/00P20P8001`21PH40OWin08:2PP1nOWh0Ng]k0861P@1lO7`00P1oOgl00`20P800RXZ:
08f=S@0208f=S@0E08Z:RP2ATI40Shn?09JFUP2@T900UYJF09bLW02CTi<0TY:B08b<S024Q8@0U9BD
08f=S@2ATI40S8b<08n?S`2FUYH0SXj>0:>SX`2VYZH0XJ6Q0080WYjN02H0[jn_0;2`/02QXJ40WinO
0:RXZ02][Jd0YZJV0:n_[`2d];@0/K6a0:b/[02h^;P0/k>c0;Jf]P2`/;00ZJVY0;Bd]02h^;P0]kNg
0:b/[02RXZ80ZZZZ0:b/[02[Zj/0ZZZZ0:f][@2g]kL0]KFe0:j^[P2XZ:P0][Jf0;^k^`2n_[h0^KVi
0:b/[02h^;P0`<300<C4a080`/;20180_kno0<30`02n_[h0]kNg0;2`/02SXj<0TI6A08:2PP1[Jf/0
KVi^07=cL`1dM7@0MGEe07MgM`1hN7P0O7al07AdM023Ph<207]kN`0707alO01mOGd0P8200820P01o
Ogl0O7al07emO@0207inOP0?07emO@21PH40OWin0861P@20P800O7al07inOP20P800Ng]k07YjNP1i
NGT0PH6107alO01gMgL0OGem00<0O7al00H0NGUi07alO01mOGd0PX:207IfMP1kNg/207MgM`0;07Qh
N01iNGT0MgMg07QhN01eMGD0Kfm_071`L01bLW80MGEe079bLP1`L7000P1bLW82075aL@0@07=cL`1]
KFd0JVYZ06YZJP1XJ6P0Jf][06m_K`1cLg<0Kfm_07EeM@1lO7`0QHF508>3P`27QhL0QXJ608f=S@80
S8b<00`0TI6A09:BTP2CTi<0Ti>C08j>SP2ATI40U9BD08j>SP2ATI40T92@09>CT`2FUYH209BDU080
Ti>C00<0UIFE09JFUP2GUiL00P2FUYH00`2IVIT0W9bL09NGU`0209VIV@0509^KV`2GUiL0WIfM09BD
U02LW9`00P2EUID209NGU`80UYJF00<0UiNG09FEU@2GUiL00P2FUYH01P2GUiL0V9RH09RHV02DU9@0
UiNG09JFUP80Ti>C01<0UYJF09>CT`2CTi<0TI6A09FEU@2CTi<0T92@09:BTP2;Rh/0SXj>09>CT`2?
Shl0SXj>08n?S`2<S8`0SHf=092@T02<S8`0SHf=00@0Rh^;0P2=SHd208Z:RP80SHf=00<0SXj>08n?
S`2@T9000`2;Rh/03`2?Shl0R8R8096AT@29RHT0Shn?09VIV@2[Zj/0_[jn0<W9b@3?cll0e=CD0=SH
f03IfMT0g=cL0=kNgP020>3Ph00D0=oOg`3QhN40hn?S0>;RhP3QhN40fm_K0=CDe039bLT0][Jf09VI
V@1nOWh0MWIf07YjNP1iNGT0N7Qh07=cL`1YJFT0DE5A03Xj>P0_;bl202d];@0502TY:@0U9BD09RHV
02TY:@0/;2`00P0_;bl04P0[:b/0;Bd]02XZ:P0];Bd0;bl_034a<@0/;2`0;Rh^038b<P0e=CD0>SXj
03<c<`0l?3`0=SHf038b<P0h>3P0;Bd]034a<@80=CDe0`0d=3@02@0b<S80=CDe03@d=00];Bd0<30`
02`/;00c<c<0=3@d038b<P02034a<@80<c<c00<0:BTY02d];@0Z:RX00P0/;2`00`0Z:RX0b>3H0<SP
f00<0<SPf0003038h=P30:2PX00;09^KV`2MWId0XZ:R0:>SX`2QXJ40WIfM0::RXP2YZJT0YjNW0:^[
Z`2XZ:P00P2ZZZX00`2UYJD0Xj>S09jNWP0209ZJVP0B09>CT`2BTY80T92@08n?S`2<S8`0RXZ:08^;
R`2BTY80S8b<08R8R02>SXh0Ti>C09NGU`2IVIT0WYjN0:2PX02TY:@0Xj>S0P2UYJD06`2QXJ40XZ:R
0::RXP2QXJ40XZ:R09fMW@2QXJ40Xj>S0:FUY@2WYjL0XJ6Q0::RXP2TY:@0XZ:R09ZJVP2GUiL0Ti>C
08n?S`29RHT0Ph>307inOP1hN7P0KFe]06EUI@1QHF40EEEE05IFEP0205=CD`09055AD@1IFET0FEUI
061PH01NGUh0Fe]K05UIF@1WIfL0IVIV0080IFEU00D0IVIV06UYJ@1XJ6P0IfMW06UYJ@0206IVIP06
06UYJ@1TI6@0Hf=S06a/K01ZJVX0IVIV0P1UIFD03P1WIfL0J6QX06a/K01VIVH0J6QX06=SH`1]KFd0
J6QX06e]K@1/K6`0Jf][06m_K`1eMGD0LG5a0`1dM7@01@1gMgL0MGEe07QhN01iNGT0MgMg0080OGem
00D0OWin07AdM01fMWH0Ng]k07MgM`0207YjNP0407emO@1nOWh0PH610861P@80PX:200D0OWin0861
P@1lO7`0NWYj07inOP0207YjNP050820P01mOGd0Ng]k07moO`23Ph<00P1mOGd00`1oOgl0PX:20820
P0020861P@0C08B4Q022PX80P82007inOP23Ph<0PH6108>3P`22PX80R8R807moO`23Ph<0QHF508>3
P`20P800O7al08N7Q`1lO7`0QXJ607inOP020820P080Ogmo00<0OWin08>3P`1oOgl01@21PH407@1l
O7`0P82007inOP1oOgl0OWin07emO@1kNg/0OWin08B4Q02=SHd0T92@08b<S02BTY80Ti>C09RHV02L
W9`0Rh^;09fMW@2PX:00UiNG096AT@27QhL0SHf=09BDU02EUID0VYZJ092@T02ATI40U9BD0080UiNG
00d0[Zj^0:f][@2][Jd0XZ:R0:ZZZP2e]KD0[Jf]0:2PX02WYjL0[:b/0:VYZ@2TY:@0]kNg0080^;Rh
00/0[Jf]0;Vi^@2i^KT0^KVi0:n_[`2YZJT0^[Zj0;bl_02g]kL0XJ6Q09nOW`020:j^[P080:RXZ02_
[jl0]KFe0<30`02f][H0[jn_0:j^[P2j^[X30;bl_00=0<71`@33`l<0`/;20;jn_P2k^k/0][Jf0:n_
[`2NWYh0SHf=07emO@1fMWH0MGEe07=cL`0207MgM`0707AdM01eMGD0Lg=c07MgM`1lO7`0MWIf07Yj
NP0207emO@0607moO`1lO7`0OWin0820P01lO7`0OWin0P1lO7`04021PH40Ogmo08:2PP21PH40Ng]k
07emO@1oOgl0P8200861P@1mOGd0P82007inOP24Q8@0Ogmo07]kN`1lO7`207emO@0;07alO01mOGd0
OWin07alO020P800O7al07]kN`1eMGD0N7Qh07IfMP1kNg/00P1hN7P02`1dM7@0MgMg07]kN`1eMGD0
MgMg079bLP1_Kfl0Lg=c075aL@1_Kfl0L71`0080KFe]00@0JFUY06e]K@1XJ6P0K6a/0P1^KVh01@1`
L700MgMg07IfMP1oOgl0Ph>30080R8R800H0S8b<08j>SP2;Rh/0SXj>09^KV`2BTY8208n?S`0908j>
SP2=SHd0SXj>092@T02DU9@0T92@08n?S`2DU9@0V9RH0080TI6A00l0UiNG09ZJVP2HV9P0V9RH09ZJ
VP2LW9`0XJ6Q09NGU`2LW9`0VIVI09NGU`2JVYX0VIVI09JFUP2GUiL00P2HV9P0102FUYH0VIVI09^K
V`2IVIT209NGU`0409RHV02GUiL0V9RH09ZJVP<0UYJF00L0VIVI09ZJVP2DU9@0VIVI09NGU`2FUYH0
TI6A0080Ti>C00/0UIFE096AT@2@T900TY:B09NGU`2CTi<0Shn?08b<S02=SHd0Rh^;08b<S00308n?
S`0908b<S02=SHd0SXj>08b<S02>SXh0TY:B08^;R`2=SHd0TY:B00<0Shn?00D0SXj>08n?S`2:RXX0
TY:B08V9R@0208n?S`0>096AT@2HV9P0Z:RX0;Zj^P35aLD0cLg=0=7Ad@3Fe]H0fMWI0=[JfP3Lg=`0
gMgM0=kNgP3Ph>020>?Sh`0C0>CTi03Shn<0gMgM0=GEe@3>c/h0_[jn0:NWY`29RHT0MGEe071`L01d
M7@0MWIf07QhN01iNGT0Lg=c06ATI01<C4`0>SXj034a<@0202XZ:P80:2PX00L0:RXZ02d];@0^;Rh0
;Rh^02`/;00Y:BT0:b/[0080;Rh^00@0<30`02XZ:P0^;Rh0;2`/0P0c<c<04`0k>c/0=cLg03De=@0b
<S80=3@d03Ti>@0e=CD0=cLg03De=@0b<S80<C4a03De=@0b<S80<30`034a<@0_;bl0<S8b02`/;00]
;Bd00P0`<3002P0_;bl0<c<c02d];@0/;2`0;bl_02/[:`0Y:BT0<C4a02`/;00];Bd>0<SPf0003038
h=P20:6QX@0B09nOW`2QXJ40WinO09nOW`2KVi/0XJ6Q0:>SX`2PX:00YJFU0:JVYP2ZZZX0[:b/0:f]
[@2ZZZX0[:b/0:JVYP2QXJ40X:2P0P2IVIT0502CTi<0SXj>08n?S`2?Shl0SHf=08n?S`2@T900RXZ:
08j>SP2=SHd0TY:B09FEU@2KVi/0WinO0:BTY02UYJD0YZJV0:BTY02RXZ80X:2P0P2UYJD08P2SXj<0
Y:BT0:2PX02QXJ40Xj>S0::RXP2SXj<0YJFU0:BTY02RXZ80WinO09bLW02IVIT0TY:B08f=S@2<S8`0
R8R808>3P`1dM7@0JVYZ06ATI01MGEd0EeMG05IFEP1BDU80De=C05ADE01IFET0FUYJ05eMG@1PH600
HF5Q05UIF@1OGel206=SH`0306ATI01WIfL0KFe]0080IfMW00h0IVIV06UYJ@1UIFD0J6QX06IVIP1R
HV80IFEU06IVIP1XJ6P0JFUY06][J`1XJ6P0Kfm_06i^KP80IfMW00H0IVIV06e]K@1/K6`0L71`06i^
KP1_Kfl2079bLP06071`L01aLG40MGEe07IfMP1gMgL0MGEe0P1jNWX01P1iNGT0MGEe07QhN01kNg/0
MgMg07AdM080N7Qh00@0O7al07emO@1kNg/0OGem0P22PX801@1nOWh0P82007alO01lO7`0PX:20080
OGem0P1lO7`20820P080OWin01D0P82007]kN`1oOgl0OGem08N7Q`2;Rh/0PH610820P01mOGd0PX:2
0861P@1oOgl0PX:207moO`1kNg/0PX:208B4Q01nOWh0Ph>308N7Q`1oOgl00P22PX808P1nOWh0O7al
07alO01mOGd0Ph>30820P026QXH0P82007moO`20P800QHF508Z:RP21PH40O7al0861P@1oOgl0P820
07inOP1mOGd0PX:207inOP1kNg/0P82007inOP1mOGd0OWin08B4Q02:RXX0Shn?09BDU02FUYH0SHf=
09JFUP2GUiL209FEU@0<09>CT`2GUiL0VYZJ08V9R@2DU9@0WinO096AT@2HV9P0UIFE09bLW02FUYH0
XJ6Q0P2ZZZX06P2`/;00[Zj^09fMW@2NWYh0[jn_0:JVYP2QXJ40YjNW0;2`/02YZJT0ZZZZ0;Vi^@31
`L40^[Zj0:^[Z`2h^;P0][Jf0:j^[P2/[:`0ZZZZ0;Jf]P2j^[X0/;2`0:RXZ02UYJD0/[:b0P2c/k<0
202g]kL0^k^k0;no_`2o_kl0^k^k0;Rh^02l_;`0^k^k0P2m_Kd01P2k^k/0/[:b09fMW@2>SXh0Ph>3
0861P@80LW9b00@0KVi^06m_K`1bLW80NGUi0P1hN7P02@1jNWX0Ng]k07UiN@1hN7P0NGUi07YjNP1n
OWh0O7al07emO@020820P00A08F5Q@22PX80P8200861P@1mOGd0PX:207alO020P800Ogmo07]kN`1n
OWh0Ogmo0861P@1oOgl0Ng]k07alO01nOWh00P20P8000`21PH40Ng]k0820P0020820P00507emO@20
P800O7al07]kN`1lO7`00P1gMgL00`1eMGD0NGUi07EeM@0207UiN@0507IfMP1cLg<0LW9b07EeM@1f
MWH00P1cLg<0101^KVh0LG5a071`L01_Kfl206i^KP0706][J`1ZJVX0J6QX06i^KP1YJFT0L71`079b
LP0207AdM00B07]kN`27QhL0QXJ608Z:RP2>SXh0RXZ:08j>SP2?Shl0Ti>C09:BTP2?Shl0TI6A092@
T02ATI40TY:B09BDU02CTi<0TY:B0P2ATI406`2EUID0U9BD09NGU`2GUiL0UIFE09NGU`2MWId0W9bL
09RHV02KVi/0V9RH09fMW@2KVi/0VYZJ09JFUP2IVIT0W9bL09ZJVP2NWYh0UiNG09VIV@2LW9`0V9RH
09^KV`2HV9P0UiNG09VIV@0209RHV00709NGU`2HV9P0V9RH09NGU`2LW9`0VYZJ09FEU@0209VIV@03
09JFUP2HV9P0Ti>C0080Ti>C00X0UYJF092@T02@T900TY:B09FEU@2@T900S8b<092@T02;Rh/0T92@
0P2>SXh01P2:RXX0Rh^;08b<S02;Rh/0RHV9092@T080SHf=01@0Shn?08Z:RP2<S8`0Shn?08Z:RP2<
S8`0R8R808j>SP2<S8`0SHf=092@T02ATI40UIFE09fMW@2d];@0`<300<[:bP3AdM40e=CD0=SHf080
f][J00D0gMgM0>3Ph03Ph>00hN7Q0>;RhP020>7Qh@0C0=kNgP3GemL0clo?0<30`02[Zj/0SXj>07Qh
N01aLG40L71`07QhN01bLW80MgMg07alO01kNg/0IVIV05eMG@1;Bd/0=3@d02d];@0202/[:`0302TY
:@0Z:RX0;2`/0080:BTY00@0:RXZ02l_;`0/;2`0;2`/0P0[:b/0300^;Rh0<30`02d];@0_;bl0>3Ph
03@d=00a<C40=cLg03<c<`0b<S80=3@d03Lg=`<0=3@d00<0=cLg03Hf=P0h>3P00P0c<c<02@0`<300
;bl_02LW9`0/;2`0:b/[02d];@0[:b/0;bl_034a<@0202`/;00502h^;P0a<C40:2PX02XZ:P0_;bl0
3P38h=P000`0b>3H0P2RXZ80102SXj<0XJ6Q09nOW`2QXJ430:2PX00?0:>SX`2VYZH0YZJV0:ZZZP2[
Zj/0[Zj^0:JVYP2YZJT0Z:RX0:6QX@2NWYh0WIfM09VIV@2GUiL0Ti>C0080TY:B0P2?Shl03P2@T900
Shn?09>CT`2CTi<0T92@09JFUP2IVIT0WIfM0:6QX@2SXj<0Y:BT0:NWY`2TY:@0Z:RX0P2PX:000`2R
XZ80Xj>S0:2PX0020:6QX@030:>SX`2RXZ80Y:BT0080XJ6Q00l0Vi^K09jNWP2JVYX0U9BD092@T027
QhL0Ph>30820P01jNWX0K6a/06=SH`1IFET0GUiN055AD@1DE5@00P1IFET01@1LG5`0Fe]K05mOG`1J
FUX0IFEU0080Hf=S00`0I6AT069RHP1[Jf/0IVIV06YZJP1YJFT0IVIV06UYJ@1[Jf/0JFUY06ATI01V
IVH206EUI@0406=SH`1XJ6P0J6QX06][J`80IVIV00<0I6AT06MWI`1WIfL00P1XJ6P0401^KVh0K6a/
075aL@1_Kfl0Lg=c071`L01bLW80M7Ad06i^KP1dM7@0MGEe07UiN@1jNWX0O7al07UiN@1lO7`207]k
N`80NWYj00H0NGUi07emO@1nOWh0OWin07YjNP1lO7`208B4Q00F07moO`1lO7`0N7Qh07alO01jNWX0
OGem07inOP1jNWX0Ogmo08B4Q01kNg/0O7al07inOP1oOgl0OGem0820P01oOgl0P82008B4Q021PH40
PX:208F5Q@80P8200P22PX80=01oOgl0P82008V9R@23Ph<0P82008>3P`22PX80P82007emO@1oOgl0
PX:207]kN`21PH40OWin0820P01mOGd0PH6108F5Q@21PH40P82008J6QP2=SHd0PH6108:2PP23Ph<0
P8200861P@27QhL0PH6107emO@20P800O7al07emO@1nOWh0Ng]k07UiN@1lO7`0OWin08Z:RP23Ph<0
TI6A09NGU`2ATI40VIVI09ZJVP2DU9@0UYJF09^KV`2DU9@0WinO0:6QX@2IVIT209>CT`0309NGU`2>
SXh0Ti>C00<0WinO00X0Y:BT0;Fe]@2a/K40Vi^K09jNWP2VYZH0/[:b0::RXP2VYZH0/;2`0P2d];@0
2`2`/;00][Jf0;Zj^P2/[:`0ZJVY0;2`/02j^[X0^k^k0;Bd]02`/;00];Bd0080^KVi00H0/[:b0:RX
Z02b/[80^KVi0;Zj^P2o_kl30<71`@0>0;bl_02j^[X0ZZZZ09bLW02BTY80SHf=0820P01fMWH0MGEe
075aL@1bLW80Ng]k071`L01dM7@207YjNP0307QhN01iNGT0O7al0080Ng]k00H0O7al07YjNP1kNg/0
Ogmo0861P@26QXH208:2PP0:08>3P`22PX80Q8B40861P@20P800PX:20820P028R8P0Ogmo07emO@<0
P82000D0OWin07]kN`1lO7`0O7al07inOP0207emO@0307inOP1kNg/0Ng]k00<0Ogmo00D0OGem0820
P01mOGd0OWin07moO`0207YjNP0>07IfMP1eMGD0NGUi07EeM@1hN7P0MgMg07]kN`1gMgL0KFe]075a
L@1^KVh0Lg=c071`L01_Kfl2071`L00G06][J`1ZJVX0KVi^06e]K@1_Kfl0LW9b07AdM01gMgL0OWin
07emO@24Q8@0PX:208N7Q`2>SXh0R8R808b<S02ATI40SXj>09>CT`2BTY80Shn?08j>SP2?Shl00P2@
T9000`2ATI40T92@096AT@0309JFUP0709>CT`2GUiL0UIFE09ZJVP2IVIT0W9bL09^KV`0209VIV@07
09^KV`2IVIT0Vi^K09RHV02IVIT0Vi^K09RHV00209ZJVP0:09VIV@2LW9`0UiNG09^KV`2HV9P0U9BD
09nOW`2GUiL0V9RH09VIV@80W9bL00P0VYZJ09bLW02HV9P0UIFE09JFUP2HV9P0UYJF09bLW080U9BD
0140Ti>C096AT@2BTY80UYJF09FEU@2?Shl0T92@08n?S`2@T900SHf=096AT@2?Shl0T92@08b<S02D
U9@0T92@08b<S00208f=S@0708j>SP2=SHd0Shn?08^;R`2<S8`0SXj>08b<S00208f=S@0=08^;R`2>
SXh0T92@09>CT`2DU9@0UiNG0:VYZ@2m_Kd0alO70<k>cP3Bd]80emOG0=WIf@020=_Kf`0M0=gMg@3P
h>00g]kN0>3Ph03Rh^80hN7Q0=oOg`3Jf]X0d];B0<W9b@2f][H0WIfM0861P@1^KVh0Jf][06a/K01e
MGD0N7Qh07inOP1kNg/0PH6107AdM01WIfL0GEeM04Q8B00j>SX0<30`02XZ:P0U9BD00P0Y:BT302XZ
:P0D02d];@0[:b/0:2PX02`/;00];Bd0;Rh^02XZ:P0_;bl0<S8b03De=@0i>CT0<S8b03Xj>P0f=SH0
=cLg03Ph>00f=SH0>3Ph03De=@0k>c/203Hf=P0903<c<`0g=cL0>CTi02d];@0a<C40;bl_02TY:@0Z
:RX0;2`/0080:b/[00P0;2`/02XZ:P0_;bl0;Bd]034a<@0[:b/0;bl_03<c<`h0b>3H000<0<SPf0<0
Xj>S01H0X:2P0:>SX`2PX:00XZ:R09jNWP2LW9`0WYjN0:6QX@2VYZH0Z:RX0:VYZ@2ZZZX0ZJVY0:f]
[@2ZZZX0Xj>S0:2PX02LW9`0Vi^K09ZJVP2IVIT0T92@0`2CTi<03P2=SHd0TY:B09>CT`2FUYH0TY:B
09NGU`2LW9`0VYZJ0:6QX@2SXj<0XZ:R09nOW`2PX:00Y:BT0P2SXj<01`2NWYh0WinO09nOW`2QXJ40
XZ:R0:RXZ02RXZ800P2SXj<05@2QXJ40W9bL09^KV`2IVIT0UYJF08f=S@2;Rh/0Q8B40820P01iNGT0
Kfm_06ATI01OGel0G5aL05]KF`1DE5@0DU9B05QHF01GEeL0Fe]K05aLG002065QH@0H06UYJ@1RHV80
Hf=S06ATI01UIFD0I6AT06IVIP1UIFD0IfMW06QXJ01VIVH0J6QX06YZJP1SHf<0Jf][06EUI@1WIfL0
Jf][06MWI`1ZJVX0IfMW06IVIP1RHV80IVIV0P1UIFD0201XJ6P0Jf][06YZJP1`L700LG5a07AdM01a
LG40LW9b0`1`L7001`1aLG40N7Qh07MgM`1hN7P0MgMg07YjNP1iNGT00P1eMGD01`1iNGT0MgMg07]k
N`1kNg/0P82007emO@1lO7`00P1mOGd03022PX80OGem07YjNP1oOgl0OWin07moO`21PH40Ng]k0820
P01nOWh0O7al08>3P`80PH61101nOWh02P1oOgl0O7al07moO`1oOgl0PH6107alO01oOgl0QHF508>3
P`25QHD207moO`80PX:200D0Ogmo07YjNP1mOGd0OGem08B4Q00208:2PP0408>3P`1nOWh0Ng]k07em
O@80PH6100@0Q8B408>3P`24Q8@0Q8B41020P8006`25QHD0OWin07moO`1oOgl0Ph>30861P@1iNGT0
O7al07emO@1kNg/0OWin08>3P`1mOGd0PH6108B4Q02EUID0TI6A08j>SP2GUiL0SHf=092@T02JVYX0
UiNG09>CT`2LW9`0UYJF092@T002096AT@1G09>CT`2FUYH0VIVI09VIV@2OWil0W9bL0::RXP2b/[80
XJ6Q09BDU02WYjL0Zj^[0;>c/`2/[:`0[Jf]0;Zj^P2d];@0XZ:R0:j^[P2h^;P0]kNg0;2`/02YZJT0
_;bl0<O7a`2j^[X0[Jf]0;:b/P2m_Kd0`l?30;Zj^P2b/[80[jn_0;Vi^@30`<00`l?30;^k^`2^[Zh0
WYjN09fMW@2ATI40NWYj07MgM`1hN7P0Lg=c07MgM`1iNGT0Lg=c07AdM01gMgL0Lg=c07QhN022PX80
NWYj07]kN`1mOGd0NWYj07inOP1mOGd0O7al07]kN`1oOgl0P82007moO`24Q8@0Ph>308B4Q023Ph<0
OWin0861P@22PX80Ph>308:2PP21PH40PX:207]kN`1nOWh0NWYj08>3P`22PX80O7al0820P01nOWh0
Ogmo0861P@1mOGd0OWin00<0Ogmo00<0PH6107emO@1lO7`00P1nOWh01P1lO7`0Ogmo07moO`1lO7`0
Ogmo07EeM@80N7Qh0P1iNGT207IfMP0b07EeM@1^KVh0Lg=c075aL@1bLW80Kfm_079bLP1`L700KFe]
06a/K01[Jf/0JVYZ06i^KP1/K6`0LG5a079bLP1jNWX0MgMg07emO@25QHD0Ph>308J6QP2:RXX0Rh^;
08f=S@2>SXh0TY:B09>CT`2ATI40Rh^;096AT@2>SXh0Shn?09NGU`2?Shl0TI6A09:BTP2IVIT0UiNG
09FEU@2GUiL0VIVI09NGU`2JVYX0W9bL09VIV@2JVYX0VIVI09ZJVP2MWId209ZJVP0609VIV@2CTi<0
UIFE09ZJVP2IVIT0V9RH0P2IVIT209RHV00409FEU@2GUiL0VIVI09fMW@80Vi^K0`2JVYX01@2KVi/0
V9RH09JFUP2FUYH0UiNG0080VYZJ0P2FUYH02P2HV9P0UIFE09FEU@2FUYH0Ti>C09BDU02ATI40Shn?
092@T02>SXh308n?S`0608j>SP2DU9@0SXj>08b<S029RHT0S8b<0P2?Shl0102BTY80SHf=08b<S02>
SXh2092@T00<08f=S@2;Rh/0T92@09>CT`2ATI40UYJF0:>SX`2h^;P0a<C40<_;b`3Bd]80e]KF0P3I
fMT0103Jf]X0gMgM0=kNgP3Ogml30>3Ph00J0=kNgP3Kfm/0e]KF0<_;b`2l_;`0ZJVY08J6QP1/K6`0
Kfm_06MWI`1/K6`0L71`07QhN01fMWH0N7Qh07inOP1mOGd0MWIf06YZJP1MGEd0C4a<03<c<`0[:b/0
9RHV02XZ:P0[:b/202d];@05034a<@0[:b/0;2`/02XZ:P0a<C400P0];Bd03@0/;2`0<C4a038b<P0f
=SH0<S8b03Lg=`0h>3P0=CDe03@d=00f=SH0B4Q803`l?011@D400P0i>CT02P0h>3P0?clo03lo?`0h
>3P0=3@d02`/;00^;Rh09bLW02/[:`0/;2`202XZ:P0802l_;`0d=3@0;Rh^034a<@0f=SH0<C4a02l_
;`0];Bd>0<SPf0003038h=P20:>SX`80X:2P00H0XZ:R0:2PX02OWil0Y:BT0:2PX02RXZ820:>SX`0<
0:ZZZP2WYjL0ZZZZ0:^[Z`2/[:`0Z:RX0:BTY02SXj<0WinO09^KV`2JVYX0VIVI0P2FUYH00`2CTi<0
UIFE09FEU@0209NGU`0;09>CT`2DU9@0U9BD09ZJVP2NWYh0XZ:R0:JVYP2RXZ80X:2P0:>SX`2QXJ40
0P2TY:@07@2MWId0XJ6Q0:2PX02LW9`0XJ6Q0:FUY@2SXj<0Y:BT0::RXP2QXJ40WYjN09^KV`2GUiL0
VIVI08Z:RP2;Rh/0Q8B408:2PP1nOWh0KFe]06QXJ01LG5`0GemO05UIF@1CDe<0DU9B05EEE@1LG5`0
FUYJ0080GemO00h0G5aL05iNGP1OGel0IfMW06ATI01VIVH0IfMW06a/K01[Jf/0J6QX06][J`1YJFT0
JVYZ06i^KP80IFEU00D0J6QX06EUI@1/K6`0I6AT06QXJ00206IVIP0J06YZJP1VIVH0IfMW06QXJ01Y
JFT0Jf][06a/K01`L700Kfm_079bLP1dM7@0Kfm_071`L01aLG40K6a/071`L01gMgL0MWIf07UiN@1j
NWX0OGem07YjNP1gMgL0NGUi07emO@1kNg/207alO0030820P01lO7`0NWYj0080Ng]k00<0OGem07al
O01mOGd00P1lO7`00`20P800OWin07moO`020820P00508:2PP1jNWX0OGem07inOP20P8000P1mOGd0
1P1oOgl0P82008:2PP23Ph<0PX:207inOP80P82002L0QHF508:2PP1oOgl0O7al07emO@1nOWh0P820
0861P@20P800PX:207moO`21PH40Ogmo07inOP20P800PH6107inOP25QHD0OGem0820P023Ph<0Ogmo
0861P@22PX80QhN708>3P`1nOWh0PH6107inOP22PX80Ogmo08:2PP20P800PH6107moO`20P800PH61
0820P01mOGd00P20P8003P1nOWh0PH6108R8R024Q8@0OWin08F5Q@2>SXh0O7al08V9R@2MWId0S8b<
08B4Q02FUYH0VYZJ0`2?Shl03`2>SXh0T92@092@T02HV9P0WIfM0:2PX02NWYh0YjNW0:f][@2YZJT0
VYZJ0:b/[02i^KT0[jn_0:6QX@020;>c/`0K0:RXZ02SXj<0/k>c0<30`02g]kL0Z:RX0;>c/`32`/80
`L710;Bd]02_[jl0^k^k0<C4a033`l<0][Jf0:BTY02RXZ80X:2P0:6QX@2?Shl0O7al07]kN`1hN7P0
LW9b07EeM@1fMWH0MGEe0080M7Ad00P0MWIf07UiN@1kNg/0NGUi07]kN`1oOgl0NWYj07moO`80O7al
00P0Ng]k0820P01iNGT0OWin07emO@1nOWh0Ph>308B4Q080Ph>30P21PH400`23Ph<0Q8B408>3P`02
0861P@0>08B4Q020P800OWin0820P021PH40Ph>307YjNP1nOWh0Ogmo0861P@1oOgl0P8200861P@1m
OGd208B4Q00<08:2PP1mOGd0OGem07emO@1oOgl0Ph>307inOP1mOGd0NGUi07]kN`1jNWX0MgMg0`1i
NGT00`1fMWH0M7Ad075aL@02071`L00306m_K`1dM7@0Kfm_0080LW9b00X0L71`06a/K01]KFd0Jf][
06i^KP1]KFd0L71`07=cL`1gMgL0NGUi0P1lO7`01P20P800RXZ:08R8R02@T900Shn?092@T0<0Shn?
00L0S8b<096AT@2>SXh0TI6A09JFUP2BTY80Ti>C0080UYJF01X0U9BD09RHV02HV9P0V9RH09bLW02J
VYX0WYjN09ZJVP2LW9`0WYjN09^KV`2JVYX0Vi^K09jNWP2HV9P0UYJF09VIV@2JVYX0UiNG09fMW@2I
VIT0VYZJ09VIV@2KVi/0VIVI09ZJVP<0Vi^K00T0UiNG09^KV`2KVi/0VYZJ09jNWP2HV9P0VIVI09FE
U@2HV9P00`2FUYH02`2IVIT0V9RH09JFUP2FUYH0Ti>C09FEU@2@T900TY:B08j>SP2CTi<0UiNG0080
TY:B00h0SXj>092@T02ATI40T92@08f=S@2BTY80SHf=08j>SP2?Shl0TI6A08Z:RP2CTi<0S8b<08n?
S`<0S8b<0200SXj>096AT@2@T900V9RH0;2`/030`<00bl_;0<k>cP3AdM40emOG0=[JfP3Lg=`0gMgM
0=oOg`3Ng]h0gMgM0>3Ph03MgMd0g]kN0=_Kf`3GemL0d=3@0<K6aP2_[jl0UIFE07AdM01YJFT0K6a/
06UYJ@1VIVH0KVi^07EeM@80LW9b00/0O7al07inOP1jNWX0Lg=c06i^KP1RHV80CTi>03`l?00/;2`0
9bLW02l_;`0202PX:00:02HV9P0Z:RX0:RXZ02`/;00];Bd0:RXZ02TY:@0`<300<C4a038b<P80<c<c
00D0>SXj03dm?@0d=3@0<c<c03`l?00203Lg=`0:03dm?@0j>SX0?3`l03Ti>@0h>3P0=3@d03<c<`0d
=3@0<C4a02h^;P80:RXZ00P0;2`/02h^;P0^;Rh0<C4a02h^;P0W9bL0;Rh^02d];@80<30`00<0=CDe
0<SPf038h=P03038h=P000`0b>3H0P2SXj<01P2OWil0YJFU0:BTY02SXj<0X:2P09fMW@80X:2P00@0
XZ:R0:FUY@2TY:@0Xj>S0P2[Zj/00`2YZJT0Zj^[0::RXP020:2PX00909fMW@2JVYX0Vi^K09JFUP2H
V9P0UIFE09VIV@2EUID0UYJF0080U9BD00H0UiNG09RHV02JVYX0W9bL09nOW`2TY:@20::RXP0Q0:JV
YP2SXj<0XZ:R0::RXP2TY:@0WIfM09nOW`2TY:@0Z:RX0:BTY02OWil0XZ:R0:>SX`2OWil0WIfM09jN
WP2IVIT0Ti>C08n?S`2BTY80PX:208B4Q01lO7`0Jf][06IVIP1QHF40Fe]K05YJFP1ADE40EUIF05AD
E01MGEd0FUYJ0080Hf=S00<0HF5Q06ATI01QHF400P1WIfL06`1XJ6P0IfMW06a/K01XJ6P0IFEU06a/
K01^KVh0LG5a06][J`1VIVH0I6AT06MWI`1UIFD0I6AT06IVIP1UIFD0K6a/06IVIP1WIfL0JFUY06AT
I01WIfL0JVYZ06IVIP1/K6`0LW9b06a/K00206m_K`06071`L01bLW80LG5a07=cL`1fMWH0MgMg0P1i
NGT207QhN00607YjNP1mOGd0MGEe07]kN`1jNWX0Ng]k0P1jNWX02`1lO7`0NWYj07moO`1oOgl0OWin
07emO@1nOWh0O7al07moO`1mOGd0PH610080OGem00T0PX:207moO`24Q8@0OWin07alO01nOWh0Ogmo
07YjNP20P8000P1oOgl01@1nOWh0Q8B408:2PP20P800O7al0080OGem00T0P8200861P@22PX80Ph>3
08F5Q@1nOWh0Ogmo08:2PP1oOgl00P1mOGd03`20P800O7al07emO@22PX80Q8B407moO`21PH40Q8B4
0861P@24Q8@0QHF508R8R021PH40QXJ607inOP0208:2PP070820P01mOGd0NWYj07emO@21PH40Ogmo
0861P@0207alO00507emO@25QHD0Q8B408N7Q`21PH40101nOWh02`1iNGT0Q8B408F5Q@2=SHd0OGem
08:2PP2JVYX0W9bL08R8R02@T900TI6A0080Shn?03P0Ti>C08b<S02EUID0VYZJ09RHV02NWYh0];Bd
0;>c/`2LW9`0XZ:R0;Ng]`2_[jl0Y:BT0:NWY`2e]KD0/K6a09nOW`2_[jl0_kno0;fm_@2^[Zh0/K6a
0;^k^`30`<00_[jn0:n_[`2XZ:P0YjNW0:RXZ02?Shl0Ogmo07YjNP1hN7P0MGEe075aL@1cLg<0MWIf
075aL@1gMgL0MWIf075aL@1eMGD0NWYj07UiN@1lO7`0Ng]k07emO@1jNWX0Ng]k07alO01mOGd0OWin
08>3P`1mOGd0Ng]k07emO@80P82000<0O7al0820P021PH400`23Ph<01@21PH40Q8B408>3P`22PX80
P8200080PX:200H0P82007UiN@1mOGd0OWin07emO@1oOgl207emO@80O7al00<0Ogmo0820P01kNg/0
0P25QHD0101jNWX0OWin07emO@1mOGd207alO00307]kN`1lO7`0O7al00<0N7Qh01`0NGUi07IfMP1f
MWH0M7Ad07IfMP1eMGD0LG5a07EeM@1fMWH0LW9b071`L01_Kfl0KVi^06a/K01ZJVX0L71`06MWI`1/
K6`0LG5a07=cL`1eMGD0MgMg07QhN01oOgl0Q8B408>3P`2:RXX0SHf=0P2;Rh/00`2CTi<0SXj>09BD
U003096AT@0;08b<S02@T900TY:B09FEU@2DU9@0UIFE09RHV02EUID0UYJF09VIV@2MWId00P2IVIT0
1@2KVi/0W9bL09bLW02LW9`0Vi^K0080WIfM00H0W9bL09NGU`2IVIT0UYJF09^KV`2HV9P209^KV`03
09NGU`2KVi/0UiNG0080V9RH0P2LW9`01P2JVYX0V9RH09ZJVP2JVYX0Vi^K09bLW080VIVI0P2FUYH0
2P2HV9P0UIFE09ZJVP2HV9P0UYJF09>CT`2HV9P0Ti>C092@T02DU9@209>CT`0;096AT@2BTY80T92@
096AT@2CTi<0SXj>09FEU@2>SXh0Shn?09:BTP2ATI400P2>SXh00`2?Shl0Rh^;08n?S`02096AT@0P
08b<S02>SXh0S8b<08j>SP2?Shl0V9RH0:RXZ02i^KT0a/K60<c<c03Cdm<0e]KF0=SHf03Kfm/0g=cL
0=kNgP3Ph>00g]kN0=oOg`3Ng]h0gmoO0=gMg@3Jf]X0d];B0<c<c02m_Kd0X:2P07inOP1_Kfl0KFe]
07emO@1`L70206m_K`0>071`L01fMWH0LG5a07=cL`1lO7`0MWIf07emO@1hN7P0JVYZ05UIF@12@T80
<30`02d];@0_;bl202`/;00302h^;P0[:b/0:b/[0080<30`00L0;bl_02d];@0Z:RX0;Rh^038b<P0a
<C40=3@d0080<S8b00L0>CTi03Hf=P0g=cL0>3Ph03Xj>P10@400?clo0080>c/k0P0h>3P303<c<`0;
02d];@0`<300:b/[02/[:`0a<C40:b/[02`/;00`<300;Rh^02/[:`0_;bl00P0`<3000`0];Bd0b>3H
0<SPf00<0<SPf0003038h=P20:BTY00I09nOW`2QXJ40Y:BT09nOW`2RXZ80X:2P09nOW`2NWYh0Xj>S
0:BTY02SXj<0Y:BT0:RXZ02VYZH0YjNW0:RXZ02UYJD0X:2P0:BTY02LW9`0VYZJ09nOW`2IVIT0V9RH
09fMW@0209VIV@0309JFUP2HV9P0UYJF0080VYZJ00L0VIVI09^KV`2NWYh0YJFU0:6QX@2TY:@0YZJV
00<0YJFU00H0X:2P0:6QX@2QXJ40WIfM0:BTY02RXZ820:6QX@030:BTY02OWil0W9bL0080VYZJ0180
UIFE08n?S`2<S8`0Ph>307alO01dM7@0JFUY06MWI`1LG5`0FEUI05MGE`1>CTh0EEEE05=CD`1NGUh0
Fe]K05UIF@1JFUX205mOG`0C06EUI@1SHf<0JVYZ06ATI01XJ6P0IVIV06e]K@1YJFT0J6QX06e]K@1X
J6P0KFe]06UYJ@1ZJVX0IFEU06a/K01ZJVX0Jf][06EUI@0206IVIP0>06EUI@1XJ6P0IVIV06IVIP1[
Jf/0J6QX06e]K@1dM7@0Kfm_075aL@1^KVh0MWIf07EeM@1dM7@207=cL`0>07QhN01mOGd0NGUi07If
MP1jNWX0NGUi07]kN`1hN7P0NWYj07emO@1hN7P0NWYj07alO01kNg/307YjNP0707emO@1jNWX0Ng]k
07UiN@21PH40OGem08:2PP0207inOP0707]kN`21PH40O7al07inOP1iNGT0Ogmo07]kN`020861P@08
07inOP20P800PX:20861P@23Ph<0O7al07moO`1lO7`20820P00608B4Q021PH40P82008B4Q023Ph<0
PH610P1nOWh04@1jNWX0Ogmo0820P021PH40Ph>309FEU@2?Shl0PX:208B4Q022PX80P8200861P@26
QXH0Ph>308b<S022PX80NGUi0080Ogmo01@0PX:207moO`1mOGd0OWin08F5Q@20P800O7al0820P022
PX80RHV908b<S029RHT0PH6107UiN@1kNg/0OWin08:2PP1nOWh0O7al07]kN`80Ogmo00L0P82007in
OP24Q8@0UIFE08f=S@28R8P0S8b<0080Rh^;0140QhN708V9R@24Q8@0R8R809bLW02=SHd0TY:B0;:b
/P2h^;P0WYjN09bLW02a/K40^[Zj0:ZZZP2RXZ80/[:b0;6a/@020:JVYP0<0:j^[P2h^;P0[Zj^0:2P
X02TY:@0YjNW09^KV`26QXH0O7al07moO`1lO7`0LW9b0P1gMgL04@1fMWH0MGEe07AdM01fMWH0NGUi
07MgM`1fMWH0Ng]k07YjNP1hN7P0NGUi0820P01mOGd0O7al07emO@1nOWh0Ogmo00<0OGem0100OWin
07YjNP20P800OWin0861P@1nOWh0P82008F5Q@22PX80QHF50820P01oOgl0Q8B407moO`21PH40O7al
0P20P8002P1oOgl0OWin07UiN@1oOgl0O7al07emO@21PH40O7al07moO`20P80207emO@0[07]kN`22
PX80PX:207emO@1oOgl0OWin0820P01kNg/0O7al07moO`1nOWh0O7al07emO@1kNg/0N7Qh07IfMP1d
M7@0MgMg079bLP1`L700MGEe071`L01_Kfl0MWIf07QhN01aLG40Kfm_06i^KP1aLG40KVi^06][J`1Z
JVX0L71`075aL@1fMWH0Lg=c07MgM`1iNGT0P8200861P@25QHD0R8R808V9R@0208b<S080Shn?00T0
T92@08j>SP2ATI40UIFE08n?S`2@T900UYJF09FEU@2CTi<00`2GUiL01`2FUYH0VYZJ09^KV`2JVYX0
WIfM09bLW02IVIT00P2NWYh00`2KVi/0UiNG09bLW00209VIV@0409RHV02JVYX0V9RH09JFUP80VIVI
00P0UiNG09ZJVP2HV9P0V9RH09fMW@2LW9`0VIVI09ZJVP<0Vi^K00/0VIVI09fMW@2KVi/0V9RH09VI
V@2KVi/0VIVI09JFUP2JVYX0V9RH09VIV@0209FEU@0809JFUP2CTi<0TY:B09JFUP2CTi<0U9BD09FE
U@2CTi<2092@T00308j>SP2DU9@0SHf=0080SXj>00P0Shn?08j>SP2GUiL0RHV908n?S`2ATI40T92@
096AT@80SXj>0P2<S8`0202@T900WYjN0;:b/P30`<00c<c<0<k>cP3De=@0e]KF0P3Lg=`00`3MgMd0
g]kN0=oOg`030>3Ph00>0=kNgP3Jf]X0e=CD0<o?c`30`<00[:b/08f=S@1/K6`0HV9R06MWI`1fMWH0
JFUY06YZJP1]KFd207EeM@0307MgM`1dM7@0NGUi0080OGem00L0O7al07=cL`1YJFT0F5QH059BDP10
@400;bl_0080;Bd]00@0:b/[02`/;00Z:RX0<S8b0P0`<300100/;2`0:RXZ02/[:`0a<C4202h^;P0<
030`<00d=3@0=3@d03Hf=P0l?3`0>SXj03Lg=`0l?3`0>3Ph03dm?@0d=3@0=cLg0P0h>3P0400n?Sh0
=CDe02XZ:P0k>c/0<S8b02l_;`0f=SH0;2`/02d];@0/;2`0;bl_02h^;P0d=3@0;Bd]02`/;00_;bl>
0<SPf0003038h=P20:6QX@0609nOW`2NWYh0XJ6Q09nOW`2MWId0XZ:R0`2PX:003@2SXj<0XZ:R0::R
XP2WYjL0[:b/0:ZZZP2][Jd0ZZZZ0:>SX`2RXZ80XJ6Q09fMW@2KVi/00P2IVIT03P2LW9`0Vi^K09ZJ
VP2LW9`0WYjN09^KV`2NWYh0Vi^K0:2PX02JVYX0X:2P0:>SX`2UYJD0Y:BT0P2PX:0409nOW`090:6Q
X@2NWYh0XJ6Q0:>SX`2RXZ80XJ6Q0:JVYP2QXJ40X:2P0080V9RH01H0UYJF08n?S`27QhL0PH6107in
OP1aLG40JVYZ065QH@1PH600F5QH05=CD`1>CTh0DU9B05ADE01PH600G5aL05iNGP1RHV80HF5Q069R
HP1SHf<0IFEU0P1TI6@05@1YJFT0IfMW06][J`1VIVH0JVYZ06MWI`1SHf<0JVYZ069RHP1VIVH0Hf=S
06IVIP1[Jf/0JFUY06IVIP1UIFD0K6a/06EUI@1VIVH0IfMW06][J`0206QXJ00;06a/K01bLW80KFe]
06][J`1^KVh0Kfm_07EeM@1hN7P0MWIf07EeM@1gMgL00P1hN7P0301iNGT0Lg=c07IfMP1jNWX0MWIf
07YjNP1oOgl0O7al07]kN`1jNWX0O7al07UiN@80MgMg00@0Ng]k0820P01lO7`0OGem0P1lO7`01P1n
OWh0PX:207inOP22PX80OWin07UiN@80Ng]k00P0OGem07YjNP21PH40P82007]kN`1oOgl0P82008:2
PP80PH6100P0P82008V9R@1oOgl0PH6108^;R`1oOgl0OWin08:2PP80Ogmo00L0OWin07emO@1lO7`0
OGem07alO026QXH0Ogmo0080QXJ600<0Q8B40820P01nOWh00`22PX802`21PH40QHF507alO020P800
Q8B40820P01mOGd0O7al0820P022PX80O7al0080OGem0P22PX8208B4Q00308:2PP1oOgl0Ng]k0080
OWin00@0NWYj0820P020P800O7al0P1jNWX01`1oOgl0P82007YjNP1lO7`0OWin07emO@1lO7`00P1n
OWh0;`1kNg/0OGem08:2PP1kNg/0PX:209BDU02;Rh/0T92@0:^[Z`2a/K40VYZJ092@T02XZ:P0];Bd
0::RXP2BTY80VYZJ0:>SX`2CTi<0S8b<08n?S`2DU9@0Ph>307IfMP1jNWX0O7al07MgM`1dM7@0MgMg
07UiN@1fMWH0Ng]k07alO01kNg/0O7al07IfMP1gMgL0NWYj07UiN@1jNWX0Ng]k07UiN@1hN7P0O7al
07]kN`1nOWh0NGUi0080NWYj00T0PX:20820P01mOGd0P82007]kN`1oOgl0P82007moO`20P8000`1o
Ogl30861P@0808:2PP24Q8@0PX:207emO@1lO7`0Ogmo07inOP1mOGd20820P00608B4Q01kNg/0PH61
08:2PP21PH40Ogmo0P1mOGd01023Ph<0P82008:2PP22PX8207emO@090861P@23Ph<0Ogmo07UiN@1m
OGd0P82007emO@22PX80O7al0080NWYj00/0M7Ad07MgM`1fMWH0L71`07AdM01fMWH0Kfm_07EeM@1f
MWH0LW9b071`L00206m_K`0J06MWI`1[Jf/0KVi^06a/K01`L700M7Ad079bLP1dM7@0NWYj08:2PP1n
OWh0QXJ608^;R`2:RXX0SHf=08^;R`2?Shl0Ti>C09JFUP2?Shl0TY:B09NGU`2ATI40UIFE09JFUP2H
V9P209ZJVP0309NGU`2FUYH0VIVI0080VIVI00D0WYjN09bLW02OWil0Vi^K09fMW@0309ZJVP0609^K
V`2HV9P0Vi^K09^KV`2JVYX0Vi^K0P2JVYX02P2LW9`0V9RH09nOW`2MWId0V9RH09ZJVP2IVIT0Vi^K
09jNWP2MWId209VIV@80W9bL00D0V9RH09NGU`2LW9`0WYjN09bLW00409VIV@0509RHV02GUiL0UIFE
09BDU02EUID00P2FUYH03`2CTi<0T92@092@T02<S8`0SXj>09>CT`2DU9@0Shn?08j>SP2?Shl0SHf=
08n?S`2ATI40SHf=08b<S002092@T00908Z:RP2BTY80T92@08b<S02?Shl0VIVI0:ZZZP2k^k/0b<S8
0080d=3@00<0e]KF0=WIf@3Lg=`00P3MgMd20=oOg`0?0>3Ph03Ogml0gmoO0=gMg@3Fe]H0d=3@0<S8
b02b/[80VYZJ07IfMP1UIFD0I6AT06YZJP1VIVH0JFUY0080K6a/00h0L71`07UiN@1aLG40Kfm_079b
LP1iNGT0PH6107emO@1oOgl0N7Qh06IVIP1NGUh0DE5A03/k>`80;bl_00`0;2`/034a<@0`<300<30`
02XZ:P0];Bd0:b/[02`/;00Z:RX0;bl_038b<P0/;2`2034a<@0;03De=@0f=SH0<S8b03Xj>P0i>CT0
>c/k03lo?`0m?Cd0>SXj03De=@0d=3@00P0c<c<01`0`<300=cLg03Hf=P0l?3`0<C4a02l_;`0[:b/0
0P0/;2`01P0_;bl0<S8b030`<00^;Rh0<C4a02d];@h0b>3H000<0<SPf080XZ:R00<0XJ6Q09bLW02Q
XJ400P2TY:@0102MWId0X:2P0:6QX@2QXJ420::RXP040:BTY02WYjL0Z:RX0:f][@80ZZZZ00D0[jn_
0:JVYP2SXj<0WinO0:6QX@0209bLW00309nOW`2LW9`0Vi^K00<0W9bL00X0Vi^K09VIV@2LW9`0Vi^K
09bLW02PX:00XJ6Q0:2PX02TY:@0X:2P0`2QXJ402P2MWId0WYjN09nOW`2NWYh0XZ:R0:BTY02PX:00
WYjN0::RXP2MWId209VIV@0P09BDU02@T900Q8B407moO`1lO7`0MGEe06YZJP1QHF40H61P05eMG@1D
E5@0Cdm?05MGE`1FEUH0Fe]K05iNGP1MGEd0HF5Q06ATI01VIVH0J6QX065QH@1SHf<0KFe]06YZJP1S
Hf<0IFEU06MWI`1[Jf/0I6AT06EUI@1ZJVX206ATI00:06YZJP1_Kfl0JFUY06ATI01VIVH0IfMW06EU
I@1TI6@0JFUY06IVIP80IFEU00L0IVIV06YZJP1^KVh0K6a/06][J`1^KVh0Kfm_0080LW9b00H0MgMg
07EeM@1dM7@0NGUi07EeM@1hN7P207YjNP0907QhN01iNGT0NWYj07alO01kNg/0PH6107moO`1jNWX0
OGem00<0P82000<0Ng]k07moO`1nOWh00P1kNg/00`21PH40O7al07emO@0307emO@0407inOP1lO7`0
Ogmo07]kN`80O7al0P1nOWh02`21PH40OWin07moO`1mOGd0OWin07moO`1lO7`0Q8B40820P01oOgl0
OWin0080PH6100H0OWin07moO`1mOGd0O7al07moO`1kNg/30820P00>08:2PP21PH40P82008B4Q021
PH40P8200861P@22PX80QHF508>3P`1oOgl0Ph>308F5Q@1oOgl20820P0030861P@1oOgl0P8200080
OWin00d0P82008J6QP26QXH0PH6107inOP1oOgl0PH6108B4Q01oOgl0Ng]k0820P01kNg/0QHF50080
PX:200H0Ph>308:2PP1nOWh0Ogmo07alO01mOGd207QhN00;07]kN`1mOGd0N7Qh07EeM@1gMgL0O7al
07inOP1iNGT0P82009:BTP2?Shl00P20P800102<S8`0RXZ:07emO@1iNGT207emO@0807IfMP1eMGD0
NWYj07AdM01eMGD0Lg=c07AdM01hN7P207MgM`0607QhN01gMgL0OGem07inOP1iNGT0MGEe0P1hN7P2
07]kN`0;08N7Q`1mOGd0PH6107]kN`1nOWh0OGem07moO`1lO7`0NWYj08>3P`1oOgl00P22PX802021
PH40P8200861P@1oOgl0P82007moO`1kNg/0PX:20`21PH4208:2PP050861P@1oOgl0PX:207alO01n
OWh00P22PX802`1mOGd0PH6107inOP1lO7`0P82007moO`25QHD0Q8B407inOP1oOgl0P82000@0OGem
00D0OWin0820P01mOGd0O7al0861P@0207]kN`0307UiN@1kNg/0Ng]k0080O7al00@0M7Ad07EeM@1i
NGT0LG5a0P1`L700201cLg<0M7Ad07EeM@1eMGD0LG5a07=cL`1^KVh0Jf][0P1/K6`02P1`L700LW9b
075aL@1bLW80Lg=c07]kN`20P800OWin08F5Q@27QhL208^;R`0F08Z:RP2=SHd0Shn?096AT@2?Shl0
TY:B09>CT`2?Shl0UIFE09JFUP2GUiL0UYJF09RHV02GUiL0V9RH09NGU`2MWId0W9bL09ZJVP2KVi/0
W9bL09^KV`80WYjN0P2LW9`01@2IVIT0VYZJ09RHV02JVYX0WIfM0080UiNG00/0WYjN09NGU`2IVIT0
Vi^K09NGU`2HV9P0UiNG09fMW@2HV9P0W9bL09ZJVP0209fMW@0909ZJVP2KVi/0VIVI09NGU`2IVIT0
W9bL09RHV02LW9`0VYZJ0080VIVI00`0V9RH09BDU02JVYX0U9BD09NGU`2EUID0U9BD08n?S`2@T900
Ti>C092@T02>SXh2096AT@0408n?S`2=SHd0T92@08n?S`@0T92@00d0SXj>08n?S`2=SHd0S8b<092@
T02=SHd0TY:B09nOW`2f][H0aLG50<c<c03AdM40e=CD0080fMWI00<0fm_K0=kNgP3Ogml00P3Ng]h2
0>3Ph00E0=kNgP3Kfm/0dm?C0<c<c031`L40Z:RX08N7Q`1[Jf/0HV9R06YZJP1VIVH0K6a/06][J`1Z
JVX0KVi^071`L01bLW80M7Ad075aL@1eMGD0N7Qh0080NGUi0P22PX80101kNg/0Jf][065QH@1?Cdl2
03Ti>@09038b<P0/;2`0:b/[02TY:@0X:2P0;Rh^030`<00^;Rh0:BTY00<0<C4a0P0c<c<04`0f=SH0
<C4a03Hf=P0l?3`0>c/k03De=@0k>c/0>CTi03De=@0n?Sh0=cLg03Xj>P0e=CD0=3@d038b<P0d=3@0
=CDe038b<P0];Bd00P0[:b/01`0];Bd0;Rh^02h^;P0a<C40;bl_02/[:`0`<3003P38h=P000`0b>3H
0P2OWil03P2TY:@0X:2P0::RXP2SXj<0YJFU0:6QX@2SXj<0XZ:R09nOW`2RXZ80XJ6Q0:>SX`2VYZH0
YjNW0P2YZJT0102ZZZX0YjNW0:b/[02UYJD30:6QX@80WinO00@0WYjN09bLW02NWYh0X:2P0`2NWYh0
202MWId0VIVI09nOW`2PX:00XZ:R09nOW`2WYjL0X:2P0P2OWil0202MWId0X:2P09nOW`2PX:00WIfM
0:2PX02QXJ40X:2P0P2QXJ40402RXZ80VYZJ09FEU@2BTY80SXj>09FEU@20P800PH6107UiN@1]KFd0
HV9R05iNGP1GEeL0EEEE04m?C`1JFUX205MGE`0A065QH@1OGel0G5aL065QH@1VIVH0Hf=S06ATI01W
IfL0JFUY06ATI01VIVH0JVYZ06MWI`1[Jf/0KFe]06YZJP1YJFT00P1UIFD0201^KVh0JVYZ06=SH`1V
IVH0K6a/06YZJP1VIVH0J6QX0P1SHf<03@1/K6`0JFUY06IVIP1YJFT0K6a/06m_K`1]KFd0Kfm_06e]
K@1aLG40LW9b075aL@1cLg<00P1lO7`0101gMgL0Ng]k07UiN@1hN7P207EeM@0707AdM01gMgL0NGUi
07emO@1kNg/0N7Qh07inOP0207]kN`080820P01mOGd0NWYj07]kN`1iNGT0OWin07QhN01mOGd207mo
O`0G07emO@23Ph<0P82007IfMP1kNg/0NWYj07alO01oOgl0NWYj07emO@1iNGT0PX:208B4Q020P800
PX:208B4Q020P800PX:207emO@20P800Ogmo0820P021PH400P20P8002P1mOGd0Ogmo07inOP1oOgl0
O7al07inOP20P800Ph>30820P01mOGd20820P00407inOP20P800Ogmo07inOP80PH6100@0OWin08B4
Q020P800PX:20`1mOGd00`24Q8@0P8200820P0020861P@0607alO023Ph<0OGem0861P@20P800PX:2
0P1nOWh02`21PH40P82008J6QP22PX80PH610820P01oOgl0OGem0820P01kNg/0OWin0080Ng]k00H0
OWin07moO`1kNg/0MWIf07YjNP1nOWh207alO00807YjNP1iNGT0O7al079bLP1jNWX0MGEe07IfMP1a
LG4207QhN003079bLP1gMgL0O7al0080MWIf00P0M7Ad07YjNP1gMgL0NGUi07AdM01hN7P0MGEe07em
O@<0NWYj0140Ng]k07alO01nOWh0NWYj07emO@20P800Ogmo0820P01oOgl0PH610820P022PX80OWin
08>3P`1oOgl0O7al07]kN`030861P@80P82000<0PH610820P01lO7`00P20P8001P24Q8@0PX:208:2
PP21PH40QHF507alO080OWin00@0Ogmo08>3P`23Ph<0PX:20P1lO7`20861P@070820P01kNg/0OGem
07]kN`21PH40P82007]kN`020820P00707emO@22PX80OGem07moO`22PX80OWin07EeM@0207MgM`04
07QhN01nOWh0Ng]k07QhN080MGEe00H0Ng]k07EeM@1bLW80M7Ad079bLP1dM7@2075aL@80Kfm_00@0
KVi^06e]K@1^KVh0JVYZ0P1]KFd207=cL`0@07QhN01jNWX0Ogmo07moO`27QhL0RXZ:08^;R`2<S8`0
Rh^;092@T02?Shl0U9BD09:BTP2DU9@0TY:B09BDU080UIFE00`0UiNG09ZJVP2KVi/0VYZJ09VIV@2H
V9P0W9bL09nOW`2MWId0WYjN0:6QX@2LW9`209VIV@80Vi^K0180VYZJ09VIV@2KVi/0VYZJ09^KV`2O
Wil0UiNG09bLW02JVYX0W9bL09^KV`2IVIT0V9RH09NGU`2JVYX0WIfM09bLW02MWId209VIV@0=09RH
V02JVYX0W9bL09NGU`2FUYH0X:2P09fMW@2NWYh0WIfM09NGU`2HV9P0Vi^K09RHV00209NGU`0309FE
U@2GUiL0Ti>C00<0TY:B00l0Shn?09:BTP2@T900Shn?096AT@2=SHd0TI6A092@T02BTY80SXj>08b<
S02=SHd0Rh^;096AT@2;Rh/00`2=SHd08`2GUiL0/;2`0;fm_@38b<P0clo?0=CDe03Hf=P0fm_K0=gM
g@3Lg=`0g]kN0=oOg`3MgMd0gmoO0>3Ph03Ng]h0gmoO0=KFeP3=cLd0a/K60;>c/`2DU9@0N7Qh06AT
I01QHF40IfMW06YZJP1/K6`0KFe]06a/K01ZJVX0Kfm_06e]K@1dM7@0LW9b0080MgMg0P1jNWX01P1m
OGd0PX:208V9R@1gMgL0LW9b05mOG`80BDU900/0@41002`/;00`<300:b/[02PX:00Z:RX0:b/[02XZ
:P0];Bd0;Rh^02l_;`03030`<00603Ti>@0g=cL0=CDe03`l?00i>CT0ADE50P0n?Sh0200j>SX0>CTi
034a<@0d=3@0=SHf03@d=00b<S80>3Ph0P0c<c<00`0_;bl0;Rh^02`/;00202`/;005030`<00c<c<0
;Rh^02TY:@0];Bd03P38h=P000`0b>3H0P2PX:00302NWYh0XJ6Q0::RXP2OWil0WYjN0:2PX02LW9`0
WinO0:6QX@2RXZ80X:2P09nOW`80YJFU00d0ZJVY0:ZZZP2XZ:P0Zj^[0:RXZ02UYJD0XZ:R0:6QX@2O
Wil0XZ:R0:BTY02LW9`0WIfM0080X:2P00/0XJ6Q09nOW`2NWYh0WinO09bLW02NWYh0Y:BT0:FUY@2Q
XJ40XZ:R09jNWP0209^KV`070:2PX02RXZ80XJ6Q0::RXP2QXJ40WinO0:6QX@020::RXP0?0:2PX02M
WId0VYZJ09JFUP2>SXh0Rh^;08R8R01mOGd0O7al071`L01YJFT0IFEU05eMG@1FEUH0FEUI0080DE5A
00l0De=C05YJFP1MGEd0FEUI069RHP1TI6@0Jf][06MWI`1VIVH0Hf=S06QXJ01VIVH0I6AT06][J`1V
IVH00P1XJ6P02@1VIVH0JFUY06IVIP1XJ6P0JFUY06a/K01QHF40Hf=S06][J`0206ATI004065QH@1Y
JFT0IFEU06QXJ080IfMW0`1ZJVX0101_Kfl0LG5a06i^KP1`L70207=cL`03079bLP1jNWX0N7Qh0080
NGUi00/0NWYj07EeM@1gMgL0MgMg07IfMP1jNWX0P82007]kN`1lO7`0Ogmo07UiN@0207alO00F0820
P01iNGT0OGem07]kN`1iNGT0P82007]kN`1jNWX0OGem08:2PP1lO7`0Ph>307inOP1kNg/0OGem07al
O021PH40O7al0861P@20P800O7al0820P080Ogmo01`0P82007moO`21PH40R8R807emO@24Q8@0PH61
07emO@21PH40Ng]k07emO@1nOWh0PH6108>3P`1mOGd0O7al0861P@24Q8@0Ph>30861P@1lO7`0P820
08>3P`24Q8@0Ph>307moO`23Ph<0P8200P22PX801`23Ph<0P82008:2PP1lO7`0QhN707moO`21PH40
0`22PX801`23Ph<0PX:207emO@1nOWh0Ogmo07emO@23Ph<00P1mOGd01020P800OWin08N7Q`24Q8@2
0861P@80OGem00<0Ng]k0820P021PH400P1kNg/01P1mOGd0Ng]k07]kN`1hN7P0OGem07YjNP80N7Qh
00T0MgMg07AdM01gMgL0MWIf07YjNP1kNg/0MgMg07YjNP1hN7P00P1dM7@207MgM`0=07YjNP1eMGD0
LW9b07AdM01fMWH0N7Qh07MgM`1hN7P0OGem07alO01nOWh0P82007emO@020861P@0307moO`1nOWh0
Ph>30080PH6100P0P8200861P@21PH40QXJ608:2PP20P800Ogmo0861P@80O7al0100OWin0861P@21
PH40Ogmo07emO@20P800Ogmo07QhN01lO7`0Ogmo08:2PP24Q8@0PX:208V9R@23Ph<0O7al0P1mOGd0
1@1lO7`0Ph>308>3P`25QHD0O7al0080OWin00P0P82007emO@1mOGd0P82007emO@1oOgl0O7al07in
OP80PX:200X0P82008:2PP1mOGd0PH6107alO01mOGd0O7al07emO@1jNWX0Ng]k0P1jNWX0501hN7P0
M7Ad075aL@1iNGT0MGEe07=cL`1bLW80Lg=c07MgM`1cLg<0LG5a07QhN01cLg<0KVi^075aL@1]KFd0
K6a/06i^KP1bLW80MGEe0P1hN7P03@1nOWh0O7al07moO`28R8P0RHV908F5Q@2>SXh0Shn?096AT@2?
Shl0Ti>C09:BTP2GUiL00P2EUID02@2FUYH0VIVI09VIV@2JVYX0V9RH09ZJVP2GUiL0W9bL09ZJVP02
09jNWP0509ZJVP2NWYh0X:2P09VIV@2KVi/00`2LW9`01@2KVi/0VIVI09^KV`2JVYX0WIfM0080Vi^K
00L0VIVI09fMW@2FUYH0VYZJ09VIV@2HV9P0VYZJ0080VIVI00<0VYZJ09VIV@2IVIT00P2JVYX00`2L
W9`0VYZJ09jNWP0209ZJVP0?09fMW@2LW9`0WIfM09fMW@2KVi/0V9RH09VIV@2GUiL0UYJF09FEU@2B
TY80U9BD09NGU`2FUYH0TI6A0080UIFE00/0TI6A09NGU`2ATI40SHf=096AT@2BTY80S8b<08n?S`2<
S8`0RXZ:08f=S@0308b<S00>09BDU02SXj<0]KFe0<C4a03;bl/0d];B0=OGe`3Jf]X0fm_K0=cLg03M
gMd0g]kN0=oOg`3Ng]h20=oOg`0N0>3Ph03Jf]X0dm?C0<[:bP2j^[X0XZ:R08J6QP1/K6`0Hf=S06QX
J01WIfL0KFe]06QXJ01YJFT0KFe]06][J`1aLG40Kfm_079bLP1]KFd0M7Ad079bLP1iNGT0NWYj07al
O024Q8@0Ph>30861P@1fMWH0LG5a0P1NGUh01P1ADE40?Cdm02h^;P0];Bd0:b/[02d];@80:BTY00P0
:RXZ02/[:`0^;Rh0:b/[02`/;00d=3@0<30`02h^;P80=SHf00D0=cLg03Xj>P0l?3`0?Cdm03Hf=P02
03@d=00<03Hf=P0a<C40>SXj034a<@0c<c<0=3@d034a<@0`<300=CDe034a<@0[:b/0;Rh^0`0];Bd0
0`0Y:BT0<C4a0<SPf00=0<SPf0003038h=P20:2PX00<09jNWP2QXJ40XZ:R09nOW`2NWYh0X:2P09bL
W02OWil0XJ6Q0::RXP2PX:00WinO0P2UYJD03@2YZJT0ZZZZ0:RXZ02[Zj/0Z:RX0:FUY@2RXZ80XJ6Q
09nOW`2RXZ80Y:BT09bLW02MWId00P2PX:002`2QXJ40WinO09jNWP2OWil0W9bL09jNWP2TY:@0YJFU
0:6QX@2RXZ80WYjN0080Vi^K00L0X:2P0::RXP2QXJ40XZ:R0:6QX@2OWil0XJ6Q0080XZ:R00l0X:2P
09fMW@2JVYX0UYJF08j>SP2;Rh/0R8R807emO@1lO7`0L71`06UYJ@1UIFD0GEeM05IFEP1IFET00P1A
DE403`1CDe<0FUYJ05eMG@1IFET0HV9R06ATI01[Jf/0IfMW06IVIP1SHf<0J6QX06IVIP1TI6@0Jf][
06IVIP0206QXJ00906IVIP1YJFT0IVIV06QXJ01YJFT0K6a/065QH@1SHf<0Jf][0080I6AT00@0HF5Q
06UYJ@1UIFD0J6QX0P1WIfL306YZJP0406m_K`1aLG40KVi^071`L080Lg=c00<0LW9b07YjNP1hN7P0
0P1iNGT02`1jNWX0MGEe07MgM`1gMgL0MWIf07YjNP20P800Ng]k07alO01oOgl0NGUi0080O7al01H0
P82007UiN@1mOGd0Ng]k07UiN@20P800Ng]k07YjNP1mOGd0PX:207alO023Ph<0OWin07]kN`1mOGd0
O7al0861P@1lO7`0PH610820P01lO7`0P8200P1oOgl07020P800Ogmo0861P@28R8P0OGem08B4Q021
PH40OGem0861P@1kNg/0OGem07inOP21PH40Ph>307emO@1lO7`0PH6108B4Q023Ph<0PH6107alO020
P800Ph>308B4Q023Ph<0Ogmo08>3P`20P80208:2PP0708>3P`20P800PX:207alO027QhL0Ogmo0861
P@0308:2PP0708>3P`22PX80OGem07inOP1oOgl0OGem08>3P`0207emO@040820P01nOWh0QhN708B4
Q080PH610P1mOGd00`1kNg/0P8200861P@0207]kN`0607emO@1kNg/0Ng]k07QhN01mOGd0NWYj0P1h
N7P02@1gMgL0M7Ad07MgM`1fMWH0NWYj07]kN`1gMgL0NWYj07QhN00207AdM080MgMg00d0NWYj07Ee
M@1bLW80M7Ad07IfMP1hN7P0MgMg07QhN01mOGd0O7al07inOP20P800OGem0080PH6100<0Ogmo07in
OP23Ph<00P21PH402020P800PH610861P@26QXH0PX:20820P01oOgl0PH610P1lO7`0401nOWh0PH61
0861P@1oOgl0OGem0820P01oOgl0N7Qh07alO01oOgl0PX:208B4Q022PX80RHV908>3P`1lO7`207em
O@0507alO023Ph<0Ph>308F5Q@1lO7`00P1nOWh02020P800OGem07emO@20P800OGem07moO`1lO7`0
OWin0P22PX802P20P800PX:207emO@21PH40O7al07emO@1lO7`0OGem07YjNP1kNg/207YjNP0D07Qh
N01dM7@0LG5a07UiN@1eMGD0Lg=c079bLP1cLg<0MgMg07=cL`1aLG40N7Qh07=cL`1^KVh0LG5a06e]
K@1/K6`0KVi^079bLP1eMGD207QhN00=07inOP1lO7`0Ogmo08R8R029RHT0QHF508j>SP2?Shl0TI6A
08n?S`2CTi<0TY:B09NGU`0209FEU@0909JFUP2IVIT0VIVI09ZJVP2HV9P0VYZJ09NGU`2LW9`0VYZJ
0080WYjN00D0VYZJ09jNWP2PX:00VIVI09^KV`0309bLW00509^KV`2IVIT0Vi^K09ZJVP2MWId00P2K
Vi/01`2IVIT0WIfM09JFUP2JVYX0VIVI09RHV02JVYX00P2IVIT00`2JVYX0VIVI09VIV@0209ZJVP03
09bLW02JVYX0WYjN0080VYZJ00l0WIfM09bLW02MWId0WIfM09^KV`2HV9P0VIVI09NGU`2FUYH0UIFE
09:BTP2DU9@0UiNG09JFUP2ATI400P2EUID02`2ATI40UiNG096AT@2=SHd0TI6A09:BTP2<S8`0Shn?
08b<S02:RXX0SHf=00<0S8b<00h0U9BD0:>SX`2e]KD0a<C40<_;b`3Bd]80emOG0=[JfP3Kfm/0g=cL
0=gMg@3Ng]h0gmoO0=kNgP80gmoO01h0h>3P0=[JfP3Cdm<0b/[:0;Zj^P2RXZ80QXJ606a/K01SHf<0
J6QX06MWI`1]KFd0J6QX06UYJ@1]KFd0Jf][075aL@1_Kfl0LW9b06e]K@1dM7@0LW9b07UiN@1jNWX0
O7al08B4Q023Ph<0PH6107IfMP1aLG4205iNGP06055AD@0m?Cd0;Rh^02d];@0[:b/0;Bd]0P0Y:BT0
200Z:RX0:b/[02h^;P0[:b/0;2`/03@d=00`<300;Rh^0P0f=SH01@0g=cL0>SXj03`l?00m?Cd0=SHf
0080=3@d00`0=SHf034a<@0j>SX0<C4a03<c<`0d=3@0<C4a030`<00e=CD0<C4a02/[:`0^;Rh302d]
;@0302TY:@0a<C40b>3H00d0b>3H000<0<SPf080Xj>S01h0XJ6Q09jNWP2QXJ40Y:BT09nOW`2QXJ40
WYjN0:2PX02TY:@0YJFU0:6QX@2PX:00YZJV0:>SX`2UYJD0Z:RX0:ZZZP2[Zj/0ZZZZ0:RXZ02WYjL0
YZJV0:>SX`2TY:@0Xj>S09nOW`2PX:00Xj>S0::RXP2TY:@20:2PX0070:6QX@2PX:00WIfM0::RXP2Q
XJ40X:2P0:>SX`030:2PX080XJ6Q00L0WYjN09nOW`2SXj<0XJ6Q0::RXP2OWil0XJ6Q0080WIfM01H0
VYZJ09NGU`2BTY80RXZ:08V9R@1oOgl0NGUi07=cL`1VIVH0I6AT05mOG`1HF5P0E5AD055AD@1CDe<0
F5QH05YJFP1IFET0I6AT05MGE`1IFET0K6a/0P1VIVH01@1aLG40JFUY06IVIP1/K6`0IFEU0080Hf=S
00@0I6AT06EUI@1VIVH0I6AT0P1VIVH02@1RHV80I6AT06][J`1UIFD0IVIV06=SH`1YJFT0HV9R06MW
I`0206IVIP0806=SH`1XJ6P0IfMW06UYJ@1[Jf/0Kfm_071`L01_Kfl2079bLP0507IfMP1kNg/0N7Qh
07UiN@1eMGD00P1hN7P02@1jNWX0MWIf07MgM`1nOWh0NWYj07QhN020P800MWIf07MgM`0207YjNP0B
07alO01hN7P0NWYj07]kN`1gMgL0Ng]k0861P@20P800Ogmo08:2PP1mOGd0Ng]k07emO@1kNg/0P820
07YjNP1mOGd0NGUi0P1lO7`01@1nOWh0OGem07inOP1jNWX0Ogmo0080O7al00<0PX:20820P01lO7`0
0P22PX802P20P800O7al08B4Q020P800PX:207moO`22PX80Ph>307inOP22PX8208B4Q00708:2PP1o
Ogl0PH610861P@26QXH0O7al0861P@020820P00307emO@20P800P8200080PX:200<0OGem07moO`1l
O7`00P21PH420820P00908J6QP1lO7`0PH6107moO`21PH40P8200861P@20P800Ng]k0080PX:200<0
P82007emO@1nOWh00P1lO7`00`1jNWX0P82007emO@0207emO@0407inOP1mOGd0OWin07UiN@<0NWYj
00H0N7Qh07EeM@1dM7@0MWIf07QhN01iNGT207EeM@0<07UiN@1fMWH0N7Qh07]kN`1iNGT0NWYj07Ui
N@1fMWH0N7Qh07=cL`1kNg/0N7Qh0P1iNGT02P1hN7P0O7al0820P01oOgl0P82007alO022PX80Ogmo
0861P@26QXH208B4Q00F07inOP1oOgl0PX:20861P@23Ph<0P82007inOP22PX80O7al07inOP23Ph<0
P82008>3P`1oOgl0OGem07moO`20P800OWin07]kN`20P800PH6108:2PP80PH6100T0Ogmo07inOP1m
OGd0Ng]k07emO@20P800OGem08:2PP21PH400P1mOGd00`1kNg/0Ph>307moO`0207moO`030820P01n
OWh0NWYj0080PH6101X0P82008N7Q`1nOWh0Ng]k08:2PP1nOWh0OGem07QhN01oOgl0O7al07YjNP1i
NGT0N7Qh07MgM`1cLg<0MGEe071`L01dM7@0LW9b07EeM@1cLg<0KVi^07QhN01eMGD0KVi^06m_K`80
KFe]00l0Lg=c06m_K`1`L700M7Ad07moO`1jNWX0O7al08:2PP25QHD0QXJ608N7Q`2;Rh/0TY:B08j>
SP2ATI400P2CTi<209:BTP0609BDU02HV9P0V9RH09VIV@2NWYh0VIVI0P2LW9`01P2NWYh0VYZJ09bL
W02LW9`0WinO09^KV`80WinO01H0Vi^K09VIV@2LW9`0W9bL09jNWP2JVYX0W9bL09RHV02NWYh0VIVI
09bLW02NWYh0VYZJ09VIV@2MWId0Vi^K09fMW@2HV9P0VIVI09RHV02JVYX0V9RH0P2LW9`0202HV9P0
VYZJ09fMW@2OWil0WYjN0:2PX02LW9`0WIfM0P2KVi/209bLW00409RHV02IVIT0VIVI09NGU`80V9RH
00@0UYJF09FEU@2EUID0UYJF0P2DU9@05@2FUYH0Shn?09:BTP2DU9@0Shn?092@T02?Shl0T92@08n?
S`2=SHd0RXZ:08b<S02;Rh/0SHf=09VIV@2_[jl0`L710<c<c03AdM40eMGE0=OGe`020=[JfP030=gM
g@3Ng]h0g]kN0080h>3P0200hN7Q0=kNgP3Lg=`0e=CD0<g=c@36a/H0[Zj^09FEU@1hN7P0I6AT069R
HP1YJFT0KFe]06][J`1]KFd0JVYZ071`L01aLG40MGEe079bLP1aLG40Kfm_075aL@1dM7@0N7Qh07al
O01jNWX0OGem08B4Q023Ph<0OWin07alO080LG5a00H0HF5Q055AD@0d=3@0=SHf02l_;`0Z:RX202`/
;00D02d];@0Z:RX0;Rh^02TY:@0[:b/0;bl_03@d=00_;bl0=3@d03Xj>P0e=CD0=cLg03<c<`0j>SX0
<c<c03`l?00d=3@0<S8b02h^;P0e=CD203Lg=`80<C4a00X0;Bd]02h^;P0a<C40;Rh^02`/;00];Bd0
;2`/02l_;`0Y:BT0;2`/3P38h=P000`0b>3H0P2TY:@05@2VYZH0XZ:R0:>SX`2QXJ40WIfM0:>SX`2R
XZ80Xj>S0:BTY02SXj<0XJ6Q0::RXP2QXJ40YjNW0:FUY@2TY:@0YJFU0:NWY`2ZZZX0Z:RX0:JVYP02
0:FUY@0?0:BTY02SXj<0Xj>S0:2PX02QXJ40Y:BT0:FUY@2TY:@0YjNW0:JVYP2NWYh0XJ6Q0:BTY02L
W9`0XJ6Q0080WinO0`2PX:00802RXZ80XJ6Q0:6QX@2PX:00XZ:R0:6QX@2RXZ80YJFU09jNWP2MWId0
VYZJ09VIV@2BTY80SXj>08J6QP1oOgl0NWYj07AdM01XJ6P0I6AT061PH01IFET0De=C04m?C`1ADE40
EEEE05aLG01TI6@0G5aL05]KF`1UIFD0HV9R0P1ZJVX206MWI`0806UYJ@1TI6@0IfMW06=SH`1TI6@0
JFUY06MWI`1[Jf/306IVIP0A06EUI@1VIVH0I6AT06ATI01]KFd0IFEU06=SH`1XJ6P0IVIV06][J`1V
IVH0JVYZ06UYJ@1ZJVX0KFe]07AdM01`L7000P1cLg<00`1fMWH0LW9b079bLP0207QhN00807EeM@1i
NGT0MGEe07]kN`1jNWX0N7Qh07YjNP1lO7`207QhN00307UiN@1jNWX0NGUi0080OWin00P0PH6107Mg
M`1iNGT0NGUi07]kN`20P800OWin08:2PP80Ng]k00D0OGem07inOP1oOgl0OGem0820P00207inOP0B
07alO020P800NGUi07emO@1jNWX0Ogmo07alO01kNg/0MgMg08:2PP1oOgl0P82007alO01oOgl0QHF5
0820P023Ph<0Ogmo0P22PX80301lO7`0Ph>307inOP20P800QXJ608>3P`1lO7`0PX:207inOP21PH40
OWin0820P080Ogmo0P24Q8@207moO`0L08B4Q022PX80PH610820P022PX80PH610820P021PH40Ph>3
08:2PP25QHD0OGem07inOP1oOgl0PH6108:2PP1nOWh0P82007emO@23Ph<0Ogmo07inOP1mOGd0P820
08B4Q01oOgl0MWIf08:2PP@0NGUi00h0P82007]kN`1kNg/0OWin07MgM`1fMWH0Lg=c07UiN@1gMgL0
NWYj07UiN@1jNWX0NGUi07]kN`80NGUi00<0Ng]k07EeM@1gMgL00P1hN7P02P1kNg/0N7Qh07QhN01f
MWH0Ng]k07YjNP1gMgL0O7al07emO@21PH4207moO`80OGem02H0Ogmo08:2PP22PX80PH6108:2PP24
Q8@0QHF508>3P`22PX80PH6107inOP20P800PH6107]kN`1oOgl0PX:207emO@23Ph<0O7al07YjNP1n
OWh0OGem07moO`23Ph<0P8200861P@1mOGd0Ogmo0820P01mOGd0OWin07moO`1hN7P0NGUi07moO`21
PH40P82007inOP<0P8200P1mOGd0101oOgl0PH6107YjNP20P80307alO00607moO`20P800Ogmo08:2
PP1mOGd0OWin0P1lO7`04`1nOWh0Ng]k07YjNP1hN7P0MGEe07UiN@1bLW80Lg=c07AdM01eMGD0MgMg
07IfMP1cLg<0KVi^07EeM@1bLW80LG5a07=cL`1dM7@00P1]KFd0101_Kfl0LW9b07=cL`1kNg/207al
O00=0861P@22PX80Q8B408Z:RP2;Rh/0Shn?08j>SP2?Shl0U9BD09JFUP2EUID0TY:B09BDU00209RH
V00609jNWP2HV9P0VYZJ09RHV02LW9`0X:2P0P2KVi/01`2JVYX0X:2P09fMW@2LW9`0WYjN09VIV@2Q
XJ400P2NWYh02@2JVYX0X:2P09fMW@2MWId0V9RH09^KV`2JVYX0WIfM09RHV00209fMW@0709RHV02K
Vi/0UYJF09NGU`2JVYX0VIVI09RHV00209^KV`0409ZJVP2MWId0WYjN09jNWP80WIfM0100Vi^K09fM
W@2KVi/0VIVI09bLW02NWYh0VYZJ09VIV@2HV9P0UIFE09^KV`2HV9P0VIVI09RHV02DU9@0UYJF0P2E
UID01`2GUiL0U9BD09:BTP2?Shl0Ti>C096AT@2>SXh00`2?Shl0302<S8`0SXj>08^;R`2CTi<0YZJV
0;Vi^@35aLD0c/k>0=GEe@3Fe]H0f=SH0=[JfP80gMgM00l0g]kN0=gMg@3Ph>00h>3P0>7Qh@3Ng]h0
f][J0=;BdP39bLT0_kno0:6QX@24Q8@0Jf][06ATI01UIFD00P1XJ6P04`1bLW80J6QX06][J`1`L700
Kfm_06i^KP1cLg<0MGEe07=cL`1gMgL0N7Qh07YjNP1kNg/0NGUi0820P025QHD0PH6108B4Q025QHD0
0P1iNGT07`1`L700Fe]K04];B`0h>3P0<30`02/[:`0V9RH0;Bd]038b<P0/;2`0:BTY02XZ:P0^;Rh0
=3@d02d];@0Y:BT0;Bd]030`<00b<S80<c<c03Lg=`0e=CD0<C4a03Ph>00a<C40=3@d03<c<`0e=CD0
<C4a030`<00a<C400P0_;bl02@0`<300=3@d030`<00/;2`0;Bd]02l_;`0/;2`0;bl_038b<P0>0<SP
f0003038h=P20:BTY00?0:2PX02RXZ80XZ:R09nOW`2NWYh0WinO09fMW@2PX:00XZ:R09nOW`2TY:@0
XJ6Q09jNWP2TY:@0X:2P0080YjNW00L0Z:RX0:VYZ@2YZJT0ZJVY0:JVYP2RXZ80Y:BT0080Xj>S00X0
YJFU0:6QX@2NWYh0Y:BT0::RXP2TY:@0YZJV0:2PX02OWil0XZ:R0`2OWil01P2MWId0X:2P0:2PX02O
Wil0WYjN0:>SX`80XJ6Q00X0XZ:R09jNWP2SXj<0XZ:R09jNWP2KVi/0W9bL09VIV@2@T900TI6A0P28
R8P0201nOWh0MWIf06e]K@1PH600EeMG05]KF`1GEeL0DU9B0P1CDe<02@1FEUH0G5aL06=SH`1TI6@0
IFEU06=SH`1VIVH0I6AT06IVIP0206EUI@0706QXJ01]KFd0Kfm_06EUI@1VIVH0JVYZ06IVIP0206EU
I@0706=SH`1VIVH0Hf=S06YZJP1YJFT0IfMW06ATI00206YZJP0306IVIP1RHV80IFEU0080J6QX01H0
JFUY071`L01bLW80KVi^075aL@1`L700MWIf07EeM@1dM7@0MGEe07IfMP1eMGD0N7Qh07]kN`1fMWH0
MGEe07UiN@1eMGD0LW9b07]kN`1gMgL0MWIf0P1lO7`207emO@0;07]kN`1mOGd0O7al07moO`1lO7`0
PH6107emO@1lO7`0Ng]k07emO@1oOgl00P20P8005P1oOgl0NWYj0861P@1lO7`0Ogmo07YjNP1iNGT0
N7Qh07emO@22PX80NWYj08B4Q01nOWh0Ph>30861P@22PX80PH6108>3P`28R8P0PX:208F5Q@1nOWh2
08:2PP090861P@1nOWh0O7al07]kN`22PX80QXJ60820P027QhL0OGem0080P82000l0Ogmo08>3P`23
Ph<0Ph>308B4Q026QXH0OWin0861P@1oOgl0Q8B407moO`1nOWh0P8200861P@24Q8@00P23Ph<01P20
P800O7al07inOP23Ph<0Ogmo0820P080Ogmo00<0PH6107inOP1kNg/00P1nOWh00`1kNg/0Q8B407Yj
NP0207YjNP0:07QhN01iNGT0NGUi07alO022PX80N7Qh07YjNP1lO7`0NGUi07IfMP<0NWYj00L0O7al
07YjNP1eMGD0M7Ad07EeM@1lO7`0MGEe0080N7Qh00P0NWYj07EeM@1hN7P0Ng]k07MgM`1lO7`0NWYj
07inOP80NWYj00T0OWin07emO@1lO7`0P82008:2PP1mOGd0O7al07UiN@24Q8@00P23Ph<207moO`05
08J6QP22PX80Ph>308>3P`20P800101oOgl207inOP060861P@20P800NWYj0820P01mOGd0Ogmo0P22
PX802024Q8@0OWin0861P@1mOGd0OWin08:2PP1oOgl0PX:20P20P8000`1lO7`0OGem07inOP0207mo
O`0407]kN`1lO7`0Ng]k07]kN`80Ogmo00<0PH6107moO`20P8000P20P8004`1lO7`0PH6107emO@1o
Ogl0OWin07emO@1jNWX0Ng]k07moO`1lO7`0NWYj07QhN01gMgL0Lg=c07IfMP1cLg<0M7Ad07=cL`1e
MGD00P1cLg<01P1eMGD0L71`06m_K`1aLG40JVYZ06e]K@80KVi^00T0M7Ad07MgM`1gMgL0O7al07in
OP23Ph<0Q8B408J6QP29RHT00P2>SXh209BDU00409:BTP2HV9P0TY:B09FEU@80UiNG00D0Vi^K09ZJ
VP2JVYX0VIVI09^KV`0209bLW00309jNWP2LW9`0XZ:R0080X:2P00<0W9bL09^KV`2NWYh00P2MWId2
09bLW00<09^KV`2LW9`0WinO0:6QX@2IVIT0WIfM09^KV`2NWYh0VIVI09ZJVP2KVi/0W9bL0P2KVi/0
0`2IVIT0UIFE09VIV@0209bLW00C09fMW@2OWil0W9bL09nOW`2LW9`0WinO09^KV`2OWil0VIVI0:2P
X02LW9`0VYZJ0:2PX02HV9P0VYZJ09FEU@2IVIT0UiNG09bLW00209BDU00:09:BTP2EUID0UIFE096A
T@2BTY80U9BD096AT@2DU9@0UIFE08j>SP<0SHf=00d0SXj>08^;R`2=SHd0VIVI0;2`/031`L40b/[:
0<o?c`3Cdm<0emOG0=[JfP3Lg=`0gMgM0080g]kN00/0gmoO0>7Qh@3Ph>00gmoO0=gMg@3GemL0d=3@
0<G5a@2_[jl0SXj>07EeM@02069RHP0706=SH`1aLG40Kfm_071`L01/K6`0KFe]071`L002079bLP06
07IfMP1iNGT0NGUi075aL@1gMgL0NGUi0P1mOGd00`23Ph<0P8200820P00208B4Q080QXJ600`0N7Qh
06a/K01LG5`0BDU903@d=00/;2`09bLW02d];@0X:2P0;Rh^034a<@0/;2`2034a<@0802d];@0X:2P0
;bl_03/k>`11@D40@d=304a<C016ATH303lo?`0<0410@00i>CT0?Shn03<c<`0d=3@0=CDe034a<@0c
<c<0=3@d038b<P0];Bd0<30`0P0];Bd202h^;P0303Xj>P38h=P0b>3H00`0b>3H000<0<SPf080WinO
00d0X:2P09jNWP2SXj<0WYjN09fMW@2PX:00XZ:R0:>SX`2PX:00XZ:R09jNWP2OWil0XZ:R00<0Y:BT
00<0Xj>S0:NWY`2UYJD00P2YZJT02@2WYjL0Z:RX0:VYZ@2UYJD0ZZZZ0:RXZ02WYjL0Xj>S0:JVYP03
0:BTY0070:>SX`2RXZ80XZ:R0::RXP2SXj<0WIfM09jNWP0209fMW@0509nOW`2RXZ80XZ:R0:2PX02N
WYh00`2RXZ800`2QXJ40Xj>S09fMW@0209RHV00?08n?S`2:RXX0Rh^;08>3P`1lO7`0MWIf071`L01T
I6@0GEeM05ADE01@D500DU9B05QHF01CDe<0EeMG0080Fe]K00h0GemO05iNGP1UIFD0Hf=S06UYJ@1S
Hf<0J6QX06e]K@1YJFT0IVIV06QXJ01TI6@0Hf=S06MWI`80I6AT00@0JFUY06ATI01VIVH0IfMW0P1V
IVH01@1XJ6P0IfMW06UYJ@1WIfL0J6QX0080I6AT00P0JFUY06MWI`1ZJVX0Kfm_06i^KP1`L700Kfm_
07EeM@80Lg=c00H0LW9b07MgM`1fMWH0Lg=c07]kN`1iNGT207QhN00307MgM`1fMWH0M7Ad0080N7Qh
0P1mOGd01P21PH40NWYj07YjNP21PH40Ng]k07emO@80O7al00X0Ogmo07emO@1kNg/0Ng]k07moO`1l
O7`0Ogmo08:2PP1oOgl0P8200P1mOGd0101kNg/0OGem07UiN@1lO7`207emO@0<07moO`21PH40Ng]k
08:2PP1nOWh0Ogmo0861P@20P800Ph>307moO`1nOWh0Ogmo0P23Ph<03`21PH40OGem07moO`1mOGd0
Ogmo0820P022PX80O7al08:2PP21PH40PX:207inOP1oOgl0QHF507moO`030861P@0508B4Q020P800
OGem08:2PP1lO7`00P20P8001P1oOgl0Q8B408:2PP20P800OGem0861P@80Ogmo00D0P82007inOP1m
OGd0OWin07moO`0207inOP0707emO@1iNGT0Ng]k07inOP1lO7`0Ng]k07QhN00207EeM@0@07YjNP1o
Ogl0O7al07UiN@1eMGD0N7Qh07]kN`1mOGd0OWin07emO@20P800NWYj07]kN`1fMWH0NWYj07MgM`80
N7Qh00X0NGUi07EeM@1hN7P0MgMg07]kN`1iNGT0MgMg07YjNP1lO7`0Ogmo101mOGd01@1nOWh0PX:2
07alO021PH40OWin0080PH6100D0OWin08:2PP25QHD0QhN708>3P`020861P@0=08F5Q@21PH40PX:2
08B4Q01nOWh0Ogmo0861P@1lO7`0PX:20820P021PH40OWin0861P@020820P00308>3P`20P800QHF5
0080OGem00D0OWin07alO01nOWh0PH6107alO00207inOP80Ogmo00H0Ng]k07alO01oOgl0OGem07in
OP1mOGd20820P00708:2PP1oOgl0Ogmo07UiN@1lO7`0Ogmo07inOP020861P@0607moO`1mOGd0OWin
07inOP1jNWX0MgMg0P1iNGT03@1dM7@0MgMg07]kN`1nOWh0MWIf07moO`1hN7P0MGEe07=cL`1^KVh0
Kfm_06UYJ@1/K6`00P1XJ6P206][J`03075aL@1dM7@0O7al0080Ogmo00@0QXJ608V9R@28R8P0SXj>
0P2?Shl01`2BTY80U9BD09RHV02EUID0UYJF09NGU`2HV9P00P2JVYX00`2LW9`0Vi^K09bLW00209nO
W`0@0:2PX02LW9`0XJ6Q09fMW@2NWYh0WIfM09bLW02OWil0WYjN09^KV`2LW9`0WIfM09bLW02JVYX0
W9bL0:2PX080VYZJ00L0WYjN09^KV`2LW9`0Vi^K09nOW`2KVi/0WYjN0080V9RH00l0VYZJ09bLW02I
VIT0VIVI09fMW@2NWYh0XZ:R09bLW02MWId0W9bL09fMW@2JVYX0W9bL09VIV@2MWId00P2HV9P01P2I
VIT0Vi^K09fMW@2HV9P0VIVI09NGU`80UYJF01`0VIVI09BDU02KVi/0U9BD092@T02FUYH0TY:B09>C
T`2@T900Shn?08j>SP2?Shl0Rh^;08j>SP2<S8`0TI6A0:>SX`2i^KT0aLG50<k>cP3Bd]80eMGE0=SH
f03Kfm/0gMgM0=kNgP3MgMd0g]kN0P3Ogml04P3QhN40g]kN0=WIf@3Bd]80b/[:0;Vi^@2LW9`0OGem
06IVIP1SHf<0HV9R06=SH`1[Jf/0JFUY06m_K`1^KVh0Kfm_071`L080Lg=c00d0LW9b07MgM`1hN7P0
MgMg07EeM@1iNGT0O7al07inOP1iNGT0OWin08F5Q@20P800QhN70080QXJ601D0P82007IfMP1[Jf/0
G5aL04Y:BP0f=SH0;Bd]02/[:`0`<300<S8b02`/;00X:2P0:BTY02XZ:P0[:b/0:2PX02h^;P0e=CD0
<S8b03De=@0d=3@00`0g=cL03P0n?Sh0>SXj03Ph>00m?Cd0=SHf03Ph>00e=CD0=3@d038b<P0h>3P0
=CDe02h^;P0/;2`0<c<c0P0_;bl203@d=0h0b>3H000<0<SPf080WYjN0`2OWil09@2NWYh0WIfM0:2P
X02TY:@0Zj^[0:b/[02VYZH0WinO0:>SX`2QXJ40Xj>S0:6QX@2VYZH0Y:BT0:FUY@2ZZZX0YjNW0:VY
Z@2XZ:P0YZJV0:ZZZP2VYZH0ZZZZ0:RXZ02UYJD0YZJV0:RXZ02WYjL0YJFU0::RXP2SXj<0Y:BT0:6Q
X@2NWYh0XJ6Q09ZJVP2MWId00P2OWil01P2PX:00WYjN09nOW`2PX:00XJ6Q09fMW@80XJ6Q0140X:2P
0:6QX@2PX:00Vi^K09FEU@2@T900Rh^;08J6QP25QHD0OWin07QhN01[Jf/0IVIV05iNGP1IFET0DU9B
05ADE00205=CD`0805aLG01IFET0IVIV05YJFP1KFe/0I6AT06=SH`1YJFT206MWI`0<06UYJ@1XJ6P0
IFEU06ATI01WIfL0HV9R06MWI`1UIFD0I6AT06YZJP1VIVH0J6QX0P1VIVH01`1SHf<0J6QX065QH@1V
IVH0JFUY06][J`1XJ6P00P1ZJVX0101[Jf/0Kfm_06][J`1/K6`2079bLP80L71`00D0LW9b07QhN01e
MGD0LG5a07EeM@0207alO00407=cL`1iNGT0NWYj075aL@80NGUi00@0Ng]k08:2PP1kNg/0N7Qh0P1i
NGT03P1jNWX0OWin08:2PP26QXH0Ng]k08:2PP1lO7`0PX:207emO@1lO7`0Ogmo08>3P`25QHD0Ogmo
0P1lO7`01@1mOGd0PH6107inOP1jNWX0OGem0080Ogmo00P0N7Qh07YjNP1kNg/0OWin07emO@1lO7`0
P8200861P@80P8200P1nOWh02@23Ph<0PX:207emO@1kNg/0P82007emO@1lO7`0P8200861P@020820
P00L08>3P`27QhL0QHF508R8R026QXH0R8R808f=S@29RHT0QXJ608:2PP23Ph<0PH6107moO`21PH40
QHF507inOP1oOgl0Ph>308:2PP20P800PH610820P024Q8@0P82007emO@1oOgl0OGem0820P080OWin
00D0P82007alO01kNg/0OGem07QhN00207]kN`0:07alO01hN7P0N7Qh07IfMP1nOWh0NGUi08>3P`1f
MWH0NGUi07inOP80O7al00D0OGem07moO`1nOWh0OWin07]kN`0207IfMP0807]kN`1eMGD0O7al07]k
N`1lO7`0MWIf07UiN@1hN7P207alO00307moO`1kNg/0OGem0080P8200P21PH402@20P800OGem08:2
PP1mOGd0PH6108>3P`21PH40Ph>30861P@0208B4Q00;08>3P`21PH40QXJ608J6QP22PX80Q8B407mo
O`21PH40Ogmo0820P01oOgl00P21PH420820P00708:2PP21PH40Q8B40861P@22PX80Ogmo07emO@02
07inOP0307emO@1nOWh0NGUi0080Ogmo00L0NGUi07emO@1jNWX0O7al0820P025QHD0PX:200<0OGem
00<0PH610820P020P8000P1mOGd01@20P800OWin07]kN`21PH40Ogmo0080Ng]k00h0NWYj07QhN01n
OWh0NWYj07MgM`1fMWH0M7Ad079bLP1mOGd0MgMg07]kN`1cLg<0LG5a07=cL`80Kfm_00l0L71`06a/
K01^KVh0JFUY071`L01/K6`0N7Qh07AdM01lO7`0Ogmo0820P026QXH0R8R808Z:RP2<S8`00P2=SHd0
0`2BTY80U9BD09BDU00209JFUP0409RHV02KVi/0VYZJ09fMW@80VYZJ00@0WYjN09fMW@2OWil0VYZJ
0`2LW9`0102PX:00Vi^K09^KV`2OWil309fMW@030:2PX02MWId0X:2P0080WIfM00L0Vi^K09fMW@2K
Vi/0VYZJ09bLW02NWYh0Xj>S0080W9bL00@0VIVI09ZJVP2LW9`0W9bL0P2OWil01@2LW9`0WIfM09bL
W02LW9`0Vi^K0080W9bL00H0WIfM09jNWP2KVi/0W9bL09ZJVP2MWId209VIV@0309jNWP2LW9`0VYZJ
0080UIFE00h0UYJF09NGU`2GUiL0V9RH09JFUP2@T900TI6A09NGU`2BTY80TI6A09:BTP2<S8`0TI6A
08b<S080SXj>00L0Vi^K0:j^[P2o_kl0b<S80=;BdP3EeMD0emOG0080fm_K00@0g=cL0=gMg@3Ng]h0
gmoO0P3Ph>00203Ng]h0gMgM0=CDe03<c<`0`<300:RXZ029RHT0LW9b0P1PH6002`1XJ6P0IfMW06m_
K`1/K6`0L71`06m_K`1gMgL0Lg=c07IfMP1aLG40MGEe0080OWin00X0O7al07UiN@1lO7`0NWYj0820
P01lO7`0P82008:2PP25QHD0Ph>30`25QHD06022PX80MWIf06UYJ@1KFe/0@D5103Ph>00/;2`09bLW
02TY:@0];Bd0:b/[02`/;00Z:RX0;Rh^02`/;00^;Rh0;bl_03<c<`0a<C40;Bd]034a<@0b<S80<c<c
03Hf=P80=CDe00H0=SHf02h^;P0k>c/0=3@d03Xj>P0c<c<2038b<P0402l_;`0d=3@0<c<c038b<P<0
;2`/3P38h=P000`0b>3H0P2PX:002P2NWYh0X:2P09fMW@2PX:00XJ6Q0::RXP2OWil0WYjN09fMW@2U
YJD30::RXP0;0:2PX02WYjL0XZ:R0:BTY02SXj<0Y:BT0:JVYP2YZJT0YjNW0:FUY@2WYjL00P2UYJD0
2@2XZ:P0YZJV0:VYZ@2YZJT0Y:BT0:VYZ@2WYjL0Z:RX0:6QX@020::RXP0309jNWP2LW9`0WinO0080
W9bL0280WinO09fMW@2RXZ80WinO09ZJVP2QXJ40WinO0:6QX@2PX:00WinO0:2PX02LW9`0V9RH09>C
T`2;Rh/0QhN708:2PP24Q8@0MWIf06][J`1/K6`0HF5Q05UIF@1JFUX0EUIF05EEE@1NGUh0F5QH05eM
G@1UIFD0HF5Q06ATI01XJ6P0IFEU0P1SHf<01`1VIVH0Hf=S06a/K01XJ6P0I6AT06MWI`1VIVH00P1W
IfL00`1VIVH0IFEU06EUI@0206QXJ00;06EUI@1SHf<0J6QX06EUI@1YJFT0Jf][06UYJ@1[Jf/0J6QX
06][J`1VIVH00P1^KVh02@1`L700Kfm_07AdM01_Kfl0KVi^07AdM01gMgL0N7Qh07EeM@0207IfMP03
07YjNP1iNGT0MgMg0080MgMg00H0MGEe07YjNP1lO7`0OWin07UiN@1mOGd207QhN00707MgM`1mOGd0
O7al07inOP20P800Ogmo0820P00207moO`0[07emO@24Q8@0OWin08J6QP1oOgl0QHF50861P@1oOgl0
OGem07inOP1lO7`0OGem07alO022PX80Ng]k07UiN@1nOWh0PH6108F5Q@1lO7`0Ogmo08:2PP1kNg/0
PX:207alO01nOWh0PX:208>3P`22PX80Ogmo08B4Q023Ph<0OWin07emO@1kNg/0PH6107inOP22PX80
O7al07emO@24Q8@0Ogmo08B4Q0020861P@0N0820P01oOgl0Ph>30820P022PX80OWin07emO@22PX80
Ogmo07inOP21PH40PX:208B4Q020P800OWin08:2PP1mOGd0NGUi07emO@20P800PX:207emO@1nOWh0
Ogmo07YjNP21PH40OGem07alO020P800O7al101jNWX207emO@0807inOP1hN7P0OGem08J6QP20P800
O7al07inOP1mOGd207inOP0@07emO@1jNWX0N7Qh07alO01mOGd0NGUi07YjNP1hN7P0MgMg07UiN@1m
OGd0OWin07]kN`1fMWH0NWYj0820P080PH610100Ph>307moO`21PH40PX:20820P023Ph<0Q8B408F5
Q@21PH40PX:208>3P`26QXH0Ph>308:2PP25QHD0OWin0P1oOgl00`23Ph<0PX:207moO`0207alO003
0820P01nOWh0Ogmo0080PH6100T0OGem08:2PP1lO7`0P82007inOP20P800OGem0820P01mOGd00P1l
O7`03@1nOWh0Ng]k07alO01jNWX0O7al0820P024Q8@0OWin07moO`20P800OGem07inOP21PH400P1l
O7`0;@1nOWh0Ogmo07emO@20P800OWin08>3P`21PH40Ng]k07UiN@1nOWh0MGEe07inOP1hN7P0MGEe
07UiN@1eMGD0LG5a07IfMP1iNGT0LW9b071`L01cLg<0MWIf075aL@1`L700KFe]06MWI`1ZJVX0KFe]
06i^KP1aLG40MWIf07UiN@1jNWX0O7al08B4Q022PX80RXZ:08f=S@2;Rh/0S8b<08n?S`2CTi<0U9BD
09VIV@0209ZJVP0;09^KV`2LW9`0Vi^K0:2PX02IVIT0W9bL09fMW@2JVYX0XJ6Q09nOW`2PX:000P2M
WId00`2NWYh0WinO09VIV@0209jNWP0309nOW`2LW9`0X:2P0080WinO00l0WIfM09bLW02LW9`0W9bL
09fMW@2HV9P0WinO09^KV`2NWYh0W9bL09ZJVP2KVi/0W9bL0::RXP2OWil00P2LW9`01P2MWId0W9bL
09fMW@2LW9`0WYjN09RHV0<0W9bL0P2KVi/03P2HV9P0Vi^K09bLW02IVIT0W9bL09fMW@2IVIT0VYZJ
09FEU@2IVIT0UYJF09FEU@2DU9@0V9RH0P2GUiL03@2HV9P0U9BD08n?S`2CTi<0Shn?09>CT`2@T900
SHf=09BDU02YZJT0^KVi0<O7a`3<c<`00P3Fe]H01`3Hf=P0fm_K0=_Kf`3Ng]h0g=cL0=gMg@3Ng]h0
0P3Ogml03@3Ng]h0e=CD0<g=c@39bLT0/K6a09NGU`1jNWX0JFUY06=SH`1ZJVX0JFUY06EUI@1[Jf/0
0P1bLW801@1eMGD0LW9b075aL@1aLG40MgMg0080NGUi00/0MgMg07alO01lO7`0OGem0861P@1mOGd0
Ogmo07UiN@21PH40QhN707emO@0208V9R@0<08R8R026QXH0OGem07UiN@1YJFT0Fe]K04];B`0l?3`0
:RXZ02/[:`0Z:RX0:2PX0P0Y:BT02@0_;bl0;Bd]02l_;`0f=SH0=CDe03@d=00i>CT0?3`l03Ti>@02
03Ph>00A03De=@0c<c<0;bl_034a<@0g=cL0<C4a03<c<`0`<300;Rh^03@d=00`<300=cLg03Hf=P0e
=CD0;bl_038b<P0/;2`03P38h=P000`0b>3H0P2PX:00502LW9`0WYjN0:2PX02MWId0Vi^K09nOW`2P
X:00WYjN0:6QX@2SXj<0YZJV0:6QX@2SXj<0WinO0::RXP2MWId0X:2P0:RXZ02SXj<0YJFU0P2VYZH0
102YZJT0YZJV0:VYZ@2WYjL20:VYZ@070:NWY`2XZ:P0YjNW0:RXZ02UYJD0ZJVY0:NWY`020:>SX`03
0:6QX@2PX:00WYjN0080XJ6Q01d0WinO09^KV`2OWil0WinO0:2PX02NWYh0XJ6Q0:JVYP2RXZ80Xj>S
09jNWP2IVIT0Vi^K092@T02?Shl0RHV908F5Q@1nOWh0LW9b06e]K@1SHf<0GemO05eMG@1GEeL0FUYJ
05UIF@1HF5P0FEUI05eMG@0206=SH`0606ATI01WIfL0Hf=S06MWI`1YJFT0Kfm_0P1XJ6P00`1WIfL0
JFUY06QXJ00306UYJ@0606MWI`1VIVH0JFUY06MWI`1/K6`0J6QX101WIfL0101UIFD0GemO06=SH`1Z
JVX206QXJ00@06a/K01[Jf/0Kfm_079bLP1_Kfl0M7Ad079bLP1eMGD0MWIf07MgM`1eMGD0MgMg07Yj
NP1kNg/0NWYj07EeM@80Ng]k00D0MWIf07]kN`1mOGd0PH6107UiN@0307alO00C07]kN`1oOgl0Ng]k
07]kN`24Q8@0P82007moO`22PX80OWin0820P01nOWh0PH6108B4Q020P800OWin08:2PP20P800Ogmo
08F5Q@0207alO00:07emO@1oOgl0OGem07UiN@1mOGd0P82008B4Q025QHD0Q8B40861P@80Ph>30P1o
Ogl06@22PX80Ogmo07alO01lO7`0P82008B4Q020P800QXJ608>3P`1oOgl0Ph>30820P021PH40PX:2
0861P@1nOWh0Ph>307moO`20P800PH610820P01oOgl0PH6107moO`1lO7`00P1oOgl03026QXH0PX:2
08N7Q`25QHD0Q8B40861P@1nOWh0PH6107moO`1mOGd0Q8B40820P080OWin00P0O7al07YjNP1lO7`0
Ng]k07alO01oOgl0NWYj07alO0<0NGUi0P1jNWX03P1iNGT0NWYj07alO01kNg/0OGem0820P01jNWX0
O7al08:2PP1nOWh0Q8B407YjNP1gMgL0Ng]k0P1hN7P0201kNg/0O7al07MgM`1hN7P0NWYj07QhN021
PH40O7al0P1mOGd20861P@0;07moO`21PH40Q8B40861P@1kNg/0Ph>308N7Q`22PX80Ph>308B4Q021
PH400`25QHD01@26QXH0QhN708B4Q021PH40OWin0080P8200P22PX801024Q8@0PX:207moO`21PH42
0820P00307alO025QHD0P8200080OGem00L0P82007emO@1oOgl0NWYj07emO@1lO7`0Ph>30080OWin
00X0O7al0861P@21PH40OWin07QhN020P800Ng]k0861P@1mOGd0PH610P1mOGd05@1oOgl0P8200820
P021PH40Ogmo08:2PP1mOGd0Ng]k07inOP1lO7`0NGUi07QhN01fMWH0M7Ad07]kN`1fMWH0LW9b07Mg
M`1bLW80Kfm_06i^KP02079bLP0406a/K01iNGT0L71`06QXJ080KVi^01P0L71`07=cL`1fMWH0NWYj
07QhN01mOGd0PH6108J6QP28R8P0RHV908^;R`2ATI40T92@09FEU@2FUYH0V9RH09BDU02FUYH0VYZJ
09jNWP2LW9`0WYjN09bLW02PX:0309jNWP080:2PX02NWYh0W9bL09jNWP2LW9`0WinO0:2PX02KVi/2
09jNWP80WIfM00P0X:2P09fMW@2MWId0VIVI09bLW02KVi/0WIfM09RHV0<0X:2P00H0W9bL09fMW@2N
WYh0UiNG09nOW`2NWYh309fMW@0709bLW02OWil0W9bL09^KV`2GUiL0W9bL09^KV`0209bLW00U09VI
V@2MWId0WIfM09nOW`2LW9`0Vi^K09jNWP2HV9P0UiNG09VIV@2JVYX0WIfM09FEU@2KVi/0U9BD09>C
T`2DU9@0TY:B09NGU`2>SXh0T92@08n?S`2ATI40SXj>092@T02RXZ80]KFe0<71`@3;bl/0d=3@0=KF
eP3GemL0fm_K0=oOg`3Ng]h0gmoO0=kNgP040=oOg`0Q0=cLg03AdM40bLW90;fm_@2UYJD0QHF506YZ
JP1WIfL0K6a/06=SH`1_Kfl0Jf][071`L01aLG40LW9b075aL@1dM7@0Lg=c07EeM@1gMgL0Ng]k07Ui
N@1lO7`0OWin07alO01gMgL0NWYj07MgM`1lO7`0NGUi0820P025QHD0Ogmo0080QHF500X0PH6108N7
Q`2:RXX0PX:207alO01eMGD0HF5Q04M7A`0d=3@0;Rh^0P0/;2`04`0X:2P0;2`/02`/;00V9RH0:b/[
02l_;`0b<S80;Rh^03Hf=P0k>c/0<C4a03Hf=P14A4@0=3@d03<c<`0e=CD0=3@d038b<P0h>3P00P0c
<c<2038b<P07030`<00f=SH0=cLg03De=@0b<S80<30`02h^;P0>0<SPf0003038h=P20:6QX@040:2P
X02NWYh0WIfM09jNWP80WIfM00D0Xj>S09jNWP2RXZ80WinO09jNWP020:2PX080Xj>S00d0XJ6Q0:2P
X02SXj<0XZ:R0:BTY02UYJD0Xj>S0:RXZ02ZZZX0YZJV0:FUY@2XZ:P0YZJV00<0YjNW00L0YZJV0:FU
Y@2XZ:P0ZJVY0:JVYP2PX:00Vi^K0080XZ:R0`2OWil00`2NWYh0WinO09jNWP020:2PX00C0:BTY02O
Wil0Xj>S0:6QX@2NWYh0VIVI09RHV02CTi<0SHf=08F5Q@22PX80O7al07=cL`1]KFd0IfMW05mOG`1P
H600DU9B05IFEP0205aLG009065QH@1JFUX0G5aL06QXJ01TI6@0Hf=S061PH01SHf<0JFUY0080IfMW
0P1[Jf/02@1ZJVX0JFUY06UYJ@1/K6`0J6QX069RHP1XJ6P0IfMW06ATI00206QXJ00506MWI`1TI6@0
IFEU061PH01YJFT00`1VIVH00`1XJ6P0IfMW06m_K`0206m_K`0=07=cL`1/K6`0Lg=c07EeM@1cLg<0
LG5a07IfMP1cLg<0MWIf07]kN`1cLg<0Ng]k07UiN@0207alO080NWYj00@0MWIf07inOP20P800NWYj
0P1lO7`01@1mOGd0Ogmo07alO021PH40P8200080PX:20340Ogmo0861P@1oOgl0P82008:2PP20P800
PX:20861P@1mOGd0OWin08:2PP1nOWh0Ogmo07inOP1oOgl0PX:207emO@1kNg/0Ogmo08:2PP21PH40
P82008J6QP23Ph<0QHF508B4Q026QXH0P82007moO`22PX80OWin0861P@20P800Q8B408>3P`25QHD0
QXJ607emO@24Q8@0P82007inOP24Q8@0PX:20861P@22PX80Ph>30861P@23Ph<0OGem0080PH6100/0
Ph>30820P024Q8@0PX:20861P@26QXH0QhN708:2PP29RHT0QhN708>3P`020861P@0407emO@1nOWh0
OWin07emO@80O7al00L0NWYj07]kN`1mOGd0NGUi07inOP1hN7P0Ng]k0080MgMg00H0MWIf07]kN`1i
NGT0N7Qh07alO01hN7P307emO@0E07]kN`1lO7`0PH6108B4Q020P800Ng]k07YjNP1iNGT0OGem07Ui
N@1kNg/0OWin07moO`1kNg/0OGem07inOP1mOGd0NWYj07alO01oOgl0Ph>30080PX:200P0P82007mo
O`20P800PH6108>3P`21PH40PX:207moO`<0PH6100l0R8R808F5Q@23Ph<0QHF508:2PP23Ph<0PH61
0820P021PH40QHF508:2PP1lO7`0Ogmo07inOP23Ph<00`22PX804P23Ph<0OWin07alO020P800PH61
08:2PP1mOGd0P82007]kN`1jNWX0P82007inOP1oOgl0O7al0861P@20P800NWYj07]kN`<0OGem00X0
PX:208>3P`1nOWh0OWin08>3P`22PX80Ng]k07moO`1nOWh0OGem0P1nOWh00`22PX80O7al07alO002
07alO00F07]kN`1gMgL0MGEe075aL@1iNGT0Lg=c075aL@1`L700LW9b06][J`1dM7@0KVi^06m_K`1W
IfL0KFe]071`L01aLG40MgMg07IfMP1gMgL0OGem07alO080PX:201X0R8R808Z:RP2=SHd0TI6A09:B
TP2GUiL0VIVI09^KV`2FUYH0WIfM09bLW02KVi/0WinO09ZJVP2MWId0X:2P09bLW02RXZ80Y:BT0:6Q
X@2OWil0WIfM09nOW`2NWYh0XJ6Q09fMW@80WYjN0P2OWil03P2LW9`0WinO0:2PX02KVi/0WYjN0:2P
X02NWYh0WIfM09bLW02KVi/0WYjN09fMW@2OWil0W9bL0P2KVi/409bLW00<09jNWP2LW9`0XZ:R09^K
V`2JVYX0W9bL09ZJVP2LW9`0WYjN09bLW02JVYX0VIVI0P2LW9`209^KV`0609ZJVP2HV9P0VYZJ09VI
V@2FUYH0VYZJ0P2HV9P01P2GUiL0TI6A09BDU02FUYH0TY:B092@T080SXj>0100Shn?08j>SP2HV9P0
[:b/0;Zj^P3:b/X0cLg=0=?Cd`3EeMD0f=SH0=_Kf`3Jf]X0fm_K0=kNgP3Ogml0gMgM0P3Ogml07P3M
gMd0e]KF0<o?c`31`L40/;2`08b<S01aLG40JVYZ06UYJ@1WIfL0JFUY06][J`1^KVh0JFUY07AdM01a
LG40L71`07AdM01gMgL0MGEe07IfMP1hN7P0NWYj07UiN@1jNWX0Ng]k07QhN01jNWX0NGUi07]kN`80
PH6100@0OWin07emO@20P800P8200P23Ph<03P25QHD0QhN70861P@1jNWX0LG5a06=SH`1;Bd/0>SXj
02h^;P0[:b/0:2PX02HV9P0Z:RX0;2`/0P0[:b/01@0];Bd0<c<c03Ti>@0n?Sh0<S8b0080=3@d00L0
<30`03Ti>@0f=SH0;Rh^034a<@0d=3@0>c/k0080<C4a00P0=CDe034a<@0b<S80=SHf03/k>`0e=CD0
<c<c03Ph>0h0b>3H000<0<SPf080W9bL00d0WinO0:6QX@2MWId0WIfM0:2PX02IVIT0XZ:R0:2PX02M
WId0WinO09jNWP2RXZ80Y:BT00<0XJ6Q00@0Y:BT0:6QX@2PX:00Y:BT0P2UYJD0102XZ:P0YjNW0:^[
Z`2XZ:P30:ZZZP80Zj^[00D0YZJV0:VYZ@2WYjL0ZJVY0:BTY0020:2PX0070:6QX@2NWYh0XJ6Q0:6Q
X@2PX:00XJ6Q09fMW@0209jNWP030:2PX02SXj<0X:2P0080Y:BT0140WIfM09bLW02HV9P0Ti>C08f=
S@29RHT0Ph>307emO@1gMgL0L71`06IVIP1PH600F5QH05eMG@1IFET0GUiN05UIF@02061PH00905eM
G@1PH600HV9R06YZJP1SHf<0HF5Q06EUI@1XJ6P0JVYZ0080JFUY00X0IfMW06QXJ01/K6`0JFUY06YZ
JP1YJFT0Kfm_06ATI01UIFD0IfMW0P1VIVH04@1TI6@0Hf=S06YZJP1VIVH0JVYZ06UYJ@1]KFd0JVYZ
06UYJ@1/K6`0Kfm_071`L01]KFd0L71`06m_K`1bLW80MWIf0080MGEe00h0MWIf07MgM`1kNg/0Ng]k
07UiN@21PH40O7al07emO@1gMgL0N7Qh07alO01nOWh0OGem07inOP80P82001D0Ogmo0861P@1oOgl0
Ogmo08F5Q@1kNg/0P82007moO`22PX80O7al08:2PP21PH40Ogmo07inOP27QhL0OGem07inOP1oOgl0
P82008:2PP20P8000P21PH40201nOWh0PH6107moO`21PH40Ph>30861P@20P800QHF50P23Ph<01P22
PX80QHF508>3P`20P800Q8B408:2PP80QHF50P23Ph<208F5Q@0407moO`1nOWh0P8200820P0<0Q8B4
0140QhN707moO`1oOgl0PX:20820P01oOgl0QXJ60820P022PX80Q8B408:2PP25QHD0QhN708:2PP21
PH40QHF50861P@0207inOP040820P01oOgl0OWin0861P@80O7al00L0Ng]k07UiN@1nOWh0Ng]k07al
O01jNWX0Ng]k0080MGEe00P0MWIf07QhN01kNg/0Ng]k07QhN01jNWX0Ng]k07inOP80OGem00D0P820
07inOP1nOWh0OWin08:2PP0307emO@0807]kN`1nOWh0PH6107UiN@1lO7`0Ng]k07emO@1gMgL207em
O@0A07alO021PH40PX:207moO`20P800OWin08>3P`25QHD0PH6107inOP20P800OGem0861P@1oOgl0
QhN708F5Q@23Ph<00P22PX804@21PH40P82008B4Q020P800PH6108B4Q01lO7`0PX:20861P@20P800
OWin07emO@23Ph<0Q8B40861P@1nOWh0PH610080Ogmo00H0PX:207moO`1nOWh0P82007YjNP1oOgl2
0861P@0:08:2PP21PH40OWin07alO01mOGd0PH6107emO@1oOgl0O7al0861P@<0OWin00H0PH6107mo
O`22PX80O7al07UiN@1oOgl307inOP0J07emO@1jNWX0MgMg07YjNP1iNGT0N7Qh075aL@1fMWH0KVi^
075aL@1^KVh0K6a/06i^KP1bLW80K6a/06QXJ01YJFT0K6a/06i^KP1_Kfl0M7Ad07IfMP1kNg/0O7al
0820P024Q8@208V9R@0708Z:RP2?Shl0Shn?09:BTP2EUID0UYJF09ZJVP0209VIV@80W9bL0P2PX:00
1`2NWYh0Xj>S0:6QX@2NWYh0XJ6Q0:2PX02LW9`00P2OWil309jNWP0:09bLW02QXJ40XZ:R09nOW`2R
XZ80WinO0:2PX02OWil0WIfM0::RXP80WinO00X0WYjN09^KV`2JVYX0WYjN09ZJVP2LW9`0WYjN09fM
W@2JVYX0WinO0`2MWId01`2LW9`0UiNG09fMW@2MWId0VIVI09jNWP2PX:00102LW9`209fMW@0;09bL
W02KVi/0VYZJ09ZJVP2HV9P0VIVI09JFUP2IVIT0V9RH09NGU`2FUYH00P2DU9@03@2FUYH0SXj>08n?
S`2>SXh0Rh^;08f=S@2ATI40Xj>S0;>c/`31`L40bl_;0=7Ad@3De=@00P3Hf=P06@3Jf]X0g=cL0=gM
g@3Ph>00gmoO0=kNgP3Ogml0gMgM0=WIf@3EeMD0bLW90;Rh^02JVYX0OWin06e]K@1ZJVX0JFUY06QX
J01]KFd0K6a/071`L01eMGD0Lg=c079bLP1eMGD00P1dM7@01P1hN7P0MGEe07]kN`1iNGT0OGem07in
OP80OGem00D0NGUi07inOP1kNg/0O7al07moO`0207alO080Ogmo0100PX:20820P027QhL0Ph>308B4
Q023Ph<0NGUi06][J`1NGUh0ATI603Ph>00d=3@09bLW02DU9@0`<300<S8b0P0X:2P203Hf=P0;03De
=@0d=3@0=cLg03@d=00[:b/0;Rh^03Xj>P0k>c/0=SHf03@d=00e=CD00P0b<S802@0_;bl0<C4a034a
<@0_;bl0<c<c038b<P0k>c/0=cLg03Ph>00>0<SPf0003038h=P309fMW@0309^KV`2PX:00WinO0080
Vi^K0P2NWYh04P2OWil0XZ:R09jNWP2NWYh0WIfM09nOW`2PX:00WinO0:>SX`2PX:00WYjN09nOW`2Q
XJ40YJFU0:NWY`2UYJD0ZJVY0:NWY`80ZJVY00@0YjNW0:^[Z`2YZJT0YjNW0P2VYZH01P2YZJT0YJFU
0:>SX`2RXZ80WinO0:6QX@<0WinO00/0WIfM09nOW`2MWId0X:2P09nOW`2TY:@0WinO0:6QX@2OWil0
Y:BT09fMW@0209VIV@0<09>CT`2<S8`0R8R808B4Q01iNGT0KFe]06UYJ@1TI6@0G5aL05YJFP1GEeL0
EUIF0P1LG5`0201TI6@0HV9R05mOG`1OGel0Hf=S06EUI@1VIVH0IFEU0P1WIfL0101XJ6P0Kfm_06UY
J@1/K6`206e]K@80Jf][00L0K6a/06i^KP1SHf<0I6AT06EUI@1VIVH0Hf=S0080J6QX00<0HV9R06AT
I01WIfL00P1XJ6P01P1ZJVX0Jf][06a/K01_Kfl0LG5a07EeM@<0LG5a0`1eMGD00`1jNWX0Ng]k07Mg
M`0307QhN00507emO@1hN7P0MWIf07QhN01nOWh00P1lO7`507inOP0L0861P@20P800Ng]k07YjNP20
P800Ph>308B4Q01nOWh0PH6108>3P`1oOgl0NWYj08:2PP1kNg/0O7al07emO@1nOWh0Ng]k08>3P`1o
Ogl0OGem0861P@23Ph<0Ogmo0820P023Ph<0OWin08B4Q080PX:20P21PH4208>3P`0408F5Q@1mOGd0
QXJ60861P@80Ph>301H0QXJ60861P@25QHD0PH6108:2PP20P800PX:20820P025QHD0RXZ:08:2PP26
QXH0PX:207inOP1lO7`0P8200861P@25QHD0P82008:2PP1oOgl0QXJ60P24Q8@208N7Q`0?0820P01m
OGd0PX:207inOP27QhL0QXJ60861P@1mOGd0Ng]k07alO020P800MgMg07QhN01mOGd0NWYj0080O7al
00H0Ng]k07UiN@1mOGd0OGem07QhN01/K6`207emO@0507moO`20P800O7al07alO01gMgL00P1lO7`2
07inOP80Ogmo01@0PH6107emO@1mOGd0O7al07emO@1kNg/0Ogmo07alO01kNg/0Ogmo0820P023Ph<0
PX:20861P@1oOgl0PH6107moO`23Ph<0PH610820P080OWin0P25QHD02P27QhL0PX:208:2PP25QHD0
Ph>30820P01nOWh0PX:207moO`1mOGd307inOP80Ogmo00H0N7Qh08:2PP20P800PH610820P01nOWh2
07emO@0507moO`1nOWh0PX:207inOP1jNWX00`1nOWh0101lO7`0Ogmo07]kN`1nOWh307emO@0307Yj
NP21PH40PH610080Ogmo00@0OWin0820P01oOgl0PX:20P1mOGd307moO`0=07UiN@1mOGd0MgMg07al
O01iNGT0N7Qh07UiN@1fMWH0M7Ad07=cL`1XJ6P0M7Ad071`L00206i^KP0506m_K`1]KFd0JFUY06][
J`1YJFT00P1[Jf/02`1cLg<0NWYj0861P@1jNWX0Ph>308J6QP27QhL0Rh^;08n?S`2<S8`0TY:B0080
UiNG00<0V9RH09^KV`2KVi/00P2MWId209nOW`050:2PX02NWYh0XZ:R09nOW`2SXj<00P2QXJ40102L
W9`0WYjN09nOW`2RXZ8309nOW`070:2PX02QXJ40WYjN0:6QX@2NWYh0W9bL0:6QX@0209jNWP0;09^K
V`2CTi<0WinO09jNWP2OWil0WIfM09bLW02MWId0W9bL09fMW@2NWYh00P2MWId03P2PX:00W9bL09VI
V@2MWId0Vi^K09bLW02JVYX0WYjN0:2PX02LW9`0WYjN09fMW@2@T900WYjN0P2KVi/0102IVIT0Vi^K
09^KV`2KVi/209VIV@0509JFUP2IVIT0V9RH09RHV02EUID00P2CTi<04P2@T900PX:208f=S@2<S8`0
UYJF0:6QX@2e]KD0_Kfm0<O7a`2o_kl0cLg=0=;BdP3AdM40e]KF0=SHf03IfMT0fm_K0=[JfP80g]kN
01@0gMgM0=[JfP3Bd]80c<c<0;bl_02PX:00Q8B407=cL`1_Kfl0Lg=c06][J`1fMWH0LG5a079bLP1c
Lg<0MWIf07YjNP1eMGD0MWIf07AdM080MgMg00L0MGEe07]kN`1lO7`0NGUi07]kN`1iNGT0N7Qh0080
OGem00@0PH6107MgM`1mOGd0O7al0P1mOGd0601oOgl0Q8B407moO`22PX80Q8B408>3P`27QhL0OWin
07QhN01_Kfl0EeMG04=3@`0c<c<0<C4a03@d=00X:2P0:BTY02`/;00h>3P0=CDe02h^;P0Y:BT0<30`
02l_;`80:b/[00H0<30`038b<P0a<C40=3@d03Ph>00f=SH203<c<`06034a<@0d=3@0;bl_038b<P0c
<c<0?Cdm0P0i>CT>0<SPf0003038h=P209jNWP040:6QX@2MWId0WIfM09nOW`80WYjN00`0XJ6Q0:2P
X02NWYh0Xj>S0:JVYP2PX:00WIfM09jNWP2PX:00XJ6Q0:2PX02QXJ420:2PX0<0Y:BT00P0YZJV0:BT
Y02UYJD0YjNW0:RXZ02YZJT0[:b/0:ZZZP<0ZJVY0P2VYZH20:2PX0030::RXP2OWil0WinO0080WinO
00<0W9bL09^KV`2QXJ400P2NWYh0@`2UYJD0XZ:R0::RXP2VYZH0X:2P09RHV02MWId0UIFE08j>SP2;
Rh/0Q8B407inOP1bLW80LG5a06IVIP1QHF40GUiN05]KF`1GEeL0EUIF05MGE`1OGel0H61P069RHP1S
Hf<0HF5Q06MWI`1RHV80I6AT06EUI@1YJFT0KVi^06a/K01`L700KVi^06e]K@1_Kfl0J6QX06EUI@1Y
JFT0Jf][06e]K@1SHf<0IVIV06EUI@1WIfL0K6a/06QXJ01]KFd0IfMW06QXJ01YJFT0K6a/06YZJP1[
Jf/0JVYZ06a/K01^KVh0L71`06m_K`1dM7@0Lg=c07IfMP1eMGD0NWYj07MgM`1mOGd00P1lO7`02P1k
Ng/0NWYj07YjNP1jNWX0MgMg07alO01kNg/0OGem07alO01mOGd207]kN`0B08>3P`1lO7`0P8200820
P022PX80Ogmo0861P@1nOWh0O7al08>3P`1nOWh0Ogmo0861P@1mOGd0P82008B4Q01mOGd0O7al0P1n
OWh02`23Ph<0PX:20820P01mOGd0Ogmo08B4Q021PH40Q8B40820P01oOgl0Ph>30080PX:201H0Ph>3
08J6QP24Q8@0Ogmo08F5Q@24Q8@0QXJ608B4Q023Ph<0P82008:2PP20P800QHF508:2PP1oOgl0Ph>3
08:2PP23Ph<0PX:208>3P`1oOgl0Ph>30P1oOgl06@1lO7`0PX:208B4Q023Ph<0QHF50820P025QHD0
PX:20861P@23Ph<0PH6108F5Q@21PH40QhN708B4Q022PX80P82007moO`1mOGd0OWin07YjNP1oOgl0
NGUi07AdM01lO7`0101kNg/00`1jNWX0OWin07UiN@0207emO@0407inOP1iNGT0Ogmo07moO`80OWin
00`0NWYj07inOP1nOWh0O7al07inOP1mOGd0OWin08:2PP1iNGT0NWYj07inOP1oOgl207alO00A0861
P@20P800O7al08B4Q022PX80QHF50820P025QHD0Ogmo08:2PP1lO7`0PX:207emO@21PH40Q8B40820
P022PX800P24Q8@0101oOgl0PH6108F5Q@27QhL207inOP80PX:20P1nOWh01`23Ph<0P82007emO@1k
Ng/0NGUi07emO@21PH400P20P8005@1oOgl0O7al07moO`21PH40OGem07moO`1nOWh0O7al07inOP23
Ph<0OGem07moO`20P800Ng]k07moO`20P800O7al08>3P`1oOgl0P82007emO@0208>3P`0907moO`20
P800PX:208:2PP21PH40OWin07moO`20P800OWin00<0NWYj00@0L71`07IfMP1hN7P0M7Ad0`1fMWH0
101gMgL0LW9b071`L01/K6`2071`L00A075aL@1]KFd0Jf][06a/K01cLg<0Kfm_07alO01mOGd0Ogmo
08R8R027QhL0R8R808Z:RP29RHT0Shn?09JFUP2EUID00P2IVIT00`2NWYh0WinO09bLW00209bLW00@
09jNWP2OWil0Y:BT0::RXP2NWYh0Xj>S0:2PX02NWYh0X:2P09ZJVP2HV9P0WYjN0::RXP2OWil0WIfM
09nOW`<0XJ6Q00L0Vi^K09bLW02LW9`0WYjN09fMW@2RXZ80W9bL0080WYjN00D0VYZJ09bLW02HV9P0
VIVI09jNWP0209^KV`0=09fMW@2OWil0WinO09jNWP2JVYX0Vi^K09RHV02MWId0WinO09fMW@2OWil0
W9bL09^KV`0209ZJVP0409bLW02OWil0V9RH09VIV@80Vi^K00<0VYZJ09FEU@2EUID00P2IVIT0402E
UID0U9BD09>CT`2>SXh0U9BD09:BTP2CTi<0Rh^;092@T02CTi<0YjNW0;Rh^036a/H0bl_;0<k>cP3D
e=@20=SHf080fm_K00`0gmoO0=kNgP3Ng]h0gMgM0=kNgP3MgMd0f=SH0=3@d036a/H0[Zj^09NGU`1f
MWH206YZJP0=06][J`1YJFT0JFUY06i^KP1_Kfl0LW9b07AdM01eMGD0MWIf07YjNP1fMWH0MgMg07Ui
N@0207emO@0407inOP1fMWH0NGUi07UiN@80MgMg00H0O7al07UiN@1mOGd0O7al07emO@1jNWX207mo
O`0A07emO@1nOWh0PX:207inOP23Ph<0QHF508Z:RP22PX80Ng]k06a/K01KFe/0B4Q803Hf=P0Y:BT0
:b/[02LW9`0Z:RX00P0b<S80300[:b/0;bl_02d];@0b<S80;bl_02d];@0^;Rh0=CDe02d];@0a<C40
=3@d03De=@80<S8b00T0<C4a03<c<`0];Bd0<C4a02`/;00e=CD0=SHf03Ph>00c<c<03P38h=P000`0
b>3H0P2MWId03@2NWYh0WinO09nOW`2PX:00WIfM0:2PX02NWYh0WinO0:6QX@2PX:00WinO09jNWP2S
Xj<00P2OWil01@2QXJ40WinO09jNWP2OWil0YJFU0080XZ:R0100XJ6Q0:FUY@2WYjL0YZJV0:RXZ02U
YJD0ZJVY0:JVYP2XZ:P0YjNW0:JVYP2UYJD0Y:BT0:JVYP2UYJD0Y:BT0P2OWil20:2PX00309jNWP2O
Wil0Vi^K0080WinO01L0WYjN0:>SX`2SXj<0YJFU0:>SX`2RXZ80WIfM09nOW`2?Shl0SHf=08V9R@20
P800Q8B407AdM01bLW80IFEU05mOG`1IFET0GEeM05]KF`1GEeL0EEEE05YJFP0205eMG@0906=SH`1T
I6@0IVIV065QH@1XJ6P0IVIV06YZJP1/K6`0Jf][0080J6QX00H0LG5a06QXJ01TI6@0IfMW06UYJ@1[
Jf/206IVIP0E06QXJ01WIfL0IVIV06EUI@1XJ6P0JVYZ06IVIP1TI6@0IVIV06][J`1VIVH0Kfm_06][
J`1_Kfl0Jf][06YZJP1]KFd0L71`075aL@1eMGD0M7Ad0080MWIf00<0N7Qh07UiN@1iNGT00P1kNg/0
201iNGT0Ogmo07moO`1mOGd0P82007YjNP1iNGT0Ng]k0P20P8000`1oOgl0OGem07emO@0307moO`09
07inOP21PH40QHF508B4Q01nOWh0PX:207moO`1lO7`0OWin00<0Ogmo00X0OGem08:2PP21PH40PH61
07moO`21PH40Ph>308:2PP1nOWh0PX:20P20P8001`22PX80P8200820P022PX80QhN707moO`20P800
0P21PH401023Ph<0QhN708B4Q020P8020861P@0B07moO`27QhL0PH6108>3P`25QHD0PH6108:2PP1n
OWh0OGem08R8R020P800Ogmo07emO@22PX80PH6108J6QP24Q8@0RXZ:0P26QXH02022PX80Q8B40861
P@26QXH0PX:208R8R023Ph<0Ogmo0P20P8001`1mOGd0MgMg07]kN`1lO7`0Ng]k07QhN01jNWX00P1k
Ng/207emO@0407MgM`1kNg/0OWin07moO`80NWYj00<0P82007moO`22PX800P20P8003@23Ph<0P820
07emO@1nOWh0P82007moO`1mOGd0PH6107]kN`1nOWh0NGUi07inOP20P8000P1mOGd01P22PX80Ng]k
08B4Q022PX80QXJ608:2PP80P8200180Ph>307inOP24Q8@0PH6108:2PP21PH40Ph>308Z:RP26QXH0
QHF50820P024Q8@0PX:20861P@22PX80OGem08:2PP1oOgl207inOP030820P023Ph<0OWin00<0Ogmo
0100Q8B40861P@20P800P82007moO`22PX80PH6108B4Q01nOWh0O7al07QhN020P800PX:207UiN@1o
Ogl0P8200P1kNg/01P1nOWh0Ogmo07inOP1nOWh0Ph>307alO080Q8B400T0QHF507emO@21PH40PH61
08:2PP23Ph<0P82008F5Q@23Ph<00P1jNWX01@1kNg/0Lg=c07EeM@1hN7P0M7Ad0080MgMg0P1eMGD0
101cLg<0LG5a06a/K01aLG4306e]K@0<06a/K01XJ6P0Jf][07AdM01fMWH0NGUi07alO024Q8@0QXJ6
08Z:RP29RHT0S8b<0P2DU9@209NGU`0309RHV02LW9`0WYjN0080WYjN00@0W9bL0:2PX02OWil0YJFU
0P2QXJ400`2NWYh0XZ:R09fMW@0209nOW`0709^KV`2PX:00XZ:R0:2PX02LW9`0WinO0:>SX`0209jN
WP0709nOW`2PX:00WinO09fMW@2NWYh0WIfM09bLW00209jNWP0809fMW@2OWil0VYZJ09RHV02IVIT0
W9bL09ZJVP2MWId209nOW`0k09bLW02JVYX0Vi^K09RHV02GUiL0V9RH09bLW02JVYX0W9bL0:6QX@2N
WYh0V9RH09nOW`2MWId0VYZJ09JFUP2HV9P0UiNG09VIV@2EUID0UYJF09RHV02GUiL0U9BD09FEU@2D
U9@0Shn?09BDU02>SXh0T92@08n?S`2BTY80WIfM0;>c/`34a<@0alO70=3@d03Bd]80eMGE0=WIf@3K
fm/0fMWI0=_Kf`3MgMd0g=cL0=gMg@3Ng]h0gMgM0=SHf03Cdm<0bl_;0;Zj^P2PX:00Ogmo06IVIP1Q
HF40JVYZ075aL@1^KVh00P1aLG40101gMgL0MWIf075aL@1dM7@207EeM@0A07AdM01eMGD0OGem07al
O01fMWH0OWin07AdM01mOGd0N7Qh07YjNP1kNg/0NGUi07QhN01oOgl0N7Qh0820P01hN7P00P1lO7`0
1P21PH40OGem0861P@23Ph<0QXJ608>3P`80Q8B40280PX:207YjNP1aLG40GemO04Y:BP0_;bl0:b/[
02PX:00/;2`0;Bd]02h^;P0b<S80<C4a02l_;`0b<S80;Rh^02TY:@0^;Rh0;bl_03Hf=P0Y:BT0;Rh^
02l_;`0`<300=CDe03<c<`0b<S80=CDe034a<@0];Bd0=CDe03Ph>00j>SX0>CTi3P38h=P000`0b>3H
0P2MWId08@2NWYh0X:2P09jNWP2LW9`0WIfM09nOW`2PX:00WYjN0:2PX02NWYh0XJ6Q09jNWP2PX:00
Vi^K09fMW@2PX:00WIfM0::RXP2PX:00W9bL0:2PX02QXJ40WinO0:FUY@2SXj<0YjNW0:ZZZP2XZ:P0
ZZZZ0:VYZ@2ZZZX0Z:RX0:FUY@020:ZZZP040:JVYP2UYJD0X:2P0:>SX`<0XJ6Q0P2OWil06@2JVYX0
WIfM09nOW`2QXJ40Y:BT0::RXP2UYJD0X:2P0:FUY@2MWId0Vi^K09:BTP2?Shl0SHf=08:2PP20P800
Lg=c071`L01VIVH0J6QX05YJFP1IFET0F5QH05=CD`1FEUH00P1MGEd00`1PH600JFUY065QH@02069R
HP0606UYJ@1ZJVX0JVYZ06MWI`1VIVH0K6a/0P1XJ6P02`1ZJVX0JFUY06UYJ@1ZJVX0Jf][06ATI01X
J6P0JFUY06QXJ01UIFD0Jf][0080JVYZ0100IfMW06ATI01XJ6P0Jf][06YZJP1]KFd0Jf][071`L01Y
JFT0Kfm_07=cL`1aLG40Lg=c07EeM@1cLg<0MGEe0P1gMgL0301lO7`0N7Qh07UiN@1mOGd0Ng]k07Qh
N01lO7`0OGem07]kN`1nOWh0PH6107emO@80OWin0`1oOgl0301mOGd0Ph>307UiN@24Q8@0OWin07em
O@22PX80O7al0861P@1oOgl0PH6107emO@80OWin01H0Ph>308:2PP26QXH0OGem0861P@20P800PX:2
07moO`20P800PX:20861P@1mOGd0Ph>30861P@23Ph<0P82008B4Q025QHD0PH6108J6QP21PH40Ph>3
0`22PX80:@20P800Ph>30820P026QXH0Ogmo08F5Q@1kNg/0QXJ608:2PP20P800O7al07emO@21PH40
P82007inOP1jNWX0P82007moO`21PH40PX:208R8R025QHD0R8R808>3P`25QHD0QhN708>3P`25QHD0
Q8B40861P@1nOWh0O7al0820P01mOGd0PH6107emO@1kNg/0NGUi07YjNP1hN7P0NWYj00<0Ng]k0P1m
OGd0201jNWX0MgMg07]kN`1nOWh0PX:208F5Q@20P800OWin0P1mOGd0101nOWh0Ng]k07]kN`20P802
07alO00407]kN`1jNWX0OGem07emO@80PH6100<0O7al07]kN`22PX800P20P8000`25QHD0Q8B408:2
PP0207moO`0908:2PP21PH40PH6107moO`1nOWh0P8200861P@23Ph<0PX:20080PH6100T0QHF508N7
Q`27QhL0R8R80820P024Q8@0P82007]kN`1lO7`00P21PH401`20P800OWin07inOP20P800Q8B40861
P@22PX800P21PH401`20P800PH610861P@1lO7`0OWin07moO`22PX800P1mOGd02P1kNg/0OGem07mo
O`1mOGd0O7al07moO`1mOGd0O7al07moO`1kNg/207moO`0608:2PP21PH40Ogmo08F5Q@20P800Ogmo
0P1mOGd03@1lO7`0OGem0820P01hN7P0LG5a07MgM`1fMWH0Ng]k079bLP1kNg/0MgMg06m_K`1/K6`0
0`1aLG400`1_Kfl0L71`06a/K00206a/K00>071`L01cLg<0MGEe07QhN01nOWh0Ogmo08>3P`25QHD0
Rh^;09:BTP2DU9@0TI6A09RHV02FUYH209fMW@0909^KV`2LW9`0WinO09jNWP2OWil0X:2P0:>SX`2R
XZ80XJ6Q0080WinO00<0Xj>S0:6QX@2SXj<0102OWil01@2PX:00XZ:R0:6QX@2RXZ80WIfM0080WinO
00H0X:2P0:6QX@2NWYh0W9bL0:2PX02QXJ4209jNWP0709nOW`2KVi/0Vi^K09^KV`2LW9`0VYZJ09jN
WP0209fMW@0:09VIV@2JVYX0V9RH09jNWP2LW9`0WIfM09nOW`2IVIT0WinO09bLW080WIfM0`2IVIT0
1P2GUiL0Vi^K09FEU@2JVYX0UiNG09JFUP<0U9BD0P2ATI403P2FUYH0UIFE08n?S`2DU9@0T92@09FE
U@2YZJT0^[Zj0<S8b03=cLd0d=3@0=GEe@3Fe]H0f=SH0P3Kfm/30=gMg@0@0=kNgP3MgMd0f][J0=GE
e@3;bl/0`/;20:^[Z`2?Shl0KVi^06MWI`1YJFT0JVYZ06][J`1`L700LG5a079bLP80MGEe00L0LW9b
07=cL`1eMGD0NWYj07emO@1iNGT0NWYj0080OGem0P1iNGT02P1nOWh0Ng]k07]kN`1hN7P0MgMg07]k
N`1fMWH0N7Qh07]kN`1hN7P307alO00@08F5Q@1mOGd0Ng]k08:2PP23Ph<0PH6108N7Q`2:RXX0Q8B4
08:2PP1/K6`0FEUI04M7A`0c<c<0<C4a030`<080:2PX00P0;2`/02l_;`0^;Rh0:b/[030`<00c<c<0
=SHf02XZ:P80:b/[00X0>SXj038b<P0a<C40=SHf03<c<`0e=CD0;Rh^03De=@0c<c<0;bl_0P0c<c<0
0`0o?cl0b>3H0<SPf00<0<SPf0003038h=P209nOW`80WIfM00@0XJ6Q09fMW@2MWId0WIfM0P2LW9`0
0`2NWYh0Xj>S09nOW`0309jNWP0409nOW`2PX:00W9bL0::RXP80WinO00D0X:2P09fMW@2MWId0XJ6Q
0:>SX`030:FUY@0<0:VYZ@2XZ:P0YjNW0:b/[02WYjL0Xj>S0:JVYP2TY:@0YZJV0:>SX`2OWil0W9bL
0P2OWil20:2PX00J09bLW02NWYh0XJ6Q09jNWP2RXZ80XJ6Q0:2PX02OWil0WIfM09ZJVP2HV9P0Ti>C
08j>SP2;Rh/0P82007alO01fMWH0Kfm_06IVIP1PH600EUIF05QHF01CDe<0EEEE05ADE01FEUH205mO
G`0G06=SH`1QHF40IFEU06EUI@1VIVH0I6AT06UYJ@1WIfL0Hf=S06YZJP1WIfL0JVYZ06a/K01XJ6P0
IfMW06UYJ@1]KFd0JFUY06=SH`1YJFT0Jf][06=SH`1XJ6P00P1WIfL01P1SHf<0JVYZ06UYJ@1WIfL0
K6a/06e]K@80K6a/0P1_Kfl0301cLg<0MGEe079bLP1eMGD0M7Ad07UiN@1mOGd0N7Qh07]kN`1gMgL0
MGEe07alO080NWYj00H0Ogmo07UiN@1mOGd0OGem07inOP20P80307moO`80OGem00P0N7Qh0861P@1l
O7`0Ogmo08N7Q`20P800PH6107alO0D0P8200100OWin07moO`20P800Ph>30820P022PX80Ph>308F5
Q@22PX80PH6108F5Q@1lO7`0PH6108J6QP20P800Q8B40P22PX820820P00608>3P`24Q8@0QXJ60861
P@23Ph<0P8200P22PX80301oOgl0QXJ608V9R@25QHD0P82008>3P`22PX80Ph>30820P01oOgl0PX:2
0861P@80PX:200l0Ph>30861P@25QHD0QXJ608F5Q@24Q8@0RHV908b<S02:RXX0Rh^;08F5Q@21PH40
Ph>30820P01nOWh00`1mOGd02020P800OGem07emO@1lO7`0OGem07QhN01iNGT0O7al0P1hN7P0101m
OGd0Ng]k07]kN`1lO7`207moO`80PH610P20P800401lO7`0Ng]k07moO`1lO7`0OGem07]kN`1lO7`0
OWin07YjNP1mOGd0PH6108>3P`1mOGd0OWin0861P@1mOGd20861P@040820P022PX80PH6107inOP80
Ogmo00T0OWin08J6QP24Q8@0Ogmo08>3P`29RHT0Q8B40861P@23Ph<00P25QHD01`26QXH0Q8B408R8
R024Q8@0PH6108:2PP25QHD00`21PH403020P800Ng]k07inOP21PH40P82007inOP20P800Ogmo07in
OP22PX80OWin07]kN`80OWin0`1oOgl0101nOWh0O7al07emO@1nOWh207emO@0307moO`21PH40Ogmo
00<0O7al0P22PX800`24Q8@0PH6107emO@0207emO@0307moO`1lO7`0Ng]k0080Ng]k01T0O7al07em
O@1eMGD0N7Qh07emO@1jNWX0LG5a07YjNP1fMWH0M7Ad06i^KP1cLg<0Kfm_06i^KP1]KFd0JVYZ06][
J`1/K6`0Jf][079bLP1`L700NWYj07alO021PH40PX:20080QhN700P0SHf=08n?S`2ATI40UiNG09ZJ
VP2KVi/0VYZJ0:2PX0<0WYjN00L0XJ6Q0:NWY`2RXZ80Xj>S0:6QX@2RXZ80YZJV00@0X:2P01P0WYjN
0:>SX`2QXJ40WinO09bLW02QXJ40X:2P0:6QX@2JVYX0Vi^K0::RXP2NWYh0W9bL09nOW`2MWId0WYjN
09bLW02NWYh0Vi^K09ZJVP2LW9`0VIVI09jNWP2OWil509fMW@0409bLW02MWId0W9bL09^KV`80VIVI
00H0V9RH09jNWP2NWYh0W9bL09VIV@2JVYX209NGU`0I09RHV02GUiL0UYJF09RHV02JVYX0Vi^K09FE
U@2GUiL0U9BD09>CT`2EUID0T92@096AT@2DU9@0T92@08n?S`2RXZ80/;2`0<?3``3;bl/0clo?0=;B
dP3Hf=P0fMWI0=SHf0020=_Kf`0F0=[JfP3MgMd0gMgM0=gMg@3Lg=`0f=SH0=3@d035aLD0]KFe09VI
V@1mOGd0IFEU06MWI`1ZJVX0Jf][06a/K01]KFd0KVi^07EeM@1dM7@0Lg=c07EeM@80NGUi0P1gMgL0
0`1fMWH0Ng]k07UiN@0207]kN`0507QhN01jNWX0N7Qh07UiN@1kNg/00P1iNGT0101kNg/0MgMg07al
O01mOGd207inOP0B07alO023Ph<0Ng]k07moO`20P800QXJ608>3P`25QHD0RHV908R8R025QHD0Lg=c
071`L01IFET0BTY:03De=@0[:b/09bLW0P0Y:BT05P0b<S80<30`02l_;`0`<300:b/[02`/;00[:b/0
;bl_02d];@0_;bl0;Rh^030`<00^;Rh0;bl_034a<@0e=CD0>SXj03Lg=`0_;bl0=SHf03Ti>@1=CDd>
0<SPf0003038h=P209fMW@0309nOW`2KVi/0WinO0080WIfM01D0VYZJ09nOW`2OWil0XJ6Q0::RXP2P
X:00WYjN09^KV`2NWYh0XJ6Q0:2PX02OWil0X:2P09bLW02JVYX0X:2P09nOW`2NWYh0Vi^K09nOW`2Q
XJ400P2WYjL01`2YZJT0YJFU0:VYZ@2UYJD0Zj^[0:FUY@2TY:@00P2VYZH00`2WYjL0WinO0::RXP02
09jNWP030:JVYP2OWil0WYjN0080X:2P00H0WIfM0:2PX02SXj<0X:2P0:JVYP2OWil209ZJVP0Q09>C
T`2?Shl0RXZ:0861P@1jNWX0LW9b06i^KP1RHV80HF5Q05MGE`1KFe/0G5aL05ADE01EEED0E5AD05EE
E@1PH600GemO06=SH`1WIfL0IVIV06ATI01[Jf/0IfMW06QXJ01YJFT0JVYZ06QXJ01[Jf/0JVYZ07Ee
M@1[Jf/0IfMW00<0Jf][00/0I6AT06QXJ01WIfL0IFEU06UYJ@1SHf<0IVIV06MWI`1XJ6P0Jf][06a/
K00206e]K@80Jf][00<0K6a/071`L01dM7@00`1eMGD02`1iNGT0O7al07UiN@1gMgL0M7Ad07alO01n
OWh0NWYj07inOP1oOgl0O7al0080Ng]k00<0P82008F5Q@1oOgl00P1oOgl03`20P800PH610820P01n
OWh0O7al07moO`21PH40O7al08>3P`1mOGd0Ogmo0820P024Q8@0Ogmo08:2PP0307moO`0;0861P@1n
OWh0Ph>308:2PP20P800PX:20861P@25QHD0PH6108B4Q025QHD00P22PX801023Ph<0QHF508>3P`21
PH4208>3P`0^07alO01nOWh0PX:208:2PP23Ph<0Ogmo08:2PP20P800Q8B408:2PP25QHD0Ph>308:2
PP1mOGd0PH6107alO022PX80Ogmo08:2PP21PH40Q8B408>3P`20P800R8R808F5Q@24Q8@0QXJ608f=
S@2>SXh0Ph>30861P@23Ph<0Q8B40861P@1oOgl0OWin07]kN`1nOWh0O7al07inOP1mOGd0PH6107Mg
M`1iNGT0OGem07alO080OGem00X0Ng]k07inOP1lO7`0Ogmo0861P@20P800Ogmo08:2PP20P800OGem
0`1nOWh02P20P800Ng]k07alO01mOGd0P8200861P@1mOGd0Ogmo07emO@20P80207moO`0608F5Q@1k
Ng/0O7al0820P021PH40O7al0P1nOWh01`1oOgl0R8R808F5Q@24Q8@0PH6108J6QP24Q8@00P23Ph<0
3026QXH0Ph>308J6QP24Q8@0PH6108F5Q@20P800RXZ:07moO`20P800OGem0820P080Ogmo01H0PH61
0820P01nOWh0PH6107moO`20P800Ogmo07emO@20P800NWYj07inOP1mOGd0P82007emO@1jNWX0Ogmo
0820P01lO7`0P82008B4Q021PH40OWin0P1oOgl0101kNg/0OWin07inOP1oOgl208>3P`0K08B4Q021
PH40OWin07alO01mOGd0OWin07]kN`1iNGT0OGem07IfMP1hN7P0NWYj07alO01oOgl0NGUi07moO`1j
NWX0Lg=c07MgM`1[Jf/0KVi^071`L01^KVh0LG5a06YZJP1]KFd0IfMW0080JFUY0180KVi^07=cL`1g
MgL0Ng]k07YjNP1oOgl0Q8B408^;R`29RHT0Ti>C096AT@2CTi<0VIVI09ZJVP2NWYh0X:2P09jNWP2U
YJD209nOW`060::RXP2QXJ40XJ6Q0:>SX`2OWil0Xj>S0P2QXJ401P2PX:00Xj>S09fMW@2OWil0W9bL
09jNWP<0WinO0`2MWId02@2NWYh0X:2P0:2PX02OWil0X:2P09nOW`2HV9P0Vi^K09ZJVP0209jNWP05
09NGU`2KVi/0X:2P09jNWP2OWil00P2MWId209bLW00=09VIV@2HV9P0WIfM09NGU`2LW9`0WIfM09RH
V02MWId0W9bL09ZJVP2HV9P0VYZJ09NGU`0209VIV@0809BDU02HV9P0UiNG09FEU@2FUYH0UiNG09BD
U02CTi<209BDU080T92@00d0TY:B09^KV`2][Jd0_[jn0<O7a`3>c/h0dM7A0=GEe@3Fe]H0f=SH0=_K
f`3Lg=`0g]kN0080gMgM00X0gmoO0=gMg@3Hf=P0d=3@0<W9b@30`<00YJFU08n?S`1]KFd0IfMW0P1X
J6P01`1_Kfl0KVi^079bLP1dM7@0Lg=c06a/K01_Kfl00P1nOWh02P1lO7`0NGUi07alO01kNg/0N7Qh
07UiN@1nOWh0OGem07moO`1lO7`207YjNP0707MgM`20P800Lg=c07AdM01kNg/0OWin07]kN`0207Mg
M`0307UiN@1oOgl0Ng]k0080OGem01L0PX:20861P@26QXH0QXJ608V9R@2:RXX0QHF507inOP1bLW80
GUiN04I6AP0g=cL0:b/[030`<00/;2`0;Rh^03Lg=`0`<300;Rh^02PX:00/;2`0:2PX02`/;00302h^
;P0702d];@0c<c<0<c<c02h^;P0[:b/0<C4a03Ph>00203@d=003030`<00a<C40b>3H00d0b>3H000<
0<SPf0<0VIVI00H0W9bL09VIV@2NWYh0W9bL09fMW@2OWil209fMW@0609nOW`2PX:00WYjN09nOW`2L
W9`0WYjN0P2LW9`0302SXj<0WYjN09bLW02KVi/0W9bL09^KV`2PX:00XJ6Q0:FUY@2PX:00Xj>S0:FU
Y@80YZJV00@0Z:RX0:JVYP2XZ:P0ZJVY0P2VYZH00`2TY:@0XJ6Q0::RXP020::RXP030:2PX02SXj<0
WinO0080WinO02P0X:2P0:6QX@2QXJ40X:2P0::RXP2LW9`0UYJF09ZJVP2EUID0Shn?08b<S025QHD0
NWYj07AdM01]KFd0Hf=S05aLG01FEUH0EeMG05IFEP1>CTh0De=C05ADE01QHF40GEeM061PH01QHF40
IFEU06ATI01XJ6P0IfMW06EUI@1YJFT0I6AT06a/K01UIFD0Jf][06MWI`1XJ6P0IfMW0P1YJFT03P1U
IFD0IfMW06IVIP1TI6@0IFEU06UYJ@1/K6`0IfMW06IVIP1UIFD0JFUY06QXJ01/K6`0JVYZ0P1_Kfl2
06a/K005075aL@1bLW80LG5a079bLP1gMgL00P1jNWX02@1gMgL0N7Qh07MgM`1nOWh0MWIf07YjNP1i
NGT0NWYj07alO00207]kN`0N07emO@1nOWh0OWin07inOP21PH40Ph>308:2PP21PH40O7al08>3P`1l
O7`0OWin0861P@24Q8@0Ogmo08>3P`22PX80PH6108B4Q01mOGd0PH6108>3P`1mOGd0PX:20820P01m
OGd0Ph>30861P@20P800PH610P22PX801P24Q8@0PH6108>3P`21PH40Ph>308B4Q080P82000/0PX:2
07moO`20P800Ogmo07emO@22PX80P82007moO`21PH40OWin08V9R@020820P00508B4Q025QHD0PX:2
08>3P`1nOWh00P22PX801021PH40QhN708B4Q028R8P208J6QP0F0820P02;Rh/0S8b<08:2PP1nOWh0
QHF508f=S@1oOgl0Ph>308B4Q025QHD0PH6107YjNP1nOWh0NWYj07inOP1oOgl0O7al0820P021PH40
OWin07]kN`80OGem00P0OWin0861P@1oOgl0Ng]k08:2PP1nOWh0Ogmo0820P080PH6100<0Ph>30820
P01lO7`00`1mOGd02`1nOWh0Ph>307moO`21PH40Ogmo07emO@1iNGT0OWin0820P01oOgl0NGUi0080
Ogmo00P0Q8B407inOP22PX80QHF508B4Q022PX80Ph>30820P080QHF500X0Ogmo08:2PP21PH40PX:2
08B4Q023Ph<0QhN708:2PP23Ph<0QXJ60P22PX80701nOWh0PH6107moO`1oOgl0OWin07moO`1lO7`0
OWin07emO@21PH40OWin0861P@1nOWh0P82007alO027QhL0OGem07moO`1kNg/0Ogmo0820P023Ph<0
P82007emO@22PX80P82007]kN`21PH4207moO`030820P022PX80P82000<0Ph>300<0Ogmo0820P01o
Ogl00`1oOgl00`1lO7`0OGem07]kN`0207UiN@<0O7al00D0OWin07MgM`1fMWH0LW9b06e]K@02075a
L@0406a/K01[Jf/0JVYZ06QXJ080JVYZ00@0KFe]06a/K01dM7@0LW9b0P1gMgL04P1oOgl0PX:208V9
R@2;Rh/0SXj>092@T02CTi<0VIVI09bLW02MWId0XZ:R09fMW@2LW9`0XZ:R0:6QX@2PX:00Y:BT0:2P
X080XJ6Q00D0Xj>S0::RXP2RXZ80WIfM0:2PX00309nOW`0<0:6QX@2LW9`0YJFU09nOW`2NWYh0X:2P
09jNWP2MWId0WYjN0:2PX02NWYh0WinO0P2NWYh209fMW@0609jNWP2JVYX0WinO09RHV02LW9`0VYZJ
0`2LW9`02@2KVi/0V9RH09VIV@2HV9P0VYZJ09RHV02GUiL0UYJF09^KV`0209RHV00309ZJVP2GUiL0
V9RH0080V9RH02/0UiNG09VIV@2DU9@0V9RH09NGU`2FUYH0VIVI09:BTP2=SHd0Ti>C09:BTP2ATI40
Ti>C09:BTP2SXj<0/k>c0<C4a03<c<`0c/k>0=CDe03EeMD0fMWI0=SHf03Jf]X0fm_K0=kNgP3MgMd0
g]kN0=gMg@3Kfm/0eMGE0<k>cP32`/80/[:b09:BTP1iNGT0I6AT06QXJ01ZJVX0Jf][06a/K01^KVh0
Kfm_0080LW9b00H0M7Ad07=cL`1lO7`0OGem07YjNP1kNg/207inOP0>07UiN@1lO7`0Ng]k07QhN01l
O7`0OGem07IfMP1hN7P0MgMg07QhN01jNWX0N7Qh0861P@1lO7`307emO@0:07MgM`1kNg/0NWYj07mo
O`1nOWh0Ogmo0820P027QhL0QXJ608R8R080QhN70140RHV907inOP1_Kfl0H61P059BDP0e=CD0<S8b
02TY:@0`<300?3`l03@d=00^;Rh09RHV02LW9`0U9BD0:BTY02l_;`0202XZ:P0;02h^;P0];Bd0;Rh^
02d];@0^;Rh0=cLg03@d=00k>c/0?3`l02l_;`0`<3003P38h=P000`0b>3H0P2KVi/03@2IVIT0VYZJ
09NGU`2NWYh0WIfM09ZJVP2MWId0Xj>S0::RXP2NWYh0XJ6Q09jNWP2LW9`00P2OWil00`2NWYh0W9bL
09fMW@0209fMW@0:09bLW02NWYh0WIfM09fMW@2OWil0XJ6Q0:2PX02TY:@0YjNW0:JVYP80Z:RX00L0
YJFU0:NWY`2XZ:P0Y:BT0:NWY`2UYJD0XZ:R00D0Xj>S0`2MWId30::RXP0309nOW`2SXj<0WIfM0080
UiNG0180TI6A08n?S`2<S8`0QHF507emO@1hN7P0LW9b06MWI`1PH600GemO05QHF01EEED0DU9B05QH
F01KFe/0IFEU05mOG`1NGUh2065QH@08061PH01UIFD0JFUY06][J`1YJFT0KVi^06MWI`1]KFd206YZ
JP0>06QXJ01TI6@0J6QX06UYJ@1/K6`0IVIV06QXJ01WIfL0J6QX06EUI@1SHf<0J6QX06YZJP1RHV82
06QXJ00=06i^KP1[Jf/0LG5a075aL@1`L700Kfm_075aL@1`L700Lg=c075aL@1hN7P0MgMg07]kN`02
07UiN@0907]kN`1hN7P0MWIf07QhN01mOGd0MgMg07emO@1nOWh0OGem0080Ogmo0P20P8002P1mOGd0
PX:20861P@20P800O7al07moO`1kNg/0QXJ608B4Q01oOgl208:2PP0908B4Q021PH40Q8B407moO`23
Ph<0PX:207moO`21PH40PX:20080Q8B400/0Ng]k0861P@25QHD0OWin08:2PP20P800OWin0820P022
PX80Ogmo0861P@0208>3P`0:0861P@22PX80PH6107inOP20P800Q8B408J6QP28R8P0QHF50861P@80
QHF500<0OWin08>3P`1oOgl00P20P8001`1oOgl0P82008F5Q@1lO7`0PH6107moO`20P8000P22PX80
2@2=SHd0Ti>C08B4Q026QXH0Ph>308J6QP28R8P0PX:207moO`020861P@0608:2PP1nOWh0PX:20861
P@1mOGd0Ogmo0P1mOGd00`1iNGT0OGem07]kN`020861P@80OWin00l0OGem0861P@21PH40Ng]k07em
O@1nOWh0Ogmo0861P@1mOGd0P8200861P@1jNWX0P82007moO`1lO7`00P1nOWh208:2PP0O07moO`1j
NWX0Ph>307alO01nOWh0Ogmo0820P01nOWh0Ph>307moO`20P800QXJ608B4Q021PH40Q8B40820P025
QHD0PX:20861P@22PX80Q8B40861P@22PX80Ph>308F5Q@22PX80Ph>308:2PP26QXH0OWin0820P002
08:2PP0607inOP22PX80OWin07]kN`1oOgl0O7al1020P8002@22PX80NWYj0861P@1oOgl0OGem07]k
N`20P800OGem0820P00207moO`090820P022PX80Ogmo0861P@1mOGd0OWin07alO01mOGd0O7al00<0
Ogmo01P0P82008F5Q@21PH40PH6107emO@1nOWh0Ng]k07inOP1oOgl0OGem07]kN`1iNGT0Ogmo08F5
Q@1iNGT0MGEe07AdM01`L700Kfm_06][J`1/K6`0KVi^06e]K@1ZJVX206UYJ@0906QXJ01^KVh0LG5a
071`L01hN7P0NWYj0820P01nOWh0R8R80080SHf=00<0TI6A09BDU02KVi/00P2JVYX0102NWYh0WinO
0:6QX@2RXZ820:6QX@030::RXP2SXj<0XJ6Q0080XZ:R00H0Z:RX0:JVYP2SXj<0XJ6Q09jNWP2PX:03
0:6QX@0609nOW`2RXZ80WinO09jNWP2OWil0XZ:R0`2OWil02P2PX:00WYjN09fMW@2HV9P0W9bL09NG
U`2KVi/0WIfM09ZJVP2HV9P209^KV`0409fMW@2IVIT0VIVI09ZJVP80W9bL00@0VIVI09ZJVP2JVYX0
V9RH0P2IVIT01P2MWId0V9RH09NGU`2GUiL0V9RH09NGU`80V9RH00H0UYJF09RHV02FUYH0U9BD09NG
U`2CTi<209FEU@80Ti>C00P0TI6A09>CT`2MWId0[Jf]0;fm_@36a/H0bl_;0=7Ad@80eMGE0P3IfMT0
3`3Lg=`0fm_K0=gMg@3Ng]h0g=cL0=_Kf`3Fe]H0d=3@0<O7a`2j^[X0YJFU08>3P`1ZJVX0IFEU06AT
I00206YZJP0906a/K01[Jf/0LW9b07MgM`1bLW80MWIf07UiN@1jNWX0MgMg0080NWYj00L0MWIf07in
OP1lO7`0Ng]k07moO`1lO7`0NGUi0080OGem0P1jNWX01P1hN7P0NGUi07YjNP1dM7@0MWIf07emO@80
O7al00D0Ogmo07inOP1iNGT0N7Qh07emO@0208B4Q00H08:2PP20P800QHF508N7Q`2:RXX0S8b<08J6
QP22PX80Kfm_05iNGP18B4P0>CTi03hn?P1;Bd/0BTY:034a<@0`<300:2PX02l_;`0[:b/0;Rh^030`
<00X:2P09bLW0P0^;Rh02@0/;2`0:BTY02h^;P0`<300<C4a03@d=00g=cL0=SHf03Xj>P0>0<SPf000
3038h=P209bLW00:09fMW@2HV9P0V9RH09fMW@2OWil0XJ6Q09nOW`2PX:00W9bL0:2PX0<0WYjN0P2O
Wil0402RXZ80Vi^K09bLW02NWYh0W9bL0:2PX02NWYh0VYZJ09bLW02OWil0WIfM0::RXP2SXj<0Y:BT
0:NWY`2VYZH20:FUY@80ZJVY00D0YZJV0:>SX`2VYZH0Y:BT0:>SX`020:FUY@0G0:6QX@2UYJD0YZJV
09^KV`2NWYh0WinO09jNWP2PX:00XJ6Q09nOW`2LW9`0VYZJ09^KV`2FUYH0SXj>08Z:RP21PH40P820
07QhN01aLG40JVYZ06=SH`1MGEd00`1IFET07P1FEUH0G5aL05iNGP1RHV80GUiN05mOG`1SHf<0IVIV
06EUI@1VIVH0Jf][06i^KP1VIVH0JVYZ06MWI`1YJFT0J6QX06MWI`1SHf<0IFEU06m_K`1ZJVX0Jf][
06MWI`1TI6@0IfMW06UYJ@1ZJVX0Hf=S06EUI@80J6QX0P1[Jf/02@1_Kfl0K6a/06][J`1]KFd0M7Ad
06a/K01_Kfl0L71`07=cL`0207QhN00507MgM`1mOGd0NGUi07]kN`1lO7`00P1hN7P01`1jNWX0M7Ad
07]kN`1oOgl0Ph>307emO@21PH400P22PX804020P800Ph>30820P01mOGd0N7Qh08>3P`1lO7`0Ogmo
0820P02;Rh/0P82007inOP22PX80PH6108>3P`22PX8207inOP80PX:200<0Ph>308:2PP23Ph<00P1n
OWh207moO`0308:2PP21PH40PX:20080Ph>301l0P82008>3P`1mOGd0QHF508:2PP20P800Q8B408:2
PP21PH40QXJ608B4Q028R8P0QXJ608F5Q@2=SHd0PH6108:2PP21PH40QXJ608B4Q022PX80Q8B408:2
PP20P800PX:20861P@22PX80R8R808B4Q026QXH0Ph>30080PX:200@0QHF508J6QP1oOgl0OGem0P24
Q8@20861P@0308B4Q020P800Ogmo0080P82000H0PH6107moO`1nOWh0Ph>308B4Q01nOWh208>3P`80
O7al00L0Ogmo07inOP1nOWh0OWin07]kN`22PX80Ogmo0080P82000`0OGem0820P020P800PH6107mo
O`22PX80Ogmo0820P01nOWh0PX:20820P01mOGd307moO`80QHF500D0PX:20820P025QHD0Ph>308J6
QP0208:2PP0308V9R@27QhL0PX:20080QHF501L0P82008F5Q@25QHD0P8200861P@24Q8@0QhN708:2
PP27QhL0P82008:2PP25QHD0Ph>307moO`1nOWh0Ogmo0861P@1oOgl0PH610820P024Q8@0PX:207mo
O`020820P00607]kN`1nOWh0P82007emO@1lO7`0NWYj0P1mOGd02020P800OGem07moO`22PX80OGem
0861P@1lO7`0P8200P1lO7`01@21PH40OWin07inOP1lO7`0Ogmo00<0P8200P1lO7`01`1iNGT0Ogmo
07moO`1hN7P0NGUi07]kN`1hN7P00P1fMWH02@1cLg<0MGEe06i^KP1_Kfl0KVi^06m_K`1/K6`0Jf][
06i^KP0206YZJP0406][J`1/K6`0Kfm_07IfMP80MGEe00l0OGem08F5Q@25QHD0QhN708j>SP2EUID0
UYJF09NGU`2HV9P0Vi^K09jNWP2OWil0WIfM0:BTY02QXJ400P2UYJD0602SXj<0Y:BT0:2PX02QXJ40
Xj>S0:NWY`2SXj<0XJ6Q09fMW@2KVi/0XJ6Q0:2PX02QXJ40X:2P0::RXP2QXJ40X:2P09jNWP2RXZ80
WYjN0:6QX@2PX:00XZ:R0:2PX080W9bL00T0VIVI09bLW02KVi/0WinO09^KV`2OWil0Vi^K09VIV@2M
WId00P2NWYh01P2KVi/0W9bL09VIV@2FUYH0VIVI09BDU080W9bL00d0V9RH09NGU`2HV9P0UYJF09RH
V02GUiL0V9RH09ZJVP2HV9P0UYJF09NGU`2FUYH0UiNG0080UIFE00h0U9BD08n?S`2ATI40T92@08n?
S`2FUYH0YjNW0;Bd]035aLD0bLW90<o?c`3De=@0eMGE0=WIf@80f][J00<0g=cL0=_Kf`3Kfm/00P3L
g=`03`3Hf=P0dm?C0<_;b`30`<00ZJVY09JFUP1dM7@0IVIV06YZJP1XJ6P0KVi^06][J`1_Kfl0LG5a
06m_K`0207IfMP0=07]kN`1lO7`0MWIf07YjNP1mOGd0NGUi07AdM01gMgL0NWYj07IfMP1kNg/0P820
07QhN00207UiN@0807QhN01jNWX0MgMg07IfMP1hN7P0MgMg07]kN`1iNGT207MgM`80PH6102@0OWin
07alO01mOGd0PX:20861P@24Q8@0PH6108f=S@2:RXX0QhN708b<S025QHD0Q8B40820P01aLG40GUiN
04Y:BP0k>c/0C4a<03lo?`0_;bl0<30`02/[:`0];Bd0<30`02`/;00b<S80:2PX02`/;00d=3@0;2`/
02d];@0/;2`0=SHf034a<@0d=3@203Lg=`80=SHf3P38h=P000`0b>3H0P2LW9`00`2MWId0VIVI09RH
V00209bLW00A09fMW@2LW9`0Xj>S09bLW02PX:00WYjN09fMW@2NWYh0WIfM0:2PX02MWId0Vi^K09bL
W02NWYh0VYZJ09nOW`2MWId00P2JVYX209^KV`070:2PX02MWId0XZ:R0:JVYP2YZJT0YjNW0:ZZZP02
0:JVYP040:ZZZP2OWil0Y:BT0:FUY@@0Y:BT0P2SXj<01`2PX:00Xj>S0:6QX@2PX:00YJFU0:BTY02M
WId00P2KVi/05P2GUiL0V9RH08j>SP2;Rh/0Q8B408F5Q@1nOWh0M7Ad06EUI@1SHf<0H61P05IFEP1I
FET0EeMG05QHF01NGUh0GemO069RHP1SHf<0J6QX069RHP1SHf<206][J`0:06QXJ01ZJVX0IfMW06EU
I@1VIVH0IfMW06QXJ01[Jf/0IfMW06EUI@<0IfMW0140Jf][06i^KP1]KFd0IfMW06=SH`1UIFD0Jf][
06UYJ@1XJ6P0JVYZ06][J`1WIfL0Jf][06YZJP1]KFd0K6a/06m_K`02075aL@0>07=cL`1aLG40M7Ad
07emO@1hN7P0MGEe07alO01iNGT0MWIf07UiN@1mOGd0MgMg07alO01nOWh207moO`0607alO01oOgl0
Ogmo08:2PP1oOgl0QXJ60P20P8000`26QXH0Ogmo08:2PP020820P00308:2PP23Ph<0Q8B40080Ogmo
00T0Q8B408J6QP22PX80QhN708F5Q@23Ph<0PH610820P024Q8@00P1nOWh01021PH40OWin08F5Q@21
PH420820P0<0Ph>30280Q8B408R8R021PH40PX:20820P022PX80Ph>308F5Q@24Q8@0QHF508B4Q022
PX80QHF508>3P`20P800PH610820P024Q8@0P82007moO`21PH40QHF507alO01nOWh0RHV90820P01l
O7`0PH6108>3P`21PH40Ph>308N7Q`20P800OWin0P23Ph<01026QXH0Ph>30861P@1nOWh20820P005
08B4Q020P800Ph>307alO01mOGd0101oOgl07`20P800Q8B407inOP21PH40OGem08F5Q@1oOgl0O7al
08:2PP23Ph<0PX:208B4Q028R8P0OGem0820P01oOgl0Ph>308F5Q@1oOgl0P82007moO`21PH40P820
07moO`24Q8@0QHF508N7Q`2;Rh/0Ph>30861P@24Q8@00P23Ph<208B4Q00?08J6QP1oOgl0PX:208F5
Q@23Ph<0PX:207inOP1oOgl0OWin0861P@23Ph<0PX:20820P022PX80Q8B40080PX:200/0Q8B408J6
QP23Ph<0Ph>307inOP21PH40PX:20820P024Q8@0Ph>307]kN`0207inOP0C07moO`1lO7`0OWin07em
O@1kNg/0Ogmo07emO@1oOgl0P82007alO01oOgl0OWin08>3P`1nOWh0O7al07moO`21PH40P82007al
O00207emO@0507moO`27QhL0P82007moO`21PH400P1nOWh01P1kNg/0Ogmo07alO01hN7P0OGem07Mg
M`80N7Qh00@0MGEe07YjNP1bLW80Lg=c0P1aLG4206a/K080L71`00D0JFUY06][J`1]KFd0JFUY06e]
K@02071`L00?079bLP1iNGT0PH6108B4Q02;Rh/0TY:B09>CT`2EUID0Ti>C09RHV02MWId0WYjN09bL
W02KVi/0Y:BT00<0XJ6Q00H0Xj>S0:FUY@2QXJ40WinO0:6QX@2SXj<20:2PX0050::RXP2OWil0X:2P
09nOW`2QXJ400P2TY:@02@2OWil0X:2P09nOW`2PX:00XZ:R0:6QX@2OWil0XJ6Q09fMW@0209^KV`09
09bLW02IVIT0Vi^K09ZJVP2MWId0WYjN09VIV@2MWId0VIVI0080VYZJ00<0V9RH09ZJVP2JVYX00P2G
UiL02@2KVi/0V9RH09JFUP2EUID0VYZJ09RHV02IVIT0UiNG09RHV00309JFUP0909FEU@2DU9@0V9RH
09NGU`2EUID0VIVI09RHV02>SXh0Shn?0080Ti>C00L0WinO0:b/[02o_kl0alO70<c<c03@d=00e=CD
0080f=SH0280fMWI0=_Kf`3Kfm/0g=cL0=_Kf`3Ogml0fm_K0=GEe@3>c/h0`/;20;>c/`2IVIT0OWin
075aL@1/K6`0IFEU06a/K01cLg<0Jf][06a/K01_Kfl0LG5a07AdM01bLW80M7Ad07QhN01bLW80MGEe
07UiN@1cLg<0N7Qh07IfMP1jNWX0MgMg0P1kNg/02P1hN7P0NGUi07UiN@1kNg/0M7Ad07]kN`1iNGT0
Ng]k07QhN01iNGT307alO00307inOP21PH40Ogmo00<0Ogmo00D0P82008B4Q023Ph<0QHF508N7Q`02
08F5Q@0908Z:RP28R8P0S8b<07emO@1aLG40HF5Q04U9B@0h>3P0<c<c0080>SXj00P0;Rh^03Hf=P0o
?cl0<c<c038b<P0`<300=SHf03<c<`80;bl_00<0;Rh^02l_;`0^;Rh00`0_;bl00`0`<300?Cdm0<SP
f00=0<SPf0003038h=P209nOW`0609^KV`2MWId0VIVI09NGU`2LW9`0WIfM0P2NWYh00`2IVIT0WYjN
09fMW@0209jNWP80WinO00<0XZ:R09jNWP2NWYh00P2NWYh01P2MWId0Vi^K09JFUP2KVi/0VYZJ09^K
V`80WIfM0P2RXZ801`2WYjL0Y:BT0:NWY`2ZZZX0YZJV0:FUY@2RXZ800`2UYJD20:RXZ0040:>SX`2U
YJD0XZ:R0::RXP80X:2P00`0W9bL09nOW`2PX:00WYjN09fMW@2HV9P0UIFE09JFUP2;Rh/0R8R808Z:
RP24Q8@207UiN@0806UYJ@1RHV80Fe]K05eMG@1GEeL0FUYJ065QH@1OGel2061PH00906IVIP1RHV80
I6AT06=SH`1WIfL0HF5Q06QXJ021PH40JVYZ0080IfMW00h0JFUY06QXJ01TI6@0Hf=S06EUI@1WIfL0
K6a/06IVIP1QHF40I6AT06QXJ01TI6@0Jf][06IVIP80J6QX00P0IVIV06QXJ01YJFT0KVi^06m_K`1^
KVh0MWIf07=cL`80Kfm_00D0MGEe07UiN@1cLg<0MgMg07alO00207EeM@80N7Qh00H0MgMg07AdM020
P800OGem07alO01oOgl207YjNP0<07]kN`1nOWh0OWin07inOP1mOGd0P82007moO`22PX80PH6108>3
P`25QHD0Ph>30P21PH401@23Ph<0P82008B4Q01oOgl0Ph>30080Ogmo00T0PH6108B4Q020P800PX:2
0820P021PH40OWin0820P023Ph<00P22PX801020P800QHF50820P023Ph<208F5Q@80Ph>300D0QHF5
08:2PP22PX80QHF508B4Q00208>3P`0Q08J6QP25QHD0P82008B4Q025QHD0Ph>30820P026QXH0Q8B4
08F5Q@23Ph<0P82008:2PP1nOWh0Q8B408>3P`26QXH0PX:208>3P`22PX80QHF508R8R023Ph<0Ogmo
08:2PP24Q8@0PH6108>3P`27QhL0Ph>307alO022PX80PH610080Q8B400@0Ph>307moO`20P800OWin
0`22PX800`1oOgl0Q8B40861P@0207moO`80PH6100/0OWin0820P024Q8@0PX:208>3P`21PH40P820
07moO`24Q8@0OWin08:2PP0207moO`0908:2PP1oOgl0Ogmo0861P@20P800Ogmo08B4Q022PX80Ph>3
0080QHF500H0QXJ608R8R025QHD0QhN708:2PP21PH4208:2PP<0Ph>30140Q8B408>3P`24Q8@0PX:2
08B4Q023Ph<0PX:20861P@26QXH0Ph>30861P@22PX80P82007inOP24Q8@0Ogmo07inOP0208:2PP07
0861P@1lO7`0OGem07alO01mOGd0NWYj0861P@0207inOP0307alO023Ph<0PH610080P82000P0OGem
0820P01nOWh0Ogmo0820P022PX80P82007emO@<0OWin00`0Ph>30861P@20P800Ogmo07inOP1mOGd0
OWin07UiN@1kNg/0NGUi07alO01kNg/307QhN00:07UiN@1bLW80LW9b07EeM@1`L700Kfm_06a/K01a
LG40MGEe06][J`80JVYZ00<0IVIV06MWI`1YJFT00P1^KVh0201bLW80OWin08>3P`28R8P0Rh^;096A
T@2FUYH0V9RH0P2JVYX209^KV`0509jNWP2MWId0Y:BT09jNWP2TY:@00P2SXj<0102QXJ40YJFU0:2P
X02OWil20:>SX`0409fMW@2OWil0X:2P0:6QX@<0XZ:R00`0YJFU09nOW`2SXj<0Xj>S0:2PX02RXZ80
XJ6Q0:>SX`2PX:00WIfM09ZJVP2GUiL309jNWP<0Vi^K00<0V9RH09bLW02KVi/00P2HV9P01@2IVIT0
VYZJ09JFUP2GUiL0VYZJ0080V9RH00@0VIVI09RHV02HV9P0Vi^K0P2FUYH309RHV00509BDU02EUID0
UYJF09NGU`2DU9@00P2FUYH02@2>SXh0Shn?08n?S`2?Shl0UYJF0:NWY`2h^;P0a<C40<W9b@020=7A
d@0N0=KFeP3GemL0f=SH0=WIf@3Jf]X0fm_K0=cLg03Kfm/0g=cL0=SHf03De=@0c<c<0;^k^`2TY:@0
RHV906a/K01ZJVX0IVIV06UYJ@1ZJVX0K6a/06m_K`1eMGD0LW9b06e]K@1iNGT0LG5a07QhN01gMgL0
M7Ad0P1fMWH01@1bLW80Lg=c079bLP1iNGT0O7al0080OWin00/0O7al07QhN01gMgL0NWYj07MgM`1e
MGD0NWYj07UiN@1eMGD0O7al0820P0020861P@0;07moO`1mOGd0QHF508B4Q025QHD0P82008>3P`21
PH40PX:208J6QP22PX800P27QhL0602:RXX0QhN708j>SP25QHD0Ogmo07AdM01KFe/0AdM703Hf=P0a
<C40=CDe02TY:@0Z:RX0;Bd]02`/;00];Bd0=SHf03De=@0n?Sh0;bl_03<c<`0d=3@0:b/[02h^;P80
<C4a00<0>3Ph03@d=00f=SH03P38h=P000`0b>3H0`2KVi/02@2JVYX0W9bL09bLW02MWId0W9bL09nO
W`2IVIT0Vi^K0::RXP0209nOW`0709^KV`2LW9`0WYjN09fMW@2OWil0W9bL09fMW@0309VIV@0709ZJ
VP2LW9`0V9RH09bLW02QXJ40WIfM0::RXP020:NWY`080:JVYP2XZ:P0YZJV0:RXZ02PX:00Xj>S0:NW
Y`2SXj<30:JVYP030:NWY`2TY:@0Y:BT0080XJ6Q0280WinO0:BTY02QXJ40Xj>S0:2PX02LW9`0XJ6Q
09BDU02BTY80SHf=08R8R022PX80OWin07UiN@1_Kfl0JFUY06ATI01MGEd0Hf=S05MGE`1FEUH0GUiN
05eMG@1RHV80Hf=S05aLG01WIfL0Hf=S06MWI`1YJFT0IfMW06IVIP1gMgL0Jf][0P1ZJVX05@1UIFD0
IfMW06UYJ@1]KFd0IVIV06UYJ@1^KVh0JFUY05mOG`1TI6@0IfMW069RHP1WIfL0KFe]06=SH`1WIfL0
IFEU06MWI`1XJ6P0Jf][071`L003075aL@0707=cL`1`L700M7Ad075aL@1hN7P0LW9b07IfMP0207Yj
NP0:07QhN01nOWh0NWYj07UiN@21PH40OGem07inOP1lO7`0P82007]kN`<0NGUi00`0P82008>3P`1o
Ogl0OWin08>3P`1oOgl0PH6108>3P`20P800Ogmo08B4Q025QHD208:2PP0707inOP1oOgl0QHF508>3
P`24Q8@0P82007moO`020861P@0408B4Q01oOgl0Ph>30861P@80PX:200<0QHF508:2PP22PX800P21
PH400`25QHD0Q8B408B4Q0030861P@80Ph>300H0QXJ608>3P`21PH40QhN708J6QP23Ph<208B4Q080
Ogmo0P23Ph<03`26QXH0P82008:2PP1nOWh0QHF508J6QP20P800Ph>308R8R024Q8@0PX:20820P024
Q8@0QhN708F5Q@0208J6QP0=08>3P`20P800QHF50820P021PH40P82008>3P`28R8P0TI6A08>3P`21
PH40Ogmo08B4Q00208>3P`0;08:2PP21PH40Ph>307inOP22PX80Ph>308V9R@21PH40Ogmo08>3P`26
QXH00P23Ph<01P22PX80Ogmo08:2PP21PH40Ogmo08>3P`<0P82000<0Ogmo08>3P`1oOgl00`21PH42
08B4Q00H08R8R027QhL0RHV908b<S02@T900RXZ:08>3P`28R8P0QhN708:2PP23Ph<0OWin08>3P`27
QhL0Ogmo08>3P`28R8P0PH6107moO`24Q8@0Ogmo08F5Q@1nOWh0PH610P20P8002@23Ph<0O7al08B4
Q023Ph<0P82007]kN`21PH40O7al07emO@0207inOP0:0861P@20P800O7al07alO01kNg/0OWin0861
P@23Ph<0O7al07]kN`80P82000D0PH6108>3P`1nOWh0Ogmo0861P@0208>3P`0808:2PP20P800PX:2
07moO`1nOWh0OGem07inOP1jNWX507]kN`0=08B4Q01lO7`0NGUi071`L01_Kfl0L71`079bLP1`L700
Kfm_06YZJP1^KVh0JVYZ071`L00206][J`0T06MWI`1]KFd0Kfm_06m_K`1cLg<0P82008B4Q02;Rh/0
SHf=096AT@2KVi/0Ti>C09VIV@2JVYX0VIVI09^KV`2OWil0XJ6Q0:>SX`2RXZ80Xj>S0::RXP2TY:@0
YZJV0:NWY`2PX:00XZ:R09jNWP2QXJ40WinO0:2PX02RXZ80X:2P0::RXP2QXJ40Xj>S0P2QXJ403P2N
WYh0XZ:R0:>SX`2NWYh0XZ:R0:2PX02MWId0V9RH09jNWP2KVi/0WIfM09jNWP2KVi/0VIVI0`2KVi/0
2P2LW9`0Vi^K09fMW@2MWId0V9RH0:2PX02IVIT0UiNG09JFUP2IVIT209RHV00309VIV@2HV9P0V9RH
0080UiNG01X0V9RH09VIV@2HV9P0V9RH09BDU02HV9P0VIVI09BDU02FUYH0UiNG09BDU02@T900TI6A
09>CT`2PX:00/[:b0;fm_@39bLT0clo?0=7Ad@3De=@0eMGE0=OGe`3IfMT0f][J0=_Kf`80g=cL02@0
fm_K0=SHf03Fe]H0c<c<0<C4a02_[jl0Ti>C07QhN01XJ6P0JFUY06e]K@1aLG40JVYZ06UYJ@1aLG40
LW9b075aL@1^KVh0MGEe07MgM`1dM7@0N7Qh07AdM01gMgL0NWYj07=cL`1hN7P0Ng]k07inOP1oOgl0
MGEe07alO01cLg<0Ng]k07moO`1kNg/207alO00507QhN01lO7`0O7al07inOP1lO7`00P20P80208J6
QP0507moO`1mOGd0Ph>30820P023Ph<00P22PX804026QXH0PX:208J6QP27QhL0RXZ:08F5Q@2:RXX0
SXj>08J6QP21PH40L71`05mOG`19BDT0?3`l03@d=00^;Rh202d];@80:BTY0P0a<C402`0e=CD0<C4a
02`/;00X:2P0:b/[030`<00_;bl0<C4a02l_;`0g=cL0<S8b00h0b>3H000<0<SPf080W9bL00<0Vi^K
0:6QX@2KVi/00P2LW9`03@2IVIT0WinO09jNWP2PX:00Vi^K09jNWP2LW9`0WinO0::RXP2MWId0XZ:R
09^KV`2OWil00P2IVIT01P2OWil0WYjN09VIV@2FUYH0Vi^K0:2PX080WYjN00/0X:2P0::RXP2SXj<0
Y:BT0:FUY@2WYjL0YJFU0:BTY02WYjL0Zj^[0:RXZ0030:FUY@060::RXP2SXj<0YJFU0:BTY02NWYh0
XJ6Q0P2SXj<02P2QXJ40WIfM09^KV`2LW9`0TI6A09>CT`2<S8`0QhN708R8R023Ph<207moO`0O07Ad
M01WIfL0GUiN069RHP1EEED0EeMG05YJFP1IFET0GemO061PH01OGel0IFEU069RHP1VIVH0JVYZ06UY
J@1WIfL0JVYZ06][J`1]KFd0JFUY06QXJ01^KVh0K6a/06YZJP1UIFD0IfMW06IVIP1UIFD0JFUY06MW
I`0206EUI@0406YZJP1/K6`0I6AT06QXJ080IfMW00H0I6AT06UYJ@1/K6`0LW9b071`L01aLG42079b
LP0306m_K`1cLg<0NWYj0080MGEe0P1gMgL02`1hN7P0MWIf07YjNP1nOWh0NWYj07alO01dM7@0Ng]k
07alO020P800OGem0080O7al0P1oOgl01@1nOWh0P8200820P022PX80P8200080Ph>300X0PX:208F5
Q@23Ph<0PH610820P021PH40OWin0820P026QXH0Q8B40P21PH401@24Q8@0QhN708B4Q023Ph<0Q8B4
0080QHF500<0PX:208>3P`23Ph<00P22PX804`1oOgl0PX:208F5Q@23Ph<0QhN708F5Q@22PX80QHF5
0820P023Ph<0QXJ608B4Q022PX80Q8B408F5Q@26QXH0OWin08:2PP21PH400P23Ph<01P25QHD0PX:2
08:2PP22PX80QHF508>3P`80Q8B401H0PX:208R8R020P800Ph>30861P@24Q8@0QHF508J6QP1nOWh0
Ph>308F5Q@24Q8@0PH6108F5Q@1oOgl0PX:208V9R@25QHD0P82008:2PP26QXH0P8200P1oOgl01024
Q8@0PH6108F5Q@23Ph<20861P@0908^;R`28R8P0QHF50820P023Ph<0PX:208B4Q021PH40QHF50080
Ph>300P0Q8B407inOP1oOgl0PH6107moO`1nOWh0QXJ60820P080QHF500@0PH6108J6QP27QhL0QhN7
0P25QHD03P2<S8`0SHf=08R8R025QHD0Ph>308:2PP25QHD0PX:208B4Q026QXH0Ph>307emO@2:RXX0
OWin0P1oOgl01026QXH0Shn?08J6QP1nOWh208F5Q@0307moO`1lO7`0Ogmo0080PH6100<0P82008B4
Q020P8000P22PX800`28R8P0Q8B40820P00207]kN`0307emO@1nOWh0Ogmo0080Ogmo00@0PH6107mo
O`22PX80PH610P23Ph<00`1oOgl0PX:207inOP0307inOP0B08:2PP1oOgl0Ogmo07emO@22PX80OWin
07UiN@1mOGd0NWYj0820P01kNg/0N7Qh08Z:RP1iNGT0N7Qh07MgM`1dM7@0Kfm_0P1cLg<0401/K6`0
KVi^06YZJP1YJFT0KFe]06UYJ@1TI6@0IVIV06e]K@1aLG40MGEe07]kN`22PX80QhN708Z:RP2=SHd2
09BDU00409>CT`2HV9P0VIVI09jNWP80W9bL00d0WIfM0:>SX`2TY:@0XJ6Q0::RXP2SXj<0XJ6Q0:BT
Y02QXJ40Xj>S09nOW`2QXJ40WinO0080YJFU00<0Y:BT0:>SX`2SXj<00P2VYZH01P2PX:00Xj>S0:6Q
X@2PX:00XJ6Q09nOW`80W9bL00X0WinO09fMW@2OWil0WIfM09nOW`2KVi/0Xj>S09nOW`2HV9P0VYZJ
0P2NWYh209fMW@0S09bLW02MWId0VYZJ09VIV@2HV9P0VIVI09NGU`2HV9P0Vi^K09NGU`2LW9`0VIVI
09fMW@2KVi/0VYZJ09VIV@2FUYH0UIFE09VIV@2HV9P0UIFE09NGU`2FUYH0W9bL09FEU@2@T900V9RH
0:ZZZP2j^[X0aLG50<c<c03?cll0d];B0=OGe`3Hf=P00P3IfMT03@3Kfm/0g=cL0=kNgP3Ogml0g=cL
0=GEe@3?cll0a/K60;Vi^@2RXZ80R8R8075aL@1SHf<00P1`L7003@1]KFd0Jf][075aL@1eMGD0LW9b
075aL@1]KFd0MGEe07QhN01eMGD0MgMg07=cL`1jNWX00`1iNGT03P1hN7P0Ng]k07]kN`1kNg/0NWYj
07QhN01nOWh0MGEe07IfMP1nOWh0NWYj07AdM01hN7P0NWYj0P1iNGT307moO`0908:2PP1nOWh0OWin
07inOP1mOGd0Ogmo0861P@23Ph<0PX:20080Q8B400<0QhN708F5Q@26QXH00P2<S8`02@27QhL0QHF5
07inOP1`L700I6AT059BDP0o?cl0=3@d03<c<`0202/[:`0>03Lg=`13@d<0=CDe038b<P0];Bd0;bl_
03Ti>@0b<S80;Rh^038b<P0^;Rh0=CDe02h^;P0d=3@>0<SPf0003038h=P309ZJVP0509^KV`2MWId0
X:2P09fMW@2LW9`00P2NWYh0102OWil0W9bL0:6QX@2IVIT209nOW`0:0:2PX02OWil0X:2P09bLW02N
WYh0Vi^K09bLW02OWil0Vi^K09RHV080VYZJ00L0WIfM09^KV`2OWil0Xj>S0:6QX@2UYJD0YZJV0080
YJFU00D0XZ:R0:JVYP2YZJT0Y:BT0:RXZ0030:JVYP040:ZZZP2SXj<0Y:BT0:2PX080YZJV01@0Xj>S
0:6QX@2JVYX0VYZJ09bLW02EUID0Ti>C08n?S`2@T900SHf=08R8R01nOWh0Ogmo075aL@1OGel0Hf=S
05QHF01FEUH0EeMG05UIF@<0GemO0180Hf=S061PH01RHV80Jf][06=SH`1TI6@0Hf=S06UYJ@1/K6`0
KVi^06][J`1YJFT0LW9b06a/K01[Jf/0JVYZ06IVIP1WIfL206QXJ00@06e]K@1WIfL0JVYZ06e]K@1V
IVH0KVi^06UYJ@1VIVH0IFEU06YZJP1[Jf/0Kfm_079bLP1eMGD0L71`07EeM@<0Lg=c0P1kNg/02@1m
OGd0NWYj07QhN01iNGT0N7Qh07IfMP1oOgl0OGem07inOP0207YjNP0307]kN`21PH40Ogmo0080PH61
00D0PX:207emO@20P800PH6108:2PP0208>3P`030861P@23Ph<0P82000<0Ph>30100Q8B408>3P`22
PX80QHF508:2PP25QHD0RHV908F5Q@23Ph<0QHF508B4Q027QhL0PH6108:2PP20P800Ph>30P25QHD0
4022PX80P8200820P025QHD0PX:208B4Q020P800QXJ608>3P`20P800Ph>308N7Q`24Q8@0QhN708J6
QP25QHD208B4Q0080820P024Q8@0PH6108F5Q@26QXH0PH6108J6QP1oOgl208>3P`80PH6100D0PX:2
0861P@23Ph<0Ph>30820P00208:2PP0608B4Q02;Rh/0QhN708N7Q`26QXH0Ph>30P24Q8@00`22PX80
QHF508J6QP0308>3P`070861P@22PX80P8200820P024Q8@0R8R808N7Q`0208:2PP0308B4Q026QXH0
R8R80080Q8B40P22PX803027QhL0P82008N7Q`1oOgl0Q8B408b<S021PH40P82008B4Q01oOgl0PH61
08F5Q@80PX:200l0Ph>308N7Q`26QXH0Ph>308F5Q@2:RXX0S8b<08N7Q`25QHD0QXJ608R8R022PX80
Ph>308F5Q@22PX800P26QXH02P24Q8@0Ph>308N7Q`21PH40Ogmo08:2PP2=SHd0TI6A0861P@20P802
07moO`060861P@1oOgl0P8200861P@23Ph<0Ogmo0P23Ph<208:2PP0808R8R021PH40OGem08B4Q01l
O7`0Ph>307moO`25QHD207moO`0407emO@24Q8@0PH6108J6QP80Q8B400<0PH6108F5Q@1nOWh00P1n
OWh06P1oOgl0PX:208>3P`21PH40P82007inOP1iNGT0Ph>307]kN`1jNWX0OWin07YjNP1fMWH0N7Qh
07IfMP1hN7P0Lg=c075aL@1dM7@0LW9b06a/K01_Kfl0KFe]075aL@1[Jf/0K6a/0P1UIFD03P1XJ6P0
KVi^079bLP1eMGD0Ng]k08:2PP28R8P0SHf=08^;R`2BTY80V9RH09FEU@2JVYX0VIVI0`2NWYh20:6Q
X@090::RXP2SXj<0XZ:R0::RXP2QXJ40YJFU0:6QX@2RXZ80W9bL0080XZ:R0P2QXJ40302PX:00YjNW
0:NWY`2SXj<0XZ:R0:>SX`2RXZ80Xj>S0:6QX@2OWil0Vi^K09jNWP80WinO00H0WIfM0:2PX02MWId0
W9bL09nOW`2NWYh209^KV`0309fMW@2JVYX0VYZJ0080VYZJ00<0W9bL09^KV`2KVi/00P2IVIT00`2K
Vi/0UYJF09RHV00209RHV00H09ZJVP2GUiL0UiNG09bLW02FUYH0UIFE09NGU`2HV9P0Vi^K09VIV@2G
UiL0UIFE09>CT`2FUYH0TY:B09JFUP2OWil0];Bd0<30`039bLT0clo?0=?Cd`3Fe]H0emOG0P3Jf]X0
0`3IfMT0f][J0=_Kf`020=_Kf`070=SHf03Cdm<0bl_;0;no_`2][Jd0TY:B07EeM@0206MWI`0506IV
IP1XJ6P0JVYZ06YZJP1]KFd00P1`L700301bLW80M7Ad071`L01bLW80MgMg07EeM@1hN7P0NGUi07in
OP1hN7P0OGem07MgM`80NGUi0P1lO7`0201jNWX0O7al07YjNP1lO7`0Ng]k07YjNP1hN7P0OWin0P1k
Ng/01@1iNGT0O7al07alO01lO7`0PX:20080O7al00d0Ogmo08:2PP22PX80OWin07emO@21PH40Ph>3
0861P@27QhL0QXJ608N7Q`28R8P0QXJ60080R8R800T0Q8B407inOP1^KVh0HV9R04a<C011@D40<30`
02HV9P0];Bd00P0b<S80300];Bd0<S8b02l_;`0a<C40>c/k034a<@0c<c<0:b/[02XZ:P0/;2`0;Bd]
03@d=0h0b>3H000<0<SPf080WIfM00@0WinO09^KV`2NWYh0WIfM0P2JVYX0502OWil0WIfM09ZJVP2L
W9`0WIfM09nOW`2QXJ40WIfM09nOW`2NWYh0WinO0:2PX02KVi/0VIVI09ZJVP2LW9`0VIVI09^KV`2J
VYX0WYjN0P2PX:00102QXJ40XZ:R0:JVYP2VYZH20:NWY`060:RXZ02VYZH0YJFU0:VYZ@2WYjL0ZZZZ
0P2WYjL0;@2VYZH0YjNW0:NWY`2RXZ80XJ6Q0:VYZ@2TY:@0Xj>S0:6QX@2PX:00Vi^K09VIV@2EUID0
SHf=08n?S`25QHD0PX:207emO@1dM7@0KFe]06ATI01NGUh0I6AT05iNGP1GEeL0GUiN05QHF01MGEd0
HF5Q05mOG`1SHf<0IfMW06][J`1RHV80I6AT06EUI@1WIfL0IFEU06YZJP1TI6@0J6QX06i^KP1YJFT0
IfMW06YZJP0206MWI`0606a/K01VIVH0IfMW06UYJ@1WIfL0JFUY0P1RHV802@1XJ6P0IFEU06EUI@1X
J6P0KFe]06i^KP1[Jf/0KVi^07AdM002079bLP0307QhN01bLW80NGUi00@0MWIf00`0N7Qh07YjNP1m
OGd0NGUi07QhN01kNg/0Ogmo07]kN`1hN7P0O7al0861P@20P80307moO`0B08>3P`22PX80Ogmo0820
P023Ph<0OWin08:2PP1nOWh0Ph>308B4Q025QHD0QhN708:2PP24Q8@0OGem08R8R021PH40PX:21024
Q8@03@22PX80QHF50861P@22PX80PH6108F5Q@1oOgl0QHF508>3P`24Q8@0PX:208B4Q027QhL00P22
PX80;P21PH40P82008N7Q`22PX80QhN708B4Q028R8P0Q8B408>3P`26QXH0PX:208Z:RP29RHT0QXJ6
08>3P`22PX80Q8B40861P@23Ph<0R8R80820P026QXH0QhN708>3P`25QHD0PX:208R8R020P800PH61
08>3P`22PX80RHV908^;R`24Q8@0QXJ608F5Q@27QhL0PX:208Z:RP23Ph<0PX:208B4Q021PH40Ph>3
0820P027QhL208F5Q@0408:2PP25QHD0SHf=08>3P`80PH6100@0PX:207moO`22PX80OWin0P20P800
1`27QhL0Ph>308R8R024Q8@0Ogmo0861P@22PX800`20P8001P1mOGd0QHF508:2PP26QXH0Q8B408V9
R@@0R8R800@0QhN708R8R025QHD0QHF50P23Ph<01@25QHD0QhN708:2PP23Ph<0Q8B400<0PX:20P25
QHD05`27QhL0PX:208J6QP24Q8@0PH6108:2PP1oOgl0Ph>307inOP1kNg/0P8200861P@22PX80QhN7
08B4Q020P800PH6108>3P`21PH40NWYj07emO@20P800OWin0080OGem00D0Ogmo0861P@23Ph<0P820
08>3P`0208:2PP0407inOP24Q8@0Q8B40820P080O7al00P0OGem07moO`20P800PX:207moO`20P800
OGem07moO`80OGem03h0O7al07]kN`1iNGT0M7Ad07=cL`1eMGD0Kfm_075aL@1fMWH0M7Ad06e]K@1`
L700K6a/075aL@1XJ6P0IFEU06YZJP1VIVH0IfMW06i^KP1eMGD0N7Qh0861P@20P800RHV908^;R`2>
SXh0Shn?09JFUP2JVYX0Vi^K09ZJVP2NWYh0X:2P09nOW`2NWYh0XJ6Q0:JVYP2QXJ40X:2P0:6QX@2P
X:00Y:BT0::RXP2PX:00WinO0:6QX@2OWil0YZJV0:>SX`2UYJD0Xj>S0:FUY@2QXJ40WYjN0:BTY02R
XZ80Xj>S0:FUY@2OWil0WYjN09nOW`80W9bL00<0WYjN0:2PX02PX:000P2QXJ40102IVIT0W9bL09fM
W@2KVi/209ZJVP80Vi^K00X0UiNG09jNWP2JVYX0VIVI09fMW@2JVYX0V9RH09VIV@2KVi/0VYZJ0P2G
UiL209RHV00409NGU`2JVYX0V9RH09NGU`80UYJF0P2DU9@0402CTi<0T92@096AT@2IVIT0[:b/0;^k
^`37alL0c<c<0=7Ad@3De=@0emOG0=[JfP3IfMT0f][J0=WIf@3Lg=`20=_Kf`0J0=cLg03De=@0cLg=
0<K6aP2a/K40W9bL08N7Q`1YJFT0IVIV06MWI`1XJ6P0KFe]06a/K01[Jf/0Kfm_071`L01eMGD0Kfm_
07YjNP1bLW80N7Qh07UiN@1dM7@0MgMg07QhN01iNGT207emO@0907moO`1hN7P0OGem08>3P`1mOGd0
PX:207moO`1jNWX0MgMg0080Ng]k00@0NWYj07]kN`26QXH0NGUi0`1lO7`01`1iNGT0O7al07inOP1g
MgL0OGem07alO022PX800P1nOWh05P20P800Ph>30820P027QhL0PH6108:2PP24Q8@0QhN708J6QP2:
RXX0Rh^;08:2PP1kNg/0KVi^05eMG@1CDe<0>CTi038b<P0[:b/0:2PX02h^;P0d=3@202h^;P0902/[
:`0b<S80;Rh^034a<@0^;Rh0<30`034a<@0^;Rh0<S8b00h0b>3H000<0<SPf080WIfM00L0Vi^K09fM
W@2OWil0VIVI09JFUP2JVYX0W9bL0080WinO00H0WYjN09ZJVP2MWId0Vi^K09bLW02KVi/209VIV@80
WIfM00H0VIVI09bLW02LW9`0Vi^K09JFUP2JVYX209RHV00:0:2PX02SXj<0WinO0:6QX@2UYJD0YZJV
0:VYZ@2XZ:P0YZJV0:FUY@80YjNW00`0Z:RX0:JVYP2VYZH0YZJV0:>SX`2XZ:P0Y:BT0:FUY@2VYZH0
Xj>S0:2PX02QXJ4209jNWP0j09RHV02CTi<0TI6A08V9R@26QXH0PH6107YjNP1`L700K6a/06QXJ01O
Gel0F5QH05aLG01JFUX0E5AD05QHF01NGUh0GemO05MGE`1PH600JFUY06ATI01_Kfl0IFEU06ATI01U
IFD0KFe]06QXJ01UIFD0J6QX06UYJ@1WIfL0Jf][06i^KP1[Jf/0J6QX06YZJP1YJFT0Hf=S06YZJP1^
KVh0JFUY06EUI@1WIfL0IVIV06ATI01VIVH0J6QX06MWI`1VIVH0KFe]06m_K`1aLG40L71`075aL@1d
M7@0LG5a07UiN@<0MGEe00d0N7Qh07MgM`1mOGd0NGUi07inOP1lO7`0NWYj07alO01hN7P0NGUi08>3
P`1nOWh0OGem0080PH6100L0P82007moO`1oOgl0OWin0820P024Q8@0QHF50080PX:200P0P82008F5
Q@23Ph<0Q8B408>3P`20P800Ogmo08:2PP<0Q8B400h0PH6108B4Q024Q8@0Q8B408J6QP25QHD0OGem
08:2PP21PH40PX:208>3P`24Q8@0Ph>308:2PP80R8R800@0PH6108F5Q@20P800QXJ60P25QHD02027
QhL0Q8B408N7Q`24Q8@0QHF5096AT@29RHT0QXJ60P25QHD06026QXH0OWin08>3P`24Q8@0Ogmo08>3
P`25QHD0QhN708Z:RP25QHD0Q8B408J6QP24Q8@0PX:208>3P`21PH40SXj>08>3P`27QhL0QXJ608B4
Q022PX80Ph>308F5Q@80QhN700D0QXJ608B4Q027QhL0QhN708V9R@0308N7Q`0508F5Q@22PX80S8b<
0820P021PH400P25QHD0401kNg/0Q8B407emO@21PH40PX:208B4Q021PH40PX:208R8R023Ph<0PH61
08>3P`22PX80OWin08:2PP24Q8@208:2PP0508B4Q023Ph<0RXZ:08Z:RP25QHD00P27QhL01@29RHT0
R8R808F5Q@24Q8@0PH610080Ph>300L0QHF508>3P`20P800PX:208R8R020P800Q8B400<0Ph>300h0
Q8B408N7Q`25QHD0Q8B408:2PP20P800Ogmo08>3P`20P800Ng]k08N7Q`23Ph<0OWin0820P0<0PH61
0P1nOWh03`1lO7`0OWin07moO`21PH40OGem0861P@24Q8@0Ph>308F5Q@20P800Ogmo08>3P`21PH40
PX:208F5Q@0408:2PP0>07inOP28R8P0P82008B4Q020P800O7al07inOP1oOgl0OGem07inOP1kNg/0
M7Ad075aL@1bLW82075aL@03079bLP1eMGD0N7Qh0080Kfm_00@0KFe]07AdM01YJFT0K6a/0P1YJFT0
501VIVH0L71`07=cL`1iNGT0PH6108b<S02=SHd0UiNG092@T02DU9@0Ti>C09JFUP2HV9P0WIfM09VI
V@2JVYX0XZ:R0:2PX02QXJ40Xj>S0P2QXJ401@2TY:@0Xj>S0:6QX@2OWil0XJ6Q00<0WinO0P2SXj<0
3@2TY:@0XZ:R0:FUY@2QXJ40XZ:R0:6QX@2RXZ80WinO0:6QX@2LW9`0XZ:R0:6QX@2NWYh00P2QXJ40
1`2LW9`0WYjN09jNWP2LW9`0WYjN09^KV`2HV9P00`2KVi/209JFUP0?09RHV02LW9`0VIVI09jNWP2M
WId0UIFE09RHV02KVi/0UIFE09NGU`2EUID0VIVI09^KV`2GUiL0UYJF0080UiNG00<0UYJF09RHV02F
UYH00P2DU9@02`2EUID0TY:B09RHV02YZJT0]kNg0<;2`P3<c<`0clo?0=?Cd`3GemL0fMWI0080f=SH
01T0fMWI0=cLg03Jf]X0g=cL0=_Kf`3GemL0d];B0<[:bP2k^k/0Zj^[08j>SP1gMgL0I6AT06MWI`1`
L700Jf][06QXJ01ZJVX0KVi^075aL@1dM7@0MGEe07AdM01cLg<0MgMg0080NGUi00T0MgMg07QhN01f
MWH0Ng]k07MgM`1kNg/0NGUi07emO@1gMgL00P1jNWX207inOP0807]kN`1iNGT0Ogmo07YjNP1iNGT0
NWYj07inOP1lO7`307inOP0407moO`21PH40Ng]k07UiN@@0OWin01`0OGem0861P@1oOgl0P8200861
P@22PX80OGem08B4Q023Ph<0Q8B408R8R029RHT0Q8B408>3P`1lO7`0LG5a061PH01@D500?Cdm02l_
;`0];Bd0<S8b02/[:`0];Bd0;Rh^02PX:00`<300<S8b0P0_;bl0100/;2`0:2PX02d];@0e=CD>0<SP
f0003038h=P209bLW00M09^KV`2MWId0WYjN09bLW02MWId0VIVI09bLW02MWId0VIVI09^KV`2NWYh0
WIfM09^KV`2MWId0VIVI09bLW02KVi/0X:2P09bLW02MWId0VYZJ09fMW@2JVYX0UIFE09JFUP2KVi/0
UiNG09jNWP2TY:@00P2QXJ401P2SXj<0YJFU0:FUY@2[Zj/0YJFU0:NWY`80YZJV0`2YZJT20:JVYP0]
0:NWY`2XZ:P0YZJV0:RXZ02WYjL0YZJV0:2PX02MWId0WinO09bLW02FUYH0Shn?08f=S@2<S8`0Q8B4
08:2PP1jNWX0KFe]06QXJ01SHf<0GEeM05YJFP1DE5@0FUYJ05QHF01MGEd0Fe]K05aLG01NGUh0IVIV
06QXJ01WIfL0IFEU05mOG`1RHV80JVYZ071`L01_Kfl0JVYZ06e]K@1WIfL0Kfm_06e]K@1RHV80JFUY
0080IFEU00<0JVYZ06IVIP1^KVh00P1UIFD306QXJ080I6AT00<0JFUY06QXJ01[Jf/00P1`L7000`1_
Kfl0LW9b079bLP02075aL@0<07=cL`1iNGT0NGUi07alO01iNGT0Ogmo07emO@1lO7`0MWIf0820P01l
O7`0P8200P1mOGd02`22PX80P82008:2PP22PX80P82008:2PP20P800Ogmo0861P@23Ph<0PH610080
OWin0P22PX801P24Q8@0PH6108B4Q021PH40QXJ608>3P`80PX:20180PH6108N7Q`22PX80PX:208>3
P`24Q8@0Ogmo08F5Q@21PH40Ogmo08:2PP25QHD0Q8B408J6QP24Q8@0RXZ:08R8R024Q8@208J6QP80
Ph>300<0SXj>08B4Q026QXH00`27QhL00`23Ph<0R8R808N7Q`0208F5Q@0808N7Q`26QXH0Ph>308V9
R@23Ph<0PX:208N7Q`25QHD208:2PP0?08B4Q021PH40Ph>308>3P`21PH40P82008J6QP24Q8@0QHF5
08>3P`24Q8@0Ogmo08:2PP25QHD0PX:20080QXJ600D0QHF508N7Q`23Ph<0R8R808J6QP020861P@05
08:2PP24Q8@0RHV908:2PP27QhL00P25QHD20861P@0507alO01nOWh0P82008B4Q026QXH00P24Q8@0
4P25QHD0Ph>307moO`24Q8@0P8200861P@23Ph<0PH6108>3P`22PX80QXJ608B4Q02:RXX0QhN708B4
Q027QhL0SHf=08V9R@80QHF500@0Ph>308B4Q025QHD0Q8B40P21PH401P23Ph<0Q8B408B4Q022PX80
PH6108N7Q`80PH6100<0PX:20861P@22PX800P23Ph<01`1nOWh0OGem0820P023Ph<0Q8B408>3P`1o
Ogl00P20P8002P1lO7`0P82008:2PP1kNg/0NWYj07moO`21PH40Ogmo0861P@20P80308:2PP0307mo
O`22PX80PH6100<0PH6100P0P82007moO`1oOgl0PH610820P022PX80Ogmo0861P@80OWin01/0Ng]k
07inOP1dM7@0MWIf07YjNP1mOGd0M7Ad07QhN01gMgL0L71`079bLP1cLg<0Ng]k07MgM`1^KVh0JFUY
06i^KP1/K6`0JVYZ06EUI@1WIfL0Jf][07=cL`1gMgL0NWYj08:2PP29RHT00P2?Shl05P2BTY80U9BD
092@T02HV9P0VIVI09bLW02OWil0Vi^K0:2PX02NWYh0Xj>S0:JVYP2WYjL0X:2P0:>SX`2OWil0W9bL
09fMW@2PX:00XZ:R0:2PX02SXj<20::RXP090:FUY@2OWil0WinO0:2PX02WYjL0XJ6Q0::RXP2SXj<0
VYZJ0080WIfM00T0WinO09bLW02QXJ40X:2P09nOW`2QXJ40WYjN09VIV@2JVYX00P2HV9P00`2KVi/0
V9RH09VIV@0209VIV@0D09NGU`2JVYX0Vi^K09bLW02KVi/0UIFE09RHV02KVi/0U9BD09FEU@2HV9P0
VIVI09RHV02FUYH0V9RH09JFUP2IVIT0UiNG09JFUP2EUID209VIV@09096AT@2DU9@0XZ:R0;6a/@31
`L40alO70<k>cP3AdM40e=CD0080emOG00<0f=SH0=_Kf`3Lg=`00P3Lg=`20=_Kf`070=CDe03>c/h0
a<C40;>c/`2KVi/0O7al075aL@0206UYJ@0306ATI01[Jf/0LG5a0080K6a/01d0LW9b07YjNP1dM7@0
M7Ad075aL@1bLW80Lg=c07IfMP1iNGT0NWYj07UiN@1hN7P0MgMg07]kN`1jNWX0MGEe07QhN01cLg<0
OGem07UiN@1jNWX0MWIf07QhN01oOgl0MgMg07UiN@1mOGd0MgMg07alO00307emO@0B07]kN`1hN7P0
MgMg07alO01kNg/0PH610820P01oOgl0OWin08:2PP20P800Ph>308B4Q01oOgl0PH6108>3P`25QHD0
Q8B40P26QXH03`2:RXX0QhN708F5Q@1jNWX0L71`05mOG`1BDU80?Shn02l_;`0a<C40<30`02XZ:P0X
:2P0<30`02/[:`03030`<00402d];@0Z:RX0<C4a03De=@h0b>3H000<0<SPf080WYjN00H0WinO09fM
W@2KVi/0WYjN09fMW@2JVYX309jNWP0909nOW`2KVi/0W9bL09ZJVP2[Zj/0WIfM09^KV`2MWId0WYjN
0080W9bL00L0VYZJ09bLW02FUYH0Vi^K09NGU`2OWil0UiNG0080WIfM00L0X:2P0:BTY02RXZ80Xj>S
0:JVYP2XZ:P0Y:BT00<0ZJVY01`0Zj^[0:b/[02/[:`0ZJVY0:JVYP2WYjL0YZJV0:VYZ@2XZ:P0XZ:R
0:FUY@2PX:00WinO09bLW02KVi/0V9RH08n?S`2>SXh0Ph>30820P01iNGT0M7Ad06i^KP1`L700IFEU
05aLG01MGEd0FEUI0P1LG5`305]KF`07069RHP1YJFT0IfMW06UYJ@1TI6@0J6QX06MWI`0206][J`07
06m_K`1XJ6P0K6a/06][J`1ZJVX0JFUY06=SH`0206YZJP0L06MWI`1XJ6P0IfMW06UYJ@1WIfL0K6a/
06][J`1VIVH0I6AT06EUI@1XJ6P0JVYZ06e]K@1_Kfl0KVi^06m_K`1^KVh0Kfm_075aL@1fMWH0LG5a
07AdM01eMGD0MgMg07QhN01iNGT0O7al07emO@80OWin00L0O7al0820P01mOGd0Ogmo0820P026QXH0
Ogmo00<0OWin00<0PH6107inOP21PH400P24Q8@07`1nOWh0Ogmo08>3P`24Q8@0Ogmo0861P@24Q8@0
Ogmo08J6QP21PH40PX:208N7Q`21PH40P82008>3P`21PH40Ph>30820P022PX80PH6107inOP21PH40
QXJ608F5Q@21PH40Ph>308N7Q`26QXH0Q8B40861P@27QhL00P24Q8@02023Ph<0QHF508Z:RP26QXH0
P82008R8R025QHD0PH610P25QHD01`23Ph<0PX:208:2PP23Ph<0Q8B408>3P`24Q8@00P22PX801P2:
RXX0PX:208B4Q020P800QXJ60820P080Q8B40180R8R808:2PP22PX80R8R808F5Q@24Q8@0Ph>308:2
PP26QXH0Q8B40861P@23Ph<0PH6108>3P`25QHD0PH6108N7Q`22PX8208J6QP0?0820P025QHD0QHF5
08:2PP21PH40PX:208>3P`22PX80QhN70861P@22PX80Q8B407moO`22PX80Q8B40080Ph>300<0Q8B4
0861P@1nOWh00P25QHD00`23Ph<0Q8B408:2PP0208B4Q00808:2PP26QXH0QhN708>3P`27QhL0R8R8
08V9R@27QhL20861P@0<0820P028R8P0R8R807moO`21PH40Ph>30820P021PH40QHF50820P026QXH0
PH610P23Ph<208F5Q@0808J6QP24Q8@0OWin07inOP23Ph<0P82008:2PP1oOgl207inOP0@0820P01n
OWh0OWin0861P@1oOgl0O7al0861P@22PX80Ph>308:2PP24Q8@0O7al0861P@24Q8@0OWin0820P080
Ph>300<0PH6107moO`1lO7`00P21PH409P28R8P0P8200861P@21PH40PX:20861P@22PX80NWYj07mo
O`1kNg/0NGUi07YjNP1hN7P0M7Ad07EeM@1dM7@0K6a/07=cL`1dM7@0OWin06][J`1_Kfl0L71`06QX
J01YJFT0J6QX06YZJP1YJFT0Kfm_079bLP1iNGT0P82008R8R029RHT0T92@09:BTP2DU9@0UiNG0P2H
V9P05@2IVIT0WYjN09bLW02PX:00WinO0:2PX02OWil0X:2P0:BTY02OWil0XJ6Q0:>SX`2PX:00WinO
09bLW02QXJ40X:2P0::RXP2QXJ40WinO0:6QX@020:>SX`050:BTY02SXj<0X:2P09jNWP2OWil00P2N
WYh01@2PX:00W9bL09^KV`2LW9`0WIfM0080Vi^K00@0WYjN09JFUP2JVYX0V9RH0P2JVYX209fMW@<0
VYZJ00<0XZ:R09bLW02IVIT00`2GUiL00`2EUID0UiNG09NGU`0209RHV00409ZJVP2GUiL0VIVI09ZJ
VP80V9RH0100VIVI09BDU02FUYH0UYJF096AT@2IVIT0[:b/0;Zj^P33`l<0bLW90<k>cP3Bd]80eMGE
0=OGe`3Hf=P0f][J0`3Kfm/02@3Lg=`0fm_K0=KFeP3@d=00a/K60;^k^`2TY:@0SXj>071`L00206UY
J@0?06e]K@1XJ6P0KVi^06e]K@1/K6`0Jf][071`L01iNGT0M7Ad07IfMP1bLW80Lg=c07IfMP1jNWX0
Ng]k0080M7Ad00@0N7Qh07MgM`1nOWh0OWin0P1iNGT0301gMgL0NGUi07]kN`1nOWh0NWYj07]kN`1h
N7P0Ng]k07emO@1hN7P0NWYj07]kN`<0NGUi00`0OWin07UiN@1jNWX0OWin07emO@1lO7`0Ng]k07em
O@1oOgl0NGUi07moO`1nOWh207moO`0D08:2PP1mOGd0PX:208F5Q@24Q8@0QHF50861P@29RHT0S8b<
08J6QP1kNg/0L71`06ATI01DE5@0@41003De=@0c<c<0:RXZ02/[:`0b<S8202h^;P0602d];@0[:b/0
=CDe02h^;P0g=cL0<30`3P38h=P000`0b>3H0P2NWYh00`2OWil0Vi^K09^KV`0209jNWP0609bLW02M
WId0W9bL09NGU`2PX:00WIfM0P2LW9`209^KV`0409nOW`2KVi/0Vi^K09RHV080Vi^K00<0VYZJ09RH
V02LW9`00P2IVIT0102KVi/0VIVI09bLW02MWId20:2PX0060:FUY@2VYZH0YjNW0:NWY`2ZZZX0YjNW
0P2XZ:P20:NWY`0J0:ZZZP2XZ:P0Zj^[0:VYZ@2VYZH0Z:RX0:FUY@2TY:@0YJFU0:6QX@2JVYX0WYjN
09RHV02@T900TI6A08J6QP22PX80OGem07moO`1aLG40Jf][06=SH`1KFe/0GUiN05UIF@1HF5P2061P
H00705eMG@1OGel0I6AT06ATI01YJFT0IVIV065QH@0206QXJ00A06MWI`1/K6`0Jf][06a/K01WIfL0
K6a/06i^KP1ZJVX0IfMW07=cL`1YJFT0IVIV06EUI@1SHf<0J6QX06YZJP1]KFd00P1VIVH0201RHV80
IVIV06ATI01YJFT0JVYZ06i^KP1YJFT0LG5a0P1bLW803@1cLg<0LW9b07QhN01eMGD0MgMg07IfMP1h
N7P0Ng]k07alO01jNWX0OGem07]kN`1oOgl00`1iNGT00`1lO7`0Q8B407alO00207moO`0707emO@1l
O7`0PH610861P@1nOWh0Ogmo07alO00207moO`0708J6QP21PH40QHF50861P@26QXH0OWin08B4Q002
0820P00308F5Q@24Q8@0PH6100D0PX:200X0OWin08J6QP21PH40Ph>308B4Q020P800Ph>30820P024
Q8@0Ph>30`22PX802023Ph<0PH6108>3P`2<S8`0QhN708>3P`26QXH0QHF51022PX803P26QXH0Q8B4
08J6QP24Q8@0QHF508>3P`21PH40QhN708R8R025QHD0P8200861P@22PX80P8200P24Q8@01028R8P0
QHF508N7Q`26QXH208B4Q00708J6QP28R8P0Ogmo08J6QP28R8P0OWin08F5Q@0208:2PP0@08N7Q`26
QXH0Ogmo07moO`24Q8@0Ph>308J6QP1nOWh0PX:20861P@25QHD0PX:208B4Q01oOgl0Q8B408:2PP80
QXJ600L0P82007inOP24Q8@0PH6108>3P`21PH40OWin0080Ph>30100QXJ60861P@21PH40QXJ60861
P@25QHD0RXZ:08B4Q025QHD0RHV908:2PP29RHT0OWin0861P@22PX80Ph>30P25QHD02023Ph<0PH61
0820P028R8P0PH6108:2PP24Q8@0Ph>30`22PX800`1oOgl0PX:208R8R0020820P00A08B4Q021PH40
PH6108B4Q01nOWh0P82007inOP1mOGd0PX:207inOP1mOGd0PH6107emO@1oOgl0P82007moO`21PH40
0P20P8000`1kNg/0Ph>30861P@0208>3P`0307emO@25QHD0PX:20080PH6100d0Q8B407inOP26QXH0
OGem07]kN`1hN7P0NGUi07YjNP22PX80O7al07YjNP1iNGT0MgMg00<0MGEe00L0Jf][07=cL`1`L700
Kfm_07AdM01YJFT0KFe]0080Jf][00X0IfMW06QXJ01]KFd0LG5a07IfMP1gMgL0Ogmo08V9R@2=SHd0
TI6A0P2CTi<01@2FUYH0UiNG09ZJVP2JVYX0W9bL0080X:2P00H0YJFU0:6QX@2NWYh0XZ:R0:6QX@2P
X:0409nOW`80X:2P00L0XJ6Q09nOW`2QXJ40YJFU0:BTY02SXj<0X:2P0080YJFU00H0Xj>S0::RXP2N
WYh0WIfM09bLW02KVi/209fMW@0309^KV`2GUiL0VYZJ0080WIfM00@0VYZJ09fMW@2KVi/0UiNG0P2J
VYX01P2LW9`0Vi^K09^KV`2LW9`0VIVI09RHV0<0UiNG00<0V9RH09VIV@2GUiL00P2JVYX0102HV9P0
VIVI09VIV@2IVIT209RHV00409bLW02IVIT0UiNG09VIV@80U9BD00L0Xj>S0;Bd]031`L40alO70<k>
cP3@d=00eMGE0080emOG00<0fMWI0=[JfP3Jf]X00P3Jf]X02@3Kfm/0f=SH0=?Cd`3<c<`0`<300;2`
/02DU9@0NWYj06MWI`0206][J`0406a/K01ZJVX0JVYZ06e]K@<0L71`0P1fMWH0401`L700LW9b07Ee
M@1aLG40N7Qh07EeM@1jNWX0NGUi07EeM@1jNWX0O7al07YjNP1hN7P0NWYj07]kN`1fMWH207QhN009
07=cL`1hN7P0O7al07]kN`1lO7`0MgMg07EeM@1hN7P0NWYj0080OWin02<0OGem07UiN@1iNGT0Ogmo
07inOP1mOGd0PH6107emO@1jNWX0OGem07inOP1kNg/0NWYj07emO@1jNWX0OGem07inOP21PH40P820
08F5Q@21PH40Q8B408>3P`28R8P0Ph>307alO01aLG40IfMW05UIF@12@T80=SHf02l_;`0b<S80B4Q8
03@d=002030`<00502l_;`0f=SH0=3@d034a<@0c<c<03P38h=P000`0b>3H102MWId05`2PX:00WIfM
09bLW02LW9`0WinO09^KV`2JVYX0WYjN09bLW02KVi/0VYZJ0:2PX02OWil0Vi^K09jNWP2HV9P0WYjN
0:2PX02FUYH0Vi^K09ZJVP2KVi/0V9RH0080Vi^K0P2MWId01@2JVYX0WIfM09nOW`2OWil0Y:BT00<0
YZJV00<0Z:RX0:^[Z`2YZJT00P2WYjL0202][Jd0Zj^[0:VYZ@2XZ:P0ZJVY0:RXZ02YZJT0YZJV0P2S
Xj<209jNWP0>09BDU02BTY80S8b<08R8R026QXH0Ng]k07=cL`1]KFd0JFUY06MWI`1KFe/0EeMG05]K
F`1PH60205aLG00805UIF@1PH600Hf=S06ATI01WIfL0IVIV06=SH`1[Jf/306UYJ@0:06m_K`1^KVh0
JVYZ06YZJP1]KFd0Jf][075aL@1/K6`0IFEU06UYJ@80IfMW00@0Jf][06UYJ@1VIVH0I6AT0P1WIfL0
3@1ZJVX0IVIV06UYJ@1_Kfl0LG5a071`L01^KVh0LW9b07=cL`1bLW80MgMg07YjNP1iNGT00P1dM7@0
0`1hN7P0Ng]k07UiN@0207MgM`0307UiN@1jNWX0NWYj0080OWin00<0O7al07moO`1mOGd00P1mOGd0
1P20P800NWYj0820P01mOGd0P82008:2PP<0P8200100Ph>308B4Q024Q8@0Ph>308J6QP21PH40QHF5
08>3P`25QHD0QXJ608F5Q@22PX80QHF508:2PP21PH40Ph>30P20P8004024Q8@0QHF508J6QP21PH40
O7al08N7Q`21PH40Q8B408>3P`26QXH0Ogmo08B4Q023Ph<0QHF508J6QP27QhL208Z:RP0<08B4Q028
R8P0Ph>308V9R@25QHD0PX:207moO`23Ph<0PH6108V9R@25QHD0Ph>30P22PX806@28R8P0QHF508N7
Q`21PH40OWin0861P@22PX80QhN708B4Q01nOWh0R8R808J6QP23Ph<0P82008>3P`26QXH0Q8B40820
P027QhL0Ph>308F5Q@24Q8@0Ph>308:2PP24Q8@00P21PH403`26QXH0PX:20861P@1oOgl0QHF508B4
Q022PX80Ph>30820P01oOgl0PH610820P022PX80QXJ608B4Q0020861P@0408F5Q@22PX80O7al0820
P080PX:200D0QXJ60820P024Q8@0RHV908R8R00208J6QP0<08^;R`25QHD0QHF508:2PP27QhL0PX:2
0861P@22PX80Q8B408>3P`22PX80Ph>30`24Q8@09`23Ph<0P82008:2PP23Ph<0OWin08>3P`2;Rh/0
P82008R8R023Ph<0OWin07moO`22PX80Ogmo07inOP26QXH0PH6108:2PP1nOWh0PH610820P01nOWh0
Ogmo08>3P`1mOGd0Ogmo08B4Q01oOgl0Ph>307inOP1lO7`0F5QH07inOP20P800Q8B40861P@1nOWh0
PH6108B4Q00207moO`80PX:201<0PH6107alO021PH40Ogmo07QhN01lO7`0OGem07YjNP1oOgl0O7al
07EeM@1aLG40N7Qh06m_K`1YJFT0KVi^06e]K@1aLG40LW9b0080L71`00T0Jf][06MWI`1TI6@0IfMW
06][J`1eMGD0O7al08>3P`25QHD00P2>SXh02@2@T900Shn?09BDU02IVIT0VYZJ09VIV@2KVi/0WIfM
0::RXP020:6QX@070::RXP2NWYh0WIfM09bLW02PX:00Vi^K09fMW@0309bLW00;09fMW@2TY:@0WinO
0:2PX02RXZ80XJ6Q0:>SX`2MWId0XZ:R0:>SX`2PX:000P2OWil0202NWYh0VYZJ09nOW`2JVYX0Vi^K
0::RXP2HV9P0WIfM0P2KVi/01`2OWil0Vi^K09ZJVP2KVi/0VYZJ09JFUP2LW9`00P2JVYX02@2LW9`0
VIVI09JFUP2KVi/0V9RH09NGU`2LW9`0UIFE09JFUP0209^KV`0909VIV@2FUYH0VIVI09JFUP2HV9P0
UYJF09RHV02DU9@0Ti>C0080UYJF00`0Vi^K0:VYZ@2j^[X0a<C40<W9b@3>c/h0d];B0=GEe@3Fe]H0
emOG0=WIf@3Jf]X20=_Kf`0G0=gMg@3Hf=P0f=SH0<k>cP35aLD0];Bd09bLW024Q8@0Jf][06MWI`1[
Jf/0JFUY06i^KP1dM7@0Lg=c06a/K01dM7@0Lg=c071`L01dM7@0O7al075aL@1gMgL00P1fMWH02@1k
Ng/0MgMg07AdM01lO7`0MWIf07YjNP1hN7P0Ng]k07QhN00207emO@0307MgM`1iNGT0NWYj0080O7al
00L0MWIf07YjNP1mOGd0MWIf07YjNP1hN7P0Ng]k0080Ogmo0P1kNg/02@1mOGd0O7al07]kN`1lO7`0
OGem07IfMP1jNWX0O7al07emO@0208:2PP0;07inOP1lO7`0Ogmo08:2PP1oOgl0OWin07emO@1nOWh0
PH6108F5Q@29RHT00P25QHD0401lO7`0M7Ad06e]K@1OGel0AdM703Ti>@0l?3`0@T92034a<@0Z:RX0
:2PX02d];@0/;2`0<S8b034a<@0b<S8>0<SPf0003038h=P209jNWP0B09fMW@2LW9`0WIfM09VIV@2O
Wil0W9bL0:6QX@2NWYh0X:2P09fMW@2LW9`0VIVI09bLW02[Zj/0W9bL09^KV`2RXZ80Vi^K0P2MWId2
09jNWP0809NGU`2KVi/0V9RH09RHV02IVIT0VYZJ09NGU`2MWId209bLW0080:>SX`2UYJD0XZ:R0:>S
X`2WYjL0[:b/0:ZZZP2YZJT20:^[Z`80ZZZZ0P2UYJD06P2/[:`0Y:BT0:^[Z`2WYjL0YZJV0:NWY`2R
XZ80WinO09FEU@2=SHd0Rh^;08V9R@22PX80OGem07EeM@1/K6`0IVIV06ATI01OGel0E5AD05YJFP1I
FET0EeMG065QH@1OGel0FEUI0P1QHF401@1TI6@0IFEU06MWI`1[Jf/0JFUY0080IfMW01H0JFUY06YZ
JP1YJFT0KFe]06][J`1/K6`0Jf][06QXJ01[Jf/0I6AT06IVIP1QHF40JFUY06MWI`1UIFD0IVIV06UY
J@1WIfL0IVIV06=SH`1YJFT0K6a/0P1bLW804@1]KFd0M7Ad071`L01cLg<0LW9b07IfMP1gMgL0N7Qh
07EeM@1hN7P0NWYj07UiN@1kNg/0NWYj07]kN`20P800NWYj0080PX:200<0NGUi07emO@1nOWh00P1l
O7`00`22PX80Ogmo07alO00207moO`0708Z:RP1oOgl0PH610861P@24Q8@0Ph>30861P@0208B4Q00@
08J6QP22PX80QhN708>3P`22PX80PH6107moO`20P800Ph>30820P024Q8@0Ph>307inOP1oOgl0Ph>3
08N7Q`80P8200180Ogmo05iNGP23Ph<0QhN708R8R021PH40QHF508J6QP24Q8@0Ph>308F5Q@24Q8@0
QHF508N7Q`26QXH0Q8B408>3P`25QHD208:2PP0408B4Q026QXH0QHF508N7Q`80Ph>300L0QHF50820
P024Q8@0PX:208>3P`21PH40QhN70080Q8B40`21PH402022PX80QhN70861P@23Ph<0QHF508R8R021
PH40QHF50P24Q8@01025QHD0QhN708>3P`23Ph<208N7Q`0608:2PP25QHD0PX:208:2PP1nOWh0OGem
0P22PX800`1oOgl0Q8B40861P@0208B4Q080PH6100<0PX:208B4Q026QXH00P21PH402P24Q8@0OWin
08:2PP24Q8@0PX:208F5Q@22PX80R8R808N7Q`29RHT308F5Q@0308N7Q`23Ph<0QHF50080PH6100L0
RXZ:07moO`22PX80Ph>308:2PP1oOgl0Ph>30080PH6100T0Ph>308J6QP20P800Ph>308^;R`26QXH0
Q8B40820P022PX800P21PH420820P00507inOP24Q8@0PH6108>3P`21PH400P20P8002P1lO7`0PH61
08>3P`20P800O7al08J6QP1nOWh0Ogmo07]kN`1GEeL207emO@80P82000<0Ogmo07]kN`1kNg/00P22
PX802020P800Q8B408B4Q01oOgl0OGem07UiN@20P800OGem0P1hN7P01P1iNGT0NWYj07UiN@1cLg<0
M7Ad071`L0<0LG5a0P1_Kfl01`1[Jf/0Kfm_06YZJP1WIfL0IVIV06UYJ@1^KVh00P1iNGT01P21PH40
QHF508n?S`29RHT0Ti>C09:BTP80UYJF00L0UiNG09VIV@2KVi/0Xj>S09jNWP2OWil0X:2P00<0WYjN
00L0V9RH09^KV`2MWId0Vi^K0:2PX02IVIT0Vi^K0080WYjN00P0X:2P09bLW02NWYh0WinO0::RXP2S
Xj<0WinO0::RXP80X:2P0P2NWYh01`2LW9`0X:2P09^KV`2OWil0W9bL09RHV02LW9`00P2JVYX01`2M
WId0VYZJ09fMW@2JVYX0WIfM09^KV`2JVYX00P2IVIT04P2MWId0VYZJ09RHV02HV9P0WIfM09NGU`2H
V9P0VIVI09^KV`2JVYX0Vi^K09ZJVP2HV9P0W9bL09NGU`2PX:00VYZJ09>CT`<0UiNG02D0V9RH0:JV
YP2d];@0`l?30<W9b@3=cLd0d];B0=CDe03EeMD0f][J0=WIf@3Lg=`0fMWI0=_Kf`3Jf]X0fm_K0=WI
f@3Bd]80bLW90;Zj^P2WYjL0Shn?07AdM01YJFT0IfMW06YZJP1WIfL0JVYZ06][J`1^KVh0LG5a071`
L01fMWH0Lg=c079bLP1eMGD0Ng]k0080N7Qh00@0MWIf07QhN01iNGT0Ng]k0P1iNGT0401lO7`0NWYj
07QhN01eMGD0NWYj07moO`1dM7@0MWIf07YjNP1fMWH0O7al07MgM`1jNWX0PH6107UiN@1kNg/207Ui
N@80Ng]k0P1gMgL02@1hN7P0Ng]k07UiN@1iNGT0OWin07YjNP1iNGT0NWYj07alO0020820P00:07em
O@1lO7`0N7Qh07]kN`1oOgl0O7al0861P@1jNWX0P82008F5Q@80Ph>300P0RXZ:0820P021PH40O7al
06i^KP1OGel0BDU903`l?080<S8b00L0:2PX02h^;P0[:b/0<30`02l_;`0`<300<S8b00h0b>3H000<
0<SPf0<0W9bL0P2OWil01@2KVi/0UYJF09BDU02PX:00WinO0080WYjN00T0W9bL09^KV`2MWId0WYjN
09^KV`2OWil0WYjN09RHV02MWId00P2KVi/04`2JVYX0Vi^K09JFUP2HV9P0VYZJ09bLW02KVi/0VYZJ
09RHV02IVIT0WIfM09bLW02MWId0YZJV0::RXP2TY:@0YZJV0:RXZ02YZJT00P2ZZZX40:^[Z`050:b/
[02^[Zh0Zj^[0:ZZZP2VYZH00P2WYjL03`2PX:00Ti>C092@T02:RXX0QHF508:2PP1nOWh0M7Ad06YZ
JP1[Jf/0H61P05aLG01IFET0Fe]K05IFEP0205MGE`0;05iNGP1TI6@0GUiN06=SH`1VIVH0H61P06AT
I01XJ6P0IVIV06EUI@1VIVH00P1YJFT00`1WIfL0JFUY06a/K00206][J`80IVIV00@0J6QX06MWI`1W
IfL0JVYZ0P1XJ6P0101^KVh0IfMW06ATI01UIFD206QXJ00306][J`1aLG40Kfm_0080LW9b00<0Kfm_
079bLP1dM7@00P1dM7@207MgM`0=07UiN@1nOWh0Ng]k07moO`1lO7`0NWYj07emO@1lO7`0P82007mo
O`1lO7`0Ph>307inOP0307moO`0A08>3P`1nOWh0Ph>307emO@24Q8@0P82007inOP21PH40PX:20820
P01nOWh0P82008R8R022PX80Q8B408J6QP24Q8@00P22PX801`26QXH0PX:208:2PP23Ph<0QHF507in
OP22PX800P21PH402`25QHD0Ph>307moO`22PX80R8R80861P@24Q8@0QXJ608B4Q026QXH0Q8B40080
Ph>300H0QHF508B4Q026QXH0QXJ608>3P`25QHD208J6QP0>0861P@26QXH0QHF507inOP24Q8@0Ph>3
08N7Q`24Q8@0QHF50861P@23Ph<0Q8B408R8R025QHD208B4Q00@0820P025QHD0PX:208R8R024Q8@0
QHF50820P025QHD0Ph>308:2PP24Q8@0Ogmo08F5Q@22PX80Ph>308N7Q`80Q8B40`22PX801`23Ph<0
PX:208:2PP25QHD0PX:20861P@24Q8@00P25QHD04@1oOgl0PH6108:2PP22PX80R8R808:2PP25QHD0
PH610820P022PX80Ogmo08N7Q`20P800Ph>30861P@24Q8@0PX:200<0QHF500X0QXJ608b<S025QHD0
Q8B407moO`25QHD0P82008:2PP27QhL0O7al0P21PH403@1mOGd0PH6108N7Q`21PH40QHF50861P@27
QhL0Ph>308N7Q`1nOWh0QHF507moO`20P8000P22PX801`1oOgl0PX:20861P@20P800PH6108:2PP23
Ph<00P21PH402P1nOWh0Ph>30861P@21PH40OWin0861P@26QXH0P8200861P@1mOGd20861P@0608B4
Q021PH40PH610861P@22PX80PH610P22PX801P20P800O7al0861P@1oOgl0OGem0820P080OGem00H0
NWYj07MgM`1gMgL0NWYj07UiN@1dM7@2075aL@0F07EeM@1/K6`0KFe]06e]K@1^KVh0J6QX06a/K01X
J6P0K6a/06UYJ@1ZJVX0LW9b07MgM`20P800QHF508J6QP2;Rh/0SHf=096AT@2FUYH0U9BD09NGU`80
VIVI0`2PX:00202QXJ40W9bL09bLW02KVi/0W9bL09ZJVP2HV9P0X:2P0P2KVi/01`2IVIT0VYZJ09bL
W02NWYh0WIfM09nOW`2KVi/00P2NWYh0202OWil0WIfM09VIV@2NWYh0W9bL09^KV`2OWil0WYjN0P2L
W9`0102IVIT0Vi^K09NGU`2KVi/209ZJVP0609VIV@2MWId0Vi^K09jNWP2HV9P0VIVI0`2HV9P209VI
V@0409ZJVP2EUID0Ti>C09NGU`<0Vi^K00T0VIVI09jNWP2IVIT0UiNG09JFUP2GUiL0VIVI09^KV`2F
UYH00P2EUID01`2GUiL0Vi^K0:f][@2j^[X0a/K60<[:bP3@d=000P3De=@00`3Fe]H0emOG0=SHf002
0=[JfP0<0=gMg@3Jf]X0f=SH0=GEe@3<c<`0`<300;2`/02IVIT0P82006][J`1XJ6P0JVYZ0P1XJ6P0
2@1ZJVX0LG5a071`L01bLW80Kfm_07=cL`1eMGD0N7Qh07UiN@0207MgM`0D07]kN`1eMGD0NWYj07Ui
N@1hN7P0NWYj07emO@1hN7P0MGEe07YjNP1hN7P0NWYj07]kN`1iNGT0MgMg07QhN01eMGD0MgMg07Qh
N01mOGd207QhN00307]kN`1lO7`0N7Qh0080O7al0P1kNg/03@1lO7`0Ogmo07]kN`1lO7`0NGUi07al
O01iNGT0NWYj07alO01mOGd0Ogmo07]kN`1lO7`00P1mOGd01P1nOWh0OGem0820P01nOWh0PH6108F5
Q@80PH6100X0QXJ608N7Q`27QhL0O7al07MgM`1YJFT0EeMG04Q8B00h>3P0=CDe0P0/;2`01@0[:b/0
<30`02h^;P0];Bd0<30`00h0b>3H000<0<SPf0<0W9bL00D0X:2P09bLW02KVi/0Vi^K09RHV00209nO
W`80WIfM00h0WinO09ZJVP2NWYh0VYZJ09^KV`2NWYh0VIVI09fMW@2NWYh0W9bL09fMW@2JVYX0UiNG
09RHV080VYZJ00@0Vi^K09jNWP2FUYH0VIVI0`2KVi/01`2OWil0X:2P0:2PX02WYjL0YJFU0:^[Z`2W
YjL00P2XZ:P05P2YZJT0Zj^[0:f][@2][Jd0YZJV0:RXZ02ZZZX0YJFU0:RXZ02TY:@0Xj>S09jNWP2E
UID0T92@08j>SP24Q8@0R8R808>3P`1lO7`0LG5a06QXJ01QHF4205YJFP0805UIF@1JFUX0Fe]K05mO
G`1SHf<0JFUY065QH@1RHV8306ATI00606UYJ@1XJ6P0IfMW06EUI@1WIfL0JFUY0P1XJ6P01`1SHf<0
IfMW06IVIP1[Jf/0KVi^06YZJP1TI6@00P1WIfL02`1UIFD0IfMW06UYJ@1VIVH0IFEU06YZJP1^KVh0
K6a/06m_K`1`L700K6a/0080KFe]00/0LG5a07EeM@1hN7P0Lg=c07MgM`1kNg/0O7al07emO@1iNGT0
OGem07UiN@0207]kN`0707YjNP1kNg/0Ogmo07]kN`1mOGd0Ph>30861P@0207emO@0>0861P@25QHD0
Ogmo07inOP20P800Ogmo0820P026QXH0P82008B4Q023Ph<0P82007moO`23Ph<20861P@0J08>3P`25
QHD0Ph>308N7Q`23Ph<0OGem08>3P`1lO7`0Ph>30861P@22PX80PH6108:2PP26QXH0PX:20820P023
Ph<0QhN70861P@27QhL0QHF508Z:RP22PX80Q8B408J6QP25QHD208>3P`0408B4Q025QHD0QHF508B4
Q080QhN700L0QHF50861P@22PX80P82007moO`24Q8@0Ogmo0080Q8B400L0Ph>308N7Q`23Ph<0Q8B4
0861P@2:RXX0PX:20080PH6100T0PX:208>3P`25QHD0QXJ607moO`27QhL0PX:208J6QP21PH400P22
PX801@20P800PX:208R8R023Ph<0R8R80080Ogmo00h0PH6108>3P`22PX80OWin08:2PP1oOgl0OWin
0820P01oOgl0OGem08B4Q01mOGd0PH6107moO`@0PH6100@0QHF50861P@21PH40PX:20P23Ph<01P20
P800PH6108J6QP20P800PH610820P080Q8B400@0P82008:2PP25QHD0P8200P21PH400`24Q8@0Ogmo
0820P0020861P@0608>3P`22PX80P82008F5Q@21PH40Q8B41022PX8208>3P`0=0861P@1nOWh0PH61
07moO`1nOWh0PX:207emO@21PH40Ogmo0861P@20P800OWin0861P@0207inOP80P82000L0Ogmo07al
O020P800O7al08:2PP20P800Q8B40080P8201@21PH402P1oOgl0PH6108B4Q01oOgl0OWin07emO@1h
N7P0MgMg07]kN`1`L70207IfMP0^07YjNP1fMWH0L71`07=cL`1dM7@0LG5a06][J`1^KVh0JVYZ06i^
KP1ZJVX0IfMW06ATI01]KFd0LG5a07QhN01lO7`0PH6108R8R02<S8`0RXZ:08n?S`2DU9@0UYJF09NG
U`2KVi/0VYZJ09nOW`2PX:00XZ:R09nOW`2SXj<0Vi^K09ZJVP2NWYh0VYZJ09NGU`2JVYX0W9bL09RH
V02GUiL0Vi^K09fMW@2KVi/0X:2P0:6QX@80WYjN00P0WIfM09nOW`2PX:00W9bL09fMW@2KVi/0WIfM
09jNWP80Vi^K00@0WIfM09^KV`2KVi/0Vi^K0P2JVYX00`2OWil0VIVI09bLW00209fMW@80Vi^K0P2I
VIT209RHV00@09jNWP2JVYX0WYjN09JFUP2IVIT0Vi^K09fMW@2IVIT0UIFE09^KV`2JVYX0UiNG09RH
V02IVIT0VYZJ09^KV`80UYJF00T0UIFE09NGU`2KVi/0Z:RX0;Rh^032`/80b/[:0<k>cP3AdM400P3E
eMD03`3Hf=P0emOG0=WIf@3IfMT0f][J0=_Kf`3IfMT0e]KF0=3@d036a/H0]kNg0:FUY@2=SHd0Kfm_
06YZJP0206ATI00706YZJP1YJFT0K6a/06e]K@1_Kfl0Lg=c06i^KP0207EeM@0:07]kN`1jNWX0Lg=c
07MgM`1fMWH0MGEe07YjNP1lO7`0NGUi07EeM@80NGUi00H0MWIf07MgM`1hN7P0MgMg07QhN01eMGD2
07UiN@80MgMg00<0NGUi07QhN01iNGT00P1lO7`03`1mOGd0NWYj07]kN`1kNg/0MWIf07inOP1jNWX0
Ng]k07YjNP1iNGT0Ng]k07emO@1nOWh0O7al07YjNP0307alO00<07moO`1mOGd0PX:20861P@1kNg/0
OWin07emO@1lO7`0Ogmo0861P@24Q8@0R8R80P23Ph<03022PX80OWin079bLP1[Jf/0Fe]K04e=C@0m
?Cd0;bl_030`<00d=3@0;bl_02h^;P80<c<c3P38h=P000`0b>3H0P2KVi/01`2MWId0WYjN09^KV`2J
VYX0Vi^K09fMW@2QXJ400P2KVi/409fMW@0309RHV02LW9`0Vi^K0080VIVI00l0W9bL09fMW@2KVi/0
VIVI09NGU`2JVYX0VIVI09^KV`2JVYX0UiNG09^KV`2MWId0V9RH09JFUP2KVi/00P2SXj<01@2RXZ80
Y:BT0:JVYP2ZZZX0Z:RX0080ZZZZ00@0Z:RX0:ZZZP2][Jd0ZJVY0`2/[:`02P2YZJT0Z:RX0:ZZZP2P
X:00Vi^K09ZJVP2EUID0S8b<08Z:RP23Ph<207UiN@0Y075aL@1ZJVX0HF5Q05iNGP1KFe/0G5aL05YJ
FP1KFe/0FEUI05]KF`1QHF40GEeM06IVIP1WIfL0HV9R06=SH`1UIFD0IVIV06a/K01UIFD0JFUY06MW
I`1SHf<0J6QX06UYJ@1`L700JFUY06MWI`1[Jf/0JVYZ06UYJ@1XJ6P0IfMW06IVIP1SHf<0Jf][06MW
I`1SHf<0I6AT06i^KP1YJFT00`1]KFd00`1ZJVX0Lg=c079bLP0207AdM00A079bLP1eMGD0M7Ad07em
O@1gMgL0MWIf07alO01oOgl0N7Qh07alO01nOWh0O7al07QhN01nOWh0O7al07inOP20P8000P1nOWh0
2@22PX80P8200861P@1mOGd0P82008>3P`21PH40Ph>30861P@020820P0040861P@20P800R8R808:2
PP80Ph>300P0P82007moO`23Ph<0P82007moO`22PX80Ph>308B4Q080P82000D0PX:20820P023Ph<0
QHF508:2PP0208B4Q00K0861P@25QHD0Ph>308J6QP27QhL0RHV908J6QP29RHT0QhN708V9R@2:RXX0
QHF508B4Q025QHD0P82008F5Q@27QhL0S8b<0861P@24Q8@0QHF508B4Q022PX80R8R808Z:RP25QHD0
RHV90080Q8B400H0S8b<08F5Q@23Ph<0PX:20820P01lO7`208F5Q@0=0861P@23Ph<0Ph>308N7Q`24
Q8@0Ogmo07emO@1oOgl0Ph>30820P026QXH0Ph>308:2PP0207emO@0;08>3P`22PX80PX:20820P021
PH40O7al0820P01oOgl0P82007moO`21PH400P26QXH20861P@0408:2PP23Ph<0Q8B407inOP80O7al
0P20P8002P1nOWh0Ph>308>3P`22PX80P8200861P@23Ph<0Q8B408>3P`24Q8@208:2PP0308B4Q020
P800PX:20080P82001H0PH6108>3P`22PX80QHF508R8R022PX80PH6108B4Q025QHD0P82008>3P`25
QHD0P82008J6QP20P800OWin08:2PP1oOgl0PH6107emO@23Ph<0Ogmo0P21PH403@1oOgl0OGem07al
O01mOGd0Ogmo07]kN`1lO7`0P82007YjNP1lO7`0PH6107emO@22PX800P21PH401@1kNg/0OWin0820
P01oOgl0PX:20080N7Qh00<0Ng]k07emO@22PX800P1mOGd01P1lO7`0Ogmo07alO01mOGd0M7Ad07Mg
M`80N7Qh00<0LW9b07=cL`1`L7000P1_Kfl06P1aLG40IfMW06m_K`1YJFT0IfMW06IVIP1/K6`0Kfm_
07EeM@1fMWH0O7al08:2PP27QhL0S8b<08^;R`2@T900UIFE09JFUP2EUID0Vi^K09VIV@2NWYh0WIfM
0:6QX@2RXZ80X:2P0P2MWId04`2HV9P0WIfM09^KV`2JVYX0W9bL09ZJVP2HV9P0VYZJ0:6QX@2LW9`0
WinO09fMW@2KVi/0W9bL09^KV`2OWil0Vi^K09VIV@2HV9P00P2IVIT04P2JVYX0WIfM09bLW02MWId0
W9bL09ZJVP2IVIT0V9RH09ZJVP2HV9P0VYZJ09NGU`2KVi/0W9bL09JFUP2GUiL0VIVI09ZJVP80W9bL
01l0VYZJ09fMW@2LW9`0UiNG09jNWP2IVIT0Vi^K09ZJVP2NWYh0Vi^K09RHV02NWYh0U9BD09VIV@2J
VYX0VIVI09ZJVP2KVi/0UIFE09JFUP2QXJ40/k>c0;jn_P37alL0cLg=0=7Ad@3Cdm<0eMGE0=OGe`3H
f=P0fMWI0080f=SH00/0fMWI0=[JfP3GemL0e=CD0<c<c02m_Kd0[:b/09BDU01lO7`0KVi^06UYJ@02
06QXJ00506a/K01^KVh0LG5a071`L01cLg<00`1eMGD02P1fMWH0MgMg07YjNP1dM7@0N7Qh07MgM`1i
NGT0NWYj07MgM`1lO7`207MgM`0?0861P@1nOWh0N7Qh07YjNP1hN7P0MgMg07QhN01kNg/0NGUi07em
O@1jNWX0Ng]k07alO01nOWh0NWYj0080Ng]k00T0OGem07moO`1oOgl0Ng]k07EeM@1jNWX0OWin07al
O01iNGT00P1nOWh02`21PH40NWYj07YjNP1lO7`0OWin0861P@1mOGd0O7al07emO@1oOgl0OWin0080
Ogmo00<0OGem07inOP1mOGd00P23Ph<0401lO7`0PX:207moO`1nOWh0OGem07MgM`1YJFT0HF5Q059B
DP0k>c/0=CDe02h^;P0a<C40;bl_02h^;P0/;2`>0<SPf0003038h=P209^KV`80WYjN00`0WinO0:2P
X02MWId0WIfM0:>SX`2MWId0WinO0:2PX02OWil0VYZJ09bLW02MWId209^KV`0F0::RXP2NWYh0WIfM
09VIV@2LW9`0V9RH09bLW02KVi/0UiNG09VIV@2HV9P0UiNG09fMW@2JVYX0Vi^K09ZJVP2IVIT0W9bL
0:6QX@2PX:00Z:RX0:FUY@80ZZZZ0P2`/;003@2YZJT0[:b/0:VYZ@2ZZZX0[Zj^0:f][@2WYjL0Z:RX
0:ZZZP2UYJD0XZ:R0:2PX02GUiL00P2CTi<07029RHT0R8R807alO01hN7P0KVi^079bLP1QHF40GUiN
05YJFP1GEeL0F5QH05aLG01MGEd0GemO05iNGP1WIfL0Hf=S06QXJ01YJFT0IfMW06QXJ01VIVH0JFUY
06i^KP1[Jf/0IfMW06QXJ01UIFD206a/K080IVIV0280Jf][06UYJ@1[Jf/0IfMW06a/K01WIfL0IVIV
06e]K@1cLg<0IfMW06YZJP1[Jf/0IfMW079bLP1^KVh0LG5a06i^KP1bLW80KVi^079bLP1gMgL0MGEe
07MgM`1hN7P0NGUi07alO01gMgL0N7Qh07moO`1jNWX0OWin07emO@22PX80O7al0P1mOGd01021PH40
P82007YjNP1jNWX207inOP80PH6100l0OGem08F5Q@25QHD0QHF50861P@25QHD0Q8B408:2PP23Ph<0
Ogmo0861P@24Q8@0P8200861P@24Q8@00P22PX803P24Q8@0PH610820P01oOgl0Ph>30861P@22PX80
QXJ60861P@2;Rh/0P82008F5Q@24Q8@0PX:20`25QHD03`26QXH0Q8B408J6QP25QHD0RXZ:08J6QP22
PX80QHF508>3P`24Q8@0Ph>308N7Q`25QHD0R8R808:2PP0208F5Q@0<0861P@1nOWh0S8b<08>3P`27
QhL0P82008F5Q@23Ph<0Q8B408>3P`26QXH0QHF50P24Q8@01@25QHD0QhN708J6QP23Ph<0Q8B40080
PX:200P0R8R80861P@24Q8@0Q8B407]kN`25QHD0Ph>308J6QP80Ph>301<0R8R808J6QP22PX80P820
07emO@20P800O7al07moO`22PX80PH6108:2PP26QXH0R8R808F5Q@2;Rh/0Q8B408J6QP24Q8@0Ogmo
0080PX:200T0Ph>308B4Q023Ph<0Q8B40861P@24Q8@0QXJ608:2PP25QHD00P22PX801P25QHD0Ph>3
07inOP21PH40Q8B408:2PP<0QXJ602P0PH6108>3P`24Q8@0R8R808>3P`25QHD0Q8B407moO`20P800
Ph>307moO`1kNg/0Q8B408:2PP1oOgl0Ph>308:2PP1mOGd0O7al08B4Q01lO7`0Ogmo07inOP23Ph<0
P82007]kN`1nOWh0P82007]kN`22PX80OWin0861P@1oOgl0PH6108:2PP23Ph<0Ogmo0820P01nOWh0
P8200P22PX804@23Ph<0Ogmo07moO`1mOGd0OWin07alO020P800N7Qh07inOP20P800NWYj07inOP1j
NWX0MgMg07YjNP1dM7@0LG5a0080L71`01H0K6a/06m_K`1aLG40Kfm_06YZJP1VIVH0IfMW06][J`1Z
JVX0Lg=c07EeM@1iNGT0Ph>308J6QP28R8P0S8b<09>CT`2?Shl0VIVI09FEU@2HV9P0VYZJ0P2LW9`0
1`2NWYh0XZ:R09nOW`2NWYh0W9bL09ZJVP2KVi/0102IVIT0202GUiL0V9RH09VIV@2KVi/0W9bL09fM
W@2IVIT0W9bL0`2JVYX0202NWYh0W9bL09nOW`2KVi/0WIfM09jNWP2OWil0VIVI0P2MWId01@2JVYX0
W9bL09bLW02HV9P0VIVI0080VYZJ00H0V9RH09ZJVP2HV9P0VYZJ09bLW02KVi/209ZJVP80W9bL00@0
VIVI09ZJVP2LW9`0Vi^K0P2IVIT04@2MWId0W9bL09^KV`2KVi/0VIVI09bLW02HV9P0UiNG09ZJVP2H
V9P0UIFE09bLW02YZJT0^[Zj0<?3``3:b/X0cLg=0080dm?C02H0e=CD0=SHf03Hf=P0f][J0=SHf03I
fMT0fm_K0=SHf03EeMD0c<c<0<C4a02c/k<0WinO08:2PP1`L700IfMW06IVIP1]KFd0K6a/06YZJP1`
L700Kfm_07=cL`1aLG40M7Ad07IfMP1kNg/0MgMg07IfMP1mOGd0MgMg07UiN@1eMGD0NGUi07emO@1f
MWH0MgMg07YjNP80MgMg0140MWIf07alO01lO7`0O7al07QhN01fMWH0NGUi07YjNP1hN7P0O7al07em
O@1lO7`0OWin07emO@1kNg/0MWIf07]kN`0207inOP0407]kN`1iNGT0O7al07inOP80Ng]k00D0N7Qh
07alO01mOGd0Ng]k07inOP0207alO00607emO@20P800PH6107emO@20P800O7al0P20P8005@1oOgl0
P8200861P@1oOgl0OGem0820P022PX80OGem07moO`20P800PH6107]kN`1/K6`0GUiN04U9B@10@400
<30`038b<P0^;Rh0;bl_034a<@0>0<SPf0003038h=P209nOW`0709^KV`2MWId0WYjN09nOW`2LW9`0
WIfM09nOW`020::RXP0;0:2PX02IVIT0VIVI09VIV@2GUiL0Vi^K09ZJVP2LW9`0VIVI09^KV`2IVIT0
0P2HV9P209ZJVP0?09VIV@2GUiL0V9RH09RHV02IVIT0VYZJ09bLW02MWId0V9RH09VIV@2MWId0WYjN
0:BTY02RXZ80Z:RX00<0ZJVY00@0ZZZZ0:n_[`2][Jd0[Jf]0P2[Zj/01`2_[jl0ZZZZ0:b/[02VYZH0
Y:BT0:>SX`2JVYX00P2FUYH01P28R8P0QHF507alO01iNGT0LW9b06i^KP80GUiN00D0FUYJ05=CD`1F
EUH0EUIF05QHF00205eMG@0G06ATI01QHF40IFEU06UYJ@1^KVh0JVYZ06e]K@1ZJVX0J6QX06MWI`1U
IFD0Hf=S06UYJ@1ZJVX0K6a/06EUI@1WIfL0IVIV06=SH`1ZJVX0IfMW06UYJ@1[Jf/00P1WIfL01`1[
Jf/0JVYZ06YZJP1YJFT0Jf][06UYJ@1]KFd00`1`L7001P1aLG40Lg=c07=cL`1gMgL0NGUi07YjNP80
OGem00/0OWin0820P01oOgl0O7al0820P01mOGd0Ng]k07YjNP21PH40N7Qh07]kN`0307moO`0E08B4
Q01oOgl0P8200861P@1oOgl0PH6108>3P`22PX80Ph>308:2PP24Q8@0OWin08B4Q026QXH0Ogmo08B4
Q026QXH0QHF508J6QP23Ph<0QXJ600<0Ph>30`21PH401@26QXH0QHF50820P023Ph<0PH610080Ph>3
0P24Q8@208J6QP0308B4Q028R8P0QHF50080PX:200<0QHF508R8R026QXH00P23Ph<01@24Q8@0PX:2
08>3P`24Q8@0QXJ60080Q8B400@0PH6108>3P`24Q8@0Q8B40P22PX801P24Q8@0QXJ608:2PP27QhL0
PH6108J6QP80Ph>300<0Q8B408J6QP25QHD00P22PX801@24Q8@0Ogmo08J6QP25QHD0Ogmo0080RHV9
0P21PH402@2<S8`0R8R808R8R024Q8@0PX:208V9R@23Ph<0PX:20861P@0208:2PP090861P@20P800
P8200861P@28R8P0RHV908:2PP24Q8@0Ph>30080PH6100L0Q8B407inOP1mOGd0P82008B4Q025QHD0
PH610080QXJ600<0Q8B408F5Q@25QHD00P25QHD03`1oOgl0PX:208F5Q@22PX80OGem08:2PP27QhL0
QHF508B4Q025QHD0R8R808>3P`24Q8@0Ph>308F5Q@0208:2PP0=0861P@1oOgl0P82008:2PP21PH40
P82008J6QP22PX80Ogmo0861P@20P800Ogmo07emO@0208:2PP0;0861P@1nOWh0P82007alO025QHD0
P82008:2PP24Q8@0P8200861P@23Ph<00`22PX800`23Ph<0OGem08:2PP0208:2PP80OGem0180PH61
07inOP1mOGd0PX:207alO01nOWh0NWYj07QhN01eMGD0MWIf07UiN@1hN7P0M7Ad07MgM`1`L700LG5a
07=cL`1_Kfl206YZJP0Z06e]K@1SHf<0IFEU075aL@1dM7@0NWYj07]kN`1nOWh0R8R808V9R@2=SHd0
Shn?096AT@2DU9@0W9bL09RHV02JVYX0Vi^K09fMW@2NWYh0Xj>S0:2PX02OWil0X:2P09^KV`2NWYh0
W9bL09BDU02HV9P0UIFE09NGU`2KVi/0VIVI09>CT`2IVIT0VYZJ09RHV02JVYX0V9RH09VIV@2GUiL0
Vi^K0P2IVIT04P2QXJ40W9bL09VIV@2KVi/0VYZJ09bLW02JVYX0VIVI09ZJVP2IVIT0UYJF09VIV@2H
V9P0Vi^K09ZJVP2GUiL0VYZJ09^KV`<0UiNG0P2HV9P02@2GUiL0Vi^K09NGU`2KVi/0VYZJ09RHV02J
VYX0XJ6Q09fMW@0209jNWP0?09bLW02IVIT0W9bL09VIV@2KVi/0UiNG09FEU@2FUYH0YJFU0;Bd]032
`/80bLW90<g=c@3@d=00dm?C00<0emOG0P3IfMT30=[JfP0/0=OGe`3AdM40bLW90;^k^`2YZJT0SHf=
07YjNP1VIVH0HF5Q06MWI`1XJ6P0Kfm_06a/K01bLW80LG5a07EeM@1bLW80MWIf07MgM`1bLW80M7Ad
07MgM`1dM7@0MgMg07IfMP1iNGT0M7Ad07]kN`1gMgL0MWIf07UiN@1lO7`0Ng]k07inOP1iNGT0OWin
07alO01kNg/0O7al07MgM`1kNg/0NWYj07alO01oOgl207alO00407emO@1oOgl0OGem07YjNP80P820
00T0OGem07QhN01lO7`0Ng]k07MgM`1nOWh0Ng]k07UiN@1mOGd00P1iNGT02`1gMgL0NWYj07inOP1n
OWh0P8200861P@20P800NWYj07moO`21PH40Ph>30080P8200P1mOGd0401kNg/0O7al07QhN020P800
PH6107inOP1oOgl0O7al079bLP1NGUh0De=C04I6AP13@d<0<S8b03Lg=`0_;bl>0<SPf0003038h=P2
0:2PX00:0:>SX`2NWYh0X:2P0::RXP2OWil0W9bL09nOW`2SXj<0WYjN0:>SX`80Vi^K00@0W9bL09RH
V02IVIT0X:2P0P2JVYX0102NWYh0UYJF09^KV`2HV9P209ZJVP0709RHV02JVYX0UiNG09FEU@2IVIT0
X:2P09jNWP0209^KV`0709ZJVP2OWil0WinO0:BTY02VYZH0Z:RX0:NWY`020:VYZ@@0Zj^[00@0[Zj^
0:b/[02][Jd0ZJVY0P2WYjL02@2VYZH0WinO09bLW02DU9@0TI6A08Z:RP22PX80NWYj07inOP0206][
J`09065QH@1RHV80FEUI05iNGP1KFe/0Hf=S05aLG01SHf<0HF5Q0080H61P0P1XJ6P03P1]KFd0Kfm_
06QXJ01VIVH0Hf=S06YZJP1WIfL0JVYZ06EUI@1ZJVX0IVIV069RHP1VIVH0J6QX0`1/K6`01P1UIFD0
Jf][06QXJ01ZJVX0Jf][06QXJ080IVIV00H0Lg=c06MWI`1/K6`0Jf][06m_K`1aLG4207QhN00307=c
L`1gMgL0MGEe0080N7Qh00@0Ng]k0820P01iNGT0O7al0P1kNg/01`1mOGd0MgMg07emO@1lO7`0NWYj
0861P@24Q8@00P25QHD20861P@0:08:2PP26QXH0QhN707emO@21PH40OWin08N7Q`21PH40QHF508B4
Q080PH6100<0Ng]k08B4Q01nOWh00P25QHD208:2PP0608>3P`1oOgl0OGem08J6QP22PX80OWin1022
PX802@26QXH0Ph>308R8R026QXH0QhN708F5Q@28R8P0QHF508B4Q00208J6QP0708B4Q026QXH0QXJ6
08Z:RP23Ph<0QHF508N7Q`0208>3P`0508J6QP23Ph<0QXJ607moO`25QHD00P21PH404022PX80Ph>3
08>3P`25QHD0Ogmo08N7Q`26QXH0QhN708J6QP25QHD0Ph>308F5Q@23Ph<0R8R808J6QP24Q8@208F5
Q@080820P025QHD0QHF508R8R026QXH0Ph>308V9R@25QHD208Z:RP0808:2PP1mOGd0Q8B408>3P`20
P800OWin08>3P`26QXH20820P00>08>3P`22PX80QHF508B4Q028R8P0RXZ:0861P@20P800Q8B408>3
P`22PX80OWin08:2PP24Q8@208>3P`0808B4Q026QXH0PX:208N7Q`24Q8@0QXJ608F5Q@1oOgl208B4
Q00A08:2PP21PH40Q8B408R8R023Ph<0PH6108>3P`27QhL0QXJ608B4Q025QHD0PX:20861P@1nOWh0
Ph>307emO@22PX800P1nOWh01`21PH40Q8B408>3P`1oOgl0Ng]k08B4Q021PH400P20P800101nOWh0
Ogmo07inOP20P80207moO`0>0820P023Ph<0QHF507emO@23Ph<0P82008:2PP20P800OWin0861P@1n
OWh0Ogmo0861P@22PX830861P@030820P01kNg/0OGem0080Ng]k00H0NWYj07alO01jNWX0Ng]k07in
OP1gMgL207AdM004071`L01^KVh0Kfm_06i^KP80IfMW01L0J6QX06IVIP1VIVH0LW9b07IfMP1jNWX0
OWin07emO@24Q8@0RHV908f=S@2ATI40UYJF092@T02FUYH0VYZJ09fMW@2NWYh0WIfM09jNWP2OWil0
Xj>S09fMW@0209^KV`0309ZJVP2GUiL0V9RH0080V9RH0P2IVIT02P2HV9P0UiNG09NGU`2MWId0V9RH
09jNWP2EUID0VYZJ09RHV02NWYh209^KV`0509bLW02JVYX0VIVI09VIV@2GUiL00P2IVIT03P2GUiL0
VIVI09NGU`2JVYX0W9bL09fMW@2KVi/0VYZJ09^KV`2HV9P0VYZJ09VIV@2HV9P0UiNG0P2JVYX07P2H
V9P0VYZJ09jNWP2KVi/0VYZJ09bLW02KVi/0WIfM09VIV@2MWId0WYjN09ZJVP2LW9`0Vi^K09ZJVP2G
UiL0UYJF09RHV02QXJ40[Zj^0<71`@37alL0bl_;0<o?c`3Cdm<0e=CD0=KFeP3Hf=P0fMWI0=[JfP80
g=cL01h0fm_K0=WIf@3De=@0cLg=0<?3``2b/[80Vi^K08:2PP1/K6`0JVYZ06ATI01VIVH0IfMW06e]
K@1YJFT0LG5a07EeM@1dM7@0Lg=c07MgM`1lO7`0MWIf07=cL`1hN7P0NWYj07UiN@1fMWH0NGUi07Yj
NP1oOgl207YjNP0307alO01mOGd0OWin0080N7Qh00d0MWIf07UiN@1mOGd0NGUi07alO01jNWX0OWin
07IfMP1jNWX0PH6107emO@1lO7`0Ng]k0080Ogmo0P1hN7P02@1mOGd0NWYj07YjNP1jNWX0MWIf07in
OP1mOGd0NWYj07emO@0207YjNP0807]kN`1nOWh0Ng]k07emO@1oOgl0NGUi07YjNP1kNg/207emO@09
07inOP1mOGd0OWin07inOP1lO7`0MgMg07QhN01fMWH0Ogmo0080OWin00X0PX:20861P@1oOgl0OWin
07UiN@1`L700G5aL04m?C`10@400>SXj3P38h=P000`0b>3H0P2TY:@00`2NWYh0Vi^K0:6QX@0209nO
W`050:2PX02QXJ40X:2P09^KV`2OWil00P2JVYX01`2LW9`0VYZJ09bLW02LW9`0VIVI09fMW@2HV9P0
0P2IVIT00`2FUYH0W9bL09bLW00209ZJVP0309bLW02HV9P0Vi^K0080WIfM00H0VIVI09RHV02GUiL0
WIfM09nOW`2QXJ420:FUY@0:0:RXZ02ZZZX0ZZZZ0:ZZZP2[Zj/0[Jf]0;2`/02[Zj/0ZZZZ0;2`/080
Zj^[01X0Z:RX0:NWY`2NWYh0WYjN09JFUP2CTi<0T92@0861P@1kNg/0MgMg06m_K`1^KVh0IVIV061P
H01LG5`0GemO05UIF@1OGel0H61P065QH@1VIVH0IFEU06=SH`1TI6@0K6a/06QXJ080JVYZ01T0JFUY
06][J`1/K6`0JFUY06ATI01ZJVX0J6QX06a/K01ZJVX0I6AT06UYJ@1XJ6P0JVYZ06a/K01YJFT0IVIV
06a/K01XJ6P0Kfm_06MWI`1YJFT0Jf][06m_K`1XJ6P0K6a/0080Kfm_00@0LW9b07MgM`1cLg<0MWIf
0P1hN7P0101jNWX0MgMg07UiN@1lO7`207YjNP050820P01mOGd0NWYj07emO@1nOWh00P1lO7`02`1m
OGd0O7al08:2PP22PX80QHF508>3P`21PH40QHF508:2PP21PH40Ogmo0080QHF500<0PH610820P027
QhL00P23Ph<208B4Q00807emO@20P800PX:208:2PP25QHD0Ph>308:2PP1oOgl30861P@0908V9R@27
QhL0QhN708F5Q@22PX80QhN708J6QP29RHT0QhN70080RXZ:00H0R8R808J6QP26QXH0QHF508V9R@26
QXH208R8R00=08B4Q026QXH0QXJ608Z:RP26QXH0Ph>308B4Q01oOgl0QHF508N7Q`1nOWh0PX:208B4
Q00208>3P`0308F5Q@26QXH0QXJ600@0QHF50100QXJ608B4Q022PX80QhN708J6QP28R8P0QHF508B4
Q025QHD0Q8B408R8R023Ph<0QXJ608N7Q`29RHT0P8200P24Q8@01P20P800PH6107moO`1nOWh0P820
08B4Q080Ph>300d0PH6108B4Q024Q8@0Ogmo07inOP23Ph<0Q8B408Z:RP21PH40Ng]k0861P@22PX80
PH610080PX:20P20P8004`28R8P0PX:208F5Q@23Ph<0QhN708B4Q023Ph<0QXJ60861P@23Ph<0QXJ6
0820P021PH40PX:208B4Q026QXH0PX:208B4Q028R8P00P26QXH03024Q8@0PX:208B4Q01mOGd0QXJ6
0820P024Q8@0PX:207inOP21PH40PX:208F5Q@80P8200100Ph>308:2PP20P800PH6108J6QP24Q8@0
Ng]k07YjNP1lO7`0P82008F5Q@1oOgl0Ph>308:2PP1oOgl0OWin0P23Ph<01P21PH40QHF507moO`1o
Ogl0OWin08>3P`80P82000T0PH6107moO`1oOgl0OWin07emO@1kNg/0N7Qh07YjNP1kNg/00P1lO7`0
3`1gMgL0M7Ad079bLP1bLW80MWIf06a/K01_Kfl0JFUY06YZJP1XJ6P0IFEU06i^KP1]KFd0N7Qh07Yj
NP020820P00408^;R`2:RXX0T92@09:BTP80UiNG00/0UIFE09VIV@2KVi/0WIfM0:6QX@2OWil0Y:BT
09nOW`2MWId0WinO09VIV@0309NGU`0B09VIV@2HV9P0UiNG09ZJVP2GUiL0TY:B09VIV@2KVi/0U9BD
09ZJVP2LW9`0UiNG09VIV@2JVYX0V9RH09bLW02NWYh0Vi^K0P2JVYX209RHV00309ZJVP2GUiL0UiNG
0080V9RH00X0VIVI09^KV`2FUYH0VYZJ09FEU@2IVIT0WYjN09nOW`2KVi/0V9RH0P2JVYX02P2KVi/0
V9RH09ZJVP2LW9`0WYjN09^KV`2LW9`0WinO09ZJVP2KVi/209fMW@0@09bLW02JVYX0V9RH09JFUP2H
V9P0WIfM0:VYZ@2j^[X0`/;20<S8b03@d=00dM7A0=CDe03Fe]H0emOG0=SHf080f][J0100fMWI0=[J
fP3Kfm/0emOG0=7Ad@38b<P0^[Zj0:>SX`2<S8`0L71`06MWI`1QHF40J6QX06IVIP1YJFT0L71`0P1_
Kfl02@1hN7P0M7Ad07MgM`1eMGD0MWIf07QhN01iNGT0N7Qh07alO00207YjNP0I07EeM@1jNWX0NWYj
07alO01jNWX0O7al07]kN`1jNWX0NGUi07alO01fMWH0MgMg07AdM01mOGd0NGUi07EeM@1jNWX0N7Qh
07]kN`1oOgl0OWin07]kN`1mOGd0O7al07moO`0207YjNP0807QhN01mOGd0Ogmo07]kN`1jNWX0PH61
07alO01kNg/207IfMP0507moO`1jNWX0NGUi07alO020P8000P1oOgl03@1lO7`0P82007inOP22PX80
OWin07alO01mOGd0NGUi07]kN`1gMgL0Lg=c079bLP1kNg/00P1jNWX207inOP0808R8R02?Shl0U9BD
09:BTP2;Rh/0O7al06MWI`1=CDd>0<SPf0003038h=P30::RXP060:6QX@2RXZ80WIfM0:>SX`2QXJ40
YZJV0P2RXZ801`2PX:00Vi^K0:>SX`2PX:00Vi^K09fMW@2LW9`00P2QXJ402@2JVYX0W9bL09ZJVP2M
WId0VIVI09fMW@2JVYX0V9RH09bLW00209ZJVP0809bLW02JVYX0WYjN09^KV`2PX:00WYjN0:NWY`2P
X:020:JVYP080:FUY@2VYZH0YZJV0:b/[02[Zj/0[jn_0:f][@2ZZZX20:b/[00>0:NWY`2_[jl0Z:RX
0:NWY`2RXZ80XJ6Q09>CT`2DU9@0VIVI08b<S022PX80MgMg07IfMP1ZJVX2065QH@0805iNGP1LG5`0
F5QH065QH@1WIfL0H61P06QXJ01UIFD406UYJ@0706QXJ01^KVh0KVi^06a/K01[Jf/0JFUY06QXJ003
06e]K@0706a/K01ZJVX0JVYZ06a/K01^KVh0KFe]06][J`0206e]K@80KVi^01d0K6a/06QXJ01ZJVX0
JVYZ06a/K01]KFd0Kfm_07IfMP1_Kfl0LG5a07IfMP1iNGT0MgMg071`L01jNWX0NGUi07YjNP1mOGd0
NWYj07UiN@1lO7`0Ng]k08:2PP21PH40Ng]k07YjNP1oOgl0Q8B408>3P`0208B4Q0040861P@27QhL0
PH610820P080Ph>300D0Ogmo08N7Q`29RHT0Q8B408J6QP0208>3P`0F0820P022PX80QXJ607inOP21
PH40OWin08F5Q@22PX80PH6108>3P`20P800Ph>30861P@20P800QhN708F5Q@28R8P0QXJ60820P026
QXH0PX:208N7Q`80QHF500P0QXJ608N7Q`24Q8@0QhN708B4Q028R8P0QXJ608B4Q080QHF502D0R8R8
08F5Q@26QXH0QXJ608B4Q025QHD0Ph>308B4Q025QHD0QhN708V9R@26QXH0QHF508>3P`25QHD0Ph>3
08N7Q`28R8P0Q8B408N7Q`28R8P0RHV908F5Q@2:RXX0R8R808N7Q`25QHD0RHV908N7Q`28R8P0Q8B4
08F5Q@2<S8`0Q8B408>3P`2;Rh/0QXJ60080Ph>300@0PH6108B4Q023Ph<0OWin0P23Ph<01`24Q8@0
Ph>30861P@24Q8@0Ph>30820P027QhL00P25QHD00`27QhL0Ph>308B4Q00208F5Q@0308>3P`25QHD0
PX:20080Ph>300T0QHF508R8R026QXH0Q8B408N7Q`24Q8@0QhN708J6QP2:RXX00`23Ph<01025QHD0
PH610861P@25QHD208Z:RP0508j>SP26QXH0Q8B408B4Q021PH400P20P8008P25QHD0QXJ60861P@24
Q8@0QXJ608F5Q@23Ph<0P8200861P@1oOgl0Ph>308B4Q01nOWh0PX:208N7Q`26QXH0PH6107moO`1n
OWh0PX:207moO`23Ph<0QXJ607moO`1nOWh0Q8B408>3P`20P800Ph>307moO`23Ph<0OGem0820P022
PX8207inOP060820P01oOgl0Q8B407inOP21PH40NGUi0P1lO7`0701iNGT0MgMg07YjNP1iNGT0MgMg
07EeM@1bLW80Kfm_075aL@1cLg<0JFUY06IVIP1WIfL0J6QX071`L01dM7@0MWIf07YjNP24Q8@0QhN7
08^;R`2<S8`0TI6A09:BTP2GUiL0VIVI09RHV02IVIT309nOW`040:>SX`2NWYh0XZ:R0:6QX@80Vi^K
0P2DU9@00`2IVIT0UIFE09ZJVP0209NGU`0709^KV`2GUiL0WIfM09^KV`2HV9P0WIfM09bLW00209ZJ
VP80WinO00l0W9bL09jNWP2JVYX0VIVI09NGU`2MWId0VIVI09NGU`2JVYX0V9RH09ZJVP2IVIT0V9RH
09VIV@2HV9P00P2GUiL00`2NWYh0VYZJ09ZJVP0209RHV080VIVI00D0WIfM09ZJVP2NWYh0WYjN09fM
W@0209ZJVP0509bLW02PX:00X:2P0:2PX02MWId00P2LW9`02@2HV9P0Vi^K09^KV`2NWYh0/K6a0<30
`036a/H0c/k>0=3@d0020=?Cd`030=CDe03GemL0f][J00<0f][J02d0g=cL0=SHf03Cdm<0c<c<0<30
`02/[:`0V9RH07YjNP1[Jf/0JVYZ06EUI@1WIfL0J6QX06m_K`1YJFT0LG5a07AdM01eMGD0MgMg07Ee
M@1gMgL0MWIf07UiN@1kNg/0Ogmo07UiN@1gMgL0MGEe07QhN01mOGd0NGUi07IfMP1kNg/0NWYj07em
O@20P800NGUi07MgM`1kNg/0MWIf07UiN@1lO7`0Ng]k07QhN01jNWX00P1iNGT01P1kNg/0NWYj07al
O021PH40MWIf07alO080OWin00@0O7al07inOP1nOWh0Ogmo0P1kNg/01P1lO7`0OGem07IfMP1fMWH0
P82007YjNP<0OWin01/0PX:207alO01nOWh0OWin07YjNP22PX80O7al07inOP1oOgl0MgMg07]kN`1b
LW80NGUi07AdM01gMgL0MWIf07=cL`1hN7P0O7al08V9R@2RXZ80Z:RX0:VYZ@2[Zj/0ZZZZ09^KV`20
P8003P38h=P000`0b>3H0`2RXZ801P2QXJ40XZ:R09fMW@2SXj<0XJ6Q0:JVYP80XZ:R00L0X:2P09^K
V`2SXj<0X:2P09^KV`2MWId0W9bL0080XJ6Q00T0VYZJ09bLW02JVYX0WIfM09VIV@2MWId0VYZJ09RH
V02LW9`00P2JVYX0202LW9`0VYZJ09jNWP2KVi/0X:2P09jNWP2WYjL0X:2P0P2VYZH0202UYJD0YZJV
0:JVYP2/[:`0Zj^[0:n_[`2][Jd0ZZZZ0P2/[:`03P2WYjL0[jn_0:RXZ02WYjL0XZ:R0:6QX@2CTi<0
U9BD09VIV@2<S8`0PX:207MgM`1fMWH0JVYZ0P1QHF40201NGUh0G5aL05QHF01QHF40IfMW061PH01X
J6P0IFEU101YJFT01`1XJ6P0KVi^06i^KP1/K6`0Jf][06UYJ@1XJ6P00`1]KFd01`1/K6`0JVYZ06YZ
JP1/K6`0KVi^06e]K@1[Jf/00P1]KFd206i^KP0M06a/K01XJ6P0JVYZ06YZJP1/K6`0KFe]06m_K`1f
MWH0Kfm_075aL@1fMWH0NGUi07MgM`1`L700NWYj07UiN@1jNWX0OGem07YjNP1iNGT0O7al07]kN`22
PX80PH6107]kN`1jNWX0Ogmo08B4Q023Ph<00P24Q8@01021PH40QhN70861P@20P80208>3P`0507mo
O`27QhL0RHV908B4Q026QXH00P23Ph<05P20P800PX:208J6QP1nOWh0PH6107inOP25QHD0PX:20861
P@23Ph<0P82008>3P`21PH40P82008N7Q`25QHD0R8R808J6QP20P800QXJ608:2PP27QhL208F5Q@08
08J6QP27QhL0Q8B408N7Q`24Q8@0R8R808J6QP24Q8@208F5Q@0U08R8R025QHD0QXJ608J6QP24Q8@0
QHF508>3P`24Q8@0QHF508N7Q`29RHT0QXJ608F5Q@23Ph<0QHF508>3P`27QhL0R8R808B4Q027QhL0
R8R808V9R@25QHD0RXZ:08R8R027QhL0QHF508V9R@27QhL0R8R808B4Q025QHD0S8b<08B4Q023Ph<0
Rh^;08J6QP0208>3P`040861P@24Q8@0Ph>307inOP80Ph>300L0Q8B408>3P`21PH40Q8B408>3P`20
P800QhN70080QHF500<0QhN708>3P`24Q8@00P25QHD00`23Ph<0QHF508:2PP0208>3P`0908F5Q@28
R8P0QXJ608B4Q027QhL0Q8B408N7Q`26QXH0RXZ:00<0Ph>300@0QHF50861P@21PH40QHF50P2:RXX0
1@2>SXh0QXJ608B4Q024Q8@0PH610080P8200280QHF508J6QP21PH40Q8B408J6QP25QHD0Ph>30820
P021PH40Ogmo08>3P`24Q8@0OWin08:2PP27QhL0QXJ60861P@1oOgl0OWin08:2PP1oOgl0Ph>308J6
QP1oOgl0OWin08B4Q023Ph<0P82008>3P`1oOgl0Ph>307emO@20P800PX:20P1nOWh01P20P800Ogmo
08B4Q01nOWh0PH6107UiN@80O7al01`0NGUi07MgM`1jNWX0NGUi07MgM`1eMGD0LW9b06m_K`1aLG40
Lg=c06UYJ@1VIVH0IfMW06QXJ01`L700M7Ad07IfMP1jNWX0Q8B408N7Q`2;Rh/0S8b<096AT@2BTY80
UiNG09VIV@2HV9P0VIVI0`2OWil0102SXj<0WYjN0::RXP2QXJ4209^KV`80U9BD00<0VIVI09FEU@2J
VYX00P2GUiL01`2KVi/0UiNG09fMW@2KVi/0V9RH09fMW@2LW9`00P2JVYX209nOW`0?09bLW02NWYh0
VYZJ09VIV@2GUiL0WIfM09VIV@2GUiL0VYZJ09RHV02JVYX0VIVI09RHV02IVIT0V9RH0080UiNG00<0
WYjN09ZJVP2JVYX00P2HV9P209VIV@0509fMW@2JVYX0WYjN09jNWP2MWId00P2JVYX01@2LW9`0X:2P
0:2PX02PX:00WIfM0080W9bL00T0V9RH09^KV`2KVi/0WYjN0;6a/@30`<00a/K60<k>cP3@d=000P3C
dm<00`3De=@0emOG0=[JfP030=[JfP0]0=cLg03Hf=P0dm?C0<c<c030`<00[:b/09RHV01jNWX0Jf][
06YZJP1UIFD0IfMW06QXJ01_Kfl0JFUY075aL@1dM7@0MGEe07MgM`1eMGD0MgMg07IfMP1iNGT0Ng]k
07moO`1iNGT0MgMg07EeM@1hN7P0OGem07UiN@1fMWH0Ng]k07YjNP1mOGd0P82007UiN@1gMgL0Ng]k
07IfMP1iNGT0O7al07]kN`1hN7P0NWYj0080NGUi00H0Ng]k07YjNP1lO7`0PH6107IfMP1lO7`207in
OP0407alO01nOWh0OWin07moO`80Ng]k00H0O7al07emO@1fMWH0MWIf0820P01jNWX307inOP0K08:2
PP1lO7`0OWin07inOP1jNWX0PX:207alO01nOWh0Ogmo07MgM`1kNg/0LW9b07UiN@1dM7@0MgMg07If
MP1cLg<0N7Qh07alO029RHT0XZ:R0:RXZ02YZJT0Zj^[0:ZZZP2KVi/0P82000h0b>3H000<0<SPf0<0
XZ:R00H0XJ6Q0::RXP2MWId0Xj>S0:6QX@2VYZH20::RXP070:2PX02KVi/0Xj>S0:2PX02KVi/0WIfM
09bLW0020:6QX@0909ZJVP2LW9`0VYZJ09fMW@2IVIT0WIfM09ZJVP2HV9P0W9bL0080VYZJ00P0W9bL
09ZJVP2NWYh0Vi^K0:2PX02NWYh0YjNW0:2PX080YZJV00P0YJFU0:JVYP2VYZH0[:b/0:^[Z`2_[jl0
[Jf]0:ZZZP80[:b/00h0YjNW0:n_[`2XZ:P0YjNW0::RXP2QXJ40Ti>C09BDU02IVIT0S8b<08:2PP1g
MgL0MWIf06YZJP80HF5Q00P0GUiN05aLG01HF5P0HF5Q06MWI`1PH600J6QX06EUI@@0JFUY00L0J6QX
06i^KP1^KVh0K6a/06][J`1YJFT0J6QX00<0KFe]00L0K6a/06YZJP1ZJVX0K6a/06i^KP1]KFd0Jf][
0080KFe]0P1^KVh07@1/K6`0J6QX06YZJP1ZJVX0K6a/06e]K@1_Kfl0MWIf06m_K`1aLG40MWIf07Ui
N@1gMgL0L71`07YjNP1iNGT0NWYj07emO@1jNWX0NGUi07alO01kNg/0PX:20861P@1kNg/0NWYj07mo
O`24Q8@0Ph>30080Q8B400@0PH6108N7Q`21PH40P8200P23Ph<01@1oOgl0QhN708V9R@24Q8@0QXJ6
0080Ph>301H0P82008:2PP26QXH0OWin0861P@1nOWh0QHF508:2PP21PH40Ph>30820P023Ph<0PH61
0820P027QhL0QHF508R8R026QXH0P82008J6QP22PX80QhN70P25QHD02026QXH0QhN708B4Q027QhL0
Q8B408R8R026QXH0Q8B40P25QHD09@28R8P0QHF508J6QP26QXH0Q8B408F5Q@23Ph<0Q8B408F5Q@27
QhL0RHV908J6QP25QHD0Ph>308F5Q@23Ph<0QhN708R8R024Q8@0QhN708R8R029RHT0QHF508Z:RP28
R8P0QhN708F5Q@29RHT0QhN708R8R024Q8@0QHF508b<S024Q8@0Ph>308^;R`26QXH00P23Ph<01021
PH40Q8B408>3P`1nOWh208>3P`0708B4Q023Ph<0PH6108B4Q023Ph<0P82008N7Q`0208F5Q@0308N7
Q`23Ph<0Q8B40080QHF500<0Ph>308F5Q@22PX800P23Ph<02@25QHD0R8R808J6QP24Q8@0QhN708B4
Q027QhL0QXJ608Z:RP0308>3P`0408F5Q@21PH40PH6108F5Q@80RXZ:00D0SXj>08J6QP24Q8@0Q8B4
0861P@020820P00R08F5Q@26QXH0PH6108B4Q026QXH0QHF508>3P`20P800PH6107moO`23Ph<0Q8B4
07inOP22PX80QhN708J6QP21PH40Ogmo07inOP22PX80Ogmo08>3P`26QXH0Ogmo07inOP24Q8@0Ph>3
0820P023Ph<0Ogmo08>3P`1mOGd0P82008:2PP80OWin00H0P82007moO`24Q8@0OWin0861P@1iNGT2
07alO00L07UiN@1gMgL0NWYj07UiN@1gMgL0MGEe079bLP1_Kfl0LG5a07=cL`1YJFT0IVIV06MWI`1X
J6P0L71`07AdM01fMWH0NWYj08B4Q027QhL0Rh^;08b<S02ATI40TY:B09NGU`2IVIT0V9RH09VIV@<0
WinO00@0Xj>S09jNWP2RXZ80XJ6Q0P2KVi/209BDU00309VIV@2EUID0VYZJ0080UiNG00L0Vi^K09NG
U`2MWId0Vi^K09RHV02MWId0W9bL0080VYZJ0P2OWil03`2LW9`0WYjN09ZJVP2IVIT0UiNG09fMW@2I
VIT0UiNG09ZJVP2HV9P0VYZJ09VIV@2HV9P0VIVI09RHV00209NGU`0309jNWP2JVYX0VYZJ0080V9RH
0P2IVIT01@2MWId0VYZJ09jNWP2NWYh0WIfM0080VYZJ00D0W9bL0:2PX02PX:00X:2P09fMW@0209bL
W00909RHV02KVi/0Vi^K09jNWP2a/K40`<300<K6aP3>c/h0d=3@0080dm?C00<0e=CD0=OGe`3Jf]X0
0`3Jf]X0;@3Lg=`0f=SH0=?Cd`3<c<`0`<300:b/[02HV9P0NWYj06][J`1ZJVX0IFEU06MWI`1XJ6P0
Kfm_06UYJ@1aLG40M7Ad07EeM@1gMgL0MGEe07MgM`1fMWH0NGUi07]kN`1oOgl0NGUi07MgM`1eMGD0
N7Qh07emO@1iNGT0MWIf07]kN`1jNWX0OGem0820P01iNGT0MgMg07]kN`1fMWH0NGUi07alO01kNg/0
N7Qh07YjNP0207UiN@0607]kN`1jNWX0O7al0861P@1fMWH0O7al0P1nOWh0101lO7`0OWin07inOP1o
Ogl207]kN`0607alO01mOGd0MWIf07IfMP20P800NWYj0`1nOWh06`22PX80O7al07inOP1nOWh0NWYj
08:2PP1lO7`0OWin07moO`1gMgL0Ng]k079bLP1iNGT0M7Ad07MgM`1fMWH0Lg=c07QhN01lO7`0RHV9
0::RXP2XZ:P0ZJVY0:^[Z`2ZZZX0Vi^K0820P00>0<SPf0003038h=P30::RXP060:6QX@2RXZ80WIfM
0:>SX`2QXJ40YZJV0P2RXZ801`2PX:00Vi^K0:>SX`2PX:00Vi^K09fMW@2LW9`00P2QXJ402@2JVYX0
W9bL09ZJVP2MWId0VIVI09fMW@2JVYX0V9RH09bLW00209ZJVP0809bLW02JVYX0WYjN09^KV`2PX:00
WYjN0:NWY`2PX:020:JVYP080:FUY@2VYZH0YZJV0:b/[02[Zj/0[jn_0:f][@2ZZZX20:b/[00>0:NW
Y`2_[jl0Z:RX0:NWY`2RXZ80XJ6Q09>CT`2DU9@0VIVI08b<S022PX80MgMg07IfMP1ZJVX2065QH@08
05iNGP1LG5`0F5QH065QH@1WIfL0H61P06QXJ01UIFD406UYJ@0706QXJ01^KVh0KVi^06a/K01[Jf/0
JFUY06QXJ00306e]K@0706a/K01ZJVX0JVYZ06a/K01^KVh0KFe]06][J`0206e]K@80KVi^01d0K6a/
06QXJ01ZJVX0JVYZ06a/K01]KFd0Kfm_07IfMP1_Kfl0LG5a07IfMP1iNGT0MgMg071`L01jNWX0NGUi
07YjNP1mOGd0NWYj07UiN@1lO7`0Ng]k08:2PP21PH40Ng]k07YjNP1oOgl0Q8B408>3P`0208B4Q004
0861P@27QhL0PH610820P080Ph>300D0Ogmo08N7Q`29RHT0Q8B408J6QP0208>3P`0F0820P022PX80
QXJ607inOP21PH40OWin08F5Q@22PX80PH6108>3P`20P800Ph>30861P@20P800QhN708F5Q@28R8P0
QXJ60820P026QXH0PX:208N7Q`80QHF500P0QXJ608N7Q`24Q8@0QhN708B4Q028R8P0QXJ608B4Q080
QHF502D0R8R808F5Q@26QXH0QXJ608B4Q025QHD0Ph>308B4Q025QHD0QhN708V9R@26QXH0QHF508>3
P`25QHD0Ph>308N7Q`28R8P0Q8B408N7Q`28R8P0RHV908F5Q@2:RXX0R8R808N7Q`25QHD0RHV908N7
Q`28R8P0Q8B408F5Q@2<S8`0Q8B408>3P`2;Rh/0QXJ60080Ph>300@0PH6108B4Q023Ph<0OWin0P23
Ph<01`24Q8@0Ph>30861P@24Q8@0Ph>30820P027QhL00P25QHD00`27QhL0Ph>308B4Q00208F5Q@03
08>3P`25QHD0PX:20080Ph>300T0QHF508R8R026QXH0Q8B408N7Q`24Q8@0QhN708J6QP2:RXX00`23
Ph<01025QHD0PH610861P@25QHD208Z:RP0508j>SP26QXH0Q8B408B4Q021PH400P20P8008P25QHD0
QXJ60861P@24Q8@0QXJ608F5Q@23Ph<0P8200861P@1oOgl0Ph>308B4Q01nOWh0PX:208N7Q`26QXH0
PH6107moO`1nOWh0PX:207moO`23Ph<0QXJ607moO`1nOWh0Q8B408>3P`20P800Ph>307moO`23Ph<0
OGem0820P022PX8207inOP060820P01oOgl0Q8B407inOP21PH40NGUi0P1lO7`0701iNGT0MgMg07Yj
NP1iNGT0MgMg07EeM@1bLW80Kfm_075aL@1cLg<0JFUY06IVIP1WIfL0J6QX071`L01dM7@0MWIf07Yj
NP24Q8@0QhN708^;R`2<S8`0TI6A09:BTP2GUiL0VIVI09RHV02IVIT309nOW`040:>SX`2NWYh0XZ:R
0:6QX@80Vi^K0P2DU9@00`2IVIT0UIFE09ZJVP0209NGU`0709^KV`2GUiL0WIfM09^KV`2HV9P0WIfM
09bLW00209ZJVP80WinO00l0W9bL09jNWP2JVYX0VIVI09NGU`2MWId0VIVI09NGU`2JVYX0V9RH09ZJ
VP2IVIT0V9RH09VIV@2HV9P00P2GUiL00`2NWYh0VYZJ09ZJVP0209RHV080VIVI00D0WIfM09ZJVP2N
WYh0WYjN09fMW@0209ZJVP0509bLW02PX:00X:2P0:2PX02MWId00P2LW9`02@2HV9P0Vi^K09^KV`2N
WYh0/K6a0<30`036a/H0c/k>0=3@d0020=?Cd`030=CDe03GemL0f][J00<0f][J02d0g=cL0=SHf03C
dm<0c<c<0<30`02/[:`0V9RH07YjNP1[Jf/0JVYZ06EUI@1WIfL0J6QX06m_K`1YJFT0LG5a07AdM01e
MGD0MgMg07EeM@1gMgL0MWIf07UiN@1kNg/0Ogmo07UiN@1gMgL0MGEe07QhN01mOGd0NGUi07IfMP1k
Ng/0NWYj07emO@20P800NGUi07MgM`1kNg/0MWIf07UiN@1lO7`0Ng]k07QhN01jNWX00P1iNGT01P1k
Ng/0NWYj07alO021PH40MWIf07alO080OWin00@0O7al07inOP1nOWh0Ogmo0P1kNg/01P1lO7`0OGem
07IfMP1fMWH0P82007YjNP<0OWin01/0PX:207alO01nOWh0OWin07YjNP22PX80O7al07inOP1oOgl0
MgMg07]kN`1bLW80NGUi07AdM01gMgL0MWIf07=cL`1hN7P0O7al08V9R@2RXZ80Z:RX0:VYZ@2[Zj/0
ZZZZ09^KV`20P8003P38h=P000`0b>3H0`2RXZ801P2QXJ40XZ:R09fMW@2SXj<0XJ6Q0:JVYP80XZ:R
00L0X:2P09^KV`2SXj<0X:2P09^KV`2MWId0W9bL0080XJ6Q00T0VYZJ09bLW02JVYX0WIfM09VIV@2M
WId0VYZJ09RHV02LW9`00P2JVYX0202LW9`0VYZJ09jNWP2KVi/0X:2P09jNWP2WYjL0X:2P0P2VYZH0
202UYJD0YZJV0:JVYP2/[:`0Zj^[0:n_[`2][Jd0ZZZZ0P2/[:`03P2WYjL0[jn_0:RXZ02WYjL0XZ:R
0:6QX@2CTi<0U9BD09VIV@2<S8`0PX:207MgM`1fMWH0JVYZ0P1QHF40201NGUh0G5aL05QHF01QHF40
IfMW061PH01XJ6P0IFEU101YJFT01`1XJ6P0KVi^06i^KP1/K6`0Jf][06UYJ@1XJ6P00`1]KFd01`1/
K6`0JVYZ06YZJP1/K6`0KVi^06e]K@1[Jf/00P1]KFd206i^KP0M06a/K01XJ6P0JVYZ06YZJP1/K6`0
KFe]06m_K`1fMWH0Kfm_075aL@1fMWH0NGUi07MgM`1`L700NWYj07UiN@1jNWX0OGem07YjNP1iNGT0
O7al07]kN`22PX80PH6107]kN`1jNWX0Ogmo08B4Q023Ph<00P24Q8@01021PH40QhN70861P@20P802
08>3P`0507moO`27QhL0RHV908B4Q026QXH00P23Ph<05P20P800PX:208J6QP1nOWh0PH6107inOP25
QHD0PX:20861P@23Ph<0P82008>3P`21PH40P82008N7Q`25QHD0R8R808J6QP20P800QXJ608:2PP27
QhL208F5Q@0808J6QP27QhL0Q8B408N7Q`24Q8@0R8R808J6QP24Q8@208F5Q@0U08R8R025QHD0QXJ6
08J6QP24Q8@0QHF508>3P`24Q8@0QHF508N7Q`29RHT0QXJ608F5Q@23Ph<0QHF508>3P`27QhL0R8R8
08B4Q027QhL0R8R808V9R@25QHD0RXZ:08R8R027QhL0QHF508V9R@27QhL0R8R808B4Q025QHD0S8b<
08B4Q023Ph<0Rh^;08J6QP0208>3P`040861P@24Q8@0Ph>307inOP80Ph>300L0Q8B408>3P`21PH40
Q8B408>3P`20P800QhN70080QHF500<0QhN708>3P`24Q8@00P25QHD00`23Ph<0QHF508:2PP0208>3
P`0908F5Q@28R8P0QXJ608B4Q027QhL0Q8B408N7Q`26QXH0RXZ:00<0Ph>300@0QHF50861P@21PH40
QHF50P2:RXX01@2>SXh0QXJ608B4Q024Q8@0PH610080P8200280QHF508J6QP21PH40Q8B408J6QP25
QHD0Ph>30820P021PH40Ogmo08>3P`24Q8@0OWin08:2PP27QhL0QXJ60861P@1oOgl0OWin08:2PP1o
Ogl0Ph>308J6QP1oOgl0OWin08B4Q023Ph<0P82008>3P`1oOgl0Ph>307emO@20P800PX:20P1nOWh0
1P20P800Ogmo08B4Q01nOWh0PH6107UiN@80O7al01`0NGUi07MgM`1jNWX0NGUi07MgM`1eMGD0LW9b
06m_K`1aLG40Lg=c06UYJ@1VIVH0IfMW06QXJ01`L700M7Ad07IfMP1jNWX0Q8B408N7Q`2;Rh/0S8b<
096AT@2BTY80UiNG09VIV@2HV9P0VIVI0`2OWil0102SXj<0WYjN0::RXP2QXJ4209^KV`80U9BD00<0
VIVI09FEU@2JVYX00P2GUiL01`2KVi/0UiNG09fMW@2KVi/0V9RH09fMW@2LW9`00P2JVYX209nOW`0?
09bLW02NWYh0VYZJ09VIV@2GUiL0WIfM09VIV@2GUiL0VYZJ09RHV02JVYX0VIVI09RHV02IVIT0V9RH
0080UiNG00<0WYjN09ZJVP2JVYX00P2HV9P209VIV@0509fMW@2JVYX0WYjN09jNWP2MWId00P2JVYX0
1@2LW9`0X:2P0:2PX02PX:00WIfM0080W9bL00T0V9RH09^KV`2KVi/0WYjN0;6a/@30`<00a/K60<k>
cP3@d=000P3Cdm<00`3De=@0emOG0=[JfP030=[JfP0]0=cLg03Hf=P0dm?C0<c<c030`<00[:b/09RH
V01jNWX0Jf][06YZJP1UIFD0IfMW06QXJ01_Kfl0JFUY075aL@1dM7@0MGEe07MgM`1eMGD0MgMg07If
MP1iNGT0Ng]k07moO`1iNGT0MgMg07EeM@1hN7P0OGem07UiN@1fMWH0Ng]k07YjNP1mOGd0P82007Ui
N@1gMgL0Ng]k07IfMP1iNGT0O7al07]kN`1hN7P0NWYj0080NGUi00H0Ng]k07YjNP1lO7`0PH6107If
MP1lO7`207inOP0407alO01nOWh0OWin07moO`80Ng]k00H0O7al07emO@1fMWH0MWIf0820P01jNWX3
07inOP0K08:2PP1lO7`0OWin07inOP1jNWX0PX:207alO01nOWh0Ogmo07MgM`1kNg/0LW9b07UiN@1d
M7@0MgMg07IfMP1cLg<0N7Qh07alO029RHT0XZ:R0:RXZ02YZJT0Zj^[0:ZZZP2KVi/0P82000h0b>3H
003o0<SPf?l0b>3H8P38h=P00?l0b>3Ho`38h=PR0<SPf000o`38h=So0<SPf280b>3H003o0<SPf?l0
b>3H8P38h=P00?l0b>3Ho`38h=PR0<SPf000o`38h=So0<SPf280b>3H003o0<SPf?l0b>3H8P38h=P0
0?l0b>3Ho`38h=PR0<SPf000o`38h=So0<SPf280b>3H003o0<SPf?l0b>3H8P38h=P00?l0b>3Ho`38
h=PR0<SPf000o`38h=So0<SPf280b>3H0000\
\>"],
  ImageRangeCache->{{{0, 543}, {543, 0}} -> {-12.8027, -12.8027, 0.990065, \
0.990065}}]
}, Open  ]],

Cell["\<\
We will only work with a small but diverse part of the image, combining sharp \
features, smooth gradients, and complex textures. Note that we conver the \
unsigned byte values [0,256) to signed on the interval [-128,128). This way \
we can exploit gradient symmetry in quantization\
\>", "Text"],

Cell[BoxData[
    \(\(sub\  = \ 
        SubMatrix[m[\([1, 1]\)], {170, 178}, {128, 128}] - 128;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Graphics[Raster[\((sub + 128)\)/255]], 
        AspectRatio \[Rule] 1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5D6685BBB54029292428262D425238333932392F2F3835392F3A37434B513F3B382F2D26
2B283E6A66665A7165535C62676A736F76827D7C83837B837D81827E8385888989888887
8C8E928B8E8C908C88898A8B8E8A8A8D8E8A928E8F9292929293908D9195938F8E929295
9090999493969B979B9B9EA0ACB1C4CFCBD1CFBE
5A597093C19C3E282C29242A373630343837372B323B30322F4135444C4D4236372F2E30
2B2742696164607A644A5C62696D7575757C7C7E7A82847F7F7E807F8586868A8B88898B
8B9090888C8A8F8B8F87888B8D8B8F8E8D9191939595928F919292909698999195949492
9293979798969A9B9BA0A1A7AAAEC4CFD1CDCCC0
595A5F729AC2953A2A262A2D38342F364438322E3335332C343D384A413D422D2E34302C
292A416364675F7B59515E69766E6D7777787D7E818281818087837F8284838B8786898B
8F8C908C8B88898B928A8A8E908D8B8E8E9694939595949595979292979C9C9394979690
94919694959B9B999B9A9DA4ABB0C4D4D3CECDC5
60595D667CACC06E2F2A24282B2A2B3D4030333031312A2E363E2F4E443E3C312D362F27
262A466C65685C77585B63656F70717276797D7B7E818082847F82828088878B8889898E
8D888D8E8C888C90928D8C908E938D949196949499979593939998999899A09A99939392
96909797949699969A999DA5A5B0C2D2CFCECCC1
5F5A5B59708DBFB35B2C27242B2D32342E30292C32332B2D3133324B4339363031343228
27304C74606A676F565E636A6E7073787A7777817F7E7E858382827C7F85888B8787878E
8B8889908B8B918B8F8C8F8E8D8F8E95949796949598969794999898999F9B979593928F
94979A9A97909897979C96A3A5AABECED1CEC8BC
625A585F6176A0C8AA3F2824242934312D2C2C3135343032383C3D4C403D433A33322C30
302D4B77696E6169515E6169737273747D7A7C827D8080837F8182848288858B898D898D
8D8F8D8D8A8C8C8A8D8B8C918C9294989A97979997979A94979C9696979D999899949494
939598959294939797989A9EA4ABB8CACECDC7BB
5C6A595A62658AC3C791372C31262C322834312E31332E2D313731413D3C3B2E322F2C2B
28264A706F6E666654616C6C717170767F7A79827A7D7E7D7E797E83848582858C898991
898D8E8F8B888A8C8E8C8F918F949697999897979B9A9694989D999C9B9C9B979794929A
9895939294949491909497969CA9B6C6CDCAC1B7
4E6955515A6994B3C7C57E3927252C2B2A313238383B39403E43424C4142423C3A3A2F39
3A3A5C72746770625D636B6B6F72787B807F7F7D7F828584838386818588888A8F8A8F91
8A8B8A8C8C8B8E8D8C9090959099999A9A9A9C99999B98989B9F9E9C9F9D9B9B9897979A
98959795929493918E8E95989FA3B1BFC9C8C0B0
516063596276939CC1CBC374383537363641403E373733383A343D3F3836342C2E32272D
2C325A6F705D6E565660646A707476787B787D827A80807E7F8280848384888D8B898D8F
8A8E8D8A8C8F938F91919397969B979D979999999A9A9C9B9F9CA09D9D9C9D9A96949A98
999796949697929291918F959EA1ACBAC2C5BBA8
65586F6A63748789A4C2D0BA4B2F2E303030343431312D353433413638363632322F2C2C
30345C73735F695554646169717076777B7D7F807A7F807F7C817F8482848B8B898B898D
8F8D908F8F918E93948D8F919398999B979E999C9D9E9EA1A49F9D9D9D9C9E9B9A989A99
999693919691918F8F8D8D949499A5B3BABFB1A1
9E5B63705F6A777D8AABCFD4A13A322E2D34383635323A393E403E3A3833393435312F31
31386077815E6751545C656D6D7275787979797B7D7C7D7B787D828682828685868E8A8C
8A8D938E908E8F8E918F91958E94989A9B9A9A9C9A9F9E9D9EA29B9D9E9D9E9C9B9BA096
969896969690958F8A8D8A8B8D919DA4B2B6A59A
B48A60646A5E65757D8EC0D4CB7730292A292E2B2F2A3232332D4641343436313332292A
2D3164777957664E575B606E6D73737A79797F7C7D7C7E7A8181847E7D8381818A898588
908B919591908F92909095949495969F9A999C9C999B9B9EA09F9B9DA19C9E9A9C9E9A98
969396908F918F8A868785888D8F9798A6A49693
ADAC72647566636C7283A2D3D7C05225262A272426292D31383D41343031302F31272529
262E6776795E644B555B676A7374737576747B797D7E7D8081827C7F8386898689898789
8E8D938E8F918D91929394979893949B99999A9A9E9A96999E9E9FA29C989C999D9A979C
9592948F938D8C86838B828385878D8F968F8486
879794616A746B6C6F7384BBCFCF9D2D29252C23292A323A434E5A3435312A2730232A2B
2F35637D7563634F52596970716F717578787A7D7A7F81817F82847F828685878B8C868C
92918D918E949393909493959A94969E9D989A979DA09D9C9F9E9F9F9E9F9C9D98979195
94958F8D898E887F7D807F808280858788817679
606F7E6D6D7A7F84847A879BB5B4B7633127232324262A3B524B4B46452C2C2D2D27333B
342C577179685D53515C61696B70777674767E7E7F7E7B7E7F88818580868687868C878D
94928F9191989294909491959493989C9A9397989D9C9D9E9FA3989B9E9E9A9794969893
938D868686827D7A7A80828287848686827C7477
4C5E6470707B8B949694999FA8A4AE9E5F3727262023282E383C2C312F2B2A2B31262F2F
2A3163747368524A505E666C68746F717577807E817B7B7C807F82828188888A898A8B90
8E95939294939595939187969693969A97969C989B9E9CA19F9E9AA09E9A9C9594949592
9089827E7B7A7E7C8082848784868685847E7777
2C3B46698D899399A1ADADB1B6BEC0B9AE8129252627242A2F2B2C342E2C2E2F3228312C
3130606E6D644D4E506365666C75777175767D7D787E818083828385858A88868A8E9190
938C8F8F909597959795969D979A9C9D999A9C9A9B9F9EA09D9D9C9EA29B979891949490
90817B74787D7F7F837F807C7E837F817D776F6E
221F235192979EA2A2AFC2B9BEC0C7C6BCA23C2325232728292727272B2B2F2D2E2F2F29
24295F6B70664D4E535F66636A6C706F7875787A7A7D7D7E838283848389888A88909090
92909492919796989696939599979A9F9C9B9F9D9F9D9EA09D9F9F9E9C9B96949494938C
8B7C777A7E808278736C6560666D78746F696064
201C222F81A4A6AAB1B4C5B7BEBFC1BEBCAE6534232128282A2525262B2A3432342F2C27
272E5A6D7069474F555C626466696E7473797C79807D7D7F83828180858787888B8C8B93
93938E9493999796969598979494989D9C9FA09E9F9B9E9C9E9D9C9FA296969895948F8B
857B757A848384816957463B4751615D5C575559
25221F2158ADB1ADB3BAC4B4B7BDBCBEB7AEA27430292A232126262525262C382E2A2E2B
2B2D576A625F4B4951605E60626B70717579787A7A7B808182808282868A8988888B8A90
8F8D8E9A9696939999969B9C98959A9C9A9A9D9CA09F9E9F9F9EA09FA1989394918D8F8A
82777981848688836541323132404D59605A6371
201D1D1F37A2B4ACAFADBFB3B3B8BDB9B3AFA7A15B3C35272521222226292D2F2F252729
252E5E6E585B47504C565D62656A777379777D7C7A7D82807F7E8284878A8D8C8B8A9090
919090959B94929A94979A9C9598999D999F9C9E9C9E9C9E9D9D999F9D9C9692948A8A87
807478878485848A78563A38394959667273777E
2920211D258CAEA5A7A7B4B4A9B0B0B4B9B4B6B4997B4C2D292620222222302D2B262829
2534606F645C464D4C555C5D666D746F797A7D807C7D857F7D83838288868C8A918D8D8F
908D9295959697959A9895979597999C9C9F989D9E9E9EA09FA09D9B9E97968F948A8A84
716C71817F89878585837770757E7F8082847E7A
2A201B1B1D62A89DAAA8A6AFA9ACA7B1B5B5B8BDAD8C774F3729242626272C2931312F26
273258695B563E3A47555A60656E7473767D7C7F837D84807F83808586838B908E898D8D
978D8F988F96999397959797949B9C9CA09A979CA19F9F9E9E9C9B9A9B969192908B9480
746C747C7D878A8786878684868D89848B847E77
28261D1D1C3BA0A3A3A59F9FA6ACA19E9B9FA9BDBAAA8F5D412621201F2635282F282A29
28345B6A675A47443D53585F697072747676837B7F84817F7F8383868686878D8D8D908D
928D939091949C9796989B9C9C979C9D9E9B9E9D9EA59E9E9F9CA29D9A9794998F918F83
756B72787D858F8D8B89888A928D8F908C837E78
26312720212A78A9A1A6A49996928180757782A1ABBDB191653124242428263227232728
252C5D71635943454A4C5C5A696D6F74787B80787D7F8280818581838887898C8B928F90
908F8F9395979796999598A19B9D9F9C9F9F9F9F9FA29F9E9F9DA19E9A959292908B8C7E
786870767D86868D8D8E898C8D8C908E8A827C79
25302C212225478C989A968881766B6D6476838792A2AD9C6E372925262323272E242F46
252E57715B4E4643444E5957636B7672777A7B827E7C827F80828686868C888F8E91918D
8E8F939C9399969695979A9D9C9F9C9F9C9D9E9EA0A29E9F9D9F9F9D9A92938E8B8D8A7D
746B6D747D83878A8D8B888B908D8F888680807D
24243226221E224C7883787A7A67656C6C90B5ADA38D909A875A452D23222B252B282822
232E5A6D5A43404B4E51535F5F6A747176767D7F7D7C827D81838685878B8D8A8B8F9493
948F939B97979A98969A9A96999C9A9F99A29F9CA19FA2A4A3A1A19B999899928C8B8F7F
77726E737C8087868B888A898B8F8484817C7D7F
2323302F2B1E23285165677E856A6E727290B9C9C3A682977D3424231F1E232925222A25
292A5C6C5C413847484F565D67686C737575797D7F808482838287858886878C8B8D9091
9393959A9B99989897999A969A9D9E9DA2A39FA2A69EA2A4A4A3A19D9C98989691908E85
7C797572767C84858387868483827F84797B7B81
25312C372F1F1B212E4F4B6D877672807B7E9EC9CACAABA0A33C28221F25272B27262C25
252C596A5D3D42474D525958656A6D7574767B7E7D8080818585858C8782858A898D9492
979693999697979896949B9A9E9FA2A0A0A0A2A5A59EA3A5A29D9F9D9B9892958E8E908A
837C7772797D8286868B8783817E7B7C7A7C7B7E
2A24293A32212330212C285C898A7578787992BFCCCECABFC57F2F2222272B2922282727
283056645A4137484553575C6066717577777D8080808784848486868A878C8F86909092
96999397959894969A9D9B9C9C989EA3A2A0A5A4A4A0A4A4A3A4A19E9B9D9494928F8E88
857D7C7A7B7C7B82838C857D7F7B7D7E79757A7E
232532382F2C1F1F221E2244829A7B7176737FA8D0CFD0CCD0B94926232A26282C242425
22285360543C414A4B545D61676A71757779777F8080858181878386878B8C988A929090
969892999899989A9B9E9B9B9F9A9EA09FA3A7A7A4A3A09EA0A1A39F9E9D999591928988
87827E817F7E7C838387837E7C7B7F7F79757681
232E3D4E3523201B1E1C1F2F6B8F867370747690BFCDCBCECCCEA3382524262925262722
24254D664E3A4247454B5761676C7171797E807A7E80808382878889898A8E8E8F949390
91989B9796999A9EA29E9D9CA09F9F9FA2A6A8A2A6A4A5A2A0A4A5A2A69F9E9A93938C8E
85858484808181847D84827C7F7C7B797B797C7D
26324C734D2620211E1D1D25508395796F797678A5C7C8CECFCECE893125262527212329
2729495C48353C45494D5A62666C72747582837D7B8083867E8487898A8A8689909A9290
96969B9997A1A1A1A3A09E9FA0A2A3A2A5A8A5A3A8A9A8A4A5A8A2A6A69FA09B96919089
8A8883838382848481817B7C7D7978787A7B7C7D
333D5C857646241E1B1B1C233770A08B6D7E767591BEC3CACACCCFC3642821232526211F
272E4B5544353A444A515668696B706F7B7E7D7D81838185817F898B8B87888D92989196
97999A969BA19DA3A29A9E9EA2A4ABAAABAAA8A7A9A8AAA6A8A6A0A0A5A19E9B9598918C
8B8A86858083868785827D7E807C787A7B7C7B7D
345166887758241C1D1B1A1E2659929E716F6F7185A8C5C9CCCBCCCEB546272121232A25
232947563F3A383C45555569666C7076777D7D858182848082828487898D8B909093959D
979C9D98A09DA1A4A2A1A2A0AAA7AAA6A3ABACA8AAABA9A7A9A5A5A1A5A1999B9897928E
89868884838383878381817D827E7B787A7E7B7E
43627E937F60261D1F241D1E243B819C7F756E707EA0C6C7CACCCDCECCA53F2623232321
212B41573C37343C45505B64656C7074767C7981818083858687838689918F928E939397
959B9C9F9A9FA4A2A0A4A0A4AAACADA6A3ABADACA8A8ABAAA9AAA7A5A5A69E9D9D979488
878584868587868883828383817C77787D7B7E83
53749BAD9869261E2024231F20265B8C947C6E6B7490B6CEC6CDCFCDCDC98B3122272724
2B264455382F35394C565A65666F7173767E788385808385858586878B8B90938F959898
9898A09DA0A49C9DA0A3A8A4ADB1A9AAA7ACA8AEB0ABAAACACA5A7A0A5A69F9E98999491
8A85868686848886828580807F7B7A787B7C8282
5F80B6AD8A5129232328252028243B7A99836D6F6F81A0D1C7C9CBCCCDD1C15C27202623
2425404E3931383F4F545B62656C706F787C7D7E857F87848685848D8F8B8C9093989B99
999C9E9B9E9CA4A1A6A3AAACB2ADACACAFAEABACAEADA8A8ABA6A7A7A1A29F9995979591
8A88868984848787878A7E7B807F80797B7D8185
7993B2986E32212E22262B2B2827306090956D64707985C3CAC5C8CBCED1D4A72F222525
282F394837363C4751535E656E6D77747A807E83837E848286878A8D8D8D909794989697
989C9C9B9D9CA5A9A7ADABABB4AFADAFB1AFB2AFACA8A7ACACA7A9A7A4A1A29E9A999391
8A898588868587889186837F81817A7D7C7C8489
A49A9470492D2621222528242A2B2A4D80977964707B7DADCCBCC4C8CCD0D5C875352922
26273F43312F363D475164686C707779798080807F828084898C8D8B8D93929098919997
98999A9E9FA2A6A9A5ADA8ABB3AEAEAEB1B0B1B0B2AAA8ABADA8A8A8A4A39F9D9B979895
92908B8C8B89898B8B86847E817E7D817C838184
AC976C442C282B262126222320282833718F8E697074778FC7BCBDC4C7CBCFD1B3442A23
24282F3E2F343C434F5163686C707A7A7B7B7B7E8183888282868C8A8D8F909298959A99
9B96999D9DA0A5A5A5ADA7AEB1B0ACB1B5B1B2AFADABA9ABAAACAAA7A7A5A1A19D9A9293
938F8C888A8A90888F88858380827B7D79828283
907A452A222B2F29222122292622242A53859F787374777BB6C5B8BDC4C5C9D0CC973229
292935432C303C3D4B555F656E747F797678797F83828C84848589898F8F918E95969899
9C929B9B9AA2A7A3A7A9AAB2AFB3AFB1AFB1B8B1AEAEA9ABB0AEA5A6A5A49E9D9B9F9292
8C8E8F898B8C918B8A898984817C76847F808388
77582D252320232225242322221F212539729A8B737270749BC6B9BBBFC4C3C5CCC26A32
302A2D3A2D37343C4D59656C71757A7876787E83868487828585878C9094928E92919495
9C9D9BA2A2A2A8A6ACAFB0B1B0B8AEB2B4B5B7B0AFAFAFABB2ADA9A8A6A7A2A2A09A9695
8B8F918C8D94938E8A8B8586817F7E7D83808682
593E272524272C27232226322522221F295B8994766F6F7384C0C7BBBDC6BDBDC3CEAC3A
2F2B2D352E3236404F59656C727175757B7B82837E8289858886848B8F91909390909597
989DA2A7A9A5A8ABACB0B2B4B6B3B0AFB4B7B3ADAFAEA9AFB0AFABADA9A2A39E9B9B9796
918F93908D92948C91888886867E7F7C82848585
4331332C2827292A29252831252A201D223A769493707478759FCCBEB9C2C0BCBBCACA90
3523252C2B2E37454D596167757379757C7D7E83827A848186848589889296969593979A
9E9EA5A7A8AAADACB2ADB1B0B1B4B4B7BEB9B5AFADAEA8ABABA9ABA8AFA8A19FA09A9B9C
989393969095928C8D8C8A8486857B8081858489
542F2F383335242A2C2A29322B27282224335F90A48373777286BFCCB1BEC1BFBAC1D1C1
622827282C30344448555F6874747979787C80807F798083868A8C8E8D92989898979B98
9CA0A1A6ADADB0AEAEB3B5B3AEB6B3BABAB6B4ADB3ABABACB0ADACA8B0A6A4A59D9F9F98
96939495919495958C8E8C8A8587817E81838483
5F37302B23292B2F2C272632333026212A2C3C789794766D7D76A4CDB3B6BFBBBCBDCAD1
AF4229272D393637475761696D75787A787C7A7B7A7A8383868A8F918F91989899989D9C
9EA2A6A8AFAEAEADB1B1B4B3B4B4B2B4B2B0AFACB6ADAFB0B3AEB0AAACAEA7A6A29F9D9A
98929999929195948F8C8C8A848983817C818482
503A2E2E26322A30322A2D2E2F292726282A325C889B7F69797983B2B8ACBBBDC0BEC8D1
CD983524262F323B415461656E727A777B7C7C7F7D7C868187898B8F938E95969B9B9C9C
A5A4A7A8ACAAACACB1B3B4B4B3B3B0ADB0AEAEAEB3B0ADADB2B3B1ABAAA9A5A2A19E9B9B
9B9A909291908E928B8B8884848081847F7F8082
3738292E2F322E2D2B2C2D2F2A2F3329292A303A6C94977373787590BCA8B6C1C1C3C3CD
D2C97C2D21282D38475560626C6F777C7B7A7E80807F87818A888E9494919397979D9D9D
A5A5A7A7AAAEADACB0B1B3B0B5AFB0B4B2B7B4AEAEAFB4B3B0B3B2B2ADAAA8A6A1A19A9D
999A9092929490948A8D8A818587858382827B7F
3E352F2D2E2E2E2F2D2E302E2D2E2F31302B2C365389AA807372747DB5B5B3BCC0C3C3C6
CFCFBD5829242E34444D575F696F777577797C7D7E8682838D898D9493979897989A9EA1
A2A3A7A9ABAEADABAEB3B2B4B0ACAAB4B3B0B1B1B2B1B0ADAEB2AFB2AFADAAA9A7A49B9C
9493949498958E928A8D86828886847F84838285
4A302D3335342F3A2D2D2C30302D2B3029292926316F9E9470666F76A6C0ABB4BDBCC4C2
C9D0CCA83D2A2836414B545A66717574757A7D7E807E81868A8C8D9290949898959E9EA2
9FA4A7AEACADA9ADAFB6B5AEA8AAABB2B2B1AFB6B3B1B0B0ADAEAFB1B0B0A9AAA4A39F9A
93919595949193908C8C85858586877D81838285
532F272E32362D2C31302B3035302B2A2C2927282D5493A27D66677088BBB4AEB9BCC2BF
C2CBCEC8903430333F4C535F5F6F727579787A7B837F8384888A8B90929799959A9DA0A0
A2A7A8A8AEA7A7B1ACB4B0ADA8B1B6B6B1B1B0AFACABA5A9AEB2AEB2ABAEAAA8A3A09A98
9696908E8E90918F8C8B86817E87877C7F808084
4227252834333429262F2B2A292F2D2D2E2B29282D42779C986E616A76A4BEA7B1BCBFBB
BDC6CCCDC17A36343D474B56676D727075787C7B83818084878C908F94989C969B9D9FA0
A5A4A8A8ACA7ADADACB0ADAEADB0B2B2ADAFACAAACADA8A4ADB1B1B2AEB2ACA7A29B9B98
9593908A8E8D948F8B8884878182877C807A7F83
2F2C2D2D36332E2E2C2D2830312C3431372C2B322C29528BA57E6967708CC0B2ABB5BCBE
BDC2C6C9C9BB593637455152616B70716F797E7A8482828A8B8B8D8D92979D9AA19B9F9F
A2A9A9A4A5A5AAADA9B1ADADACABADABACADABAAACADA8A9A8A9A9B0B0ADA8ACA09C9A9A
95948D888E8E96898B8980838281817A867A7E87
3134313337362E2B302C282F322F35332D2E313127273A6F969B746C6982ACBEA0B3B8BF
C0BEC4C3C7CCB04C39434B575F647070767C7A797F7F7F8C8B8B8A93939698979E9D9F9F
A7AAA9A1A3A2AAACAEB4ACABA9A3A6A5A8A6A9ACAEAEADACA8A8AAA6A8ACA8AAA3A2A099
948E8A888D8D8D8A858387828183847F85807F89
333030333431262B2B2C282C31353136353234352A2E2C5082A37F67656E8EB9A3B1B6BC
BBBDC0C2C8CCCCA4403F47515C5F6C7074787B7C837D868D898C8E95969898989D9FA09E
A8A9A7A3A5A2AAACACB2ABA9A8A3A6AAA4A7A8AEB1B0AEACA5A9A6A6A6A7A7A6A1A69B9F
958D88898B8E92908A86878584867F8281818488
322B2F32302C302E27302E31323F30303030332B2A2A2C386B92956F626475A2B5AAB2B5
BABDBDC6C9CFCEC78A40404D59616A71717576777D858689858A8D979497969CA198A1A2
A4A7A4A6A0A4A7AAADACA6A6A0A5A7A5A8A3A7A9ABADA9A9B1AEA9A4A6ACB0A4A6AEA59E
938C8E8888908F8E8B8689868181838182807F8B
2C2C2D2F2D272C31282B293036372D33323130302627282D47829E8469656B87B4ADB1B4
B6BBBBC3C3CACFCDC1813F4554606671706F72787F878687838E8C9694979C9C9C9B9FA4
A1A1A2A49EA6A1A1A39F9A9F9BA2A29D9E9FA6A4ABAAA3A6B1ACAEA5A2ACACA0A2AAA4A4
958C8D8585888A8F8E888882827E847F7F807D8C
302D292C2E2E2D2C2B2F2934352F2F322A2F32292521252330668F9F7C64687BA4BBACB6
B1B3B7BAC0C6CBCCCEBB703C4E555E656E70767879828787868D8E989699979A97979A9B
A0A39EA39FA09C9A9A97949696989B96999E9B9C9CA5A0A2A4A5A7AAA5A7A5A29FA6A3A7
9C8E8B827F84868B8C8789807E8084828283878D
2B2F2C2F3231332C272E31383633302F2D2D2C2723242523243F799C8F736B6F96C1B2AB
A6AAB1B5BCBFC8CCCFCCB66047515C5F676E727B7A7C838B88909294999A9A989793969E
949B9B9F9A9D9A9597918E9291938F909093929298969C9DA0A1A8A8A7A3A4A49CA1A3A7
A0928683858484868A8B87847F817C837C81848E
272B342E2D2B2E2F302D2E362C2E2F2B2F2A3027282B262122286085A1826B677EA9C0A8
A1ABB2B6B7B5C1C7C9CACAA95F4A565D636D75757D7F838A888D939494959B999A9A9698
969497999594939095908B94928F908D8E908E8F8E969796979A9B9DA1A3A5A49A9DA1A3
A1988B81818188848A88868781837E827F82838C
342A2C343432312E282E3733332E3437342C3030271E212020233C76999B6E63708CB9AA
9FA7B0B3B3B0BBC2CAC9CBC8A25D4F535C63717679848386878B8C8F9392979A92969297
999193918B8F919495958C8A94908D8988898B8D8D94918C95959B999F9FA49E9A949699
9C9C8D837A7B81848689868285817F7F7D838590
2D2A2C312F3433292E33302E2F2C2F343532362D2627261C1E23265987A180636673A8B8
A3A3A8B3ADB2B5BDC5C8CBC6C49E595151606B6E7B807E8385878E92958D8D9090969497
92948B8F8C8F9396979084838C89827C7E847F88888585778C958E90A099999696969191
96958F83777A80818884857E8383807D80868991
2E31334429292B2F2F2E2D2E2A2C2C303236342D28252623222223326B8D956E626990BB
B7A2A1B0ADB6B8BCC4C4CBC9C5C59A59515F666E767C818289858C8D93858D8B91949392
8E928D9190909695948E837781817B716E867F888A8F7B6C868A8186A692929799979992
8E8E847F75797F838384847F81837E7F82888A91
282B2D262D292D2C2C3034342B2A2F39382F302C2327262323222126467C9980625C7FB3
C3AD9FA9AAB3B3B8C1C2C8CAC5C7C1965953696C747E7E8388858A8D8D8A8E8E908F8F91
8E8C91958F8C908D8E85816D77807A6E5C808089868B716E807B667DA698939CA5A2A399
978A837E7A777A7C8284847D838081807E8A9495
2C262A2D2E2B302F2B2D2E312F3030333239332E2B312426222320202A5E899C6F59679C
C0C2A2A4A8AFB0BBBDC2C8CEC6C5C6C2966060696E76787F8583868B848789898F8D9291
908F9292898684888A837A6D68777D6459768182847F696A8073657F9FA3A8A7B3AFAFA8
9E90887D777D787E7C81818283848782818A8F96
302A23292A2F2C362D2E2F30302B2A2B322C3A2D39282425242523222239779C875F6181
B7CAB9A6A7AAB1B6BABEC3CACBC9C2C2BF8A5E5F68757781827C828A81878285928E8F8F
8D8F8F8D8678767D7E7F7E6C6D6B7C6F607A858892969193A7A08D9FA2A4AFACACABAEAD
9F948C837E807C7F747B827B7E808383868D9295
2824252B252C2F343231303138322E3930312F2A382F27262D22211F232C52849F6D566C
9BC2CBAFA3A7ACB6B9BCBEC8C9CAC6C4C5BE94625C6C787B7C7B81867E817D8493939190
8F8D878881706D72696C78726F7485858F979B979EA9A7ACB2B2AAB1B4BBBDB1A09B9794
88888984837E79777973788083818079828D9497
2C2724272931342C312D303C403A362E2C3032443B2F342B232725222C293B6E91935F60
7CACCEBF9EA3A6AEB4BABBC5C8CAC8C6C4BFBC8F606277797B7B7F8181807E889093908D
8D8C827C746B6369534B717D878A92959D9D9FA8ADB0BBBBC1C4C1B9AFA7AA9B928E877C
75768280867E7D7877797B8082828580848E949A
322C27272429303938322E36433F2E2E36302C2E313727242825242120392A4D859B7C63
6688C2C59C959FADB1B9B5C0C7C7C6C7C5C1C1BC926669727F7C7B7A7C7E7B878E8B8D86
8685726A5F5B5D5F5E6E77828B8D83858A939EB6BBC1C5C7CBCED1CEC7B69E908991988B
73707C83827D797275797C8481828185848D8D99
2C2B362C2F2B363D3A362D283740312726292C2F303526252E2D2123212A363C58889663
5866A3C2AB969CACB5B2B4BDC3C3C7C9C5C7C1C4C19C6C6A73777A72767E7C838C838F88
7C766353434352637377777C84786C65667489A3BAC5C6CACDCFD1CFCAC6B09788908E94
716E79857E747179747C7B7C7F82828386869094
3C35282E2A2E34454F3D2A29313A322D2C282D2D36382827272421252A3032353F6E957C
53567EAFB99F98A9B0B3B4BCBEC3C7C9CAC4C5C5C5C4A06D68717576767F8284827C827C
756C56412F2F496371707578715F523F424B587F9EBCCACBCACACECCC6C3BCA3948A8478
6A747E7A7070737C7D78767B7A86848B8A8F949B
402E2C282C283A52744D2A2C3430352C2D2B2B3534302A302C27282B272E28252C407D8A
67516689A6A19097A3A8ABBBB9C1C6C5C8C7C5C4C2C7C3986C6370727A7E817D7475796D
64604A322B33445C69727D71593E39363D3A414D6BA0C6D0CED0CFD1CAC8C0B09E837261
667D7D74666F72777C75717B818286898A8E939B
38282627262D40657F4F352E3129352B29312D313D2D282D262C2B28232D2724262F5A78
73515C7D97B19E93979399A2AAB4BBC3C6C9CAC8C5C5C3C298676D6573787A756E64615F
564E372F3345535A6C7F73583B3C4F575A504D374171ADCFD3D2D3D3CDCECAB69E7B5D54
637E7666626B6F6F7572767A80808688899097A2
382E2B292B31457977463E2C292A2C2A2D2C2A303A2E2A2628292B2B25272325252E4A69
8472566C93BCBFA8A1999599A8ADB3BEC3CACACBC6C1C6C7C793696267746E695C54524E
423B2E2B2D454A5D757963433A546256565B534839427EC5D1CED0D2CDCEC8B6956C4C46
6C7E6A5C6070706D7076797A7D81858A888D959C
352A3026272E528854364430302324262F262E37382F2B29273439322B25282D35484A62
899D756074A9CDBFAAA4ADAAB2BBB6BDBCC8C9CBC6C6CDC9C8C28D5D616B656156534035
3330312D2F42475F736B47345C625A4842425A6C4A3557B1CFCCCCCECBC8BFAB80584658
7C785E5A6C7772707173787B818687888B8D9199
28352B2C2C34668D49313D35292729282E2E2F2C3A32322A2B2A343A342A292F494B393B
74988E675C8CC2C9B4A4AFB6B3B9B9B8B7C0CCCFCBC7C9C9C4C9BD7A505B5E5651443838
35332A2E3438465C675A32395E5D4C30292B45704D38429DCCCCC6C6C6C1AC906246445D
836E545B747A75747173888284898B89908C8F99
27382E272C3E7A7D3F2B352B2C282A2B2933302F312E2F2B2B2D404841383A2526272125
528DA17E606C9CC6BDA4ADAFB1B7B2B1B7B9C3CECBCAC7C1C8C5CBB76B515258554E4438
31352C2A2C3341525A51323C504F30262427385A413248A3CCCCC7C0C0B98B6B483C3E68
6C544B647B7C787A7779808782878B8B968D919A
2C302D2E304780652A2F2D31312E2B322F2B2D30323B3B2D333F505A55322A2722211F21
3272989C6B5F79B1C8B0A4A8ACB3B5AFB5B8B6CACEC9C7C1C5C5C5C4AF694C5057554C44
3C322A292A33353D4D432B2F3E3C2D2724285857415679AECACCBFB0A39A61452B2B3B4C
4A3F4F6D7B827C797679808A868C8B9290919499
31303840334F8D53282E2C2C2F2B282928252B344867604A5A536D5E2F292A2823252220
26538C9F85656592C3C6ABACA6AFB2AEB5B5B4C4C9CAC4C7C5C0BEC0C8AE614448504B4B
463A292F3130313035352F2B363132282E304C3E455E80A2C1C0AF9577623B2A2726272A
2C33516E8187817E7D807E8788858E8C93959899
2F3A5256355C8747252D34322C252B292B2A303E6E7A706D66523B2B27272D2922222621
21336A93A6715F7EACC9BDA7A9AAABAFB3B9B9C4C9CDCAC2C4BEBEC3C1C5A659434B493E
3B42333030342F30302F372F33302E2C2E2F2C3238465A8AA2968E684E382A29292B262A
2E436475848884817E8082888A8B8A8F92969499
2A3F553D2D5E82382C2C2A2826242429252A4169797972674828242926272D2F25292722
21234580A195646490B9C6AFA7A4ACB1B0B8B8C2C5CDCAC3C2C0BDBFBFBDC5A75E4A4141
43433935322F30353533353733352D2C2A2F2E2F304F4262776F5C46392E2A272E29262E
3C5673818B8787837D8282858D8D90979394999D
37563A2F3259732E26292724272525203035707971726040262624272B2F33342A20262A
1B1F265A90AD76677B9AC1C3A6A6ACB0ADB6B4B9C4C8CBC3C1C2BABCBEB9C2C6A2584640
3F4B3B36373935323534343A332F32342E302E2F2C33373F544737332E282E2727302837
586F8388898180837B7E83828C8F8B9294949C9D
4A472D303163672E2B262B242826272B305C7B7C6E4F322D2A2E282B292F2E2C25242C33
1D1F1F3978A098806D7DAACBB4A7ADB3AFB1B7BBC4C8CBC5C2BEB9B7BAB4BBC6C89D5041
47464744433F3A3533363433343431322F31302E323B30383936412C2E28262C292A385E
838A8D82827F847D7E83828F8C8E909197999C9E
582F2C2A2F5D652F282622232631303A497D7865412F28252B2B2C392F2F302826242427
1F2523284F91A0886E668DBCC0A6ACAAADB0B3BBC3C6CBC7C9C2BBB9BBB6B6BFC5C99F5A
484E564D5048473C343B4038363935323831323533353532312D2B2D2B29282C35444B6A
8A8C8880807A85837D7A8989899292979B9E9C9F
4027292D36595D2B27262624292E30435C76603A2A292C2F322D282F2D2E332930262423
283D2122276E8F9F77656FA2BFB9A8AAAAB0AEB6BFC4CBCCCBC7BCB9B5ACB1B7BFC6CDA6
5E4F514F5E574D454657544040433E393B3936322C32353C37382F2B2F303038537B6461
7888817C797A7B7C777A84898C8F969A9FA19A9D
31302D2D3C545E312F2D262429333E5F606C573425302B2B2C2E2D342A2E2B2B2A2E2727
443F1E1D223E81A28D6A697CB0C6B5A4AAA8ADB1BBC1C5C8C8CAC0B5B3A9AEADB7BDC6CA
AD6454555F6260646764604A4B49435249513B362F3851695E4B302E434540546F798057
6580777A75737474777A80868D93999C9DA2A09D
2C2C312A305B57342E29252324304D676C6234282B2528262B34322E2D262C2A25282D3B
55261C1E212C6194A173686B8CB9C1B0A4ACA7B2BBBDC2C4CBC8C3B9B1A8A8A6B2BABCC4
CCB275556460686C6B655E5F626666696D6B573E2F456F91847C5344657049676E7B7C6B
5F75746F6D7170666D79818A939B9F9A9EA3A3A2
302F292A3C5351322626282A30315565685B2D272828242A2A302F28282A28312D385262
3D2922262121357B9699716D779EBCC2A7A3ACAEAFB8C0C0C3C7C5BBACA3A1A2A6B7BAC2
C8C8B68264626C7171727875767D78757C816E58335A8195928B7460777D5B5971737C71
69646E635D6461686D7A85989C9D9C9DA1A6A4A5
28252C29344C40372B27263028385766664C352A23222C2D2C2A3128272A3335436C6E41
2B312F221E20214A7B9E8E7B7281A3BFB9A8A8A9ABB2B8BDC1C6C5BFB5A99AA19CB1B5BE
C4C7C7BD956C6F71787E7D7B7C8A8786848A83734F7B9B9D9B9D89718489765B6C656A64
5E575D5A515A5C626F778F9EA5A4A3A3A7AAA2A5
2429312634473B3E372E2A2C33395B5D613C3830242424292829272A3031595360855225
2B495C27201D1F32628EA796827182A8C3B7A1A8ACB1B3B8BBC7C6C4BBA7969A99A8ABBA
BFC1C5C7C09E6F6E7B828283858992938E928A757A90A5A3A09B8F7F818A7E5B685A5E55
544F4B4E484E4E60768796A6AAA9A6A8A7ABAAAD
26242F3345614C463C373D63463F5B5C4327353B2929282B272529232D334F5F66765426
2D5B592E2A1F1D2439759AA7886E688FB7C3ACA7AAADB4B4BEC2C6C7BFACA39696A1A9B3
BCBEC4C5C7C1AB7C74787A86898E97999A958E7B969D9FA3A09A8B857E7E736161565348
48443F3F414F5B798895A1A7ABA7ABA4A7ABABAD
25282727334D3F423A2B3D532A334A543429363E2A28232C29202829345066593D696125
335D3A2D3E2228272A5085A2907264739ABFBDA69EAAB0B2B8BBC1C6C4B3A69B949CA5A8
B2BBBDC0C5C3BDB1887679838B919198999998929DA29B96958F817A6D605D52464D4341
3F39464F59678196A0A9AFABAAADABA8ABAAABB0
212827262A3C4C424E4C3B35293B4F4835302B3C2D2727282A272A2E4A6D6033284E6328
4B5C2B364E28221D2F3A6E8D9E816562799BBFB1A1ABAFB0B7B9BAC3C7BDAF9B979A9CAB
ACBCBDBAC6C3C3C0B9927B7D84898F969C9696979794918C847D74685C4B433B463D3D44
4C585E71848D9BA7A9AFB0ADAFB5B1AEACAEAEB1
242B34232A34353C5642323B344746392F2A2C3A372F322B30302C4260684E46323C602E
5B53252D55311F2725233E75979F6E5B607BAAB9AEA6ADACB4B2B8C0C2C4B5A59A9C989F
A8B6BCBBBDC2C3C2C1BA9979767A8289908C8E8D897F79756E6B645B503F3F4447494B59
6A6F7A8D9EA5A8B0B3B0AFB1B3B4B3B4B0ACACAC
2828362E2730302F383738343F4A393329302F36392D2B272F48464F5A52323D3D345733
694E262F5C341D2727202A4C84A6836C5C6488B0BFAEA9AAACAFB5B8BEC2BBA9979A989E
9EB6BABEBEC2C4C2C1C2C19E7666686E76787977756C666067655B534D57555D656B727D
8592989FA7AEB0B9B5B5B0ADB1B3B2B1AFAFADAA
262B412C2C2E383433392A34353A302B2F2A2C353A372E323839352E4A462F2B2C386049
6C3E30325F422A25201D232B6D8B9982635D6C8FB5C1ACA5ACAEB3B2BFC0BBAD9A9D999C
9DADB8BDC0C3C4C6C5C0C0BFAA785555575861616066635B6068646456666E737A7C8690
9CA3A6ADAFB3B3B6B6B5B1B2B3B0B0AFB5ADAAAF
23263D3233393F39342F2F2F3340322831292A2B342C2E353335312C47372A2929306555
6C3929325B5B37322E291E233B798CA0785F647297C6BAA9ABA6A7B0B9B9B7ABA39A9B96
9BA4B3BDC3C1C0C2C5C0BEBBB9B0894F454755595D656A6E6874797D7E7D84878994989E
A6A6ACB1AFB5B4B4B7B5B5B4AEB3B3AFAFB2AFB4
262230373235484D463E3C323E432D282C28252A282D3132333A332F57472424262C5465
6C3C23234A6D4145503B27212A457D9D97745B657DAAC6B9A4A8A7ABB3B3B7ABA69A9C96
9DA6B2B8C0C0C0BEC6BFBEBFBBB6B8A36D4E4A5266756E797986898E93919498989EA4AB
AAAEAEAAB1B4B0B4B6B4B0B4AEAEB1B0B1B2AFB5
22292F33292A32405A615F5043463A3A312B272C292A2C3435382B315A582D2326263C69
633D25243A6A412C3440362E2F2B5883A689605D6187B4C2AFA3A6B0ACB3B2AEA5A69B9C
9EA7B3B7BFBEBEBABFBDB9B4B9B4B6B5A5896C64687C7B8A8A8E939499A0A3A3A5A5A8A9
A6AEB1AFB2AFB0B3B3B4B2B0B2B0B1AFB4B7B5B8
2621253725282F384853666E565056433E312C2C2D2D313E38332D2B476F2F2728263864
753D29252C5C662A2B30383226242E648E9A735F596994B4B9ACA0A9A6B0ABAEA9A59FA1
9EA7B0BDBFBEBABAB9BFBCB7B2B6B2B0B4ACA28C7C858B9397969E9FA2A1A3A4A7A4A6AF
A9A8AEB0AEB1B1B2B1B3B6B7AFB5B2AFB6B6B7B7
27292A34372334474B444E687857494F48353127282F28383D31252B4472332A282B3F5E
723E36292B417D3A29242D342E21223E768C906956597290B9B89FA0A7A7A5A8AAA59D9F
A1A9AFBEBEBEBDBAB5C0BAB7ADAFB2B8AFAEB2A89E959598A0A0A1A3A3A7A5A5A7A3A7A9
A7A9ABABAEAFB4B1B1AFB1B2B2B1B0B0B4B2B8B8
363424283D2C3A3F3B3B33476D71423946363425272E2C3C37292827376B4D272A2C3F5D
5D3A3B3B282A5D753E282C282520292B49788775635C66799ABBB0A1A0A4A3A5A29C9E9E
A3A6AFBCBEC2BCB7B4BCB7B8B2AAAEB9B5ACA9A6A6A79B989AA1A4A8A2A4A6A4A4A1A6A3
A9A7A7ACABB4B2ADB0B0B0B2B0B2B4AEAEB1B6BC
404F2B2433373D2F322D2E37426B686547363B2A25222B3B372E26293759642A252A4751
583940432F273C78714130231D1E2020325372767E6C636A839EB4AEA29DA1A1A09FA1A1
A0A6ADBCBBBEBEB5B7B9B7B4AC9CA2B6B9B6ACA3A7A6A49B9A9A9CA1A6A9A4A1A3A29EA4
A9A7A6A8ADB0ADAEADAEAFB1B2B4B4B1B2B4B8BE
3A6234292839282524272C363E4D6369623F3637282930393C2E2B2C2D52642D262D4A3C
3E392931322D2E638C61291F1F1D1F21283E6C8E97847C716E86A7BCAD9D9EA3A09FA2A1
A6ACAFBBBCBABBBCBBBBBBB2AE908FABB5BCB8A7A9A7A6A19E9A9B9CA0A5A6A39E9DA3A1
A6A1A8A8B0ABB0ADADB0B0AEB4B5B6B2B6B8B9BE
274A5432313C2A2525283452483E395A62533D322628293239372C292940663B273B5A31
343225263245344F7A532120231E1E203162678E8EA1887D6A7488A3B2A5A0A4A19CA2A2
A5AFB3C0BCBAB9BBB8BBB9AFA48A84ABB0B9C3B8AEA8A69F9C9E9C9B989EA09E9E9EA3A0
A2A6A5ACAAAEAFABACACB0AFAFB4B4B3B7B6BCBD
2931453327302C26293449613B2E293B55584A392E2B2F3831392A2C2A3C5F412B455D33
2D37272B2E3D364F653F241F2120202C4F7D675F729BA187746F7A84ABAFA3A4A29DA6A6
AAB4B5BDBBBAB6BFBBB8B1A098747DA9B0BCC3C0B6AFA6A2A199979B969B9A9B999BA0A4
A1A3A5A9AAADAAA9ACAFB1B1B4B0B7B5B7B5BDC1
2926363728292B2C3348684B3625322E3E574E35342D3C362F3B2A302A36594B323D4E2F
3137312E422D344E533F23231F20243373865A3156819F947D6F777A90B7A99DA2A5A5AB
AEB3B3BABEBAB9BBBBBAAE929A7681ACABB8C0C2BEB8AAABA19D999CA2A59A989B98A1A1
A0A3A2A8AAAEADACAEADB3AEB3B0B0B2B5B7BBBD
2328292E292A2A34476B5F3B312B2F30334D5C46362D2C35383A2D2C2E334A542F343B28
2F2E3451562A324D51412B2823202B45947B4B202C6687A0907A777F8095B1AA9DA7A7AE
B1AEB0BCC3BBB8BBB9B9AC8C9B7D88B0ADB1BAC0C5C1B6AFA9A4A09C9BA9A2939C9D9F9D
A99DA1A8A9A9ABAEAEADAEAEB3B0B0B9B8B8BAC3
2B282B2B292A2B335A6C4D3F3E3D342F3F41484B312F2A32394732312C303D523F38382F
282C3868612E4A514C482F2722242E6E91692E1D2336698AA28A787A727B96BAABA6A6AC
ADACB3BFC2BCBABAB4B9AF8998878BAAA6ADB4BCC5C9C0B2ACA7A2A19FA1AAA29C96999B
A1A09CA3A6A9AAABAEAAAEACB0ABB2BDBBB8BFC1
252729232D282F45685733474B4E352B2C2F3A423131313039383536333239484B3A3926
272C386A5B3C67434251473733344F9A88512A1F212041788BAA8579707781A2B6B3AAAA
AAADBBB8BBBEB4B4ADB6B2939A8F95A7A1A4B2B9C6C6C5BCAEAAA2A5A6A1A4A6A797939A
9A9E9BA5A2A9A5A8ABADAFABADB4B5B8B7BCBEC3
2B27252C2929314D6E492C3336383E332E2D353D47302D3337333A423131373B483D3526
242E4769594E643C4B59615D565677A68A5E271D1E202A46769A9B83787B7881AABEB6A5
AAACB9B3B8BBB6B5ACB5B399919298A7A0A3AEB6C3C9C7C3B6ADA5A7A8A9A49FA0A69493
989B9CA09FA3A2A6ADAAA9A8AEB3B7B4BABBBDBF
2D2926272E282B576E3E272B2E2A38403F2F353744342C2F34383D373132312E443C312E
313C4B5548595B4568655F52533E68A48C6F36231D1D20295285979B8079727B8EAFC0B7
A6ACB8B5BAB0B2B0B3B3B1A18D90A4A6A6AAB1B7C0C7C5CABEB0A8A6ADADABA4A2A3A49D
95929B9CA1A0A2A6AAABABAAA8ACB4B8BBBDC0C1
3A2729252E39345B693F2527272F3047513E303840422B292D383438362A2B2E3A483B2D
3938334649666C6F79594C3B3B2D5E986A41251F1C201D252E5983A196857C737B93B4BD
A9AAB0B8B9AEAEA9A8ABAE998A90A7A8A7A6B6BABDBFBFC4BFB3ABA5A9ACA7A7A9A7A2A5
9991969B9D9C9FA6A6A8A7A9ADAFB7B8BAC1C2BE
322B32262F3538696D41272A292F2E414C47382C363D302D333732423537292E36413C38
3734323F607269787E50402A35366889582920262024221E24365D91A994847B777D95B6
B9A9A8B6B3AEAAA6A3B0A3948B8FA9B5ADACAFAEB9BEC3BFBAB6ACA7ACABA7ABADA8A7AB
A5A0959394979DA5A6A9ABA8ADADB3B7B9BEBFBE
3F372E2A2C2C3C686D4D2E312C2B2B303E473F32333B353235313736442E2B2E3B3E4039
3232374E636E675C7A3F372D333B8089472524281F24232823292B6291A5958174727BA0
B5B9A5AEADA8A9A1A8A8AA96878EA9B6B1A9A8AFB9BCC0C6B9B8AFA7AAABA9AAACA9ABAE
AAAFA19693959CA3A6A5A9A7AEACB2B0BABDBFB9
4F5247332B2C35666D49342D2A2A2C2E3646463A3B3C392A2B2E2F2F3B353134433E4239
3634445A60633B436A372C2F3450908137292D2A27242123202124346B9BA08F786B6A7D
9BB5B5ACABA5A5A6A6A7A394848DA7B1ADA39FB1BAC1BEBDB8B7B1A7A7A7A8AAABABAAAB
ADAEACA79C9395A2A0A2A9AAADAFB0AEB6BABCBB
5C5C5A43392E3754685A322D292A2D262D4043372E413A322C2E342B303A3C414C3A3B41
353448545C4F3137613A2C2E406F8F712C2E292327262322211F2025367097A88E746772
83A0B3BFB1A9A4A5A4A5A08E8489A4A9A59E9FA9B6C1BBB5ADB6B4ABACACA9A9ACA6A8A4
AAA8B2B3AF9D8A939D9FA6A7A9ACAFAFB4B9BBB7
43424435342E2E5561623E2D2A272D292D343B2E2E383E33312F36313340514C4A413D44
39414D465950292B4B3B352D59888A5E272926242E282323211D1E1F264173A4AC887167
74879FB6BFADA6A4A6A5A38D86809BA7A4ACACA2B0C0BFB6ADACBDAEA7ADAAA9AAA1A7A0
A8A3AEB0B7B59E8F999FA6A5AAB2ADAFB4BBB4B9
50563F2F2E3233515E604D322B2A29272D3237332F313B3332352E333853544848454245
41433A4061562B2E3E40373C57928E5B28272C2D2B2A25242A211E1E21254A85A49C8970
6A7284A0BABDA7A4A5A4A386808399AFB5B6AEA4B2C1C0B8B9B3BBB3A9A7A6A0A8A0A4A1
A5A4AEAFB4BBB5A59B9C9BA4A7AEACADB5B6B3BD
7569472D272B2D3E575F562C2D292F262B2F36342D2B32302D3134384A564F453A3F494B
4540314562582B2D3C3C2C32518E8558313E404B433E2E29262423231F212956829AA088
716C68789FB8B5A0A7A298807B8EA0BBBAB1B4A6B7BCC3BCBCBEB8B5ADAAACA2A4A39FA1
9E9FA7B1B4B6BCB1B09F989CA4A8A8A7AFB0B4BA
786857302C262B363F5B5D362D2F2C2B352A2A2A2B2E30312B37434C54504E3B3F485655
45382838675324232D392B3B629187635651646F63593325212A22241F22282E50869FA2
81665D637C9EB5ABA1A48E7A7B86B0BEBAAEAFB4B5C0C1BFBFC1BFB5AEAAA6A2A5A29F9C
A19FA6AAADB5B9B6B2B0A29EA0A4A7ADADADB0BB
725D342D26292F3C33435847413330302B2D312D3132382F3134465C50533B3F4B4E594B
3D2C2E3A625325232A3731537288876B685E5F5D48352523262A242125242521325B839A
94755A53667696B4B6A589788D95ACBBBCB6B0B5BBBABCC0C2C1C1BDB6B3A7A9A5A5A1A1
A1A6A5AAAFACB4B7B6B2ADA7A4A1A6ABADACB1B8
76522E272B313B342B3C54503D39312C2B2D2F2F352F2E2B2F3E585F58423A415557604D
2B272F405750252A2C3A5C687D8D865C463F362F2E2A31292A26292322222428262F5F7E
937A6669605C7795B5AE8677A69EA7BCB6B4B4B5B6B5BABCC1BEBFBEB9B4B1A9A2A49B9C
A2A4A5A8ABACB0B5B6B3B1A6A29BA0A5ACAEB6B6
765D4335353D392E2B384E5F4A36342B2D333129312F3233394A62594A3E45475254613B
2B2F3648564127282E4776757E8162392A2A2D2F2E3031342B2F2C2E232222242629375F
767C6C755C4E5B7793A38B7AB19893B9B5B3B6B4B8B6B8BABCBBBDBBB6B5B3AAA5A5A1A0
A1A0A6A4A6ABACB3B9B4AFACA7999CA39EA5AEB5
6D5E56434A534433313249665949412E33342A2A302B2F343346614B3B454458555B5945
292D37485036222F3B5A76857C6F4B2A2B2C302E333A312B2929292C2D282A2324242736
5C696E7A6B4F4F5F6F89827DB19785B3B7B4B7B1B6B2B6BBB6BBBDBBB8B4B4AFA9A7A1A2
A3A5A7A6A6A5ABB1B6B6B0ACABA39A9DA5A7A9A7
6A66584F67625D4E463B44575A4F4233342E2F2D2E2B31353D4A55514655444855604C3D
3825384B4F3F282C5E597B806C5E35292D2F322D31323234302C2A31332B2F21272C2635
3C536F8A765649545D6C657CB19A86A7BDB7B7AFB3B7B6B6B7B9BDBFBCB9B6B6ADACA4A2
A0A9A8A9AEAEB0B3B1B8B0AEB1AB9D9DAAADA8A6
766F5C5B7C716A595553494A514D4C3D3E3B3230292A383A484D484E434145455551473E
3B27364C51382636715B79785F5832282C2B2F3A2F2C2D30303631303A2F292A2C292729
2C415F6C846B585559614F72A7A1839DB6B0AEA9B1B7B1B0B3B5B7BBBCBCB7B2ABADADA5
A3A6ABACAFACB3B3AFB2B4B3B0A9A7A0AFB3ACAD
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf0001P38h=P205eMG@80IVIV0P25QHD30;^k^`80]KFe
0P10@40402TY:@8092@T0P0X:2P302HV9P80;Bd]0P12@T82059BDP80>3Ph0P0c<c<203Ti>@<0<S8b
0P0i>CT402l_;`80>3Ph0P0e=CD203Ti>@<0;bl_0P0j>SX203Lg=`80@d=30P1;Bd/2055AD@80?clo
0P0k>c/303Ph>080;bl_0P0];Bd202HV9P80:b/[0P0X:2P203hn?P<0JVYZ101VIVH205YJFP80LG5a
0P1UIFD205=CD`<0G5aL0P1RHV8206MWI`80JVYZ0P1cLg<206m_K`80MWIf0`22PX8207emO@80O7al
1023Ph<207]kN`80Ph>30`1mOGd20861P@80PX:20P1nOWh208>3P`80QHF50P28R8P508V9R@@0R8R8
0P27QhL208b<S080SXj>0`2BTY8208^;R`80SXj>0P2<S8`2092@T080S8b<0P28R8P308V9R@80RXZ:
0P2;Rh/208j>SP@0RXZ:0P2=SHd308j>SP80RXZ:0P2BTY8208j>SP80Shn?2@2BTY8209>CT`80T92@
0P2=SHd2096AT@80UIFE0P2CTi<308n?S`80SXj>102BTY8209FEU@@0T92@0`2IVIT209BDU080Ti>C
0P2FUYH209^KV`80UiNG1@2KVi/209jNWP80X:2P0P2/[:`20;6a/@80a<C40P3?cll30<_;b`80dM7A
0P3?cll20;jn_PP0b>3H00060<SPf080GEeM0P1VIVH208F5Q@<0^k^k0P2e]KD20410@0@0:BTY0P0T
92@202PX:0<09RHV0P0];Bd20492@P80DU9B0P0h>3P203<c<`80>CTi0`0b<S8203Ti>@@0;bl_0P0h
>3P203De=@80>CTi0`0_;bl203Xj>P80=cLg0P13@d<204];B`80DE5A0P0o?cl203/k>`<0>3Ph0P0_
;bl202d];@809RHV0P0[:b/202PX:080?Shn0`1ZJVX406IVIP80FUYJ0P1aLG4206EUI@80De=C0`1L
G5`2069RHP80IfMW0P1ZJVX207=cL`80Kfm_0P1fMWH308:2PP80OGem0P1lO7`408>3P`80Ng]k0P23
Ph<307emO@80PH610P22PX8207inOP80Ph>30P25QHD208R8R0D0RHV91028R8P208N7Q`80S8b<0P2>
SXh309:BTP80Rh^;0P2>SXh208b<S080T92@0P2<S8`208R8R0<0RHV90P2:RXX208^;R`80SXj>102:
RXX208f=S@<0SXj>0P2:RXX209:BTP80SXj>0P2?Shl909:BTP80Ti>C0P2@T90208f=S@80TI6A0P2E
UID209>CT`<0Shn?0P2>SXh409:BTP80UIFE102@T90309VIV@80U9BD0P2CTi<209JFUP80Vi^K0P2G
UiL509^KV`80WYjN0P2PX:020:b/[080/K6a0P34a<@20<o?c`<0bl_;0P3AdM420<o?c`80_[jn2038
h=P000H0b>3H0P1JFUX205UIF@80L71`0`2CTi<20<71`@80W9bL0P0n?Sh202PX:080;2`/0P0Y:BT3
02@T9080:RXZ0P0g=cL203Hf=P80<30`0P0d=3@203Ph>0D0=cLg0P0[:b/2038b<P80>c/k0P0`<302
038b<P<0;bl_0P11@D4203De=@80A4A40P1<C4`204e=C@80@T920P0f=SH303Lg=`80;bl_0P0^;Rh2
030`<080:b/[0P0W9bL20492@P<0JFUY0P1QHF4206ATI080H61P0P1jNWX206ATI080BTY:0`1LG5`2
069RHP80JFUY0P1]KFd607EeM@D0O7al0P1nOWh207YjNP80PX:20P24Q8@507moO`80OWin0P20P802
07moO`80QHF51026QXH308Z:RP80Rh^;0P28R8P208V9R@@0Rh^;1@2@T90208R8R080S8b<0P2:RXX2
08n?S`80Rh^;0P2?Shl308N7Q`80R8R80P2;Rh/208f=S@80Rh^;0P2?Shl208j>SP<0SHf=102ATI42
09>CT`@0UIFE0P2BTY8208n?S`<0TI6A102BTY82092@T080UYJF0P2HV9P209VIV@<0TI6A0P2EUID4
09BDU0@0TY:B0P2CTi<509NGU`80V9RH0P2FUYH209ZJVP@0Vi^K0`2PX:020:6QX@80YjNW0P2ZZZX2
0:j^[P80a<C40P3?cll30=7Ad@80cLg=0P3<c<`20<30`0P0b>3H00060<SPf080FUYJ0P1IFET2071`
L0<0Ti>C0P31`L4209bLW080?Shn0P0X:2P202`/;080:BTY0`0T92@202XZ:P80=cLg0P0f=SH2030`
<080=3@d0P0h>3P503Lg=`80:b/[0P0b<S8203/k>`80<30`0P0b<S8302l_;`80@D510P0e=CD204A4
A080C4a<0P1=CDd20492@P80=SHf0`0g=cL202l_;`80;Rh^0P0`<30202/[:`809bLW0P12@T8306UY
J@80HF5Q0P1TI6@2061PH080NWYj0P1TI6@204Y:BP<0G5aL0P1RHV8206UYJ@80KFe]1P1eMGD507al
O080OWin0P1jNWX208:2PP80Q8B41@1oOgl207inOP80P8200P1oOgl208F5Q@@0QXJ60`2:RXX208^;
R`80R8R80P29RHT408^;R`D0T92@0P28R8P208b<S080RXZ:0P2?Shl208^;R`80Shn?0`27QhL208R8
R080Rh^;0P2=SHd208^;R`80Shn?0P2>SXh308f=S@@0TI6A0P2CTi<409FEU@80TY:B0P2?Shl3096A
T@@0TY:B0P2@T90209JFUP80V9RH0P2IVIT3096AT@80UIFE102DU9@409:BTP80Ti>C1@2GUiL209RH
V080UYJF0P2JVYX409^KV`<0X:2P0P2QXJ420:NWY`80ZZZZ0P2^[Zh20<C4a080clo?0`3AdM420<g=
c@80c<c<0P30`<080<SPf0001P38h=P205UIF@80FUYJ0P1OGel3079bLP80VYZJ0P32`/8209FEU@80
>SXj0P0Z:RX202HV9P<0:RXZ0P0];Bd203Ph>080=3@d0P0_;bl203Hf=P80A4A40`0h>3P2038b<P80
;Rh^0P0c<c<203De=@80<c<c0P0/;2`303@d=080?Cdm0P0h>3P204Y:BP80@D510P0m?Cd20492@P80
;Bd]0`0^;Rh203@d=080<30`0P0/;2`202TY:@80:RXZ0P11@D4306=SH`80I6AT0P1WIfL205mOG`80
Ng]k0P1IFET2055AD@<0GUiN0P1YJFT207IfMP80KVi^0P1]KFd407MgM`<0N7Qh0P1mOGd207inOP80
PH610P22PX840861P@<0P8200P27QhL208>3P`80Ogmo0P22PX8208B4Q080Ph>30`2;Rh/208N7Q`80
QXJ60P29RHT208^;R`80Shn?0P2<S8`3092@T080S8b<0P2;Rh/208R8R080RHV90P2;Rh/209:BTPD0
RXZ:0P2>SXh2092@T080SHf=0P2;Rh/508j>SP80UYJF0P2DU9@209>CT`@0UIFE0P2DU9@509FEU@80
UiNG102BTY8209NGU`@0W9bL0`2CTi<209BDU080UiNG0P2FUYH2092@T080U9BD0P2ATI4309JFUP80
U9BD0P2EUID409^KV`80VIVI0P2KVi/309ZJVP80WIfM0P2TY:@20:^[Z`80/;2`0P34a<@20=CDe0<0
dm?C0P3>c/h20<g=c@80aLG52038h=P000H0b>3H0P1IFET205YJFP80GemO0`1bLW8209ZJVP80`/;2
0P2EUID203Xj>P80:RXZ0P0V9RH302XZ:P80;Bd]0P0h>3P203@d=080;bl_0P0f=SH204A4A0<0>3Ph
0P0b<S8202h^;P80<c<c0P0e=CD203<c<`80;2`/0`0d=3@203dm?@80>3Ph0P1:BTX20451@@80?Cdm
0P12@T8202d];@<0;Rh^0P0d=3@2030`<080;2`/0P0Y:BT202XZ:P80@D510`1SHf<206ATI080IfMW
0P1OGel207]kN`80FEUI0P1ADE4305iNGP80JFUY0P1fMWH206i^KP80KFe]101gMgL307QhN080OGem
0P1nOWh20861P@80PX:21021PH430820P080QhN70P23Ph<207moO`80PX:20P24Q8@208>3P`<0Rh^;
0P27QhL208J6QP80RHV90P2;Rh/208n?S`80S8b<0`2@T90208b<S080Rh^;0P28R8P208V9R@80Rh^;
0P2BTY8508Z:RP80SXj>0P2@T90208f=S@80Rh^;1@2>SXh209JFUP80U9BD0P2CTi<409FEU@80U9BD
1@2EUID209NGU`@0TY:B0P2GUiL409bLW0<0Ti>C0P2DU9@209NGU`80UYJF0P2@T90209BDU080TI6A
0`2FUYH209BDU080UIFE102KVi/209VIV@80Vi^K0`2JVYX209fMW@80Y:BT0P2[Zj/20;2`/080a<C4
0P3De=@30=?Cd`80c/k>0P3=cLd20<G5a@P0b>3H00060<SPf080H61P0P1IFET205eMG@<0IVIV0P1l
O7`20:b/[080`<300P1^KVh202l_;`80:RXZ0`0T92@202PX:080:b/[0P0Z:RX202/[:`80?Cdm0P10
@403030`<080<c<c0P0`<304034a<@80:RXZ0P0^;Rh303Hf=P80?Shn0P0_;bl204i>CP80A4A40P0n
?Sh203`l?080<C4a0`0];Bd203Hf=P80;bl_0P0W9bL202HV9P80:RXZ0P16ATH306a/K080IFEU0P1X
J6P205aLG080MgMg0P1HF5P205]KF`<0Hf=S0P1UIFD206m_K`80L71`0P1aLG42079bLP80MWIf0`1i
NGT207emO@80Ng]k0P1nOWh20861P@80P8200P22PX8308B4Q080Ogmo1022PX820820P080R8R80P27
QhL308^;R`80R8R81029RHT208j>SP80SHf=0P28R8P308f=S@80SXj>0P2<S8`208R8R080S8b<0P2@
T90209:BTP<0SHf=0P2<S8`2092@T080SXj>0P2CTi<208f=S@80U9BD0`2ATI4209JFUP@0U9BD0P2I
VIT209NGU`80UIFE1@2CTi<209VIV@80V9RH0P2IVIT209RHV080VIVI0P2PX:0309ZJVP80VIVI102C
Ti<209:BTP80UYJF0P2@T90509NGU`80U9BD0P2FUYH209VIV@80UYJF0P2JVYX309VIV@80WIfM102U
YJD20;2`/080`/;20P3Bd]830<o?c`80c/k>0P3<c<`20<71`@P0b>3H00060<SPf080H61P0P1IFET2
05eMG@<0IVIV0P1lO7`20:b/[080`<300P1^KVh202l_;`80:RXZ0`0T92@202PX:080:b/[0P0Z:RX2
02/[:`80?Cdm0P10@403030`<080<c<c0P0`<304034a<@80:RXZ0P0^;Rh303Hf=P80?Shn0P0_;bl2
04i>CP80A4A40P0n?Sh203`l?080<C4a0`0];Bd203Hf=P80;bl_0P0W9bL202HV9P80:RXZ0P16ATH3
06a/K080IFEU0P1XJ6P205aLG080MgMg0P1HF5P205]KF`<0Hf=S0P1UIFD206m_K`80L71`0P1aLG42
079bLP80MWIf0`1iNGT207emO@80Ng]k0P1nOWh20861P@80P8200P22PX8308B4Q080Ogmo1022PX82
0820P080R8R80P27QhL308^;R`80R8R81029RHT208j>SP80SHf=0P28R8P308f=S@80SXj>0P2<S8`2
08R8R080S8b<0P2@T90209:BTP<0SHf=0P2<S8`2092@T080SXj>0P2CTi<208f=S@80U9BD0`2ATI42
09JFUP@0U9BD0P2IVIT209NGU`80UIFE1@2CTi<209VIV@80V9RH0P2IVIT209RHV080VIVI0P2PX:03
09ZJVP80VIVI102CTi<209:BTP80UYJF0P2@T90509NGU`80U9BD0P2FUYH209VIV@80UYJF0P2JVYX3
09VIV@80WIfM102UYJD20;2`/080`/;20P3Bd]830<o?c`80c/k>0P3<c<`20<71`@P0b>3H00060<SP
f080H61P0P1IFET205eMG@<0IVIV0P1lO7`20:b/[080`<300P1^KVh202l_;`80:RXZ0`0T92@202PX
:080:b/[0P0Z:RX202/[:`80?Cdm0P10@403030`<080<c<c0P0`<304034a<@80:RXZ0P0^;Rh303Hf
=P80?Shn0P0_;bl204i>CP80A4A40P0n?Sh203`l?080<C4a0`0];Bd203Hf=P80;bl_0P0W9bL202HV
9P80:RXZ0P16ATH306a/K080IFEU0P1XJ6P205aLG080MgMg0P1HF5P205]KF`<0Hf=S0P1UIFD206m_
K`80L71`0P1aLG42079bLP80MWIf0`1iNGT207emO@80Ng]k0P1nOWh20861P@80P8200P22PX8308B4
Q080Ogmo1022PX820820P080R8R80P27QhL308^;R`80R8R81029RHT208j>SP80SHf=0P28R8P308f=
S@80SXj>0P2<S8`208R8R080S8b<0P2@T90209:BTP<0SHf=0P2<S8`2092@T080SXj>0P2CTi<208f=
S@80U9BD0`2ATI4209JFUP@0U9BD0P2IVIT209NGU`80UIFE1@2CTi<209VIV@80V9RH0P2IVIT209RH
V080VIVI0P2PX:0309ZJVP80VIVI102CTi<209:BTP80UYJF0P2@T90509NGU`80U9BD0P2FUYH209VI
V@80UYJF0P2JVYX309VIV@80WIfM102UYJD20;2`/080`/;20P3Bd]830<o?c`80c/k>0P3<c<`20<71
`@P0b>3H00060<SPf080GemO0P1JFUX205]KF`<0FEUI0P1`L70208f=S@80_kno0P2c/k<205]KF`80
;2`/0`0W9bL202@T9080:b/[0P0];Bd2038b<P80=3@d0P0^;Rh3030`<080:BTY0P0/;2`2038b<P80
<c<c0P0[:b/202d];@<0<C4a0P0c<c<2038b<P80Bd];0P13@d<203Ti>@80=SHf0P0`<303034a<@80
=3@d0P0b<S8202PX:0809bLW0P0`<30204a<C0<0M7Ad0P1PH60206YZJP80IfMW0P1_Kfl205IFEP80
GUiN0`1SHf<206YZJP80KVi^0P1`L70207=cL`80N7Qh0P1jNWX507MgM`80PH610P1oOgl407inOP80
QHF50`23Ph<408:2PP80O7al0P1oOgl208F5Q@80R8R80`2;Rh/608N7Q`80SXj>0P2;Rh/208R8R0<0
RHV90P2@T90408^;R`80TI6A0P2;Rh/208n?S`<0S8b<0P2?Shl208j>SP80SHf=0P2?Shl208j>SP80
UIFE0`2DU9@209NGU`80UYJF0P2DU9@209FEU@80V9RH0P2FUYH209NGU`<0U9BD0P2IVIT409RHV080
VIVI0P2OWil209^KV`<0UiNG0P2EUID209>CT`80TY:B0P2?Shl209BDU080UiNG1@2JVYX209NGU`80
T92@0P2HV9P409NGU`<0W9bL0P2FUYH20:>SX`80YJFU0P2ZZZX20;jn_P80c/k>0`3AdM420<k>cP80
b<S80P2l_;`80<SPf0001P38h=P205mOG`80FUYJ0P1KFe/305UIF@80L71`0P2=SHd20;no_`80/k>c
0P1KFe/202`/;0<09bLW0P0T92@202/[:`80;Bd]0P0b<S8203@d=080;Rh^0`0`<30202TY:@80;2`/
0P0b<S8203<c<`80:b/[0P0];Bd3034a<@80<c<c0P0b<S8204];B`80@d=30P0i>CT203Hf=P80<30`
0`0a<C4203@d=080<S8b0P0X:2P202LW9`80<30`0P1<C4`307AdM080H61P0P1ZJVX206MWI`80Kfm_
0P1FEUH205iNGP<0Hf=S0P1ZJVX206i^KP80L71`0P1cLg<207QhN080NWYj1@1gMgL20861P@80Ogmo
101nOWh208F5Q@<0Ph>31022PX8207alO080Ogmo0P25QHD208R8R0<0Rh^;1P27QhL208j>SP80Rh^;
0P28R8P308V9R@80T92@102;Rh/2096AT@80Rh^;0P2?Shl308b<S080Shn?0P2>SXh208f=S@80Shn?
0P2>SXh209FEU@<0U9BD0P2GUiL209JFUP80U9BD0P2EUID209RHV080UYJF0P2GUiL309BDU080VIVI
102HV9P209VIV@80WinO0P2KVi/309NGU`80UIFE0P2CTi<209:BTP80Shn?0P2DU9@209NGU`D0VYZJ
0P2GUiL2092@T080V9RH102GUiL309bLW080UYJF0P2SXj<20:FUY@80ZZZZ0P2n_[h20<k>cP<0dM7A
0P3>c/h20<S8b080_;bl2038h=P000H0b>3H0P1RHV8205YJFP80F5QH0`1OGel2065QH@80MWIf0P2P
X:020<S8b080ZZZZ0P0o?cl302PX:0@092@T0P0Y:BT203@d=080<C4a0P0];Bd502`/;080<C4a0P0e
=CD203@d=080<30`0P0b<S8303Ph>080?3`l0P0m?Cd204a<C080@4100P0m?Cd204=3@`80>SXj0`0c
<c<2038b<P80;2`/100`<30202d];@80Bd];0`1gMgL206UYJ@80KVi^0P1QHF4206UYJ@80DE5A0P1N
GUh3065QH@80JFUY0P1cLg<2079bLP80Lg=c0P1dM7@207emO@<0NWYj0P1lO7`208:2PP80OGem1020
P80208>3P`<0Ogmo0P21PH4208:2PP80Q8B40P22PX8208R8R080QHF50`2;Rh/208V9R@80SHf=0P29
RHT408f=S@80Shn?1@2=SHd208Z:RP@0S8b<0P2:RXX208f=S@<0Rh^;0P2<S8`2096AT@80S8b<0P2B
TY8209BDU080V9RH0`2JVYX409NGU`80VIVI102GUiL209ZJVP80U9BD0`2GUiL209bLW0@0UYJF0P2G
UiL209fMW@80VIVI0`2HV9P209VIV@H0U9BD0P2CTi<209FEU@<0V9RH0P2EUID209:BTP80U9BD0P2C
Ti<409NGU`<0V9RH0P2JVYX209jNWP80Y:BT0P2[Zj/20;Rh^080b/[:0`3>c/h20<g=c@80alO70P2k
^k/80<SPf0001P38h=P2069RHP80FUYJ0P1HF5P305mOG`80HF5Q0P1fMWH20:2PX080b<S80P2ZZZX2
03lo?`<0:2PX100T92@202TY:@80=3@d0P0a<C4202d];@D0;2`/0P0a<C4203De=@80=3@d0P0`<302
038b<P<0>3Ph0P0l?3`203dm?@80C4a<0P10@40203dm?@80@d=30P0j>SX303<c<`80<S8b0P0/;2`4
030`<080;Bd]0P1;Bd/307MgM`80JFUY0P1^KVh2065QH@80JFUY0P1ADE4205iNGP<0HF5Q0P1YJFT2
07=cL`80LW9b0P1cLg<207AdM080OGem0`1jNWX207alO080PX:20P1mOGd40820P080Ph>30`1oOgl2
0861P@80PX:20P24Q8@208:2PP80R8R80P25QHD308^;R`80RHV90P2=SHd208V9R@@0SHf=0P2?Shl5
08f=S@80RXZ:102<S8`208Z:RP80SHf=0`2;Rh/208b<S080TI6A0P2<S8`209:BTP80U9BD0P2HV9P3
09ZJVP@0UiNG0P2IVIT409NGU`80VYZJ0P2DU9@309NGU`80W9bL102FUYH209NGU`80WIfM0P2IVIT3
09RHV080VIVI1P2DU9@209>CT`80UIFE0`2HV9P209FEU@80TY:B0P2DU9@209>CT`@0UiNG0`2HV9P2
09ZJVP80WYjN0P2TY:@20:^[Z`80^;Rh0P3:b/X30<k>cP80cLg=0P37alL20;^k^`P0b>3H00060<SP
f080G5aL0P1ZJVX205UIF@<0FUYJ0P1RHV8206EUI@80RXZ:0P33`l<20<O7a`80TI6A0`0g=cL202`/
;080<C4a0P0V9RH202`/;080<S8b0P0X:2P303@d=080<C4a0P0^;Rh2034a<@80<c<c0P0^;Rh202d]
;@<0<C4a0P0g=cL2034a<@80@D510P0m?Cd203`l?080>c/k0P0^;Rh3038b<P80;bl_0P0/;2`202/[
:`80:2PX0P0V9RH204Y:BP<0L71`0P1_Kfl206i^KP@0IVIV0P1DE5@2065QH@D0K6a/101aLG42071`
L080MWIf0P1oOgl307YjNP80NGUi0P22PX8207YjNP80OGem0P1nOWh207emO@<0OWin0P1iNGT207in
OP80Ph>30P24Q8@208F5Q@80PX:20`25QHD208b<S0@0RHV90P2ATI4208V9R@80SHf=0`2>SXh208n?
S`80Rh^;0P28R8P208Z:RP80S8b<0P2>SXh308b<S080Shn?0P2ATI4208n?S`80U9BD0P2FUYH209NG
U`<0VIVI0P2HV9P409NGU`80Vi^K0P2JVYX209JFUP80U9BD0`2HV9P209fMW@80VIVI0P2LW9`209^K
V`80W9bL0P2KVi/509NGU`80U9BD0P2BTY8209ZJVP80V9RH0P2EUID309>CT`80TY:B1P2DU9@2096A
T@80T92@0`2DU9@209NGU`80UYJF0P2LW9`20:VYZ@80][Jf0P36a/H30<g=c@80b/[:0P31`L420;Ng
]`P0b>3H00060<SPf080G5aL0P1ZJVX205UIF@<0FUYJ0P1RHV8206EUI@80RXZ:0P33`l<20<O7a`80
TI6A0`0g=cL202`/;080<C4a0P0V9RH202`/;080<S8b0P0X:2P303@d=080<C4a0P0^;Rh2034a<@80
<c<c0P0^;Rh202d];@<0<C4a0P0g=cL2034a<@80@D510P0m?Cd203`l?080>c/k0P0^;Rh3038b<P80
;bl_0P0/;2`202/[:`80:2PX0P0V9RH204Y:BP<0L71`0P1_Kfl206i^KP@0IVIV0P1DE5@2065QH@D0
K6a/101aLG42071`L080MWIf0P1oOgl307YjNP80NGUi0P22PX8207YjNP80OGem0P1nOWh207emO@<0
OWin0P1iNGT207inOP80Ph>30P24Q8@208F5Q@80PX:20`25QHD208b<S0@0RHV90P2ATI4208V9R@80
SHf=0`2>SXh208n?S`80Rh^;0P28R8P208Z:RP80S8b<0P2>SXh308b<S080Shn?0P2ATI4208n?S`80
U9BD0P2FUYH209NGU`<0VIVI0P2HV9P409NGU`80Vi^K0P2JVYX209JFUP80U9BD0`2HV9P209fMW@80
VIVI0P2LW9`209^KV`80W9bL0P2KVi/509NGU`80U9BD0P2BTY8209ZJVP80V9RH0P2EUID309>CT`80
TY:B1P2DU9@2096AT@80T92@0`2DU9@209NGU`80UYJF0P2LW9`20:VYZ@80][Jf0P36a/H30<g=c@80
b/[:0P31`L420;Ng]`P0b>3H00060<SPf080CTi>0P1YJFT205EEE@<0DE5A0P1JFUX206UYJ@80U9BD
0P2c/k<20<O7a`80aLG50`1nOWh203Ti>@809bLW0P0U9BD202`/;080:b/[0P0Z:RX3034a<@80<S8b
100h>3P203/k>`80>CTi0P10@40303hn?P80@d=30P12@T8204a<C080@D511012@T8203`l?0D0>SXj
0P0_;bl203Ti>@@0>SXj0P1LG5`3079bLP80M7Ad0P1WIfL2071`L080HV9R0P1MGEd206=SH`D0Jf][
0P1_Kfl2079bLP80N7Qh0P1kNg/20820P0D0Ogmo0P1mOGd207moO`80PX:20P25QHD208B4Q0D0Ph>3
0P26QXH20861P@80QHF51028R8P308Z:RP80Shn?0P2:RXX208n?S`80TI6A0P2:RXX208^;R`<0RXZ:
102<S8`208^;R`80SXj>0P2=SHd208b<S0D0T92@0P2EUID2092@T0@0VIVI1`2JVYX209bLW0@0VIVI
0P2KVi/409RHV0<0Vi^K0P2OWil209jNWP80W9bL0P2OWil209fMW@D0Vi^K0P2HV9P409NGU`80VYZJ
0P2HV9P209FEU@<0UiNG0P2EUID209:BTP80U9BD0P2CTi<2096AT@D0SXj>0P2EUID209RHV080WinO
0P2SXj<20;6a/@80_kno0`39bLT20<S8b080`<300P2`/;080<SPf0001P38h=P204i>CP80JFUY0P1E
EED3055AD@80FUYJ0P1YJFT209BDU080/k>c0P37alL20<G5a@<0OWin0P0i>CT202LW9`809BDU0P0/
;2`202/[:`80:RXZ0`0a<C42038b<P@0>3Ph0P0k>c/203Ti>@80@4100`0n?Sh204=3@`80@T920P1<
C4`20451@@@0@T920P0l?3`503Xj>P80;bl_0P0i>CT403Xj>P80G5aL0`1bLW8207AdM080IfMW0P1`
L702069RHP80GEeM0P1SHf<506][J`80Kfm_0P1bLW8207QhN080Ng]k0P20P80507moO`80OGem0P1o
Ogl208:2PP80QHF50P24Q8@508>3P`80QXJ60P21PH4208F5Q@@0R8R80`2:RXX208n?S`80RXZ:0P2?
Shl2096AT@80RXZ:0P2;Rh/308Z:RP@0S8b<0P2;Rh/208j>SP80SHf=0P2<S8`5092@T080UIFE0P2@
T90409VIV@L0VYZJ0P2LW9`409VIV@80Vi^K102HV9P309^KV`80WinO0P2NWYh209bLW080WinO0P2M
WId509^KV`80V9RH102GUiL209ZJVP80V9RH0P2EUID309NGU`80UIFE0P2BTY8209BDU080Ti>C0P2A
TI4508j>SP80UIFE0P2HV9P209nOW`80Xj>S0P2a/K420;no_`<0bLW90P38b<P20<30`080/;2`2038
h=P000H0b>3H0P1ADE42061PH080Hf=S0`1IFET2069RHP80MWIf0P2CTi<209bLW080`L710P3;bl/3
0<?3``80M7Ad0P0h>3P203De=@80=cLg100f=SH30451@@80@4100P0n?Sh403Lg=`80<c<c0P0h>3P3
03Xj>P80=3@d0P0m?Cd203lo?`80>3Ph0P0f=SH203@d=080;2`/0`0^;Rh2038b<P809bLW0P0];Bd2
02`/;080<S8b0P1JFUX306m_K`80L71`0P1MGEd206i^KP@0EUIF0P1PH60306ATI080JVYZ0P1`L702
07AdM080MWIf0P1hN7P207]kN`<0N7Qh0P1mOGd208:2PP80NWYj1020P80207inOP<0Ogmo0P22PX82
0820P080Q8B40P23Ph<208B4Q080R8R80`2=SHd208^;R`80RHV90P2=SHd208n?S`80RXZ:0P2>SXh3
08f=S@80RXZ:0P2<S8`208n?S`80Ti>C0P2?Shl5096AT@80Ti>C0P2GUiL209JFUP80Vi^K0P2GUiL2
09fMW@<0UiNG1P2IVIT409ZJVP80W9bL0P2KVi/309nOW`80W9bL0P2PX:0409fMW@80W9bL0P2MWId3
09ZJVP80UYJF0P2DU9@209ZJVP80V9RH0P2IVIT209NGU`<0UYJF0P2DU9@209JFUP80UiNG102BTY85
096AT@80Shn?0P2EUID209jNWP80XJ6Q0P2/[:`20;Zj^P<0`/;20P35aLD20;^k^`80Z:RX2038h=P0
00H0b>3H0P1ADE42061PH080Hf=S0`1IFET2069RHP80MWIf0P2CTi<209bLW080`L710P3;bl/30<?3
``80M7Ad0P0h>3P203De=@80=cLg100f=SH30451@@80@4100P0n?Sh403Lg=`80<c<c0P0h>3P303Xj
>P80=3@d0P0m?Cd203lo?`80>3Ph0P0f=SH203@d=080;2`/0`0^;Rh2038b<P809bLW0P0];Bd202`/
;080<S8b0P1JFUX306m_K`80L71`0P1MGEd206i^KP@0EUIF0P1PH60306ATI080JVYZ0P1`L70207Ad
M080MWIf0P1hN7P207]kN`<0N7Qh0P1mOGd208:2PP80NWYj1020P80207inOP<0Ogmo0P22PX820820
P080Q8B40P23Ph<208B4Q080R8R80`2=SHd208^;R`80RHV90P2=SHd208n?S`80RXZ:0P2>SXh308f=
S@80RXZ:0P2<S8`208n?S`80Ti>C0P2?Shl5096AT@80Ti>C0P2GUiL209JFUP80Vi^K0P2GUiL209fM
W@<0UiNG1P2IVIT409ZJVP80W9bL0P2KVi/309nOW`80W9bL0P2PX:0409fMW@80W9bL0P2MWId309ZJ
VP80UYJF0P2DU9@209ZJVP80V9RH0P2IVIT209NGU`<0UYJF0P2DU9@209JFUP80UiNG102BTY85096A
T@80Shn?0P2EUID209jNWP80XJ6Q0P2/[:`20;Zj^P<0`/;20P35aLD20;^k^`80Z:RX2038h=P000H0
b>3H0P1UIFD205QHF080Kfm_0`1ZJVX206=SH`80M7Ad0P27QhL208V9R@80Y:BT0P32`/830=3@d080
^[Zj0P1;Bd/202l_;`80;Rh^1`0`<30403@d=0@0<C4a0P0];Bd203De=@<0=3@d0P0c<c<20451@@80
=SHf0P0h>3P403Hf=PD0<S8b0P0_;bl402`/;080<30`0P0d=3@205aLG0D0Lg=c0P1OGel206UYJ@80
EEEE0P1DE5@206ATI0<0HF5Q0P1YJFT2075aL@80L71`0P1fMWH207MgM`80Ng]k0`1mOGd207moO`80
P8200P1jNWX207moO`80P8200P1oOgl307alO080PH610P1oOgl208B4Q080PX:20P24Q8@508^;R`80
RHV90P2;Rh/208V9R@80SHf=0P2?Shl208f=S@<0T92@102?Shl2096AT@80SXj>0P2CTi<209BDU0<0
SHf=0P2?Shl2096AT@80Ti>C0P2HV9P209VIV@80Vi^K0`2GUiL209jNWP80VIVI0P2LW9`209fMW@@0
WYjN0P2QXJ430:BTY080WinO1P2MWId209bLW080WYjN0`2KVi/209ZJVP80V9RH0P2JVYX409VIV@80
UYJF0`2CTi<2096AT@80UYJF102ATI4408n?S`D0SHf=102DU9@209VIV@80YJFU0P2c/k<30;Zj^P80
_kno0P2a/K420:6QX@P0b>3H00060<SPf080IFEU0P1HF5P206m_K`<0JVYZ0P1SHf<207AdM080QhN7
0P29RHT20:BTY080`/;20`3@d=020;Zj^P80Bd];0P0_;bl202h^;PL0<30`100d=3@4034a<@80;Bd]
0P0e=CD303@d=080<c<c0P11@D4203Hf=P80>3Ph100f=SH5038b<P80;bl_100/;2`2030`<080=3@d
0P1LG5`507=cL`80GemO0P1YJFT205EEE@80E5AD0P1TI6@3065QH@80JFUY0P1aLG42071`L080MWIf
0P1gMgL207]kN`<0OGem0P1oOgl20820P080NWYj0P1oOgl20820P080Ogmo0`1lO7`20861P@80Ogmo
0P24Q8@208:2PP80Q8B41@2;Rh/208V9R@80Rh^;0P29RHT208f=S@80Shn?0P2=SHd3092@T0@0Shn?
0P2ATI4208j>SP80Ti>C0P2DU9@308f=S@80Shn?0P2ATI4209>CT`80V9RH0P2IVIT209^KV`<0UiNG
0P2NWYh209VIV@80W9bL0P2MWId409jNWP80XJ6Q0`2TY:@209nOW`H0WIfM0P2LW9`209jNWP<0Vi^K
0P2JVYX209RHV080VYZJ102IVIT209JFUP<0Ti>C0P2ATI4209JFUP@0TI6A102?Shl508f=S@@0U9BD
0P2IVIT20:FUY@80/k>c0`2j^[X20;no_`80/K6a0P2QXJ480<SPf0001P38h=P209jNWP80Fe]K0P1S
Hf<3071`L080GemO0P1ZJVX207MgM`80OGem0P2:RXX20:^[Z`<0clo?0P3De=@20:6QX@80>SXj0P0b
<S8202h^;P80;Bd]0`0d=3@203Ph>080=SHf0P0e=CD2038b<P80>SXj0P0i>CT303hn?P80@4100P0n
?Sh203Xj>P80>3Ph0P0c<c<203Ti>@80=3@d0`0e=CD2034a<@80;bl_100a<C4203Ph>080H61P0`1g
MgL20861P@80GUiN0P1WIfL2055AD@80E5AD0P1LG5`306EUI@@0KFe]0P1bLW8207EeM@80N7Qh1`1i
NGT207]kN`80OGem0P1lO7`207emO@80Ng]k0`1hN7P207emO@80PX:20P26QXH408:2PP80QXJ60`25
QHD208J6QP80SXj>0P2:RXX208b<S080RXZ:0P2=SHd309>CT`80SXj>0P2@T90208j>SP80Shn?0P2>
SXh2096AT@<0Shn?0P2ATI4209FEU@80SXj>0P2DU9@209RHV080VYZJ0`2KVi/409ZJVP80W9bL0P2J
VYX209nOW`80WYjN0P2MWId309jNWP80XZ:R0P2KVi/209fMW@80WYjN0P2MWId209jNWP<0W9bL102K
Vi/20:2PX0@0UYJF0P2HV9P709JFUP80T92@0P2EUID208n?S`80RXZ:0`2=SHd208Z:RP80Rh^;0P2=
SHd2096AT@80WIfM0P2TY:@30;:b/P80][Jf0P2UYJD209ZJVPP0b>3H00060<SPf080WYjN0P1KFe/2
06=SH`<0L71`0P1OGel206YZJP80MgMg0P1mOGd208Z:RP80Zj^[0`3?cll20=CDe080XJ6Q0P0j>SX2
038b<P80;Rh^0P0];Bd303@d=080>3Ph0P0f=SH203De=@80<S8b0P0j>SX203Ti>@<0?Shn0P10@402
03hn?P80>SXj0P0h>3P203<c<`80>CTi0P0d=3@303De=@80<C4a0P0_;bl4034a<@80>3Ph0P1PH603
07MgM`80PH610P1NGUh206MWI`80DE5A0P1DE5@205aLG0<0IFEU101]KFd2079bLP80MGEe0P1hN7P7
07UiN@80Ng]k0P1mOGd207alO080OGem0P1kNg/307QhN080OGem0P22PX8208J6QP@0PX:20P26QXH3
08F5Q@80QXJ60P2>SXh208Z:RP80S8b<0P2:RXX208f=S@<0Ti>C0P2>SXh2092@T080SXj>0P2?Shl2
08j>SP80TI6A0`2?Shl2096AT@80UIFE0P2>SXh209BDU080V9RH0P2JVYX309^KV`@0VYZJ0P2LW9`2
09ZJVP80WinO0P2NWYh209fMW@<0WYjN0P2RXZ8209^KV`80WIfM0P2NWYh209fMW@80WYjN0`2LW9`4
09^KV`80X:2P102FUYH209RHV0L0UYJF0P2@T90209FEU@80Shn?0P2:RXX308f=S@80RXZ:0P2;Rh/2
08f=S@80TI6A0P2MWId20:BTY0<0/[:b0P2f][H20:FUY@80VYZJ2038h=P000H0b>3H0P2NWYh205]K
F`80Hf=S0`1`L70205mOG`80JVYZ0P1gMgL207emO@80RXZ:0P2[Zj/30<o?c`80e=CD0P2QXJ4203Xj
>P80<S8b0P0^;Rh202d];@<0=3@d0P0h>3P203Hf=P80=CDe0P0b<S8203Xj>P80>CTi0`0n?Sh20410
@080?Shn0P0j>SX203Ph>080<c<c0P0i>CT203@d=0<0=CDe0P0a<C4202l_;`@0<C4a0P0h>3P2061P
H0<0MgMg0P21PH4205iNGP80IfMW0P1ADE4205ADE080G5aL0`1UIFD406e]K@80LW9b0P1eMGD207Qh
N0L0NGUi0P1kNg/207emO@80O7al0P1mOGd207]kN`<0N7Qh0P1mOGd208:2PP80QXJ61022PX8208J6
QP<0QHF50P26QXH208j>SP80RXZ:0P2<S8`208Z:RP80SHf=0`2CTi<208j>SP80T92@0P2>SXh208n?
S`80SXj>0P2ATI4308n?S`80TI6A0P2EUID208j>SP80U9BD0P2HV9P209ZJVP<0Vi^K102JVYX209bL
W080VYZJ0P2OWil209jNWP80WIfM0`2NWYh20::RXP80Vi^K0P2MWId209jNWP80WIfM0P2NWYh309bL
W0@0Vi^K0P2PX:0409JFUP80V9RH1`2FUYH2092@T080UIFE0P2?Shl208Z:RP<0SHf=0P2:RXX208^;
R`80SHf=0P2ATI4209fMW@80Y:BT0`2b/[820;Jf]P80YJFU0P2JVYX80<SPf0001P38h=P20;Bd]080
RXZ:0P1PH60306ATI080JVYZ0P1NGUh206EUI@80MGEe0P1mOGd208j>SP<0`<300P3De=@20<_;b`80
MgMg0P0`<30202TY:@80:RXZ0`0Y:BT202h^;P80:b/[0P0_;bl202XZ:P@0<S8b0`0c<c<202d];@80
ATI60P11@D4403@d=080=SHf0P0a<C4303<c<`80<S8b0P0Y:BT202XZ:P80;Bd]0P0a<C4206ATI0<0
MgMg0P1iNGT205MGE`80IVIV0P1>CTh205MGE`80Fe]K0`1PH60206i^KP80KFe]101cLg<207YjNPD0
NGUi0P1oOgl207alO080OGem0P1lO7`207inOP80NWYj1@21PH4208B4Q080OWin0P1mOGd208>3P`D0
PH610P2:RXX208V9R@80QHF50P28R8P2092@T080Rh^;0`2ATI4209FEU@80TI6A0P2@T90208n?S`80
TY:B1@2@T90209FEU@@0U9BD0P2EUID209JFUP80WinO0`2JVYX209VIV@@0W9bL0P2IVIT409^KV`80
WYjN0`2PX:0209nOW`80Vi^K0P2MWId20:6QX@80W9bL0P2NWYh309ZJVP80W9bL0P2NWYh209ZJVP80
V9RH0P2FUYH209>CT`<0UYJF0P2@T90208n?S`80TI6A0P2?Shl208Z:RP80QXJ60`27QhL208F5Q@80
R8R80P2=SHd208n?S`80UiNG0P2HV9P30:JVYP80Y:BT0P2FUYH209>CT`P0b>3H00060<SPf080];Bd
0P2:RXX2061PH0<0I6AT0P1ZJVX205iNGP80IFEU0P1eMGD207emO@80SXj>0`30`<020=CDe080bl_;
0P1gMgL2030`<080:BTY0P0Z:RX302TY:@80;Rh^0P0[:b/202l_;`80:RXZ100b<S8303<c<`80;Bd]
0P16ATH20451@@@0=3@d0P0f=SH2034a<@<0<c<c0P0b<S8202TY:@80:RXZ0P0];Bd2034a<@80I6AT
0`1gMgL207UiN@80EeMG0P1VIVH204i>CP80EeMG0P1KFe/3061PH080KVi^0P1]KFd407=cL`80NWYj
1@1iNGT207moO`80O7al0P1mOGd207alO080OWin0P1jNWX50861P@80Q8B40P1nOWh207emO@80Ph>3
1@21PH4208Z:RP80RHV90P25QHD208R8R080T92@0P2;Rh/3096AT@80UIFE0P2ATI42092@T080Shn?
0P2BTY85092@T080UIFE102DU9@209FEU@80UYJF0P2OWil309ZJVP80VIVI102LW9`209VIV@@0Vi^K
0P2NWYh30:2PX080WinO0P2KVi/209fMW@80XJ6Q0P2LW9`209jNWP<0VYZJ0P2LW9`209jNWP80VYZJ
0P2HV9P209JFUP80Ti>C0`2FUYH2092@T080Shn?0P2ATI4208n?S`80RXZ:0P26QXH308N7Q`80QHF5
0P28R8P208f=S@80Shn?0P2GUiL209RHV0<0YZJV0P2TY:@209JFUP80Ti>C2038h=P000H0b>3H0P2]
[Jd20:b/[080LW9b0`1TI6@207EeM@80IVIV0P1SHf<206a/K080LW9b0P23Ph<30::RXP80dm?C0P3G
emL20<30`080DU9B0P0U9BD202HV9P<0:RXZ0P0W9bL202@T90809RHV0P0Y:BT202d];@80<C4a0`0h
>3P203dm?@80@D510P0d=3@2030`<080<C4a0P0`<30202l_;`<0<C4a0P0W9bL202DU9@80:BTY0P0V
9RH202h^;P80IfMW0`1fMWH207UiN@80GUiN0P1TI6@204];B`80EEEE0P1KFe/306MWI`80JVYZ0P1c
Lg<207AdM080Lg=c0P1eMGD207IfMP<0M7Ad0P1kNg/207UiN@80OGem0P1nOWh207emO@80P8200`21
PH4208:2PP80O7al0P1oOgl208>3P`80QXJ60P29RHT308J6QP@0RHV90P27QhL208V9R@80SXj>0P2=
SHd309>CT`80SXj>0P2?Shl2096AT@80SHf=0P2ATI4209:BTP<0Ti>C0P2DU9@209NGU`80V9RH0P2C
Ti<209BDU080Vi^K1@2IVIT409ZJVP80WYjN0P2JVYX209JFUP80VIVI1@2NWYh209nOW`80XZ:R0P2L
W9`209RHV080W9bL0`2IVIT209fMW@80VYZJ0P2GUiL209bLW080UIFE0P2BTY8309BDU080Shn?0P2C
Ti<208f=S@80S8b<0P26QXH208>3P`<0Rh^;0P22PX8208>3P`80QHF50P27QhL208f=S@80Shn?0`2F
UYH208n?S`80Q8B40P26QXH80<SPf0001P38h=P20:f][@80[:b/0P1bLW8306ATI080MGEe0P1VIVH2
06=SH`80K6a/0P1bLW8208>3P`<0XZ:R0P3Cdm<20=OGe`80`<300P1BDU8202DU9@809RHV0`0Z:RX2
02LW9`8092@T0P0V9RH202TY:@80;Bd]0P0a<C4303Ph>080?Cdm0P11@D4203@d=080<30`0P0a<C42
030`<080;bl_0`0a<C4202LW9`809BDU0P0Y:BT202HV9P80;Rh^0P1WIfL307IfMP80NGUi0P1NGUh2
06ATI080Bd];0P1EEED205]KF`<0IfMW0P1ZJVX207=cL`80M7Ad0P1cLg<207EeM@80MWIf0`1dM7@2
07]kN`80NGUi0P1mOGd207inOP80OGem0P20P8030861P@80PX:20P1lO7`207moO`80Ph>30P26QXH2
08V9R@<0QXJ61029RHT208N7Q`80RHV90P2>SXh208f=S@<0Ti>C0P2>SXh208n?S`80TI6A0P2=SHd2
096AT@80TY:B0`2CTi<209BDU080UiNG0P2HV9P209>CT`80U9BD0P2KVi/509VIV@@0VYZJ0P2NWYh2
09ZJVP80UYJF0P2IVIT509jNWP80WinO0P2RXZ8209bLW080V9RH0P2LW9`309VIV@80WIfM0P2JVYX2
09NGU`80W9bL0P2EUID209:BTP<0U9BD0P2?Shl209>CT`80SHf=0P2<S8`208J6QP80Ph>30`2;Rh/2
08:2PP80Ph>30P25QHD208N7Q`80SHf=0P2?Shl309JFUP80Shn?0P24Q8@208J6QPP0b>3H00060<SP
f080QhN70P2GUiL209BDU0<0HF5Q0P1ZJVX207AdM080Jf][0P1/K6`206m_K`80Lg=c0`24Q8@20;^k
^`@0clo?0P2MWId202d];@80:BTY0`0U9BD202`/;0808b<S0P0Y:BT202XZ:P80<S8b0P0j>SX304=3
@`80CTi>0P1JFUX203@d=080=CDe0P0a<C4202XZ:P809bLW0`0`<30202<S8`80:RXZ0P0[:b/202l_
;`80=CDe0P1SHf<307emO@80MGEe101SHf<204m?C`80DU9B0P1IFET306UYJ@80L71`0P1aLG4206m_
K`80LG5a0P1eMGD507QhN080NWYj0P1mOGd207YjNP80Ogmo1021PH4307moO`80PX:20P24Q8@207mo
O`80PX:20P26QXH208F5Q@<0QhN70P2;Rh/208b<S080QXJ60P2<S8`209:BTP80TI6A0`2=SHd2096A
T@80SXj>0P2DU9@409>CT`80T92@0`2DU9@209>CT`80UIFE0P2JVYX209BDU080UYJF0P2NWYh309fM
W@80V9RH0P2JVYX209NGU`80WIfM0P2PX:0209fMW@80W9bL0`2OWil209jNWP@0WinO0P2NWYh209nO
W`80W9bL0`2MWId209RHV080UiNG0P2ATI4209FEU@80U9BD0P2EUID308n?S`80SHf=0P29RHT208j>
SP80R8R80P1oOgl207emO@<0P8200P1oOgl20820P080PX:20P20P80208F5Q@80QhN70`28R8P20861
P@80MWIf0P1iNGT80<SPf0001P38h=P208N7Q`80UiNG0P2DU9@3065QH@80JVYZ0P1dM7@206][J`80
K6a/0P1_Kfl207=cL`<0Q8B40P2k^k/40<o?c`80WIfM0P0];Bd202TY:@<09BDU0P0/;2`202<S8`80
:BTY0P0Z:RX2038b<P80>SXj0`13@d<204i>CP80FUYJ0P0d=3@203De=@80<C4a0P0Z:RX202LW9`<0
<30`0P0S8b<202XZ:P80:b/[0P0_;bl203De=@80Hf=S0`1mOGd207EeM@@0Hf=S0P1?Cdl2059BDP80
FEUI0`1YJFT2071`L080LG5a0P1_Kfl2075aL@80MGEe1@1hN7P207YjNP80OGem0P1jNWX207moO`@0
PH610`1oOgl208:2PP80Q8B40P1oOgl208:2PP80QXJ60P25QHD308N7Q`80Rh^;0P2<S8`208J6QP80
S8b<0P2BTY82096AT@<0SHf=0P2ATI4208j>SP80U9BD102CTi<2092@T0<0U9BD0P2CTi<209FEU@80
VYZJ0P2DU9@209JFUP80WYjN0`2MWId209RHV080VYZJ0P2GUiL209fMW@80X:2P0P2MWId209bLW0<0
WinO0P2NWYh409nOW`80WYjN0P2OWil209bLW0<0WIfM0P2HV9P209NGU`80TI6A0P2EUID209BDU080
UIFE0`2?Shl208f=S@80RHV90P2>SXh208R8R080Ogmo0P1mOGd30820P080Ogmo0P20P80208:2PP80
P8200P25QHD208N7Q`<0R8R80P21PH4207IfMP80NGUi2038h=P000H0b>3H0P1PH60206m_K`80OWin
1@1]KFd207YjNP80Ogmo1024Q8@207YjNP<0QhN70P2KVi/20;Fe]@80];Bd0P2g]kL206=SH`80<C4a
0`0W9bL402<S8`8092@T0P0V9RH202XZ:P80>c/k0`1BDU8404];B`80ATI60P15ADD402`/;0D0;Bd]
0P0W9bL203<c<`80>c/k0P0d=3@202`/;080EeMG0`1aLG4207UiN@80J6QX0P1MGEd205=CD`80DE5A
0P1LG5`3065QH@80JFUY0P1[Jf/2071`L080MgMg0P1fMWH207AdM0<0MWIf101nOWh207moO`80OWin
0P1kNg/207inOP<0Ogmo0P28R8P20861P@80QHF50P20P80408J6QP<0QhN70P26QXH208b<S080QhN7
0P2=SHd209BDU080TY:B0`2?Shl4096AT@80V9RH0P2BTY8209BDU080T92@0`2DU9@2096AT@80UIFE
0P2DU9@209>CT`80V9RH0P2LW9`309ZJVP80Ti>C0P2GUiL209RHV080WIfM0P2LW9`209fMW@80WYjN
0`2OWil20:>SX`80V9RH0P2KVi/409jNWP80VYZJ0`2GUiL209BDU080UYJF0P2HV9P409>CT`80SHf=
1`26QXH208:2PP80OGem101jNWX30820P0@0PX:20P27QhL208B4Q0@0QXJ60`22PX8207alO080M7Ad
0P1gMgL80<SPf0001P38h=P2061PH080Kfm_0P1nOWh506e]K@80NWYj0P1oOgl408B4Q080NWYj0`27
QhL209^KV`80]KFe0P2d];@20;Ng]`80Hf=S0P0a<C4302LW9`@08b<S0P0T92@202HV9P80:RXZ0P0k
>c/3059BDP@0Bd];0P16ATH204E5A@@0;2`/1@0];Bd202LW9`80<c<c0P0k>c/203@d=080;2`/0P1G
EeL3075aL@80NGUi0P1XJ6P205eMG@80De=C0P1ADE4205aLG0<0HF5Q0P1YJFT206][J`80L71`0P1g
MgL207IfMP80M7Ad0`1fMWH407inOP80Ogmo0P1nOWh207]kN`80OWin0`1oOgl208R8R080PH610P25
QHD20820P0@0QXJ60`27QhL208J6QP80S8b<0P27QhL208f=S@80U9BD0P2BTY8308n?S`@0TI6A0P2H
V9P209:BTP80U9BD0P2@T90309BDU080TI6A0P2EUID209BDU080Ti>C0P2HV9P209bLW0<0VYZJ0P2C
Ti<209NGU`80V9RH0P2MWId209bLW080WIfM0P2NWYh309nOW`80Xj>S0P2HV9P209^KV`@0WYjN0P2J
VYX309NGU`80U9BD0P2FUYH209RHV0@0Ti>C0P2=SHd708J6QP80PX:20P1mOGd407YjNP<0P8201022
PX8208N7Q`80Q8B41026QXH308:2PP80O7al0P1dM7@207MgM`P0b>3H00060<SPf080C4a<0P1NGUh2
06ATI0D0L71`0P1kNg/208^;R`80U9BD0P2FUYH209BDU0<0VIVI0P2OWil20:RXZ080Y:BT0P2^[Zh2
09jNWP80GemO0`0g=cL202LW9`809RHV0P0P820202<S8`80:2PX0P0^;Rh303Ph>080?3`l0P0/;2`2
034a<@80;bl_0P0[:b/202XZ:P80:b/[0`0a<C4202HV9P@0;bl_0P0Z:RX2034a<@80Hf=S0`1dM7@2
07=cL`80J6QX0P1BDU8204Y:BP80D51@0P1NGUh306IVIP80K6a/0P1XJ6P207AdM080Kfm_0P1aLG42
07EeM@<0MgMg0P20P80207inOP80PH61101kNg/207alO0<0P8200P1oOgl408:2PP80PH611028R8P3
08Z:RP80RHV90P2:RXX208^;R`80T92@0P2>SXh209FEU@<0Ti>C0P2BTY8209BDU080Ti>C102EUID2
09>CT`<0TI6A0P27QhL409JFUP80Ti>C0P2FUYH209ZJVP<0UiNG0P2FUYH209bLW080V9RH0P2KVi/2
09jNWP80W9bL0P2QXJ4309nOW`80WYjN0P2JVYX20:2PX080WYjN0P2JVYX209bLW0<0UIFE102DU9@2
09FEU@80TY:B0P2@T90208V9R@<0PX:20P1nOWh207]kN`80NWYj0P1nOWh207alO080P8200`22PX82
08B4Q080QhN70P24Q8@408J6QP80QHF50`24Q8@207inOP@0MgMg2038h=P000H0b>3H0P1<C4`205iN
GP80I6AT1@1`L70207]kN`80Rh^;0P2DU9@209JFUP80U9BD0`2IVIT209nOW`80Z:RX0P2TY:@20:j^
[P80WYjN0P1OGel303Lg=`809bLW0P0V9RH2020P80808b<S0P0X:2P202h^;P<0>3Ph0P0l?3`202`/
;080<C4a0P0_;bl202/[:`80:RXZ0P0[:b/3034a<@809RHV100_;bl202XZ:P80<C4a0P1SHf<307Ad
M080Lg=c0P1XJ6P2059BDP80BTY:0P1@D50205iNGP<0IVIV0P1/K6`206QXJ080M7Ad0P1_Kfl2075a
L@80MGEe0`1gMgL20820P080OWin0P21PH4407]kN`80O7al0`20P80207moO`@0PX:20P21PH4408R8
R0<0RXZ:0P29RHT208Z:RP80Rh^;0P2@T90208j>SP80UIFE0`2CTi<209:BTP80U9BD0P2CTi<409FE
U@80Ti>C0`2ATI4208N7Q`@0UYJF0P2CTi<209JFUP80VYZJ0`2GUiL209JFUP80W9bL0P2HV9P209^K
V`80WYjN0P2LW9`20:6QX@<0WinO0P2NWYh209ZJVP80X:2P0P2NWYh209ZJVP80W9bL0`2EUID409BD
U080UIFE0P2BTY82092@T080RHV90`22PX8207inOP80Ng]k0P1jNWX207inOP80O7al0P20P80308:2
PP80Q8B40P27QhL208B4Q0@0QXJ60P25QHD308B4Q080OWin101gMgL80<SPf0001P38h=P202`/;080
>c/k0P16ATH306UYJ@80SHf=0P29RHT209>CT`80VIVI0P2QXJ450:f][@80/K6a0P2f][H20;jn_P80
`<300P2i^KT20:j^[P<0PH610P0Y:BT202DU9@809RHV0P0W9bL202@T9080:RXZ0`0_;bl202/[:`80
;2`/0P0d=3@202h^;P80;2`/0P0^;Rh202l_;`<0<S8b0P0X:2P2034a<@80;2`/0P0a<C42030`<080
H61P0`1^KVh206e]K@80I6AT0P1=CDd204i>CP80D51@0P1SHf<306EUI@80IVIV0P1/K6`207EeM@80
MgMg0P1aLG4207EeM@<0MWIf101mOGd207QhN080OWin0P21PH420820P0<0Ph>30P22PX8208>3P`@0
QHF50P2:RXX208R8R0<0QXJ60P2:RXX208j>SP80TI6A0P2@T90209>CT`80S8b<1@2?Shl2092@T080
UIFE0P2GUiL209FEU@80UiNG0`2EUID209JFUP80WIfM0P2GUiL209ZJVP80W9bL0P2MWId309VIV@80
VYZJ0P2LW9`209ZJVP80Vi^K0P2OWil209jNWP80X:2P1@2MWId209bLW080WYjN0P2RXZ8209^KV`80
UiNG0`2HV9P2096AT@@0U9BD102@T9020861P@<0Ng]k0P1dM7@207QhN080OGem101oOgl208>3P`<0
Ogmo0P20P80207alO080OWin0P23Ph<207moO`80PH610`1mOGd207MgM`80Kfm_0P1^KVh80<SPf000
1P38h=P202`/;080>c/k0P16ATH306UYJ@80SHf=0P29RHT209>CT`80VIVI0P2QXJ450:f][@80/K6a
0P2f][H20;jn_P80`<300P2i^KT20:j^[P<0PH610P0Y:BT202DU9@809RHV0P0W9bL202@T9080:RXZ
0`0_;bl202/[:`80;2`/0P0d=3@202h^;P80;2`/0P0^;Rh202l_;`<0<S8b0P0X:2P2034a<@80;2`/
0P0a<C42030`<080H61P0`1^KVh206e]K@80I6AT0P1=CDd204i>CP80D51@0P1SHf<306EUI@80IVIV
0P1/K6`207EeM@80MgMg0P1aLG4207EeM@<0MWIf101mOGd207QhN080OWin0P21PH420820P0<0Ph>3
0P22PX8208>3P`@0QHF50P2:RXX208R8R0<0QXJ60P2:RXX208j>SP80TI6A0P2@T90209>CT`80S8b<
1@2?Shl2092@T080UIFE0P2GUiL209FEU@80UiNG0`2EUID209JFUP80WIfM0P2GUiL209ZJVP80W9bL
0P2MWId309VIV@80VYZJ0P2LW9`209ZJVP80Vi^K0P2OWil209jNWP80X:2P1@2MWId209bLW080WYjN
0P2RXZ8209^KV`80UiNG0`2HV9P2096AT@@0U9BD102@T9020861P@<0Ng]k0P1dM7@207QhN080OGem
101oOgl208>3P`<0Ogmo0P20P80207alO080OWin0P23Ph<207moO`80PH610`1mOGd207MgM`80Kfm_
0P1^KVh80<SPf0001P38h=P2028R8P807alO0P0S8b<3055AD@80TY:B0P2GUiL209jNWP@0XZ:R0P2_
[jl30<;2`P80^KVi0P2n_[h20<30`080alO70P36a/H20;bl_0<0XZ:R0P0l?3`202<S8`809BDU0P0S
8b<202LW9`80:2PX0`0Y:BT602LW9`@0:b/[0P0_;bl202d];@<0;Rh^100_;bl202TY:@8092@T0P0Y
:BT205mOG`<0Jf][0P1`L70206IVIP80CDe=0P1>CTh205=CD`80GemO0`1VIVH206=SH`80JVYZ0P1/
K6`2071`L080Kfm_0P1hN7P307EeM@80N7Qh101jNWX407emO@80OWin0`23Ph<208:2PP80Ph>30P24
Q8@208>3P`80RHV90P28R8P308Z:RP80R8R81P2@T90209:BTP80T92@0`2DU9@209:BTP80TI6A0P2G
UiL209JFUP80V9RH1@2FUYH209>CT`80UIFE0P2IVIT209NGU`80VYZJ0P2OWil309bLW080Vi^K0P2O
Wil209fMW@80WinO0P2MWId209jNWP80X:2P0`2MWId409nOW`80WYjN0P2LW9`209^KV`80UYJF1`2D
U9@209>CT`80S8b<0P2;Rh/207alO0<0MgMg0P1jNWX207inOP80P8200P22PX8207QhN080Lg=c0`1/
K6`206EUI@80H61P0P1VIVH206e]K@80N7Qh0P1dM7@306m_K`80JFUY0P1PH60206ATI0P0b>3H0006
0<SPf0808R8R0P0O7al202<S8`<0DE5A0P2BTY8209NGU`80WYjN102RXZ820:n_[`<0`/;20P2i^KT2
0;jn_P80`<300P37alL20<K6aP80_;bl0`2RXZ8203`l?0808b<S0P0U9BD202<S8`809bLW0P0X:2P3
02TY:@H09bLW100[:b/202l_;`80;Bd]0`0^;Rh402l_;`80:BTY0P0T92@202TY:@80GemO0`1[Jf/2
071`L080IVIV0P1=CDd204i>CP80De=C0P1OGel306IVIP80Hf=S0P1ZJVX206a/K080L71`0P1_Kfl2
07QhN0<0MGEe0P1hN7P407YjNP@0OGem0P1nOWh308>3P`80PX:20P23Ph<208B4Q080Ph>30P29RHT2
08R8R0<0RXZ:0P28R8P6092@T080TY:B0P2@T90309BDU080TY:B0P2ATI4209NGU`80UYJF0P2HV9P5
09JFUP80Ti>C0P2EUID209VIV@80UiNG0P2JVYX209nOW`<0W9bL0P2KVi/209nOW`80WIfM0P2OWil2
09fMW@80WYjN0P2PX:0309fMW@@0WinO0P2NWYh209bLW080Vi^K0P2FUYH709BDU080Ti>C0P2<S8`2
08^;R`80O7al0`1gMgL207YjNP80OWin0P20P80208:2PP80N7Qh0P1cLg<306a/K080IFEU0P1PH602
06IVIP80KFe]0P1hN7P207AdM0<0Kfm_0P1YJFT2061PH080I6AT2038h=P000H0b>3H0P0R8R8201lO
7`808b<S0`1ADE4209:BTP80UiNG0P2NWYh40::RXP80[jn_0`32`/820;Vi^@80_[jn0P30`<020<O7
a`80a/K60P2l_;`30::RXP80?3`l0P0S8b<202DU9@808b<S0P0W9bL202PX:0<0:BTY1P0W9bL402/[
:`80;bl_0P0];Bd302h^;P@0;bl_0P0Y:BT202@T9080:BTY0P1OGel306][J`80L71`0P1VIVH204e=
C@80CTi>0P1CDe<205mOG`<0IVIV0P1SHf<206YZJP80K6a/0P1`L70206m_K`80N7Qh0`1eMGD207Qh
N0@0NWYj101mOGd207inOP<0Ph>30P22PX8208>3P`80Q8B40P23Ph<208V9R@80R8R80`2:RXX208R8
R0H0T92@0P2BTY82092@T0<0U9BD0P2BTY82096AT@80UiNG0P2FUYH209RHV0D0UYJF0P2CTi<209FE
U@80VIVI0P2GUiL209ZJVP80WinO0`2LW9`209^KV`80WinO0P2MWId209nOW`80WIfM0P2NWYh20:2P
X0<0WIfM102OWil209jNWP80W9bL0P2KVi/209JFUPL0U9BD0P2CTi<208b<S080Rh^;0P1lO7`307Mg
M`80NWYj0P1nOWh20820P080PX:20P1hN7P207=cL`<0K6a/0P1UIFD2061PH080IVIV0P1]KFd207Qh
N080M7Ad0`1_Kfl206UYJ@80H61P0P1TI6@80<SPf0001P38h=P2020P808071`L0P0R8R8302l_;`80
PH610P2TY:@20:JVYP80ZZZZ0P2a/K420;Bd]0<0aLG50P2g]kL20;jn_P80_kno0P31`L420;jn_P80
_;bl0`2^[Zh206EUI@80=3@d0P0S8b<2024Q8@@0:2PX0`0Z:RX402DU9@809RHV0P0[:b/202XZ:P80
=3@d0P0b<S8303@d=080;bl_0P0/;2`402LW9`80;Rh^0P1JFUX306e]K@80L71`0P1YJFT204M7A`80
Cdm?0P1EEED205aLG0<0HV9R0P1TI6@206IVIP80JFUY0P1^KVh207AdM080Lg=c0`1iNGT207alO080
NGUi0P20P80407emO@80Ogmo0`23Ph<208:2PP80PH610P20P80208F5Q@@0QhN70`28R8P208^;R`80
S8b<0P2;Rh/609>CT`<0SXj>0P2DU9@209>CT`80VIVI0P2GUiL409JFUP<0UIFE0P2HV9P209NGU`@0
U9BD0P2HV9P209fMW@<0W9bL0P2OWil20:2PX080WYjN0P2OWil209^KV`80WYjN0P2LW9`309jNWP80
WIfM0P2LW9`209nOW`80XZ:R102FUYH309RHV080UIFE0P2DU9@208n?S`80Rh^;0P25QHD207]kN`<0
MGEe0P1jNWX208B4Q080Ph>30P24Q8@20861P@80JFUY0`1GEeL204I6AP80>c/k0P17AdL2055AD@80
HF5Q0P1MGEd305aLG080EeMG0P1EEED205UIF@P0b>3H00060<SPf080820P0P0L71`2028R8P<0;bl_
0P21PH420:BTY080YZJV0P2ZZZX20;6a/@80];Bd0`35aLD20;Ng]`80_[jn0P2o_kl20<71`@80_[jn
0P2l_;`30:j^[P80IFEU0P0d=3@202<S8`808B4Q100X:2P302XZ:P@09BDU0P0V9RH202/[:`80:RXZ
0P0d=3@2038b<P<0=3@d0P0_;bl202`/;0@09bLW0P0^;Rh205YJFP<0KFe]0P1`L70206UYJ@80AdM7
0P1?Cdl205EEE@80G5aL0`1RHV8206ATI080IVIV0P1YJFT206i^KP80M7Ad0P1cLg<307UiN@80O7al
0P1iNGT20820P0@0OGem0P1oOgl308>3P`80PX:20P21PH420820P080QHF51027QhL308R8R080Rh^;
0P2<S8`208^;R`H0Ti>C0`2>SXh209BDU080Ti>C0P2IVIT209NGU`@0UYJF0`2EUID209RHV080UiNG
102DU9@209RHV080WIfM0`2LW9`209nOW`80X:2P0P2NWYh209nOW`80Vi^K0P2NWYh209bLW0<0WYjN
0P2MWId209bLW080WinO0P2RXZ8409JFUP<0V9RH0P2EUID209BDU080Shn?0P2;Rh/208F5Q@80Ng]k
0`1eMGD207YjNP80Q8B40P23Ph<208B4Q080PH610P1YJFT305MGE`80ATI60P0k>c/204M7A`80DE5A
0P1QHF4205eMG@<0G5aL0P1GEeL205EEE@80FEUI2038h=P000H0b>3H0P0U9BD2028R8P807alO0`0Q
8B4205QHF080[Jf]0P2a/K420:f][@80/k>c0P2j^[X30<C4a080];Bd0P2g]kL20;fm_@80_;bl0P2n
_[h20;Ng]`<0[Zj^0P2RXZ8207AdM080<30`0P0Y:BT202XZ:P808b<S0`0Q8B4402HV9P@09BDU0P0V
9RH202`/;080>3Ph0`0^;Rh202XZ:P80;Rh^100[:b/202d];@80EeMG0`1ZJVX2069RHP80GemO0P1;
Bd/204U9B@80DE5A0P1PH60305iNGP80H61P0P1RHV8206][J`80L71`0P1aLG4207EeM@<0NGUi0P1h
N7P407YjNP80Ng]k0P20P8020861P@<0PX:20P20P80408:2PP80QXJ60P2:RXX208V9R@D0R8R80P2;
Rh/208Z:RP80T92@0P2?Shl208f=S@<0SXj>0P2JVYX409JFUP80Ti>C102IVIT309JFUP80Vi^K0P2L
W9`209RHV080UIFE0P2JVYX209bLW0D0VYZJ0P2MWId209bLW080X:2P0P2OWil209jNWPD0WinO0P2N
WYh20:2PX080WinO0P2QXJ4209RHV080Ti>C0`2DU9@2096AT@80SHf=0P2?Shl208Z:RP80PX:20P1g
MgL307UiN@80PH610P24Q8@208J6QP80R8R80P23Ph<206EUI@<0@D510P0b<S82034a<@80<S8b0P10
@40204e=C@80FEUI0`1PH60205YJFP80Hf=S0P1aLG480<SPf0001P38h=P202DU9@808R8R0P0O7al3
024Q8@80F5QH0P2][Jd20;6a/@80[Jf]0P2c/k<20;Zj^P<0a<C40P2d];@20;Ng]`80_Kfm0P2l_;`2
0;jn_P80]kNg0`2^[Zh20::RXP80M7Ad0P0`<30202TY:@80:RXZ0P0S8b<3024Q8@@09RHV100U9BD2
02HV9P80;2`/0P0h>3P302h^;P80:RXZ0P0^;Rh402/[:`80;Bd]0P1GEeL306YZJP80HV9R0P1OGel2
04];B`80BDU90P1ADE42061PH0<0GUiN0P1PH602069RHP80Jf][0P1`L702075aL@80MGEe0`1iNGT2
07QhN0@0NWYj0P1kNg/20820P080PH610`22PX820820P0@0PX:20P26QXH208Z:RP80RHV91@28R8P2
08^;R`80RXZ:0P2@T90208n?S`80SHf=0`2>SXh209ZJVP@0UYJF0P2CTi<409VIV@<0UYJF0P2KVi/2
09bLW080V9RH0P2EUID209ZJVP80W9bL1@2JVYX209fMW@80W9bL0P2PX:0209nOW`80WYjN1@2OWil2
09jNWP80X:2P0P2OWil20:6QX@80V9RH0P2CTi<309BDU080TI6A0P2=SHd208n?S`80RXZ:0P22PX82
07MgM`<0NGUi0P21PH4208B4Q080QXJ60P28R8P208>3P`80IFEU0`11@D42038b<P80<C4a0P0b<S82
0410@080CDe=0P1IFET3061PH080FUYJ0P1SHf<2075aL@P0b>3H00060<SPf080820P100M7Ad301lO
7`80=cLg0P2RXZ820;Bd]080[:b/0P2_[jl20:f][@<0_kno102c/k<20;Rh^080_Kfm0P2i^KT20;>c
/`<0[jn_0P2WYjL20:6QX@80Fe]K0P0l?3`203De=@809bLW0`0U9BD2024Q8@@08R8R0P0V9RH202TY
:@80;Bd]1@0_;bl202DU9@809bLW0P0Y:BT202DU9@80;Rh^0P1NGUh306i^KP80F5QH0P1KFe/204M7
A`80D51@0P1<C4`205IFEP<0GEeM0P1RHV8206EUI@80JVYZ0P1gMgL207=cL`80NGUi0`1gMgL207em
O@80O7al0P1jNWX207emO@80PX:20P20P80307moO`80OWin0P22PX8208B4Q080QhN70P2:RXX208f=
S@<0S8b<0P2;Rh/208Z:RP@0T92@0P2ATI45092@T080UIFE0P2KVi/209BDU080TY:B0P2JVYX209BD
U0<0UiNG0P2JVYX209bLW080UIFE0P2HV9P209VIV@80WIfM0`2IVIT209nOW`80W9bL0P2NWYh209bL
W080WYjN0P2LW9`209jNWPD0WIfM0P2IVIT209nOW`80WIfM0P2LW9`209JFUP<0TY:B0P2DU9@408Z:
RP80QhN70P20P80207AdM0<0N7Qh0P27QhL208B4Q080QHF50P24Q8@208Z:RP80N7Qh0`1FEUH203Xj
>P80>3Ph0P0i>CT204U9B@80FEUI0P1VIVH3079bLP80Lg=c0P1gMgL207inOPP0b>3H00060<SPf080
820P100M7Ad301lO7`80=cLg0P2RXZ820;Bd]080[:b/0P2_[jl20:f][@<0_kno102c/k<20;Rh^080
_Kfm0P2i^KT20;>c/`<0[jn_0P2WYjL20:6QX@80Fe]K0P0l?3`203De=@809bLW0`0U9BD2024Q8@@0
8R8R0P0V9RH202TY:@80;Bd]1@0_;bl202DU9@809bLW0P0Y:BT202DU9@80;Rh^0P1NGUh306i^KP80
F5QH0P1KFe/204M7A`80D51@0P1<C4`205IFEP<0GEeM0P1RHV8206EUI@80JVYZ0P1gMgL207=cL`80
NGUi0`1gMgL207emO@80O7al0P1jNWX207emO@80PX:20P20P80307moO`80OWin0P22PX8208B4Q080
QhN70P2:RXX208f=S@<0S8b<0P2;Rh/208Z:RP@0T92@0P2ATI45092@T080UIFE0P2KVi/209BDU080
TY:B0P2JVYX209BDU0<0UiNG0P2JVYX209bLW080UIFE0P2HV9P209VIV@80WIfM0`2IVIT209nOW`80
W9bL0P2NWYh209bLW080WYjN0P2LW9`209jNWPD0WIfM0P2IVIT209nOW`80WIfM0P2LW9`209JFUP<0
TY:B0P2DU9@408Z:RP80QhN70P20P80207AdM0<0N7Qh0P27QhL208B4Q080QHF50P24Q8@208Z:RP80
N7Qh0`1FEUH203Xj>P80>3Ph0P0i>CT204U9B@80FEUI0P1VIVH3079bLP80Lg=c0P1gMgL207inOPP0
b>3H00060<SPf080:BTY0P0P8202024Q8@<07AdM0P0U9BD208b<S080[Zj^0P2UYJD40:NWY`D0];Bd
0P2YZJT40;2`/080];Bd0P2i^KT30;Bd]080][Jf0P2d];@209VIV@80Ng]k0P1<C4`202d];@<0:BTY
0P0V9RH2020P80H08R8R0P0`<30202d];@<0:b/[0P0V9RH202PX:080:BTY0P0U9BD203@d=080H61P
0`1_Kfl206ATI080G5aL0P16ATH204e=C@80C4a<0P1EEED305aLG080GEeM0P1VIVH206e]K@80M7Ad
0P1_Kfl207UiN@<0NWYj0P1mOGd20820P080O7al0P1mOGd208F5Q@80Ogmo0`1mOGd408>3P`80PX:2
0P28R8P208J6QP80S8b<0`2:RXX2096AT@@0SHf=0P2?Shl2092@T080SHf=0`2BTY8409FEU@80UYJF
0P2GUiL209FEU@80VYZJ0`2HV9P209FEU@80UiNG0P2EUID209NGU`80VIVI1@2LW9`209nOW`80V9RH
0P2MWId609jNWP80X:2P0`2OWil20:2PX080WIfM0P2KVi/209jNWP80UiNG0P2FUYH308n?S`80U9BD
102:RXX208B4Q080LG5a0P1/K6`3075aL@80PH610P1oOgl208V9R@80QhN71025QHD308>3P`80MgMg
0P1`L70207EeM@80OWin0P1oOgl20820P0<0PX:20P24Q8@207inOP80NWYj2038h=P000H0b>3H0P0Y
:BT2020P80808B4Q0`0M7Ad202DU9@80S8b<0P2^[Zh20:FUY@@0YjNW1@2d];@20:VYZ@@0/;2`0P2d
];@20;Vi^@<0];Bd0P2f][H20;Bd]080VIVI0P1kNg/204a<C080;Bd]0`0Y:BT202HV9P80820P1P0R
8R82030`<080;Bd]0`0[:b/202HV9P80:2PX0P0Y:BT202DU9@80=3@d0P1PH60306m_K`80I6AT0P1L
G5`204I6AP80CDe=0P1<C4`205EEE@<0G5aL0P1MGEd206IVIP80KFe]0P1dM7@206m_K`80NGUi0`1j
NWX207emO@80P8200P1lO7`207emO@80QHF50P1oOgl307emO@@0Ph>30P22PX8208R8R080QXJ60P2<
S8`308Z:RP80TI6A102=SHd208n?S`80T92@0P2=SHd309:BTP@0UIFE0P2FUYH209NGU`80UIFE0P2J
VYX309RHV080UIFE0P2GUiL209FEU@80UiNG0P2IVIT509bLW080WinO0P2HV9P209fMW@H0WYjN0P2P
X:0309nOW`80X:2P0P2MWId209^KV`80WYjN0P2GUiL209JFUP<0Shn?0P2DU9@408Z:RP80Q8B40P1a
LG4206a/K0<0LG5a0P21PH4207moO`80RHV90P27QhL408F5Q@<0Ph>30P1gMgL2071`L080MGEe0P1n
OWh207moO`80P8200`22PX8208B4Q080OWin0P1jNWX80<SPf0001P38h=P202XZ:P80820P1@0K6a/2
01dM7@80HV9R0P2XZ:P209fMW@80ZZZZ0P2XZ:P30:JVYP80[jn_0P2YZJT20:b/[080YjNW0P2a/K45
0;Fe]@80^;Rh0P2m_Kd20:f][@80S8b<0P1gMgL204m?C`<0=cLg0P0Y:BT202@T90@09RHV0P0W9bL2
02`/;080:BTY1@0a<C4202l_;`809RHV0P0W9bL2038b<P80F5QH0`1YJFT205]KF`80EUIF0P0n?Sh2
03Xj>P80AdM70P1EEED305YJFP80H61P0P1UIFD206i^KP80M7Ad0P1cLg<207IfMP<0OGem0P1lO7`2
07moO`80Ph>30P1mOGd208B4Q080P8200`1oOgl208>3P`80P8200P25QHD208J6QP80Ph>30P2;Rh/3
092@T080SXj>0P29RHT408f=S@80UiNG0P2=SHd308n?S`80V9RH0P2?Shl209JFUP80VIVI0P2CTi<2
09NGU`<0UIFE102GUiL209BDU080Vi^K102LW9`30:2PX080VYZJ0P2GUiL209bLW080XJ6Q102OWil5
09jNWP80W9bL0P2KVi/209ZJVP80Vi^K0P2FUYH2096AT@<0TY:B0P2@T90208^;R`80U9BD0P20P802
07AdM080K6a/0`1dM7@207alO080OGem0P27QhL208Z:RP80QhN70P26QXH308N7Q`80QXJ60P24Q8@2
08J6QP80SHf=0P29RHT208B4Q0<0Rh^;0P24Q8@207inOP80MgMg2038h=P000H0b>3H0P0Z:RX2020P
80D06a/K0P0M7Ad2069RHP80Z:RX0P2MWId20:ZZZP80Z:RX0`2VYZH20:n_[`80ZJVY0P2/[:`20:NW
Y`80/K6a1@2e]KD20;Rh^080_Kfm0P2][Jd208b<S080MgMg0P1?Cdl303Lg=`80:BTY0P0T92@402HV
9P809bLW0P0/;2`202TY:@D0<C4a0P0_;bl202HV9P809bLW0P0b<S8205QHF0<0JFUY0P1KFe/205IF
EP80?Shn0P0j>SX204M7A`80EEEE0`1JFUX2061PH080IFEU0P1^KVh207AdM080Lg=c0P1fMWH307em
O@80O7al0P1oOgl208>3P`80OGem0P24Q8@20820P0<0Ogmo0P23Ph<20820P080QHF50P26QXH208>3
P`80Rh^;0`2@T90208j>SP80RHV9102=SHd209NGU`80SHf=0`2?Shl209RHV080Shn?0P2FUYH209VI
V@80Ti>C0P2GUiL309FEU@@0UiNG0P2DU9@209^KV`@0W9bL0`2PX:0209ZJVP80UiNG0P2LW9`20:6Q
X@@0WinO1@2NWYh209bLW080Vi^K0P2JVYX209^KV`80UYJF0P2ATI4309:BTP80T92@0P2;Rh/209BD
U080P8200P1dM7@206a/K0<0M7Ad0P1lO7`207emO@80QhN70P2:RXX208N7Q`80QXJ60`27QhL208J6
QP80Q8B40P26QXH208f=S@80RHV90P24Q8@308^;R`80Q8B40P1nOWh207MgM`P0b>3H00060<SPf080
:2PX0P0V9RH501dM7@8071`L0P0k>c/20:2PX0@0Xj>S0P2UYJD509nOW`80YZJV0P2/[:`20:6QX@80
WYjN0P2KVi/309nOW`80ZJVY0P2m_Kd20;Zj^P80ZZZZ0P2?Shl205eMG@<0@D510P0V9RH2024Q8@80
820P0P0O7al202HV9P80=CDe0P0X:2P302l_;`80:2PX0P0Z:RX202TY:@80:2PX0P0d=3@205]KF`<0
JVYZ0P1WIfL205YJFP80AdM70P14A4@203dm?@80De=C0`1HF5P205mOG`80JFUY0P1`L702079bLP80
M7Ad1@1fMWH208>3P`80Ng]k0P1oOgl208B4Q080PH611@1oOgl408>3P`H0QXJ60P27QhL708f=S@80
T92@0P2=SHd209:BTP80SHf=0`2CTi<2092@T080TI6A0P2DU9@209bLW080UiNG0P2FUYH309RHV080
Vi^K102LW9`209NGU`80W9bL0P2MWId309jNWP80Vi^K0P2NWYh209fMW@80WYjN0P2UYJD409jNWP<0
WinO0P2LW9`20::RXP80WIfM0P2JVYX209NGU`80U9BD0`2IVIT208n?S`80TI6A0P2?Shl208>3P`80
MGEe0P1[Jf/3079bLP80N7Qh0P1mOGd208F5Q@80Shn?0P2=SHd208^;R`<0RHV90P28R8P208Z:RP80
TY:B0P2=SHd208n?S`80T92@0`2<S8`208>3P`80OWin0P1hN7P80<SPf0001P38h=P202PX:0809RHV
1@0M7Ad201`L7080>c/k0P2PX:040:>SX`80YJFU1@2OWil20:JVYP80[:b/0P2QXJ4209jNWP80Vi^K
0`2OWil20:VYZ@80_Kfm0P2j^[X20:ZZZP80Shn?0P1MGEd30451@@809RHV0P0Q8B42020P80807alO
0P0V9RH203De=@80:2PX0`0_;bl202PX:080:RXZ0P0Y:BT202PX:080=3@d0P1KFe/306YZJP80IfMW
0P1JFUX204M7A`80A4A40P0m?Cd205=CD`<0F5QH0P1OGel206UYJ@80L71`0P1bLW8207AdM0D0MWIf
0P23Ph<207]kN`80Ogmo0P24Q8@20861P@D0Ogmo1023Ph<608J6QP80QhN71`2=SHd2092@T080SHf=
0P2BTY8208f=S@<0Ti>C0P2@T902096AT@80U9BD0P2LW9`209NGU`80UYJF0`2HV9P209^KV`@0W9bL
0P2GUiL209bLW080WIfM0`2NWYh209^KV`80WYjN0P2MWId209jNWP80YJFU102NWYh309nOW`80W9bL
0P2RXZ8209fMW@80VYZJ0P2GUiL209BDU0<0VIVI0P2?Shl2096AT@80Shn?0P23Ph<207EeM@80Jf][
0`1bLW8207QhN080OGem0P25QHD208n?S`80SHf=0P2;Rh/308V9R@80R8R80P2:RXX209:BTP80SHf=
0P2?Shl2092@T0<0S8b<0P23Ph<207inOP80N7Qh2038h=P000H0b>3H0P0V9RH2034a<@809bLW0`0P
8202024Q8@80:RXZ0P1hN7P20:VYZ@80XJ6Q0P2VYZH30:BTY080VIVI0P2FUYH209:BTP80PH610P20
P80207EeM@<0MgMg0P22PX820:6QX@80Zj^[0P2m_Kd20;6a/@80TI6A0`1UIFD2034a<@H092@T0P0X
:2P202HV9P80<S8b0`0W9bL202<S8`809bLW0P0X:2P202DU9@80;2`/0P1MGEd3075aL@80Hf=S0P1I
FET204=3@`80ADE50P1:BTX204a<C0<0G5aL0P1JFUX206UYJ@80KFe]0P1_Kfl207AdM080N7Qh0`1k
Ng/20820P080N7Qh0P1mOGd207moO`80PX:20P20P8030861P@80QHF50P21PH4208>3P`80R8R80P27
QhL208V9R@<0S8b<0P2;Rh/209:BTP80Shn?102@T90508n?S`80Ti>C0P2EUID409NGU`80UYJF0P2I
VIT309FEU@80V9RH0P2QXJ4209^KV`80WIfM0P2OWil209bLW0/0WinO0P2RXZ8209nOW`80WYjN0`2O
Wil209fMW@80XJ6Q0P2NWYh209ZJVP80UIFE1@2BTY82092@T080Rh^;0P2<S8`207inOP80N7Qh0P1X
J6P3071`L080MWIf0P1mOGd408J6QP@0SHf=0`2>SXh208V9R@80S8b<0P2=SHd208b<S080T92@0P2>
SXh308Z:RP80PX:20P1lO7`207UiN@P0b>3H00060<SPf0809RHV0P0a<C4202LW9`<0820P0P0Q8B42
02XZ:P80N7Qh0P2YZJT20:6QX@80YZJV0`2TY:@209VIV@80UYJF0P2BTY820861P@80P8200P1eMGD3
07MgM`80PX:20P2QXJ420:^[Z`80_Kfm0P2a/K42096AT@<0IFEU0P0a<C4602@T9080:2PX0P0V9RH2
038b<P<09bLW0P0S8b<202LW9`80:2PX0P0U9BD202`/;080GEeM0`1aLG4206=SH`80FEUI0P13@d<2
04E5A@80BTY:0P1<C4`305aLG080FUYJ0P1YJFT206e]K@80Kfm_0P1dM7@207QhN0<0Ng]k0P20P802
07QhN080OGem0P1oOgl208:2PP80P8200`21PH4208F5Q@80PH610P23Ph<208R8R080QhN70P29RHT3
08b<S080Rh^;0P2BTY8208n?S`@0T92@1@2?Shl209>CT`80UIFE102GUiL209JFUP80VIVI0`2EUID2
09RHV080XJ6Q0P2KVi/209fMW@80WinO0P2LW9`;09nOW`80XZ:R0P2OWil209jNWP<0WinO0P2MWId2
0:6QX@80WYjN0P2JVYX209FEU@D0TY:B0P2@T90208^;R`80S8b<0P1nOWh207QhN080J6QX0`1`L702
07IfMP80OGem1026QXH408f=S@<0SXj>0P29RHT208b<S080SHf=0P2<S8`2092@T080SXj>0`2:RXX2
08:2PP80O7al0P1iNGT80<SPf0001P38h=P202HV9P80<C4a0P0W9bL3020P80808B4Q0P0Z:RX207Qh
N080ZJVY0P2QXJ420:JVYP<0Y:BT0P2IVIT209JFUP80TY:B0P21PH420820P080MGEe0`1gMgL208:2
PP80XJ6Q0P2[Zj/20;fm_@80/K6a0P2ATI4306EUI@80<C4a1P0T92@202PX:0809RHV0P0b<S8302LW
9`808b<S0P0W9bL202PX:0809BDU0P0/;2`205eMG@<0LG5a0P1SHf<205UIF@80@d=30P15ADD204Y:
BP80C4a<0`1LG5`205YJFP80JFUY0P1]KFd206m_K`80M7Ad0P1hN7P307]kN`80P8200P1hN7P207em
O@80Ogmo0P22PX820820P0<0PH610P25QHD20861P@80Ph>30P28R8P208N7Q`80RHV90`2<S8`208^;
R`80TY:B0P2?Shl4092@T0D0Shn?0P2CTi<209FEU@@0UiNG0P2FUYH209VIV@<0UIFE0P2HV9P20:6Q
X@80Vi^K0P2MWId209nOW`80W9bL2`2OWil20::RXP80WinO0P2NWYh309nOW`80WIfM0P2QXJ4209jN
WP80VYZJ0P2EUID509:BTP80T92@0P2;Rh/208b<S080OWin0P1hN7P206QXJ0<0L71`0P1fMWH207em
O@@0QXJ6102=SHd308j>SP80RHV90P2<S8`208f=S@80S8b<0P2@T90208j>SP<0RXZ:0P22PX8207al
O080NGUi2038h=P000H0b>3H0P0U9BD2030`<080;2`/0`0Q8B42028R8P809BDU0P17AdL208b<S080
V9RH0P2JVYX309JFUP80R8R80P21PH4207IfMP80Jf][0P1]KFd206ATI0<0MWIf0P23Ph<208N7Q`80
TY:B0P2RXZ820:f][@80W9bL0`1^KVh203Lg=`80:BTY0P0U9BD202HV9P@08b<S0P0W9bL302h^;P80
92@T0P0_;bl204I6AP809BDU0P0^;Rh205MGE`<0LG5a0P1KFe/204i>CP80ATI60P13@d<204A4A080
CTi>0`1IFET205MGE`80Hf=S0P1[Jf/207IfMP80LW9b0P1gMgL307YjNP80Ng]k0P22PX8207inOP80
O7al0P22PX8207moO`<0P8200P22PX8608J6QP80S8b<0P28R8P308n?S`80SXj>102ATI4208f=S@80
SXj>0P2?Shl309>CT`80W9bL0P2CTi<209VIV@@0UYJF0P2EUID309NGU`80VYZJ0P2MWId209bLW080
WinO0P2LW9`209nOW`<0W9bL0P2MWId409jNWP80X:2P0P2RXZ8209jNWP80WinO0`2MWId409nOW`80
WIfM0P2JVYX209:BTP80Ti>C0`2>SXh208^;R`80SHf=0P2:RXX207emO@80M7Ad0P1[Jf/306e]K@80
M7Ad0P1mOGd208>3P`80QhN70P2:RXX208f=S@<0Rh^;0P28R8P208^;R`80T92@0P2=SHd208n?S`80
R8R80`26QXH40820P080OGem2038h=P000H0b>3H0P0U9BD2030`<080;2`/0`0Q8B42028R8P809BDU
0P17AdL208b<S080V9RH0P2JVYX309JFUP80R8R80P21PH4207IfMP80Jf][0P1]KFd206ATI0<0MWIf
0P23Ph<208N7Q`80TY:B0P2RXZ820:f][@80W9bL0`1^KVh203Lg=`80:BTY0P0U9BD202HV9P@08b<S
0P0W9bL302h^;P8092@T0P0_;bl204I6AP809BDU0P0^;Rh205MGE`<0LG5a0P1KFe/204i>CP80ATI6
0P13@d<204A4A080CTi>0`1IFET205MGE`80Hf=S0P1[Jf/207IfMP80LW9b0P1gMgL307YjNP80Ng]k
0P22PX8207inOP80O7al0P22PX8207moO`<0P8200P22PX8608J6QP80S8b<0P28R8P308n?S`80SXj>
102ATI4208f=S@80SXj>0P2?Shl309>CT`80W9bL0P2CTi<209VIV@@0UYJF0P2EUID309NGU`80VYZJ
0P2MWId209bLW080WinO0P2LW9`209nOW`<0W9bL0P2MWId409jNWP80X:2P0P2RXZ8209jNWP80WinO
0`2MWId409nOW`80WIfM0P2JVYX209:BTP80Ti>C0`2>SXh208^;R`80SHf=0P2:RXX207emO@80M7Ad
0P1[Jf/306e]K@80M7Ad0P1mOGd208>3P`80QhN70P2:RXX208f=S@<0Rh^;0P28R8P208^;R`80T92@
0P2=SHd208n?S`80R8R80`26QXH40820P080OGem2038h=P000H0b>3H100T92@2038b<P<09RHV0P0R
8R8201hN7P808R8R0P1<C4`207QhN080Ph>30`1hN7P407YjNP80IfMW0P1UIFD406a/K0<0T92@0P2e
]KD20:f][@80Xj>S0P2=SHd2092@T080VYZJ0`27QhL205YJFP80ADE50P0];Bd202<S8`808R8R0P0[
:b/202DU9@<0:b/[100X:2P2028R8P808b<S0P0^;Rh205YJFP<0KFe]0P1JFUX204=3@`80@4100P1;
Bd/204i>CP80DE5A0`1CDe<405mOG`80JVYZ0P1dM7@2075aL@D0MWIf0P1mOGd207moO`80OGem0P1l
O7`208:2PP80OGem0`21PH4208>3P`80QXJ60P25QHD208N7Q`80Rh^;0P2=SHd308Z:RP80Rh^;0P2?
Shl209BDU080Ti>C0P2DU9@208n?S`<0Ti>C0P2KVi/409NGU`80VYZJ0P2HV9P209JFUPD0VYZJ0P2F
UYH209VIV@80W9bL0P2JVYX209nOW`<0VIVI0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`80XZ:R0P2T
Y:@30:>SX`@0XJ6Q0P2KVi/209VIV@80V9RH0P2IVIT309:BTP80S8b<0P2;Rh/208n?S`80Ogmo0P1g
MgL2079bLP<0KVi^0P1cLg<207alO080P8200P27QhL208J6QP80Rh^;0`28R8P208Z:RP80RHV90P2;
Rh/208n?S`@0Q8B40`21PH4207alO080OGem0P1oOgl80<SPf0001P38h=P402@T9080<S8b0`0V9RH2
028R8P807QhN0P0R8R8204a<C080N7Qh0P23Ph<307QhN0@0NWYj0P1WIfL206EUI@@0K6a/0`2@T902
0;Fe]@80[Jf]0P2SXj<208f=S@80T92@0P2JVYX308N7Q`80FUYJ0P15ADD202d];@808b<S0P0R8R82
02/[:`809BDU0`0[:b/402PX:0808R8R0P0S8b<202h^;P80FUYJ0`1]KFd205YJFP80@d=30P10@402
04];B`80CTi>0P1ADE4305=CD`@0GemO0P1ZJVX207AdM080LG5a1@1fMWH207emO@80Ogmo0P1mOGd2
07alO080PX:20P1mOGd30861P@80Ph>30P26QXH208F5Q@80QhN70P2;Rh/208f=S@<0RXZ:0P2;Rh/2
08n?S`80U9BD0P2CTi<209BDU080Shn?0`2CTi<209^KV`@0UiNG0P2JVYX209RHV080UYJF1@2JVYX2
09JFUP80VIVI0P2LW9`209ZJVP80WinO0`2IVIT20::RXP80WinO0P2LW9`20:6QX@80WinO0P2RXZ82
0:BTY0<0Xj>S102QXJ4209^KV`80VIVI0P2HV9P209VIV@<0TY:B0P2<S8`208^;R`80Shn?0P1oOgl2
07MgM`80LW9b0`1^KVh207=cL`80O7al0P20P80208N7Q`80QXJ60P2;Rh/308R8R080RXZ:0P29RHT2
08^;R`80Shn?1024Q8@30861P@80O7al0P1mOGd207moO`P0b>3H00060<SPf0@08b<S0P0`<30302l_
;`80:b/[0P0N7Qh202<S8`80:2PX0P1ADE4206EUI@<0IfMW0P1nOWh208F5Q@80JVYZ0P1^KVh4079b
LP<0T92@0P2i^KT20<W9b@80`l?30P2VYZH208:2PP80UiNG0`1mOGd203@d=08092@T0P0S8b<201lO
7`807QhN0P0S8b<202TY:@<09BDU0P0R8R8202XZ:P809BDU0P0Y:BT202XZ:P80G5aL0`1/K6`205aL
G080@D510P0h>3P204M7A`80B4Q80P1?Cdl305IFEP80GEeM0P1WIfL206QXJ080K6a/0P1cLg<507Ee
M@80NGUi0P1mOGd207moO`80P8200P24Q8@208:2PP<0Ph>30P22PX8208N7Q`80QHF50P28R8P208J6
QP80QhN70`2<S8`208^;R`80SHf=0P2@T902096AT@@0Ti>C0`2EUID209ZJVP80Vi^K0P2IVIT409RH
V080UiNG0`2IVIT209ZJVP80UYJF0P2JVYX209fMW@80WYjN0P2MWId30::RXP80Xj>S0P2OWil20::R
XP80YZJV0P2NWYh20::RXPD0Y:BT0P2SXj<20:6QX@80WIfM0P2LW9`409RHV0<0UYJF0P2ATI42092@
T080SXj>0P25QHD207alO080NGUi0`1eMGD2079bLP80MWIf0P1lO7`208B4Q080QHF50P23Ph<308N7
Q`80QXJ60P24Q8@208>3P`80PX:20P1oOgl208B4Q0<0NGUi101kNg/20861P@P0b>3H00060<SPf0@0
8b<S0P0`<30302l_;`80:b/[0P0N7Qh202<S8`80:2PX0P1ADE4206EUI@<0IfMW0P1nOWh208F5Q@80
JVYZ0P1^KVh4079bLP<0T92@0P2i^KT20<W9b@80`l?30P2VYZH208:2PP80UiNG0`1mOGd203@d=080
92@T0P0S8b<201lO7`807QhN0P0S8b<202TY:@<09BDU0P0R8R8202XZ:P809BDU0P0Y:BT202XZ:P80
G5aL0`1/K6`205aLG080@D510P0h>3P204M7A`80B4Q80P1?Cdl305IFEP80GEeM0P1WIfL206QXJ080
K6a/0P1cLg<507EeM@80NGUi0P1mOGd207moO`80P8200P24Q8@208:2PP<0Ph>30P22PX8208N7Q`80
QHF50P28R8P208J6QP80QhN70`2<S8`208^;R`80SHf=0P2@T902096AT@@0Ti>C0`2EUID209ZJVP80
Vi^K0P2IVIT409RHV080UiNG0`2IVIT209ZJVP80UYJF0P2JVYX209fMW@80WYjN0P2MWId30::RXP80
Xj>S0P2OWil20::RXP80YZJV0P2NWYh20::RXPD0Y:BT0P2SXj<20:6QX@80WIfM0P2LW9`409RHV0<0
UYJF0P2ATI42092@T080SXj>0P25QHD207alO080NGUi0`1eMGD2079bLP80MWIf0P1lO7`208B4Q080
QHF50P23Ph<308N7Q`80QXJ60P24Q8@208>3P`80PX:20P1oOgl208B4Q0<0NGUi101kNg/20861P@P0
b>3H00060<SPf0809BDU0P0a<C4202`/;0<0=cLg0P0_;bl201lO7`806a/K0P0Q8B4202h^;P80Cdm?
0`1;Bd/206e]K@80QhN70P1fMWH2079bLP80P8200P1kNg/307inOP80WYjN0P39bLT40<[:bP80Zj^[
0P2PX:030:>SX`80?3`l0P0X:2P2028R8P807alO0P0U9BD202LW9`80:b/[0`0W9bL202HV9P80;2`/
100U9BD202`/;080FEUI0`1ZJVX205eMG@80?Cdm0P12@T8204M7A`80CDe=0P1BDU8305UIF@80F5QH
0P1UIFD206YZJP80KFe]0P1eMGD207AdM0<0MWIf0P1kNg/207inOP80OGem1020P8020861P@L0QHF5
0P2<S8`208N7Q`80PX:20P25QHD308Z:RP80RHV90P2=SHd209BDU080TY:B0P2GUiL209JFUP<0Ti>C
0P2IVIT209JFUP@0UiNG0P2HV9P209JFUP<0U9BD0P2KVi/209ZJVP80WYjN0P2OWil20::RXPL0X:2P
0P2RXZ840:FUY@80WYjN0P2SXj<20:FUY@<0XZ:R0P2MWId209nOW`80WIfM0P2KVi/209RHV080TY:B
0`2EUID408j>SP80T92@0P2:RXX208>3P`80O7al0`1gMgL2079bLP80NGUi0P1mOGd208:2PP@0QXJ6
0`2;Rh/208N7Q`80Ph>30P21PH4207inOP80Ng]k0P1lO7`307YjNP80O7al0P1kNg/207inOPP0b>3H
00060<SPf0809BDU0P0a<C4202`/;0<0=cLg0P0_;bl201lO7`806a/K0P0Q8B4202h^;P80Cdm?0`1;
Bd/206e]K@80QhN70P1fMWH2079bLP80P8200P1kNg/307inOP80WYjN0P39bLT40<[:bP80Zj^[0P2P
X:030:>SX`80?3`l0P0X:2P2028R8P807alO0P0U9BD202LW9`80:b/[0`0W9bL202HV9P80;2`/100U
9BD202`/;080FEUI0`1ZJVX205eMG@80?Cdm0P12@T8204M7A`80CDe=0P1BDU8305UIF@80F5QH0P1U
IFD206YZJP80KFe]0P1eMGD207AdM0<0MWIf0P1kNg/207inOP80OGem1020P8020861P@L0QHF50P2<
S8`208N7Q`80PX:20P25QHD308Z:RP80RHV90P2=SHd209BDU080TY:B0P2GUiL209JFUP<0Ti>C0P2I
VIT209JFUP@0UiNG0P2HV9P209JFUP<0U9BD0P2KVi/209ZJVP80WYjN0P2OWil20::RXPL0X:2P0P2R
XZ840:FUY@80WYjN0P2SXj<20:FUY@<0XZ:R0P2MWId209nOW`80WIfM0P2KVi/209RHV080TY:B0`2E
UID408j>SP80T92@0P2:RXX208>3P`80O7al0`1gMgL2079bLP80NGUi0P1mOGd208:2PP@0QXJ60`2;
Rh/208N7Q`80Ph>30P21PH4207inOP80Ng]k0P1lO7`307YjNP80O7al0P1kNg/207inOPP0b>3H0006
0<SPf080:RXZ0P0T92@202TY:@<0>SXj0P0b<S82024Q8@808b<S0P0`<302024Q8@80;2`/0`0X:2P2
05aLG080RHV90P2:RXX207EeM@@0N7Qh0`1iNGT209:BTP80_kno0P3<c<`20<k>cP80b/[:0P2o_kl3
0<G5a@80Ogmo0P0_;bl4028R8P809bLW0P0[:b/202TY:@<08R8R0P0X:2P402LW9`80:2PX0P0`<302
05IFEP<0I6AT0P1JFUX20451@@80=cLg0P18B4P204E5A@80De=C0`1GEeL205aLG080H61P0P1VIVH2
075aL@80MGEe1@1gMgL207emO@H0P8200P27QhL708B4Q0@0QXJ60P2:RXX208N7Q`80S8b<0`2?Shl2
08J6QP@0T92@0P2BTY8209JFUP80VIVI0`2CTi<209NGU`80UIFE0P2HV9P209BDU080UYJF0P2JVYX3
09fMW@80Vi^K102LW9`209RHV080WYjN0P2SXj<30::RXP80X:2P0P2UYJD40:BTY080X:2P102TY:@3
0:>SX`80Y:BT0P2QXJ4209jNWP80Vi^K0P2MWId509BDU080TY:B0P2?Shl208j>SP80R8R80P25QHD2
07emO@<0O7al0P1jNWX207]kN`80O7al0P1kNg/208:2PP80Ph>30`2<S8`208F5Q@80OGem0P1oOgl2
07]kN`80OGem0P1nOWh307UiN@80MGEe0P1jNWX207inOPP0b>3H00060<SPf080:RXZ0P0T92@202TY
:@<0>SXj0P0b<S82024Q8@808b<S0P0`<302024Q8@80;2`/0`0X:2P205aLG080RHV90P2:RXX207Ee
M@@0N7Qh0`1iNGT209:BTP80_kno0P3<c<`20<k>cP80b/[:0P2o_kl30<G5a@80Ogmo0P0_;bl4028R
8P809bLW0P0[:b/202TY:@<08R8R0P0X:2P402LW9`80:2PX0P0`<30205IFEP<0I6AT0P1JFUX20451
@@80=cLg0P18B4P204E5A@80De=C0`1GEeL205aLG080H61P0P1VIVH2075aL@80MGEe1@1gMgL207em
O@H0P8200P27QhL708B4Q0@0QXJ60P2:RXX208N7Q`80S8b<0`2?Shl208J6QP@0T92@0P2BTY8209JF
UP80VIVI0`2CTi<209NGU`80UIFE0P2HV9P209BDU080UYJF0P2JVYX309fMW@80Vi^K102LW9`209RH
V080WYjN0P2SXj<30::RXP80X:2P0P2UYJD40:BTY080X:2P102TY:@30:>SX`80Y:BT0P2QXJ4209jN
WP80Vi^K0P2MWId509BDU080TY:B0P2?Shl208j>SP80R8R80P25QHD207emO@<0O7al0P1jNWX207]k
N`80O7al0P1kNg/208:2PP80Ph>30`2<S8`208F5Q@80OGem0P1oOgl207]kN`80OGem0P1nOWh307Ui
N@80MGEe0P1jNWX207inOPP0b>3H00060<SPf0808b<S0P0U9BD2038b<P<0>3Ph0P0_;bl202`/;0@0
7alO0P0R8R8201hN7P<08R8R0P14A4@208:2PP80VYZJ0P1kNg/2075aL@80MWIf0`1cLg<207moO`80
Z:RX0P3@d=020<o?c`80d=3@0P3<c<`30=3@d080^KVi0P19BDT202HV9P808b<S0P0Z:RX202HV9P80
:2PX0`0/;2`402@T90809BDU0P0R8R8202PX:080De=C0`1PH60205ADE080?3`l0P11@D4204Y:BP80
Bd];0P1DE5@305eMG@80HF5Q0P1WIfL206YZJP80LG5a0P1eMGD207MgM`<0NGUi0P1gMgL207moO`@0
P8200P25QHD50861P@80QhN70P23Ph<208J6QP80QhN70P2;Rh/208b<S0<0V9RH0P2:RXX209:BTP@0
T92@0P2FUYH209RHV0<0TY:B0P2IVIT209RHV080VIVI0P2HV9P209ZJVP80Vi^K0`2NWYh409^KV`80
WinO0P2JVYX209jNWP80X:2P0`2OWil20:>SX`@0YjNW0P2TY:@20:>SX`80X:2P0P2NWYh30:2PX080
XJ6Q0P2SXj<209nOW`80WYjN0P2MWId209VIV@<0UIFE0P2ATI4209:BTP80RHV90P28R8P208N7Q`80
PX:20`1nOWh20861P@80Ogmo0P1nOWh207alO0@0Ph>30`27QhL208>3P`80OWin0P1lO7`207]kN`@0
Ogmo0`1iNGT207EeM@80MWIf0P21PH480<SPf0001P38h=P202<S8`809BDU0P0b<S8303Ph>080;bl_
0P0/;2`401lO7`808R8R0P0N7Qh3028R8P80A4A40P22PX8209ZJVP80Ng]k0P1aLG4207IfMP<0Lg=c
0P1oOgl20:RXZ080d=3@0P3?cll20=3@d080c<c<0`3@d=020;Vi^@80BDU90P0V9RH202<S8`80:RXZ
0P0V9RH202PX:0<0;2`/100T92@202DU9@808R8R0P0X:2P205=CD`<0H61P0P1DE5@203`l?080@D51
0P1:BTX204];B`80E5AD0`1MGEd2065QH@80IfMW0P1ZJVX2075aL@80MGEe0P1gMgL307UiN@80MgMg
0P1oOgl40820P080QHF51@21PH4208N7Q`80Ph>30P26QXH208N7Q`80Rh^;0P2<S8`309RHV080RXZ:
0P2BTY84092@T080UYJF0P2HV9P309:BTP80VIVI0P2HV9P209VIV@80V9RH0P2JVYX209^KV`<0WYjN
102KVi/209nOW`80VYZJ0P2NWYh20:2PX0<0WinO0P2SXj<40:NWY`80Y:BT0P2SXj<20:2PX080WYjN
0`2PX:020:6QX@80Xj>S0P2OWil209jNWP80WIfM0P2IVIT309FEU@80TI6A0P2BTY8208V9R@80R8R8
0P27QhL208:2PP<0OWin0P21PH4207moO`80OWin0P1lO7`408>3P`<0QhN70P23Ph<207inOP80O7al
0P1kNg/407moO`<0NGUi0P1eMGD207IfMP80PH612038h=P000H0b>3H0P0S8b<202h^;P80?Cdm0`1>
CTh203De=@808b<S0P0P820201/K6`807QhN0P0L71`301lO7`80;bl_0P1[Jf/208n?S`80QXJ60P1c
Lg<2071`L0<0M7Ad0P1fMWH2092@T080_kno0P3=cLd20<_;b`80c/k>0`3<c<`20<k>cP80Xj>S0P0h
>3P202DU9@8092@T0P0V9RH202TY:@<09BDU0P0V9RH202LW9`808R8R0P0T92@202DU9@80CDe=0`1V
IVH204i>CP80>SXj0P12@T8204M7A`80ADE50P1;Bd/305MGE`80HF5Q0P1WIfL206a/K0@0LG5a0P1i
NGT307inOP80P8200P1jNWX207inOP@0P8200P23Ph<308:2PP80QhN70P28R8P408V9R@80RXZ:1@2>
SXh208n?S`80U9BD0P2CTi<2092@T080TI6A0P2HV9P309^KV`80UiNG0P2FUYH209VIV@80VYZJ0P2N
WYh20::RXP<0WYjN0P2MWId209bLW080X:2P1P2OWil30::RXP80YZJV0P2XZ:P20::RXP80YZJV0P2T
Y:@20:FUY@80XZ:R0`2PX:020:BTY080YJFU0P2RXZ820:JVYP80WinO0P2NWYh309ZJVP@0Ti>C0P2<
S8`208j>SP@0QHF51@24Q8@20820P0@0PH610P24Q8@207emO@<0Q8B40P22PX8207alO080Ogmo0P1l
O7`207]kN`80NGUi0`1kNg/207UiN@80O7al0P1mOGd80<SPf0001P38h=P202<S8`80;Rh^0P0m?Cd3
04i>CP80=CDe0P0S8b<2020P80806a/K0P0N7Qh201`L70<07alO0P0_;bl206][J`80Shn?0P26QXH2
07=cL`80L71`0`1dM7@207IfMP80T92@0P2o_kl20<g=c@80bl_;0P3>c/h30<c<c080c/k>0P2SXj<2
03Ph>0809BDU0P0T92@202HV9P80:BTY0`0U9BD202HV9P809bLW0P0R8R8202@T90809BDU0P1=CDd3
06IVIP80CTi>0P0j>SX20492@P80AdM70P15ADD204];B`<0EeMG0P1QHF4206MWI`80K6a/101aLG42
07UiN@<0OWin0P20P80207YjNP80OWin1020P80208>3P`<0PX:20P27QhL208R8R0@0RHV90P2:RXX5
08j>SP80Shn?0P2DU9@209>CT`80T92@0P2ATI4209RHV0<0Vi^K0P2GUiL209JFUP80VIVI0P2JVYX2
09jNWP80XZ:R0`2NWYh209fMW@80W9bL0P2PX:0609nOW`<0XZ:R0P2VYZH20:RXZ080XZ:R0P2VYZH2
0:BTY080YJFU0P2RXZ830:2PX080Y:BT0P2UYJD20::RXP80YZJV0P2OWil209jNWP<0VYZJ102CTi<2
08b<S080SXj>1025QHD508B4Q080P8201021PH4208B4Q080OGem0`24Q8@208:2PP80O7al0P1oOgl2
07alO080Ng]k0P1iNGT307]kN`80NGUi0P1lO7`207emO@P0b>3H00060<SPf0808b<S0P0^;Rh203dm
?@<0CTi>0P0e=CD202<S8`80820P0P0K6a/201hN7P8071`L0`0O7al202l_;`80Jf][0P2?Shl208J6
QP80Lg=c0P1`L70307AdM080MWIf0P2@T9020;no_`80cLg=0P3;bl/20<k>cP<0c<c<0P3>c/h20:>S
X`80>3Ph0P0U9BD202@T90809RHV0P0Y:BT302DU9@809RHV0P0W9bL2028R8P8092@T0P0U9BD204e=
C@<0IVIV0P1>CTh203Xj>P80@T920P17AdL204E5A@80Bd];0`1GEeL2065QH@80IfMW0P1/K6`4075a
L@80NGUi0`1nOWh20820P080NWYj0P1nOWh40820P080Ph>30`22PX8208N7Q`80R8R81029RHT208Z:
RPD0SXj>0P2?Shl209BDU080Ti>C0P2@T902096AT@80V9RH0`2KVi/209NGU`80UYJF0P2IVIT209ZJ
VP80WYjN0P2RXZ8309jNWP80WIfM0P2LW9`20:2PX0H0WinO0`2RXZ820:JVYP80Z:RX0P2RXZ820:JV
YP80Y:BT0P2UYJD20::RXP<0X:2P0P2TY:@20:FUY@80XZ:R0P2VYZH209nOW`80WYjN0`2JVYX409>C
T`80S8b<0P2>SXh408F5Q@D0Q8B40P20P8040861P@80Q8B40P1mOGd308B4Q080PX:20P1lO7`207mo
O`80O7al0P1kNg/207UiN@<0Ng]k0P1iNGT207alO080OGem2038h=P000H0b>3H0P0V9RH2038b<P80
C4a<0`1cLg<204e=C@809RHV0P0P8202024Q8@807QhN1@0M7Ad202DU9@80D51@0P23Ph<209FEU@80
NGUi0P1_Kfl307UiN@80MWIf0P1hN7P20:FUY@80alO70P38b<P20<k>cP<0clo?103>c/h208V9R@80
<C4a0P0U9BD202HV9P809BDU0`0W9bL2024Q8@808b<S0P0Y:BT202LW9`80:BTY0P19BDT305aLG080
B4Q80P0e=CD203`l?080ADE50P19BDT204e=C@<0FUYJ0P1RHV8206IVIP80K6a/0P1bLW8207AdM080
MGEe0`22PX8208>3P`80OGem0P1kNg/20820P080Ph>30P26QXH307inOP80Q8B40P27QhL208V9R@@0
RXZ:0P26QXH308V9R@80T92@0P2JVYX209:BTP80T92@102FUYH309^KV`80VIVI0P2GUiL60:6QX@80
Xj>S0`2PX:0209jNWP80WinO0P2PX:020::RXP80Xj>S0P2RXZ830:FUY@80Z:RX0P2UYJD20:>SX`80
Z:RX0P2YZJT20:RXZ080Y:BT0`2UYJD20:RXZ080XZ:R102VYZH209nOW`80X:2P0`2KVi/209JFUP80
TI6A0P2@T90208V9R@80RXZ:0P28R8P708>3P`80PX:21024Q8@50861P@80Ng]k0P1lO7`207emO@80
NGUi101hN7P307YjNP80Ng]k0P1lO7`207emO@P0b>3H00060<SPf0809RHV0P0b<S8204a<C0<0Lg=c
0P1=CDd202HV9P80820P0P0Q8B4201hN7PD07AdM0P0U9BD2051@D080Ph>30P2EUID207UiN@80Kfm_
0`1iNGT207IfMP80N7Qh0P2UYJD20<O7a`80b<S80P3>c/h30<o?c`@0c/k>0P29RHT2034a<@809BDU
0P0V9RH202DU9@<09bLW0P0Q8B4202<S8`80:BTY0P0W9bL202TY:@80BDU90`1LG5`204Q8B080=CDe
0P0l?3`204E5A@80BDU90P1=CDd305YJFP80HV9R0P1VIVH206a/K080LW9b0P1dM7@207EeM@<0PX:2
0P23Ph<207emO@80Ng]k0P20P80208>3P`80QXJ60`1nOWh208B4Q080QhN70P29RHT408Z:RP80QXJ6
0`29RHT2092@T080VYZJ0P2BTY82092@T0@0UYJF0`2KVi/209VIV@80UiNG1P2QXJ420:>SX`<0X:2P
0P2NWYh209nOW`80X:2P0P2RXZ820:>SX`80XZ:R0`2UYJD20:RXZ080YJFU0P2SXj<20:RXZ080ZJVY
0P2XZ:P20:BTY0<0YJFU0P2XZ:P20::RXP@0YZJV0P2OWil20:2PX0<0Vi^K0P2FUYH2096AT@80T92@
0P29RHT208Z:RP80R8R81`23Ph<208:2PP@0Q8B41@21PH4207]kN`80O7al0P1mOGd207UiN@@0N7Qh
0`1jNWX207]kN`80O7al0P1mOGd80<SPf0001P38h=P203<c<`80?Cdm0P1LG5`308F5Q@80MWIf0P16
ATH202@T90807QhN100K6a/301`L70808b<S0P0g=cL2071`L080X:2P0P2;Rh/206e]K@<0OWin0P1f
MWH207EeM@80TI6A0P2n_[h20<?3``D0b/[:0P3<c<`20<o?c`80`l?30P1TI6@202PX:0808B4Q0P0S
8b<302DU9@809RHV0P0Q8B4201lO7`809bLW0P0^;Rh204];B`<0EEEE0P14A4@203De=@80>SXj0P14
A4@204Y:BP80DE5A0`1FEUH206QXJ080JFUY0P1[Jf/2071`L080Kfm_0P1kNg/307inOP@0OGem0P21
PH4208>3P`80PH610P25QHD30861P@80Ogmo0P29RHT408^;R`80QhN70P28R8P308f=S@80TY:B0P2H
V9P2096AT@80UYJF0P2GUiL209VIV@<0VYZJ0P2FUYH209^KV`80XJ6Q0P2MWId20:>SX`80XZ:R0`2J
VYX409jNWP80XZ:R0P2TY:@20:^[Z`80ZZZZ0`2[Zj/20:ZZZP80Z:RX0P2WYjL20:VYZ@80Z:RX0P2Z
ZZX20:JVYP<0Z:RX0P2VYZH40:2PX080YJFU0P2QXJ4209jNWP<0Vi^K0P2EUID209RHV080TI6A0P2<
S8`208^;R`80RXZ:0`26QXH208F5Q@80P8200P23Ph<208J6QP80QhN70P25QHD308:2PP80OGem0P1n
OWh20820P080O7al0P1hN7P207YjNP<0Ng]k0P1lO7`207]kN`80OGem2038h=P000H0b>3H0P0c<c<2
03dm?@80G5aL0`25QHD207IfMP80ATI60P0T92@201hN7P@06a/K0`0L71`202<S8`80=cLg0P1`L702
0:2PX080Rh^;0P1]KFd307inOP80MWIf0P1eMGD2096AT@80_[jn0P33`l<50<[:bP80c<c<0P3?cll2
0<?3``80I6AT0P0X:2P2024Q8@808b<S0`0U9BD202HV9P808B4Q0P0O7al202LW9`80;Rh^0P1;Bd/3
05EEE@80A4A40P0e=CD203Xj>P80A4A40P1:BTX2055AD@<0EUIF0P1XJ6P206UYJ@80Jf][0P1`L702
06m_K`80Ng]k0`1nOWh407emO@80PH610P23Ph<20861P@80QHF50`21PH4207moO`80RHV9102;Rh/2
08N7Q`80R8R80`2=SHd209:BTP80V9RH0P2ATI4209JFUP80UiNG0P2IVIT309ZJVP80UYJF0P2KVi/2
0:6QX@80WIfM0P2SXj<20::RXP<0VYZJ102NWYh20::RXP80Y:BT0P2[Zj/20:ZZZP<0Zj^[0P2ZZZX2
0:RXZ080YjNW0P2YZJT20:RXZ080ZZZZ0P2VYZH30:RXZ080YZJV102PX:020:FUY@80XJ6Q0P2NWYh3
09^KV`80UIFE0P2HV9P2096AT@80S8b<0P2;Rh/208Z:RP<0QXJ60P25QHD20820P080Ph>30P26QXH2
08N7Q`80QHF50`22PX8207emO@80OWin0P20P80207alO080N7Qh0P1jNWX307]kN`80O7al0P1kNg/2
07emO@P0b>3H00060<SPf080=3@d0P1ADE4206IVIP<0R8R80P1gMgL205QHF08092@T0P0L71`201dM
7@806a/K0`0J6QX201hN7P809RHV0P1IFET209:BTP80WYjN0P1aLG4506m_K`80LG5a0P25QHD20:RX
Z080aLG50P39bLT30<c<c080bl_;0P3<c<`20<k>cP80]KFe0P16ATH202LW9`D08B4Q0P0S8b<202XZ
:P809BDU0P0S8b<202TY:@80AdM70`1FEUH203lo?`80>SXj0P0h>3P203`l?080ADE51@1EEED206UY
J@80IVIV0P1/K6`2071`L080MWIf0P1gMgL507emO@80QHF50P21PH4208:2PP80Q8B40P20P80508:2
PP80Q8B40P27QhL208V9R@80SHf=0P2;Rh/5092@T080Ti>C0P2EUID209fMW@80UiNG0P2LW9`309fM
W@80V9RH0P2PX:0209fMW@80XJ6Q0P2TY:@20::RXP<0XJ6Q0P2RXZ820:2PX080ZZZZ0P2WYjL20:ZZ
ZP80YZJV0`2SXj<20:^[Z`80[:b/0P2XZ:P20:ZZZP80Zj^[0P2YZJT20:NWY`<0ZJVY102UYJD20:6Q
X@80YJFU0P2QXJ4209VIV@<0Vi^K0P2HV9P209NGU`80TY:B0P2>SXh208V9R@80QXJ60`28R8P208B4
Q0H0Ph>30P27QhL208>3P`D0PH610P1mOGd208:2PP80OWin0P1kNg/207QhN0<0NWYj0P1nOWh207]k
N`80OWin2038h=P000H0b>3H0P0d=3@2055AD@80IVIV0`28R8P207MgM`80F5QH0P0T92@201`L7080
7AdM0P0K6a/301XJ6P807QhN0P0V9RH205UIF@80TY:B0P2NWYh2075aL@D0Kfm_0P1aLG4208F5Q@80
Z:RX0P35aLD20<W9b@<0c<c<0P3;bl/20<c<c080c/k>0P2e]KD204I6AP809bLW1@0Q8B4202<S8`80
:RXZ0P0U9BD202<S8`80:BTY0P17AdL305IFEP80?clo0P0j>SX203Ph>080?3`l0P15ADD505EEE@80
JFUY0P1VIVH206a/K080L71`0P1fMWH207MgM`D0OGem0P25QHD20861P@80PX:20P24Q8@20820P0D0
PX:20P24Q8@208N7Q`80RHV90P2=SHd208^;R`D0T92@0P2CTi<209FEU@80WIfM0P2GUiL209bLW0<0
WIfM0P2HV9P20:2PX080WIfM0P2QXJ420:BTY080XZ:R0`2QXJ420::RXP80X:2P0P2ZZZX20:NWY`80
ZZZZ0P2VYZH30:>SX`80Zj^[0P2/[:`20:RXZ080ZZZZ0P2[Zj/20:VYZ@80YjNW0`2YZJT40:FUY@80
XJ6Q0P2UYJD20:6QX@80VIVI0`2KVi/209RHV080UiNG0P2BTY8208j>SP80RHV90P26QXH308R8R080
Q8B41P23Ph<208N7Q`80Ph>31@21PH4207emO@80PX:20P1nOWh207]kN`80N7Qh0`1jNWX207inOP80
Ng]k0P1nOWh80<SPf0001P38h=P204=3@`80HV9R0P1nOWh309>CT`80Ogmo0P1PH60202HV9P807AdM
0P0O7al202@T90<07AdM0P0N7Qh202@T9080>c/k0P21PH4209bLW080Ogmo0`1eMGD206i^KP80L71`
0P1nOWh20:2PX080a/K60P37alL30<[:bP80c<c<0P3=cLd20<k>cP80c<c<0P2UYJD203lo?`809RHV
1`0S8b<4024Q8@80:b/[0P11@D4305MGE`80?3`l0P0g=cL203@d=080?3`l0P15ADD2051@D0<0Fe]K
0P1TI6@206EUI@80K6a/0P1`L70207AdM080MWIf0`1lO7`207UiN@@0PH610P20P80208>3P`80QHF5
0`26QXH208N7Q`80Ph>30P26QXH208V9R@80TI6A0P2?Shl309:BTP80SXj>102CTi<209NGU`80UIFE
0P2KVi/309bLW080WinO0P2JVYX209nOW`80Y:BT0P2RXZ820:2PX0<0Y:BT0P2PX:020:BTY080ZZZZ
0P2/[:`20:f][@80YZJV0`2SXj<20:^[Z`80[Jf]0P2/[:`40:RXZ080Zj^[0P2ZZZX30:VYZ@80ZZZZ
0P2WYjL40:FUY@80YZJV0P2NWYh509fMW@80UiNG0P2DU9@208R8R080QhN70P25QHD308B4Q080QXJ6
0P25QHD208N7Q`80QXJ60P28R8P208>3P`<0PX:21023Ph<20861P@80O7al0P1gMgL207QhN0<0OGem
0P1kNg/207inOP80Ph>32038h=P000H0b>3H0P13@d<2069RHP80OWin0`2CTi<207moO`80H61P0P0V
9RH201dM7@807alO0P0T92@301dM7@807QhN0P0T92@203/k>`80PH610P2LW9`207moO`<0MGEe0P1^
KVh2071`L080OWin0P2PX:020<K6aP80alO70`3:b/X20<c<c080cLg=0P3>c/h20<c<c080YJFU0P0o
?cl202HV9PL08b<S100Q8B4202/[:`80@D510`1GEeL203`l?080=cLg0P0d=3@203`l?080ADE50P1@
D50305]KF`80I6AT0P1UIFD206a/K080L71`0P1dM7@207IfMP<0O7al0P1iNGT40861P@80P8200P23
Ph<208F5Q@<0QXJ60P27QhL208>3P`80QXJ60P29RHT2096AT@80Shn?0`2BTY8208j>SP@0Ti>C0P2G
UiL209FEU@80Vi^K0`2LW9`209nOW`80VYZJ0P2OWil20:BTY080XZ:R0P2PX:030:BTY080X:2P0P2T
Y:@20:ZZZP80[:b/0P2][Jd20:JVYP<0Xj>S0P2[Zj/20:f][@80[:b/102XZ:P20:^[Z`80ZZZZ0`2Y
ZJT20:ZZZP80YjNW102UYJD20:JVYP80WYjN1@2MWId209NGU`80U9BD0P28R8P208N7Q`80QHF50`24
Q8@208J6QP80QHF50P27QhL208J6QP80R8R80P23Ph<308:2PP@0Ph>30P21PH4207alO080MgMg0P1h
N7P307emO@80Ng]k0P1nOWh208>3P`P0b>3H00060<SPf080De=C0P1dM7@209^KV`<0[Jf]0P2HV9P2
06UYJ@809RHV0P0N7Qh2020P808092@T0`0S8b<201lO7`80820P0P0V9RH205]KF`80S8b<0P2DU9@3
07alO080KVi^0P1[Jf/207AdM080T92@0P2f][H20<k>cP<0a/K60P3=cLd20<o?c`@0cLg=0P39bLT2
08^;R`80<C4a0`0R8R8402LW9`8092@T0P0[:b/202HV9P80A4A40`1EEED203Ph>080;bl_0P0e=CD2
03Ti>@80C4a<0P1FEUH305YJFP80IFEU0P1VIVH206m_K`80LG5a0P1cLg<207IfMP<0OWin0P1hN7P2
08>3P`80QHF50P20P80208>3P`L0QHF50P26QXH208N7Q`@0Rh^;0P2@T90309>CT`80Shn?0P2EUID8
09RHV0<0X:2P0P2MWId20:2PX080Y:BT0P2LW9`209fMW@80X:2P0`2SXj<20:RXZ080Y:BT0P2][Jd2
0;6a/@80ZJVY0P2ZZZX30:NWY`80[:b/0P2XZ:P20:j^[P80/;2`0P2[Zj/20:ZZZPD0[:b/0P2UYJD2
0:NWY`80X:2P0P2UYJD20:JVYP80WinO0`2NWYh209RHV080VIVI0P2DU9@2096AT@80RXZ:0P25QHD7
08J6QP80Q8B40P28R8P208J6QP80PX:20`25QHD40820P080Ogmo0P1kNg/207YjNP80N7Qh0`1kNg/2
07alO0@0PX:22038h=P000H0b>3H0P1CDe<207AdM080Vi^K0`2][Jd209RHV080JFUY0P0V9RH201hN
7P80820P0P0T92@302<S8`807alO0P0P820202HV9P80Fe]K0P2<S8`209BDU0<0O7al0P1^KVh206][
J`80M7Ad0P2@T9020;Jf]P80c/k>0`36a/H20<g=c@80clo?103=cLd20<W9b@80Rh^;0P0a<C43028R
8P@09bLW0P0T92@202/[:`809RHV0P14A4@305EEE@80>3Ph0P0_;bl203De=@80>CTi0P1<C4`205IF
EP<0FUYJ0P1UIFD206IVIP80Kfm_0P1aLG4207=cL`80MWIf0`1nOWh207QhN080Ph>30P25QHD20820
P080Ph>31`25QHD208J6QP80QhN7102;Rh/2092@T0<0Ti>C0P2?Shl209FEU@P0V9RH0`2PX:0209fM
W@80X:2P0P2TY:@209bLW080WIfM0P2PX:030:>SX`80Z:RX0P2TY:@20:f][@80/K6a0P2YZJT20:ZZ
ZP<0YjNW0P2/[:`20:RXZ080[Zj^0P2`/;020:^[Z`80ZZZZ1@2/[:`20:FUY@80YjNW0P2PX:020:FU
Y@80YZJV0P2OWil309jNWP80V9RH0P2IVIT209BDU080TI6A0P2:RXX208F5Q@L0QXJ60P24Q8@208R8
R080QXJ60P22PX8308F5Q@@0P8200P1oOgl207]kN`80NWYj0P1hN7P307]kN`80O7al1022PX880<SP
f0001P38h=P205mOG`80P8200P2f][H30:f][@80RXZ:0P1ADE4202TY:@@08b<S0P0X:2P302DU9@80
820P0P0X:2P202@T9080>c/k0P1jNWX209VIV@<0Ph>30P1]KFd406m_K`80PH610P2PX:020=7Ad@<0
alO70P39bLT20<_;b`80c<c<0P3=cLd20=7Ad@80`L710P1LG5`302LW9`80820P0P0V9RH202<S8`80
92@T0P0U9BD20410@0<0CTi>0P0i>CT2034a<@80>3Ph0P0o?cl204m?C`80E5AD0`1KFe/2069RHP80
IFEU0P1/K6`2071`L080Kfm_0P1hN7P307alO080OGem0P1nOWh208F5Q@80Ogmo0P27QhL208B4Q0<0
QXJ60P25QHD208B4Q080SHf=0P2?Shl208^;R`80S8b<0`2@T90209>CT`80V9RH0P2KVi/409VIV@80
W9bL0`2NWYh209^KV`80WYjN0P2LW9`20:BTY080XJ6Q0P2VYZH30:>SX`80ZZZZ0P2/[:`20;:b/P80
[Jf]102/[:`30:n_[`80[Zj^0P2[Zj/20:b/[080[Zj^0P2][Jd40:RXZ0<0Zj^[0P2VYZH40:NWY`80
XJ6Q0P2RXZ8209nOW`<0VIVI0P2EUID209NGU`80UIFE0P2ATI4208Z:RP80R8R80`26QXH208V9R@@0
Q8B41P27QhL308Z:RP80OWin0P1kNg/20820P080Ogmo0P20P80207UiN@<0Ng]k0P1mOGd20861P@80
QHF52038h=P000H0b>3H0P1OGel20820P080][Jf0`2][Jd208Z:RP80DE5A0P0Y:BT402<S8`80:2PX
0`0U9BD2020P8080:2PX0P0T92@203/k>`80NWYj0P2IVIT308>3P`80KFe]101_Kfl20861P@80X:2P
0P3AdM430<O7a`80bLW90P3;bl/20<c<c080cLg=0P3AdM420<71`@80G5aL0`0W9bL2020P80809RHV
0P0S8b<202@T90809BDU0P10@40304i>CP80>CTi0P0a<C4203Ph>080?clo0P1?Cdl205ADE0<0Fe]K
0P1RHV8206EUI@80K6a/0P1`L70206m_K`80N7Qh0`1lO7`207emO@80OWin0P25QHD207moO`80QhN7
0P24Q8@308J6QP80QHF50P24Q8@208f=S@80Shn?0P2;Rh/208b<S0<0T92@0P2CTi<209RHV080Vi^K
102IVIT209bLW0<0WYjN0P2KVi/209jNWP80W9bL0P2TY:@20:6QX@80YZJV0`2SXj<20:ZZZP80[:b/
0P2b/[820:f][@@0[:b/0`2_[jl20:j^[P80Zj^[0P2/[:`20:j^[P80[Jf]102XZ:P30:^[Z`80YZJV
102WYjL20:6QX@80XZ:R0P2OWil309VIV@80UIFE0P2GUiL209FEU@80TI6A0P2:RXX208R8R0<0QXJ6
0P29RHT408B4Q0H0QhN70`2:RXX207inOP80Ng]k0P20P80207moO`80P8200P1iNGT307]kN`80OGem
0P21PH4208F5Q@P0b>3H00060<SPf080NGUi0P2CTi<20;:b/P<0V9RH0P1^KVh2038b<P808B4Q0P0^
;Rh2028R8P809RHV1@0[:b/202PX:0809bLW0P0`<302061PH080T92@0`2EUID206e]K@80I6AT0P1`
L70207UiN@80QHF50P33`l<30<[:bP80aLG50P38b<P20<_;b`80c/k>0P3AdM420=CDe080YjNW0`0_
;bl2028R8P@09BDU0P0X:2P202l_;`80>CTi0`18B4P203Lg=`80=SHf0P0l?3`204M7A`80DE5A0P1C
De<305iNGP80IFEU0P1^KVh206e]K@80MgMg0P1dM7@207YjNP<0P8200P1nOWh408>3P`80OWin0P24
Q8@208:2PP<0QXJ60P27QhL208Z:RPH0SHf=0P2@T90309NGU`80U9BD0P2HV9P209JFUP80UiNG0P2H
V9P509bLW080Vi^K0P2MWId209bLW080YJFU0P2YZJT20:NWY`<0[Jf]102[Zj/20;Bd]080[jn_0P2]
[Jd20:n_[`<0/K6a0P2_[jl20;:b/P80[jn_0P2/[:`20:RXZ080YjNW1@2/[:`20:NWY`80ZJVY0P2W
YjL20:BTY080XJ6Q0P2RXZ8309jNWP80VYZJ0P2IVIT209>CT`80TI6A0P2:RXX208V9R@<0QHF50P28
R8P208J6QP80QHF50P27QhL208R8R080TI6A0`26QXH208>3P`80Ogmo1021PH4207YjNP80OGem1@1l
O7`208B4Q080RHV92038h=P000H0b>3H0P1iNGT209>CT`80/[:b0`2HV9P206i^KP80<S8b0P0Q8B42
02h^;P808R8R0P0V9RH502/[:`80:2PX0P0W9bL2030`<080H61P0P2@T90309FEU@80KFe]0P1TI6@2
071`L080NGUi0P25QHD20<?3``<0b/[:0P35aLD20<S8b080bl_;0P3>c/h20=7Ad@80e=CD0P2WYjL3
02l_;`808R8R100U9BD202PX:080;bl_0P0i>CT304Q8B080=cLg0P0f=SH203`l?080AdM70P1ADE42
05=CD`<0GUiN0P1UIFD206i^KP80KFe]0P1gMgL207AdM080NWYj0`20P80207inOP@0Ph>30P1nOWh2
08B4Q080PX:20`26QXH208N7Q`80RXZ:1P2=SHd2092@T0<0UiNG0P2DU9@209RHV080UYJF0P2GUiL2
09RHV0D0W9bL0P2KVi/209fMW@80W9bL0P2UYJD20:VYZ@80YjNW0`2][Jd40:^[Z`80];Bd0P2_[jl2
0:f][@80[jn_0`2a/K420:n_[`80/[:b0P2_[jl20:b/[080Z:RX0P2WYjL50:b/[080YjNW0P2YZJT2
0:NWY`80Y:BT0P2QXJ420::RXP<0WYjN0P2JVYX209VIV@80Ti>C0P2ATI4208Z:RP80RHV90`25QHD2
08R8R080QXJ60P25QHD208N7Q`80R8R80P2ATI4308J6QP80Ph>30P1oOgl40861P@80NWYj0P1mOGd5
07alO080Q8B40P29RHT80<SPf0001P38h=P20:BTY080VYZJ0P2DU9@3071`L080BDU90P0];Bd202HV
9P808B4Q0P0R8R8202DU9@<0:2PX0P0T92@202XZ:P80:b/[0P0Z:RX204e=C@80P8200`2GUiL207Ui
N@80I6AT0P1`L70207]kN`80OGem0P2][Jd30<c<c080_;bl0P34a<@20<S8b080c<c<0P3@d=020=GE
e@80b<S80`1eMGD203De=@80:BTY0P0R8R8202HV9P809bLW0P0o?cl304=3@`80<C4a0P0_;bl203Hf
=P80?Cdm0P17AdL2055AD@<0I6AT0P1XJ6P206a/K080L71`0P1gMgL407UiN@L0P8200P1oOgl208:2
PP80P8200P24Q8@308V9R@80S8b<0P2=SHd208^;R`80SHf=0P2CTi<209:BTP<0T92@0P2HV9P2096A
T@80VIVI0P2GUiL209RHV080VIVI0`2JVYX209jNWP80WinO0P2RXZ820:JVYP80ZJVY0P2UYJD30:f]
[@80Z:RX0P2[Zj/20;>c/`H0[Zj^0`2a/K420;2`/080/K6a0P2`/;020;:b/P80ZZZZ0P2XZ:P20:^[
Z`<0[Jf]1P2XZ:P20:BTY080Xj>S0P2OWil309fMW@80Vi^K0P2GUiL209RHV080UIFE0P2BTY82092@
T0<0Rh^;0P2<S8`208^;R`@0RHV9102;Rh/308J6QP80Q8B40P1nOWh20861P@80OWin0P1mOGd20861
P@<0O7al0P23Ph<20861P@80Q8B42038h=P000H0b>3H0P2TY:@209ZJVP80U9BD0`1`L70204U9B@80
;Bd]0P0V9RH2024Q8@808R8R0P0U9BD302PX:08092@T0P0Z:RX202/[:`80:RXZ0P1=CDd20820P0<0
UiNG0P1iNGT206ATI080L71`0P1kNg/207emO@80[Jf]0`3<c<`20;bl_080a<C40P38b<P20<c<c080
d=3@0P3EeMD20<S8b0<0MGEe0P0e=CD202TY:@808R8R0P0V9RH202LW9`80?clo0`13@d<2034a<@80
;bl_0P0f=SH203dm?@80AdM70P1ADE4306ATI080J6QX0P1/K6`2071`L080MgMg101iNGT70820P080
Ogmo0P22PX820820P080Q8B40`29RHT208b<S080SHf=0P2;Rh/208f=S@80Ti>C0P2BTY83092@T080
V9RH0P2ATI4209VIV@80UiNG0P2HV9P209VIV@<0VYZJ0P2NWYh209nOW`80XZ:R0P2VYZH20:VYZ@80
YJFU0`2][Jd20:RXZ080Zj^[0P2c/k<60:j^[P<0/K6a0P2`/;020;6a/@80/;2`0P2b/[820:ZZZP80
Z:RX0P2[Zj/30:f][@H0Z:RX0P2TY:@20:>SX`80WinO0`2MWId209^KV`80UiNG0P2HV9P209FEU@80
TY:B0P2@T90308^;R`80S8b<0P2;Rh/408V9R@@0Rh^;0`26QXH208B4Q080OWin0P21PH4207inOP80
OGem0P21PH4307alO080Ph>30P21PH4208B4Q0P0b>3H00060<SPf080Y:BT0P2JVYX209BDU0<0L71`
0P19BDT202d];@809RHV0P0Q8B42028R8P809BDU0`0X:2P202@T9080:RXZ0P0[:b/202XZ:P80CDe=
0P20P80309NGU`80NGUi0P1TI6@2071`L080Ng]k0P1mOGd20:f][@<0c<c<0P2l_;`20<C4a080b<S8
0P3<c<`20=3@d080eMGE0P38b<P307EeM@80=CDe0P0Y:BT2028R8P809RHV0P0W9bL203lo?`<0@d=3
0P0a<C4202l_;`80=SHf0P0m?Cd204M7A`80DE5A0`1TI6@206QXJ080K6a/0P1`L70207MgM`@0NGUi
1`20P80207moO`80PX:20P20P80208B4Q0<0RHV90P2<S8`208f=S@80Rh^;0P2=SHd209>CT`80TY:B
0`2@T90209RHV080TI6A0P2IVIT209NGU`80V9RH0P2IVIT309ZJVP80WYjN0P2OWil20::RXP80YZJV
0P2YZJT20:FUY@<0[Jf]0P2XZ:P20:^[Z`80/k>c1P2^[Zh30;6a/@80/;2`0P2a/K420;2`/080/[:b
0P2ZZZX20:RXZ080Zj^[0`2][Jd60:RXZ080Y:BT0P2SXj<209nOW`<0WIfM0P2KVi/209NGU`80V9RH
0P2EUID209:BTP80T92@0`2;Rh/208b<S080Rh^;1029RHT408^;R`<0QXJ60P24Q8@207inOP80PH61
0P1nOWh207emO@80PH610`1lO7`208>3P`80PH610P24Q8@80<SPf0001P38h=P20:b/[080UiNG0P1/
K6`304A4A080;2`/0P0X:2P202/[:`809RHV0P0Q8B4202HV9P<08R8R0P0S8b<2020P80@0:2PX0P0c
<c<2075aL@<0Shn?0P2>SXh206UYJ@80L71`0P1dM7@207MgM`80Shn?0`37alL20;bl_080_Kfm0P34
a<@20<O7a`80bl_;0P3?cll20=7Ad@<0/k>c0P14A4@202XZ:P808b<S0P0T92@202PX:080;bl_0`0n
?Sh202l_;`80=3@d0P0l?3`204=3@`80Cdm?0P1ADE4306=SH`80J6QX0P1/K6`2071`L0@0NWYj1`1k
Ng/207inOP80PH610P23Ph<208R8R0D0PX:20P26QXH208b<S080RXZ:0P2=SHd208n?S`80T92@0`2B
TY8209RHV080UIFE0P2JVYX209VIV@80Vi^K0P2FUYH309VIV@@0WIfM0P2PX:060:FUY@<0[Jf]0P2W
YjL20:j^[P80/K6a0P2`/;020:b/[080/K6a0`2e]KD20;6a/@80/[:b0P2_[jl20:f][@80Zj^[0P2Y
ZJT20:^[Z`<0ZZZZ0P2/[:`20:ZZZP@0YjNW0P2UYJD50:6QX@80WIfM0P2JVYX209:BTP@0Ti>C0P2?
Shl308b<S080R8R8102:RXX2092@T080R8R80P2?Shl308R8R080QHF50P23Ph<20820P080PX:20P1k
Ng/207emO@<0NGUi1022PX8208>3P`P0b>3H00060<SPf080[:b/0P2GUiL206a/K0<0A4A40P0/;2`2
02PX:080:b/[0P0V9RH2024Q8@809RHV0`0R8R8202<S8`80820P100X:2P203<c<`80LG5a0`2?Shl2
08j>SP80JFUY0P1`L70207AdM080MgMg0P2?Shl30<O7a`80_;bl0P2m_Kd20<C4a080alO70P3;bl/2
0<o?c`80dM7A0`2c/k<204A4A080:RXZ0P0S8b<202@T9080:2PX0P0_;bl303hn?P80;bl_0P0d=3@2
03`l?080@d=30P1?Cdl2055AD@<0Hf=S0P1XJ6P206a/K080L71`101jNWX707]kN`80OWin0P21PH42
08>3P`80R8R81@22PX8208J6QP80S8b<0P2:RXX208f=S@80Shn?0P2@T90309:BTP80V9RH0P2EUID2
09ZJVP80VIVI0P2KVi/209JFUP<0VIVI102MWId20:2PX0H0YJFU0`2][Jd20:NWY`80[Zj^0P2a/K42
0;2`/080[:b/0P2a/K430;Fe]@80/K6a0P2b/[820:n_[`80[Jf]0P2[Zj/20:VYZ@80Zj^[0`2ZZZX2
0:b/[080ZZZZ102WYjL20:FUY@D0XJ6Q0P2MWId209ZJVP80TY:B102CTi<208n?S`<0S8b<0P28R8P4
08Z:RP80T92@0P28R8P208n?S`<0R8R80P25QHD208>3P`80P8200P22PX8207]kN`80OGem0`1iNGT4
08:2PP80Ph>32038h=P000H0b>3H0P2@T90207YjNP80ADE50`0Z:RX2028R8P80:b/[0P0_;bl202TY
:@808R8R0P0Q8B43028R8P80:BTY0P0V9RH2028R8P8092@T0P0Z:RX205=CD`<0QHF50P2OWil207Qh
N080Lg=c0P1dM7@207MgM`80Ng]k0`2f][H20<G5a@80^;Rh0P2m_Kd20<C4a080aLG50P39bLT20=3@
d0<0c<c<0P2GUiL2038b<PH0:BTY0P0e=CD304=3@`80;2`/0P0`<30203`l?080?Cdm0P1;Bd/205EE
E@<0GemO0P1UIFD206i^KP80M7Ad0P1oOgl207UiN@80MWIf0`1hN7P207UiN@80Ogmo0P23Ph<208:2
PP80S8b<1@24Q8@208F5Q@@0RHV9102?Shl2096AT@<0SXj>0P2EUID209JFUP80V9RH0P2IVIT209bL
W080TY:B1@2KVi/209ZJVP80XZ:R0P2WYjL20:>SX`80YjNW0`2YZJT20:ZZZP80/[:b0P2_[jl20;>c
/`80[jn_0P2a/K430:n_[`80/K6a0P2h^;P20;6a/@@0[Zj^0P2YZJT20:^[Z`<0/;2`0P2^[Zh20:FU
Y@80YZJV0P2UYJD20:BTY080WYjN0`2MWId209^KV`80WinO102BTY8208b<S080SXj>0`2?Shl208V9
R@80Rh^;0P2<S8`2096AT@80Rh^;0P2:RXX508V9R@80Q8B40P21PH4207alO080MWIf0P24Q8@307mo
O`80P8200P23Ph<208R8R0P0b>3H00060<SPf080T92@0P1jNWX204E5A@<0:RXZ0P0R8R8202/[:`80
;bl_0P0Y:BT2028R8P808B4Q0`0R8R8202TY:@809RHV0P0R8R8202@T9080:RXZ0P1CDe<308F5Q@80
WinO0P1hN7P207=cL`80M7Ad0P1gMgL207]kN`<0][Jf0P35aLD20;Rh^080_Kfm0P34a<@20<G5a@80
bLW90P3@d=030<c<c080UiNG0P0b<S8602TY:@80=CDe0`13@d<202`/;080<30`0P0l?3`203dm?@80
Bd];0P1EEED305mOG`80IFEU0P1^KVh207AdM080Ogmo0P1iNGT207IfMP<0N7Qh0P1iNGT207moO`80
Ph>30P22PX8208b<S0D0Q8B40P25QHD408V9R@@0Shn?0P2ATI4308j>SP80UIFE0P2FUYH209RHV080
VIVI0P2LW9`209:BTPD0Vi^K0P2JVYX20::RXP80YjNW0P2SXj<20:NWY`<0ZJVY0P2ZZZX20;:b/P80
[jn_0P2c/k<20:n_[`80/K6a0`2_[jl20;6a/@80^;Rh0P2a/K440:j^[P80ZJVY0P2[Zj/30;2`/080
[Zj^0P2UYJD20:JVYP80YJFU0P2TY:@209jNWP<0WIfM0P2KVi/209nOW`@0TY:B0P2<S8`208j>SP<0
Shn?0P29RHT208^;R`80S8b<0P2ATI4208^;R`80RXZ:1@29RHT208B4Q080PH610P1lO7`207IfMP80
Q8B40`1oOgl20820P080Ph>30P28R8P80<SPf0001P38h=P207MgM`80F5QH0P0];Bd302DU9@808b<S
0P0P820202<S8`808R8R0P0U9BD202@T90<08b<S100R8R8201lO7`808B4Q0P0U9BD203Ti>@<0LW9b
0P2JVYX208^;R`80Lg=c0P1bLW82071`L080M7Ad0`2KVi/20<K6aP80^KVi0P2k^k/20;no_`80a<C4
0P33`l<20<G5a@<0c<c<0P32`/8206YZJP80<S8b0P0`<30202XZ:P80;Bd]0`0j>SX202d];@80=cLg
0P0d=3@203`l?080CDe=0P1IFET306EUI@80K6a/0P1aLG4207EeM@80NWYj0P1hN7P207IfMP<0N7Qh
0P1nOWh208>3P`80QXJ60P24Q8@208N7Q`80PX:21@25QHD208N7Q`80S8b<0P2@T90209BDU080TY:B
0`2>SXh209:BTP80TI6A0P2DU9@209FEU@80W9bL0P2MWId309^KV`H0XZ:R0P2XZ:P20:JVYP80[:b/
0`2_[jl20;2`/080/K6a0P2`/;020;Rh^080[Zj^0P2b/[830;Bd]080]KFe0P2g]kL20;2`/0H0[jn_
0P2[Zj/30;:b/P80[Jf]0P2YZJT20:RXZ080YZJV0P2WYjL50::RXP80X:2P0P2JVYX209JFUP80UIFE
0P2;Rh/208n?S`<0TI6A0P2<S8`208f=S@80U9BD0P2CTi<208j>SP80RXZ:0`2;Rh/208F5Q@80QXJ6
0P21PH4207moO`80OWin0P1mOGd308>3P`80P8200P26QXH208:2PPP0b>3H00060<SPf080MgMg0P1H
F5P202d];@<09BDU0P0S8b<2020P80808b<S0P0R8R8202DU9@8092@T0`0S8b<4028R8P807alO0P0Q
8B4202DU9@80>CTi0`1bLW8209ZJVP80Rh^;0P1cLg<2079bLP80L71`0P1dM7@309^KV`80a/K60P2i
^KT20;^k^`80_kno0P34a<@20<?3``80aLG50`3<c<`20<;2`P80JVYZ0P0b<S82030`<080:RXZ0P0]
;Bd303Xj>P80;Bd]0P0g=cL203@d=080?3`l0P1=CDd205UIF@<0IFEU0P1/K6`2075aL@80MGEe0P1j
NWX207QhN080MWIf0`1hN7P207inOP80Ph>30P26QXH208B4Q080QhN70P22PX8508F5Q@80QhN70P2<
S8`2092@T080U9BD0P2BTY8308j>SP80TY:B0P2ATI4209BDU080UIFE0P2LW9`209fMW@<0Vi^K1P2R
XZ820:RXZ080YZJV0P2/[:`30:n_[`80/;2`0P2a/K420;2`/080^;Rh0P2^[Zh20;:b/P<0];Bd0P2e
]KD20;Ng]`80/;2`1P2_[jl20:^[Z`<0/[:b0P2][Jd20:VYZ@80Z:RX0P2VYZH20:NWY`D0XZ:R0P2P
X:0209ZJVP80UYJF0P2EUID208^;R`80Shn?0`2ATI4208b<S080SHf=0P2DU9@209>CT`80SXj>0P2:
RXX308^;R`80QHF50P26QXH20861P@80Ogmo0P1nOWh207emO@<0Ph>30P20P80208J6QP80PX:22038
h=P000H0b>3H0P1IFET203hn?P809bLW0`0U9BD202@T90809bLW0P0/;2`202LW9`808b<S0P0R8R83
02HV9P80<S8b0P0U9BD4028R8P807alO0P0Y:BT305]KF`80RHV90P2DU9@207IfMP@0Kfm_0P1cLg<3
08B4Q080`<300P37alL20;^k^`80_Kfm0P36a/H40;fm_@<0`l?30P3>c/h20:b/[080>SXj0P0_;bl2
02/[:`80;Bd]0`0e=CD202h^;P80<S8b0P0f=SH20410@080Cdm?0P1IFET306EUI@80K6a/0P1bLW82
075aL@@0MGEe1@1kNg/208:2PP80Ph>30P1nOWh208:2PP80RHV90P25QHD308R8R080QXJ60P24Q8@2
08^;R`80Shn?0P2ATI42092@T0<0Ti>C102@T90209FEU@80UiNG0P2HV9P209fMW@<0XZ:R0P2WYjL2
0:VYZ@80YJFU0P2XZ:P20:^[Z`80[:b/0`2`/;020;:b/P80];Bd0P2f][H20;>c/`80/;2`0P2_[jl3
0;Bd]080]kNg0P2c/k<20:f][@80[jn_0P2^[Zh20:VYZ@80[jn_0`2`/;020:n_[`80Zj^[0P2][Jd2
0:VYZ@80XZ:R0P2SXj<309jNWP@0Vi^K0P2GUiL209JFUP80TI6A0P2?Shl309>CT`80T92@0P2=SHd2
09:BTP80U9BD0P2<S8`2096AT@D0R8R81026QXH207inOP80Ogmo0P1lO7`308:2PP80Q8B41025QHD8
0<SPf0001P38h=P205UIF@80?Shn0P0W9bL302DU9@8092@T0P0W9bL202`/;0809bLW0P0S8b<2028R
8P<09RHV0P0b<S8202DU9@@08R8R0P0O7al202TY:@<0Fe]K0P29RHT209BDU080MWIf101_Kfl207=c
L`<0Q8B40P30`<020<O7a`80^k^k0P2m_Kd20<K6aP@0_Kfm0`33`l<20<k>cP80[:b/0P0j>SX202l_
;`80:b/[0P0];Bd303De=@80;Rh^0P0b<S8203Hf=P80@4100P1?Cdl205UIF@<0IFEU0P1/K6`2079b
LP80LG5a101eMGD507]kN`80PX:20P23Ph<207inOP80PX:20P29RHT208F5Q@<0R8R80P26QXH208B4
Q080Rh^;0P2?Shl2096AT@80T92@0`2CTi<4092@T080UIFE0P2GUiL209RHV080WIfM0`2RXZ820:NW
Y`80ZJVY0P2UYJD20:RXZ080Zj^[0P2/[:`30;2`/080/[:b0P2d];@20;Jf]P80/k>c0P2`/;020:n_
[`<0];Bd0P2g]kL20;>c/`80[Jf]0P2_[jl20:j^[P80ZJVY0P2_[jl30;2`/080[jn_0P2[Zj/20:f]
[@80ZJVY0P2RXZ820:>SX`<0WYjN102KVi/209NGU`80UYJF0P2ATI4208n?S`<0Ti>C0P2@T90208f=
S@80TY:B0P2DU9@208b<S080TI6A1@28R8P408J6QP80OWin0P1oOgl207alO0<0PX:20P24Q8@408F5
Q@P0b>3H00060<SPf080@d=30P0a<C4203<c<`<0;2`/0P0X:2P202LW9`80:BTY0P0Z:RX202TY:@80
9BDU0`0X:2P2034a<@809BDU0P0Z:RX2020P80807AdM0P0R8R8303Xj>P80MWIf0P2DU9@209>CT`80
L71`0P1dM7@207QhN0<0MGEe0P2OWil20<c<c080_[jn0P2i^KT20<;2`P80`<300P2l_;`30;^k^`@0
b/[:0P2@T90203De=@808b<S0P0U9BD302`/;080:b/[0P0^;Rh203Lg=`80ADE50P1=CDd205UIF@<0
HF5Q0P1WIfL207EeM@80Lg=c0P1iNGT207EeM@80O7al0`1mOGd207inOP80Ph>30P22PX8207YjNP80
Q8B40P21PH4308J6QP80Q8B40P25QHD208V9R@80R8R80P2BTY8509JFUP80UIFE0P2CTi<209NGU`80
VYZJ102NWYh30:FUY@80YjNW0P2XZ:P20:ZZZP80[Jf]0P2/[:`20;:b/P<0[Jf]0P2a/K420;2`/080
/K6a102d];@20;Ng]`<0_[jn0P2i^KT20;Fe]@80[jn_0P2][Jd20:j^[P80Z:RX1@2[Zj/20:VYZ@80
Zj^[0P2XZ:P20:n_[`80Z:RX0P2QXJ4309nOW`80X:2P0P2JVYX209^KV`80W9bL0P2HV9P509>CT`80
UYJF0P2@T90209FEU@80TY:B0P2<S8`208f=S@<0S8b<0P2:RXX208B4Q080QXJ60P25QHD207]kN`80
P8200`21PH4208F5Q@80Q8B40P29RHT80<SPf0001P38h=P204=3@`80<C4a0P0c<c<302`/;080:2PX
0P0W9bL202TY:@80:RXZ0P0Y:BT202DU9@<0:2PX0P0a<C4202DU9@80:RXZ0P0P820201dM7@808R8R
0`0j>SX207IfMP80U9BD0P2CTi<2071`L080M7Ad0P1hN7P307EeM@80WinO0P3<c<`20;jn_P80^KVi
0P32`/820<30`080_;bl0`2k^k/40<[:bP80T92@0P0e=CD202<S8`809BDU0`0/;2`202/[:`80;Rh^
0P0g=cL204E5A@80CDe=0P1IFET3065QH@80IfMW0P1eMGD207=cL`80NGUi0P1eMGD207alO0<0OGem
0P1nOWh208>3P`80PX:20P1jNWX208B4Q080PH610`26QXH208B4Q080QHF50P29RHT208R8R080TY:B
1@2FUYH209FEU@80Ti>C0P2GUiL209ZJVP@0WYjN0`2UYJD20:NWY`80Z:RX0P2ZZZX20:f][@80[:b/
0P2b/[830:f][@80/K6a0P2`/;020;6a/@@0];Bd0P2g]kL30;jn_P80^KVi0P2e]KD20:n_[`80[Jf]
0P2^[Zh20:RXZ0D0Zj^[0P2YZJT20:^[Z`80Z:RX0P2_[jl20:RXZ080XJ6Q0`2OWil20:2PX080VYZJ
0P2KVi/209bLW080V9RH1@2CTi<209JFUP80T92@0P2EUID209:BTP80S8b<0P2=SHd308b<S080RXZ:
0P24Q8@208J6QP80QHF50P1kNg/20820P0<0PH610P25QHD208B4Q080RHV92038h=P000H0b>3H0P1D
E5@402l_;`<0>3Ph0P0c<c<203De=@8092@T0P0Z:RX202`/;080:RXZ0`0Y:BT2038b<P80:b/[0P0W
9bL202PX:0808R8R0P0T92@303<c<`80GemO0P2@T9020:BTY080Ph>30P1cLg<207MgM`<0LW9b0P26
QXH20;no_`80c<c<0P2a/K420;jn_P80`L710P2o_kl30;Zj^P80`L710P3AdM420<71`@80HV9R0P0X
:2P202LW9`<0:2PX0P0/;2`2030`<080=3@d0P14A4@204Q8B080EEEE0`1OGel206QXJ0@0M7Ad101i
NGT207QhN0<0O7al1020P80207moO`80NGUi0P20P80208>3P`<0QXJ60P2:RXX208b<S080SXj>0P2=
SHd209:BTPL0V9RH0P2GUiL209^KV`80V9RH0P2LW9`20:2PX0<0XJ6Q0P2VYZH40:f][@80/;2`102^
[Zh30;>c/`80]KFe0P2c/k<20:j^[P80][Jf0P2c/k<50;Zj^P80][Jf0P2d];@20:f][@80/k>c102[
Zj/20:b/[0<0/;2`0P2][Jd20:b/[080Z:RX0P2`/;020:JVYP80Y:BT0`2UYJD209fMW@@0WinO0P2H
V9P209JFUP80Ti>C0`2DU9@209FEU@80TI6A0P2DU9@409FEU@80S8b<0`2>SXh208b<S080RXZ:0P25
QHD208N7Q`80PH610P1nOWh30861P@80Ph>30P24Q8@208>3P`P0b>3H00060<SPf080E5AD100_;bl3
03Ph>080<c<c0P0e=CD202@T9080:RXZ0P0/;2`202XZ:P<0:BTY0P0b<S8202/[:`809bLW0P0X:2P2
028R8P8092@T0`0c<c<205mOG`80T92@0P2TY:@208>3P`80Lg=c0P1gMgL3079bLP80QXJ60P2o_kl2
0<c<c080/K6a0P2n_[h20<71`@80_kno0`2j^[X20<71`@80dM7A0P31`L42069RHP80:2PX0P0W9bL3
02PX:080;2`/0P0`<30203@d=080A4A40P18B4P205EEE@<0GemO0P1XJ6P407AdM0@0NGUi0P1hN7P3
07alO0@0P8200P1oOgl207UiN@80P8200P23Ph<308J6QP80RXZ:0P2<S8`208j>SP80SHf=0P2BTY87
09RHV080UiNG0P2KVi/209RHV080W9bL0P2PX:030:6QX@80YZJV102][Jd20;2`/0@0[Zj^0`2c/k<2
0;Fe]@80/k>c0P2^[Zh20;Jf]P80/k>c1@2j^[X20;Jf]P80];Bd0P2][Jd20;>c/`@0Zj^[0P2/[:`3
0;2`/080[Jf]0P2/[:`20:RXZ080/;2`0P2VYZH20:BTY0<0YJFU0P2MWId409nOW`80V9RH0P2FUYH2
09>CT`<0U9BD0P2EUID2096AT@80U9BD102EUID208b<S0<0SXj>0P2<S8`208Z:RP80QHF50P27QhL2
0861P@80OWin0`21PH4208>3P`80Q8B40P23Ph<80<SPf0001P38h=P205mOG`80=cLg0P0`<30302/[
:`808b<S0P0Y:BT202/[:`80;bl_0P0/;2`202LW9`<09RHV0P0b<S8203<c<`80<30`0P0V9RH2024Q
8@80:RXZ0`0/;2`203`l?080N7Qh0P2GUiL209BDU080MWIf0P1]KFd307emO@80MWIf0P2TY:@20<g=
c@80/k>c0P2f][H20;no_`80^k^k0`2l_;`20;fm_@80b/[:0P3AdM420:n_[`80@T920P0Y:BT302LW
9`80;Bd]0P0i>CT203Hf=P80=cLg0P17AdL205MGE`<0HF5Q0P1YJFT206e]K@80MGEe0P1hN7P207Yj
NP80N7Qh0`1lO7`207YjNP80Ng]k101jNWX408>3P`<0QXJ60P2:RXX208n?S`80TI6A0P2?Shl2096A
T@D0V9RH0P2IVIT209RHV080WIfM0P2LW9`209jNWP80XZ:R0`2VYZH20:RXZ080[jn_102^[Zh20:f]
[@D0/K6a0P2d];@20;>c/`@0];Bd0P2b/[820;Bd]0<0/[:b0P2`/;020:n_[`80[:b/0P2f][H20:f]
[@80[jn_0P2`/;030;>c/`80[Zj^0P2`/;020:ZZZP80[:b/0P2^[Zh20:NWY`<0YZJV0P2RXZ8209nO
W`80WIfM0P2JVYX209RHV080TY:B1@2IVIT209:BTP80TI6A0P2EUID209BDU080Shn?1@2<S8`208Z:
RP80Q8B40P29RHT208>3P`80PH610`1lO7`20861P@80Q8B40P22PX880<SPf0001P38h=P205mOG`80
=cLg0P0`<30302/[:`808b<S0P0Y:BT202/[:`80;bl_0P0/;2`202LW9`<09RHV0P0b<S8203<c<`80
<30`0P0V9RH2024Q8@80:RXZ0`0/;2`203`l?080N7Qh0P2GUiL209BDU080MWIf0P1]KFd307emO@80
MWIf0P2TY:@20<g=c@80/k>c0P2f][H20;no_`80^k^k0`2l_;`20;fm_@80b/[:0P3AdM420:n_[`80
@T920P0Y:BT302LW9`80;Bd]0P0i>CT203Hf=P80=cLg0P17AdL205MGE`<0HF5Q0P1YJFT206e]K@80
MGEe0P1hN7P207YjNP80N7Qh0`1lO7`207YjNP80Ng]k101jNWX408>3P`<0QXJ60P2:RXX208n?S`80
TI6A0P2?Shl2096AT@D0V9RH0P2IVIT209RHV080WIfM0P2LW9`209jNWP80XZ:R0`2VYZH20:RXZ080
[jn_102^[Zh20:f][@D0/K6a0P2d];@20;>c/`@0];Bd0P2b/[820;Bd]0<0/[:b0P2`/;020:n_[`80
[:b/0P2f][H20:f][@80[jn_0P2`/;030;>c/`80[Zj^0P2`/;020:ZZZP80[:b/0P2^[Zh20:NWY`<0
YZJV0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080TY:B1@2IVIT209:BTP80TI6A0P2EUID209BDU080
Shn?1@2<S8`208Z:RP80Q8B40P29RHT208>3P`80PH610`1lO7`20861P@80Q8B40P22PX880<SPf000
1P38h=P205mOG`80=cLg0P0`<30302/[:`808b<S0P0Y:BT202/[:`80;bl_0P0/;2`202LW9`<09RHV
0P0b<S8203<c<`80<30`0P0V9RH2024Q8@80:RXZ0`0/;2`203`l?080N7Qh0P2GUiL209BDU080MWIf
0P1]KFd307emO@80MWIf0P2TY:@20<g=c@80/k>c0P2f][H20;no_`80^k^k0`2l_;`20;fm_@80b/[:
0P3AdM420:n_[`80@T920P0Y:BT302LW9`80;Bd]0P0i>CT203Hf=P80=cLg0P17AdL205MGE`<0HF5Q
0P1YJFT206e]K@80MGEe0P1hN7P207YjNP80N7Qh0`1lO7`207YjNP80Ng]k101jNWX408>3P`<0QXJ6
0P2:RXX208n?S`80TI6A0P2?Shl2096AT@D0V9RH0P2IVIT209RHV080WIfM0P2LW9`209jNWP80XZ:R
0`2VYZH20:RXZ080[jn_102^[Zh20:f][@D0/K6a0P2d];@20;>c/`@0];Bd0P2b/[820;Bd]0<0/[:b
0P2`/;020:n_[`80[:b/0P2f][H20:f][@80[jn_0P2`/;030;>c/`80[Zj^0P2`/;020:ZZZP80[:b/
0P2^[Zh20:NWY`<0YZJV0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080TY:B1@2IVIT209:BTP80TI6A
0P2EUID209BDU080Shn?1@2<S8`208Z:RP80Q8B40P29RHT208>3P`80PH610`1lO7`20861P@80Q8B4
0P22PX880<SPf0001P38h=P2051@D080>SXj1@0^;Rh202HV9P80<S8b0P0Z:RX2030`<080<S8b0P0Z
:RX302d];@80;Rh^0P0_;bl202TY:@809bLW0P0V9RH202PX:0<0:RXZ0P0b<S8205aLG080R8R80P2K
Vi/207moO`80JFUY1@1iNGT208>3P`80/[:b0P2h^;P20:b/[080^k^k0P2m_Kd30<30`080_[jn0P38
b<P20=7Ad@80cLg=0P2HV9P203De=@<092@T0P0V9RH202l_;`80<S8b0P0k>c/20451@@80E5AD0`1Q
HF4206EUI@80KVi^0P1bLW8207YjNP80MgMg0P1kNg/507alO080Ogmo0P1mOGd207alO080QXJ60P21
PH4308N7Q`80RHV90P2;Rh/208n?S`80Ti>C0P2>SXh209FEU@<0UYJF102KVi/409bLW080YJFU0P2T
Y:@30:NWY`80Z:RX0P2/[:`20:ZZZP@0[:b/0P2a/K430;>c/`@0];Bd102c/k<20;2`/080[Jf]0`2`
/;060:j^[P80/k>c0P2`/;040:f][@<0/[:b0P2c/k<20;6a/@80Zj^[0P2ZZZX20:VYZ@80YJFU0`2R
XZ820:6QX@80WYjN1P2KVi/209ZJVP<0T92@0P2BTY82096AT@80T92@0P2>SXh209:BTPD0Rh^;0P28
R8P408B4Q080P8200P21PH4208B4Q0D0Ogmo0P20P80208:2PPP0b>3H00060<SPf080D51@0P0j>SX5
02h^;P809RHV0P0b<S8202XZ:P80<30`0P0b<S8202XZ:P<0;Bd]0P0^;Rh202l_;`80:BTY0P0W9bL2
02HV9P80:2PX0`0Z:RX2038b<P80G5aL0P28R8P209^KV`80Ogmo0P1YJFT507UiN@80Ph>30P2b/[82
0;Rh^080[:b/0P2k^k/20;fm_@<0`<300P2n_[h20<S8b080dM7A0P3=cLd209RHV080=CDe0`0T92@2
02HV9P80;bl_0P0b<S8203/k>`80@D510P1DE5@3065QH@80IFEU0P1^KVh2079bLP80NWYj0P1gMgL2
07]kN`D0O7al0P1oOgl207emO@80O7al0P26QXH20861P@<0QhN70P29RHT208^;R`80Shn?0P2CTi<2
08j>SP80UIFE0`2FUYH409^KV`@0W9bL0P2UYJD20:BTY0<0YjNW0P2XZ:P20:b/[080ZZZZ102/[:`2
0;6a/@<0/k>c102d];@40;>c/`80/;2`0P2][Jd30;2`/0H0[Zj^0P2c/k<20;2`/0@0[Jf]0`2b/[82
0;>c/`80/K6a0P2[Zj/20:ZZZP80ZJVY0P2UYJD30::RXP80XJ6Q0P2NWYh609^KV`80VYZJ0`2@T902
09:BTP80TI6A0P2@T90208j>SP80TY:B1@2;Rh/208R8R0@0Q8B40P20P8020861P@80Q8B41@1oOgl2
0820P080PX:22038h=P000H0b>3H0P0g=cL203Ph>080:BTY0`0^;Rh202l_;`80<S8b0P0^;Rh202d]
;@80:b/[0P0/;2`302d];@80;bl_0P0Z:RX202l_;`80<c<c100Y:BT302XZ:P80<30`0P0j>SX206a/
K080U9BD0P2GUiL507=cL`80N7Qh0P1eMGD2092@T080_;bl0P2XZ:P20;Jf]PD0`L711033`l<20<g=
c@80d];B0P39bLT207alO0<0;Bd]0P0Q8B4202PX:080;Bd]0P0h>3P204M7A`80EEEE0`1PH602069R
HP80K6a/0P1_Kfl207MgM`80O7al0P1kNg/307YjNP80OWin1020P80207moO`80QhN70P21PH4308Z:
RP80R8R80P2>SXh409BDU080TI6A0P2CTi<509NGU`H0WIfM102UYJD50:NWY`80ZZZZ0P2^[Zh20:f]
[@80[:b/0P2`/;030;6a/@80/k>c0P2`/;020;Fe]@80[jn_0P2`/;020;Bd]0<0/[:b0P2g]kL20;Bd
]0@0[Zj^0P2_[jl20;Bd]080/k>c0`2`/;020;>c/`@0/[:b0P2][Jd20:ZZZP80Z:RX0`2VYZH40:6Q
X@80VYZJ0P2MWId209VIV@80VYZJ0`2@T90409:BTP80U9BD0P2@T90209BDU080RXZ:0`2=SHd208Z:
RP80PH610P25QHD208N7Q`80QHF50P23Ph<508:2PP80Ng]k0P1oOgl80<SPf0001P38h=P203Lg=`80
>3Ph0P0Y:BT302h^;P80;bl_0P0b<S8202h^;P80;Bd]0P0[:b/202`/;0<0;Bd]0P0_;bl202XZ:P80
;bl_0P0c<c<402TY:@<0:RXZ0P0`<30203Xj>P80K6a/0P2DU9@209NGU`D0Lg=c0P1hN7P207EeM@80
T92@0P2l_;`20:RXZ080][Jf1@31`L440<?3``80cLg=0P3Bd]820<W9b@80O7al0`0];Bd2024Q8@80
:2PX0P0];Bd203Ph>080AdM70P1EEED3061PH080HV9R0P1/K6`206m_K`80MgMg0P1lO7`207]kN`<0
NWYj0P1nOWh40820P080Ogmo0P27QhL20861P@<0RXZ:0P28R8P208j>SP@0U9BD0P2ATI4209>CT`D0
UiNG1P2MWId40:FUY@D0YjNW0P2ZZZX20:j^[P80[Jf]0P2/[:`20;2`/0<0/K6a0P2c/k<20;2`/080
]KFe0P2_[jl20;2`/080];Bd0`2b/[820;Ng]`80];Bd102^[Zh20:n_[`80];Bd0P2c/k<30;2`/080
/k>c102b/[820:f][@80ZZZZ0P2XZ:P30:JVYP@0XJ6Q0P2JVYX209fMW@80VIVI0P2JVYX3092@T0@0
TY:B0P2DU9@2092@T080U9BD0P2:RXX308f=S@80RXZ:0P21PH4208F5Q@80QhN70P25QHD208>3P`D0
PX:20P1kNg/207moO`P0b>3H00060<SPf080?Shn0P0e=CD202l_;`<0;Bd]1P0^;Rh202l_;`80;Bd]
0P0^;Rh3030`<080;Rh^0P0];Bd202h^;P80;bl_0P0a<C42030`<0<0:b/[0P0/;2`203Hf=P80De=C
0P29RHT20:ZZZP80P8200`1cLg<2079bLP80M7Ad0P1mOGd40;Fe]@80/k>c0P2l_;`30<30`0@0`l?3
0P36a/H40<o?c`80_Kfm0`1HF5P202TY:@8092@T0P0^;Rh203@d=080A4A40P1=CDd305MGE`80GemO
0P1YJFT206m_K`80MgMg0P1eMGD207MgM`<0NGUi0P1lO7`207emO@80OWin0P26QXH208:2PP80Ph>3
0`2=SHd208V9R@80SHf=0P2DU9@209>CT`80UiNG0P2HV9P309NGU`80V9RH0P2JVYX209jNWP80XJ6Q
0P2RXZ820:>SX`<0YjNW0P2YZJT20:^[Z`80[Zj^0P2][Jd20:^[Z`80[Zj^0`2c/k<20;:b/P80];Bd
0P2`/;020:b/[080ZZZZ0P2d];@30;>c/`80/;2`102a/K420;:b/P80/K6a0P2`/;020:f][@<0[Zj^
0P2b/[820:n_[`80/[:b0P2_[jl20:f][@80ZZZZ0`2YZJT20:NWY`80Y:BT0P2KVi/209bLW080U9BD
0P2CTi<509BDU080V9RH0P2EUID208j>SP80TY:B0P2:RXX308f=S@80QXJ60P22PX8208R8R080QXJ6
0P24Q8@207moO`<0Q8B40P23Ph<208:2PP80QHF52038h=P000H0b>3H0P0n?Sh203De=@80;bl_0`0]
;Bd602h^;P80;bl_0P0];Bd202h^;P<0<30`0P0^;Rh202d];@80;Rh^0P0_;bl2034a<@80<30`0`0[
:b/202`/;080=SHf0P1CDe<208V9R@80ZZZZ0P20P80307=cL`80LW9b0P1dM7@207emO@@0]KFe0P2c
/k<20;bl_0<0`<301033`l<20<K6aP@0clo?0P2m_Kd305QHF080:BTY0P0T92@202h^;P80=3@d0P14
A4@204e=C@<0EeMG0P1OGel206UYJ@80Kfm_0P1gMgL207EeM@80MgMg0`1iNGT207alO080OGem0P1n
OWh208J6QP80PX:20P23Ph<308f=S@80RHV90P2=SHd209BDU080Ti>C0P2GUiL209RHV0<0UiNG0P2H
V9P209ZJVP80WYjN0P2QXJ420::RXP80Xj>S0`2WYjL20:VYZ@80Zj^[0P2^[Zh20:f][@80Zj^[0P2^
[Zh30;>c/`80/[:b0P2d];@20;2`/080[:b/0P2ZZZX20;Bd]0<0/k>c0P2`/;040;6a/@80/[:b0P2a
/K420;2`/080[Jf]0`2^[Zh20;:b/P80[jn_0P2b/[820:n_[`80[Jf]0P2ZZZX30:VYZ@80YjNW0P2T
Y:@209^KV`80W9bL0P2DU9@209>CT`D0U9BD0P2HV9P209FEU@80SXj>0P2BTY8208Z:RP<0SHf=0P26
QXH208:2PP80R8R80P26QXH208B4Q080Ogmo0`24Q8@208>3P`80PX:20P25QHD80<SPf0001P38h=P2
04Y:BP80<30`0P0];Bd303<c<`80=CDe0P0d=3@202l_;`80>SXj100];Bd302`/;0@0<30`0P0];Bd2
02/[:`80<30`1`0Y:BT202HV9P80<C4a0P1_Kfl209jNWP80U9BD0`1`L70206IVIP80Kfm_0P1fMWH2
0:JVYP80`<300P2[Zj/20;Bd]0<0_Kfm0P2l_;`20<C4a080`/;20P39bLT20=3@d080c<c<0`2XZ:P2
03dm?@80:RXZ0P0X:2P203Hf=P80@D510P1;Bd/305ADE080FUYJ0P1VIVH2075aL@80MGEe0P1dM7@2
07EeM@<0NWYj0P1mOGd207inOP80P8200P1nOWh20861P@80QXJ60`2:RXX208b<S080SHf=0P2BTY82
092@T080U9BD1@2HV9P209FEU@@0WYjN0P2RXZ8209nOW`80Y:BT0`2WYjL20:j^[P80[:b/0P2][Jd2
0:VYZ@80[Jf]0P2_[jl30;Jf]P80]KFe0P2^[Zh20:RXZ080ZZZZ0P2[Zj/50;:b/P80/K6a0P2_[jl2
0;Jf]P80/k>c0P2a/K440;2`/0<0[Jf]0P2^[Zh20:n_[`80/K6a102`/;020:VYZ@<0ZZZZ0P2TY:@2
0:>SX`80WinO0P2JVYX209>CT`80TI6A1@2EUID209BDU080TI6A0P2CTi<2092@T0D0S8b<1P25QHD2
08J6QP80QhN70P1mOGd30861P@80Ph>30P22PX8208F5Q@P0b>3H00060<SPf080BTY:0P0`<30202d]
;@<0<c<c0P0e=CD203@d=080;bl_0P0j>SX402d];@<0;2`/100`<30202d];@80:b/[0P0`<30702TY
:@809RHV0P0a<C4206m_K`80WYjN0P2DU9@3071`L080IVIV0P1_Kfl207IfMP80YZJV0P30`<020:^[
Z`80];Bd0`2m_Kd20;bl_080a<C40P32`/820<W9b@80d=3@0P3<c<`30:RXZ080?Cdm0P0Z:RX202PX
:080=SHf0P11@D4204];B`<0E5AD0P1JFUX206IVIP80LG5a0P1eMGD207AdM080MGEe0`1jNWX207em
O@80OWin0P20P80207inOP80PH610P26QXH308Z:RP80S8b<0P2=SHd209:BTP80T92@0P2DU9@509RH
V080UIFE102NWYh20::RXP80WinO0P2TY:@30:NWY`80[Zj^0P2/[:`20:f][@80ZJVY0P2][Jd20:n_
[`<0][Jf0P2e]KD20:j^[P80Z:RX0P2ZZZX20:^[Z`D0/[:b0P2a/K420:n_[`80][Jf0P2c/k<20;6a
/@@0/;2`0`2][Jd20:j^[P80[jn_0P2a/K440;2`/080ZJVY0`2ZZZX20:BTY080Xj>S0P2OWil209ZJ
VP80Ti>C0P2ATI4509FEU@80U9BD0P2ATI4209>CT`80T92@1@2<S8`608F5Q@80QXJ60P27QhL207em
O@<0PH610P23Ph<208:2PP80QHF52038h=P000H0b>3H0P1CDe<202l_;`809bLW0`0^;Rh2038b<P80
=SHf0P0];Bd202`/;080<C4a0P0`<30302/[:`80<30`0P0e=CD2030`<080:b/[0P0Z:RX202`/;0<0
:BTY0P0W9bL202PX:080;Bd]0P1DE5@209>CT`80XZ:R0`1mOGd206IVIP80IfMW0P1`L70208R8R080
^k^k0P2d];@20:j^[P<0^KVi0P2l_;`20<;2`P80_kno0P32`/820<_;b`80c/k>0`38b<P2092@T080
=3@d0P0`<30203<c<`80?clo0P1<C4`305=CD`@0GemO0P1_Kfl2079bLP80MGEe0P1iNGT307QhN080
NWYj0P1kNg/208>3P`80Ogmo0P23Ph<208B4Q0<0R8R80P2:RXX208^;R`80T92@0P2BTY8209NGU`80
VIVI0`2EUID209ZJVP80WIfM102PX:020::RXP80YjNW1@2XZ:P20:j^[P@0YjNW0P2a/K420:b/[0<0
];Bd0P2`/;020:f][@80Z:RX0P2a/K440;Jf]PD0/K6a0P2`/;020:n_[`80[:b/0P2[Zj/20:FUY@80
ZJVY0`2^[Zh20;:b/P80[Zj^0P2b/[820:^[Z`80[Zj^0P2ZZZX30:RXZ080Xj>S0P2PX:0209ZJVP80
V9RH102FUYH3092@T0@0SXj>0P2@T902096AT@80Shn?0P2<S8`308^;R`80QXJ60P21PH4207inOP@0
QhN70P1lO7`307moO`@0P8200P24Q8@80<SPf0001P38h=P205=CD`80;bl_0P0W9bL302h^;P80<S8b
0P0f=SH202d];@80;2`/0P0a<C42030`<0<0:b/[0P0`<30203De=@80<30`0P0[:b/202XZ:P80;2`/
0`0Y:BT202LW9`80:2PX0P0];Bd205ADE080Ti>C0P2RXZ8307emO@80IVIV0P1WIfL2071`L080R8R8
0P2k^k/20;Bd]080[Zj^0`2i^KT20;bl_080`/;20P2o_kl20<;2`P80bl_;0P3>c/h30<S8b080T92@
0P0d=3@2030`<080<c<c0P0o?cl204a<C0<0De=C101OGel206m_K`80LW9b0P1eMGD207UiN@<0N7Qh
0P1jNWX207]kN`80Ph>30P1oOgl208>3P`80Q8B40`28R8P208Z:RP80Rh^;0P2@T90209:BTP80UiNG
0P2IVIT309FEU@80VYZJ0P2MWId40:2PX080XZ:R0P2WYjL50:RXZ080[Zj^102WYjL20;6a/@80[:b/
0`2d];@20;2`/080[Jf]0P2XZ:P20;6a/@@0][Jf1@2a/K420;2`/080[jn_0P2/[:`20:^[Z`80YJFU
0P2YZJT30:j^[P80/[:b0P2^[Zh20;:b/P80Zj^[0P2^[Zh20:ZZZP<0Z:RX0P2SXj<20:2PX080VYZJ
0P2HV9P409JFUP<0T92@102>SXh2092@T080TI6A0P2?Shl208b<S0<0Rh^;0P26QXH20861P@80OWin
1027QhL207alO0<0Ogmo1020P80208B4Q0P0b>3H00060<SPf080@T920P0W9bL202DU9@<0:2PX0P0d
=3@203<c<`80=3@d0P0Y:BT202HV9P80;bl_0`0[:b/202XZ:P80:BTY0P0_;bl402d];@80;Rh^0`0[
:b/202TY:@80:2PX0P0];Bd20492@P80MgMg0P2LW9`309RHV080KVi^0P1QHF4206YZJP80MWIf0P2T
Y:@20;jn_P80YjNW0`2a/K420;bl_080_kno0P2k^k/20;fm_@80a/K60P3<c<`30<g=c@80`L710P1j
NWX203Hf=P80=3@d0P0m?Cd204M7A`<0Bd];0P1FEUH206MWI`80KFe]0P1bLW82071`L080MGEe0`1h
N7P207alO080Ng]k0P23Ph<20861P@80P8200P24Q8@308N7Q`80S8b<0P2@T90208n?S`80U9BD0P2H
V9P209bLW0<0UYJF0P2KVi/209fMW@80WinO0P2PX:020:FUY@80Y:BT1@2XZ:P20:b/[080YjNW102]
[Jd20:b/[0<0/;2`0P2][Jd20:j^[P80[Jf]0P2`/;040;:b/P<0[Jf]0P2_[jl20:b/[080ZZZZ0P2/
[:`20:f][@80Z:RX0P2TY:@30:f][@@0/K6a0P2b/[820:j^[P80/[:b0P2/[:`30:NWY`80XZ:R102K
Vi/209RHV080UIFE0P2CTi<3092@T080RXZ:0P2>SXh208f=S@80U9BD0P2?Shl208^;R`<0R8R80P24
Q8@208N7Q`80PH610P22PX8208N7Q`80O7al0`20P80207YjNP80Ogmo0P23Ph<80<SPf0001P38h=P2
0492@P809bLW0P0U9BD302PX:080=3@d0P0c<c<203@d=080:BTY0P0V9RH202l_;`<0:b/[0P0Z:RX2
02TY:@80;bl_100];Bd202h^;P<0:b/[0P0Y:BT202PX:080;Bd]0P12@T8207MgM`80W9bL0`2HV9P2
06i^KP80HF5Q0P1ZJVX207IfMP80Y:BT0P2n_[h20:NWY`<0/K6a0P2l_;`20;no_`80^k^k0P2m_Kd2
0<K6aP80c<c<0`3=cLd20<71`@80NWYj0P0f=SH203@d=080?Cdm0P17AdL304];B`80EUIF0P1WIfL2
06e]K@80LW9b0P1`L70207EeM@<0N7Qh0P1lO7`207]kN`80Ph>30P21PH420820P080Q8B40`27QhL2
08b<S080T92@0P2?Shl209BDU080V9RH0P2LW9`309JFUP80Vi^K0P2MWId209nOW`80X:2P0P2UYJD2
0:BTY0D0Z:RX0P2/[:`20:NWY`@0[Jf]0P2/[:`30;2`/080[Jf]0P2^[Zh20:f][@80/;2`102b/[83
0:f][@80[jn_0P2/[:`20:ZZZP80[:b/0P2][Jd20:RXZ080Y:BT0`2][Jd40;6a/@80/[:b0P2^[Zh2
0;:b/P80[:b/0`2WYjL20::RXP@0Vi^K0P2HV9P209FEU@80Ti>C0`2@T90208Z:RP80SXj>0P2=SHd2
09BDU080Shn?0P2;Rh/308R8R080Q8B40P27QhL20861P@80PX:20P27QhL207alO0<0P8200P1jNWX2
07moO`80Ph>32038h=P000H0b>3H0P0_;bl202`/;0D0;Bd]0P0f=SH203<c<`@0;Rh^0P0/;2`202d]
;@<0:2PX0P0`<302034a<@80;2`/0P0d=3@2034a<@80=cLg0`0/;2`202/[:`80<S8b0P0/;2`202TY
:@80DU9B0P2;Rh/30:FUY@80OWin0P1YJFT206MWI`80L71`0P2<S8`20<30`080/[:b0`2[Zj/20;Fe
]@80_;bl0P2n_[h20;fm_@80`/;20P36a/H50<W9b@80^k^k0P1IFET203Hf=P80=cLg0P15ADD3055A
D@80DU9B0P1QHF4206][J`80L71`0P1aLG4206m_K`<0NGUi0P1nOWh207YjNP80Q8B41022PX8208Z:
RPD0Rh^;102=SHd209:BTP80UiNG0P2MWId309ZJVP80XJ6Q0P2KVi/409nOW`80XZ:R1@2YZJT20:BT
Y0@0YJFU0P2ZZZX20:f][@80ZJVY0`2a/K440:f][@80[:b/0P2[Zj/20:f][@80Zj^[0`2/[:`20:f]
[@80Zj^[0P2ZZZX20:b/[080[Jf]0P2XZ:P20:VYZ@<0Z:RX102YZJT40;2`/080[Jf]0P2XZ:P30:b/
[080X:2P0P2LW9`409ZJVP80UIFE0P2DU9@308f=S@80R8R8102>SXh209JFUP80RHV90P2;Rh/308V9
R@80P8200P23Ph<208:2PP@0PH610P1jNWX308J6QP80NWYj0P1nOWh208N7Q`P0b>3H00060<SPf080
;bl_0P0/;2`502d];@80=SHf0P0c<c<402h^;P80;2`/0P0];Bd302PX:080<30`0P0a<C4202`/;080
=3@d0P0a<C4203Lg=`<0;2`/0P0[:b/2038b<P80;2`/0P0Y:BT2059BDP80Rh^;0`2UYJD207inOP80
JFUY0P1WIfL2071`L080S8b<0P30`<020;:b/P<0Zj^[0P2e]KD20;bl_080_[jn0P2m_Kd20<;2`P80
a/K61@39bLT20;^k^`80FEUI0P0f=SH203Lg=`80ADE50`1ADE42059BDP80HF5Q0P1[Jf/2071`L080
LG5a0P1_Kfl307UiN@80OWin0P1jNWX208B4Q0@0PX:20P2:RXX508^;R`@0SHf=0P2BTY8209NGU`80
WIfM0`2JVYX20:6QX@80Vi^K102OWil20::RXPD0ZJVY0P2TY:@40:FUY@80ZZZZ0P2][Jd20:VYZ@<0
/K6a102][Jd20:b/[080Zj^[0P2][Jd20:^[Z`<0[:b/0P2][Jd20:^[Z`80ZZZZ0P2/[:`20:f][@80
Z:RX0P2YZJT30:RXZ0@0ZJVY102`/;020:f][@80Z:RX0`2/[:`20:2PX080W9bL102JVYX209FEU@80
U9BD0`2=SHd208R8R0@0SXj>0P2FUYH208V9R@80Rh^;0`29RHT20820P080Ph>30P22PX840861P@80
NWYj0`26QXH207YjNP80OWin0P27QhL80<SPf0001P38h=P202l_;`80;2`/1@0];Bd203Hf=P80<c<c
100^;Rh202`/;080;Bd]0`0X:2P2030`<080<C4a0P0/;2`203@d=080<C4a0P0g=cL302`/;080:b/[
0P0b<S8202`/;080:BTY0P1BDU8208^;R`<0YJFU0P1nOWh206UYJ@80IfMW0P1`L70208b<S080`<30
0P2b/[830:^[Z`80]KFe0P2l_;`20;jn_P80_Kfm0P32`/820<K6aPD0bLW90P2k^k/205UIF@80=SHf
0P0g=cL204E5A@<0DE5A0P1BDU82065QH@80Jf][0P1`L702075aL@80Kfm_0`1iNGT207inOP80NWYj
0P24Q8@408:2PP80RXZ:1@2;Rh/408f=S@80TY:B0P2GUiL209fMW@<0VYZJ0P2QXJ4209^KV`@0WinO
0P2RXZ850:VYZ@80Y:BT102UYJD20:ZZZP80[Jf]0P2YZJT30;6a/@@0[Jf]0P2/[:`20:^[Z`80[Jf]
0P2[Zj/30:b/[080[Jf]0P2[Zj/20:ZZZP80[:b/0P2][Jd20:RXZ080ZJVY0`2XZ:P40:VYZ@@0/;2`
0P2][Jd20:RXZ0<0[:b/0P2PX:0209bLW0@0VYZJ0P2EUID209BDU0<0SHf=0P28R8P408j>SP80UYJF
0P29RHT208^;R`<0RHV90P20P80208>3P`80PX:21021PH4207YjNP<0QXJ60P1jNWX207inOP80QhN7
2038h=P000H0b>3H0P0a<C4203@d=080<C4a0`0c<c<203Lg=`80=SHf0P0^;Rh202/[:`80<30`0P0/
;2`302PX:080;bl_0P0b<S8202l_;`80=CDe0P0c<c<202d];@<0;Rh^100a<C4402LW9`80>SXj0P1_
Kfl309JFUP80Vi^K0P1dM7@206a/K080JFUY0P22PX820:b/[080_[jn0`2PX:020;>c/`80^;Rh0P2o
_kl20<30`080_[jn0P34a<@30<?3``80alO70P3<c<`20;2`/080C4a<0P0i>CT204=3@`<0Bd];0P1G
EeL205mOG`80I6AT101`L70207IfMP<0O7al0P1jNWX207UiN@H0Ogmo0P2<S8`508^;R`80RXZ:102C
Ti<209JFUP80V9RH0`2GUiL209jNWP80WIfM102OWil20:NWY`80ZZZZ0`2YZJT20:6QX@80Xj>S0P2R
XZ820:ZZZP80[:b/0P2^[Zh30;Bd]080[:b/0P2[Zj/20:VYZ@80Xj>S0P2VYZH20:FUY@<0Z:RX0P2V
YZH20:VYZ@80[:b/102^[Zh20:f][@80[:b/1@2XZ:P20:ZZZP80YZJV0P2XZ:P20:b/[080Z:RX0`2Z
ZZX20:>SX`80XZ:R0P2PX:0209VIV@80U9BD0P2>SXh308Z:RP80R8R81P2=SHd208Z:RP80QHF50`23
Ph<208N7Q`80PX:20P21PH4208>3P`80Q8B40P1oOgl308F5Q@80P8200P1oOgl208V9R@P0b>3H0006
0<SPf080<C4a0P0d=3@2034a<@<0<c<c0P0g=cL203Hf=P80;Rh^0P0[:b/2030`<080;2`/0`0X:2P2
02l_;`80<S8b0P0_;bl203De=@80<c<c0P0];Bd302h^;P@0<C4a100W9bL203Xj>P80Kfm_0`2FUYH2
09^KV`80M7Ad0P1/K6`206UYJ@80PX:20P2/[:`20;jn_P<0X:2P0P2c/k<20;Rh^080_kno0P30`<02
0;jn_P80a<C40`33`l<20<O7a`80c<c<0P2`/;0204a<C080>CTi0P13@d<304];B`80EeMG0P1OGel2
06ATI0@0L71`0P1fMWH307alO080NWYj0P1iNGT607moO`80S8b<1@2;Rh/208Z:RP@0Ti>C0P2FUYH2
09RHV0<0UiNG0P2NWYh209fMW@@0WinO0P2WYjL20:ZZZP<0ZJVY0P2QXJ420:>SX`80XZ:R0P2ZZZX2
0:b/[080[Zj^0`2d];@20:b/[080Zj^[0P2YZJT20:>SX`80YZJV0P2UYJD30:RXZ080YZJV0P2YZJT2
0:b/[0@0[Zj^0P2][Jd20:b/[0D0Z:RX0P2ZZZX20:JVYP80Z:RX0P2/[:`20:RXZ0<0ZZZZ0P2SXj<2
0::RXP80X:2P0P2IVIT209BDU080SXj>0`2:RXX208R8R0H0SHf=0P2:RXX208F5Q@<0Ph>30P27QhL2
08:2PP80PH610P23Ph<208B4Q080Ogmo0`25QHD20820P080Ogmo0P29RHT80<SPf0001P38h=P203<c
<`@0<30`0`0c<c<203@d=080<C4a0P0V9RH402/[:`80;2`/0`0X:2P202`/;080<C4a0P0e=CD2034a
<@80=SHf0P0e=CD3038b<P80=3@d0P0e=CD202XZ:P80;Rh^0P0/;2`2051@D0<0PX:20P2SXj<207mo
O`80IfMW0P1UIFD206i^KP80SXj>0P2i^KT30:>SX`80/K6a0P2f][H20;bl_080^k^k0P2m_Kd20<30
`0<0`/;20P38b<P40<c<c080Y:BT0P10@40203lo?`<0AdM70P1ADE4205aLG080GemO0P1/K6`2071`
L080M7Ad0`1hN7P207]kN`80O7al0P23Ph<207emO@80QXJ60P2=SHd308V9R@80S8b<0P2>SXh209FE
U@80UYJF1`2HV9P209fMW@80WinO0P2PX:0209jNWP80Z:RX0P2YZJT30:NWY`80Xj>S0P2UYJD20::R
XP80ZZZZ102/[:`30;:b/P80Zj^[0P2YZJT20:RXZ080Xj>S0P2VYZH20:ZZZP<0Y:BT0P2WYjL20:RX
Z080[Zj^0P2a/K420;2`/080[Zj^0P2/[:`30:FUY@80ZJVY1P2VYZH40:NWY`<0YZJV0P2QXJ420:JV
YP80Vi^K0P2OWil209FEU@80SHf=0`28R8P208V9R@80Rh^;0P2>SXh209:BTP80T92@0P2:RXX308J6
QP80QhN70P25QHD208B4Q080QXJ60P1oOgl208:2PPD0PH610P24Q8@208R8R0P0b>3H00060<SPf080
<c<c100`<30303<c<`80=3@d0P0a<C4202HV9P@0:b/[0P0/;2`302PX:080;2`/0P0a<C4203De=@80
<C4a0P0f=SH203De=@<0<S8b0P0d=3@203De=@80:RXZ0P0^;Rh202`/;080D51@0`22PX820:>SX`80
Ogmo0P1WIfL206EUI@80KVi^0P2>SXh20;Vi^@<0Xj>S0P2a/K420;Jf]P80_;bl0P2k^k/20;fm_@80
`<300`32`/820<S8b0@0c<c<0P2TY:@20410@080?clo0`17AdL2055AD@80G5aL0P1OGel206a/K080
L71`0P1dM7@307QhN080Ng]k0P1lO7`208>3P`80OGem0P26QXH208f=S@<0RHV90P2<S8`208j>SP80
UIFE0P2FUYH709RHV080WIfM0P2OWil20:2PX080WYjN0P2XZ:P20:VYZ@<0YjNW0P2SXj<20:FUY@80
XZ:R0P2ZZZX40:b/[0<0/[:b0P2[Zj/20:VYZ@80Z:RX0P2SXj<20:JVYP80ZZZZ0`2TY:@20:NWY`80
Z:RX0P2^[Zh20;6a/@80/;2`0P2^[Zh20:b/[0<0YJFU0P2YZJT60:JVYP@0YjNW0`2VYZH20:6QX@80
YZJV0P2KVi/209nOW`80UIFE0P2=SHd308R8R080RHV90P2;Rh/208j>SP80TY:B0P2@T90208Z:RP<0
QXJ60P27QhL208F5Q@80Q8B40P26QXH207moO`80PX:21@21PH4208B4Q080R8R82038h=P000H0b>3H
0P0b<S8202/[:`80;bl_0`0b<S82030`<080;2`/0P0`<30202h^;P809bLW0P0`<30302h^;P80<C4a
0P0b<S8203lo?`T0<30`0P0c<c<202/[:`@0:RXZ0P0/;2`203Ph>0<0Jf][0P2BTY8209FEU@80Kfm_
0P1RHV8206ATI080MGEe0P2RXZ830;Fe]@80ZZZZ0P2b/[820;Fe]@80^[Zj102m_Kd30<K6aP80bLW9
0P3?cll20<k>cP80alO70P2:RXX50410@080CDe=0P1IFET2065QH@80JVYZ101aLG4307EeM@80MWIf
0P1gMgL207emO@80QHF50P26QXH208V9R@<0QHF50P2:RXX208f=S@80UiNG0P2DU9@209NGU`80UYJF
0`2LW9`20:6QX@80V9RH0P2QXJ420::RXP80Y:BT0P2WYjL30:BTY080YZJV0P2PX:020:BTY080YjNW
0P2ZZZX20:f][@<0[:b/102VYZH20:2PX080YJFU0P2WYjL20:FUY@<0Z:RX0P2SXj<20:NWY`80ZJVY
0P2[Zj/20:f][@@0ZJVY0`2a/K420:j^[P80ZJVY0P2TY:@20:JVYP80[:b/0P2`/;030:BTY080YZJV
0P2^[Zh20:FUY@80WYjN0P2CTi<208b<S0<0SXj>1028R8P2092@T080Shn?0P2>SXh208^;R`<0QXJ6
0P29RHT208J6QP@0PH610P23Ph<20861P@<0PX:20P20P80207moO`80Rh^;2038h=P000H0b>3H0P0b
<S8202/[:`80;bl_0`0b<S82030`<080;2`/0P0`<30202h^;P809bLW0P0`<30302h^;P80<C4a0P0b
<S8203lo?`T0<30`0P0c<c<202/[:`@0:RXZ0P0/;2`203Ph>0<0Jf][0P2BTY8209FEU@80Kfm_0P1R
HV8206ATI080MGEe0P2RXZ830;Fe]@80ZZZZ0P2b/[820;Fe]@80^[Zj102m_Kd30<K6aP80bLW90P3?
cll20<k>cP80alO70P2:RXX50410@080CDe=0P1IFET2065QH@80JVYZ101aLG4307EeM@80MWIf0P1g
MgL207emO@80QHF50P26QXH208V9R@<0QHF50P2:RXX208f=S@80UiNG0P2DU9@209NGU`80UYJF0`2L
W9`20:6QX@80V9RH0P2QXJ420::RXP80Y:BT0P2WYjL30:BTY080YZJV0P2PX:020:BTY080YjNW0P2Z
ZZX20:f][@<0[:b/102VYZH20:2PX080YJFU0P2WYjL20:FUY@<0Z:RX0P2SXj<20:NWY`80ZJVY0P2[
Zj/20:f][@@0ZJVY0`2a/K420:j^[P80ZJVY0P2TY:@20:JVYP80[:b/0P2`/;030:BTY080YZJV0P2^
[Zh20:FUY@80WYjN0P2CTi<208b<S0<0SXj>1028R8P2092@T080Shn?0P2>SXh208^;R`<0QXJ60P29
RHT208J6QP@0PH610P23Ph<20861P@<0PX:20P20P80207moO`80Rh^;2038h=P000H0b>3H100/;2`2
02d];@<0;bl_0P0];Bd202LW9`80;2`/0P0a<C4202PX:080:b/[0`0Y:BT2030`<080=SHf0P0g=cL2
02d];@80<c<c0P0b<S83034a<@@0<30`0P0V9RH202LW9`80:2PX0P0];Bd304M7A`80PX:20P2NWYh2
08B4Q080JFUY0P1UIFD206][J`80QhN70`2d];@20:f][@80/K6a0P2d];@20;Jf]P@0^k^k1@33`l<2
0<[:bP80clo?0P3=cLd20<71`@80PH610`0o?cl204E5A@80E5AD0P1PH60206IVIP80LG5a0P1`L703
06m_K`80LW9b0P1hN7P207moO`80QhN70P26QXH208N7Q`<0Ph>30P2>SXh208b<S080UYJF0P2DU9@2
09NGU`L0W9bL0P2KVi/209nOW`80Y:BT102QXJ430::RXP80Y:BT0P2NWYh20:JVYP@0XJ6Q0P2SXj<3
09nOW`80VYZJ0P2OWil209^KV`@0XZ:R0P2MWId309jNWP80WinO0P2VYZH20:BTY080Zj^[0P2ZZZX2
0:>SX`80YZJV0`2a/K420:b/[080[Zj^0P2UYJD20::RXP@0[:b/0`2PX:020::RXP80ZZZZ102TY:@2
09FEU@80S8b<0`2=SHd408F5Q@80R8R80P2:RXX208n?S`80SXj>1@28R8P408:2PP80OWin0P24Q8@5
07moO`80P8200P1mOGd208b<S0P0b>3H00060<SPf0@0;2`/0P0];Bd302l_;`80;Bd]0P0W9bL202`/
;080<C4a0P0X:2P202/[:`<0:BTY0P0`<30203Hf=P80=cLg0P0];Bd203<c<`80<S8b0`0a<C44030`
<0809RHV0P0W9bL202PX:080;Bd]0`17AdL208:2PP80WYjN0P24Q8@206UYJ@80IFEU0P1[Jf/208N7
Q`<0];Bd0P2][Jd20;6a/@80];Bd0P2f][H40;^k^`D0`l?30P3:b/X20<o?c`80cLg=0P31`L420861
P@<0?clo0P15ADD205ADE080H61P0P1VIVH2075aL@80L71`0`1_Kfl2079bLP80N7Qh0P1oOgl208N7
Q`80QXJ60P27QhL308>3P`80SXj>0P2<S8`209JFUP80U9BD0P2GUiL709bLW080Vi^K0P2OWil20:BT
Y0@0XJ6Q0`2RXZ820:BTY080WYjN0P2VYZH40:6QX@80Xj>S0`2OWil209ZJVP80WinO0P2KVi/40::R
XP80WIfM0`2NWYh209nOW`80YZJV0P2TY:@20:^[Z`80ZZZZ0P2SXj<20:JVYP<0/K6a0P2/[:`20:j^
[P80YJFU0P2RXZ840:b/[0<0X:2P0P2RXZ820:ZZZP@0Y:BT0P2EUID208b<S0<0SHf=1025QHD208R8
R080RXZ:0P2?Shl208j>SPD0R8R81022PX8207inOP80Q8B41@1oOgl20820P080OGem0P2<S8`80<SP
f0001P38h=P2030`<080;Bd]0P0Y:BT302`/;0@0;Rh^0P0];Bd202`/;080:b/[0P0_;bl302TY:@80
=3@d0P0e=CD402l_;`80<S8b0P0Z:RX302l_;`80<S8b0P0Y:BT202DU9@808B4Q0P0U9BD202<S8`<0
<30`0P1VIVH208n?S`80WinO0P1lO7`206ATI080J6QX0P1kNg/30:BTY080^k^k0P2/[:`20;Jf]P80
/K6a0P2c/k<20;Ng]`<0^[Zj0P30`<020<K6aP80bl_;0P3<c<`20<k>cP80^k^k0`1`L70203`l?080
CTi>0P1EEED205iNGP80IFEU0P1^KVh3071`L080MWIf0P1hN7P207UiN@80PX:21027QhL308J6QP80
SHf=0P2>SXh209RHV080UYJF0P2IVIT209NGU`<0VYZJ102GUiL209ZJVP80Vi^K0P2PX:020:>SX`<0
WYjN0P2SXj<209nOW`80X:2P0P2LW9`409ZJVP<0UiNG0P2DU9@409JFUP80V9RH0P2KVi/209JFUP<0
VIVI0P2NWYh209^KV`@0W9bL0P2UYJD20:2PX080XZ:R0`2TY:@20:FUY@80YjNW0P2ZZZX20:FUY@80
YjNW0P2UYJD30::RXP80WinO0P2VYZH20:>SX`80YjNW0P2LW9`208j>SP<0Rh^;0P22PX8207moO`80
Q8B40P26QXH208^;R`80S8b<0`27QhL208V9R@80P8200P1nOWh20820P080Q8B41@22PX8208>3P`80
QhN70P2=SHd80<SPf0001P38h=P2030`<080;Bd]0P0Y:BT302`/;0@0;Rh^0P0];Bd202`/;080:b/[
0P0_;bl302TY:@80=3@d0P0e=CD402l_;`80<S8b0P0Z:RX302l_;`80<S8b0P0Y:BT202DU9@808B4Q
0P0U9BD202<S8`<0<30`0P1VIVH208n?S`80WinO0P1lO7`206ATI080J6QX0P1kNg/30:BTY080^k^k
0P2/[:`20;Jf]P80/K6a0P2c/k<20;Ng]`<0^[Zj0P30`<020<K6aP80bl_;0P3<c<`20<k>cP80^k^k
0`1`L70203`l?080CTi>0P1EEED205iNGP80IFEU0P1^KVh3071`L080MWIf0P1hN7P207UiN@80PX:2
1027QhL308J6QP80SHf=0P2>SXh209RHV080UYJF0P2IVIT209NGU`<0VYZJ102GUiL209ZJVP80Vi^K
0P2PX:020:>SX`<0WYjN0P2SXj<209nOW`80X:2P0P2LW9`409ZJVP<0UiNG0P2DU9@409JFUP80V9RH
0P2KVi/209JFUP<0VIVI0P2NWYh209^KV`@0W9bL0P2UYJD20:2PX080XZ:R0`2TY:@20:FUY@80YjNW
0P2ZZZX20:FUY@80YjNW0P2UYJD30::RXP80WinO0P2VYZH20:>SX`80YjNW0P2LW9`208j>SP<0Rh^;
0P22PX8207moO`80Q8B40P26QXH208^;R`80S8b<0`27QhL208V9R@80P8200P1nOWh20820P080Q8B4
1@22PX8208>3P`80QhN70P2=SHd80<SPf0001P38h=P202/[:`80;bl_0P0/;2`302l_;`80<S8b0P0a
<C4203<c<`80;2`/0P0W9bL202h^;P<0<C4a0P0h>3P203Hf=P80<c<c0P0`<30202l_;`D0;Bd]0P0/
;2`202LW9`808b<S0P0T92@202DU9@808b<S0`0T92@203lo?`80NGUi0P2LW9`208n?S`80Lg=c0P1[
Jf/206m_K`<0UYJF0P31`L420;:b/P80Zj^[0P2VYZH20:ZZZP80/K6a0`2e]KD20;bl_080_kno0P38
b<P20<c<c080clo?0P3<c<`30;Jf]P80H61P0P17AdL2055AD@80G5aL0P1OGel206MWI`<0KVi^0P1b
LW8207]kN`80NWYj0P1lO7`208>3P`80Rh^;0`28R8P2092@T080TY:B0P2DU9@209VIV@@0VYZJ0`2H
V9P209NGU`80Ti>C0P2FUYH209jNWP80U9BD1@2KVi/209nOW`80VYZJ0P2MWId209ZJVP80UIFE0P2G
UiL3096AT@80SXj>0P2BTY82096AT@80Ti>C0P2?Shl5092@T080Ti>C102BTY8209RHV080UYJF0P2L
W9`209fMW@<0X:2P0P2QXJ440:RXZ080YjNW0P2SXj<50:BTY080W9bL0P2QXJ420:>SX`80YjNW0P2P
X:0209:BTP<0QXJ60P23Ph<208F5Q@@0Q8B40P26QXH208Z:RP<0Rh^;0P27QhL208B4Q080Ogmo0P21
PH4207alO080Ph>30`1lO7`20861P@80Q8B40P2>SXh80<SPf0001P38h=P202/[:`80;bl_0P0/;2`3
02l_;`80<S8b0P0a<C4203<c<`80;2`/0P0W9bL202h^;P<0<C4a0P0h>3P203Hf=P80<c<c0P0`<302
02l_;`D0;Bd]0P0/;2`202LW9`808b<S0P0T92@202DU9@808b<S0`0T92@203lo?`80NGUi0P2LW9`2
08n?S`80Lg=c0P1[Jf/206m_K`<0UYJF0P31`L420;:b/P80Zj^[0P2VYZH20:ZZZP80/K6a0`2e]KD2
0;bl_080_kno0P38b<P20<c<c080clo?0P3<c<`30;Jf]P80H61P0P17AdL2055AD@80G5aL0P1OGel2
06MWI`<0KVi^0P1bLW8207]kN`80NWYj0P1lO7`208>3P`80Rh^;0`28R8P2092@T080TY:B0P2DU9@2
09VIV@@0VYZJ0`2HV9P209NGU`80Ti>C0P2FUYH209jNWP80U9BD1@2KVi/209nOW`80VYZJ0P2MWId2
09ZJVP80UIFE0P2GUiL3096AT@80SXj>0P2BTY82096AT@80Ti>C0P2?Shl5092@T080Ti>C102BTY82
09RHV080UYJF0P2LW9`209fMW@<0X:2P0P2QXJ440:RXZ080YjNW0P2SXj<50:BTY080W9bL0P2QXJ42
0:>SX`80YjNW0P2PX:0209:BTP<0QXJ60P23Ph<208F5Q@@0Q8B40P26QXH208Z:RP<0Rh^;0P27QhL2
08B4Q080Ogmo0P21PH4207alO080Ph>30`1lO7`20861P@80Q8B40P2>SXh80<SPf0001P38h=P202LW
9`80:b/[0P0d=3@302h^;P80;Bd]0P0[:b/202h^;P80;bl_0P0`<30202d];@<0;Rh^0P0f=SH202`/
;080;Rh^0P0_;bl202/[:`80;bl_0`0Z:RX2030`<0809bLW0P0X:2P202/[:`809RHV0P0Q8B43028R
8P80:2PX0P1PH60208F5Q@80XJ6Q0P22PX8206][J`80IfMW0`1nOWh20:VYZ@80`<300P2XZ:P20:6Q
X@80Zj^[0P2b/[830;Jf]P80]kNg0P2e]KD20<71`@80alO70P39bLT50<[:bP80ZJVY0P1OGel204Y:
BP80EUIF0P1MGEd206=SH`<0KFe]101eMGD207emO@80Ogmo0P23Ph<208Z:RP<0R8R80P2=SHd209>C
T`@0U9BD0P2EUID209^KV`<0VIVI102JVYX209JFUP80V9RH0P2FUYH209BDU0<0UiNG0P2IVIT209FE
U@80U9BD0P2CTi<2092@T080UIFE0`2@T90208^;R`80U9BD0P2BTY8208n?S`80T92@0P2=SHd308j>
SP80T92@0P2>SXh208n?S`80SXj>0P2FUYH209NGU`80UYJF0`2GUiL209ZJVP80Vi^K0P2MWId20:6Q
X@80Xj>S0P2UYJD30:BTY080VYZJ0P2MWId20:6QX@80Xj>S0P2QXJ4209RHV0<0Rh^;1P21PH4208R8
R080Q8B40P2:RXX308R8R080QXJ60P27QhL20861P@80Ph>30P1nOWh208:2PP<0Ogmo0P22PX8208>3
P`80S8b<2038h=P000H0b>3H0P0W9bL202/[:`80=3@d0`0^;Rh202d];@80:b/[0P0^;Rh202l_;`80
<30`0P0];Bd302h^;P80=SHf0P0/;2`202h^;P80;bl_0P0[:b/202l_;`<0:RXZ0P0`<30202LW9`80
:2PX0P0[:b/202HV9P808B4Q0`0R8R8202PX:080H61P0P25QHD20:6QX@80PX:20P1[Jf/206MWI`<0
OWin0P2YZJT20<30`080Z:RX0P2QXJ420:^[Z`80/[:b0`2f][H20;Ng]`80]KFe0P31`L420<O7a`80
bLW91@3:b/X20:VYZ@80GemO0P1:BTX205IFEP80GEeM0P1SHf<306e]K@@0MGEe0P1mOGd207moO`80
Ph>30P2:RXX308R8R080SHf=0P2CTi<409BDU080UIFE0P2KVi/309VIV@@0VYZJ0P2FUYH209RHV080
UYJF0P2DU9@309NGU`80VIVI0P2EUID209BDU080Ti>C0P2@T90209FEU@<0T92@0P2;Rh/209BDU080
TY:B0P2?Shl2092@T080SHf=0`2>SXh2092@T080SXj>0P2?Shl208j>SP80UYJF0P2GUiL209JFUP<0
UiNG0P2JVYX209^KV`80WIfM0P2QXJ420:>SX`80YJFU0`2TY:@209ZJVP80WIfM0P2QXJ420:>SX`80
XJ6Q0P2HV9P308^;R`H0PH610P28R8P208B4Q080RXZ:0`28R8P208J6QP80QhN70P21PH4208>3P`80
OWin0P22PX8307moO`80PX:20P23Ph<208b<S0P0b>3H00060<SPf0809bLW0P0[:b/203@d=0<0;Rh^
0P0];Bd202/[:`80;Rh^0P0_;bl2030`<080;Bd]0`0^;Rh203Hf=P80;2`/0P0^;Rh202l_;`80:b/[
0P0_;bl302XZ:P80<30`0P0W9bL202PX:080:b/[0P0V9RH2024Q8@<08R8R0P0X:2P2061PH080QHF5
0P2QXJ4208:2PP80Jf][0P1WIfL307inOP80ZJVY0P30`<020:RXZ080XJ6Q0P2[Zj/20;:b/P<0][Jf
0P2g]kL20;Fe]@80`L710P37alL20<W9b@D0b/[:0P2YZJT205mOG`80BTY:0P1FEUH205eMG@80Hf=S
0`1]KFd407EeM@80OGem0P1oOgl208>3P`80RXZ:0`28R8P208f=S@80Ti>C102DU9@209FEU@80Vi^K
0`2IVIT409ZJVP80UYJF0P2HV9P209JFUP80U9BD0`2GUiL209VIV@80UIFE0P2DU9@209>CT`80T92@
0P2EUID3092@T080Rh^;0P2DU9@209:BTP80Shn?0P2@T90208f=S@<0SXj>0P2@T90208j>SP80Shn?
0P2>SXh209JFUP80UiNG0P2FUYH309NGU`80VYZJ0P2KVi/209fMW@80XJ6Q0P2SXj<20:FUY@<0Y:BT
0P2JVYX209fMW@80XJ6Q0P2SXj<20:6QX@80V9RH0`2;Rh/60861P@80R8R80P24Q8@208Z:RP<0R8R8
0P26QXH208N7Q`80PH610P23Ph<207inOP80PX:20`1oOgl208:2PP80Ph>30P2<S8`80<SPf0001P38
h=P203@d=080:RXZ0P0/;2`503@d=080<S8b0P0a<C4202h^;P80:2PX0P0^;Rh303Lg=`@0<c<c0P0^
;Rh203@d=080=cLg0P0d=3@302`/;0@0<30`0P0W9bL201hN7P808B4Q1@0P820202<S8`80?3`l0P1f
MWH209VIV@80Vi^K0P1^KVh206=SH`<0L71`0P2<S8`20;Vi^@80ZZZZ0P2OWil20:NWY`80/;2`1@2c
/k<20;2`/080^k^k0P32`/820<[:bP80bLW90`3;bl/20<S8b080XZ:R0P1MGEd204m?C`80De=C0P1L
G5`306=SH`80LG5a0P1fMWH207UiN@80Q8B40P23Ph<208J6QP<0QhN70P2;Rh/208b<S080Shn?0P2C
Ti<209:BTP80UiNG0`2JVYX209:BTP80UYJF0P2BTY8209NGU`80VIVI0P2ATI4309>CT`80TI6A0P2;
Rh/208n?S`80TI6A0P2DU9@509FEU@80S8b<0P2:RXX209BDU080T92@0P2=SHd208V9R@<0R8R80P29
RHT208^;R`@0SHf=0P2DU9@2096AT@80S8b<1@2EUID209^KV`80VIVI102OWil20:BTY0<0WYjN0P2J
VYX209BDU080UYJF0P2IVIT409bLW0<0SHf=0P23Ph<207YjNP80Ng]k0P21PH4208B4Q080QXJ60`29
RHT208J6QP80PX:20P25QHD20861P@@0Ogmo0`1mOGd208>3P`80QHF50P2@T9080<SPf0001P38h=P2
03@d=080:RXZ0P0/;2`503@d=080<S8b0P0a<C4202h^;P80:2PX0P0^;Rh303Lg=`@0<c<c0P0^;Rh2
03@d=080=cLg0P0d=3@302`/;0@0<30`0P0W9bL201hN7P808B4Q1@0P820202<S8`80?3`l0P1fMWH2
09VIV@80Vi^K0P1^KVh206=SH`<0L71`0P2<S8`20;Vi^@80ZZZZ0P2OWil20:NWY`80/;2`1@2c/k<2
0;2`/080^k^k0P32`/820<[:bP80bLW90`3;bl/20<S8b080XZ:R0P1MGEd204m?C`80De=C0P1LG5`3
06=SH`80LG5a0P1fMWH207UiN@80Q8B40P23Ph<208J6QP<0QhN70P2;Rh/208b<S080Shn?0P2CTi<2
09:BTP80UiNG0`2JVYX209:BTP80UYJF0P2BTY8209NGU`80VIVI0P2ATI4309>CT`80TI6A0P2;Rh/2
08n?S`80TI6A0P2DU9@509FEU@80S8b<0P2:RXX209BDU080T92@0P2=SHd208V9R@<0R8R80P29RHT2
08^;R`@0SHf=0P2DU9@2096AT@80S8b<1@2EUID209^KV`80VIVI102OWil20:BTY0<0WYjN0P2JVYX2
09BDU080UYJF0P2IVIT409bLW0<0SHf=0P23Ph<207YjNP80Ng]k0P21PH4208B4Q080QXJ60`29RHT2
08J6QP80PX:20P25QHD20861P@@0Ogmo0`1mOGd208>3P`80QHF50P2@T9080<SPf0001P38h=P202d]
;@80:RXZ0P0/;2`3034a<@80;bl_0P0d=3@203<c<`80:BTY0P0^;Rh203<c<`<0<30`0P0^;Rh202l_
;`80;2`/0P0_;bl203@d=080=CDe0`0b<S8203Hf=P80;Bd]0P0V9RH202LW9`809RHV0P0L71`301hN
7P808b<S0P0V9RH205UIF@80QhN70P2QXJ420820P080Hf=S0`1VIVH207=cL`80Z:RX0P2h^;P40:>S
X`80Z:RX0`2c/k<20:f][@80/[:b0P2e]KD20;fm_@80aLG50P38b<P30<_;b`80a/K60P34a<@209jN
WP80FEUI101ADE43061PH080Jf][0P1^KVh207]kN`80P8200P1nOWh208>3P`<0QHF50P27QhL208j>
SP80TY:B0P2EUID408f=S@D0T92@0P2FUYH209BDU080UiNG0P2BTY8209BDU0<0Rh^;0P2?Shl208b<
S080Shn?0P2CTi<209JFUP80UiNG0`2@T90208B4Q080Ph>30P2<S8`208V9R@80PX:20P1lO7`307in
OP80Q8B40P1oOgl408R8R0@0QHF50P1gMgL308b<S080UIFE0P2>SXh2092@T080X:2P102IVIT709JF
UP@0TI6A0P2FUYH209FEU@<0Shn?0P23Ph<207MgM`80NWYj0P20P8020861P@80R8R80`24Q8@208F5
Q@80OWin1023Ph<20820P080OGem0`20P80208J6QP80RHV90P2ATI480<SPf0001P38h=P202d];@80
:RXZ0P0/;2`3034a<@80;bl_0P0d=3@203<c<`80:BTY0P0^;Rh203<c<`<0<30`0P0^;Rh202l_;`80
;2`/0P0_;bl203@d=080=CDe0`0b<S8203Hf=P80;Bd]0P0V9RH202LW9`809RHV0P0L71`301hN7P80
8b<S0P0V9RH205UIF@80QhN70P2QXJ420820P080Hf=S0`1VIVH207=cL`80Z:RX0P2h^;P40:>SX`80
Z:RX0`2c/k<20:f][@80/[:b0P2e]KD20;fm_@80aLG50P38b<P30<_;b`80a/K60P34a<@209jNWP80
FEUI101ADE43061PH080Jf][0P1^KVh207]kN`80P8200P1nOWh208>3P`<0QHF50P27QhL208j>SP80
TY:B0P2EUID408f=S@D0T92@0P2FUYH209BDU080UiNG0P2BTY8209BDU0<0Rh^;0P2?Shl208b<S080
Shn?0P2CTi<209JFUP80UiNG0`2@T90208B4Q080Ph>30P2<S8`208V9R@80PX:20P1lO7`307inOP80
Q8B40P1oOgl408R8R0@0QHF50P1gMgL308b<S080UIFE0P2>SXh2092@T080X:2P102IVIT709JFUP@0
TI6A0P2FUYH209FEU@<0Shn?0P23Ph<207MgM`80NWYj0P20P8020861P@80R8R80`24Q8@208F5Q@80
OWin1023Ph<20820P080OGem0`20P80208J6QP80RHV90P2ATI480<SPf0001P38h=P202h^;P80<C4a
0P0c<c<304A4A0@0:BTY0P0[:b/402l_;`80;Rh^0`0];Bd202h^;P80:RXZ100/;2`2030`<080<S8b
0`0f=SH203@d=080;Bd]0P0X:2P202DU9@809RHV0P0S8b<5028R8P808b<S0P0b<S8206][J`80SHf=
0P2EUID206i^KP<0HV9R0P1YJFT2092@T080^k^k0P2g]kL20::RXP80XJ6Q0`2`/;020:f][@80][Jf
0P2h^;P20;bl_0@0a<C40`3;bl/20<W9b@@0aLG50P2JVYX205UIF@80DE5A0`1OGel206IVIP80KVi^
0P1fMWH207alO080PH610P22PX8308V9R@80QHF50P2<S8`208f=S@80Ti>C0P25QHD208f=S@<0Rh^;
0P2ATI4209BDU080Ti>C0P2BTY8208j>SP80TY:B0`2=SHd2096AT@@0T92@0P2FUYH209FEU@80U9BD
0`2>SXh208>3P`80MgMg1021PH4207]kN`80LG5a0`1^KVh208J6QP80Ogmo0P28R8P208Z:RP80Shn?
0P1kNg/206a/K0<0QXJ60P2:RXX20861P@80QXJ60P2VYZH409:BTP<0UiNG0P2IVIT209NGU`80VIVI
0P2BTY8408j>SP<0Q8B40P1oOgl207EeM@80NGUi0P1oOgl408>3P`D0Q8B40P1oOgl20861P@80Ph>3
0P1nOWh207moO`<0PX:20P28R8P208Z:RP80TI6A2038h=P000H0b>3H0P0^;Rh2034a<@80<c<c0`14
A4@402TY:@80:b/[100_;bl202h^;P<0;Bd]0P0^;Rh202XZ:P@0;2`/0P0`<302038b<P<0=SHf0P0d
=3@202d];@80:2PX0P0U9BD202HV9P808b<S1@0R8R8202<S8`80<S8b0P1[Jf/208f=S@80UIFE0P1^
KVh3069RHP80JFUY0P2@T9020;^k^`80]kNg0P2RXZ820:6QX@<0/;2`0P2][Jd20;Jf]P80^;Rh0P2l
_;`40<C4a0<0bl_;0P39bLT40<G5a@80VYZJ0P1IFET2055AD@<0GemO0P1VIVH206i^KP80MWIf0P1l
O7`20861P@80PX:20`29RHT208F5Q@80S8b<0P2=SHd209>CT`80QHF50P2=SHd308^;R`80TI6A0P2D
U9@209>CT`80TY:B0P2>SXh209:BTP<0SHf=0P2ATI44092@T080UYJF0P2EUID209BDU0<0SXj>0P23
Ph<207MgM`@0PH610P1kNg/2075aL@<0KVi^0P26QXH207moO`80R8R80P2:RXX208n?S`80Ng]k0P1/
K6`308J6QP80RXZ:0P21PH4208J6QP80YZJV102BTY8309NGU`80VIVI0P2GUiL209VIV@80TY:B102>
SXh308B4Q080Ogmo0P1eMGD207UiN@80Ogmo1023Ph<508B4Q080Ogmo0P21PH4208>3P`80OWin0P1o
Ogl308:2PP80R8R80P2:RXX2096AT@P0b>3H00060<SPf080:2PX0P0[:b/202d];@<09RHV0P0];Bd2
02TY:@80;Bd]100/;2`2030`<0D0=3@d0P0[:b/202XZ:P80;bl_0P0i>CT203Ph>0<0;bl_0P0`<302
02`/;0808b<S0P0W9bL202HV9PD08b<S0P0R8R82024Q8@809RHV0P16ATH207alO080VIVI0P20P803
069RHP80G5aL0P1oOgl20;>c/`80`l?30P2][Jd209nOW`<0ZJVY0P2ZZZX40;>c/`80^;Rh0P31`L42
0<;2`P<0b<S80P3:b/X20<G5a@80alO70P31`L4209JFUP80FEUI0`1CDe<206UYJ@80K6a/0P1dM7@4
07inOP80Ph>30`28R8P208F5Q@80RXZ:102=SHd208Z:RPD0SXj>0P2@T90408n?S`80TI6A0P2>SXh2
08b<S0<0TI6A0P2EUID208n?S`80S8b<0P2@T90208f=S@80SXj>0`25QHD20861P@80KFe]0P1gMgL2
0820P080NWYj0P1^KVh305aLG0@0P8200P29RHT208J6QP80Rh^;0P1aLG4206i^KP<0P8200P1kNg/2
06IVIP80OGem0P2VYZH209RHV080Ti>C0`2LW9`20:FUY@80XZ:R0P2SXj<209VIV@80UiNG0P2:RXX3
08>3P`80OWin0P1jNWX207MgM`80NWYj0P1lO7`208:2PPD0Q8B40P1mOGd208>3P`80P8200P21PH42
0820P0<0OWin0P2:RXX209BDU080UIFE2038h=P000H0b>3H0P0X:2P202/[:`80;Bd]0`0V9RH202d]
;@80:BTY0P0];Bd402`/;080<30`1@0d=3@202/[:`80:RXZ0P0_;bl203Ti>@80>3Ph0`0_;bl2030`
<080;2`/0P0S8b<202LW9`809RHV1@0S8b<2028R8P808B4Q0P0V9RH204I6AP80O7al0P2IVIT20820
P0<0HV9R0P1LG5`207moO`80/k>c0P33`l<20:f][@80WinO0`2YZJT20:ZZZP@0/k>c0P2h^;P20<71
`@80`/;20`38b<P20<[:bP80aLG50P37alL20<71`@80UYJF0P1IFET305=CD`80JFUY0P1/K6`207Ad
M0@0OWin0P23Ph<308R8R080QHF50P2:RXX408f=S@80RXZ:1@2>SXh2092@T0@0Shn?0P2ATI4208j>
SP80S8b<0`2ATI4209FEU@80Shn?0P2<S8`2092@T080SHf=0P2>SXh308F5Q@80PH610P1]KFd207Mg
M`80P8200P1jNWX206i^KP<0G5aL1020P80208V9R@80QXJ60P2;Rh/2075aL@80KVi^0`20P80207]k
N`80IVIV0P1mOGd20:JVYP80V9RH0P2CTi<309bLW080YJFU0P2RXZ820:>SX`80VIVI0P2GUiL208Z:
RP<0Ph>30P1nOWh207YjNP80MgMg0P1jNWX207alO080PX:21@24Q8@207emO@80Ph>30P20P8020861
P@80P8200`1nOWh208Z:RP80U9BD0P2EUID80<SPf0001P38h=P202`/;0809RHV0P0Z:RX302d];@80
;Rh^0P0[:b/2030`<080;bl_0P0[:b/202d];@<0;Rh^0P0a<C4202l_;`@0<30`0P0c<c<2038b<P<0
>CTi0P0c<c<202h^;P80:b/[0P0a<C4202@T90809RHV0`0R8R8202<S8`@0820P0P0Z:RX205iNGP80
RHV90P2LW9`306m_K`80FEUI0P1WIfL209bLW080`<300P32`/820::RXP<0Y:BT0P2XZ:P20:n_[`80
/;2`0P2k^k/20;fm_@80`/;20`38b<P20<k>cP80a/K60P35aLD20<K6aP80`/;20P2FUYH5061PH080
JFUY0P1^KVh207IfMP80N7Qh0P1oOgl308F5Q@80Ph>30P26QXH208^;R`80Q8B40P27QhL508V9R@80
Shn?0P2=SHd209:BTP80TI6A0P2@T90208n?S`D0TY:B0P29RHT208J6QP80Q8B40P28R8P208Z:RP<0
Ph>30P1jNWX206e]K@80J6QX0P1gMgL207emO@80I6AT0`1IFET207IfMP80PH610P22PX8208B4Q080
Ogmo0P1YJFT206YZJP<0P8200P1cLg<206EUI@80Ogmo0P2OWil20:>SX`80Z:RX0`2WYjL20;>c/`@0
[jn_0P2XZ:P209jNWP80T92@0`28R8P207emO@80MgMg0P1mOGd207QhN080OWin0P1lO7`50861P@80
PX:20P23Ph<208B4Q080QhN70P22PX830861P@80RXZ:0P2?Shl209JFUPP0b>3H00060<SPf080;2`/
0P0V9RH202XZ:P<0;Bd]0P0^;Rh202/[:`80<30`0P0_;bl202/[:`80;Bd]0`0^;Rh2034a<@80;bl_
100`<30203<c<`80<S8b0`0i>CT203<c<`80;Rh^0P0[:b/2034a<@8092@T0P0V9RH3028R8P808b<S
100P820202XZ:P80GUiN0P29RHT209bLW0<0Kfm_0P1IFET206MWI`80W9bL0P30`<020<;2`P80XZ:R
0`2TY:@20:RXZ080[jn_0P2`/;020;^k^`80_Kfm0P32`/830<S8b080c/k>0P36a/H20<G5a@80a/K6
0P32`/8209JFUPD0H61P0P1YJFT206i^KP80MWIf0P1hN7P207moO`<0QHF50P23Ph<208J6QP80Rh^;
0P24Q8@208N7Q`D0RHV90P2?Shl208f=S@80TY:B0P2ATI42092@T080Shn?1@2BTY8208V9R@80QXJ6
0P24Q8@208R8R080RXZ:0`23Ph<207YjNP80KFe]0P1XJ6P207MgM`80OGem0P1TI6@305UIF@80MWIf
0P21PH4208:2PP80Q8B40P1oOgl206UYJ@80JVYZ0`20P80207=cL`80IFEU0P1oOgl209nOW`80Xj>S
0P2XZ:P30:NWY`80/k>c102_[jl20:RXZ080WYjN0P2@T90308R8R080OGem0P1gMgL207emO@80N7Qh
0P1nOWh207alO0D0PH610P22PX8208>3P`80Q8B40P27QhL208:2PP<0PH610P2:RXX208n?S`80UYJF
2038h=P000H0b>3H0P0`<30202XZ:P808b<S0`0Y:BT202XZ:P80;bl_0P0/;2`203Hf=P80;Bd]0P0^
;Rh302l_;`@0<30`0P0[:b/202XZ:P80:b/[0P0b<S8302`/;080>SXj0P0];Bd203Ti>@80:2PX0P0T
92@202DU9@<092@T0P0U9BD202<S8`@08R8R0P0i>CT207MgM`80W9bL0`27QhL205mOG`80HF5Q0P21
PH420;Ng]`80b/[:0P2i^KT30:JVYP80YjNW0P2ZZZX20;6a/@80][Jf0P2j^[X20;jn_P<0`l?30P3:
b/X20<_;b`80bLW91032`/820;no_`<0RXZ:0P1NGUh205mOG`80J6QX0P1eMGD207MgM`80PH610`22
PX8207alO080PX:20P2:RXX20861P@80QhN70P22PX8308F5Q@80TY:B0P2>SXh408n?S`80SHf=1@2?
Shl208f=S@80QXJ60P1hN7P207IfMP80OGem0P1nOWh307moO`80OWin0P1/K6`206e]K@80Jf][0P1l
O7`206m_K`<0H61P0P1jNWX208F5Q@80R8R80P2BTY8209JFUP80TI6A0P2CTi<30:NWY`80X:2P0P2=
SHd209nOW`80XZ:R0P2TY:@20:n_[`D0[:b/0P2[Zj/20:j^[P80[Jf]0P2OWil209BDU0<0S8b<0P23
Ph<207inOP80P8200P1lO7`207moO`80M7Ad0`1kNg/208:2PP80Ng]k0P1nOWh20820P0@0Ph>30`26
QXH208f=S@80TY:B0P2EUID80<SPf0001P38h=P2030`<080:RXZ0P0S8b<302TY:@80:RXZ0P0_;bl2
02`/;080=SHf0P0];Bd202h^;P<0;bl_100`<30202/[:`80:RXZ0P0[:b/2038b<P<0;2`/0P0j>SX2
02d];@80>CTi0P0X:2P202@T90809BDU0`0T92@202DU9@808b<S100R8R8203Ti>@80MgMg0P2LW9`3
08N7Q`80GemO0P1QHF420861P@80]kNg0P3:b/X20;Vi^@<0YZJV0P2WYjL20:ZZZP80/K6a0P2f][H2
0;Zj^P80_[jn0`33`l<20<[:bP80bl_;0P39bLT40<;2`P80_kno0`2:RXX205iNGP80GemO0P1XJ6P2
07EeM@80MgMg0P21PH4308:2PP80O7al0P22PX8208Z:RP80PH610P27QhL208:2PP<0QHF50P2BTY82
08j>SP@0Shn?0P2=SHd508n?S`80SHf=0P26QXH207QhN080MWIf0P1mOGd207inOP<0Ogmo0P1nOWh2
06a/K080KFe]0P1[Jf/207alO080Kfm_0`1PH60207YjNP80QHF50P28R8P209:BTP80UYJF0P2ATI42
09>CT`<0YjNW0P2PX:0208f=S@80WinO0P2RXZ820:BTY080[jn_1@2/[:`20:^[Z`80[Zj^0P2][Jd2
09nOW`80U9BD0`2<S8`208>3P`80OWin0P20P80207alO080Ogmo0P1dM7@307]kN`80PX:20P1kNg/2
07inOP80P8201023Ph<308J6QP80SHf=0P2BTY8209FEU@P0b>3H00060<SPf080:2PX0P0T92@202DU
9@<0:b/[0P0U9BD202`/;080;bl_0P0d=3@2038b<P80<C4a0`0`<302034a<@80>3Ph0P0b<S8202h^
;P80>CTi0P0`<303034a<@80;bl_0P0Z:RX203Ph>080;bl_0P0W9bL202HV9P<0;Bd]0P0R8R82024Q
8@807alO0P0S8b<202`/;080DU9B0P24Q8@309nOW`80KFe]0P1FEUH206a/K080Vi^K0P32`/820<_;
b`<0[jn_0P2SXj<20:NWY`80[:b/0P2f][H20;Vi^@80_;bl0`2n_[h20<S8b080bLW90P3:b/X20<K6
aP80a<C40P35aLD30;jn_P80U9BD0P1RHV8205aLG080K6a/0P1hN7P207]kN`<0O7al0P1kNg/20861
P@80QXJ60P1nOWh20861P@80OGem0`24Q8@409>CT`80TI6A0P2@T90208n?S`80SHf=0`27QhL208R8
R080PH610P1`L70206e]K@80LW9b0P1YJFT306a/K080N7Qh0P1bLW8206m_K`80M7Ad1025QHD308n?
S`80UiNG0P2KVi/209NGU`80WYjN0P2YZJT20:NWY`80[:b/1@2b/[820:ZZZP80/K6a0P2d];@20;^k
^`80_Kfm0`2a/K420:2PX080Vi^K0P2GUiL209BDU0@0R8R80`29RHT208B4Q080Ph>30P1nOWh207Ui
N@80MgMg0P1iNGT307=cL`80N7Qh0P20P80208>3P`80PH610P20P80207UiN@<0PX:20P2=SHd209BD
U080UiNG2038h=P000H0b>3H0P0X:2P202@T90809BDU0`0[:b/202DU9@80;2`/0P0_;bl203@d=080
<S8b0P0a<C43030`<080<C4a0P0h>3P2038b<P80;Rh^0P0i>CT2030`<0<0<C4a0P0_;bl202XZ:P80
>3Ph0P0_;bl202LW9`809RHV0`0];Bd2028R8P808B4Q0P0O7al202<S8`80;2`/0P1BDU8208B4Q0<0
WinO0P1]KFd205IFEP80K6a/0P2KVi/20<;2`P80bl_;0`2_[jl20:>SX`80YjNW0P2/[:`20;Jf]P80
^KVi0P2l_;`30;jn_P80b<S80P39bLT20<[:bP80a/K60P34a<@20<G5a@<0_[jn0P2DU9@2069RHP80
G5aL0P1/K6`207QhN080Ng]k0`1lO7`207]kN`80PH610P26QXH207inOP80PH610P1mOGd308B4Q0@0
Ti>C0P2ATI42092@T080Shn?0P2=SHd308N7Q`80R8R80P21PH42071`L080KFe]0P1bLW8206UYJ@<0
K6a/0P1hN7P2079bLP80Kfm_0P1dM7@408F5Q@<0Shn?0P2GUiL209^KV`80UiNG0P2NWYh20:VYZ@80
YjNW0P2/[:`50;:b/P80ZZZZ0P2a/K420;Bd]080^k^k0P2m_Kd30;6a/@80X:2P0P2KVi/209NGU`80
U9BD1028R8P308V9R@80Q8B40P23Ph<207inOP80NGUi0P1gMgL207UiN@<0Lg=c0P1hN7P20820P080
Ph>30P21PH420820P080NGUi0`22PX8208f=S@80U9BD0P2GUiL80<SPf0001P38h=P202PX:08092@T
0P0U9BD302/[:`809BDU0P0/;2`202l_;`80=3@d0P0b<S82034a<@<0<30`0P0a<C4203Ph>080<S8b
0P0^;Rh203Ti>@80<30`0`0a<C4202l_;`80:RXZ0P0h>3P202l_;`809bLW0P0V9RH302d];@808R8R
0P0Q8B4201lO7`808b<S0P0/;2`2059BDP80Q8B40`2OWil206e]K@80EUIF0P1/K6`209^KV`80`/;2
0P3;bl/30:n_[`80Xj>S0P2WYjL20:b/[080][Jf0P2i^KT20;bl_0<0_[jn0P38b<P20<W9b@80b/[:
0P36a/H20<C4a080aLG50`2n_[h209BDU080HV9R0P1LG5`206a/K080N7Qh0P1kNg/307alO080Ng]k
0P21PH4208J6QP80OWin0P21PH4207emO@<0Q8B4102CTi<2096AT@80T92@0P2?Shl208f=S@<0QhN7
0P28R8P20861P@80L71`0P1]KFd2079bLP80JFUY0`1/K6`207QhN080LW9b0P1_Kfl207AdM0@0QHF5
0`2?Shl209NGU`80Vi^K0P2GUiL209jNWP80ZJVY0P2WYjL20:b/[0D0/[:b0P2ZZZX20;6a/@80];Bd
0P2k^k/20;fm_@<0/K6a0P2PX:0209^KV`80UiNG0P2DU9@408R8R0<0RHV90P24Q8@208>3P`80OWin
0P1iNGT207MgM`80NGUi0`1cLg<207QhN080P8200P23Ph<20861P@80P8200P1iNGT308:2PP80SHf=
0P2DU9@209NGU`P0b>3H00060<SPf080;2`/0P0W9bL202@T90<09bLW0P0Y:BT2034a<@80=3@d0P0/
;2`2034a<@80;Bd]0`0`<30203`l?080@4100P0j>SX203Hf=P80;Rh^0P0/;2`3030`<080<S8b0P14
A4@203/k>`80;bl_0P0d=3@202/[:`<08b<S0P0W9bL202DU9@808R8R0P0/;2`202TY:@80>c/k0P1^
KVh3096AT@80Ti>C0P1OGel2061PH080O7al0P2/[:`20<k>cP<0_kno0P2NWYh20:>SX`80YZJV0P2^
[Zh20;Bd]080^[Zj0`2k^k/20<G5a@80b<S80P3:b/X20<S8b080a/K60P34a<@30;no_`80_;bl0P2?
Shl2061PH080HV9R0P1gMgL207UiN@D0Ng]k0P1oOgl40861P@80P8200P1nOWh308R8R080T92@0P2C
Ti<2092@T0@0SHf=0P2<S8`308:2PP80O7al0P1dM7@206][J`80Hf=S0P1YJFT205=CD`<0Bd];0P1a
LG4207emO@80QhN70P2:RXX209:BTP80UIFE1@2MWId209nOW`80Z:RX0P2][Jd20;2`/0@0^k^k0`31
`L420<C4a080`L710P2i^KT20:n_[`80YjNW0P2ZZZX309^KV`80TY:B0P2>SXh208N7Q`80O7al0P1e
MGD207IfMP<0PX:20P20P80208J6QP80OWin0P1mOGd207QhN080MgMg0`1iNGT207]kN`80P8201022
PX8208F5Q@80P8200`24Q8@208j>SP80U9BD0P2JVYX80<SPf0001P38h=P202`/;0809bLW0P0T92@3
02LW9`80:BTY0P0a<C4203@d=080;2`/0P0a<C4202d];@<0<30`0P0l?3`20410@080>SXj0P0f=SH2
02h^;P80;2`/0`0`<302038b<P80A4A40P0k>c/202l_;`80=3@d0P0[:b/302<S8`809bLW0P0U9BD2
028R8P80;2`/0P0Y:BT203/k>`80KVi^0`2ATI4209>CT`80GemO0P1PH60207alO080[:b/0P3>c/h3
0;no_`80WYjN0P2SXj<20:JVYP80[Zj^0P2d];@20;Zj^P<0^k^k0P35aLD20<S8b080b/[:0P38b<P2
0<K6aP80a<C40`2o_kl20;bl_080Shn?0P1PH602069RHP80MgMg0P1iNGT507]kN`80Ogmo1021PH42
0820P080OWin0`28R8P2092@T080Ti>C0P2@T90408f=S@80S8b<0`22PX8207alO080M7Ad0P1[Jf/2
06=SH`80JFUY0P1CDe<304];B`80LG5a0P1mOGd208N7Q`80RXZ:0P2BTY8209FEU@D0WIfM0P2OWil2
0:RXZ080[Jf]0P2`/;040;^k^`<0`L710P34a<@20<71`@80^KVi0P2_[jl20:NWY`80ZZZZ0`2KVi/2
09:BTP80SXj>0P27QhL207alO080MGEe0P1fMWH308:2PP80P8200P26QXH207inOP80OGem0P1hN7P2
07MgM`<0NGUi0P1kNg/20820P0@0PX:20P25QHD20820P0<0Q8B40P2>SXh209BDU080VYZJ2038h=P0
00H0b>3H0P0b<S8202`/;0D09bLW0P0T92@202TY:@80<30`0P0i>CT203Ph>080<S8b0`0^;Rh203Hf
=P80@d=30P0o?cl402h^;P80=SHf0`0`<30202`/;080;Rh^0P0a<C4203Lg=`809bLW0P0T92@302PX
:0809BDU0P0T92@2024Q8@80820P0P0i>CT202XZ:P80CDe=0`25QHD209^KV`80O7al0P1SHf<206IV
IP80R8R80P32`/830<G5a@80W9bL0P2EUID209nOW`80[Jf]0P2a/K420;Vi^@<0]KFe0P30`<040<O7
a`80a/K60P37alL20<G5a@D0`L710P2l_;`209:BTP80IVIV0P1YJFT2079bLP<0Ogmo0P1lO7`207]k
N`80NWYj0P1lO7`207inOP80Ng]k0`27QhL208j>SP80Rh^;0P2=SHd408J6QP80QHF50`1bLW8206YZ
JP80GemO0P1KFe/205eMG@80GemO0P1NGUh306i^KP80MgMg0P22PX8208^;R`80SHf=0P23Ph<208F5
Q@<0RXZ:0P2CTi<209jNWP80][Jf0P2k^k/20<71`@80aLG50P37alL30<_;b`80c/k>0P3AdM420<k>
cP80alO70P2f][H209jNWP<0T92@0P29RHT2096AT@80V9RH0P2;Rh/207=cL`80L71`0`1lO7`208>3
P`80PX:20P1mOGd207UiN@80LW9b0P1eMGD307UiN@80O7al0P24Q8@20861P@80PX:20P21PH4208F5
Q@<0Q8B4102=SHd209VIV@P0b>3H00060<SPf080<S8b0P0/;2`502LW9`8092@T0P0Y:BT2030`<080
>CTi0P0h>3P2038b<P<0;Rh^0P0f=SH204=3@`80?clo100^;Rh203Hf=P<0<30`0P0/;2`202h^;P80
<C4a0P0g=cL202LW9`8092@T0`0X:2P202DU9@8092@T0P0Q8B42020P8080>CTi0P0Z:RX204e=C@<0
QHF50P2KVi/207alO080Hf=S0P1VIVH208R8R080`/;20`35aLD209bLW080UIFE0P2OWil20:f][@80
/K6a0P2i^KT30;Fe]@80`<301037alL20<K6aP80alO70P35aLD50<71`@80_;bl0P2BTY8206IVIP80
JFUY0P1bLW8307moO`80O7al0P1kNg/207YjNP80O7al0P1nOWh207]kN`<0QhN70P2>SXh208^;R`80
SHf=1026QXH208F5Q@<0LW9b0P1ZJVX205mOG`80Fe]K0P1MGEd205mOG`80GUiN0`1^KVh207MgM`80
PX:20P2;Rh/208f=S@80Ph>30P25QHD308Z:RP80Ti>C0P2NWYh20;Jf]P80^k^k0P31`L420<G5a@80
alO70`3;bl/20<k>cP80dM7A0P3>c/h20<O7a`80][Jf0P2NWYh3092@T080RHV90P2ATI4209RHV080
Rh^;0P1cLg<2071`L0<0O7al0P23Ph<208:2PP80OGem0P1iNGT2079bLP80MGEe0`1iNGT207alO080
Q8B40P21PH4208:2PP80PH610P25QHD308B4Q0@0SHf=0P2IVIT80<SPf0001P38h=P202`/;080:b/[
0P0f=SH302`/;080;bl_0P0[:b/203Hf=P80?Cdm0P0j>SX203Hf=P<0;Bd]0P0X:2P203Lg=`80@410
0P0a<C4202LW9`809RHV0`0Y:BT202`/;080;bl_0P0`<30203De=@809RHV0P0U9BD302h^;P80;Bd]
0P0Q8B4202<S8`808B4Q0P0Z:RX203Hf=P80?3`l0`1HF5P208R8R080UYJF0P1SHf<205QHF080IVIV
0P2SXj<30<;2`P80Zj^[0P2FUYH209bLW080[:b/0P2e]KD20;:b/P<0];Bd0P2m_Kd40<?3``80alO7
0P39bLT20<G5a@<0alO70P31`L420<C4a080`L710P2LW9`206a/K080JVYZ0`1cLg<207MgM`80NWYj
0P1bLW8207IfMP80OWin0P1lO7`308>3P`80S8b<0P23Ph<208n?S`80R8R80P1lO7`207IfMP<0Hf=S
0P1CDe<404=3@`80DU9B0P1SHf<207=cL`D0MgMg0P1lO7`208B4Q080N7Qh0P1/K6`206EUI@<0IVIV
0P1dM7@208V9R@80Xj>S0P2j^[X20<G5a@80a/K60P3:b/X30<g=c@80clo?0P3AdM420<o?c`80b/[:
0P36a/H20;2`/0<0UiNG0P28R8P2092@T080SXj>0P2DU9@2075aL@80KVi^0`1iNGT208F5Q@80OWin
0P1dM7@2075aL@80NGUi0P1dM7@307alO080Ng]k0P1lO7`207moO`@0PX:20P23Ph<508J6QP80T92@
0P2DU9@80<SPf0001P38h=P202`/;080:b/[0P0f=SH302`/;080;bl_0P0[:b/203Hf=P80?Cdm0P0j
>SX203Hf=P<0;Bd]0P0X:2P203Lg=`80@4100P0a<C4202LW9`809RHV0`0Y:BT202`/;080;bl_0P0`
<30203De=@809RHV0P0U9BD302h^;P80;Bd]0P0Q8B4202<S8`808B4Q0P0Z:RX203Hf=P80?3`l0`1H
F5P208R8R080UYJF0P1SHf<205QHF080IVIV0P2SXj<30<;2`P80Zj^[0P2FUYH209bLW080[:b/0P2e
]KD20;:b/P<0];Bd0P2m_Kd40<?3``80alO70P39bLT20<G5a@<0alO70P31`L420<C4a080`L710P2L
W9`206a/K080JVYZ0`1cLg<207MgM`80NWYj0P1bLW8207IfMP80OWin0P1lO7`308>3P`80S8b<0P23
Ph<208n?S`80R8R80P1lO7`207IfMP<0Hf=S0P1CDe<404=3@`80DU9B0P1SHf<207=cL`D0MgMg0P1l
O7`208B4Q080N7Qh0P1/K6`206EUI@<0IVIV0P1dM7@208V9R@80Xj>S0P2j^[X20<G5a@80a/K60P3:
b/X30<g=c@80clo?0P3AdM420<o?c`80b/[:0P36a/H20;2`/0<0UiNG0P28R8P2092@T080SXj>0P2D
U9@2075aL@80KVi^0`1iNGT208F5Q@80OWin0P1dM7@2075aL@80NGUi0P1dM7@307alO080Ng]k0P1l
O7`207moO`@0PX:20P23Ph<508J6QP80T92@0P2DU9@80<SPf0001P38h=P203`l?080=CDe0P0X:2P3
02h^;P80:RXZ0P0^;Rh203@d=080ADE50P1?Cdl203dm?@<0:RXZ0P0Y:BT2034a<@80>SXj0P0b<S82
02d];@80;2`/0`0X:2P402d];@80=SHf0P0h>3P202PX:0D09bLW0P0T92@2024Q8@809BDU0P0Z:RX2
030`<080<S8b0P0e=CD303lo?`80KVi^0P2EUID207alO080De=C0P1FEUH207inOP<0[jn_0P2i^KT2
09nOW`80V9RH0P2YZJT20;2`/080/k>c0`2d];@20;bl_080_[jn0P33`l<20<O7a`80bLW90P3:b/X3
0<C4a0H0aLG50P34a<@20:2PX080KFe]0`1XJ6P2075aL@80MGEe101fMWH207moO`80PX:20`24Q8@2
08:2PP80O7al0P22PX8207alO080MGEe0P1/K6`305IFEP80@D51100_;bl204U9B@80Hf=S0P1aLG43
071`L080MGEe0P1hN7P2075aL@80GemO0P1BDU8203lo?`<0@T920P1;Bd/205QHF080Ogmo0P2NWYh2
0;bl_080b/[:0P3;bl/50<[:bP80c/k>0P3<c<`20<K6aP80`l?30P2l_;`30:>SX`80U9BD0P2:RXX2
08B4Q080N7Qh0P1ZJVX207AdM0<0OWin0P1jNWX4071`L080Lg=c0P1lO7`207emO@<0N7Qh0P1fMWH2
07]kN`80NWYj0P26QXH208B4Q080Rh^;0`2:RXX208n?S`80U9BD0P2KVi/80<SPf0001P38h=P203`l
?080=CDe0P0X:2P302h^;P80:RXZ0P0^;Rh203@d=080ADE50P1?Cdl203dm?@<0:RXZ0P0Y:BT2034a
<@80>SXj0P0b<S8202d];@80;2`/0`0X:2P402d];@80=SHf0P0h>3P202PX:0D09bLW0P0T92@2024Q
8@809BDU0P0Z:RX2030`<080<S8b0P0e=CD303lo?`80KVi^0P2EUID207alO080De=C0P1FEUH207in
OP<0[jn_0P2i^KT209nOW`80V9RH0P2YZJT20;2`/080/k>c0`2d];@20;bl_080_[jn0P33`l<20<O7
a`80bLW90P3:b/X30<C4a0H0aLG50P34a<@20:2PX080KFe]0`1XJ6P2075aL@80MGEe101fMWH207mo
O`80PX:20`24Q8@208:2PP80O7al0P22PX8207alO080MGEe0P1/K6`305IFEP80@D51100_;bl204U9
B@80Hf=S0P1aLG43071`L080MGEe0P1hN7P2075aL@80GemO0P1BDU8203lo?`<0@T920P1;Bd/205QH
F080Ogmo0P2NWYh20;bl_080b/[:0P3;bl/50<[:bP80c/k>0P3<c<`20<K6aP80`l?30P2l_;`30:>S
X`80U9BD0P2:RXX208B4Q080N7Qh0P1ZJVX207AdM0<0OWin0P1jNWX4071`L080Lg=c0P1lO7`207em
O@<0N7Qh0P1fMWH207]kN`80NWYj0P26QXH208B4Q080Rh^;0`2:RXX208n?S`80U9BD0P2KVi/80<SP
f0001P38h=P20410@080;Rh^0P0/;2`302PX:080;2`/0P0X:2P203Xj>P80DU9B0P1dM7@204e=C@<0
:RXZ0P0/;2`203@d=080<30`0P0e=CD202`/;080;Bd]1@0[:b/203De=@80=3@d0P0`<30202XZ:P80
<30`0`0/;2`202LW9`80:2PX0P0[:b/202LW9`80;Rh^0P0X:2P202DU9@<0;2`/0P10@40207emO@80
RXZ:0P1WIfL2055AD@80IVIV0`29RHT20:JVYP80XJ6Q0P2@T90209NGU`80Xj>S0P2XZ:P30:^[Z`80
^k^k0P2i^KT20<71`@80a/K60P35aLD20<S8b0<0alO70P35aLD20<C4a080`/;20P37alL20<?3``80
V9RH0`1/K6`206=SH`80L71`0P1bLW8207YjNP80OWin0P21PH4307emO@80M7Ad0P1eMGD207UiN@80
KFe]0P1TI6@2061PH0<0BTY:0P0b<S8202/[:`80<c<c0P14A4@205aLG080JFUY0`1bLW8207emO@80
LG5a0P1IFET203hn?P80>CTi0P0f=SH303dm?@80>SXj0P11@D4204e=C@80Jf][0P2PX:020<K6aP80
d=3@0`3>c/h20=3@d080clo?0P3AdM420<[:bP80b<S80P30`<030;2`/080WYjN0P23Ph<2079bLP80
HF5Q0P1VIVH507emO@80M7Ad0P1VIVH206m_K`80LW9b0P1gMgL207alO0<0MGEe0P1aLG4207]kN`80
PH610P22PX8208J6QP80RHV90`2:RXX208j>SP80Ti>C0P2KVi/80<SPf0001P38h=P20410@080;Rh^
0P0/;2`302PX:080;2`/0P0X:2P203Xj>P80DU9B0P1dM7@204e=C@<0:RXZ0P0/;2`203@d=080<30`
0P0e=CD202`/;080;Bd]1@0[:b/203De=@80=3@d0P0`<30202XZ:P80<30`0`0/;2`202LW9`80:2PX
0P0[:b/202LW9`80;Rh^0P0X:2P202DU9@<0;2`/0P10@40207emO@80RXZ:0P1WIfL2055AD@80IVIV
0`29RHT20:JVYP80XJ6Q0P2@T90209NGU`80Xj>S0P2XZ:P30:^[Z`80^k^k0P2i^KT20<71`@80a/K6
0P35aLD20<S8b0<0alO70P35aLD20<C4a080`/;20P37alL20<?3``80V9RH0`1/K6`206=SH`80L71`
0P1bLW8207YjNP80OWin0P21PH4307emO@80M7Ad0P1eMGD207UiN@80KFe]0P1TI6@2061PH0<0BTY:
0P0b<S8202/[:`80<c<c0P14A4@205aLG080JFUY0`1bLW8207emO@80LG5a0P1IFET203hn?P80>CTi
0P0f=SH303dm?@80>SXj0P11@D4204e=C@80Jf][0P2PX:020<K6aP80d=3@0`3>c/h20=3@d080clo?
0P3AdM420<[:bP80b<S80P30`<030;2`/080WYjN0P23Ph<2079bLP80HF5Q0P1VIVH507emO@80M7Ad
0P1VIVH206m_K`80LW9b0P1gMgL207alO0<0MGEe0P1aLG4207]kN`80PH610P22PX8208J6QP80RHV9
0`2:RXX208j>SP80Ti>C0P2KVi/80<SPf0001P38h=P203Ph>080:2PX0P0V9RH302LW9`809RHV0P0]
;Bd20410@080IFEU0P1oOgl204m?C`<0=CDe0P0^;Rh2034a<@80:BTY0P0e=CD202/[:`80:BTY0`0a
<C4202d];@80<C4a0P0m?Cd202d];@80:2PX0P0];Bd302HV9P80;2`/0P0[:b/202PX:0808b<S0P0]
;Bd202LW9`8092@T0`0V9RH202l_;`80FUYJ0P1hN7P207=cL`80DE5A0P1LG5`307emO@80UiNG0P2a
/K4209jNWP80Ti>C0P2GUiL209>CT`<0VIVI0P2RXZ820:ZZZP80];Bd0P2k^k/20<?3``80a/K60`39
bLT20<[:bP80b<S81035aLD20<?3``80`/;20`2HV9P206MWI`80KFe]0P1UIFD207=cL`80N7Qh0P1j
NWX307EeM@80KVi^0P1TI6@2065QH@80GemO0P1FEUH204i>CP<0=cLg0P0_;bl203<c<`80ADE50P1C
De<205YJFP80K6a/0`1oOgl207=cL`80F5QH0P0k>c/203`l?080Cdm?0P1GEeL305YJFP80D51@0P1=
CDd203Lg=`80@D510P1aLG420:f][@80clo?0`3Cdm<20=;BdP@0dm?C0P3=cLd20<k>cP80b/[:0`2f
][H209jNWP80Ng]k0P1MGEd205ADE080Hf=S0P1nOWh307IfMP80IVIV0P1RHV8206][J`@0Kfm_0P1e
MGD3079bLP80MWIf0P1jNWX40820P080QXJ60P28R8P308V9R@80T92@0P2GUiL20::RXPP0b>3H0006
0<SPf080>3Ph0P0X:2P202HV9P<09bLW0P0V9RH202d];@80@4100P1UIFD207moO`80Cdm?0`0e=CD2
02h^;P80<C4a0P0Y:BT203De=@80:b/[0P0Y:BT3034a<@80;Bd]0P0a<C4203dm?@80;Bd]0P0X:2P2
02d];@<09RHV0P0/;2`202/[:`80:2PX0P0S8b<202d];@809bLW0P0T92@302HV9P80;bl_0P1JFUX2
07QhN080Lg=c0P1ADE4205aLG0<0OGem0P2GUiL20;6a/@80WYjN0P2CTi<209NGU`80Ti>C0`2IVIT2
0::RXP80ZZZZ0P2d];@20;^k^`80`l?30P36a/H30<W9b@80b/[:0P38b<P40<G5a@80`l?30P32`/83
09RHV080IfMW0P1]KFd206EUI@80Lg=c0P1hN7P207YjNP<0MGEe0P1^KVh206ATI080HF5Q0P1OGel2
05IFEP80CTi>0`0g=cL202l_;`80<c<c0P15ADD205=CD`80FUYJ0P1/K6`307moO`80Lg=c0P1HF5P2
03/k>`80?3`l0P1?Cdl205MGE`<0FUYJ0P1@D50204e=C@80=cLg0P11@D42075aL@80[Jf]0P3?cll3
0=?Cd`80d];B103Cdm<20<g=c@80c/k>0P3:b/X30;Jf]P80WYjN0P1kNg/205eMG@80E5AD0P1SHf<2
07inOP<0MWIf0P1VIVH2069RHP80Jf][101_Kfl207EeM@<0LW9b0P1fMWH207YjNP@0P8200P26QXH2
08R8R0<0RHV90P2@T90209NGU`80XZ:R2038h=P000H0b>3H0P0h>3P202h^;P80:b/[0`0Y:BT202/[
:`80<C4a0P15ADD207UiN@80MgMg0P16ATH303hn?P80;2`/0P0Y:BT202XZ:P80;2`/0P0Z:RX202d]
;@<0;2`/0P0Z:RX2030`<080>SXj0P0^;Rh202XZ:P809RHV0`0X:2P202TY:@@0:b/[0P0U9BD202LW
9`808b<S1@0U9BD202h^;P80BTY:0P1YJFT208B4Q080LW9b0P1FEUH306a/K080Ti>C0P2l_;`20;no
_`80Z:RX0P2QXJ4209VIV@<0UIFE0P2IVIT20:RXZ080[Jf]0P2c/k<20;jn_P80`l?31@3:b/X20<_;
b`80a/K60P31`L420<K6aPD0alO70P2CTi<206UYJ@80HV9R0P1WIfL207AdM080KVi^0`1YJFT205aL
G080E5AD0P1BDU8204i>CP80@T920P0k>c/302h^;P80:b/[0P0];Bd204E5A@80BTY:0P1MGEd207Ee
M@<0NGUi0P1SHf<204=3@`80>SXj0P1DE5@2069RHPD0EUIF0P1KFe/205=CD`80B4Q80P0i>CT20492
@P80OWin0P35aLD30=7Ad@80c/k>0P3@d=020=;BdP80cLg=0P3>c/h20<S8b0<0][Jf0P2EUID206a/
K080C4a<0P16ATH206a/K080OWin0`1ZJVX205aLG080H61P101`L70206e]K@80L71`0`1fMWH207Ui
N@80NWYj0P1mOGd20861P@80QHF50P2:RXX308R8R080SHf=0P2EUID209bLW0P0b>3H00060<SPf080
>3Ph0P0^;Rh202/[:`<0:BTY0P0[:b/2034a<@80ADE50P1iNGT207MgM`80ATI60`0n?Sh202`/;080
:BTY0P0Z:RX202`/;080:RXZ0P0];Bd302`/;080:RXZ0P0`<30203Xj>P80;Rh^0P0Z:RX202HV9P<0
:2PX0P0Y:BT402/[:`809BDU0P0W9bL202<S8`D09BDU0P0^;Rh204Y:BP80JFUY0P24Q8@2079bLP80
EUIF0`1/K6`209>CT`80_;bl0P2o_kl20:RXZ080XJ6Q0P2IVIT309FEU@80VIVI0P2XZ:P20:f][@80
/k>c0P2n_[h20<?3``D0b/[:0P3;bl/20<K6aP80`L710P36a/H50<O7a`80Ti>C0P1YJFT2069RHP80
IfMW0P1dM7@206i^KP<0JFUY0P1LG5`205ADE080DU9B0P1>CTh20492@P80>c/k0`0^;Rh202/[:`80
;Bd]0P15ADD204Y:BP80GEeM0P1eMGD307UiN@80Hf=S0P13@d<203Xj>P80E5AD0P1RHV8505IFEP80
Fe]K0P1CDe<204Q8B080>CTi0P12@T8207inOP80aLG50`3AdM420<k>cP80d=3@0P3Bd]820<g=c@80
c/k>0P38b<P30;Jf]P80UIFE0P1/K6`204a<C080ATI60P1/K6`207inOP<0JVYZ0P1LG5`2061PH0@0
L71`0P1]KFd2071`L0<0MWIf0P1iNGT207YjNP80OGem0P21PH4208F5Q@80RXZ:0`28R8P208f=S@80
UIFE0P2LW9`80<SPf0001P38h=P203Ph>080;Rh^0P0[:b/302TY:@80:b/[0P0a<C4204E5A@80NGUi
0P1gMgL204I6AP<0?Shn0P0/;2`202TY:@80:RXZ0P0/;2`202XZ:P80;Bd]0`0/;2`202XZ:P80<30`
0P0j>SX202h^;P80:RXZ0P0V9RH302PX:080:BTY100[:b/202DU9@809bLW0P0S8b<502DU9@80;Rh^
0P1:BTX206UYJ@80Q8B40P1bLW8205IFEP<0K6a/0P2CTi<20;bl_080_kno0P2XZ:P20:6QX@80VIVI
0`2EUID209VIV@80Z:RX0P2][Jd20;>c/`80_[jn0P33`l<50<[:bP80bl_;0P36a/H20<71`@80a/K6
1@37alL209>CT`80JFUY0P1RHV8206MWI`80M7Ad0P1^KVh306UYJ@80G5aL0P1DE5@2059BDP80CTi>
0P12@T8203/k>`<0;Rh^0P0[:b/202d];@80ADE50P1:BTX205eMG@80MGEe0`1iNGT206=SH`80@d=3
0P0j>SX205ADE080HV9R1@1FEUH205]KF`80De=C0P18B4P203Ti>@80@T920P1nOWh20<G5a@<0dM7A
0P3>c/h20=3@d080d];B0P3=cLd20<k>cP80b<S80`2f][H209FEU@80K6a/0P1<C4`204I6AP80K6a/
0P1nOWh306YZJP80G5aL0P1PH604071`L080KFe]0P1`L70307IfMP80NGUi0P1jNWX207emO@80PH61
0P25QHD208Z:RP<0R8R80P2=SHd209FEU@80W9bL2038h=P000H0b>3H0P0e=CD202XZ:P80<30`0`0V
9RH202LW9`80;Rh^0P1BDU8208R8R080E5AD0P0f=SH304A4A0@0<30`0P0S8b<202@T90809RHV0P0_
;bl302HV9P80;Rh^0P0g=cL203Ph>080;bl_0P0[:b/202TY:@<09bLW0P0d=3@203Ti>@80<S8b0P0[
:b/202DU9@80:2PX0P0];Bd303De=@80B4Q80P1:BTX2069RHP80RHV90P2MWId207EeM@<0H61P0P1d
M7@20:VYZ@80cLg=0P2o_kl20:ZZZP80Y:BT0`2][Jd20:ZZZP80/[:b0P2k^k/20;Jf]P80_Kfm0P2l
_;`30<S8b080bLW90P3;bl/40<K6aP80cLg=0P39bLT30<S8b080`/;20P2=SHd205eMG@80HF5Q0P1[
Jf/206EUI@<0HF5Q0P1FEUH205=CD`80@4100P0e=CD203<c<`80<30`0`0a<C4202d];@80;bl_0P12
@T8204M7A`80GemO0P1cLg<306][J`80AdM70P0d=3@205aLG080HV9R0P1JFUX204Q8B0D0@T920P1J
FUX206a/K080BTY:0P0e=CD205MGE`80/K6a0`3?cll40<c<c080c/k>0P3;bl/20<S8b080_kno0`2[
Zj/20820P080F5QH0P16ATH205QHF080O7al0P1hN7P305iNGP80FUYJ0P1/K6`207MgM`80LW9b0P1`
L702075aL@<0Lg=c0P1hN7P207]kN`80PH610P26QXH208N7Q`80R8R80`2;Rh/208f=S@80TI6A0P2I
VIT80<SPf0001P38h=P203De=@80:RXZ0P0`<30302HV9P809bLW0P0^;Rh2059BDP80R8R80P1DE5@2
03Hf=P<0A4A4100`<30202<S8`8092@T0P0V9RH202l_;`<09RHV0P0^;Rh203Lg=`80>3Ph0P0_;bl2
02/[:`80:BTY0`0W9bL203@d=080>CTi0P0b<S8202/[:`809BDU0P0X:2P202d];@<0=CDe0P18B4P2
04Y:BP80HV9R0P29RHT209fMW@80MGEe0`1PH60207AdM080ZJVY0P3=cLd20;no_`80ZZZZ0P2TY:@3
0:f][@80ZZZZ0P2b/[820;^k^`80][Jf0P2m_Kd20;bl_0<0b<S80P39bLT20<_;b`@0a/K60P3=cLd2
0<W9b@<0b<S80P32`/8208f=S@80GEeM0P1QHF4206][J`80IFEU0`1QHF4205IFEP80De=C0P10@402
03De=@80<c<c0P0`<303034a<@80;Bd]0P0_;bl20492@P80AdM70P1OGel207=cL`<0Jf][0P17AdL2
03@d=080G5aL0P1RHV8205YJFP80B4Q81@12@T8205YJFP80K6a/0P1:BTX203De=@80EeMG0P2a/K43
0<o?c`@0c<c<0P3>c/h20<_;b`80b<S80P2o_kl30:^[Z`80P8200P1HF5P204I6AP80F5QH0P1lO7`2
07QhN0<0GUiN0P1JFUX206a/K080MgMg0P1bLW82071`L080LG5a0`1cLg<207QhN080Ng]k0P21PH42
08J6QP80QhN70P28R8P308^;R`80SHf=0P2ATI4209VIV@P0b>3H00060<SPf080:2PX0P0e=CD202/[
:`D0;2`/0P0d=3@206IVIP80SHf=0P19BDT2034a<@<0?Cdm0P0e=CD202TY:@809bLW0P0Y:BT202PX
:0D0;Rh^0P0_;bl202`/;080>SXj100b<S8202XZ:P<0:b/[0P0Z:RX203@d=080>SXj0P0d=3@202XZ
:P80:BTY0P0_;bl304U9B@80Bd];0P0i>CT203/k>`80M7Ad0P2HV9P208j>SP<0IfMW0P1LG5`208b<
S080`/;20P39bLT20;Bd]080Y:BT0`2_[jl20;Jf]P80/k>c102i^KT20;Rh^080]kNg0`30`<020<c<
c080clo?0P3;bl/20<O7a`@0bLW90`34a<@20<W9b@80_Kfm0P1jNWX2051@D080Fe]K0P1NGUh305IF
EP80DE5A0P14A4@403Ph>080=CDe0P0c<c<302XZ:P80;Rh^0P0d=3@203Ph>080ATI60P1LG5`206MW
I`<0FUYJ0P0b<S8203Ti>@80GUiN0P1MGEd204a<C080<30`0`0Y:BT202/[:`80ADE50P1`L70204e=
C@80>3Ph0P12@T8209fMW@D0c<c<1P36a/H20<71`@80[:b/0`2@T902069RHP80ATI60P14A4@205eM
G@80Ph>30P1^KVh305ADE080Fe]K0P1dM7@207YjNP80MGEe0P1dM7@2075aL@<0Lg=c0P28R8P208:2
PP80Q8B40P29RHT208^;R`80RHV90`2@T90208b<S080Shn?0P2IVIT80<SPf0001P38h=P202PX:080
=CDe0P0[:b/502`/;080=3@d0P1VIVH208f=S@80BDU90P0a<C4303dm?@80=CDe0P0Y:BT202LW9`80
:BTY0P0X:2P502h^;P80;bl_0P0/;2`203Xj>P@0<S8b0P0Z:RX302/[:`80:RXZ0P0d=3@203Xj>P80
=3@d0P0Z:RX202TY:@80;bl_0`19BDT204];B`80>CTi0P0k>c/207AdM080V9RH0P2>SXh306MWI`80
G5aL0P2<S8`20<;2`P80bLW90P2d];@20:BTY0<0[jn_0P2f][H20;>c/`@0^KVi0P2h^;P20;Ng]`<0
`<300P3<c<`20<o?c`80bl_;0P37alL40<W9b@<0a<C40P39bLT20;fm_@80NWYj0P1@D50205]KF`80
GUiN0`1FEUH2055AD@80A4A4100h>3P203De=@80<c<c0`0Z:RX202h^;P80=3@d0P0h>3P204I6AP80
G5aL0P1WIfL305YJFP80<S8b0P0i>CT205iNGP80GEeM0P1<C4`2030`<0<0:BTY0P0[:b/204E5A@80
L71`0P1=CDd203Ph>080@T920P2MWId50<c<c0H0a/K60P31`L420:b/[0<0T92@0P1RHV8204I6AP80
A4A40P1MGEd208>3P`80KVi^0`1DE5@205]KF`80M7Ad0P1jNWX207EeM@80M7Ad0P1aLG4307=cL`80
R8R80P22PX8208B4Q080RHV90P2;Rh/208V9R@<0T92@0P2<S8`208n?S`80VIVI2038h=P000H0b>3H
0P0W9bL203Ph>080;Rh^0`0W9bL202`/;080?Shn0P1jNWX207emO@80?clo0P0[:b/303De=@80:b/[
0P0/;2`202PX:080:RXZ0P0[:b/202TY:@<0<c<c0P0`<30202l_;`80<C4a0P0^;Rh202l_;`D0:b/[
0P0];Bd20410@080B4Q80P11@D4203Ph>080>SXj0P0U9BD302HV9P809bLW0P0Q8B4202DU9@80DU9B
0P2=SHd20:6QX@<0OWin0P1PH60206a/K080W9bL0P36a/H20;fm_@80Y:BT0`2][Jd20:n_[`80/K6a
0P2g]kL20;:b/P80/K6a0P2g]kL30;Vi^@80`l?30P3>c/h20<_;b`80b/[:0P37alL20<71`@<0b<S8
0P35aLD20<_;b`80]kNg0P1[Jf/2055AD@80DU9B0`1HF5P205EEE@80CTi>0P14A4@203Ph>080<C4a
0P0e=CD302`/;080:RXZ0P0/;2`203<c<`80@D510P1BDU8205YJFP<0DE5A0P0b<S8203`l?080D51@
0P1?Cdl2030`<0809RHV0`0T92@202LW9`80>3Ph0P1JFUX20451@@80<S8b0P18B4P20:>SX`D0c<c<
0P37alL40<30`080^KVi0P2;Rh/306][J`80B4Q80P0l?3`203hn?P80J6QX0P1/K6`205ADE0<0Bd];
0P1TI6@207]kN`80O7al0P1hN7P207YjNP80MgMg0`1iNGT20820P080QhN70P22PX8208N7Q`@0Rh^;
0`2FUYH208f=S@80TI6A0P2JVYX80<SPf0001P38h=P202LW9`80>3Ph0P0^;Rh302LW9`80;2`/0P0n
?Sh207YjNP80OGem0P0o?cl202/[:`<0=CDe0P0[:b/202`/;080:2PX0P0Z:RX202/[:`80:BTY0`0c
<c<2030`<080;bl_0P0a<C4202h^;P80;bl_1@0[:b/202d];@80@4100P18B4P20451@@80>3Ph0P0j
>SX202DU9@<09RHV0P0W9bL2024Q8@809BDU0P1BDU8208f=S@80XJ6Q0`1nOWh2061PH080K6a/0P2L
W9`20<K6aP80_Kfm0P2TY:@30:f][@80[jn_0P2a/K420;Ng]`80/[:b0P2a/K420;Ng]`<0^KVi0P33
`l<20<k>cP80bl_;0P3:b/X20<O7a`80`L710`38b<P20<G5a@80bl_;0P2g]kL206][J`80DE5A0P1B
DU8305QHF080EEEE0P1>CTh204A4A080>3Ph0P0a<C4203De=@<0;2`/0P0Z:RX202`/;080<c<c0P11
@D42059BDP80FUYJ0`1ADE42038b<P80?3`l0P1@D50204m?C`80<30`0P0V9RH302@T90809bLW0P0h
>3P205YJFP80@D510P0b<S8204Q8B080Xj>S1@3<c<`20<O7a`@0`<300P2i^KT208^;R`<0Jf][0P18
B4P203`l?080?Shn0P1XJ6P206a/K080E5AD0`1;Bd/206ATI080Ng]k0P1lO7`207QhN080NWYj0P1g
MgL307UiN@80P8200P27QhL208:2PP80QhN7102;Rh/309JFUP80SHf=0P2ATI4209ZJVPP0b>3H0006
0<SPf080;2`/0P0`<30202d];@<0;Rh^0P0`<30204M7A`80P8200P1UIFD202XZ:P80;bl_0`0];Bd4
034a<@80;Rh^0P0[:b/2038b<P80;bl_0`0[:b/202d];@80<30`0P0b<S8403/k>`80;Bd]0`0c<c<2
03lo?`80D51@0P1JFUX205EEE@80<S8b0P0Z:RX202LW9`<08R8R0P0Q8B4201lO7`808B4Q0P0b<S82
079bLP80V9RH0`2LW9`206][J`80GemO0P1iNGT20;6a/@80b<S80P2`/;030:BTY080Z:RX0P2/[:`2
0;>c/`80]KFe0P2_[jl20;Fe]@<0^;Rh0P2f][H20<[:bP80c/k>0P39bLT20<O7a`80`L711`35aLD2
0<C4a080[jn_0P1YJFT204a<C0<0D51@0P1GEeL205EEE@80C4a<0P14A4@203`l?080<S8b0`0Z:RX2
02TY:@80:RXZ0P0c<c<203De=@80?Cdm0P1=CDd304=3@`80:b/[0P0_;bl203hn?P80?3`l0P0];Bd2
02LW9`<092@T0P0X:2P205QHF080EeMG0P11@D4205IFEP80NGUi0P2^[Zh30<[:bP80c<c<0P2o_kl2
0;2`/080Xj>S0P2JVYX2065QH@<0ADE5100[:b/203/k>`80C4a<0P1:BTX203lo?`<0Cdm?0P1]KFd2
07]kN`80PX:20P1lO7`207UiN@80MWIf0`1iNGT20820P080RXZ:0P26QXH208b<S080Rh^;0P2BTY83
092@T080TI6A0P2DU9@209VIV@P0b>3H00060<SPf080;2`/0P0`<30202d];@<0;Rh^0P0`<30204M7
A`80P8200P1UIFD202XZ:P80;bl_0`0];Bd4034a<@80;Rh^0P0[:b/2038b<P80;bl_0`0[:b/202d]
;@80<30`0P0b<S8403/k>`80;Bd]0`0c<c<203lo?`80D51@0P1JFUX205EEE@80<S8b0P0Z:RX202LW
9`<08R8R0P0Q8B4201lO7`808B4Q0P0b<S82079bLP80V9RH0`2LW9`206][J`80GemO0P1iNGT20;6a
/@80b<S80P2`/;030:BTY080Z:RX0P2/[:`20;>c/`80]KFe0P2_[jl20;Fe]@<0^;Rh0P2f][H20<[:
bP80c/k>0P39bLT20<O7a`80`L711`35aLD20<C4a080[jn_0P1YJFT204a<C0<0D51@0P1GEeL205EE
E@80C4a<0P14A4@203`l?080<S8b0`0Z:RX202TY:@80:RXZ0P0c<c<203De=@80?Cdm0P1=CDd304=3
@`80:b/[0P0_;bl203hn?P80?3`l0P0];Bd202LW9`<092@T0P0X:2P205QHF080EeMG0P11@D4205IF
EP80NGUi0P2^[Zh30<[:bP80c<c<0P2o_kl20;2`/080Xj>S0P2JVYX2065QH@<0ADE5100[:b/203/k
>`80C4a<0P1:BTX203lo?`<0Cdm?0P1]KFd207]kN`80PX:20P1lO7`207UiN@80MWIf0`1iNGT20820
P080RXZ:0P26QXH208b<S080Rh^;0P2BTY83092@T080TI6A0P2DU9@209VIV@P0b>3H00060<SPf080
<C4a0P0`<30203Ph>0<0@4100P0c<c<204m?C`80SHf=0P1CDe<202PX:080;Rh^1@0/;2`202l_;`80
:b/[0P0X:2P202TY:@80:2PX0`0U9BD202/[:`80=3@d0P18B4P206MWI`80H61P0P1:BTX305YJFP80
De=C0P1]KFd205iNGP80;bl_0P0Y:BT202XZ:P80:2PX0`0S8b<202DU9@808R8R0P0P820202HV9P80
De=C0P2<S8`309nOW`80QHF5101UIFD209:BTP80`l?30P36a/H30:^[Z`80[:b/0P2VYZH20:n_[`80
/[:b0P2^[Zh50;Fe]@80];Bd0P34a<@20<W9b@80b/[:0P34a<@20<O7a`<0aLG50P30`<020;jn_P80
`<300P38b<P20:j^[P80HF5Q0`14A4@204Q8B080D51@101;Bd/204I6AP80>SXj0`0Y:BT202l_;`80
<C4a0P0`<302034a<@80<30`1@0e=CD202l_;`80:b/[0P0f=SH2034a<@80<S8b0P0X:2P302h^;P80
<30`0P1<C4`203hn?P80ADE50P1NGUh20820P080XZ:R0`31`L420<30`080[jn_0P2EUID207MgM`80
HV9R0P0k>c/302XZ:P809bLW0P0V9RH202LW9`80:RXZ0P0/;2`203<c<`<0DE5A0P1^KVh20861P@80
QhN70P21PH4207inOP80OGem0`20P80207inOP80QhN70P28R8P208F5Q@80SXj>0P2<S8`309>CT`80
UIFE0P2HV9P209VIV@P0b>3H00060<SPf080<C4a0P0`<30203Ph>0<0@4100P0c<c<204m?C`80SHf=
0P1CDe<202PX:080;Rh^1@0/;2`202l_;`80:b/[0P0X:2P202TY:@80:2PX0`0U9BD202/[:`80=3@d
0P18B4P206MWI`80H61P0P1:BTX305YJFP80De=C0P1]KFd205iNGP80;bl_0P0Y:BT202XZ:P80:2PX
0`0S8b<202DU9@808R8R0P0P820202HV9P80De=C0P2<S8`309nOW`80QHF5101UIFD209:BTP80`l?3
0P36a/H30:^[Z`80[:b/0P2VYZH20:n_[`80/[:b0P2^[Zh50;Fe]@80];Bd0P34a<@20<W9b@80b/[:
0P34a<@20<O7a`<0aLG50P30`<020;jn_P80`<300P38b<P20:j^[P80HF5Q0`14A4@204Q8B080D51@
101;Bd/204I6AP80>SXj0`0Y:BT202l_;`80<C4a0P0`<302034a<@80<30`1@0e=CD202l_;`80:b/[
0P0f=SH2034a<@80<S8b0P0X:2P302h^;P80<30`0P1<C4`203hn?P80ADE50P1NGUh20820P080XZ:R
0`31`L420<30`080[jn_0P2EUID207MgM`80HV9R0P0k>c/302XZ:P809bLW0P0V9RH202LW9`80:RXZ
0P0/;2`203<c<`<0DE5A0P1^KVh20861P@80QhN70P21PH4207inOP80OGem0`20P80207inOP80QhN7
0P28R8P208F5Q@80SXj>0P2<S8`309>CT`80UIFE0P2HV9P209VIV@P0b>3H00060<SPf080;bl_0P0j
>SX2059BDP<0EUIF0P0e=CD205aLG080QhN70P17AdL202DU9@80;Bd]0`0d=3@2038b<P80;2`/0P0U
9BD202/[:`80:BTY0P0[:b/302XZ:P80<30`0P0n?Sh206i^KP80NWYj0P1`L70206e]K@<0IVIV0P1B
DU8203/k>`80:b/[100W9bL202d];@80:BTY1@0R8R8202HV9P@08B4Q0P0c<c<206YZJP<0Ti>C0P2V
YZH2075aL@80GemO0P1nOWh20:b/[080bLW90`2m_Kd20:NWY`80ZJVY0P2ZZZX20:^[Z`80[jn_0P2c
/k<50;Vi^@80a<C40P39bLT20<g=c@80b/[:0P32`/830<C4a0@0_[jn0P33`l<20<71`@80aLG50P2V
YZH305UIF@80@d=30P1;Bd/204U9B@80?Shn0P0k>c/20492@P<0<c<c100`<30203@d=080;bl_100`
<30302l_;`80=cLg0P0_;bl203<c<`80<30`0P0^;Rh202`/;0<0;Rh^0P0_;bl202`/;080<S8b0P0h
>3P204I6AP80FUYJ0P2:RXX30::RXP80UYJF0P2>SXh206QXJ080CTi>0P0h>3P202XZ:PD0:BTY0P0[
:b/202HV9P80:RXZ0P0^;Rh204=3@`<0I6AT0P1eMGD208B4Q080R8R80P24Q8@20861P@80OWin0`20
P80208:2PP80R8R80P2:RXX208^;R`80RXZ:0P2?Shl309:BTP80UYJF0P2DU9@209VIV@P0b>3H0006
0<SPf080;bl_0P0j>SX2059BDP<0EUIF0P0e=CD205aLG080QhN70P17AdL202DU9@80;Bd]0`0d=3@2
038b<P80;2`/0P0U9BD202/[:`80:BTY0P0[:b/302XZ:P80<30`0P0n?Sh206i^KP80NWYj0P1`L702
06e]K@<0IVIV0P1BDU8203/k>`80:b/[100W9bL202d];@80:BTY1@0R8R8202HV9P@08B4Q0P0c<c<2
06YZJP<0Ti>C0P2VYZH2075aL@80GemO0P1nOWh20:b/[080bLW90`2m_Kd20:NWY`80ZJVY0P2ZZZX2
0:^[Z`80[jn_0P2c/k<50;Vi^@80a<C40P39bLT20<g=c@80b/[:0P32`/830<C4a0@0_[jn0P33`l<2
0<71`@80aLG50P2VYZH305UIF@80@d=30P1;Bd/204U9B@80?Shn0P0k>c/20492@P<0<c<c100`<302
03@d=080;bl_100`<30302l_;`80=cLg0P0_;bl203<c<`80<30`0P0^;Rh202`/;0<0;Rh^0P0_;bl2
02`/;080<S8b0P0h>3P204I6AP80FUYJ0P2:RXX30::RXP80UYJF0P2>SXh206QXJ080CTi>0P0h>3P2
02XZ:PD0:BTY0P0[:b/202HV9P80:RXZ0P0^;Rh204=3@`<0I6AT0P1eMGD208B4Q080R8R80P24Q8@2
0861P@80OWin0`20P80208:2PP80R8R80P2:RXX208^;R`80RXZ:0P2?Shl309:BTP80UYJF0P2DU9@2
09VIV@P0b>3H00060<SPf080:RXZ0P0o?cl205EEE@<0?Cdm0P0];Bd205iNGP80PX:20P0h>3P402`/
;0<0:RXZ0P0X:2P202HV9P@092@T0P0Y:BT202DU9@<0:RXZ0P11@D4206UYJ@@0NGUi0P1bLW8206MW
I`<0B4Q80P0X:2P202@T9080:BTY0P0V9RH202LW9`80;Bd]0P0_;bl302DU9@80:BTY0P0W9bL2028R
8P808B4Q0P0S8b<204E5A@<0P8200P2QXJ4209FEU@@0I6AT0P2@T9020;Vi^@<0a/K60P2_[jl20:NW
Y`80Y:BT0P2/[:`20;6a/@80/;2`1@2h^;P20<;2`P80aLG50P3=cLd20<[:bP80`l?30`32`/820<30
`080_Kfm102o_kl20;fm_@80aLG50`2WYjL205iNGP80BTY:1011@D4404=3@`<0>CTi0P0e=CD2038b
<P80;bl_0P0`<30403De=@<0<c<c0P0e=CD203Lg=`80<c<c0P0e=CD202d];@80;2`/0`0Z:RX202l_
;`80;Rh^0P0_;bl2030`<080Cdm?0P12@T82069RHP<0MgMg0P1_Kfl205aLG080ATI60P0i>CT202h^
;P80:RXZ0`0W9bL202h^;P80:BTY0P0V9RH202h^;P80?3`l0P1FEUH307=cL`80PH610P2;Rh/408N7
Q`80Ph>30P1mOGd508:2PP80QHF5102=SHd2092@T080UiNG0`2CTi<209BDU080VIVI0P2MWId80<SP
f0001P38h=P202XZ:P80?clo0P1EEED303dm?@80;Bd]0P1NGUh208:2PP80>3Ph100/;2`302XZ:P80
:2PX0P0V9RH402@T9080:BTY0P0U9BD302XZ:P80@D510P1YJFT407UiN@80LW9b0P1WIfL304Q8B080
:2PX0P0T92@202TY:@809RHV0P0W9bL202d];@80;bl_0`0U9BD202TY:@809bLW0P0R8R82024Q8@80
8b<S0P15ADD30820P080XJ6Q0P2EUID406ATI080T92@0P2i^KT30<K6aP80[jn_0P2WYjL20:BTY080
[:b/0P2a/K420;2`/0D0^;Rh0P32`/820<G5a@80cLg=0P3:b/X20<?3``<0`/;20P30`<020;fm_@@0
_kno0P2m_Kd20<G5a@<0YjNW0P1NGUh204Y:BP@0@D511013@d<303Ti>@80=CDe0P0b<S8202l_;`80
<30`100e=CD303<c<`80=CDe0P0g=cL203<c<`80=CDe0P0];Bd202`/;0<0:RXZ0P0_;bl202h^;P80
;bl_0P0`<30204m?C`80@T920P1RHV8307MgM`80Kfm_0P1LG5`204I6AP80>CTi0P0^;Rh202XZ:P<0
9bLW0P0^;Rh202TY:@809RHV0P0^;Rh203`l?080EUIF0`1cLg<20861P@80Rh^;1027QhL208>3P`80
OGem1@22PX8208F5Q@@0SHf=0P2@T90209NGU`<0Ti>C0P2DU9@209VIV@80WIfM2038h=P000H0b>3H
0P0Z:RX203lo?`80EEEE0`0m?Cd202d];@80GUiN0P22PX8203Ph>0@0;2`/0`0Z:RX202PX:0809RHV
100T92@202TY:@809BDU0`0Z:RX20451@@80JFUY101iNGT2079bLP80IfMW0`18B4P202PX:08092@T
0P0Y:BT202HV9P809bLW0P0];Bd202l_;`<09BDU0P0Y:BT202LW9`808R8R0P0Q8B4202<S8`80ADE5
0`20P8020:6QX@80UIFE101TI6@2092@T080^KVi0`36a/H20:n_[`80YjNW0P2TY:@20:b/[080/K6a
0P2`/;050;Rh^080`/;20P35aLD20<g=c@80b/[:0P33`l<30<;2`P80`<300P2m_Kd40;no_`80_Kfm
0P35aLD30:NWY`80GUiN0P1:BTX40451@@@0@d=30`0i>CT203De=@80<S8b0P0_;bl2030`<0@0=CDe
0`0c<c<203De=@80=cLg0P0c<c<203De=@80;Bd]0P0/;2`302XZ:P80;bl_0P0^;Rh202l_;`80<30`
0P1?Cdl20492@P80HV9R0`1gMgL206m_K`80G5aL0P16ATH203Ti>@80;Rh^0P0Z:RX302LW9`80;Rh^
0P0Y:BT202HV9P80;Rh^0P0l?3`205IFEP<0Lg=c0P21PH4208^;R`@0QhN70P23Ph<207emO@D0PX:2
0P25QHD408f=S@80T92@0P2GUiL309>CT`80U9BD0P2IVIT209fMW@P0b>3H00060<SPf080=cLg0P1F
EUH203Xj>P<0;bl_0P0b<S8205UIF@80Lg=c0P0^;Rh202HV9P80:BTY0`0W9bL202@T90809bLW100U
9BD2020P8080<30`0`0e=CD2071`L080NGUi0P1aLG42079bLP80H61P0P10@40502HV9P8092@T0P0W
9bL202/[:`80;bl_0P0c<c<203@d=0<0:RXZ0P0P820202HV9P80:RXZ0P0K6a/201lO7`809RHV0`1J
FUX2092@T080[Jf]0P1fMWH206MWI`80Ng]k0P2JVYX30<71`@80`l?3102VYZH20:b/[080/;2`0P2]
[Jd30;Jf]P80];Bd0P2i^KT20<C4a080b<S80P3;bl/20<?3``<0`L710P32`/820;Zj^P80_;bl0P2n
_[h20;Vi^@80`/;20`36a/H20::RXP80F5QH0P16ATH20410@080?clo0P1;Bd/303/k>`80=SHf0P0g
=cL203Ti>@80=CDe0P0b<S8203De=@D0=3@d0P0j>SX203<c<`80;bl_0P0b<S8203@d=0<0;Rh^0P0`
<30202h^;P80;bl_0P0/;2`203<c<`80=cLg0P0o?cl305ADE080AdM70P0g=cL203<c<`80;Rh^0P0X
:2P202h^;PD09bLW0P0`<30202PX:080=cLg0P1HF5P206m_K`<0Ph>30P28R8P208V9R@80PH610P20
P80208>3P`80Ng]k0`1nOWh208>3P`80PX:20P2<S8`208n?S`80Rh^;0P2BTY8509BDU080W9bL0P2M
WId80<SPf0001P38h=P203Lg=`80EUIF0P0j>SX302l_;`80<S8b0P1IFET207=cL`80;Rh^0P0V9RH2
02TY:@<09bLW0P0T92@202LW9`@09BDU0P0P8202030`<0<0=CDe0P1`L70207UiN@80LG5a0P1bLW82
061PH080@4101@0V9RH202@T90809bLW0P0[:b/202l_;`80<c<c0P0d=3@302XZ:P80820P0P0V9RH2
02XZ:P806a/K0P0O7al202HV9P<0FUYJ0P2@T9020:f][@80MWIf0P1WIfL207]kN`80VYZJ0`31`L42
0<?3``@0YZJV0P2/[:`20;2`/080[Jf]0`2f][H20;Bd]080^KVi0P34a<@20<S8b080bl_;0P33`l<3
0<71`@80`/;20P2j^[X20;bl_080_[jn0P2i^KT20<;2`P<0a/K60P2RXZ8205QHF080ATI60P10@402
03lo?`80Bd];0`0k>c/203Hf=P80=cLg0P0i>CT203De=@80<S8b0P0e=CD503@d=080>SXj0P0c<c<2
02l_;`80<S8b0P0d=3@302h^;P80<30`0P0^;Rh202l_;`80;2`/0P0c<c<203Lg=`80?clo0`1DE5@2
04M7A`80=cLg0P0c<c<202h^;P80:2PX0P0^;Rh502LW9`80<30`0P0X:2P203Lg=`80F5QH0P1_Kfl3
08>3P`80R8R80P29RHT20861P@80P8200P23Ph<207]kN`<0OWin0P23Ph<208:2PP80S8b<0P2?Shl2
08^;R`80TY:B1@2DU9@209bLW080WIfM2038h=P000H0b>3H0P1:BTX204M7A`80;Bd]0`0`<302034a
<@80Hf=S0P1WIfL202h^;P80:b/[0P0V9RH302/[:`8092@T0P0X:2P202HV9P809bLW0P0[:b/2030`
<0<0G5aL0P1kNg/207alO080KVi^0P1?Cdl2038b<P80;Bd]0`0Z:RX202h^;P80:2PX0P0[:b/202TY
:@80;bl_0P0^;Rh202`/;0<09BDU0P0T92@202`/;080<c<c0P0M7Ad401lO7`<0>CTi0P1hN7P20:2P
X080V9RH0P20P80206e]K@80OGem0`2ZZZX20<_;b`80];Bd0P2WYjL20:f][@80/k>c0P2_[jl30;6a
/@80]kNg0P2k^k/20<C4a080b<S80P3;bl/20<G5a@<0`/;20P2n_[h20;Vi^@80]kNg0P2j^[X20;Bd
]080^k^k0`36a/H20<S8b080WIfM0P1@D5020451@@80AdM70P16ATH304M7A`80A4A40P13@d<203lo
?`80>SXj0P0e=CD203<c<`<0=SHf0P0d=3@203<c<`@0=3@d0P0a<C42038b<P<0;bl_0P0a<C42030`
<080;Rh^0P0b<S8203/k>`80<30`0P0h>3P303Ti>@80=SHf0P11@D4202`/;080;Rh^0P0X:2P202HV
9P<0;2`/0P0Y:BT202XZ:P80>3Ph0P1NGUh208>3P`80RXZ:0`2=SHd408:2PP80Ogmo0P24Q8@207em
O@80OWin0`23Ph<208:2PP80Shn?0P2<S8`208j>SP80T92@0P2ATI4309NGU`80VIVI0P2LW9`209jN
WPP0b>3H00060<SPf080BTY:0P17AdL202d];@<0<30`0P0a<C4206=SH`80IfMW0P0^;Rh202/[:`80
9RHV0`0[:b/202@T9080:2PX0P0V9RH202LW9`80:b/[0P0`<30305aLG080Ng]k0P1lO7`206i^KP80
Cdm?0P0b<S8202d];@<0:RXZ0P0^;Rh202PX:080:b/[0P0Y:BT202l_;`80;Rh^0P0/;2`302DU9@80
92@T0P0/;2`203<c<`807AdM100O7al303Ti>@80N7Qh0P2PX:0209RHV080P8200P1]KFd207emO@<0
ZZZZ0P3;bl/20;Bd]080YjNW0P2][Jd20;>c/`80[jn_0`2a/K420;Ng]`80^k^k0P34a<@20<S8b080
bl_;0P35aLD30<;2`P80_[jn0P2i^KT20;Ng]`80^[Zj0P2d];@20;^k^`<0a/K60P38b<P209fMW@80
D51@0P11@D4204M7A`80ATI60`17AdL204A4A080@d=30P0o?cl203Xj>P80=CDe0P0c<c<303Hf=P80
=3@d0P0c<c<403@d=080<C4a0P0b<S8302l_;`80<C4a0P0`<30202h^;P80<S8b0P0k>c/2030`<080
>3Ph0`0i>CT203Hf=P80@D510P0/;2`202h^;P80:2PX0P0V9RH302`/;080:BTY0P0Z:RX203Ph>080
GUiN0P23Ph<208Z:RP<0SHf=1022PX8207moO`80Q8B40P1mOGd207inOP<0Ph>30P22PX8208n?S`80
S8b<0P2>SXh2092@T080TI6A0`2GUiL209VIV@80W9bL0P2NWYh80<SPf0001P38h=P205QHF080;bl_
0P0/;2`302XZ:P80;bl_0P1MGEd206EUI@80;bl_0P0X:2P202HV9P<08R8R0P0S8b<202HV9P80<C4a
0P0`<30203Xj>P80BDU90`1mOGd207QhN080IFEU0P11@D4202l_;`80:2PX0P0U9BD502/[:`80;2`/
0P0i>CT402l_;`80<30`0P0X:2P302HV9P@092@T0P0W9bL201lO7`809BDU0P0S8b<302PX:080Cdm?
0P2ATI420:2PX080R8R80P1^KVh206IVIP<0SHf=0P2l_;`20<30`080YZJV0P2/[:`20:ZZZP80[Jf]
0`2`/;020;>c/`80^k^k0P33`l<20<K6aP80bl_;0P37alL30<W9b@80`/;20P2k^k/20;Vi^@80^k^k
102f][H30;no_`80aLG50P39bLT209nOW`80FUYJ0P18B4P204i>CP<0EUIF0P1=CDd2051@D080B4Q8
0P17AdL203`l?080=3@d0`0k>c/20410@080>3Ph0P0f=SH203Ti>@80=CDe0P0b<S8303Ph>080<C4a
0P0b<S8203De=@80<c<c100e=CD2038b<P<0<C4a0P0];Bd202/[:`80;Bd]0P0[:b/202TY:@80:2PX
0`0/;2`203De=@80A4A40P1;Bd/206YZJP80RXZ:0P2<S8`308R8R0@0P8200P1jNWX208F5Q@80Ph>3
0P1mOGd307YjNPH0RHV9102BTY8209NGU`<0Vi^K0P2NWYh209bLW080WinO2038h=P000H0b>3H0P1H
F5P202l_;`80;2`/0`0Z:RX202l_;`80GEeM0P1UIFD202l_;`80:2PX0P0V9RH3028R8P808b<S0P0V
9RH2034a<@80<30`0P0j>SX204U9B@<0OGem0P1hN7P206EUI@80@D510P0_;bl202PX:0809BDU1@0[
:b/202`/;080>CTi100_;bl2030`<080:2PX0`0V9RH402@T90809bLW0P0O7al202DU9@808b<S0`0X
:2P204m?C`80TI6A0P2PX:0208R8R080KVi^0P1VIVH308f=S@80_;bl0P30`<020:JVYP80[:b/0P2Z
ZZX20:f][@<0/;2`0P2c/k<20;^k^`80`l?30P36a/H20<_;b`80alO70`39bLT20<;2`P80^k^k0P2i
^KT20;^k^`@0][Jf0`2o_kl20<G5a@80bLW90P2OWil205YJFP80B4Q80P1>CTh305IFEP80CDe=0P1@
D50204Q8B080AdM70P0l?3`203@d=0<0>c/k0P10@40203Ph>080=SHf0P0i>CT203De=@80<S8b0`0h
>3P2034a<@80<S8b0P0e=CD203<c<`@0=CDe0P0b<S83034a<@80;Bd]0P0[:b/202d];@80:b/[0P0Y
:BT202PX:0<0;2`/0P0e=CD204A4A080Bd];0P1ZJVX208Z:RP80S8b<0`28R8P40820P080NWYj0P25
QHD208>3P`80OGem0`1jNWX608V9R@@0TY:B0P2GUiL309^KV`80WYjN0P2LW9`209nOW`P0b>3H0006
0<SPf080@4100P0W9bL202TY:@<0;Bd]0P0f=SH205UIF@80GEeM0P0[:b/202LW9`D09RHV0P0T92@2
02TY:@80;Rh^0P0`<30204=3@`80G5aL0`1fMWH2061PH080>SXj0P0Z:RX202TY:@80;2`/0P0_;bl3
038b<P80;Bd]0P0X:2P202l_;`80;Bd]0P0^;Rh203<c<`80:BTY0`0`<30202HV9P8092@T0P0S8b<2
02PX:080?Cdm0P0Q8B43028R8P809bLW0P1^KVh208n?S`80WinO0P1gMgL206EUI@<0Kfm_0P2RXZ82
0;no_`80^KVi0P2XZ:P40:ZZZP<0/;2`0P2^[Zh20;Jf]P80_kno0P34a<@20<_;b`80c<c<0`3;bl/2
0<O7a`80_;bl0P2i^KT20;Fe]@80[:b/0P2a/K430;Ng]`80_kno0P36a/H20<g=c@80YZJV0P1NGUh2
04m?C`<0DE5A0P1?Cdl205iNGP80EeMG0P1=CDd204E5A@80ATI60`1GEeL205ADE0@0@4100P13@d<2
03hn?P80>CTi0`0k>c/203Ti>@80=SHf0P0b<S8202`/;080<S8b0P0e=CD203`l?0<0=cLg0P0h>3P2
02l_;`80:b/[0P0_;bl4030`<0<0>3Ph0P1CDe<207]kN`80I6AT0P1QHF4207QhN080R8R80`21PH42
07alO080NGUi0P1jNWX207]kN`80O7al0P1gMgL307YjNP80Q8B40P29RHT208b<S080Shn?0P2FUYH2
09ZJVP<0WinO0P2QXJ4209ZJVP80WIfM2038h=P000H0b>3H0P10@40202LW9`80:BTY0`0];Bd203Hf
=P80FEUI0P1MGEd202/[:`809bLW1@0V9RH202@T9080:BTY0P0^;Rh2030`<080@d=30P1LG5`307If
MP80H61P0P0j>SX202XZ:P80:BTY0P0/;2`202l_;`<0<S8b0P0];Bd202PX:080;bl_0P0];Bd202h^
;P80<c<c0P0Y:BT3030`<0809RHV0P0T92@202<S8`80:2PX0P0m?Cd2024Q8@<08R8R0P0W9bL206i^
KP80Shn?0P2OWil207MgM`80IFEU0`1_Kfl20::RXP80_kno0P2i^KT20:RXZ0@0ZZZZ0`2`/;020:j^
[P80][Jf0P2o_kl20<C4a080bl_;0P3<c<`30<_;b`80alO70P2l_;`20;Vi^@80]KFe0P2/[:`20;6a
/@<0]kNg0P2o_kl20<K6aP80cLg=0P2VYZH205iNGP80Cdm?0`1ADE4204m?C`80GUiN0P1GEeL204e=
C@80ADE50P16ATH305MGE`80E5AD1010@40204=3@`80?Shn0P0i>CT303/k>`80>CTi0P0f=SH2038b
<P80;2`/0P0b<S8203De=@80?3`l0`0g=cL203Ph>080;bl_0P0[:b/202l_;`@0<30`0`0h>3P205=C
D`80Ng]k0P1TI6@2065QH@80N7Qh0P28R8P30861P@80O7al0P1iNGT207YjNP80Ng]k0P1lO7`207Mg
M`<0NWYj0P24Q8@208V9R@80S8b<0P2?Shl209JFUP80VYZJ0`2OWil20:6QX@80VYZJ0P2MWId80<SP
f0001P38h=P2034a<@80<30`1@0];Bd203`l?080E5AD0P1NGUh2034a<@80;bl_0P0];Bd302HV9P80
92@T0P0Y:BT203<c<`80?Shn0P1OGel2061PH0<0K6a/0P1GEeL203@d=0809BDU0P0`<30402/[:`<0
;2`/0P0^;Rh202d];@80=3@d0P0Z:RX202h^;P@0:b/[0`0Z:RX202h^;P@09bLW0P14A4@203lo?`80
7QhN0`0M7Ad2028R8P80?Shn0P21PH420::RXP80SHf=0P1ZJVX306UYJ@80O7al0P2`/;020<K6aP80
]KFe0P2TY:@20:ZZZP<0Z:RX0P2][Jd20;6a/@80^k^k0P31`L420<G5a@D0b<S80P3:b/X20<30`080
]KFe0P2c/k<20:VYZ@80[Zj^0`2][Jd20;Ng]`80_Kfm0P36a/H20<[:bP80[Jf]0P1TI6@305ADE080
EEEE0P1OGel2069RHP80H61P0P1TI6@206MWI`<0I6AT0P1PH60204Y:BP80Bd];0P19BDT204=3@`80
DU9B0`19BDT2055AD@80>c/k0P0f=SH202l_;`80>3Ph0P1ADE4206UYJ@<0GUiN0P1;Bd/2030`<080
;Rh^0P13@d<204E5A@80@4100`1DE5@206m_K`80NGUi0P20P80205MGE`80IFEU0P20P80307MgM`80
NWYj0P1eMGD207=cL`@0M7Ad0P1gMgL307YjNP80P8200P26QXH208f=S@80Ti>C0P2IVIT209bLW0<0
WIfM0P2RXZ820:2PX080WIfM2038h=P000H0b>3H0P0a<C42030`<0D0;Bd]0P0l?3`205ADE080GUiN
0P0a<C4202l_;`80;Bd]0`0V9RH202@T9080:BTY0P0c<c<203hn?P80GemO0P1PH60306a/K080EeMG
0P0d=3@202DU9@80<30`100[:b/302`/;080;Rh^0P0];Bd203@d=080:RXZ0P0^;Rh402/[:`<0:RXZ
0P0^;Rh402LW9`80A4A40P0o?cl201hN7P<07AdM0P0R8R8203hn?P80PH610P2RXZ8208f=S@80JVYZ
0`1YJFT207alO080/;2`0P36a/H20;Fe]@80Y:BT0P2ZZZX30:RXZ080[Jf]0P2a/K420;^k^`80`L71
0P35aLD50<S8b080b/[:0P30`<020;Fe]@80/k>c0P2YZJT20:j^[P<0[Jf]0P2g]kL20;fm_@80a/K6
0P3:b/X20:f][@80I6AT0`1DE5@205EEE@80GemO0P1RHV82061PH080I6AT0P1WIfL306ATI080H61P
0P1:BTX204];B`80BDU90P13@d<2059BDP<0BDU90P1ADE4203/k>`80=SHf0P0_;bl203Ph>080DE5A
0P1YJFT305iNGP80Bd];0P0`<30202h^;P80@d=30P15ADD20410@0<0E5AD0P1_Kfl207UiN@80P820
0P1GEeL206EUI@80P8200`1gMgL207YjNP80MGEe0P1cLg<407AdM080MgMg0`1jNWX20820P080QXJ6
0P2=SHd209>CT`80VIVI0P2LW9`309fMW@80XZ:R0P2PX:0209fMW@P0b>3H00060<SPf0@0;2`/0P0a
<C4302XZ:P80<30`0P1KFe/205MGE`80=3@d0P0^;Rh202TY:@<09BDU0P0S8b<202@T9080<30`0P1=
CDd206MWI`80K6a/0`1RHV8203@d=080:2PX0P0[:b/202DU9@80:2PX0P0V9RH302/[:`80=3@d0P0b
<S8202h^;P80;Bd]0P0V9RH202`/;080:RXZ0`0U9BD202PX:080;Bd]0P0k>c/205EEE@809RHV0P0L
71`301hN7P808B4Q0P0/;2`2065QH@80U9BD0P2QXJ4207=cL`<0J6QX0P1[Jf/208b<S080^KVi0P31
`L420;2`/080Y:BT0`2/[:`20:NWY`80/[:b0P2k^k/20;fm_@80`/;20P34a<@30<_;b`80b<S80P33
`l<20;Vi^@80/K6a102XZ:P30:JVYP80/[:b0P2j^[X20;bl_080a<C40P3<c<`20;:b/P<0MGEe0P1E
EED206ATI080H61P0P1XJ6P206a/K080Jf][0`1UIFD205iNGP80GemO0P1RHV8406IVIP80JFUY0`1]
KFd206][J`80EeMG0P0n?Sh202l_;`80ADE50P1_Kfl2096AT@<0Q8B40P1lO7`205=CD`80A4A40P1U
IFD2071`L080BDU90`1WIfL206i^KP80Ng]k0P1lO7`206][J`80GemO0P1eMGD307AdM080Kfm_0P1]
KFd2075aL@80L71`0P1VIVH206e]K@<0NGUi0P21PH4208Z:RP80Ti>C0P2KVi/209nOW`80VYZJ0`2N
WYh40:>SX`80XZ:R2038h=P000H0b>3H100/;2`2034a<@<0:RXZ0P0`<30205]KF`80EeMG0P0d=3@2
02h^;P80:BTY0`0U9BD202<S8`8092@T0P0`<30204e=C@80IfMW0P1/K6`3069RHP80=3@d0P0X:2P2
02/[:`809BDU0P0X:2P202HV9P<0:b/[0P0d=3@2038b<P80;Rh^0P0];Bd202HV9P80;2`/0P0Z:RX3
02DU9@80:2PX0P0];Bd203/k>`80EEEE0P0V9RH201`L70<07QhN0P0Q8B4202`/;080HF5Q0P2DU9@2
0:6QX@80Lg=c0`1XJ6P206][J`80S8b<0P2i^KT20<71`@80/;2`0P2TY:@30:b/[080YjNW0P2b/[82
0;^k^`80_Kfm0P32`/820<C4a0<0bl_;0P38b<P20<?3``80^KVi0P2a/K440:RXZ0<0YZJV0P2b/[82
0;Zj^P80_;bl0P34a<@20<c<c080/[:b0`1eMGD205EEE@80I6AT0P1PH60206QXJ080K6a/0P1[Jf/3
06EUI@80GUiN0P1OGel2069RHP@0IVIV0P1YJFT306e]K@80Jf][0P1GEeL203hn?P80;bl_0P15ADD2
06m_K`80TI6A0`24Q8@207alO080De=C0P14A4@206EUI@80L71`0P19BDT306MWI`80KVi^0P1kNg/2
07alO080Jf][0P1OGel207EeM@<0M7Ad0P1_Kfl206e]K@80LG5a0P1`L70206IVIP80KFe]0`1iNGT2
0861P@80RXZ:0P2CTi<209^KV`80WinO0P2JVYX309jNWP@0Xj>S0P2RXZ880<SPf0001P38h=P2030`
<080;bl_0P0Y:BT302XZ:P80?3`l0P1CDe<2055AD@80<S8b100V9RH302PX:080:RXZ0P0`<302034a
<@80EEEE0P1UIFD206QXJ0<0Fe]K0P0];Bd202LW9`@0:2PX0P0T92@502XZ:P80<30`0P0_;bl402PX
:080:RXZ0P0X:2P2034a<@<0;Bd]0P0h>3P2059BDP80HV9R0P0m?Cd202TY:@808R8R0`0V9RH4024Q
8@80=CDe0P1kNg/209JFUP80VIVI0`1aLG4206e]K@80MgMg0P2NWYh20;bl_080`/;20P2WYjL30:>S
X`80[:b/0P2^[Zh20:n_[`80^;Rh1030`<030<?3``80alO70P35aLD20;^k^`80[:b/0P2SXj<20:6Q
X@<0XZ:R0P2VYZH20;Ng]`80^[Zj0P32`/840<S8b0<0][Jf0P22PX8206ATI080HV9R0P1/K6`4075a
L@<0LW9b0P1hN7P207EeM@80MWIf0P1mOGd207QhN080MGEe0`1lO7`20861P@80KVi^0P1HF5P203<c
<`80FUYJ0P21PH4209FEU@<0TY:B0P2;Rh/207AdM080H61P0P1gMgL207emO@80Fe]K0`1IFET2075a
L@80Lg=c0P1lO7`2075aL@80JFUY0P1TI6@306i^KP80Hf=S0P1MGEd206ATI080HF5Q0P1XJ6P206e]
K@<0NWYj0P25QHD209RHV080W9bL0P2MWId209bLW080WIfM0`2QXJ420:JVYP80Y:BT0P2UYJD80<SP
f0001P38h=P2030`<080;bl_0P0Y:BT302XZ:P80?3`l0P1CDe<2055AD@80<S8b100V9RH302PX:080
:RXZ0P0`<302034a<@80EEEE0P1UIFD206QXJ0<0Fe]K0P0];Bd202LW9`@0:2PX0P0T92@502XZ:P80
<30`0P0_;bl402PX:080:RXZ0P0X:2P2034a<@<0;Bd]0P0h>3P2059BDP80HV9R0P0m?Cd202TY:@80
8R8R0`0V9RH4024Q8@80=CDe0P1kNg/209JFUP80VIVI0`1aLG4206e]K@80MgMg0P2NWYh20;bl_080
`/;20P2WYjL30:>SX`80[:b/0P2^[Zh20:n_[`80^;Rh1030`<030<?3``80alO70P35aLD20;^k^`80
[:b/0P2SXj<20:6QX@<0XZ:R0P2VYZH20;Ng]`80^[Zj0P32`/840<S8b0<0][Jf0P22PX8206ATI080
HV9R0P1/K6`4075aL@<0LW9b0P1hN7P207EeM@80MWIf0P1mOGd207QhN080MGEe0`1lO7`20861P@80
KVi^0P1HF5P203<c<`80FUYJ0P21PH4209FEU@<0TY:B0P2;Rh/207AdM080H61P0P1gMgL207emO@80
Fe]K0`1IFET2075aL@80Lg=c0P1lO7`2075aL@80JFUY0P1TI6@306i^KP80Hf=S0P1MGEd206ATI080
HF5Q0P1XJ6P206e]K@<0NWYj0P25QHD209RHV080W9bL0P2MWId209bLW080WIfM0`2QXJ420:JVYP80
Y:BT0P2UYJD80<SPf0001P38h=P2030`<080;bl_0P0Y:BT302XZ:P80?3`l0P1CDe<2055AD@80<S8b
100V9RH302PX:080:RXZ0P0`<302034a<@80EEEE0P1UIFD206QXJ0<0Fe]K0P0];Bd202LW9`@0:2PX
0P0T92@502XZ:P80<30`0P0_;bl402PX:080:RXZ0P0X:2P2034a<@<0;Bd]0P0h>3P2059BDP80HV9R
0P0m?Cd202TY:@808R8R0`0V9RH4024Q8@80=CDe0P1kNg/209JFUP80VIVI0`1aLG4206e]K@80MgMg
0P2NWYh20;bl_080`/;20P2WYjL30:>SX`80[:b/0P2^[Zh20:n_[`80^;Rh1030`<030<?3``80alO7
0P35aLD20;^k^`80[:b/0P2SXj<20:6QX@<0XZ:R0P2VYZH20;Ng]`80^[Zj0P32`/840<S8b0<0][Jf
0P22PX8206ATI080HV9R0P1/K6`4075aL@<0LW9b0P1hN7P207EeM@80MWIf0P1mOGd207QhN080MGEe
0`1lO7`20861P@80KVi^0P1HF5P203<c<`80FUYJ0P21PH4209FEU@<0TY:B0P2;Rh/207AdM080H61P
0P1gMgL207emO@80Fe]K0`1IFET2075aL@80Lg=c0P1lO7`2075aL@80JFUY0P1TI6@306i^KP80Hf=S
0P1MGEd206ATI080HF5Q0P1XJ6P206e]K@<0NWYj0P25QHD209RHV080W9bL0P2MWId209bLW080WIfM
0`2QXJ420:JVYP80Y:BT0P2UYJD80<SPf0001P38h=P202PX:0809BDU0P0/;2`302TY:@80=3@d0P1<
C4`20410@080=cLg0P0[:b/202LW9`<09RHV0P0`<30202PX:080>3Ph0P1GEeL406IVIP<0C4a<0P0e
=CD202XZ:P808b<S0P0R8R8202`/;080;Bd]0`0/;2`202XZ:P80<C4a0P0X:2P202LW9`80:RXZ0P0c
<c<203De=@<0@d=30P1/K6`206i^KP80@D510P0[:b/2034a<@80;bl_0`0R8R8201hN7P80820P0P0Q
8B4204Y:BP80Ng]k0P2NWYh308j>SP80Ng]k0P1bLW820861P@80Xj>S0P2o_kl20;Vi^@D0Z:RX0P2Y
ZJT20:^[Z`80/[:b0P2h^;P20;fm_@<0`L710P36a/H20<G5a@80_kno0P2e]KD20:VYZ@80VYZJ0`2Q
XJ4209bLW080/K6a0P2e]KD20;jn_P80a<C41@37alL20;fm_@80UIFE0P1/K6`206m_K`80LG5a0P1h
N7P307inOP80OGem0P1kNg/207alO080RXZ:0P27QhL208J6QP<0Q8B40P2:RXX208>3P`80Lg=c0P1?
Cdl207]kN`80Vi^K0P2MWId309^KV`80WIfM0P29RHT2075aL@80Q8B40P29RHT207IfMP<0Fe]K0P1/
K6`206EUI@80JVYZ0P1TI6@205iNGP80EeMG0`1MGEd205YJFP80DE5A0P1JFUX205aLG080HV9R0P1_
Kfl307MgM`80Shn?0P2NWYh20:FUY@80Y:BT102SXj<30:NWY`80ZZZZ0P2RXZ820:FUY@P0b>3H0006
0<SPf080:2PX0P0U9BD202`/;0<0:BTY0P0d=3@204a<C080@4100P0g=cL202/[:`809bLW0`0V9RH2
030`<080:2PX0P0h>3P205MGE`@0IVIV0`1<C4`203De=@80:RXZ0P0S8b<2028R8P80;2`/0P0];Bd3
02`/;080:RXZ0P0a<C4202PX:0809bLW0P0Z:RX203<c<`80=CDe0`13@d<206a/K080KVi^0P11@D42
02/[:`80<C4a0P0_;bl3028R8P807QhN0P0P8202024Q8@80BTY:0P1kNg/209jNWP<0SXj>0P1kNg/2
079bLP80PH610P2SXj<20;no_`80^KVi1@2XZ:P20:VYZ@80Zj^[0P2b/[820;Rh^080_Kfm0`31`L42
0<K6aP80aLG50P2o_kl20;Fe]@80ZJVY0P2JVYX30:6QX@80W9bL0P2a/K420;Fe]@80_[jn0P34a<@5
0<O7a`80_Kfm0P2EUID206a/K080Kfm_0P1aLG4207QhN0<0OWin0P1mOGd207]kN`80O7al0P2:RXX2
08N7Q`80QXJ60`24Q8@208Z:RP80Ph>30P1cLg<204m?C`80Ng]k0P2KVi/209fMW@<0Vi^K0P2MWId2
08V9R@80LG5a0P24Q8@208V9R@80MWIf0`1KFe/206a/K080IFEU0P1ZJVX206ATI080GUiN0P1GEeL3
05eMG@80FUYJ0P1ADE4205YJFP80G5aL0P1RHV8206m_K`<0MgMg0P2?Shl209jNWP80YJFU0P2TY:@4
0:>SX`<0YjNW0P2ZZZX20::RXP80YJFU2038h=P000H0b>3H0P0T92@202TY:@80<C4a0`0V9RH203@d
=080AdM70P0k>c/203hn?P80=cLg0P0^;Rh302XZ:P80;2`/0P0c<c<203Ti>@80Fe]K0P1MGEd2065Q
H@<0?3`l0P0h>3P2030`<0H092@T0P0Y:BT302PX:080:BTY0P0W9bL202XZ:P80<30`0P0a<C4205UI
F@80De=C0`1PH60208F5Q@80DU9B0P0U9BD202/[:`80BDU90P1LG5`302LW9`80820P0P0M7Ad201lO
7`80<S8b0P1RHV8208j>SP<0YjNW0P2FUYH208:2PP80LG5a0P22PX820:RXZ080`l?30`2g]kL20:6Q
X@80Z:RX0P2/[:`20;6a/@80/k>c0P2h^;P30;^k^`80alO70P36a/H20<C4a080^k^k0P2WYjL209JF
UP<0VYZJ0P2IVIT20:RXZ080Zj^[0P2j^[X20;no_`80`L710`35aLD20<O7a`80`<300P2NWYh206m_
K`80KVi^0P1kNg/508:2PP80Ph>30P25QHD208V9R@80TY:B0P2CTi<308j>SP80TY:B0P2:RXX207Ee
M@80NWYj0P2@T9020:FUY@80Xj>S0`2PX:0209^KV`80Shn?0P1oOgl20861P@80RXZ:0P1nOWh305]K
F`80J6QX0P1JFUX205iNGP80EEEE0P1DE5@204m?C`<0Bd];0P1>CTh204Q8B0@0CTi>0P1PH60207If
MP<0QhN70P2FUYH20:JVYP80ZZZZ0P2YZJT20:JVYP80Z:RX0`2WYjL20:^[Z`80ZZZZ0P2][Jd80<SP
f0001P38h=P202@T9080:BTY0P0a<C4302HV9P80=3@d0P17AdL203/k>`80?Shn0P0g=cL202h^;P<0
:RXZ0P0/;2`203<c<`80>CTi0P1KFe/205eMG@80HF5Q0`0l?3`203Ph>080<30`1P0T92@202TY:@<0
:2PX0P0Y:BT202LW9`80:RXZ0P0`<302034a<@80FEUI0P1CDe<3061PH080QHF50P1BDU8202DU9@80
:b/[0P19BDT205aLG0<09bLW0P0P820201dM7@807alO0P0b<S82069RHP80SXj>0`2WYjL209JFUP80
PX:20P1aLG4208:2PP80Z:RX0P33`l<30;Ng]`80XJ6Q0P2XZ:P20:b/[080/K6a0P2c/k<20;Rh^0<0
^k^k0P37alL20<K6aP80a<C40P2k^k/20:NWY`80UYJF0`2JVYX209VIV@80Z:RX0P2[Zj/20;Zj^P80
_kno0P31`L430<G5a@80alO70P30`<0209jNWP80Kfm_0P1^KVh207]kN`D0PX:20P23Ph<208F5Q@80
RHV90P2BTY8209>CT`<0SXj>0P2BTY8208Z:RP80MGEe0P1jNWX2092@T080YJFU0P2SXj<30:2PX080
Vi^K0P2?Shl207moO`80PH610P2:RXX207inOP<0Fe]K0P1XJ6P205YJFP80GUiN0P1EEED205ADE080
Cdm?0`1;Bd/204i>CP80B4Q8101>CTh2061PH080MWIf0`27QhL209JFUP80YZJV0P2ZZZX20:VYZ@80
YZJV0P2XZ:P30:NWY`80Zj^[0P2ZZZX20:f][@P0b>3H00060<SPf0809RHV0P0T92@202l_;`<0<c<c
0P15ADD2065QH@80C4a<0P16ATH203`l?080=cLg0`0m?Cd206=SH`80ATI60P0o?cl205]KF`80G5aL
0P13@d<302LW9`80=CDe0P0k>c/402TY:@80:2PX0P0[:b/302LW9`809BDU0P0Y:BT202<S8`80;Bd]
0P0c<c<204m?C`80GemO0`1VIVH207IfMP80E5AD0P0V9RH202d];@80Fe]K0P1IFET302h^;P80:RXZ
0P0O7al201dM7@8092@T0P0i>CT207EeM@<0VYZJ0P2WYjL208R8R080KVi^0P1XJ6P208n?S`80]kNg
0`33`l<20:b/[080YjNW0P2ZZZX20:f][@@0];Bd0`2n_[h20<;2`P80a/K60P37alL20;no_`80[:b/
0P2SXj<509JFUP80XJ6Q0P2YZJT20;>c/`80_;bl0P2n_[h30<C4a080aLG50P37alL20<71`@80Zj^[
0P1lO7`207AdM0<0N7Qh0P1jNWX208J6QP80RHV90P2>SXh209NGU`80VIVI0`2JVYX209FEU@80SXj>
0P1kNg/209JFUP80WIfM0P2OWil20:>SX`<0X:2P0P2JVYX208^;R`80QHF5101nOWh207=cL`D0HF5Q
0P1FEUH205=CD`@0B4Q80P14A4@503lo?`80@D510P1?Cdl205]KF`80NGUi0P28R8P309FEU@80XJ6Q
0P2WYjL20:^[Z`80YjNW0P2[Zj/20:BTY0<0YjNW102[Zj/20:f][@P0b>3H00060<SPf0809RHV0P0T
92@202l_;`<0<c<c0P15ADD2065QH@80C4a<0P16ATH203`l?080=cLg0`0m?Cd206=SH`80ATI60P0o
?cl205]KF`80G5aL0P13@d<302LW9`80=CDe0P0k>c/402TY:@80:2PX0P0[:b/302LW9`809BDU0P0Y
:BT202<S8`80;Bd]0P0c<c<204m?C`80GemO0`1VIVH207IfMP80E5AD0P0V9RH202d];@80Fe]K0P1I
FET302h^;P80:RXZ0P0O7al201dM7@8092@T0P0i>CT207EeM@<0VYZJ0P2WYjL208R8R080KVi^0P1X
J6P208n?S`80]kNg0`33`l<20:b/[080YjNW0P2ZZZX20:f][@@0];Bd0`2n_[h20<;2`P80a/K60P37
alL20;no_`80[:b/0P2SXj<509JFUP80XJ6Q0P2YZJT20;>c/`80_;bl0P2n_[h30<C4a080aLG50P37
alL20<71`@80Zj^[0P1lO7`207AdM0<0N7Qh0P1jNWX208J6QP80RHV90P2>SXh209NGU`80VIVI0`2J
VYX209FEU@80SXj>0P1kNg/209JFUP80WIfM0P2OWil20:>SX`<0X:2P0P2JVYX208^;R`80QHF5101n
OWh207=cL`D0HF5Q0P1FEUH205=CD`@0B4Q80P14A4@503lo?`80@D510P1?Cdl205]KF`80NGUi0P28
R8P309FEU@80XJ6Q0P2WYjL20:^[Z`80YjNW0P2[Zj/20:BTY0<0YjNW102[Zj/20:f][@P0b>3H0006
0<SPf0809BDU0P0X:2P502LW9`80<c<c0P1=CDd203lo?`80@T920P0j>SX202/[:`<0?Cdm0P1CDe<2
02XZ:P80<c<c0P1:BTX205ADE080=3@d0`0Y:BT203Hf=P80?Shn0P0Z:RX202PX:0808b<S0P0/;2`3
02TY:@80820P0P0X:2P202TY:@80=3@d0P1@D50206IVIP80FEUI0`0m?Cd206UYJ@80HF5Q0P0U9BD2
03<c<`80GEeM0P0j>SX302d];@80?Shn0P0R8R8202PX:0809bLW0P0Z:RX2051@D0<0QHF50P2RXZ82
092@T080LW9b0P1TI6@207=cL`80VYZJ0`2o_kl20;fm_@80YZJV0P2NWYh20:ZZZP80/;2`0P2b/[83
0;Rh^080^k^k0P31`L420<K6aP80a<C40P2c/k<20:JVYP<0Vi^K0P2DU9@209bLW080YJFU0P2XZ:P2
0;:b/P80^k^k0`2m_Kd20<30`080aLG50P33`l<20;fm_@80/K6a0P28R8P307IfMP80NGUi0P23Ph<2
08^;R`@0TI6A0P2HV9P509VIV@80V9RH0P2BTY8209fMW@80XZ:R0P2KVi/209JFUP<0UIFE0P2?Shl2
0861P@80NWYj0P1]KFd2061PH080GEeM0`1BDU8204I6AP80CDe=0P13@d<20451@@80?clo0P0i>CT3
04I6AP80Cdm?0P1IFET206MWI`80PH610P2FUYH20:2PX0<0ZJVY0P2_[jl20:^[Z`80ZZZZ0P2][Jd2
0:^[Z`80Z:RX0`2[Zj/20:ZZZP80Zj^[0P2`/;080<SPf0001P38h=P202DU9@80:2PX1@0W9bL203<c
<`80CDe=0P0o?cl20492@P80>SXj0P0[:b/303dm?@80De=C0P0Z:RX203<c<`80BTY:0P1DE5@203@d
=0<0:BTY0P0f=SH203hn?P80:RXZ0P0X:2P202<S8`80;2`/0`0Y:BT2020P8080:2PX0P0Y:BT203@d
=080D51@0P1VIVH205UIF@<0?Cdm0P1YJFT2065QH@809BDU0P0c<c<205eMG@80>SXj0`0];Bd203hn
?P808R8R0P0X:2P202LW9`80:RXZ0P1@D50308F5Q@80XZ:R0P2@T902079bLP80I6AT0P1cLg<209ZJ
VP<0_kno0P2m_Kd20:JVYP80WYjN0P2ZZZX20;2`/080/[:b0`2h^;P20;^k^`80`L710P36a/H20<C4
a080/k>c0P2VYZH309^KV`80U9BD0P2LW9`20:FUY@80Z:RX0P2b/[820;^k^`<0_Kfm0P30`<020<G5
a@80`l?30P2m_Kd20;6a/@80R8R80`1fMWH207UiN@80Ph>30P2;Rh/4096AT@80V9RH1@2IVIT209RH
V080TY:B0P2MWId20::RXP80Vi^K0P2FUYH309FEU@80Shn?0P21PH4207YjNP80KFe]0P1PH60205eM
G@<0DU9B0P16ATH204e=C@80@d=30P11@D4203lo?`80>CTi0`16ATH204m?C`80FEUI0P1WIfL20861
P@80UYJF0P2PX:030:VYZ@80[jn_0P2[Zj/20:ZZZP80[Jf]0P2[Zj/20:RXZ0<0Zj^[0P2ZZZX20:^[
Z`80/;2`2038h=P000H0b>3H0P0Q8B4202PX:0809bLW0`0V9RH202XZ:P80?3`l0P1<C4`20492@P80
CTi>0P1<C4`303/k>`80=CDe0P0Y:BT203/k>`80Cdm?0P18B4P203De=@<0<30`0P0[:b/203`l?080
;Bd]100W9bL202PX:0<0:RXZ0P0W9bL202XZ:P80;Rh^0P1:BTX206e]K@80H61P0P0c<c<302PX:080
CTi>0P1SHf<202PX:080Bd];0P1LG5`202/[:`<0=SHf0P1>CTh202PX:0808R8R0P0M7Ad202l_;`80
>SXj0`1^KVh208f=S@80WYjN0P21PH4206EUI@80HV9R0P1iNGT309^KV`80_kno0P2a/K420:6QX@80
Zj^[0P2_[jl20;2`/0<0]kNg0P2i^KT20;Zj^P80`l?30P37alL20;fm_@80[jn_0`2KVi/209NGU`80
VYZJ0P2LW9`20:^[Z`80[:b/0P2l_;`30;fm_@80^[Zj0P36a/H40<?3``80`<300P2i^KT309:BTP80
Ng]k0P1mOGd208B4Q080RHV90P2?Shl209JFUP<0W9bL102FUYH409NGU`80U9BD0P2ATI4208b<S0<0
Q8B40P1mOGd207AdM080J6QX0P1LG5`204];B`80@d=30`0k>c/204I6AP@0?Cdm0P14A4@204a<C080
F5QH0`1NGUh2075aL@80Q8B40P2=SHd209^KV`80YjNW0P2YZJT30:n_[`80/;2`0P2][Jd20:n_[`80
]KFe0P2a/K420:j^[P<0[:b/102^[Zh20;6a/@P0b>3H00060<SPf0808B4Q0P0X:2P202LW9`<09RHV
0P0Z:RX203`l?080C4a<0P12@T8204i>CP80C4a<0`0k>c/203De=@80:BTY0P0k>c/204m?C`80B4Q8
0P0e=CD3030`<080:b/[0P0l?3`202d];@@09bLW0P0X:2P302XZ:P809bLW0P0Z:RX202h^;P80BTY:
0P1]KFd2061PH080<c<c0`0X:2P204i>CP80Hf=S0P0X:2P204];B`80G5aL0P0[:b/303Hf=P80CTi>
0P0X:2P2028R8P807AdM0P0_;bl203Xj>P<0KVi^0P2=SHd209jNWP80PH610P1UIFD2069RHP80NGUi
0`2KVi/20;no_`80/K6a0P2QXJ420:^[Z`80[jn_0P2`/;030;Ng]`80^KVi0P2j^[X20<?3``80alO7
0P2m_Kd20:n_[`<0Vi^K0P2GUiL209ZJVP80W9bL0P2[Zj/20:b/[080_;bl0`2m_Kd20;Zj^P80a/K6
1033`l<20<30`080^KVi0`2BTY8207]kN`80OGem0P24Q8@208V9R@80Shn?0P2FUYH309bLW0@0UYJF
102GUiL209BDU080TI6A0P2<S8`308B4Q080OGem0P1dM7@206QXJ080G5aL0P1;Bd/204=3@`<0>c/k
0P16ATH403dm?@80A4A40P1<C4`205QHF0<0GUiN0P1aLG4208B4Q080SHf=0P2KVi/20:NWY`80ZJVY
0`2_[jl20;2`/080[Jf]0P2_[jl20;Fe]@80/K6a0P2^[Zh30:b/[0@0[Zj^0P2a/K480<SPf0001P38
h=P202@T9080:b/[0P0d=3@302<S8`80:RXZ0P0d=3@203De=@80?3`l0P1FEUH20492@P<0<S8b0P0k
>c/203@d=080AdM70P16ATH203Ti>@80;bl_0`0Z:RX202`/;080>SXj0P0g=cL202l_;`80<S8b0P0[
:b/5030`<080;2`/0P12@T82061PH080J6QX0P1>CTh204I6AP<0<S8b0P0l?3`2061PH080;Rh^0P1K
Fe/205=CD`809BDU0`0];Bd205EEE@80<C4a0P0O7al202LW9`809BDU0P0S8b<303hn?P80MGEe0P2G
UiL209nOW`80KVi^0P1KFe/2061PH0<0Ng]k0P2ZZZX20;Vi^@80[Zj^0P2VYZH20:f][@80[:b/0`2d
];@20;:b/P80^;Rh0P30`<020<;2`P80a<C40P2e]KD30:FUY@80VYZJ0P2LW9`209RHV080WinO0P2X
Z:P20;Jf]P<0_;bl0P2k^k/20;fm_@80`/;20P33`l<20<;2`P80`L710`2j^[X209VIV@80NGUi0P1f
MWH207YjNP80PX:20P29RHT3092@T080S8b<0P2>SXh208f=S@80RHV90P1oOgl207UiN@80MGEe0`1^
KVh206][J`80I6AT0P1KFe/2051@D0@0?clo0`14A4@204M7A`80BDU90P1;Bd/205UIF@80JVYZ0P1_
Kfl307YjNP80SHf=0P2NWYh20:FUY@80Z:RX0P2`/;020;>c/`<0/;2`0P2_[jl20;6a/@80/k>c0P2d
];@20;>c/`80];Bd0`2`/;060:b/[0P0b>3H00060<SPf08092@T0P0[:b/203@d=0<08b<S0P0Z:RX2
03@d=080=CDe0P0l?3`205IFEP80@T920`0b<S8203/k>`80=3@d0P17AdL204I6AP80>CTi0P0_;bl3
02XZ:P80;2`/0P0j>SX203Lg=`80;bl_0P0b<S8202/[:`D0<30`0P0/;2`20492@P80H61P0P1XJ6P2
04i>CP80ATI60`0b<S8203`l?080H61P0P0^;Rh205]KF`80De=C0P0U9BD302d];@80EEEE0P0a<C42
01lO7`809bLW0P0U9BD202<S8`<0?Shn0P1eMGD209NGU`80WinO0P1^KVh205]KF`80H61P0`1kNg/2
0:ZZZP80^KVi0P2^[Zh20:JVYP80[Jf]0P2/[:`30;Bd]080/[:b0P2h^;P20<30`080`/;20P34a<@2
0;Fe]@<0YJFU0P2JVYX209bLW080V9RH0P2OWil20:RXZ080][Jf0`2l_;`20;^k^`80_Kfm0P32`/82
0<?3``80`/;20P31`L430;Zj^P80VIVI0P1iNGT207IfMP80NWYj0P22PX8208V9R@<0T92@0P2<S8`2
08j>SP80SHf=0P29RHT207moO`80NGUi0P1eMGD306i^KP80Jf][0P1TI6@205]KF`80D51@100o?cl3
04A4A080AdM70P19BDT204];B`80FEUI0P1ZJVX206m_K`<0NWYj0P2=SHd209jNWP80YJFU0P2XZ:P2
0;2`/080/k>c0`2`/;020:n_[`80/K6a0P2c/k<20;Bd]080/k>c0P2d];@30;2`/0H0[:b/2038h=P0
00H0b>3H100X:2P203Hf=P<0;Rh^0P0W9bL4030`<080;bl_0P0h>3P203Lg=`<0>3Ph0P0d=3@203lo
?`80BTY:0P0i>CT203<c<`80:BTY0`0`<30202l_;`80=SHf0P0i>CT202d];@80:b/[0P0W9bL302l_
;`80B4Q80P16ATH204m?C`80FUYJ0P1BDU82038b<PD0?Cdm0P0d=3@205MGE`80<c<c0P1YJFT204i>
CP809RHV0`0_;bl205aLG080=3@d0P0M7Ad402LW9`80820P0`0Z:RX204a<C080Q8B40P2VYZH208>3
P`80K6a/0P1LG5`306ATI080R8R80P2`/;020;no_`80[Zj^0P2YZJT20:ZZZP<0[:b/0P2_[jl20;Fe
]@80^;Rh0P2n_[h20<;2`P80^k^k0`2YZJT209NGU`80VYZJ0P2HV9P409jNWP80][Jf0`2j^[X40;jn
_P80`/;20P34a<@20<;2`P80`L710`32`/820<71`@80WYjN0P1fMWH206IVIP80J6QX0P1^KVh307If
MP80N7Qh0P1iNGT207MgM`80MGEe0P1/K6`206IVIP80H61P0`1WIfL206EUI@80Fe]K0P1CDe<204e=
C@80EeMG0P1EEED305eMG@80IFEU0P1[Jf/2079bLP80OGem0P25QHD209:BTP<0V9RH0P2OWil20:NW
Y`80[Zj^0P2`/;020;Vi^@D0]KFe0P2`/;020:f][@80/K6a0P2c/k<20;:b/P80/K6a1@2_[jl20:f]
[@80ZZZZ2038h=P000H0b>3H100X:2P203Hf=P<0;Rh^0P0W9bL4030`<080;bl_0P0h>3P203Lg=`<0
>3Ph0P0d=3@203lo?`80BTY:0P0i>CT203<c<`80:BTY0`0`<30202l_;`80=SHf0P0i>CT202d];@80
:b/[0P0W9bL302l_;`80B4Q80P16ATH204m?C`80FUYJ0P1BDU82038b<PD0?Cdm0P0d=3@205MGE`80
<c<c0P1YJFT204i>CP809RHV0`0_;bl205aLG080=3@d0P0M7Ad402LW9`80820P0`0Z:RX204a<C080
Q8B40P2VYZH208>3P`80K6a/0P1LG5`306ATI080R8R80P2`/;020;no_`80[Zj^0P2YZJT20:ZZZP<0
[:b/0P2_[jl20;Fe]@80^;Rh0P2n_[h20<;2`P80^k^k0`2YZJT209NGU`80VYZJ0P2HV9P409jNWP80
][Jf0`2j^[X40;jn_P80`/;20P34a<@20<;2`P80`L710`32`/820<71`@80WYjN0P1fMWH206IVIP80
J6QX0P1^KVh307IfMP80N7Qh0P1iNGT207MgM`80MGEe0P1/K6`206IVIP80H61P0`1WIfL206EUI@80
Fe]K0P1CDe<204e=C@80EeMG0P1EEED305eMG@80IFEU0P1[Jf/2079bLP80OGem0P25QHD209:BTP<0
V9RH0P2OWil20:NWY`80[Zj^0P2`/;020;Vi^@D0]KFe0P2`/;020:f][@80/K6a0P2c/k<20;:b/P80
/K6a1@2_[jl20:f][@80ZZZZ2038h=P000H0b>3H100X:2P203Hf=P<0;Rh^0P0W9bL4030`<080;bl_
0P0h>3P203Lg=`<0>3Ph0P0d=3@203lo?`80BTY:0P0i>CT203<c<`80:BTY0`0`<30202l_;`80=SHf
0P0i>CT202d];@80:b/[0P0W9bL302l_;`80B4Q80P16ATH204m?C`80FUYJ0P1BDU82038b<PD0?Cdm
0P0d=3@205MGE`80<c<c0P1YJFT204i>CP809RHV0`0_;bl205aLG080=3@d0P0M7Ad402LW9`80820P
0`0Z:RX204a<C080Q8B40P2VYZH208>3P`80K6a/0P1LG5`306ATI080R8R80P2`/;020;no_`80[Zj^
0P2YZJT20:ZZZP<0[:b/0P2_[jl20;Fe]@80^;Rh0P2n_[h20<;2`P80^k^k0`2YZJT209NGU`80VYZJ
0P2HV9P409jNWP80][Jf0`2j^[X40;jn_P80`/;20P34a<@20<;2`P80`L710`32`/820<71`@80WYjN
0P1fMWH206IVIP80J6QX0P1^KVh307IfMP80N7Qh0P1iNGT207MgM`80MGEe0P1/K6`206IVIP80H61P
0`1WIfL206EUI@80Fe]K0P1CDe<204e=C@80EeMG0P1EEED305eMG@80IFEU0P1[Jf/2079bLP80OGem
0P25QHD209:BTP<0V9RH0P2OWil20:NWY`80[Zj^0P2`/;020;Vi^@D0]KFe0P2`/;020:f][@80/K6a
0P2c/k<20;:b/P80/K6a1@2_[jl20:f][@80ZZZZ2038h=P000H0b>3H0P0V9RH202/[:`80@D511@0/
;2`202h^;P80>3Ph0P0d=3@203<c<`80>CTi0`0Z:RX203@d=080=CDe0P0j>SX2030`<080:b/[0P0_
;bl302XZ:P80;2`/0P0e=CD203Xj>P80=cLg0P0^;Rh2038b<P<0>3Ph0P0i>CT203De=@80;Rh^0P1:
BTX204I6AP80;bl_0P0[:b/302`/;080>3Ph0P1PH60204U9B@80K6a/0P0n?Sh2030`<0<0<S8b0P1O
Gel20492@P80:RXZ0P0U9BD2020P80807AdM0`0S8b<202/[:`80KFe]0P2;Rh/209VIV@80PX:20P1S
Hf<305eMG@80K6a/0P2?Shl20;Fe]@80`L710P2/[:`20:FUY@<0[:b/0P2^[Zh20;>c/`80/[:b0P2o
_kl20<30`080^k^k0`2][Jd209ZJVP80WIfM0P2IVIT209bLW080WIfM0P2][Jd30;Rh^080_Kfm0P30
`<020<?3``80a<C40P36a/H20<G5a@D0`<300P2o_kl20:ZZZP80N7Qh101EEED305MGE`80F5QH101Q
HF42061PH080IVIV0P1SHf<205]KF`<0H61P0P1XJ6P406ATI080EUIF0P1VIVH206i^KP<0Lg=c0P1j
NWX207alO080QXJ60P2@T90209bLW080Xj>S0`2VYZH20:f][@80[jn_102c/k<40;Jf]P<0]KFe0P2a
/K420;:b/P80/k>c102`/;020:n_[`<0]KFe0P2][Jd20:ZZZP80[jn_2038h=P000H0b>3H0P0V9RH2
02/[:`80@D511@0/;2`202h^;P80>3Ph0P0d=3@203<c<`80>CTi0`0Z:RX203@d=080=CDe0P0j>SX2
030`<080:b/[0P0_;bl302XZ:P80;2`/0P0e=CD203Xj>P80=cLg0P0^;Rh2038b<P<0>3Ph0P0i>CT2
03De=@80;Rh^0P1:BTX204I6AP80;bl_0P0[:b/302`/;080>3Ph0P1PH60204U9B@80K6a/0P0n?Sh2
030`<0<0<S8b0P1OGel20492@P80:RXZ0P0U9BD2020P80807AdM0`0S8b<202/[:`80KFe]0P2;Rh/2
09VIV@80PX:20P1SHf<305eMG@80K6a/0P2?Shl20;Fe]@80`L710P2/[:`20:FUY@<0[:b/0P2^[Zh2
0;>c/`80/[:b0P2o_kl20<30`080^k^k0`2][Jd209ZJVP80WIfM0P2IVIT209bLW080WIfM0P2][Jd3
0;Rh^080_Kfm0P30`<020<?3``80a<C40P36a/H20<G5a@D0`<300P2o_kl20:ZZZP80N7Qh101EEED3
05MGE`80F5QH101QHF42061PH080IVIV0P1SHf<205]KF`<0H61P0P1XJ6P406ATI080EUIF0P1VIVH2
06i^KP<0Lg=c0P1jNWX207alO080QXJ60P2@T90209bLW080Xj>S0`2VYZH20:f][@80[jn_102c/k<4
0;Jf]P<0]KFe0P2a/K420;:b/P80/k>c102`/;020:n_[`<0]KFe0P2][Jd20:ZZZP80[jn_2038h=P0
00H0b>3H0P0S8b<202HV9P80?Cdm0`0b<S8203<c<`80>CTi0P0o?cl203Ti>@80=3@d1`0_;bl203<c
<`80@4100P0b<S8202PX:080<C4a0`0Y:BT202XZ:P80:b/[0P0d=3@202`/;080;Rh^0P0e=CD303<c
<`80=CDe0P0a<C4202`/;080AdM70P0g=cL202XZ:PD0:BTY0P0`<30206EUI@80EEEE0P1/K6`203Ti
>@80:BTY0`0b<S8405]KF`80=cLg0P0b<S8202h^;P80:BTY0`0N7Qh202<S8`80>c/k0P1iNGT208b<
S080X:2P0P1hN7P305mOG`80I6AT0P1bLW8209NGU`80a/K60P2j^[X20:VYZ@<0Zj^[0P2VYZH20:NW
Y`80/;2`102i^KT20;Ng]`<0Zj^[0P2SXj<209ZJVP80Vi^K0P2FUYH209^KV`80Y:BT0`2c/k<20;fm
_@80`l?30P31`L420<30`080`/;20P35aLD30<30`080_[jn0P2k^k/20;Vi^@80/;2`0P29RHT204m?
C`<0ADE50P17AdL205EEE@80FEUI0P1MGEd206EUI@80JVYZ0P1^KVh306QXJ080M7Ad0P1iNGT207em
O@80OWin0P1mOGd208B4Q0<0QhN70P29RHT209BDU080V9RH0P2NWYh40:JVYP<0[:b/0P2a/K420:n_
[`80]KFe102d];@20;Ng]`D0]KFe0P2d];@20:j^[P@0/k>c1@2_[jl20;:b/P80[jn_0P2d];@80<SP
f0001P38h=P202<S8`809RHV0P0m?Cd3038b<P80<c<c0P0i>CT203lo?`80>CTi0P0d=3@702l_;`80
<c<c0P10@402038b<P80:2PX0P0a<C4302TY:@80:RXZ0P0[:b/203@d=080;2`/0P0^;Rh203De=@<0
<c<c0P0e=CD2034a<@80;2`/0P17AdL203Lg=`80:RXZ1@0Y:BT2030`<080IFEU0P1EEED206a/K080
>CTi0P0Y:BT3038b<P@0Fe]K0P0g=cL2038b<P80;Rh^0P0Y:BT301hN7P808b<S0P0k>c/207UiN@80
S8b<0P2PX:0207QhN0<0GemO0P1TI6@2079bLP80UiNG0P36a/H20;Zj^P80ZJVY0`2[Zj/20:JVYP80
YjNW0P2`/;040;Vi^@80]kNg0`2[Zj/20:>SX`80VYZJ0P2KVi/209JFUP80Vi^K0P2TY:@30;>c/`80
_Kfm0P33`l<20<71`@80`<300P32`/820<G5a@<0`<300P2n_[h20;^k^`80^KVi0P2`/;0208V9R@80
Cdm?0`15ADD204M7A`80EEEE0P1IFET205eMG@80IFEU0P1ZJVX206i^KP<0J6QX0P1dM7@207UiN@80
OGem0P1nOWh207emO@80Q8B40`27QhL208V9R@80U9BD0P2HV9P209jNWP@0YZJV0`2/[:`20;6a/@80
[jn_0P2e]KD40;Bd]080]kNg1@2e]KD20;Bd]080[Zj^102c/k<50:n_[`80/[:b0P2_[jl20;Bd]0P0
b>3H00060<SPf0809RHV0P0R8R82030`<0<0=cLg0P0b<S8203De=@80B4Q80P1=CDd204I6AP80?Shn
0`0l?3`2038b<P80?Shn0P13@d<202d];@80:2PX0P0/;2`302PX:0809BDU0P0Z:RX202PX:080;Bd]
0P0a<C42038b<P<0<c<c0P0j>SX203<c<`80;bl_0P1GEeL204M7A`@092@T0`0V9RH202`/;080E5AD
0P1UIFD206a/K080?3`l1@0S8b<204Y:BP80KFe]0P11@D4204E5A@80D51@0P0k>c/302LW9`808B4Q
0P0Z:RX204E5A@80OGem0P2MWId209NGU`<0M7Ad0P1KFe/206EUI@80OGem0P2ZZZX20<K6aP80^KVi
0`2TY:@20:RXZ080YjNW0P2[Zj/40;>c/`80]kNg0`2[Zj/20:JVYP80VYZJ0P2LW9`209JFUP80WIfM
0P2VYZH30;:b/P80^;Rh1P30`<020;jn_P80a/K60`2o_kl20;jn_P80_kno0P2k^k/20;Jf]P80^;Rh
0P2SXj<306e]K@80CTi>0P1:BTX2059BDP80IVIV0P1eMGD206i^KPD0NGUi0P26QXH208V9R@80SXj>
0P2CTi<2096AT@80U9BD1@2HV9P209jNWP80Y:BT0P2[Zj/20:ZZZPD0[Zj^0P2ZZZX20;6a/@80];Bd
0P2`/;020;Bd]080][Jf0`2d];@20;2`/080];Bd102^[Zh20;6a/@80/;2`0`2a/K420;:b/P80[jn_
0P2e]KD80<SPf0001P38h=P202HV9P808R8R0P0`<30303Lg=`80<S8b0P0e=CD204Q8B080CDe=0P16
ATH203hn?P<0?3`l0P0b<S8203hn?P80@d=30P0];Bd202PX:080;2`/0`0X:2P202DU9@80:RXZ0P0X
:2P202d];@80<C4a0P0b<S8303<c<`80>SXj0P0c<c<202l_;`80EeMG0P17AdL402@T90<09RHV0P0/
;2`205ADE080IFEU0P1/K6`203`l?0D08b<S0P1:BTX206e]K@80@D510P15ADD2051@D080>c/k0`0W
9bL2024Q8@80:RXZ0P15ADD207emO@80WIfM0P2GUiL307AdM080Fe]K0P1UIFD207emO@80ZZZZ0P36
a/H20;Vi^@<0Y:BT0P2XZ:P20:NWY`80Zj^[102c/k<20;Ng]`<0Zj^[0P2VYZH209ZJVP80W9bL0P2F
UYH209fMW@80YZJV0`2b/[820;Rh^0H0`<300P2n_[h20<K6aP<0_kno0P2n_[h20;no_`80^k^k0P2f
][H20;Rh^080Xj>S0`1]KFd204i>CP80BTY:0P1BDU8206IVIP80MGEe0P1^KVh507UiN@80QXJ60P29
RHT208j>SP80Ti>C0P2ATI4209BDU0D0V9RH0P2NWYh20:BTY080Zj^[0P2ZZZX50:j^[P80ZZZZ0P2a
/K420;Bd]080/;2`0P2d];@20;Jf]P<0];Bd0P2`/;020;Bd]0@0[Zj^0P2a/K420;2`/0<0/K6a0P2b
/[820:n_[`80]KFe2038h=P000H0b>3H0P0R8R8202TY:@80;bl_0`0c<c<202TY:@80:RXZ0P0b<S82
0410@080FUYJ0P1QHF4305mOG`80D51@0P13@d<204I6AP@0>SXj0P0a<C4302/[:`809bLW0P0/;2`2
02TY:@80:RXZ0P0/;2`203@d=0<0=CDe0P0h>3P202/[:`80<C4a0P1JFUX205QHF080;Bd]0P0S8b<5
02HV9P80?3`l0P1YJFT206=SH`80?Cdm0P0U9BD302@T9080>SXj0P1ZJVX20451@@80;2`/0P0d=3@2
0410@0<0=SHf0P0^;Rh202l_;`80:b/[0P1HF5P208>3P`80YZJV0`29RHT2061PH080GEeM0P1QHF42
08N7Q`80];Bd0P32`/830:n_[`80Xj>S0P2VYZH20;2`/080[:b/0P2c/k<20;:b/P<0[Zj^0P2UYJD2
0:JVYP80Vi^K0P2LW9`209jNWP80YjNW0`2c/k<20;Ng]`80_kno102n_[h20;Zj^P80_kno0`2m_Kd2
0;Vi^@80];Bd0P2i^KT20;Bd]080][Jf0P2e]KD30:FUY@80RHV90P1/K6`206ATI080J6QX0P1lO7`2
07]kN`D0RXZ:0P2>SXh209>CT`80U9BD0P2IVIT20:2PX0D0Xj>S102UYJD20:RXZ080ZJVY0P2VYZH2
0:j^[P<0/K6a0P2_[jl20;:b/P80[jn_0P2`/;040;>c/`<0];Bd0P2b/[820;2`/080/[:b0P2`/;02
0;6a/@80[jn_0`2d];@20;Ng]`80]KFe0P2h^;P80<SPf0001P38h=P2028R8P80:BTY0P0_;bl303<c
<`80:BTY0P0Z:RX2038b<P80@4100P1JFUX2065QH@<0GemO0P1@D50204=3@`80ATI6100j>SX2034a
<@<0:b/[0P0W9bL202`/;080:BTY0P0Z:RX202`/;080=3@d0`0e=CD203Ph>080:b/[0P0a<C4205YJ
FP80F5QH0P0];Bd202<S8`D09RHV0P0l?3`206UYJ@80Hf=S0P0m?Cd202DU9@<092@T0P0j>SX206YZ
JP80@D510P0/;2`203@d=080@4100`0f=SH202h^;P80;bl_0P0[:b/205QHF080Ph>30P2VYZH308V9
R@80H61P0P1MGEd2065QH@80QhN70P2d];@20<;2`P<0[jn_0P2SXj<20:JVYP80/;2`0P2/[:`20;>c
/`80/[:b0`2^[Zh20:FUY@80YZJV0P2KVi/209bLW080WYjN0P2WYjL30;>c/`80]kNg0P2o_kl40;jn
_P80^[Zj0P2o_kl30;fm_@80^KVi0P2d];@20;Vi^@80];Bd0P2f][H20;Fe]@<0YJFU0P29RHT206a/
K080I6AT0P1XJ6P207alO080Ng]k1@2:RXX208j>SP80Ti>C0P2DU9@209VIV@80X:2P1@2SXj<40:FU
Y@80Z:RX0P2YZJT20:JVYP80[Zj^0`2a/K420:n_[`80/[:b0P2_[jl20;2`/0@0/k>c0`2d];@20;:b
/P80/;2`0P2b/[820;2`/080/K6a0P2_[jl30;Bd]080]kNg0P2e]KD20;Rh^0P0b>3H00060<SPf080
9RHV0P0Q8B4202DU9@<0=cLg0P0U9BD202PX:080;bl_0P0h>3P204Q8B080De=C0`1VIVH206i^KP80
EUIF0P1@D50205IFEP80@d=30P0n?Sh3034a<@@0;2`/100];Bd2034a<@80?Shn0`0h>3P203<c<`80
;Bd]0P0[:b/204M7A`80Kfm_0P0_;bl202LW9`<0:2PX0P0V9RH203Ph>080I6AT0P1eMGD203dm?@80
:BTY0`0U9BD202`/;080G5aL0P1VIVH202XZ:P80:b/[0P0`<30303Ph>080<S8b0P0V9RH202@T9080
;Rh^0P1TI6@208j>SP<0VYZJ0P1cLg<205mOG`80FEUI0P1YJFT209BDU080];Bd0`2i^KT20:b/[080
X:2P0P2YZJT20:JVYP80/;2`0P2[Zj/30:j^[P80ZJVY0P2UYJD209nOW`80XJ6Q0P2NWYh20:NWY`<0
/;2`0P2m_Kd20;no_`80_[jn102j^[X20;Vi^@<0_kno0P2l_;`20;Ng]`80/[:b0P2f][H20;:b/P80
/;2`0`2d];@20:b/[080XZ:R0P2<S8`207alO080QHF50P2;Rh/209>CT`<0UiNG0P2FUYH209jNWP80
WinO0P2RXZ820:6QX@80Xj>S0`2TY:@20:NWY`80Y:BT0P2VYZH20:n_[`80ZJVY0P2XZ:P30:j^[P80
/;2`0P2^[Zh40;6a/@80/[:b0P2a/K430;>c/`80][Jf0P2g]kL20:n_[`80]KFe0P2b/[820:n_[`D0
][Jf102g]kL80<SPf0001P38h=P202HV9P808B4Q0P0U9BD303Lg=`809BDU0P0X:2P202l_;`80>3Ph
0P18B4P205=CD`<0IVIV0P1^KVh205IFEP80D51@0P1FEUH204=3@`80?Shn0`0a<C4402`/;0@0;Bd]
0P0a<C4203hn?P<0>3Ph0P0c<c<202d];@80:b/[0P17AdL206m_K`80;bl_0P0W9bL302PX:0809RHV
0P0h>3P206ATI080MGEe0P0m?Cd202TY:@<09BDU0P0/;2`205aLG080IVIV0P0Z:RX202/[:`80<30`
0`0h>3P2038b<P809RHV0P0T92@202h^;P80I6AT0P2>SXh309ZJVP80Lg=c0P1OGel205UIF@80JFUY
0P2DU9@20;Bd]0<0^KVi0P2/[:`20:2PX080ZJVY0P2VYZH20;2`/080Zj^[0`2^[Zh20:VYZ@80YJFU
0P2OWil20:6QX@80WYjN0P2WYjL30;2`/080_Kfm0P2o_kl20;jn_P@0^[Zj0P2i^KT30;no_`80_;bl
0P2g]kL20;:b/P80][Jf0P2b/[820;2`/0<0];Bd0P2/[:`20::RXP80S8b<0P1lO7`208F5Q@80Rh^;
0P2CTi<309NGU`80UYJF0P2NWYh209nOW`80XZ:R0P2QXJ420:>SX`<0Y:BT0P2WYjL20:BTY080YZJV
0P2_[jl20:VYZ@80Z:RX0`2^[Zh20;2`/080[Zj^102a/K420;:b/P80/K6a0`2c/k<20;Jf]P80]kNg
0P2_[jl20;Fe]@80/[:b0P2_[jl50;Jf]P@0]kNg2038h=P000H0b>3H0P0W9bL202TY:@80:RXZ0`0d
=3@203Lg=`808b<S0P0d=3@204M7A`80Bd];0P14A4@304i>CP80J6QX0P1hN7P205MGE`80BDU90P1?
Cdl204Q8B0<0=CDe0P0a<C4202LW9`80:2PX0P0_;bl202PX:080>3Ph0`0m?Cd2034a<@809BDU0P0[
:b/204A4A080LW9b0P0c<c<202XZ:P<0:2PX0P0[:b/203lo?`80GUiN0P1bLW8203hn?P80=SHf0`0Y
:BT202/[:`80@D510P1mOGd203Xj>P80:BTY0P0T92@302d];@80=3@d0P0^;Rh2024Q8@808R8R0P0n
?Sh207IfMP<0S8b<0P2@T90206UYJ@80EUIF0P1IFET2079bLP80T92@0`2i^KT20;Rh^080WinO0P2P
X:040:NWY`80YJFU0`2XZ:P20:ZZZP80YJFU0P2MWId209nOW`80XJ6Q0P2YZJT30:n_[`H0_[jn0P2m
_Kd20;Zj^P80]KFe0`30`<020;Zj^P80]kNg0P2][Jd20:n_[`80/[:b0P2h^;P30:n_[`80[Zj^0P2b
/[820:RXZ080WYjN102EUID209RHV0D0X:2P0P2QXJ440:>SX`80YjNW1@2UYJD20:NWY`80Xj>S0P2W
YjL20:VYZ@80YjNW0P2YZJT50:^[Z`80[Zj^0P2_[jl20;Bd]0@0/K6a0`2_[jl20;6a/@@0/[:b0P2a
/K440;2`/0<0];Bd0P2b/[840;Rh^0P0b>3H00060<SPf0809bLW0P0Y:BT202XZ:P<0=3@d0P0g=cL2
02<S8`80=3@d0P17AdL204];B`80A4A40`1>CTh206QXJ080N7Qh0P1GEeL204U9B@80Cdm?0P18B4P3
03De=@80<C4a0P0W9bL202PX:080;bl_0P0X:2P203Ph>0<0?Cdm0P0a<C4202DU9@80:b/[0P14A4@2
079bLP80<c<c0P0Z:RX302PX:080:b/[0P0o?cl205iNGP80LW9b0P0n?Sh203Hf=P<0:BTY0P0[:b/2
0451@@80OGem0P0j>SX202TY:@8092@T0`0];Bd203@d=080;Rh^0P0Q8B42028R8P80?Shn0P1fMWH3
08b<S080T92@0P1YJFT205IFEP80FEUI0P1bLW82092@T0<0^KVi0P2h^;P209nOW`80X:2P102WYjL2
0:FUY@<0Z:RX0P2ZZZX20:FUY@80WIfM0P2OWil20:6QX@80ZJVY0`2_[jl60;jn_P80_Kfm0P2j^[X2
0;Fe]@<0`<300P2j^[X20;Ng]`80[Jf]0P2_[jl20;:b/P80^;Rh0`2_[jl20:j^[P80/[:b0P2XZ:P2
09jNWP@0UIFE0P2HV9P50:2PX080XJ6Q102SXj<20:NWY`D0YJFU0P2WYjL20:>SX`80YjNW0P2YZJT2
0:NWY`80ZJVY1@2[Zj/20:j^[P80[jn_0P2d];@40;6a/@<0[jn_0P2a/K440;:b/P80/K6a102`/;03
0;Bd]080/[:b102h^;P80<SPf0001P38h=P203Hf=P80=3@d0P0T92@302PX:080?Cdm0P0/;2`203Xj
>P80?clo100k>c/303<c<`80AdM70P1]KFd2075aL@80@T920P0i>CT204I6AP<0=SHf0P0d=3@202DU
9@809bLW0P0^;Rh202`/;080?3`l0`0g=cL202TY:@80:2PX0P0W9bL203Lg=`80Jf][0P1=CDd202LW
9`<0:RXZ0P0/;2`203lo?`@0GEeM0P0j>SX503/k>`80:2PX0P0Z:RX205eMG@80MGEe0P0n?Sh202PX
:0<0;2`/0P0X:2P202DU9@80820P0P0Y:BT202/[:`80BDU90`1hN7P208N7Q`80MGEe0P1SHf<205aL
G080IVIV0P1iNGT309ZJVP80^k^k0P2`/;020:6QX@80X:2P0P2TY:@20:>SX`<0YJFU0P2RXZ8209bL
W0@0WYjN0P2SXj<20:JVYP<0[jn_0P2l_;`20;jn_P80`/;20P2l_;`20;Ng]`80];Bd0`2l_;`20;Ng
]`80^;Rh0P2b/[820:ZZZP80[Zj^0P2i^KT30;Fe]@80[:b/0P2YZJT40:JVYP80YjNW0P2KVi/209RH
V0<0VYZJ0P2QXJ420:BTY080Z:RX0P2RXZ820:BTY080YZJV1@2TY:@20:6QX@80YZJV0P2SXj<20:VY
Z@D0YjNW0P2/[:`20:^[Z`80];Bd0P2b/[820:f][@L0/;2`0P2b/[820;2`/080/[:b0P2d];@50:j^
[P80/K6a0P2f][H20;bl_0P0b>3H00060<SPf080=SHf0P0d=3@202@T90<0:2PX0P0m?Cd202`/;080
>SXj0P0o?cl403/k>`<0<c<c0P17AdL206e]K@80LG5a0P12@T8203Ti>@80ATI60`0f=SH203@d=080
9BDU0P0W9bL202h^;P80;2`/0P0l?3`303Lg=`80:BTY0P0X:2P202LW9`80=cLg0P1[Jf/204e=C@80
9bLW0`0Z:RX202`/;080?clo101MGEd203Xj>PD0>c/k0P0X:2P202XZ:P80GEeM0P1eMGD203hn?P80
:2PX0`0/;2`202PX:0809BDU0P0P820202TY:@80:b/[0P19BDT307QhN080QhN70P1eMGD206=SH`80
G5aL0P1VIVH207UiN@<0VYZJ0P2k^k/20;2`/080XJ6Q0P2PX:020:BTY080Xj>S0`2UYJD20::RXP80
W9bL102NWYh20:>SX`80YZJV0`2_[jl20;bl_080_[jn0P32`/820;bl_080]kNg0P2d];@30;bl_080
]kNg0P2h^;P20;:b/P80ZZZZ0P2^[Zh20;Vi^@<0]KFe0P2/[:`20:VYZ@@0YZJV0P2WYjL209^KV`80
V9RH0`2JVYX20:6QX@80Y:BT0P2XZ:P20::RXP80Y:BT0P2VYZH50:BTY080XJ6Q0P2VYZH20:>SX`80
ZJVY1@2WYjL20:b/[080Zj^[0P2d];@20;:b/P80[Jf]1`2`/;020;:b/P80/;2`0P2b/[820;Bd]0D0
[Zj^0P2a/K420;Jf]P80_;bl2038h=P000H0b>3H0P10@40204m?C`80:b/[0`0T92@203<c<`80=cLg
0P0m?Cd202l_;`80<S8b0P0];Bd302h^;P80=cLg0P12@T8206][J`80J6QX0P1UIFD204M7A`<0=SHf
0P0k>c/202XZ:P809BDU0P0R8R8202/[:`80>c/k0`0g=cL202h^;P809RHV0P0Y:BT203Lg=`80FEUI
0P1TI6@202XZ:P<09BDU0P0Z:RX204M7A`80DE5A0P1HF5P203Ti>@80@4100`13@d<202l_;`809bLW
0P0l?3`207QhN080LG5a0P11@D43030`<0808b<S0P0M7Ad201hN7P@0820P0P0b<S8305=CD`80LW9b
0P1fMWH207inOP80K6a/0P1SHf<206YZJP<0Ph>30P2NWYh20;Bd]080[Zj^0P2RXZ8209fMW@D0XJ6Q
0P2PX:0209nOW`@0XJ6Q0P2PX:020:JVYP<0[Jf]0P2l_;`20;^k^`@0_[jn0P2e]KD20;Ng]`<0^KVi
0P2g]kL20;Bd]080[:b/0P2LW9`20::RXP80][Jf0`2i^KT20;Jf]P80[:b/0P2SXj<20:NWY`80YZJV
0P2TY:@209^KV`D0VYZJ0P2LW9`20:6QX@80YZJV0P2YZJT20:BTY0<0XJ6Q0P2SXj<20::RXP80WYjN
0P2TY:@20:VYZ@80YjNW0`2VYZH20:RXZ080[Jf]0P2`/;020:f][@80[Zj^0P2][Jd30:j^[P80[jn_
0P2a/K420;:b/P@0];Bd0P2a/K430;:b/P80];Bd0P2h^;P20;jn_PP0b>3H00060<SPf080@4100P1?
Cdl202/[:`<092@T0P0c<c<203Lg=`80?Cdm0P0_;bl2038b<P80;Bd]0`0^;Rh203Lg=`80@T920P1[
Jf/206QXJ080IFEU0P17AdL303Hf=P80>c/k0P0Z:RX202DU9@808R8R0P0[:b/203/k>`<0=cLg0P0^
;Rh202HV9P80:BTY0P0g=cL205UIF@80I6AT0P0Z:RX302DU9@80:RXZ0P17AdL2055AD@80F5QH0P0i
>CT20410@0<0@d=30P0_;bl202LW9`80?3`l0P1hN7P2075aL@80@D510`0`<30202<S8`807AdM0P0N
7Qh4020P8080<S8b0`1CDe<2079bLP80MWIf0P1nOWh206a/K080Hf=S0P1ZJVX308>3P`80WYjN0P2d
];@20:j^[P80XZ:R0P2MWId50:6QX@80X:2P0P2OWil40:6QX@80X:2P0P2VYZH30:f][@80_;bl0P2k
^k/40;jn_P80]KFe0P2g]kL30;Vi^@80]kNg0P2d];@20:b/[080W9bL0P2RXZ820;Jf]P<0^KVi0P2f
][H20:b/[080Xj>S0P2WYjL20:JVYP80Y:BT0P2KVi/509ZJVP80W9bL0P2QXJ420:JVYP80ZJVY0P2T
Y:@30:6QX@80Xj>S0P2RXZ8209jNWP80Y:BT0P2YZJT20:NWY`<0YZJV0P2XZ:P20:f][@80/;2`0P2]
[Jd20:j^[P80[Jf]0`2^[Zh20:n_[`80/K6a0P2b/[840;Bd]080/K6a0`2b/[820;Bd]080^;Rh0P2n
_[h80<SPf0001P38h=P20410@080Cdm?0P0[:b/302@T9080<c<c0P0g=cL203dm?@80;bl_0P0b<S82
02d];@<0;Rh^0P0g=cL20492@P80Jf][0P1XJ6P206EUI@80AdM70`0f=SH203/k>`80:RXZ0P0U9BD2
028R8P80:b/[0P0k>c/303Lg=`80;Rh^0P0V9RH202TY:@80=cLg0P1IFET206ATI080:RXZ0`0U9BD2
02XZ:P80AdM70P1ADE4205QHF080>CTi0P10@40304=3@`80;bl_0P0W9bL203`l?080N7Qh0P1aLG42
0451@@<0<30`0P0S8b<201dM7@807QhN100P8202038b<P<0De=C0P1bLW8207IfMP80OWin0P1/K6`2
06=SH`80JVYZ0`23Ph<209jNWP80];Bd0P2^[Zh20::RXP80WIfM1@2QXJ420:2PX080WinO102QXJ42
0:2PX080YZJV0`2][Jd20;bl_080^k^k102n_[h20;Fe]@80]kNg0`2i^KT20;Ng]`80];Bd0P2/[:`2
09bLW080XZ:R0P2f][H30;Vi^@80][Jf0P2/[:`20:>SX`80YjNW0P2VYZH20:BTY080Vi^K1@2JVYX2
09bLW080XJ6Q0P2VYZH20:VYZ@80Y:BT0`2QXJ420:>SX`80XZ:R0P2NWYh20:BTY080ZJVY0P2WYjL3
0:JVYP80Z:RX0P2][Jd20;2`/080[Jf]0P2^[Zh20:f][@<0[Zj^0P2_[jl20;6a/@80/[:b102d];@2
0;6a/@<0/[:b0P2d];@20;Rh^080_[jn2038h=P000H0b>3H0P0j>SX2069RHP80=3@d0`0Y:BT202PX
:080>CTi0P0X:2P202DU9@8092@T0P0W9bL302`/;080=SHf0P0n?Sh204e=C@80Hf=S0P1YJFT2069R
HP<0?clo0P0f=SH203Lg=`80:2PX0P0Y:BT2030`<080>CTi0`0l?3`202h^;P80:b/[0P0/;2`202d]
;@80DU9B0P1TI6@202d];@<09RHV0P0];Bd204Y:BP80?3`l0P0n?Sh203Ti>@80:BTY0`0a<C42038b
<P80;Bd]0P0^;Rh206=SH`80S8b<0P1QHF4302TY:@@07alO0P0M7Ad201lO7`808B4Q0P0X:2P303hn
?P80K6a/0P2>SXh209NGU`80Q8B40P1lO7`2075aL@<0KVi^0P26QXH20:NWY`80_;bl0P2][Jd209fM
W@80WYjN0`2SXj<20:2PX080WinO0P2RXZ820:6QX@80YZJV0P2/[:`30:n_[`80^k^k0P2l_;`20;Zj
^P80^k^k0P2l_;`70;^k^`80/[:b0P2^[Zh2092@T080Shn?0P2[Zj/30;Fe]@80_;bl0P2h^;P20:NW
Y`80ZJVY0P2WYjL20:JVYP80XJ6Q0`2NWYh209ZJVP80Vi^K0P2LW9`20:2PX080YJFU0P2VYZH30:>S
X`80WYjN0P2MWId20:>SX`80XJ6Q0P2VYZH20:6QX@D0Z:RX0P2`/;020:^[Z`80/;2`102][Jd50;2`
/080[Zj^0P2d];@20;Fe]@80][Jf0P2b/[830;Jf]P80^;Rh0P2i^KT20;jn_PP0b>3H00060<SPf080
>SXj0P1RHV8203@d=0<0:BTY0P0X:2P203Ti>@80:2PX0P0U9BD202@T90809bLW0`0/;2`203Hf=P80
?Shn0P1=CDd206=SH`80JFUY0P1RHV8303lo?`80=SHf0P0g=cL202PX:080:BTY0P0`<30203Ti>@<0
?3`l0P0^;Rh202/[:`80;2`/0P0];Bd2059BDP80I6AT0P0];Bd302HV9P80;Bd]0P1:BTX203`l?080
?Shn0P0i>CT202TY:@<0<C4a0P0b<S8202d];@80;Rh^0P1SHf<208b<S080HF5Q0`0Y:BT401lO7`80
7AdM0P0O7al2024Q8@80:2PX0`0n?Sh206a/K080SXj>0P2GUiL208B4Q080O7al0P1aLG4306i^KP80
QXJ60P2WYjL20;bl_080[Jf]0P2MWId209jNWP<0Xj>S0P2PX:0209nOW`80XZ:R0P2QXJ420:JVYP80
[:b/0`2_[jl20;^k^`80_;bl0P2j^[X20;^k^`80_;bl1`2k^k/20;:b/P80[Zj^0P2@T90208n?S`80
Zj^[0`2e]KD20;bl_080^;Rh0P2WYjL20:VYZ@80YjNW0P2VYZH20:6QX@<0WYjN0P2JVYX209^KV`80
W9bL0P2PX:020:FUY@80YZJV0`2SXj<209jNWP80WIfM0P2SXj<20:6QX@80YZJV0P2QXJ450:RXZ080
/;2`0P2[Zj/20;2`/0@0[Jf]1@2`/;020:j^[P80];Bd0P2e]KD20;Jf]P80/[:b0`2f][H20;Rh^080
^KVi0P2n_[h80<SPf0001P38h=P202LW9`80BTY:0P1DE5@3038b<P80<C4a0P0l?3`202XZ:P@09BDU
0P0X:2P303@d=080DU9B0P18B4P203hn?P80>CTi0P1JFUX2069RHP<0De=C0P0m?Cd2038b<P809RHV
0P0X:2P202TY:@80<S8b0`0i>CT203Lg=`80;2`/100Y:BT20410@080IVIV0P0k>c/302LW9`80>c/k
0P1JFUX2034a<@80=3@d0P0b<S8202DU9@<09RHV0P0b<S8204E5A@80=3@d0P1?Cdl207YjNP80De=C
0`0Q8B42020P80808b<S100N7Qh2020P8080<C4a0`1RHV8206MWI`@0SXj>0P2QXJ4208R8R080OGem
0`1ZJVX207AdM080R8R80P2SXj<20;:b/P80YJFU0P2PX:030:BTY080XJ6Q0P2LW9`40::RXP80YJFU
0P2_[jl30;>c/`80`<300P2l_;`20;Zj^P80^KVi0P2k^k/20;Rh^0<0^k^k0P2i^KT20:n_[`80Y:BT
0P2:RXX208B4Q080Zj^[0`2`/;020;Vi^@80`l?30P2h^;P20:j^[P80Z:RX0P2VYZH209nOW`<0W9bL
0P2NWYh209bLW080Vi^K0P2HV9P209jNWP80X:2P1`2NWYh20:>SX`80X:2P0P2RXZ820:JVYP<0YJFU
0P2/[:`20:ZZZP80[Zj^0P2_[jl20:^[Z`D0[:b/0P2`/;040:n_[`@0];Bd0P2c/k<30;Ng]`80][Jf
0P2l_;`20;fm_@P0b>3H00060<SPf0809bLW0P1:BTX205ADE0<0<S8b0P0a<C4203`l?080:RXZ100U
9BD202PX:0<0=3@d0P1BDU8204Q8B080?Shn0P0i>CT205YJFP80HV9R0`1CDe<203dm?@80<S8b0P0V
9RH202PX:080:BTY0P0b<S8303Ti>@80=cLg0P0/;2`402TY:@80@4100P1VIVH203/k>`<09bLW0P0k
>c/205YJFP80<C4a0P0d=3@2038b<P809BDU0`0V9RH2038b<P80ADE50P0d=3@204m?C`80NWYj0P1C
De<3024Q8@80820P0P0S8b<401hN7P80820P0P0a<C43069RHP80IfMW102>SXh20:6QX@80R8R80P1m
OGd306YZJP80M7Ad0P28R8P20:>SX`80/[:b0P2UYJD20:2PX0<0Y:BT0P2QXJ4209bLW0@0XZ:R0P2U
YJD20:n_[`<0/k>c0P30`<020;bl_080^[Zj0P2i^KT20;^k^`80^;Rh0`2k^k/20;Vi^@80[jn_0P2T
Y:@208Z:RP80Q8B40P2[Zj/30;2`/080^KVi0P33`l<20;Rh^080[Zj^0P2XZ:P20:JVYP80WinO0`2L
W9`209jNWP80W9bL0P2KVi/209RHV080WYjN0P2PX:0709jNWP80Xj>S0P2PX:020::RXP80YZJV0`2U
YJD20:b/[080ZZZZ0P2^[Zh20:n_[`80Zj^[1@2/[:`20;2`/0@0[jn_102d];@20;>c/`<0]kNg0P2f
][H20;bl_080_Kfm2038h=P000H0b>3H0P0Y:BT2034a<@80ADE50`0c<c<202LW9`80<30`0P0/;2`2
02HV9P80:BTY0P0d=3@304U9B@80HF5Q0P0k>c/202h^;P80:BTY0P0k>c/205EEE@<0F5QH0P1:BTX2
03Ti>@80;Rh^0P0[:b/202l_;`80>3Ph0`0a<C4203Ti>@80:RXZ0P0/;2`202XZ:P80?3`l0P1OGel2
0451@@<0:b/[0P15ADD205eMG@80<c<c0P0];Bd203Lg=`809bLW0`0[:b/202h^;P80?Cdm0P0f=SH2
04m?C`80IFEU0P0o?cl302@T90807alO0P0Q8B44020P8080;2`/0P1?Cdl307emO@80IfMW0P1OGel2
079bLP80Vi^K0P2QXJ4208N7Q`<0M7Ad0P1_Kfl207YjNP80Q8B40P2[Zj/20:n_[`80Xj>S0`2TY:@2
0::RXP80WIfM102VYZH20:ZZZP80];Bd0`2e]KD20;fm_@80^k^k0P2j^[X20;Jf]P80_kno0P2k^k/3
0;Rh^080/K6a0P2PX:0209RHV080M7Ad0P1mOGd20:VYZ@<0/;2`0P2l_;`20<?3``80`<300P2f][H2
0:n_[`80YZJV0P2RXZ830:6QX@80VIVI0P2GUiL209^KV`80UYJF0P2KVi/209ZJVP<0Vi^K0P2IVIT2
09^KV`80X:2P0P2TY:@20:6QX@80Xj>S0`2UYJD20:VYZ@80ZZZZ0P2][Jd20:ZZZP80ZJVY0P2/[:`3
0:n_[`@0/K6a0P2d];@20;2`/080]kNg0P2e]KD30;Ng]`80]KFe0P2m_Kd20<71`@P0b>3H00060<SP
f080:BTY0P0a<C4204E5A@<0<c<c0P0W9bL2030`<080;2`/0P0V9RH202TY:@80=3@d0`19BDT2065Q
H@80>c/k0P0^;Rh202TY:@80>c/k0P1EEED305QHF080BTY:0P0i>CT202h^;P80:b/[0P0_;bl203Ph
>0<0<C4a0P0i>CT202XZ:P80;2`/0P0Z:RX203`l?080GemO0P11@D4302/[:`80ADE50P1MGEd203<c
<`80;Bd]0P0g=cL202LW9`<0:b/[0P0^;Rh203dm?@80=SHf0P1?Cdl206EUI@80?clo0`0T92@201lO
7`808B4Q100P820202`/;080Cdm?0`1mOGd206MWI`80GemO0P1bLW8209^KV`80XJ6Q0P27QhL307Ad
M080Kfm_0P1jNWX208B4Q080Zj^[0P2_[jl20:>SX`<0Y:BT0P2RXZ8209fMW@@0YZJV0P2ZZZX20;Bd
]0<0]KFe0P2m_Kd20;^k^`80^[Zj0P2f][H20;no_`80^k^k0`2h^;P20;6a/@80X:2P0P2HV9P207Ad
M080OGem0P2YZJT30;2`/080_;bl0P33`l<20<30`080][Jf0P2_[jl20:JVYP80XZ:R0`2QXJ4209VI
V@80UiNG0P2KVi/209JFUP80Vi^K0P2JVYX309^KV`80VIVI0P2KVi/20:2PX080Y:BT0P2QXJ420:>S
X`<0YJFU0P2YZJT20:ZZZP80[Jf]0P2ZZZX20:VYZ@80[:b/0`2_[jl40;6a/@80];Bd0P2`/;020;Ng
]`80]KFe0`2g]kL20;Fe]@80_Kfm0P31`L480<SPf0001P38h=P202TY:@809RHV0P0f=SH303Lg=`80
:2PX0P0Y:BT202/[:`80;2`/0P0c<c<204Q8B0<0J6QX0P1;Bd/203Hf=P809BDU0P0b<S8202h^;P80
?Shn0`1GEeL204i>CP80=CDe0P0d=3@202d];@80?3`l0P0f=SH302l_;`80>c/k0P0Z:RX2030`<080
:RXZ0P0f=SH205UIF@80Bd];0`0b<S8203dm?@80CTi>0P0_;bl2034a<@80=cLg0P0a<C4302h^;P80
@T920P0];Bd203@d=080CTi>0P1CDe<203lo?`D08b<S0P0O7al2020P808092@T0P0c<c<207=cL`<0
QXJ60P1JFUX2034a<@80EUIF0P21PH4209nOW`80U9BD0`1mOGd206m_K`80MgMg0P1jNWX2092@T080
]kNg0P2YZJT309fMW@80XZ:R102UYJD20:^[Z`80[Zj^1@2c/k<20;Zj^P80_[jn0P2j^[X20;Vi^@@0
^k^k0`2j^[X20:j^[P80TY:B0P2JVYX207IfMP80PH610P2/[:`30:^[Z`80^;Rh0P30`<020<;2`P80
_[jn0P2h^;P20:ZZZP80Zj^[0`2QXJ4209fMW@80VIVI0P2LW9`20::RXP80YJFU0P2JVYX309RHV080
Vi^K0P2HV9P40:6QX@80X:2P0P2SXj<30::RXP80Z:RX0P2ZZZX20:j^[P80[Jf]0P2/[:`20:j^[P<0
[Jf]0P2c/k<20:j^[P80/k>c102`/;020;:b/P<0]KFe0P2g]kL20;^k^`80_Kfm2038h=P000H0b>3H
0P0Y:BT202HV9P80=SHf0`0g=cL202PX:080:BTY0P0[:b/202`/;080<c<c0P18B4P306QXJ080Bd];
0P0f=SH202DU9@80<S8b0P0^;Rh203hn?P<0EeMG0P1>CTh203De=@80=3@d0P0];Bd203`l?080=SHf
0`0_;bl203/k>`80:RXZ0P0`<30202XZ:P80=SHf0P1IFET204];B`<0<S8b0P0m?Cd204i>CP80;bl_
0P0a<C4203Lg=`80<C4a0`0^;Rh20492@P80;Bd]0P0d=3@204i>CP80De=C0P0o?cl502<S8`807alO
0P0P820202@T9080<c<c0P1cLg<308J6QP80FUYJ0P0a<C4205IFEP80PH610P2OWil209BDU0<0OGem
0P1_Kfl207MgM`80NWYj0P2@T9020;Ng]`80ZJVY0`2MWId20::RXP@0YJFU0P2[Zj/20:j^[PD0/k>c
0P2j^[X20;jn_P80^[Zj0P2i^KT40;^k^`<0^[Zj0P2^[Zh209:BTP80VYZJ0P1fMWH20861P@80[:b/
0`2[Zj/20;Rh^080`<300P32`/820;jn_P80^;Rh0P2ZZZX20:^[Z`<0XJ6Q0P2MWId209VIV@80W9bL
0P2RXZ820:FUY@80VYZJ0`2HV9P209^KV`80V9RH102QXJ420:2PX080Xj>S0`2RXZ820:RXZ080ZZZZ
0P2^[Zh20:f][@80[:b/0P2^[Zh30:f][@80/k>c0P2^[Zh20;>c/`@0/;2`0P2b/[830;Fe]@80]kNg
0P2k^k/20;fm_@P0b>3H00060<SPf0808b<S0P0X:2P202TY:@<0;Rh^0P0Y:BT402XZ:P80=3@d0P17
AdL206][J`<0GemO0P0k>c/2034a<@80:b/[0P0_;bl2030`<080<c<c0`1=CDd205aLG080ATI60P0f
=SH202d];@80;2`/0P0e=CD303Ph>080>SXj0P0];Bd202`/;080;Rh^0P0c<c<204Y:BP80E5AD0`0_
;bl203@d=080>c/k0P0X:2P202l_;`80;Rh^0P0d=3@3055AD@80EUIF0P0Z:RX2038b<P80CDe=0P1A
DE420451@@<0:b/[0P0X:2P202<S8`80820P0P0[:b/204E5A@80U9BD0`1kNg/204];B`80820P0P0/
;2`206IVIP80QhN70P2PX:03092@T080NWYj0P1gMgL207moO`80P8200P2EUID20;6a/@<0ZZZZ0P2M
WId40:NWY`80[Zj^0P2a/K420:j^[P<0/;2`0P2l_;`20<?3``80^k^k0P2h^;P20;^k^`D0^KVi0P2/
[:`208b<S080Vi^K0P1mOGd208R8R080/;2`0`2][Jd20;6a/@80^[Zj0P30`<020<G5a@80`L710P2f
][H20:n_[`<0ZJVY0P2TY:@20:2PX080W9bL0P2KVi/20:VYZ@80XZ:R0`2CTi<209bLW080WIfM0P2O
Wil209fMW@80ZJVY0P2MWId30:6QX@80Z:RX102YZJT20:^[Z`@0[Zj^0`2][Jd40:j^[P80/k>c102`
/;020;Vi^@D0^;Rh0P2j^[X20<?3``P0b>3H00060<SPf0808b<S0P0X:2P202TY:@<0;Rh^0P0Y:BT4
02XZ:P80=3@d0P17AdL206][J`<0GemO0P0k>c/2034a<@80:b/[0P0_;bl2030`<080<c<c0`1=CDd2
05aLG080ATI60P0f=SH202d];@80;2`/0P0e=CD303Ph>080>SXj0P0];Bd202`/;080;Rh^0P0c<c<2
04Y:BP80E5AD0`0_;bl203@d=080>c/k0P0X:2P202l_;`80;Rh^0P0d=3@3055AD@80EUIF0P0Z:RX2
038b<P80CDe=0P1ADE420451@@<0:b/[0P0X:2P202<S8`80820P0P0[:b/204E5A@80U9BD0`1kNg/2
04];B`80820P0P0/;2`206IVIP80QhN70P2PX:03092@T080NWYj0P1gMgL207moO`80P8200P2EUID2
0;6a/@<0ZZZZ0P2MWId40:NWY`80[Zj^0P2a/K420:j^[P<0/;2`0P2l_;`20<?3``80^k^k0P2h^;P2
0;^k^`D0^KVi0P2/[:`208b<S080Vi^K0P1mOGd208R8R080/;2`0`2][Jd20;6a/@80^[Zj0P30`<02
0<G5a@80`L710P2f][H20:n_[`<0ZJVY0P2TY:@20:2PX080W9bL0P2KVi/20:VYZ@80XZ:R0`2CTi<2
09bLW080WIfM0P2OWil209fMW@80ZJVY0P2MWId30:6QX@80Z:RX102YZJT20:^[Z`@0[Zj^0`2][Jd4
0:j^[P80/k>c102`/;020;Vi^@D0^;Rh0P2j^[X20<?3``P0b>3H00060<SPf080:b/[0P0X:2P502/[
:`80:BTY0P0Z:RX202/[:`80<c<c0P1JFUX206a/K0<0CDe=0P0o?cl203hn?P80?Cdm0P0d=3@202l_
;`80?clo0`11@D4204Q8B080Bd];0P0a<C4202l_;`80:RXZ0P0b<S8303Ti>@80AdM70P0b<S82034a
<@80;2`/0P0`<30203dm?@80DU9B0`0o?cl403Ph>080;bl_0P0X:2P202`/;080>3Ph0`1XJ6P2065Q
H@80;Rh^0P1:BTX2055AD@80C4a<0P18B4P302l_;`809bLW0P0R8R8202@T9080;Rh^0P1^KVh2096A
T@<0JFUY0P0^;Rh201dM7@808b<S0P0f=SH206UYJ@80RXZ:0`2RXZ8208Z:RP80N7Qh0P1jNWX2079b
LP80Ng]k0P2FUYH30;Zj^P80Zj^[102VYZH20:b/[080[Jf]0P2/[:`30;>c/`80_kno0P32`/820;bl
_0@0^[Zj0P2d];@30;Vi^@80[jn_0P29RHT209RHV080QhN70P2;Rh/20:ZZZP<0YZJV0P2][Jd20;Bd
]080_;bl0P35aLD20<W9b@80`<300P2b/[830:b/[080YjNW0P2RXZ820:6QX@80WinO0P2QXJ420:ZZ
ZP<0XZ:R0P2LW9`209JFUP80VIVI0P2KVi/20:6QX@80X:2P0`2LW9`20:>SX`80YZJV0P2YZJT20:ZZ
ZP80Zj^[0P2^[Zh30:ZZZP80[Zj^0P2/[:`20;2`/080Zj^[0P2b/[820;fm_@<0^k^k0P2h^;P20;no
_`80`L712038h=P000H0b>3H0P0[:b/202PX:0D0:b/[0P0Y:BT202XZ:P80:b/[0P0c<c<205YJFP80
K6a/0`1=CDd203lo?`80?Shn0P0m?Cd203@d=080;bl_0P0o?cl30451@@80B4Q80P1;Bd/2034a<@80
;bl_0P0Z:RX2038b<P<0>CTi0P17AdL2038b<P80<C4a0P0/;2`2030`<080?Cdm0P1BDU8303lo?`@0
>3Ph0P0_;bl202PX:080;2`/0P0h>3P306QXJ080HF5Q0P0^;Rh204Y:BP80DE5A0P1<C4`204Q8B0<0
;bl_0P0W9bL2028R8P8092@T0P0^;Rh206i^KP80TI6A0`1YJFT202h^;P807AdM0P0S8b<203Hf=P80
JFUY0P2:RXX30::RXP80RXZ:0P1hN7P207YjNP80LW9b0P1kNg/209JFUP<0^[Zj0P2[Zj/40:JVYP80
[:b/0P2][Jd20:b/[0<0/k>c0P2o_kl20<;2`P80_;bl102j^[X20;Bd]0<0^KVi0P2_[jl208V9R@80
V9RH0P27QhL208^;R`80ZZZZ0`2VYZH20:f][@80];Bd0P2l_;`20<G5a@80bLW90P30`<020;:b/P<0
[:b/0P2WYjL20::RXP80XJ6Q0P2OWil20:6QX@80ZZZZ0`2RXZ8209bLW080UYJF0P2IVIT209^KV`80
XJ6Q0P2PX:0309bLW080Xj>S0P2VYZH20:VYZ@80ZZZZ0P2[Zj/20:j^[P<0ZZZZ0P2^[Zh20:b/[080
/;2`0P2[Zj/20;:b/P80_Kfm0`2k^k/20;Rh^080_kno0P31`L480<SPf0001P38h=P202DU9@809bLW
0P0Y:BT302<S8`80;Bd]0P0X:2P202l_;`80ADE50P1XJ6P205MGE`<0<c<c0P17AdL204];B`80CTi>
0P0e=CD202/[:`80;2`/0`0_;bl203Xj>P80@T921P0a<C42030`<0<0>CTi0P0h>3P203De=@80=SHf
0P0c<c<2038b<P80>CTi0P18B4P304];B`80>SXj0P0i>CT202HV9P809bLW0P0/;2`203Ph>0<0JVYZ
0P1KFe/203`l?080IfMW0P13@d<20492@P80DE5A0`17AdL203Lg=`80<c<c0P0d=3@204m?C`80VYZJ
0P28R8P3055AD@80:RXZ0P0O7al2024Q8@80820P0P11@D4207QhN0<0Rh^;0P2ZZZX208F5Q@80NGUi
0P1`L70207MgM`80PH610`2RXZ820;Jf]P80/k>c1P2ZZZX20:f][@<0^k^k0P2h^;P20;^k^`80_[jn
102d];@20:f][@<0][Jf0P2b/[8209>CT`80VYZJ0P2?Shl209FEU@80YjNW0`2QXJ420:BTY080/[:b
0P2i^KT40<K6aP80aLG50P2l_;`30:j^[P80ZZZZ0P2RXZ820:FUY@80YZJV0P2QXJ420:BTY0<0YZJV
0P2WYjL209NGU`80Ti>C102JVYX209jNWP<0Vi^K0P2UYJD20::RXP80ZJVY0P2UYJD20:RXZ080Zj^[
0`2][Jd20:n_[`80Zj^[0P2][Jd20;Bd]080]KFe0P2h^;P30;Ng]`80_;bl0P2n_[h20<?3``P0b>3H
00060<SPf0809BDU0P0W9bL202TY:@<08b<S0P0];Bd202PX:080;bl_0P15ADD206QXJ080EeMG0`0c
<c<204M7A`80Bd];0P1>CTh203De=@80:b/[0P0/;2`302l_;`80>SXj0P12@T86034a<@80<30`0`0i
>CT203Ph>080=CDe0P0f=SH203<c<`80<S8b0P0i>CT204Q8B0<0Bd];0P0j>SX203Ti>@809RHV0P0W
9bL202`/;080>3Ph0`1ZJVX205]KF`80?3`l0P1WIfL204=3@`80@T920P1ADE4304M7A`80=cLg0P0c
<c<203@d=080Cdm?0P2JVYX208R8R0<0DE5A0P0Z:RX201lO7`808B4Q0P0P82020451@@80N7Qh0`2;
Rh/20:ZZZP80QHF50P1iNGT2071`L080MgMg0P21PH430::RXP80][Jf0P2c/k<60:ZZZP80[Jf]0`2k
^k/20;Rh^080^k^k0P2n_[h40;Bd]080[Jf]0`2f][H20;:b/P80Ti>C0P2JVYX208n?S`80UIFE0P2W
YjL30:6QX@80Y:BT0P2b/[820;Vi^@@0a/K60P35aLD20;bl_0<0[Zj^0P2ZZZX20::RXP80YJFU0P2V
YZH20:6QX@80Y:BT0`2VYZH20:NWY`80UiNG0P2CTi<409ZJVP80WYjN0`2KVi/20:FUY@80XZ:R0P2Y
ZJT20:FUY@80Z:RX0P2[Zj/30:f][@80[jn_0P2[Zj/20:f][@80];Bd0P2e]KD20;Rh^0<0]kNg0P2l
_;`20;jn_P80`l?32038h=P000H0b>3H0P0U9BD202LW9`80:BTY0`0S8b<202d];@80:2PX0P0_;bl2
04E5A@80J6QX0P1GEeL303<c<`80AdM70P1;Bd/204i>CP80=CDe0P0[:b/202`/;0<0;bl_0P0j>SX2
0492@PH0<C4a0P0`<30303Ti>@80>3Ph0P0e=CD203Hf=P80<c<c0P0b<S8203Ti>@80B4Q80`1;Bd/2
03Xj>P80>CTi0P0V9RH202LW9`80;2`/0P0h>3P306YZJP80Fe]K0P0l?3`206MWI`80@d=30P12@T82
055AD@<0AdM70P0g=cL203<c<`80=3@d0P1?Cdl209ZJVP80R8R80`1ADE4202XZ:P807alO0P0Q8B42
020P8080@D510P1hN7P308^;R`80ZZZZ0P25QHD207UiN@80L71`0P1gMgL20861P@<0XZ:R0P2f][H2
0;>c/`H0ZZZZ0P2][Jd30;^k^`80^;Rh0P2k^k/20;jn_P@0];Bd0P2][Jd30;Jf]P80/[:b0P2CTi<2
09ZJVP80Shn?0P2EUID20:NWY`<0XJ6Q0P2TY:@20;:b/P80^KVi1036a/H20<G5a@80_;bl0`2^[Zh2
0:ZZZP80XZ:R0P2UYJD20:JVYP80XJ6Q0P2TY:@30:JVYP80YjNW0P2GUiL209>CT`@0VYZJ0P2NWYh3
09^KV`80YJFU0P2RXZ820:VYZ@80YJFU0P2XZ:P20:^[Z`<0[Jf]0P2_[jl20:^[Z`80[Jf]0P2d];@2
0;Fe]@80^;Rh0`2g]kL20;bl_080_[jn0P33`l<80<SPf0001P38h=P202/[:`809bLW0P0U9BD302`/
;0@0:BTY0P0a<C4204e=C@80KVi^0P19BDT302`/;080<c<c0P0f=SH203Ph>080?Shn0P0c<c<202h^
;P<0;Bd]0P0e=CD203dm?@80AdM70P0`<30202d];@80<c<c0`0g=cL203<c<`80>SXj0P12@T84034a
<@80=cLg0P0k>c/304Q8B080?Cdm0P0e=CD202HV9P8092@T0P0^;Rh204M7A`<0JFUY0P1IFET204i>
CP80I6AT0P0l?3`204];B`80FEUI0`1QHF4205eMG@@0EUIF0P1gMgL20:JVYP80RXZ:0`1NGUh202LW
9`807AdM0P0N7Qh2020P8080:RXZ0P16ATH307IfMP80VYZJ0P2KVi/208>3P`80N7Qh0P1kNg/207Qh
N0<0PH610P2ZZZX20;jn_P80][Jf0P2UYJD20:ZZZP80[:b/0`2i^KT20;>c/`80^;Rh0P2k^k/20;Jf
]P80]KFe0P2/[:`30;Fe]@80/k>c0P2IVIT2096AT@80TY:B0P2HV9P20:NWY`<0X:2P0P2SXj<20:j^
[P80][Jf0P33`l<20<W9b@80alO70P33`l<30;Jf]P80[Jf]0P2UYJD20:NWY`80Z:RX0P2YZJT20:BT
Y0<0WinO0P2PX:020:JVYP80U9BD0P2CTi<209RHV080Vi^K0`2LW9`20:2PX080WinO0P2SXj<20::R
XP80YZJV0P2][Jd30:ZZZP80ZJVY0P2XZ:P20:j^[P80/k>c0P2g]kL20;Bd]0<0^[Zj0P2k^k/20;fm
_@80_kno2038h=P000H0b>3H0P0[:b/202LW9`809BDU0`0/;2`402TY:@80<C4a0P1=CDd206i^KP80
BDU90`0/;2`203<c<`80=SHf0P0h>3P203hn?P80<c<c0P0^;Rh302d];@80=CDe0P0m?Cd204M7A`80
<30`0P0];Bd203<c<`<0=cLg0P0c<c<203Xj>P80@T92100a<C4203Lg=`80>c/k0`18B4P203dm?@80
=CDe0P0V9RH202@T9080;Rh^0P17AdL306UYJ@80FEUI0P1>CTh206ATI080?3`l0P1;Bd/205UIF@<0
HF5Q0P1MGEd405IFEP80MgMg0P2VYZH208Z:RP<0GUiN0P0W9bL201dM7@807QhN0P0P820202XZ:P80
ATI60`1fMWH209ZJVP80Vi^K0P23Ph<207QhN080Ng]k0P1hN7P30861P@80ZZZZ0P2n_[h20;Jf]P80
YJFU0P2ZZZX20:b/[0<0^KVi0P2c/k<20;Rh^080^k^k0P2f][H20;Fe]@80[:b/0`2e]KD20;>c/`80
VIVI0P2ATI4209:BTP80V9RH0P2WYjL30:2PX080Xj>S0P2^[Zh20;Jf]P80`l?30P39bLT20<O7a`80
`l?30`2f][H20:f][@80YJFU0P2WYjL20:RXZ080ZJVY0P2TY:@309nOW`80X:2P0P2VYZH209BDU080
Ti>C0P2HV9P209^KV`<0W9bL0P2PX:0209nOW`80Xj>S0P2RXZ820:JVYP80[Jf]0`2ZZZX20:VYZ@80
Z:RX0P2^[Zh20;>c/`80]kNg0P2d];@30;Zj^P80^k^k0P2m_Kd20;no_`P0b>3H00060<SPf080;Bd]
0P0Y:BT202HV9P<09bLW0P0^;Rh202PX:080:b/[0P1GEeL206i^KP80?Shn0`0W9bL202/[:`80;Rh^
0P0Z:RX203Ph>080@4100P0o?cl302l_;`80=CDe0P0g=cL204A4A080=3@d0P0/;2`202l_;`<0=3@d
0P0h>3P203dm?@80=cLg0P0a<C42038b<P80<C4a0P0^;Rh304A4A080?3`l0P0a<C4202h^;P80<C4a
0P0l?3`204];B`<0EEEE0P18B4P205UIF@80Fe]K0P15ADD206QXJ080IFEU0`1OGel2059BDP80De=C
0P0n?Sh206QXJ080Y:BT0P2<S8`306m_K`80=SHf0P0S8b<401dM7@80820P0P0Y:BT3059BDP80QHF5
0P2GUiL209^KV`80P8200P1iNGT2079bLP<0Ng]k0P2>SXh20:n_[`80`<300P2g]kL20:JVYP80[:b/
0`2h^;P20;Fe]@80^[Zj0P2`/;020;:b/P80/;2`1@2c/k<20;6a/@80XJ6Q0P2=SHd2092@T080Y:BT
1@2VYZH20:ZZZP80/K6a0P2g]kL20<30`080alO70P35aLD20<[:bP<0_[jn0P2`/;020:RXZ080YZJV
102][Jd20:^[Z`<0Y:BT0P2RXZ820:>SX`80Y:BT0P2MWId209FEU@80TY:B0`2KVi/209bLW080XJ6Q
0P2PX:020::RXP80YZJV0P2ZZZX50:^[Z`80ZZZZ0P2XZ:P20:b/[080];Bd0P2h^;P30;^k^`80_Kfm
0P30`<020<71`@P0b>3H00060<SPf080;Bd]0P0Y:BT202HV9P<09bLW0P0^;Rh202PX:080:b/[0P1G
EeL206i^KP80?Shn0`0W9bL202/[:`80;Rh^0P0Z:RX203Ph>080@4100P0o?cl302l_;`80=CDe0P0g
=cL204A4A080=3@d0P0/;2`202l_;`<0=3@d0P0h>3P203dm?@80=cLg0P0a<C42038b<P80<C4a0P0^
;Rh304A4A080?3`l0P0a<C4202h^;P80<C4a0P0l?3`204];B`<0EEEE0P18B4P205UIF@80Fe]K0P15
ADD206QXJ080IFEU0`1OGel2059BDP80De=C0P0n?Sh206QXJ080Y:BT0P2<S8`306m_K`80=SHf0P0S
8b<401dM7@80820P0P0Y:BT3059BDP80QHF50P2GUiL209^KV`80P8200P1iNGT2079bLP<0Ng]k0P2>
SXh20:n_[`80`<300P2g]kL20:JVYP80[:b/0`2h^;P20;Fe]@80^[Zj0P2`/;020;:b/P80/;2`1@2c
/k<20;6a/@80XJ6Q0P2=SHd2092@T080Y:BT1@2VYZH20:ZZZP80/K6a0P2g]kL20<30`080alO70P35
aLD20<[:bP<0_[jn0P2`/;020:RXZ080YZJV102][Jd20:^[Z`<0Y:BT0P2RXZ820:>SX`80Y:BT0P2M
WId209FEU@80TY:B0`2KVi/209bLW080XJ6Q0P2PX:020::RXP80YZJV0P2ZZZX50:^[Z`80ZZZZ0P2X
Z:P20:b/[080];Bd0P2h^;P30;^k^`80_Kfm0P30`<020<71`@P0b>3H00060<SPf080>SXj0P0W9bL2
02TY:@<09BDU0P0^;Rh203Ti>@80=3@d0P1KFe/206UYJ@80?clo0`0U9BD402LW9`80;bl_0P0`<302
04M7A`80DE5A0`0n?Sh2030`<080>3Ph0P10@4020492@P80:b/[0P0Y:BT302d];@80>3Ph0P0d=3@2
03Ph>080=SHf0P0Z:RX202/[:`80;Rh^0`0j>SX204Q8B080>c/k0P0];Bd203Ti>@80>3Ph0P0c<c<3
04I6AP80BDU90P1VIVH206a/K080Kfm_0P1iNGT205UIF@<0C4a<100k>c/202d];@80GUiN0P2HV9P2
06YZJP<0@D510P0U9BD201lO7`8071`L0P0P820201dM7@809BDU0`0^;Rh205UIF@80Ph>30P2QXJ42
09JFUP80QHF50P1lO7`307=cL`80Ng]k0P2CTi<20;Bd]080_Kfm0P2YZJT20:ZZZP<0/;2`0P2h^;P2
0;Vi^@@0[Zj^0P2YZJT20:RXZ0<0Zj^[0P2^[Zh209VIV@80RXZ:0P2@T9020:NWY`80Z:RX0`2WYjL2
0:JVYP80][Jf0P2j^[X20;fm_@@0_kno0P34a<@30;no_`80/k>c0P2[Zj/20:FUY@80ZJVY0P2/[:`5
0:NWY`80ZJVY0P2WYjL20::RXP80YJFU0P2IVIT2096AT@<0UYJF0P2KVi/209fMW@80W9bL0P2OWil4
0:JVYP<0Z:RX0P2WYjL20:VYZ@80[Jf]0P2_[jl20;Ng]`80^;Rh0`2j^[X20<71`@80`/;20P2n_[h8
0<SPf0001P38h=P203Xj>P809bLW0P0Y:BT302DU9@80;Rh^0P0i>CT203@d=080Fe]K0P1YJFT203lo
?`<09BDU100W9bL202l_;`80<30`0P17AdL2055AD@<0?Shn0P0`<30203Ph>080@4100P12@T8202/[
:`80:BTY0`0];Bd203Ph>080=3@d0P0h>3P203Hf=P80:RXZ0P0[:b/202h^;P<0>SXj0P18B4P203/k
>`80;Bd]0P0i>CT203Ph>080<c<c0`16ATH204U9B@80IVIV0P1/K6`206m_K`80NGUi0P1IFET304a<
C0@0>c/k0P0];Bd205iNGP80V9RH0P1ZJVX30451@@809BDU0P0O7al201`L7080820P0P0M7Ad202DU
9@<0;Rh^0P1IFET208>3P`80XJ6Q0P2FUYH208F5Q@80O7al0`1cLg<207]kN`80Ti>C0P2d];@20;fm
_@80ZJVY0P2ZZZX30;2`/080^;Rh0P2i^KT40:j^[P80ZJVY0P2XZ:P30:^[Z`80[Zj^0P2IVIT208Z:
RP80T92@0P2WYjL20:RXZ0<0YjNW0P2VYZH20;Jf]P80^[Zj0P2m_Kd40;no_`80a<C40`2o_kl20;>c
/`80Zj^[0P2UYJD20:VYZ@80[:b/1@2WYjL20:VYZ@80YjNW0P2RXZ820:FUY@80VIVI0P2ATI4309JF
UP80Vi^K0P2MWId209bLW080WinO102VYZH30:RXZ080YjNW0P2YZJT20:f][@80[jn_0P2g]kL20;Rh
^0<0^[Zj0P31`L420<;2`P80_[jn2038h=P000H0b>3H0P0b<S8202/[:`80<S8b0`0V9RH202l_;`80
=CDe0P0h>3P206UYJ@80KFe]0P11@D4302LW9`80:RXZ0P0Y:BT202l_;`80;Rh^0P11@D4204a<C0<0
AdM70P0h>3P202`/;080=SHf0P0m?Cd2030`<080;Bd]0`0c<c<203Lg=`80<S8b0P12@T8203De=@80
=cLg0P0Y:BT202h^;P<0=SHf0P11@D4203`l?080>3Ph0P0g=cL203@d=080<S8b0`0o?cl2061PH080
LW9b0P1YJFT207QhN080OWin0P1@D5030410@080:RXZ0P0e=CD203Hf=P80J6QX0P29RHT205QHF0<0
:BTY0P0P820202HV9P80820P0P0T92@2028R8P807QhN0`0T92@203Hf=P80GEeM0P2ATI420:VYZ@80
U9BD0P24Q8@307]kN`80MgMg0P1mOGd209FEU@80][Jf0P2i^KT20:VYZ@<0Z:RX0P2f][H20;>c/`80
[Zj^0P2ZZZX20:JVYP80Xj>S0`2`/;020:>SX`80U9BD0P2;Rh/208n?S`80ZJVY0P2e]KD30:f][@80
[:b/0P2_[jl20:j^[P80^KVi0P2n_[h20<?3``80_kno0`2j^[X20;Jf]P80[:b/0P2WYjL20:b/[080
Zj^[0P2WYjL30:^[Z`80[Jf]0P2XZ:P20:NWY`80Zj^[0P2UYJD20:2PX0<0UIFE0P2CTi<209BDU080
UiNG0P2MWId20:FUY@80YZJV0`2YZJT20:^[Z`80Z:RX102][Jd20;>c/`80]kNg0`2i^KT20;jn_P80
_kno0P2n_[h80<SPf0001P38h=P2038b<P80:b/[0P0b<S8302HV9P80;bl_0P0e=CD203Ph>080JFUY
0P1]KFd20451@@<09bLW0P0Z:RX202TY:@80;bl_0P0^;Rh20451@@80C4a<0`17AdL203Ph>080;2`/
0P0f=SH203dm?@80<30`0P0];Bd303<c<`80=cLg0P0b<S820492@P80=CDe0P0g=cL202TY:@80;Rh^
0`0f=SH20451@@80?3`l0P0h>3P203Lg=`80=3@d0P0b<S8303lo?`80H61P0P1bLW8206UYJ@80N7Qh
0P1nOWh2051@D0<0@4100P0Z:RX203De=@80=SHf0P1XJ6P208V9R@80F5QH0`0Y:BT2020P80809RHV
0P0P820202@T90808R8R0P0N7Qh302@T9080=SHf0P1MGEd2096AT@80ZJVY0P2DU9@208B4Q0<0Ng]k
0P1gMgL207emO@80UIFE0P2f][H20;Vi^@80ZJVY0`2XZ:P20;Jf]P80/k>c0P2^[Zh20:ZZZP80YZJV
0P2SXj<30;2`/080Xj>S0P2DU9@208^;R`80Shn?0P2YZJT20;Fe]@<0[Jf]0P2/[:`20:n_[`80[Zj^
0P2i^KT20;jn_P80`l?30P2o_kl30;Zj^P80][Jf0P2/[:`20:NWY`80[:b/0P2[Zj/20:NWY`<0Zj^[
0P2][Jd20:RXZ080YjNW0P2[Zj/20:FUY@80X:2P0`2EUID209>CT`80U9BD0P2GUiL209fMW@80YJFU
0P2VYZH30:VYZ@80Zj^[0P2XZ:P40:f][@80/k>c0P2g]kL30;Vi^@80_[jn0P2o_kl20;jn_PP0b>3H
00060<SPf080?clo0P0g=cL202h^;P<0:RXZ100/;2`203`l?080J6QX0P1]KFd204e=C@<0;Rh^0P0a
<C4202`/;0@0:b/[0P0`<30203hn?P<0AdM70P0o?cl2038b<P80<c<c0P0k>c/203De=@80<S8b0`0e
=CD2034a<@80=cLg0P0f=SH204A4A080;Rh^0P0[:b/202h^;P<0>c/k0P0n?Sh20410@080>CTi100b
<S8203Lg=`<0CTi>0P1SHf<206i^KP80IfMW0P1LG5`207YjNP80?clo0`0g=cL202d];@80<c<c0P0k
>c/20820P080RHV90P17AdL302DU9@8092@T0P0X:2P201lO7`8092@T0P0S8b<202PX:0<08b<S0P0Y
:BT202/[:`80HV9R0P2ATI420:FUY@80UIFE0`21PH4207AdM080LW9b0P1kNg/20:2PX080]KFe0P2i
^KT30:FUY@80[Zj^0P2][Jd20:RXZ080ZJVY0P2QXJ450:RXZ080ZZZZ0P2FUYH208N7Q`80SXj>0P2Y
ZJT20;Jf]P<0/K6a0P2YZJT20:RXZ080[jn_0P2i^KT20;bl_080`<300P36a/H30;Vi^@80^;Rh0P2_
[jl20:NWY`80ZZZZ0P2[Zj/20:VYZ@<0ZZZZ0P2/[:`20:VYZ@80Zj^[0P2^[Zh20:ZZZP80[jn_0`2Q
XJ4209JFUP80Ti>C0P2EUID209bLW080Xj>S0P2VYZH30:FUY@80ZJVY0P2WYjL20:j^[P80[:b/0P2b
/[820;2`/0<0^[Zj0P2m_Kd20;no_`80^KVi2038h=P000H0b>3H0P0o?cl203Lg=`80;Rh^0`0Z:RX4
02`/;080?3`l0P1XJ6P206e]K@80CDe=0`0^;Rh2034a<@80;2`/100[:b/2030`<080?Shn0`17AdL2
03lo?`80<S8b0P0c<c<203/k>`80=CDe0P0b<S8303De=@80<C4a0P0g=cL203Hf=P80A4A40P0^;Rh2
02/[:`80;Rh^0`0k>c/203hn?P80@4100P0i>CT4038b<P80=cLg0`1>CTh206=SH`80KVi^0P1WIfL2
05aLG080NWYj0P0o?cl303Lg=`80;Bd]0P0c<c<203/k>`80P8200P29RHT204M7A`<09BDU0P0T92@2
02PX:0807alO0P0T92@202<S8`80:2PX0`0S8b<202TY:@80:b/[0P1RHV82096AT@80YJFU0P2EUID3
0861P@80M7Ad0P1bLW8207]kN`80X:2P0P2e]KD20;Vi^@<0YJFU0P2^[Zh20:f][@80Z:RX0P2YZJT2
0:6QX@D0Z:RX0P2ZZZX209JFUP80QhN70P2>SXh20:VYZ@80][Jf0`2a/K420:VYZ@80Z:RX0P2_[jl2
0;Vi^@80_;bl0P30`<020<K6aP<0^KVi0P2h^;P20:n_[`80YjNW0P2ZZZX20:^[Z`80ZJVY0`2ZZZX2
0:b/[080ZJVY0P2[Zj/20:j^[P80ZZZZ0P2_[jl30:6QX@80UYJF0P2CTi<209FEU@80W9bL0P2SXj<2
0:JVYP<0YJFU0P2YZJT20:NWY`80[Zj^0P2/[:`20;:b/P80/;2`0`2j^[X20;fm_@80_kno0P2i^KT8
0<SPf0001P38h=P204m?C`80DU9B0P17AdL303<c<`80:b/[0P0/;2`203De=@80IVIV0P1]KFd204U9
B@<0=3@d0P0];Bd402XZ:P80;2`/0P0^;Rh203Hf=PD0ATI60P0j>SX203/k>`80?3`l0P0i>CT202XZ
:P<0:b/[0P0^;Rh402l_;`80>c/k0P0e=CD2034a<@80=3@d0`13@d<203hn?P80@T920P0i>CT203Hf
=P80=3@d0P14A4@305YJFP80H61P0P1SHf<203/k>`80@d=30P1ZJVX203Lg=`<0;2`/0P0_;bl203@d
=080D51@0P2@T9020861P@80=cLg0`0Y:BT202d];@80:RXZ0P0W9bL202@T90808B4Q0P0S8b<3020P
80808B4Q0P0T92@203@d=080Jf][0P2KVi/20:2PX0<0Shn?0P1hN7P206][J`80JVYZ0P1mOGd209^K
V`D0]KFe0P2/[:`20:^[Z`@0YJFU102VYZH30:NWY`80Xj>S0P2DU9@208B4Q080SHf=0P2WYjL20;6a
/@<0[Jf]0P2SXj<209nOW`80/K6a0P2j^[X20<71`@80_[jn0P2m_Kd30;Rh^080]kNg0P2a/K460:NW
Y`80Z:RX0`2ZZZX40:^[Z`80ZZZZ0P2[Zj/20:f][@80[Zj^0`2/[:`20:NWY`80W9bL0P2CTi<209FE
U@80XZ:R0P2PX:030::RXP80ZJVY0P2ZZZX20:f][@80[jn_0P2`/;020:j^[P<0][Jf0P2j^[X20;bl
_080^k^k2038h=P000H0b>3H0P1?Cdl2059BDP80AdM70`0c<c<202/[:`80;2`/0P0e=CD206IVIP80
KFe]0P19BDT303@d=080;Bd]100Z:RX202`/;080;Rh^0P0f=SH504I6AP80>SXj0P0k>c/203`l?080
>CTi0P0Z:RX302/[:`80;Rh^100_;bl203/k>`80=CDe0P0a<C4203@d=0<0@d=30P0n?Sh20492@P80
>CTi0P0f=SH203@d=080A4A40`1JFUX2061PH080Hf=S0P0k>c/204=3@`80JVYZ0P0g=cL302`/;080
;bl_0P0d=3@2051@D080T92@0P21PH4203Lg=`<0:BTY0P0];Bd202XZ:P809bLW0P0T92@2024Q8@80
8b<S0`0P8202024Q8@8092@T0P0d=3@206][J`80Vi^K0P2PX:0308n?S`80N7Qh0P1[Jf/206YZJP80
OGem0P2KVi/50;Fe]@80[:b/0P2[Zj/40:FUY@@0YZJV0`2WYjL20:>SX`80U9BD0P24Q8@208f=S@80
YjNW0P2a/K430:f][@80Xj>S0P2OWil20;6a/@80^[Zj0P31`L420;jn_P80_Kfm0`2h^;P20;Ng]`80
/K6a1P2WYjL20:RXZ0<0ZZZZ102[Zj/20:ZZZP80Zj^[0P2][Jd20:j^[P<0[:b/0P2WYjL209bLW080
Ti>C0P2EUID20::RXP80X:2P0`2RXZ820:VYZ@80ZZZZ0P2][Jd20:n_[`80/;2`0P2^[Zh30;Jf]P80
^[Zj0P2l_;`20;^k^`P0b>3H00060<SPf0@0G5aL0P1JFUX304=3@`80>CTi0P0^;Rh203Lg=`80E5AD
0P1XJ6P205YJFP<0<S8b0P0];Bd202TY:@80:RXZ0P0];Bd202HV9P80;Bd]0`10@40204=3@`80=cLg
0P0^;Rh20451@@80>SXj0P0b<S8302`/;080;Rh^0P0d=3@202/[:`80<30`0P0j>SX203`l?080@D51
0`1<C4`203Xj>P80>c/k0P11@D4203De=@80=3@d0P18B4P305ADE080G5aL0P1?Cdl2034a<@80=cLg
0P1QHF4203Xj>P<0;2`/0P0^;Rh20410@080Kfm_0P2?Shl2075aL@80;2`/0`0^;Rh202TY:@808b<S
0P0W9bL202HV9P808b<S0P0R8R83024Q8@807alO0P0P820202DU9@80=SHf0P1`L70209NGU`<0Z:RX
0P2>SXh207AdM080IfMW0P1bLW8208>3P`80X:2P0`2c/k<20;no_`80/K6a0P2YZJT20:BTY080YJFU
0P2TY:@30:FUY@80X:2P0P2>SXh208B4Q080RHV90P2TY:@20:VYZ@<0YJFU0P2NWYh209nOW`80ZJVY
0P2f][H20<71`@80^k^k0P2e]KD30:f][@80][Jf0P2d];@20:^[Z`@0[:b/1@2YZJT20:b/[080YZJV
0P2XZ:P20:BTY080ZZZZ0P2XZ:P30;:b/P80/k>c0P2_[jl209fMW@80RXZ:0P2CTi<209fMW@<0WinO
0P2VYZH20:NWY`80ZJVY0P2/[:`40:n_[`<0];Bd0P2i^KT20;^k^`80]kNg2038h=P000H0b>3H101L
G5`205YJFP<0@d=30P0i>CT202h^;P80=cLg0P1DE5@206QXJ080FUYJ0`0b<S8202d];@80:BTY0P0Z
:RX202d];@809RHV0P0];Bd30410@080@d=30P0g=cL202h^;P80@D510P0j>SX2038b<P<0;2`/0P0^
;Rh203@d=080:b/[0P0`<30203Xj>P80?3`l0P11@D4304a<C080>SXj0P0k>c/20451@@80=CDe0P0d
=3@204Q8B0<0E5AD0P1LG5`204m?C`80<C4a0P0g=cL2065QH@80>SXj0`0/;2`202h^;P80@4100P1_
Kfl208n?S`80LG5a0P0/;2`302h^;P80:BTY0P0S8b<202LW9`809RHV0P0S8b<2028R8P<08B4Q0P0O
7al2020P80809BDU0P0f=SH2071`L080UiNG0`2XZ:P208j>SP80M7Ad0P1WIfL2079bLP80Ph>30P2P
X:030;>c/`80_kno0P2a/K420:VYZ@80Y:BT0P2UYJD20:BTY0<0YJFU0P2PX:0208j>SP80Q8B40P29
RHT20:BTY080ZJVY0`2UYJD209jNWP80WinO0P2YZJT20;Jf]P80`L710P2k^k/20;Fe]@<0[Jf]0P2f
][H20;Bd]080Zj^[102/[:`50:VYZ@80[:b/0P2VYZH20:RXZ080Y:BT0P2ZZZX20:RXZ0<0/[:b0P2c
/k<20:n_[`80WIfM0P2:RXX209>CT`80WIfM0`2OWil20:JVYP80YjNW0P2YZJT20:b/[0@0[jn_0`2d
];@20;Vi^@80^k^k0P2g]kL80<SPf0001P38h=P405aLG080FUYJ0`13@d<203Ti>@80;Rh^0P0g=cL2
05ADE080J6QX0P1JFUX3038b<P80;Bd]0P0Y:BT202XZ:P80;Bd]0P0V9RH202d];@<0@4100P13@d<2
03Lg=`80;Rh^0P11@D4203Xj>P80<S8b0`0/;2`202h^;P80=3@d0P0[:b/2030`<080>SXj0P0l?3`2
0451@@<0C4a<0P0j>SX203/k>`80@D510P0e=CD203@d=080B4Q80`1DE5@205aLG080Cdm?0P0a<C42
03Lg=`80HF5Q0P0j>SX302`/;080;Rh^0P10@40206m_K`80Shn?0P1aLG4202`/;0<0;Rh^0P0Y:BT2
02<S8`809bLW0P0V9RH202<S8`808R8R0`0Q8B4201lO7`80820P0P0U9BD203Hf=P80L71`0P2GUiL3
0:RXZ080SXj>0P1dM7@206MWI`80LW9b0P23Ph<20:2PX0<0/k>c0P2o_kl20;6a/@80ZJVY0P2TY:@2
0:FUY@80Y:BT0`2UYJD20:2PX080SXj>0P24Q8@208V9R@80Y:BT0P2YZJT30:FUY@80WYjN0P2OWil2
0:VYZ@80][Jf0P31`L420;^k^`80]KFe0`2][Jd20;Jf]P80];Bd0P2[Zj/40:b/[0D0ZJVY0P2/[:`2
0:JVYP80Z:RX0P2TY:@20:ZZZP80Z:RX0`2b/[820;>c/`80[jn_0P2MWId208Z:RP80Ti>C0P2MWId3
09nOW`80YZJV0P2WYjL20:VYZ@80[:b/102_[jl30;Bd]080^KVi0P2k^k/20;Ng]`P0b>3H00060<SP
f080@d=30P12@T8204A4A0<0=CDe0P0d=3@402h^;P80EEEE0P1QHF42069RHP<0?Shn0P0];Bd202XZ
:P809bLW0P0];Bd202TY:@80;Bd]0`0d=3@203/k>`@0;Rh^0P0h>3P203hn?P80<c<c0`0a<C4202l_
;`80=SHf0P0a<C4203<c<`80@4100P1ADE4204a<C0<0BTY:0P11@D4203dm?@80A4A40P0i>CT20451
@@80CDe=0`16ATH205UIF@80D51@0P0Y:BT202/[:`80Bd];0P0k>c/303De=@80;Bd]0P1IFET208R8
R080RXZ:0P1NGUh202LW9`<0:BTY0P0V9RH202@T9080;Rh^0P0X:2P402<S8`<08B4Q0P0M7Ad201hN
7P807alO0P0V9RH20451@@80Lg=c0`2TY:@20:b/[080R8R80P1aLG4206MWI`80M7Ad0P27QhL309nO
W`80][Jf0P2o_kl20:f][@80YZJV0P2TY:@20:JVYP<0YJFU0P2SXj<208f=S@80QXJ60P20P80209^K
V`80YjNW0`2TY:@40:b/[080XZ:R0P2`/;020<30`080_kno0P2f][H30:f][@80[:b/0P2m_Kd20:j^
[P80YjNW0P2][Jd20:ZZZP<0ZJVY0P2ZZZX20:6QX@80YjNW0P2PX:020:RXZ080Xj>S0`2^[Zh20;2`
/080]kNg0P2e]KD209jNWP80Shn?0P2IVIT309nOW`80YZJV0P2UYJD20:ZZZP80/[:b0P2][Jd20:n_
[`<0];Bd0P2k^k/20;Bd]080^KVi2038h=P000H0b>3H0P13@d<20492@P80A4A40`0e=CD203@d=0@0
;Rh^0P1EEED2065QH@80HV9R0`0n?Sh202d];@80:RXZ0P0W9bL202d];@80:BTY0P0];Bd303@d=080
>c/k100^;Rh203Ph>080?Shn0P0c<c<3034a<@80;bl_0P0f=SH2034a<@80<c<c0P10@402055AD@80
C4a<0`1:BTX20451@@80?Cdm0P14A4@203Ti>@80@D510P1=CDd304I6AP80FEUI0P1@D50202TY:@80
:b/[0P1;Bd/203/k>`<0=CDe0P0];Bd205UIF@80R8R80P2:RXX205iNGP809bLW0`0Y:BT202HV9P80
92@T0P0^;Rh202PX:0@08b<S0`0Q8B4201dM7@807QhN0P0O7al202HV9P80@D510P1cLg<30:BTY080
[:b/0P28R8P2075aL@80IfMW0P1dM7@208N7Q`<0WinO0P2f][H20;no_`80[Jf]0P2VYZH20:BTY080
YZJV0`2UYJD20:>SX`80SHf=0P26QXH20820P080Vi^K0P2WYjL30:BTY0@0[:b/0P2RXZ820;2`/080
`<300P2o_kl20;Jf]P<0[Jf]0P2/[:`20;fm_@80[Zj^0P2WYjL20:f][@80ZZZZ0`2YZJT20:ZZZP80
XJ6Q0P2WYjL20:2PX080Z:RX0P2SXj<30:j^[P80/;2`0P2g]kL20;Fe]@80WYjN0P2?Shl209VIV@<0
WinO0P2VYZH20:FUY@80ZZZZ0P2b/[820:f][@80[jn_0`2d];@20;^k^`80];Bd0P2i^KT80<SPf000
1P38h=P2051@D080EUIF0P0o?cl302l_;`80;Rh^0P0b<S8203<c<`80DE5A0P1NGUh2061PH0<0CDe=
0P0b<S8202/[:`80:RXZ0P0Y:BT202LW9`80;Bd]0`0b<S8203Lg=`80<c<c0P0_;bl2034a<@80>c/k
0P0c<c<3038b<P80=CDe0P0^;Rh203<c<`80>3Ph0P1CDe<205ADE0D0B4Q80P15ADD20492@P80ADE5
0P11@D4204=3@`80>SXj0`10@402065QH@80EUIF0P0[:b/202h^;P80?Shn0P10@40303Lg=`80?3`l
0P1GEeL209:BTP80SXj>0P1KFe/202PX:0<09bLW0P0/;2`202d];@80:b/[0P0Z:RX202DU9@8092@T
0`0Z:RX2024Q8@@07QhN0P0Q8B4202DU9@80BTY:0`25QHD20:BTY080W9bL0P29RHT2071`L080JVYZ
0P1bLW8308B4Q080X:2P0P2j^[X20;fm_@80YjNW0P2TY:@20:FUY@<0Y:BT0P2SXj<208J6QP80P820
0P23Ph<209VIV@80[jn_0`2e]KD20;Jf]P80[Zj^0P2TY:@20;:b/P80`L710P30`<020;Rh^0<0^KVi
0P2c/k<20;^k^`80/k>c0P2YZJT20:NWY`80YZJV0`2PX:020:RXZ080X:2P0P2TY:@20:6QX@80YJFU
0P2TY:@30:j^[P80[jn_0P2d];@20;^k^`80]KFe0P2UYJD209^KV`<0W9bL0P2KVi/20:BTY080YjNW
0P2^[Zh20:b/[080[Jf]0`2e]KD20;Jf]P80/k>c0P2m_Kd80<SPf0001P38h=P2051@D080EUIF0P0o
?cl302l_;`80;Rh^0P0b<S8203<c<`80DE5A0P1NGUh2061PH0<0CDe=0P0b<S8202/[:`80:RXZ0P0Y
:BT202LW9`80;Bd]0`0b<S8203Lg=`80<c<c0P0_;bl2034a<@80>c/k0P0c<c<3038b<P80=CDe0P0^
;Rh203<c<`80>3Ph0P1CDe<205ADE0D0B4Q80P15ADD20492@P80ADE50P11@D4204=3@`80>SXj0`10
@402065QH@80EUIF0P0[:b/202h^;P80?Shn0P10@40303Lg=`80?3`l0P1GEeL209:BTP80SXj>0P1K
Fe/202PX:0<09bLW0P0/;2`202d];@80:b/[0P0Z:RX202DU9@8092@T0`0Z:RX2024Q8@@07QhN0P0Q
8B4202DU9@80BTY:0`25QHD20:BTY080W9bL0P29RHT2071`L080JVYZ0P1bLW8308B4Q080X:2P0P2j
^[X20;fm_@80YjNW0P2TY:@20:FUY@<0Y:BT0P2SXj<208J6QP80P8200P23Ph<209VIV@80[jn_0`2e
]KD20;Jf]P80[Zj^0P2TY:@20;:b/P80`L710P30`<020;Rh^0<0^KVi0P2c/k<20;^k^`80/k>c0P2Y
ZJT20:NWY`80YZJV0`2PX:020:RXZ080X:2P0P2TY:@20:6QX@80YJFU0P2TY:@30:j^[P80[jn_0P2d
];@20;^k^`80]KFe0P2UYJD209^KV`<0W9bL0P2KVi/20:BTY080YjNW0P2^[Zh20:b/[080[Jf]0`2e
]KD20;Jf]P80/k>c0P2m_Kd80<SPf0001P38h=P207EeM@80JFUY0P17AdL302d];@809bLW0P0[:b/2
02d];@80?Shn0P1GEeL205mOG`<0EUIF0P0/;2`202d];@80:BTY0P0_;bl202HV9P80:b/[0`0_;bl2
03Hf=P80=3@d0P0];Bd202/[:`80<S8b0P0`<30302d];@80<C4a0P0d=3@203Ph>080BTY:0P1FEUH2
04m?C`80ADE50`0j>SX203lo?`80BDU90P1;Bd/204E5A@80@4100P0a<C4304E5A@80HV9R0P1HF5P2
02/[:`80;Bd]100l?3`302`/;080<S8b0P1ADE4208j>SP80QHF50P1HF5P2034a<@<0?Shn0P10@402
04];B`80@d=30P0n?Sh202h^;P80:BTY0`0V9RH202@T90@08b<S0P0O7al2024Q8@80:BTY0`1FEUH2
08:2PP80VYZJ0P2PX:0208R8R080LG5a0P1/K6`306QXJ080N7Qh0P2OWil20;Rh^080]KFe0P2PX:02
0:NWY`<0XZ:R0P2HV9P20820P080Ng]k0P2>SXh20:2PX080^k^k0`2j^[X20;6a/@80];Bd0P2VYZH2
0;Ng]`80_;bl0P33`l<50;bl_080_[jn0P2h^;P20;Fe]@80[Jf]0P2ZZZX20:b/[0<0XZ:R0P2TY:@2
0:>SX`80WinO0P2QXJ4209jNWP80WinO0`2WYjL20;6a/@80];Bd0P2f][H20;bl_080/K6a0P2`/;03
09nOW`80V9RH0P2LW9`20:BTY0@0Z:RX0P2WYjL30:n_[`80/;2`0P2d];@20;Zj^PP0b>3H00060<SP
f080MGEe0P1YJFT204M7A`<0;Bd]0P0W9bL202/[:`80;Bd]0P0n?Sh205MGE`80GemO0`1FEUH202`/
;080;Bd]0P0Y:BT202l_;`809RHV0P0[:b/302l_;`80=SHf0P0d=3@202d];@80:b/[0P0b<S82030`
<0<0;Bd]0P0a<C4203@d=080>3Ph0P1:BTX205IFEP80Cdm?0P15ADD303Xj>P80?clo0P19BDT204];
B`80ADE50P10@402034a<@<0ADE50P1RHV8205QHF080:b/[0P0];Bd403`l?0<0;2`/0P0b<S82055A
D@80SXj>0P25QHD205QHF080<C4a0`0n?Sh20410@080Bd];0P13@d<203hn?P80;Rh^0P0Y:BT302HV
9P8092@T100S8b<201lO7`808B4Q0P0Y:BT305IFEP80PX:20P2JVYX20:2PX080R8R80P1aLG4206a/
K0<0J6QX0P1hN7P209nOW`80^;Rh0P2e]KD20:2PX080YjNW0`2RXZ8209RHV080P8200P1kNg/208j>
SP80X:2P0P2k^k/30;Zj^P80/K6a0P2d];@20:JVYP80]kNg0P2l_;`20<?3``D0_;bl0P2n_[h20;Rh
^080]KFe0P2][Jd20:ZZZP80[:b/0`2RXZ820:BTY080Xj>S0P2OWil20:6QX@80WYjN0P2OWil30:NW
Y`80/K6a0P2d];@20;Jf]P80_;bl0P2a/K420;2`/0<0WinO0P2HV9P209bLW080Y:BT102XZ:P20:NW
Y`<0[jn_0P2`/;020;Bd]080^[Zj2038h=P000H0b>3H0P1hN7P206QXJ080EeMG0`0`<30202`/;080
9RHV0P0[:b/203Hf=P80?clo0P1KFe/305eMG@80=SHf0P0];Bd202l_;`80;2`/0P0[:b/203De=@L0
:RXZ0P0[:b/202h^;P80<30`0P0a<C4302/[:`80=cLg0P13@d<204a<C080E5AD0P1@D50204i>CP80
>c/k0`0o?cl204Q8B080EUIF0P1EEED204E5A@80>3Ph0P0X:2P303Ph>080IfMW0P1CDe<202@T9080
8b<S0P0];Bd203Ti>@<0:b/[0P0k>c/2069RHP80TI6A0P27QhL206=SH`80EUIF0`1ADE4206ATI080
Kfm_0P1SHf<205UIF@80<c<c0P0U9BD3024Q8@80:RXZ0P0R8R8202@T90807alO0P0R8R8202PX:0<0
;Rh^0P1@D50208J6QP80WinO0P2RXZ820861P@80IVIV0`1MGEd206=SH`80O7al0P2NWYh20;Fe]@80
Zj^[0P2QXJ430:BTY080SXj>0P1jNWX207]kN`80QXJ60P2`/;020;jn_P<0^[Zj0P2^[Zh20:n_[`80
];Bd0P2e]KD20<30`080`L711@2o_kl20<71`@80_kno0P2e]KD20:j^[P80ZZZZ0P2VYZH30::RXP80
YJFU0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`<0YZJV0P2ZZZX20:f][@80]KFe0P2i^KT20;Jf]P80
/[:b0`2`/;020::RXP80WYjN0P2PX:020:BTY080YjNW1`2][Jd20;2`/080^k^k2038h=P000H0b>3H
0P1hN7P206QXJ080EeMG0`0`<30202`/;0809RHV0P0[:b/203Hf=P80?clo0P1KFe/305eMG@80=SHf
0P0];Bd202l_;`80;2`/0P0[:b/203De=@L0:RXZ0P0[:b/202h^;P80<30`0P0a<C4302/[:`80=cLg
0P13@d<204a<C080E5AD0P1@D50204i>CP80>c/k0`0o?cl204Q8B080EUIF0P1EEED204E5A@80>3Ph
0P0X:2P303Ph>080IfMW0P1CDe<202@T90808b<S0P0];Bd203Ti>@<0:b/[0P0k>c/2069RHP80TI6A
0P27QhL206=SH`80EUIF0`1ADE4206ATI080Kfm_0P1SHf<205UIF@80<c<c0P0U9BD3024Q8@80:RXZ
0P0R8R8202@T90807alO0P0R8R8202PX:0<0;Rh^0P1@D50208J6QP80WinO0P2RXZ820861P@80IVIV
0`1MGEd206=SH`80O7al0P2NWYh20;Fe]@80Zj^[0P2QXJ430:BTY080SXj>0P1jNWX207]kN`80QXJ6
0P2`/;020;jn_P<0^[Zj0P2^[Zh20:n_[`80];Bd0P2e]KD20<30`080`L711@2o_kl20<71`@80_kno
0P2e]KD20:j^[P80ZZZZ0P2VYZH30::RXP80YJFU0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`<0YZJV
0P2ZZZX20:f][@80]KFe0P2i^KT20;Jf]P80/[:b0`2`/;020::RXP80WYjN0P2PX:020:BTY080YjNW
1`2][Jd20;2`/080^k^k2038h=P000H0b>3H0P1bLW8205eMG@80=3@d0`0];Bd202HV9P80:BTY0P0_
;bl203`l?080<c<c0P13@d<305QHF080AdM70P11@D4203<c<`@0<30`0P0[:b/302d];@80<C4a0P0]
;Bd2034a<@80<S8b0P0h>3P202l_;`<0<C4a0P0d=3@204I6AP80G5aL0P1@D50205=CD`80>c/k0P0o
?cl304];B`80CTi>0P1IFET204];B`80?Cdm0P0/;2`202h^;P<0>SXj0P1RHV8205=CD`809BDU0P0S
8b<202XZ:P80=cLg0`0a<C4205=CD`80LW9b0P28R8P208N7Q`80Jf][0P1XJ6P305iNGP80GemO0P1M
GEd204Q8B080=CDe0P0U9BD202<S8`<09RHV0P0Z:RX202@T90808B4Q0P0U9BD202@T90809BDU0`0Q
8B42038b<P80Fe]K0P23Ph<209ZJVP80U9BD0P1eMGD305YJFP80De=C0P1VIVH207IfMP80UYJF0P2d
];@20;Jf]P<0YJFU0P29RHT207QhN080SHf=0P2EUID20:b/[080^k^k0`2l_;`20;Jf]P80/;2`0P2e
]KD20;^k^`80^[Zj0P2l_;`20<30`0<0`/;21031`L420;fm_@80][Jf0P2c/k<20:NWY`<0ZJVY102U
YJD60:6QX@80YZJV0`2UYJD20:ZZZP80[jn_0P2/[:`20;Bd]080]kNg0P2f][H30;:b/P80[Jf]0P2W
YjL20:BTY080XJ6Q0P2VYZH20:^[Z`<0[Jf]0P2/[:`20;6a/@80^;Rh2038h=P000H0b>3H0P1bLW82
05eMG@80=3@d0`0];Bd202HV9P80:BTY0P0_;bl203`l?080<c<c0P13@d<305QHF080AdM70P11@D42
03<c<`@0<30`0P0[:b/302d];@80<C4a0P0];Bd2034a<@80<S8b0P0h>3P202l_;`<0<C4a0P0d=3@2
04I6AP80G5aL0P1@D50205=CD`80>c/k0P0o?cl304];B`80CTi>0P1IFET204];B`80?Cdm0P0/;2`2
02h^;P<0>SXj0P1RHV8205=CD`809BDU0P0S8b<202XZ:P80=cLg0`0a<C4205=CD`80LW9b0P28R8P2
08N7Q`80Jf][0P1XJ6P305iNGP80GemO0P1MGEd204Q8B080=CDe0P0U9BD202<S8`<09RHV0P0Z:RX2
02@T90808B4Q0P0U9BD202@T90809BDU0`0Q8B42038b<P80Fe]K0P23Ph<209ZJVP80U9BD0P1eMGD3
05YJFP80De=C0P1VIVH207IfMP80UYJF0P2d];@20;Jf]P<0YJFU0P29RHT207QhN080SHf=0P2EUID2
0:b/[080^k^k0`2l_;`20;Jf]P80/;2`0P2e]KD20;^k^`80^[Zj0P2l_;`20<30`0<0`/;21031`L42
0;fm_@80][Jf0P2c/k<20:NWY`<0ZJVY102UYJD60:6QX@80YZJV0`2UYJD20:ZZZP80[jn_0P2/[:`2
0;Bd]080]kNg0P2f][H30;:b/P80[Jf]0P2WYjL20:BTY080XJ6Q0P2VYZH20:^[Z`<0[Jf]0P2/[:`2
0;6a/@80^;Rh2038h=P000H0b>3H0P1fMWH2059BDP80;Rh^0`0W9bL202/[:`80<C4a0P0k>c/203@d
=080:b/[0P0l?3`305ADE080D51@0P0m?Cd203Ti>@80<C4a0P0/;2`202/[:`<0;Bd]100_;bl203De
=@80;bl_0P0^;Rh202/[:`<0;bl_0P0n?Sh205QHF080GemO0P1HF5P20492@P80>SXj0P11@D4305EE
E@80EeMG0P1PH60204e=C@80:b/[0P0W9bL202l_;`<0@4100P1GEeL2051@D0809BDU0P0Z:RX202`/
;080>SXj0`1LG5`206QXJ080OGem0P2=SHd208J6QP80G5aL0P16ATH303lo?`80=SHf0P0_;bl202h^
;P80:RXZ0P0a<C4202TY:@<0:RXZ0P0V9RH202TY:@808b<S100R8R8202@T90<0:2PX0P0V9RH202l_
;`80GemO0P1nOWh209>CT`80NWYj0`1VIVH206UYJ@80H61P0P1LG5`207MgM`80UIFE0P2e]KD30:j^
[P80QXJ60P1gMgL20:JVYP80WYjN0P2WYjL20;bl_0<0][Jf102d];@20;Fe]@80][Jf0P2e]KD20;Zj
^P80_;bl0`31`L420;jn_P80_kno0P2n_[h20;Vi^@80];Bd0P2a/K430:VYZ@80XZ:R0P2TY:@209^K
V`80W9bL0P2RXZ820:BTY0<0YJFU0P2XZ:P20:^[Z`80[:b/0P2`/;020;Fe]@80][Jf0`2c/k<20;6a
/@80YZJV0P2RXZ8209^KV`80X:2P0P2UYJD30:b/[080[Zj^102f][H80<SPf0001P38h=P207IfMP80
DU9B0P0^;Rh302LW9`80:b/[0P0a<C4203/k>`80=3@d0P0[:b/203`l?0<0E5AD0P1@D50203dm?@80
>CTi0P0a<C4202`/;080:b/[0`0];Bd402l_;`80=CDe0P0_;bl202h^;P80:b/[0`0_;bl203hn?P80
F5QH0P1OGel205QHF080@T920P0j>SX20451@@<0EEEE0P1GEeL2061PH080CDe=0P0[:b/202LW9`80
;bl_0`10@40205MGE`80D51@0P0U9BD202XZ:P80;2`/0P0j>SX305aLG080J6QX0P1mOGd208f=S@80
QXJ60P1LG5`204I6AP<0?clo0P0f=SH202l_;`80;Rh^0P0Z:RX2034a<@80:BTY0`0Z:RX202HV9P80
:BTY0P0S8b<4028R8P8092@T0`0X:2P202HV9P80;bl_0P1OGel207inOP80Ti>C0P1jNWX306IVIP80
JFUY0P1PH60205aLG080MgMg0P2EUID20;Fe]@<0[Zj^0P26QXH207MgM`80YZJV0P2NWYh20:NWY`80
_;bl0`2f][H40;Bd]080]KFe0P2f][H20;Fe]@80^[Zj0P2l_;`30<71`@80_[jn0P2o_kl20;jn_P80
^KVi0P2d];@20;6a/@<0ZJVY0P2RXZ820:BTY080Vi^K0P2LW9`20::RXP80Y:BT0`2UYJD20:RXZ080
Zj^[0P2/[:`20;2`/080]KFe0P2f][H30;>c/`80/K6a0P2VYZH20::RXP80Vi^K0P2PX:020:FUY@<0
[:b/0P2^[Zh40;Jf]PP0b>3H00060<SPf080MWIf0P1MGEd204=3@`D0=CDe0P0m?Cd203Ti>@80;Rh^
0P0[:b/203Ph>0<0CTi>0P1OGel204Y:BP80=SHf0P0d=3@202/[:`80;Bd]0`0c<c<2034a<@80:BTY
0P0a<C4202l_;`80<S8b0P0c<c<303Ti>@80BTY:0P1RHV8205UIF@80BTY:0P0n?Sh204E5A@80AdM7
0`1BDU8205ADE080HF5Q0P0k>c/202/[:`80;bl_0P0f=SH304Q8B080EUIF0P11@D4202LW9`80:2PX
0P0^;Rh204M7A`<0MWIf0P1eMGD207inOP80PH610P1RHV8203Ti>@D0:RXZ0P0];Bd202l_;`80;Rh^
0P0`<302034a<@80=3@d0`0[:b/202l_;`80;2`/0P0^;Rh202<S8`@08R8R0`0T92@202HV9P80:BTY
0P0g=cL205mOG`80MWIf0P1lO7`306a/K080MGEe0P1LG5`204i>CP80Fe]K0P1gMgL209>CT`<0Xj>S
0P2;Rh/207YjNP80/K6a0P2HV9P209>CT`80^KVi0`2e]KD20;>c/`80][Jf0P2d];@20;Rh^080][Jf
0P2h^;P20;Zj^P<0_;bl0P2k^k/20;fm_@80^k^k0P2f][H20;Fe]@80/k>c0`2ZZZX40:FUY@80XJ6Q
0P2PX:020:6QX@80X:2P0`2VYZH20:BTY080YZJV0P2[Zj/20:b/[080/k>c0P2i^KT30;Bd]080[jn_
0P2/[:`20:NWY`80VIVI0P2LW9`20:>SX`<0WYjN0P2UYJD20:j^[P80]KFe2038h=P000H0b>3H0P1f
MWH205eMG@80@d=31@0e=CD203dm?@80>CTi0P0^;Rh202/[:`80>3Ph0`1>CTh205mOG`80BTY:0P0f
=SH203@d=080:b/[0P0];Bd303<c<`80<C4a0P0Y:BT2034a<@80;bl_0P0b<S8203<c<`<0>CTi0P1:
BTX2069RHP80FEUI0P1:BTX203hn?P80ADE50P17AdL3059BDP80E5AD0P1QHF4203/k>`80:b/[0P0_
;bl203Hf=P<0B4Q80P1FEUH20451@@809bLW0P0X:2P202h^;P80AdM70`1fMWH207EeM@80OWin0P21
PH42069RHP80>CTi1@0Z:RX202d];@80;bl_0P0^;Rh2030`<080<C4a0P0d=3@302/[:`80;bl_0P0/
;2`202h^;P808b<S100R8R8302@T90809RHV0P0Y:BT203Lg=`80GemO0P1fMWH207alO0<0K6a/0P1e
MGD205aLG080CTi>0P1KFe/207MgM`80Ti>C0`2SXj<208^;R`80NWYj0P2a/K4209RHV080Ti>C0P2i
^KT30;Fe]@80/k>c0P2f][H20;Bd]080^;Rh0P2f][H20;Rh^080^[Zj0`2l_;`20;^k^`80_Kfm0P2k
^k/20;Jf]P80]KFe0P2c/k<30:ZZZP@0YJFU0P2QXJ420:2PX080XJ6Q0P2PX:030:JVYP80Y:BT0P2V
YZH20:^[Z`80[:b/0P2c/k<20;Vi^@<0];Bd0P2_[jl20:b/[080YjNW0P2IVIT209bLW080Xj>S0`2N
WYh20:FUY@80[Zj^0P2e]KD80<SPf0001P38h=P207IfMP80GEeM0P13@d<503De=@80?Cdm0P0i>CT2
02h^;P80:b/[0P0h>3P304i>CP80GemO0P1:BTX203Hf=P80=3@d0P0[:b/202d];@<0<c<c0P0a<C42
02TY:@80<C4a0P0_;bl2038b<P80<c<c0`0i>CT204Y:BP80HV9R0P1IFET204Y:BP80?Shn0P15ADD2
04M7A`<0DU9B0P1DE5@2065QH@80>c/k0P0[:b/202l_;`80=SHf0`18B4P205IFEP80@D510P0W9bL2
02PX:080;Rh^0P17AdL307IfMP80MGEe0P1nOWh20861P@80HV9R0P0i>CT502XZ:P80;Bd]0P0_;bl2
02h^;P80<30`0P0a<C4203@d=0<0:b/[0P0_;bl202`/;080;Rh^0P0S8b<4028R8P<092@T0P0V9RH2
02TY:@80=cLg0P1OGel207IfMP80O7al0`1/K6`207EeM@80G5aL0P1>CTh205]KF`80MgMg0P2CTi<3
0:>SX`80Rh^;0P1jNWX20;6a/@80V9RH0P2CTi<20;Vi^@<0]KFe0P2c/k<20;Jf]P80];Bd0P2h^;P2
0;Jf]P80^;Rh0P2j^[X30;bl_080^k^k0P2m_Kd20;^k^`80][Jf0P2e]KD20;>c/`<0ZZZZ102UYJD2
0:6QX@80X:2P0P2QXJ420:2PX0<0YZJV0P2TY:@20:JVYP80Zj^[0P2/[:`20;>c/`80^KVi0`2d];@2
0:n_[`80[:b/0P2WYjL209VIV@80W9bL0P2SXj<309jNWP80YJFU0P2^[Zh20;Fe]@P0b>3H00060<SP
f080KFe]0P1NGUh205IFEP<0@d=30P1:BTX205=CD`80A4A40P0c<c<2034a<@80<S8b0`19BDT206IV
IP80FEUI0P19BDT20451@@80;Rh^0P0c<c<303@d=0@0:RXZ0P0`<30202/[:`80;bl_0P0d=3@303<c
<`80ATI60P1QHF4204];B`80>c/k0P15ADD204A4A080F5QH0`1EEED205]KF`80FEUI0P15ADD202TY
:@80;Bd]0P0g=cL304Q8B080D51@0P0f=SH2028R8P80;bl_0P0k>c/205YJFP<0MWIf0P25QHD207al
O080Kfm_0P1;Bd/202XZ:P80:b/[0`0/;2`2030`<080;Rh^0P0c<c<203Xj>P80<C4a0P0[:b/702TY
:@80;2`/0P0];Bd202PX:080:RXZ0`0S8b<402@T90809bLW0P0f=SH205aLG080JFUY0`1^KVh207Yj
NP80Jf][101?Cdl205mOG`80Kfm_0`29RHT208:2PP80OGem0P2a/K4209NGU`80QHF50P2c/k<30;Ng
]`80];Bd0P2g]kL20;6a/@80][Jf0P2b/[820;Jf]P80^k^k0`2f][H20;^k^`80_Kfm0P2k^k/20;Rh
^0@0];Bd0`2_[jl20:VYZ@80YjNW0P2QXJ420::RXP80Xj>S0P2UYJD30:NWY`@0YZJV0P2UYJD20:^[
Z`80/K6a1@2f][H20;2`/080[:b/0P2[Zj/20:>SX`80VYZJ0P2MWId30:FUY@80YjNW0P2YZJT20:NW
Y`P0b>3H00060<SPf080KFe]0P1NGUh205IFEP<0@d=30P1:BTX205=CD`80A4A40P0c<c<2034a<@80
<S8b0`19BDT206IVIP80FEUI0P19BDT20451@@80;Rh^0P0c<c<303@d=0@0:RXZ0P0`<30202/[:`80
;bl_0P0d=3@303<c<`80ATI60P1QHF4204];B`80>c/k0P15ADD204A4A080F5QH0`1EEED205]KF`80
FEUI0P15ADD202TY:@80;Bd]0P0g=cL304Q8B080D51@0P0f=SH2028R8P80;bl_0P0k>c/205YJFP<0
MWIf0P25QHD207alO080Kfm_0P1;Bd/202XZ:P80:b/[0`0/;2`2030`<080;Rh^0P0c<c<203Xj>P80
<C4a0P0[:b/702TY:@80;2`/0P0];Bd202PX:080:RXZ0`0S8b<402@T90809bLW0P0f=SH205aLG080
JFUY0`1^KVh207YjNP80Jf][101?Cdl205mOG`80Kfm_0`29RHT208:2PP80OGem0P2a/K4209NGU`80
QHF50P2c/k<30;Ng]`80];Bd0P2g]kL20;6a/@80][Jf0P2b/[820;Jf]P80^k^k0`2f][H20;^k^`80
_Kfm0P2k^k/20;Rh^0@0];Bd0`2_[jl20:VYZ@80YjNW0P2QXJ420::RXP80Xj>S0P2UYJD30:NWY`@0
YZJV0P2UYJD20:^[Z`80/K6a1@2f][H20;2`/080[:b/0P2[Zj/20:>SX`80VYZJ0P2MWId30:FUY@80
YjNW0P2YZJT20:NWY`P0b>3H00060<SPf080JVYZ0P1VIVH205QHF0<0Cdm?0P1WIfL2069RHP80GEeM
0P1>CTh204I6AP80>c/k0`14A4@205MGE`80FUYJ0P1?Cdl20492@P80<c<c0P0d=3@302h^;P80;bl_
0P0];Bd202h^;P80:b/[0P0a<C4203De=@<0?Cdm0P1:BTX205EEE@80DE5A0P16ATH205EEE@80A4A4
0P18B4P305EEE@80H61P0P1<C4`203dm?@80>3Ph0P0U9BD203Ph>0<0Bd];0P1?Cdl203lo?`80:2PX
0P0/;2`205iNGP80FEUI0`1kNg/20820P080K6a/0P1NGUh203De=@80:BTY0P0];Bd302l_;`80<S8b
0P0];Bd2034a<@@0<S8b0P0d=3@3030`<080;2`/0P0Z:RX2034a<@80<c<c0P0[:b/202l_;`<08B4Q
0P0W9bL202`/;0809RHV0P0e=CD203`l?080De=C0`1_Kfl208Z:RP80MWIf0P1FEUH204U9B@80E5AD
0P1MGEd306a/K080IFEU0P1lO7`20;6a/@80VYZJ0P26QXH20:NWY`<0_Kfm102g]kL20:n_[`80/k>c
0P2g]kL40;Jf]P<0]kNg0P2i^KT20;fm_@80_kno0P2l_;`20;Vi^@D0][Jf0P2][Jd20:b/[080Y:BT
0P2RXZ820:2PX080ZJVY0`2XZ:P20:VYZ@@0[Zj^0P2`/;020;>c/`80/K6a0`2h^;P20;2`/080[Zj^
0P2a/K420:^[Z`@0WIfM0`2ZZZX20:f][@80Z:RX0P2VYZH80<SPf0001P38h=P206YZJP80IVIV0P1H
F5P304m?C`80IfMW0P1RHV8205eMG@80CTi>0P16ATH203/k>`<0A4A40P1GEeL205YJFP80Cdm?0P12
@T8203<c<`80=3@d0`0^;Rh202l_;`80;Bd]0P0^;Rh202/[:`80<C4a0P0e=CD303dm?@80BTY:0P1E
EED2055AD@80ATI60P1EEED204A4A080B4Q80`1EEED2061PH080C4a<0P0m?Cd203Ph>0809BDU0P0h
>3P304];B`80Cdm?0P0o?cl202PX:080;2`/0P1NGUh205UIF@<0Ng]k0P20P80206a/K080GUiN0P0e
=CD202TY:@80;Bd]0`0_;bl2038b<P80;Bd]0P0a<C44038b<P80=3@d0`0`<30202`/;080:RXZ0P0a
<C4203<c<`80:b/[0P0_;bl3024Q8@809bLW0P0/;2`202HV9P80=CDe0P0l?3`205=CD`<0Kfm_0P2:
RXX207IfMP80EUIF0P19BDT205ADE080GEeM0`1/K6`206EUI@80O7al0P2a/K4209ZJVP80QXJ60P2W
YjL30;fm_@@0]kNg0P2_[jl20;>c/`80]kNg102f][H30;Ng]`80^KVi0P2m_Kd20;no_`80_;bl0P2i
^KT50;Jf]P80[Jf]0P2/[:`20:BTY080XZ:R0P2PX:020:VYZ@<0Z:RX0P2YZJT40:j^[P80/;2`0P2c
/k<20;6a/@<0^;Rh0P2`/;020:j^[P80/K6a0P2[Zj/409fMW@<0ZZZZ0P2][Jd20:RXZ080YZJV2038
h=P000H0b>3H0P1fMWH206m_K`80G5aL0`1KFe/207alO080LG5a0P1ZJVX205UIF@80EEEE0P1CDe<3
04U9B@80BTY:0P1ADE4204e=C@80C4a<0P0m?Cd203hn?P<0>c/k0P0b<S82030`<080:BTY0P0Z:RX2
03Ph>080>SXj0`18B4P204e=C@80B4Q80P1>CTh204=3@`80@D511015ADD305EEE@80DE5A0P17AdL2
03hn?P80>c/k0P0W9bL203Hf=P<0C4a<0P1ADE4203Ph>0809RHV0P0f=SH2075aL@80Fe]K0`1iNGT2
07QhN080GemO0P1HF5P2038b<P80:2PX0P0/;2`302/[:`80;bl_0P0j>SX202l_;`80;2`/0P0];Bd5
030`<080=SHf0P0a<C42030`<080>SXj0P0_;bl202TY:@<0:RXZ0P0/;2`202TY:@809bLW0P0Y:BT2
02`/;080@D510`1OGel206a/K080Q8B40P1[Jf/205QHF080EEEE0P1IFET3065QH@80Cdm?0P1bLW82
0:NWY`80XJ6Q0P23Ph<209fMW@<0][Jf0P2`/;020:j^[P80ZJVY0P2a/K420;Ng]`80/K6a0P2`/;03
0;>c/`80]KFe0P2g]kL20;^k^`@0_;bl0P2g]kL30;:b/P80Zj^[102][Jd20:FUY@80Xj>S0P2VYZH3
0:^[Z`80[:b/0P2_[jl20:b/[0@0/k>c0P2_[jl30;:b/P80];Bd0P2c/k<20;2`/080ZJVY0P2WYjL2
0:2PX0<0[jn_0P2c/k<20:b/[080[Jf]2038h=P000H0b>3H0P1fMWH206m_K`80G5aL0`1KFe/207al
O080LG5a0P1ZJVX205UIF@80EEEE0P1CDe<304U9B@80BTY:0P1ADE4204e=C@80C4a<0P0m?Cd203hn
?P<0>c/k0P0b<S82030`<080:BTY0P0Z:RX203Ph>080>SXj0`18B4P204e=C@80B4Q80P1>CTh204=3
@`80@D511015ADD305EEE@80DE5A0P17AdL203hn?P80>c/k0P0W9bL203Hf=P<0C4a<0P1ADE4203Ph
>0809RHV0P0f=SH2075aL@80Fe]K0`1iNGT207QhN080GemO0P1HF5P2038b<P80:2PX0P0/;2`302/[
:`80;bl_0P0j>SX202l_;`80;2`/0P0];Bd5030`<080=SHf0P0a<C42030`<080>SXj0P0_;bl202TY
:@<0:RXZ0P0/;2`202TY:@809bLW0P0Y:BT202`/;080@D510`1OGel206a/K080Q8B40P1[Jf/205QH
F080EEEE0P1IFET3065QH@80Cdm?0P1bLW820:NWY`80XJ6Q0P23Ph<209fMW@<0][Jf0P2`/;020:j^
[P80ZJVY0P2a/K420;Ng]`80/K6a0P2`/;030;>c/`80]KFe0P2g]kL20;^k^`@0_;bl0P2g]kL30;:b
/P80Zj^[102][Jd20:FUY@80Xj>S0P2VYZH30:^[Z`80[:b/0P2_[jl20:b/[0@0/k>c0P2_[jl30;:b
/P80];Bd0P2c/k<20;2`/080ZJVY0P2WYjL20:2PX0<0[jn_0P2c/k<20:b/[080[Jf]2038h=P00?l0
b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0
b>3H8@38h=P00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.20067, -3.20067, 0.468297, \
0.468297}}]
}, Open  ]],

Cell["\<\
By transposing the image, we can easily implement the 2D DWT:\
\>", "Text"],

Cell[BoxData[{
    \(\(ImgDWT = 
        Compile[{{X, _Real, 2}}, 
          ExtDWT\  /@ \ 
            Transpose[
              ExtDWT\  /@ \ Transpose[X]]];\)\), "\[IndentingNewLine]", 
    \(\(ImgIDWT = 
        Compile[{{X, _Real, 2}}, 
          ExtIDWT /@ Transpose[ExtIDWT /@ X]];\)\)}], "Input"],

Cell["\<\
It is very useful to interleave and deinterlave images too. We do this by \
creating four subimages, for the HH, LH, HL, and LL subbands.\
\>", "Text"],

Cell[BoxData[{
    \(\(DeInterleave2[X_]\  := \ 
        Table[Table[
            Table[X[\([2  a - i, 2  b - j]\)], {a, 
                1, \(Dimensions[X]\)[\([1]\)]/2}, {b, 
                1, \(Dimensions[X]\)[\([2]\)]/2}], {i, 1, 0, \(-1\)}], {j, 1, 
            0, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(Interleave2[X_] := 
      Flatten[Table[{Flatten[
              Table[{X[\([1, 1, a, b]\)], X[\([1, 2, a, b]\)]}, {a, 
                  1, \(Dimensions[X]\)[\([3]\)]}]], 
            Flatten[Table[{X[\([2, 1, a, b]\)], X[\([2, 2, a, b]\)]}, {a, 
                  1, \(Dimensions[X]\)[\([3]\)]}]]}, {b, 
            1, \(Dimensions[X]\)[\([4]\)]}], 1]\)}], "Input"],

Cell["\<\
Now that we have everything ready, we can embark on processing the chosen \
section of the image.\
\>", "Text"],

Cell[BoxData[{
    \(\(isub\  = \ ImgDWT[sub];\)\), "\[IndentingNewLine]", 
    \(\(decomp\  = \ DeInterleave2[isub];\)\)}], "Input"],

Cell["Let's show all four subbands:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Map[Graphics[Raster[\((# + 128)\)/256], AspectRatio \[Rule] 1] &, 
            decomp, {2}], GraphicsSpacing \[Rule] 0]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
88779C727C8771838388757972817582847E8E647E6A957C838577817C7C808480808180
7E8683828180837E83817D817E847D837F7C838183817E80897A7D91
7F8F58A57683807F85857A867371858A797D8C6D7F5C8D81837B81807E817D827D7A827F
83828282847D7F7D7A827F807C8180867E8484807D82817C87788288
84819264977D817C80817B807D6D86817B818C617C6B7C808081817B7F7B81817C7C7E7B
827A8283827D7C7B7F817F807B807C818182827E84807C7986797E8D
707E8E707A84877A7A827D817A7482867D79936C82757D837F8282797F7F837F7C818179
7E7E817F817B7D8181817E837A7F7E81807B81807E7F8082807D7D8B
76888290788378807C7D7C7B877C7F8478799275948A78818181837B7D817C7F817D837C
7E817F81807D7B7B7D807F818381817E828081827E7F7F7E847D7994
A46C827F8A65A87581808480858084837F7C937899897B7B807E807F81807F7C80827A7E
8381807F837C7E7E7F7D7D817B7F828181847E8184807D7E8285758B
6993827988765E997A84817F86877B8483799978948F80807F7E84817E817E827D847E81
847F7D7D8080837981827E80817D83827E7A82837E82788082847D7C
7E8C777E887E8B92807F7F838187877F8B76987684837D7B7F7F8280807F7B7E7C7F7A7F
7D7E7B7E7B7C847C85837F807A7F7F7F7F827D7E7E817D81837F7E7B
777D8B7E7C82827D6B7C7E807F798081887D9A7C798078837B85847E7E82827E7C817F81
83817F817F79817C81827D7C7F7F817E7F8384817F8481817C7F7E7E
7C9F7083868C7F85658A7F818081857F807D947C747F7D81807E7E83808080817D807D7D
807A7B7F827F837C818283807F81847D7F8082808378818582828377
7F884E8D88857D7F876482847E80827B8777967076797C808186827D818080818081817E
817E827A817B807C7B7F7E7E7E7E7F83867B87758078837C7D7F8378
837780947F797A7E837A83897F7C8489807F8E76788179817E837E8084817B7F857E8383
87787F86807F7F81807F7F808082817D867F857A7D837D847B847E86
757DA366808778798077797F917B7E7A887095717D7D81897F8082847E817C807F7C7C81
817E7F818279818181807A80837F817C8181897F7D7E7D7F857F8182
85847F807C7F897680858B6C917F82848576956D89797F7C8184827B848381827D7F8081
8378807F7D837C7C7A83827E8081828081837E80818281817B7D827D
7C758A806C7C8B738D6E7585A6757F7A828096738F787F85807B827E7F81817D847B7F83
7E7C7F7E82818181817E877D81807E7B828080847F7E7A82817B7F7C
85767F7C7C8F6986827E858E5795787F817B94718E767E7F82817F7E83817B8081757A83
7B7D7E807D81847D818180807F837E807B7E817D7F7B7B84827D8476
875E937C7C8F738D70946E7E897A807F817C926B8F7A847C80837B847E79807F7F827783
8181798083807F827D8480827B80857E7F817D7E817E7C818080807F
7C6E797F7D7A8A6B7A867A8483719A7680808B6D827F7A7680807D7B8081817F7D7D7E79
7D84817D808383807D827F827F837D7E7E81807F7F7C81837F817E7B
817677807A80976C897D85737F8860A47781926786847F7C7C82797D857F7E7F817C7E80
82817C8280847C7F7B7E817F82837B7F7E80817D827E7A808182827E
877D917280827F806F867E638A7E8C62827F8770847F848084847C7F8482807E807E8080
7D81857E7C8482808281807E847D80807F7E7D7C808281847E7E827B
7C847E817C7E7797719A7691897D83749F76876E8382868083807E7F818280837E848581
857D7F80797E7F7F83817F7E7E817E7E7C7F8082828581817D797B7E
7D7F8081817B82847981799461857C8A56A080707B8580808280817E83847F807E828081
817C82837F7E797F80847D847F7D7E807D7A7F837D837E7E81808481
8C7D7E7E83737C7F8E739473808777808379827A827B7F848584817C8783807C7E7E8280
817F818182807D8280837D7D8084837F817E827B7C8380837C807D7C
9478787D827B808282767785995C85818A6C9E7778827C807F7F7D7E85817F7E83818282
7E82818180807C7E8086848182857D7D8081837C827C807D7C7E7F82
7B7E7B80817D80837D8F6F997487947A7F8660A077817E848380827E8187837D837F7E84
82817E837F81827D7E8280817D7E80807D7C7A807D787C867F807E7B
8D7C7D787F7F817B807F7F7A82956781838487678C7E7F807C827F818080807B7F807D7D
7E7E7E7D7C7F7E7C817C807E7E7D7D7D7E7D8180817E7B817E877D7C
8C817F84797F7E83817B936E927A76957C827E80817D7C827D817F86817F7F827F868181
8082857C7B7E7F7F7D827B847D7C7C7E827F7D8483837D7B80898579
7D827B817E7C867E8376847C707F8E69787D83856D97738283827C858278807C7F848084
7D84847F7880847F807F807C7F817E797E7E7F82818180817D858475
857D847A7A81737F827F79906D9080728D807D7C86639876827C7F827F7C7D7A7F808680
7F7C7F807D7C7E8083817D837F827D87767B83817D7E847F80808073
7E7E817E7A7C837A7F7F81807D6D888E6F7A80807F8A679E7880817D7E7E7B7B7F7E827D
7C7B7B82807D7E837C827B81827E7E807B7985817E7E8382807F8076
8181827E8279808285817E7C957A8288758C7C7F877E88728E7C8081807B7F8082807E7B
837C7E847F7C81807E7F7D818181827B817F7D8282837E7D7D7A7F75
83747E837D82827D847F82837982698D927085777F81828475867A847C808280867D7C7E
7C7C80807B877E83787D7C93788986807F827C7E7F8081867D827E77
807E847F807A807C807D7B807C8C787D8C6E86777B80847C7E7B8A7F7C81847E8582817E
827A8282818C78806B806E8F758A877F8483817E7F807E84807E7E7E
827B7E787F81807D838E807E807A90669586708A7F7D817C7F7E8382787D86767985837F
7F7C857B7F858782778778897A788382827981817B79808280837E7D
817C7E84817E817E7E7884817F847D816D867F7C7C7D7C7C7E81807E887F837E7D7F7E83
7A7E82708E7F8083807C81827E7F83817F7F83838283817C81837C7A
828184797E897384818472857C7D778A718F93668F78807E827D807C7D867D84797F8B80
797C857F7D827E827E7B7E80818079837D6F8678837A7D7F7C7D8279
867C8587857E85847E7F8079817D797E946994797B8080777F8281807C7F8982807E8382
7684827B837A898282847A7F807C7F82828674807C81837C807E8077
887F86649A8482827F81857F7D7F7C7C84807A846E8B80857E7C7C7D847E8388777D807D
7C817388738D798580789564897C7F7B7F8F6D8A76847E81807C8178
777E9B489780828280858480847B838B7099688E83738F7D7A7E817C8282798778817D80
7B80817E709278868B56906288827B7685807E867C7D87827D858474
7A7A9A757A81807B817F788B88768B7F7C83786D8E708A7B7C877E78818385758A7C7E80
7D7E7D867785797F947485767F85687F82738D787D7F80787F7F837B
896D8798787F847E7E8A7783897B817D7E7E90778B876D8C7E807C7C7C83818270917384
76807E7E83867F837F81797A86857E817D7D84817F807D7E827F7E7C
678576A67983807F95787D7E7E7D807986757D855E8D8474847B7B827F837B7F8E6D907C
77827D81807A817B7D7F7384818383817A848081847C7D827E7C847E
917B6B9E7C827A82678182817F7680848377738E697B9067917C7F8081837F8082836D8E
7B8782817B867A85837E7B7E82827E8173828084857E857C7D817D7C
8085749A7A817F77728C78827D798182799275798E68928A6E8A7B8180807B8286838772
8E857E807D8A7C79757F8771778C758076986A7F7F817F8080817C82
7F876F8B7E7A8E7D7181817E7E847F7985738978867275837C74847E7F827F7E807F7685
7688887C8181788679737C79739B6687837E85827981807B7F837C7F
828C6C7D81738F7F9379807D8080908B599B7399778A757F8A797F7D80807C7F817B787C
857B7E88797F817E7A897C827A8A74988784807A7A7F837C82807C7D
7D856E808B5D8D6D8D6E7F7987867C8066AC52918F7D8770878671897984817E84827E80
7C85807B867B7F7E808B7B817D7D82827B80837E847980827D847F7B
8087798E7F7D76827E76878577876F7C88BB63908C788D7E69868A758881827E7A837A7C
79847E847A878080837E827F7E808281807F7E807F7C7F817D7D8080
88887F82797F76848180807F7991787A91A88994847B7D9771788682728780857F7E7C7D
7C7F807E857B808481807D857A7A7A8180807F7D7D7E7E807F83807B
867C857E818B6E84817C817F75997A7C927F899055857C7F8971878076817E7E82838384
818280858181837A858276787C81837D7E7E7E847C807F7C80817C7A
827084818673897F837E7F797B934C83877495816EA7797D85827382897784787A7D7C7C
7F7C807F7A817D8080817B7D84817E818379827F817E807E7C848180
7787927C7D886D8188887A768388589585769B709E62907C828D768881896F897D7F8280
81797D82797B867683827C827E7C7E8182827F7E7B83807E8081827B
5A8D6E84807980768D77827D837D7D99868E7E7B7A7E837E7F7F8376827D85728B7A8281
7E78828080828A727E89808180817D808182838183807F827E83807B
868677818A6784827785827B73798D847F996F857384847E7D8E598F6F83818E74818580
7B7B7F7B7E869266837E7E7F807C7C7E837D7D7D7C8281818281847D
81797D866E9183837B84827E737C8B6A828B7F76A0717D7B7D9C739778778D777F7C7B7D
817D857E789A926583817C7F7F8177898185847C817F8283827A8379
8083808D76787586847381827D7983798984835BAC8F72828959887C8D796C837E7A7F81
85837A7B7895846F84837F807D7D8480817D7B7A7B8181837F7E817C
827F7E7A907A877C8884837E817D808C7B858270799D8080A0577982798B76797C887980
81858580817E857D83817D7982827C837B7E8580817F807F81818080
87887B6E8A787A7E7C8872847C787F8177857B8475849386A05396757C7C837386808771
8576838278828A778484817D7D857C7F83797C80807D7F8483807D84
7C848371877C8085778779857F8A8185887D877A6D9797769A64847E7E7C798C6D7F8080
74818281807D877A837B7D7C7A857F8080807E7E8378848180857F84
7E878076718481837E857B8481807B85847481916F8D82926E7D77868080827C8A6F8984
8179837E80868D797C8B768187847A828786878476877F817A827A7B
788B7A8279947D87827D847E7B867984807E758C6F84738B60887B7878827E7C80807B80
7D88738E7A878174868A7D857E7E81877F7E847D80847F7F7D838176
7E81837581887F7E8283818186747985867C83926F817583758F85797E837A827F858177
8682877B76908A79827D808081807C7E7C817E7F837E7E82827E8379
85857883866D87867987827D8681867E88837B817C778888728E7B817F7E7F7B807C867F
7D6E8C8269A989658583837E817E81827B8082817E808180867A827D
7B917E84857882897E7F8480807D728376818E7A7D8E9576718880807E7E7E8085867A7E
83768A7D6D957E7586867D7F807E807C7D807C81837E7A837C877C81
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7D66A8887C83748687788782897A817E7A897A857D7F748181807F8880777B807F7E7E84
857D7F7B7C817D7E8482807D7D7E7E7C7D7E84817A8584857E7B7C81
7C8C7374988380897181818288858284847E7D7D8185817A83798279837D7786837D8181
7D7E7D86818285827F7E7E7D808377807B847982827C79808582817D
728C8A7C498B837678847C7F7A7F7C8482847C848383847F7D7C7E7D8181858382848679
837B857F8185807F7C857B7A827E83807C7F7F7E87837B7C8082807E
8B817B7F9A697F7B7C847D8584847F858281817A7B7C7A817D8084737D827F76827D7C7E
7E817E818483817D7D7F8381837B808281807D837E817B817B7D7E7E
8279827E81AD947E798084867B7483827A7B7D8488838A7C7A7E8180818182817E7E817E
7B8284857B7B7E7F877F7F817C827F7D81847E7C7E7E7C8580848080
86807787716A7A8E787E7B84698A807E897C7B837A7E818982847D7F7F787C7B887C7D7D
7C897E837E7B81867C827F817F7B7E7E857E7B7F88807A7E7F7C7F81
76699079878C7F557F787C83816A8C787C76858B81807A827D7F828780807978817F8080
82857D7E817C7F807F7D847E7A7D838683808483877C7B817E81817F
858C7F827D8078AB62847D7D9181877B7F83847E85797B8489827F797A80797D7F827A86
887C798083847C817F7D82827B867A797E8381827B7F80867F7C7F7E
7D8B78857B7D7B7F8F7D7B808179817F86857C7B7B7E7D7B7C7A7C83817F7F838085847C
7D7C818485797D827C807E82818189797E7C7D857F7783827B7F8283
837E877B8A7F8588698387808581808E7E7B7F817B728B7F867E85847E807F80827F8381
7B88817E7B807C7E7A7C81817C7A7F847D7E7E7E7F80758783847789
7C7D8B887C84827C7F6E9779848278837F8482797B877B79827B7E83807E84797F778385
7F7B8179827F7D8084817E80817B7A7881898381857888778082877A
7D856D748679817A80817E76827F7B6E7E808477778A8D838081747C8A807C8184807D7E
7D777A83837977857D7D87807C7F80878885827F787F7C7D79877D80
877D8890787E82808678807F7B817F7B74A282887E7A84787D7C858A7B817C8285847D7D
808786817F7F82827B81828183817B7E858281807F7F817F7A7A7F7C
787F7A6D7885797A837B829A82857D897B7D767D87867F7D7D83807E7F827E7980838082
817A7F7F817F807880817E7E837F7D7E82828081808282817B888184
76887196808A7E807F847A7A8387797F8A7F857C8B8A85867D7D7C7E7C807C797D7C8582
817E847C83837D847C7D7E7F8581857D7B7D7C80817F847B7E807B7B
877C807881797D8480817F867B4A7F8684767C8B7E7E8081817B7C79837F7D807C787983
817A7D807B7D827E7F7B7C837E7A7D82818A7F7F8083817A827C7F79
76787B817F857C788A818B8280A67D7D887882777C817F817E767D7C8183778079818280
807E858379817E807C837C7E807E807F877F8183807D808280837E80
807F817F867F7480857F7F748073AF917C838B83838777797E807F7E80818480857F827E
838C7D7D87877E7C7E827E808685817B7A77848283807B8381817B85
797E7E7685788386728B7B85808374617A837C7C7E7E7F80837D7A787D7D81847F7B7D7E
817F797A77857A7D807D857B8186807D7F7F80828080897C7D7A8481
778485737E777F8887818582797E8285837A727A7F80827F8485817E8882817E8577777F
81818382817D7E7E837E7C7E7D82837F787E81808189827C7981847E
877B85827B867A827E767C76827E7C7CA0947985777C867C7D7D8381797F7F7E7C7E8382
757D847C7A857D827E7F83808281807E8980807F7C827E7B7F8D7C89
7F827F7F7F887B7D888B8A7D8C7B85817945877D7F7D7C8280807B81867F817F7D867E83
817E7D86847F787D857D7F868286797F857D7C7F7C797780787B837E
7C878980827F75827F7A798B7C838384799A807A7D8A7E7F7D847D7D8083817E7F7F817B
85807E82858285847F7D7C7D827F7786837B847D808783827F797E7D
7D828880797B7C878181877E88867E7D7D73A3937989817D7E7780827D7E837D7C7C807E
7D817C80818383787D83857D827D807C7D7D867F807F808077857C82
7E7B7C79807C81807C887A7180787D7D84816B5C82787F837D7C817E8C7E7D80837C7982
7D7E7E7D818680837A7D817B82807F7D7F837C7B8182817E7F7F7C7F
7E8489757E7F7D7B8083768983848C827E8182834D7D818B85817D807B7D8082817D7D7C
84797D888180807E7E7E818282847F7F837E858185817E7A87808380
837D7E887F8379797A8677806E7C71777981827DAD8878778586817B807F7E7D7F807983
84818483807F817D817F81837F847A878083827E7E7587807F7C7A84
7E7F85837F7D7F827D84897F8F7E7B8E8982817E6DAF95777C7F7C807480807C7F7F887A
7F7D7A81827C7C8986817D8485847D84838780847B81817F85877F74
827F7B867B7D7F807E8A818681768A74727C8284816B87977F857E7F818085807B7C8486
7A7E867E7F8382807D797E7E7A7B857B7F82807E7C81817E7A7D8387
85817E7E827B837F83837F837A8880798F817D7F80847461917B83877B848179807E798B
8480817E7E7E85847F7C737F7D7D7B827F7F81818080848082878082
7B837D887D787A867D8A748482898B857A78807A7C7D81885B857687867B84808086817D
767F818383767F827B7D86837681807B7A8084827F85847C7A818081
809C7F887C82857B887A7A847D6E7178888278827F7E7D818F5590847A7C7D7C787A807D
857D7D80827F7C7C847C86797E7A79847C82868280858083857F8083
79837B7A8180827E91858D8281838B9186848B83818680847A9467897B7E83807F817E7D
7F8086807F8C86737A7E7C80787E8476807F7E7E878082877F7D8187
7D837D828278818F86738A79768183736A837E7880827E81807C9B63897D8080807D7F80
7E837A7C8782827A7D7A8986807B878580848381807A7984807A807C
818581867E80807E7C768C807880A2747E877A827F81877F8080799664847D827F82827A
84808177937E8782808880807E7F82837A78818184777E8580868688
8B8C89857E8285837B77827F7F7B7B8887848C817885817C8180787D90638C8680818180
7C8478847982837686897C7F7C7F7A7C7D797E7A7F807B8388838380
7F8482798181777F89767B85867D837C81826C898A7E797F80827E7E809C65797C7B7D83
82807C768C85798877758679807E807C8289807C7B7F7B7D7D7D8083
6F7B7E8C80757A81728D828488797A85888691787E8081788781868080789F697F828C77
797D8680806C7E8571837A837E817D837C877E7F817E83828180827E
8679817876787D808B807C887B8083777E7E7D74798B787A8380798184796EA879847E7C
887D7D847E868A809083768C7A7B827C85937E827B8183867E797A83
7F837677827B837E7B838F6D6992897E83817D808975868F817C7D7F8289826CA37F7E85
7D85787F837D77787D6E807087877D788278807F807E837E76777E7A
6F7287777F81838C8A95728D6D8B7C828A777A8A867784747A817F8483807F816BA18A7F
748278848082897F7E7E9B82877E847C768381817C7E827F7B857E81
86888A82767C798A89777E85857B85827F857F76698A80878284787E81827D7D826E9B87
71858180827B81848578878D756C838B6E857E7B84748A8E7A7B817F
7E8280807D7D7E727E767D827F797C7775869189968D8C88828C85817E8180857C86699B
8C78827B8B7C81767A7F877C84807F73A4807E7E868482817A7E8184
7981937F7D82817B8182727A847C727C8770627E7B756581847691827C7D7B80817B846E
A46C7B8082897B7A797379888B778E988490867C7F75847B827A7E80
798483847D8E8B877D7F797E767E8A7D806A8F858577897D7D84757D80817D7E8487807F
78996383827E88837B9087798679787C82817C837D7D757C7F7D8282
7981867A869574847B847E7E8279808A698D7D7F86858D8987838480797A7C827C777F7F
7C7C85618A837D7B7F717E87808383847A7B867B84877E7F787B817C
83896F7398687E7689857F7F8075905F887A808A7E6F756F7083777C897E857E7E7A7F8C
83787D7874887C7F7D867D817D7C857173818C7F7E80837E837F8380
7C8F8484776D8589887B7C7F8B887F86777C87807F8281808F7F7E876F8981807E807E82
88827F8176877C80847C7F7B807A8A808183847B8085827B81808478
7F7A887C778582777D7876877B87768277757D877A80848C9F94787694747B87817E7B7D
7B827E8284749B57868276877D7C7780877C7887807C7C808580847D
897584768A7A888B8082817E858271798394897E8E8B8C796F727A887D88768481828B81
7E7A7F7D81797A80868086827F7F857C7F7A857F7A8082777C7F8180
817D758A758164957B8088788382858C7F717E756E5986847F786C798573817F797C827F
83827B8182827E897D80757E817E84807E80837A78807E7C7C837B7D
7C7F7E7179898A8F81777785887E6D7D7F7E6F85848C6D7F867F8372847E757B817C8184
80827F797E827E7E83807C7D7F7D837C8686827E83857E8280817E80
796D8281827F828D847C877A807C79867F767A788D7287827C7D8D96918A838578827F81
7E837F7E82828A8478837D7E867F807B807B8587827E7C8386807E7C
7A8979856C7075768C77757885877E777B80816C76838782817E866A717E817A9F6F8481
817C7F7B817B7D81837F8188827A7F857883877E817E7C7B837C837A
7A828574877E8076798D84818F808383808D80847B89808086868A8A716A6C88759B7482
8086797F807C857E858085797E8276867E7F847B7E7D7C817684787A
7E8E817B7D7D797D88767586778F7D7F82807A7E7E7F7988856F857F8A74736E87688C70
7E7E8483837E86867F7F817E8081877B93788280807E7F7D7F787F80
78808B79857E8A807F8C8A7E88797185896F838D7D897C857D8D797D80907D837D7D7985
847F7D81777B827B77857F807C80837F818679857E8281817F7E837A
8088757C8A837B7A80817F847571707F7D838383746A7A8076807F8381838C89867B8480
8A837D77747E7F807F7E7C8A7F7F817E7D80887983787E7E7D7B7F7B
7C7F7A6E8983817B84858D867F7E898178887986747E80868781887E827C7D8A83888089
7C8D8480837F827D7A81807F8C7E7E7E80807C827D837D827B817C78
8D8282877886858281827B7B88888C77837A847B7F86828C7D7F75817F7A7E7D7682837C
7D80888A7C7B807B8683847C79827E7D7C7F817D808884867F7E7E86
736E7C7E8C7F8A797A80858783796E75818485787A7F8375877D717F8D7D88857F768B8C
77877F7F8C846F7E7B8C87807F7A807D7D79797E88808A7D81858185
7B7F797B807E8C7E7D837F81817A777E81907D848C83717E7C8389777978767B7E8B6C77
76867D73837E807E80807F7C7F817A7E857D81817F807E7B82787F76
797D8C7D7A877E7986827D877B7886937D8E887D788F97897A787F7C89787F7B7F7F816A
80777C827F7B82897F7E7A87837D7D7F7F817F827B7F7F7E847D7E7B
81817C7B92737D7F87847E778589637B6E8083807883757E84807C947B7F8874858E747D
845C877785868E79827F837D817E837B7D7B77817B807686757C8185
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5B80AE292E243D383434303633394D41362C2943686365586672767D7E807E7F82878988
8B8F8B8E89888B8C8D8F9191919092949093909694989BA0A9C1CEC9
5B5E9E8B282A322E3E313230353C443C2E3127436667605B706F767C7E81818182868889
8D8D8A898F898F8D909395939494979A95949294969A9A9FA8C3D2C9
5E5B6BB562252931322C322C343944373130274F69685C626D72787A7F7F838180898889
8B8B8B8D8D8D8E90959596979598989B969193989495989BA5BDD0C6
635B5E8DC1432B2C2B303332363C403D332F2C4D72685A6870727D7C7D807E8085848A8B
8C8D8B8A8C8E909699979996989A9B9A97959794929391979EB5CBC0
5663618EB6B53A35333B3735383E3B35322E2F586C6558666F767A7E7D81808283898B8C
8C8C8C9090929699999A9A9B9E9E9C9C97989895949290909CABC2B7
806267758BCA912C30333134373D3736332F2E5B755D54646E74797B7C7C7A828184878A
8C90908E909191989A9A9B9EA09C9D9D9A9B969592918B8B8E9BB1A5
AE786C6573A1D85E262A272E3542302F2E27265F715B52657173767A7B7E817F81858987
8D8F8F90919497969B999C989D9E9D9B9B9795928F8B8483858B9486
667B6A808187AFA53428242C4846392A2B302F56755A52646C73747C7E7C7F8381868889
929092949190949699969B9DA09B9D9B95959188847F7B8183848276
36478391A0AEB3B9A43627262C2A2C2C2E2E28596E5153666B73737B7A7E81828588898F
909091959593989A999B9B9E9E9C9E9893938C7B797E7F7D7D817D71
241D77A7ACBEBBBFBB6E25282726282F312E25536F4E5561656E74797C7C828184878A8C
92909497969795989C9E9E9D9E9D9E95948F847781846946475E5D59
231F47B4A8B9B1B9B1AC66342423242C2C282558614D505D6472767B7A817E81868B8A8D
8F909894979997999B9C9D9D9E9C9E9590897D7884867645445D6F76
261E269BA1A7ABAAB2B7AD6E3425232C2D2C26566244475A6672757D7F817F8285898E8B
919092989597969A9D999F9E9E9C9A938F8E72737F898787898A887D
2B291D73A49E95877987A9AA5B222529292B2657654846576571767D7C81808386888D8F
8E919497969A9D9D9D9E9F9F9D9F99928F89746E7D888D888C8D887C
222D232B757B786870A89E917C372425282B24565A404C556171747B7D808085878B8C91
919498989699999C9D9EA0A0A29F99968C8B76707A8488878A87807D
282F2F1E355181747BA2CDAA8F242327252924545A3C4B56626D757A7E82838687868A91
9595979696999B9FA1A1A3A2A29F9B95908E8277778186867F7C7A7B
2331312223227C7E7383C7CACF5C24292726214E523F4B5A6470777A7F838285878F8E90
949597979C9B9C9DA0A6A3A1A0A29E99928B857F7F7D83837C7E7979
2852521E1F1D4F8E7177A3C9C8C33B2725242448493B4957677077807C8381878A879193
9399989FA19DA0A3A6A5A6A7A5A3A49E958F89848184827D7D787A7C
3D6B79291E1D2B8F797187C2C8CAA428252521464338475A686F787D81828284898C9195
989B9CA1A29FA6A9A5ABA8A9A8A3A39C999288868385848080797B7C
5898902E22231F5A8F6E77B5C9CBCE84232723423D33495B6670767B828285858A8F9197
979D9E9FA0A5ACABA9AAADA9AAA5A4A099948985858784817E797A80
7CA86825262829348C716F91CAC5C9CF4528253C39394D5D6A727980818186898D8F9597
989C9CA4A8AAB1ACB0AFADA8AAA7A39F99958C8887868C81807D7C82
A36A302B222426276A876F7ABABCC6CDA52A27353239495F6B78797B8085838A8C909598
98999DA4A6A9B0ADB1B1AEA9ABA8A6A09C94928C898C8A85807C7D82
6F312326232424213E9374709DBFBFC0CC6E2B3333364B636F78767D8386848790909094
999DA1A5AAAFB3B0B1B4AEACB0A9A6A19D968D8F8C928B87827C8183
3F2E2C29272A292423728B727CC3B9C0BAC23F2A2C374E6071757A807F8185868B959496
9BA3A9ABAEB1B2B3BAB3AEAAACAAABA19D9B969391928C89857E8185
4E2E2B2B2D2831262844967774A3B9BCBAC9A028303645606E78787C7A80858E8F96989B
9EA4ACADAFB4B2B2B2ADB2ACB1ADABA7A19C969692938E8B85837E82
3B2D2E2E2C2E2B2E2A2F6C90737AAFB3C2C2D17A2331455C6976797D7F83878C9393999C
A3A6AAACAFB2B2AFB2B1AEB1B0B2ACA7A29B9A9193908C878483827E
412C3330302D312C2C2A3A99746CA2B3BAC1C4CA4F2D41546574767B7F81898D9297979F
A0A7ACAAAFB3AAAEB2B0B2ADAEAFAFAAA59E949393918D8684848083
382432302A2C2D2D2E2A2D7391637DB6AFBEBDC8B73E404E6370747A8181878D92999A9E
A3A7A8AAADAEACB2AEACABA6ABB0AFABA199968F8B918B8581827D7F
3130362C2E29303230312B3D94786BA9A9B9BEC0C6A139505C6C747B7E828C8C94979C9D
A5A7A1A8AEADA8A5A7A9AEADA7A7A9A8A39D95898B8E868482818282
2E2E2F2C2A2C343231312C2C678F627BAFB0B9BFC6CF87405B6972757E87878F95989D9F
A4A5A2A6ABA6A2A6A4A6ADA9ADA9A5ABA4A5948B898F8B8782818082
2E2A2E2D2B2D352F2E2F2425348E7D68A3B1B1B6BFC7CD744A616B737B8587909799979A
9EA0A09D99949698979B9EA0A4A8A6A5A0A59B8882868B867E828086
2A2F2F2F2C32312F2D2C27262159976B82B8A0B2B5BFC6C6685563727B84899193999896
96979593938E928E8D8E9097989CA0A59C9FA08A80848786827F7F85
2E2F32302C302E2F33332723212D858163A2A7A9B0B6C4C6BE66556A7880858B918D9194
948E8D92968689827F848B838B919B989692948D787F8583817F808A
292E2B2B2C312C2F35302726232147926480BEA0ADB4BFC7C3BC6466747E85898B8B8F90
8E918F8E8C7C757B668388717B6C9C95A3A09383797A818281818090
2B262B2F2F2E302C3031312426232372855EB2B7A5B0BAC3C9C1B7686A797F8284828E8F
8E8E84777E7A68786A868F8C9D8FA5B0ABAB9D8A7E7C787E7F828491
2A25283132303E333031372D2623283C91677EC7A1A7B4BBC8C6C1B568737B7E807E8F8E
8C817367586F828C9AA0ACB8BFC1B5A8938B777F827A767A82818394
2F2F2A343C2C37312A2A3228292325345D8E56A0AC9CB4B5C2C6C6C1BA757478777E8787
7D6545527076806C6587B7C5CBCFC9AD8B93757A7C73777B7E838690
38282A38662E31322B2D352B2A272A2C2C756567A594A1ACB9C3C7C5C2BD716F77807673
664A2E486877563D40446EC1CCCFC9BF9B70687D697279737F868A95
322A284B6D372B2A2B2B3728282E2626284B7F6091B99D98A8B5C3CAC5C3BC6E6B6F5F51
4331334D7160405D56583D82D1CECDC5934E6B6B637070777D858895
2E30276850362B262C2E352F2A35332B3F39718D62BCB2AEB6B8B8CAC9C8C4B4595F523C
332E314567385948294A514BC9C3C4AB66467B567276727F83898D90
2F302E75362E2E2B2C2E353C3354492C221F3898707DC1A5ADB2B4BACCC4C3C4A54F574B
3C2B2C3648303C2F234B4677C7BBA468313A484E7C7C7880878B9195
2C4F3B7728322A28292F66705E41272B242622679962ABBAA6ACB3BAC8C8C2BCC39C474A
403531303033322E2D323C629C86502D2B272F5F83847F82898C9296
43403564242925252963745A2D242A312828222C907F79BCAAACB0B6C3C8C1BCB9C19C42
463E3735353534312E2F3139503E2F2B2A2D598085817D828B8E939A
4629395A2326282F4D7444282D2D2F2E26272424519D6E8EBCA7AEB3C1C9C6BBB8B3C698
49534D43374037363432333431312C28394F84867C817C868C929B9C
2F2C3A542A272840654F272D2D2E2D2D2C233E25237C8C66ABB4A7ACBBC4C9C0B1ABB4C6
A254605E625A4B4B50412F51613643436B74657C747474808D999E9F
2E29394C2628294F683428262B2F282B2E513E20233D94767ABAAAAAB1BDC3C3AFA2A9B8
C7AD6A6C717175787B724082947175626A75656A60666D879C9DA1A4
242C3943363036555535272829292B4665592A4D1E215D9E7F83BEA5ADB3BDC5B99B9DAF
BDC3BA7B7881838F8F8779A09E8C8278615B534D4B547695A8A6A8A9
2627394A3A43374D38332E262825355C4856384334242F8390659AB9A1B1B7C0C1A696A4
B3BDC2BD8D788C929992999A94826D5A4C4641485B7F9EABAAABA9AC
252D29374A373846302F342B2F345C50344A512D48202A42957462A5AEAAB1B7C2B49A9B
A9BBBDC0C09B75828E8B8779716450424B50697C9BA8B1AEB1B3AFAC
23382B35313039332D2D372D363645322F4F5B2B532C24206393676FB2ADAAAFBBB99D9B
9EB7C0C3C1C0A15F5563636362675F6F798799A5ADB3B6B2B1B0B0AC
22313140473C3C322B272A2E352E4C2C244D61224E46432B2D78925F7FBFA7A8B1B3A49A
9CB0BEBEC2BBB9B0714F65747C89909498A2A8ACB0B1B5B2AFB0B0B2
232C2B2D4B635A4C3D2C2C2F3A28503B263B6828345924372C338D785A91B6A2ABACA9A0
A0B1BEBBBABBB2B1B19D818B969A9FA3A5A7A8ADAEB1B1B4B2B0B4B6
382834383E36674E4131262E3724414E2443593B2A5A452926244D8262659CAD9FA3A29D
A1AFBEBCB6B9AEAEB3A9A69C9BA2A4A4A3A3A7A7ADB1AEB0B1B2AEB7
4A3E2D2F262F40605A37292D392B325A22443D2F35357E2C201F2C69907872A4AB9EA0A0
A4B1BCBAB9B9A894B7B4A6A59C9BA0A49FA0A4A6ACAEADAFB2B4B4BA
27412C2D284C432B52472C31352F2A5530502E2B323B5A252320536A749B7478A4A5A1A3
AAB6BBB8BBB09384B2C0B6A69F999A9B9AA0A1A5AAABABB0B1B3B4BB
262B2B2A495C2F313953342F39312B4938372D394C32522C2326824732878D7782A9A2A8
AFB1C0B8BAA78F8CB0B8C3B6A89F9FA1999DA2A0A9ABADADB0B0B8BB
27282A2E603C48382E3B372E3837323A463525435A524549355A872A214390897385B2AA
A9B6BBB8B0AC9297A4AEC2C3AFA4A4A3A2949C9DA3A6ABACADB5B8BE
2E262C3263282C373D32422C323A322F3E342F4950575D5D4B6D8C351F21519684768FBB
A7B4B6B1AFAF8EA0A4B0BFC5BDA7AAA8A2A195999FA1A9A9AAB4BABF
302A2D40672A2D304A36373232363A2A383D36325C6E733B2D675A1F2223265C9F847798
B6A9B4A9A5A68AA6ADAEB7C0BBACAAA8ABA7A597959EA6A8ABB2B9BE
52462D3B68332C2B354337372C2F37303F3E344263435A2D3486412B26232424679D796E
9DB2A9A5A5A386A5ACA1BABEB8B0A8A8AAA9ABAC9D95A2A6ABAEB5BB
4844343663402A2A2C392E3B2F33334B483F3D44572F453256892F27272222202773A371
749FBAA4A59F8299A8A7B0BEADB6A9A9A7A3A4ACB59E97A3AAAEB4B7
6F4929305350292B2C322D312F3548503C4947325F303A31598538454830262321307D9A
736B9DB0A1977BA3B9AEB3C0BBB9ACA7A3A09FA7B1B9AB9AA4A8ADB4
6E3B293337523A302D2D2F322E49563F48573C2A5B2B2E3A71845E5A4B2B262423263481
8F5D6795B28888ACBAB0B8BCC0BFB6AAA59FA1A5ACB2B5ACA2A5ADB2
6C40363A2A4F4B322D2E2F30355C484251592C36502B316C7D642C2C2C312B2B2524263A
7571615B9588A09AB8B3B5B7BBBCB6B1A5A0A0A4A6ACB6AEA49CA2AE
6D57615A44475742352F2C313D514647554E33364E2751726F3B2C3132302E2C3129272A
3E6A754F6367A38CB8B1B2B5B5BBBBB6ADA6A2A8ABAFB3B1AF9FA9A9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
828A688A7783898584807F817F817B7E7E7E7E7D837C7E83837B817F857C82837D7F7E7E
7F80817E7F81827C7F7F7C81837F7E7F7D807F7E7D817D7B80817F82
7D7B88788B7D84827A7C81837A827C7E808183817C857D7D8380837E828080817D7E7E7E
80807F7F7D7F7E7D7F817D81817C817D7C807E828180817E817D827F
83807F847889837B7F7F7B7C797480757D81777F7D8482867C80807C7F7D807C7D7E7E7F
7D7E80808181807E7D7E807E7F8283817E7E827F81807C7E7C81807E
7E86887B807E8B8787867B757372767372776E757C7B797D827B7B7E7D797A7A7F7C7E7D
80837F80827F817E7F7C807F7F7E7D7F7D7E817C817F837F7F81807F
8E747C7F83798E81858B86888882827F80828281827F7E817F817F7B807E7E82807C7F82
7C7F7D807C85807F807F7C7F7B8080807E827E848183807F807E7F80
778A82847D827E8A7D8380828A7D7B7F7E7F808184817D83817F7D7B7F817D7D84857F84
7D807C7E807E7F7D7F7E827E7D837D7F7F808081848081817A7D7E7D
866F86818987767183787C788072878281847D77807E827B7D837C80827A827D80817C7F
7E81817D807F7D7E7C7F7F7B817E7E7C7E857F7C807A828384848285
737C8A7E7B7E8E8D8D828481878D8A817F8387777E83827D80857F7E7C848283817E7F81
817A7E817F8A8084827E80807F7F817F7F80807D82807F7E7F7E7C7A
848B797F887B7C7A7B857D7E80808182847D8780807D807F80837E848081807E817E807D
817B80807F837F7F7E807E7F7F7D837F807F807F7D81837C7C787A7E
777D837D7B7E8181846B877F837B82817F7C7B848381807F82818082827F7E7F7F808282
83807F817D7E7D7F82837E7D7E7C7F82837D807E817C8C89868B8681
7D7B7D7F847E84847F856C818281847E84827F7B767B7B817F82807E817E807E80827C7F
827F807F7C8380817F7F807F7D7D80807F82858480817865686E797D
8282847B85877A72796F768D8D81867981817C7F7C79847F7D7E837E7F7F817E7F81807E
817E837C807C7F82817D807E7F7D807A7D7D7D7F817B80867F817F80
7B807D7D757C8586889A9674888D7D867E717582827E877F837D7F7F7D80817E7F807C81
837C8081827F7D7E80827E8183818084828182817F807F817E7E807D
85817E7C867A797D807372929290828482827E807E8583807B847E837E7C7F8180807E83
817F7C807E8081817C807D817E7D7E7D7B807F7C83808482847F8180
7F837D777D897D81817B8576747D7D7C847F7A7F7D858381857E7F7C7F7C7F807F7E8280
7F7F81827E7E82817D81817D7C7E7F807F7F817F80838080807F8080
7D808882827E828281837D828578897E817C837E7D7D85847E817F7F80837D7D807D817E
837C82827E807E80807F817F817E7D7E7F7D817D807D837D7D807F7E
7C7E6D7D817D807B7E787F81837D85807D857F7D81807B807C837E857D807F7E7F817D81
7F827F828283827B79807F807F83817E807E7E7E817E7D7F7F7F7E80
7F848E807D7F7E7A827F7C7C808373857B8682817D7F837F8280808182807C807F7D8083
827F837B7F81807E827C847F7F7B7E7D7C8283817D7E7F7D7E827E7F
89797E7C7F837E857E7E807D7F80847D827F85817F807F8184838181817D80827C857F7C
7E7F827F80807E817D827F80827F8182847F7F7E81807F81817B8181
77807F8282817D7D7F827E7C80807E7F797982798387887C7F7F807C80837A7E7E7E8281
817F7C7E8080807F82807B807E818081817C7C7C7C7F8280817E7C80
84828076807F7A80807B7E7D7E81808175867D7A817E8185817C8282817D7F8181807F7D
8181847E8281807E847D7F827E838184817F82808181817D80837C7F
80848179837D7C7F7F7F88817E7B7E828381887A7E7F7F7D81847E7D847B7D807D83817F
837D7C81807D7C8384837F807C7C81808381817F82807D817F7F817F
7E806D837E7D847C7F79777E837C827C807B877B82817F827E7E817D7E827E7D7E7F7E7F
81837F7D817C827D7D7D80807E808080807D8282807C7F7D7F7F7E81
7C7E807F7B7F828580807C867E847F818082758C7D7F83807F80807F7F7F808481827E81
7D7F81827E7E808284837D848080838381817C838184818382847F7F
817D8682817E807F797D78787E7D807D7F7E8578857C81827F8082817F7F7E807D7C8080
8081807E81807C827F827E8281807F7E7C80827F7B817F817D827E7D
75807F847B8078818180807C847E817E7E7F7F817B837F7983807B827F7E81837F817F7F
7E7F80827E8081787F7E83857E8084817F827D818181807F847E8080
887D80807D7F7C7F79807E867A83817E7E807F82798C7E7E827E847E7E7D7E81827D7C80
827E8180827F7F7F7E7F808081837B8080817E7E7F7D7D837E847E81
7D817E86808382817A7D7A817E838080827C818085728C798382807D7D7F7E7D7D7F817F
7F807D7F817F7E7F807E7D7D8581808582847C82807D7D807C80807C
847D83817F847F827B807E7D827A838081807F7D8084728B787C7E847B808080827C7F7C
8081807F81827E7E837D7B827C7D837E817F817F7F807D817F818284
7D807B7A857B7B7E7E82827F82817F7D798183847F7D82738B7A828180827D7F7D808380
837F7F7C7F818284838481837E7B7D817F7F7F837A82807F80828280
78847A7E857A7D7A7C8080867D817C828081817D80817D8276897D7F7F7C7F84827B8083
7D7F84817F7C7D7A7F7C7C7A7D7D807B7E827E7E8182807F7F80817F
7C727E837C868184847D7D7F7D81837F7D807E817D7B807F8079847E827F7F8181837F7E
817F7E7D7E7E81847D7E7A7B7D767F8284808582817B807F80817C83
837F7C7E82827C7B7F7C7E7C8180827D80837F8480807E7C827D77817E84807F827F827D
7D7E817E7E83827D848289969493857A797B7F8083807E7F7B7B8182
877D83807B80827D7A8984837A8480867B887F7E7F7E7D8180807C78867D837F82827E7E
7F827E817B7C8985747A7F7B807E716C7E83817D7F857F867C85847F
78848683798079847485848382807E85777D7E7C888282817F81817E7F8977817E818084
807F7C7E80777C7D7C787C7D7C7A768C81757E80807F837D7E807D81
76837E808880837E7D817C7E86847B7B7C7784817279787C807F7E807D79857B807D7E83
7D7F86827E877D7E8D8776828584877D8081827F837D7C80837C7C7C
8784837E7C7E7F7D817D7D81807E827D7E89897E84888B888580807E7F7F808281807B83
7B827676827B8B7C6E7E8C787D7C7E7D7F7E817F8082827E7F80807C
817F85818B7E7C86817E7E807D74817E7E70717982797C75797C7F82827C7C83797F7B80
897C81817C86747E817275817F80817F7E7F7D807D7F7E877E808080
7E7B827B7B838480827B828481878472938B827B818282807F84807E808182758A7D7D7E
857C847C7F777D897D948C948080797C7B7A78837E807B8182827D80
7C89817E7F848083857F82777E5B87807B7D807A82817C7F807E808382817D88718C807F
75837B828781837C7B7979707A778088828A8C867F7F7D818281807D
8E7B877C7B83827F81867B7B838D7E837D7F7F7F7D83837F82807F7D7F7F7F7E8671867D
7C7E81807A7F7C80847D7B7E81847F7D7B7E81807C7C7F7F7F797E7F
7C8179807D7B8081867C708F797D848282777B837F787F7D7D7C7E7E7F7F838282877097
79837E817E84808080807C7B7F717D7F8381707C83817E7E7C81817F
87837E84867F7E897E8C8A797986827C7B7F8579868180837B847D80807D7D7F81808669
917E7C8785787E7D867F838B8C7A8585797A83808180827F7F817D82
857B877C7C82877D7B897C84807C7F7E839279867E7B7D85837C80807A817C807C7F7C8B
6F8A807F838C7D79778081786F7C777A7F81817F7D7D8580817C827E
858282848380847F807B84797F7D828A866A8A8D7E85847F877D7F7F83817E827D7D807D
84777D827B80827F84787F7B827D7F7C8383817E7D7881807F7E7D84
807C6B6F7A6E637987837B7B807F85906F887B768282867E7D847B827B7F7D7E817C817E
7D7F7F72907E817E7C887E837C7F797B747C7C848B87818381808280
82828675777E8D7C7982838481837F7F957D7D7F7A847B787F82827C827D7E817D81817F
7C807D83708B777D7D7F7F797D7E80888388817C767B817F7E7D807C
7F837E848D7B777E817C838681657989728C7C81818477827E7E7F8178838180837E837F
817D8080876E967F797E7F877D86807A78737C7A847E7E80837F827E
827E7B808A8383797D80808181848A7E807A827E7B7D8A81847A837F817F7F857E837E80
82827D828085777F9E77837B807C7880807F8281807E807C807C827C
7D7B838A6E748683818080858082797E8184887E7E9084787A827884847B817C7E7E807F
7F7F817F818581856986867F7F82837A7D80847D7F817F827F817F7D
85797D7F78827284748080857B827A867E7D7C8082758C8377867D75828877887C837B80
7E7E807E7F7D847E887775817A817F7F807F8180817F7F837F827E80
7A828178817C9067897B858380807F7B827D79757B85787E8382808C8587827D857F817D
8381817F8282847E7B84837F83847B827D837C80808280807F807F7F
8C70777E7D84718A788184877E7E847F7F7E83857A7B85827C818179748180867D807F82
827E7E80827C7A7B837C8080817A83807E7F807E807D818182818080
7F827F808678847B85868275847E7F7E7C7F7B80877F837F807E7F82807E857F7F807F7F
7F7F827F80807F7F827F8080818276817F80827F7F7D807E80838281
7A7C7F837F7D808070817E837B7A83827E7D7E7C7B817789878C7D8481837A8783807D83
80807D7D7E8083827F80807E807E8379837F7F81807F808182817C7F
7F7E807C8080897C868079817F7E7D7D817F887D777F8973686683867D82817E7E817D82
8082817B827F81818183807F817F7F8381837F7E82817E847C7F8182
78827D7C857F808076817880858482837D7C7E8787777B868C898988827E867B827E877A
857D7E80847F8181857B7D857E7F83817E8283817B8081827D7D7F7E
858E827F7E7A7D838580847E7A7D7B82817F827F7F75837D7E7D7D80827D788D7B807E80
75868080807B7F7F7C7E827E7D7F7F7E817E7D7E837C7E8180817E80
6A6A778081837F7F837C817E807F84837E83818281827982837F7D7D817E807B8B76847F
8178817F8183807C85867E8382807B807F81827D7B8D7E828380817F
878680777E7D7B827E7F7D7E7B82807E7A807F857D7C82757A7983888F867B827F837881
857F77837E7D8084787F7E807C808086807F7D7D837685807E7E7D7F
806B7C84837986817989838180787F7D84797A857F8583817F807D705F72837D807D8774
828083758C7E897C83817F7D817F858380828181837F7F7D837E8081
828E81798080857E82807B86847F79877A7B8482817C7D7A7E718393937E8182827B8284
7B7B7A8474837979817E83807F807D7D8185807F7E7F827F82817A7B
867A83868A7F767C7E838081877F8D7A7B7B817F8484837E78827E7C788087847F7E8188
80818180867682837F7F8080807F828280817D7F84847F8080818084
717C70766E788E797478837A7587868786877C807E8173858B7D827F7F867D787C817A80
89987C6E7D90857F898981848486807F84787F7E7F7E837D82797C78
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{619.188, 619.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009[0002Jb000`400?l00000o`00003oo`38h=So
0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H
003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0
b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P0
0?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38
h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000
o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SP
f6d0b>3H003o0<SPf?l0b>3HK@38h=P001D0b>3H1@28R8P407MgM`@0W9bL1@1bLW8407alO0D0QhN7
101aLG4908>3P`@0R8R81@1eMGD407UiN@@0LW9b1@21PH4407EeM@D0PX:21024Q8@407inOPD0SXj>
101TI6@407inOPD0JVYZ102EUID507alO0@0Ph>31025QHD507MgM`@0PH612@1lO7`40820P0D0Q8B4
2@20P8040861P@@0P8201@1nOWh408J6QPD0Ph>31022PX840861P@D0P8201023Ph<507inOP@0Ph>3
1021PH4507emO@@0PH611@1nOWh408B4Q0@0OGem1@23Ph<407moO`D0O7al1023Ph<40861P@D0Ph>3
1021PH4507inOP@0P8201029RHT507YjNP@0OGem1@2ATI4=0<SPf0@0OGem101VIVH50:RXZ0@0R8R8
1@1lO7`408>3P`@0M7Ad1@26QXH408N7Q`D0N7Qh1027QhL408:2PPD0RHV9101jNWX40861P@D0OWin
101jNWX508V9R@@0NWYj1025QHD507emO@@0Ogmo1@1dM7@80861P@D0P820101oOgl508R8R0@0P820
101gMgL507]kN`@0P8201@1oOgl807inOPD0Q8B41025QHD507emO@@0Ogmo101kNg/507alO0@0PH61
1@1mOGd407inOP@0Q8B41@22PX840820P0T0OGem2@1nOWh407alO0D0OGem101nOWh408B4Q0D0PH61
101jNWX508F5Q@@0Q8B41025QHD507inOP@0Ng]k101lO7`50861PAH0b>3H000E0<SPf0D0R8R8101g
MgL409bLW0D0LW9b101lO7`508N7Q`@0LG5a2@23Ph<408R8R0D0MGEe101iNGT4079bLPD0PH61101e
MGD508:2PP@0Q8B4101nOWh508j>SP@0I6AT101nOWh506YZJP@0UIFE1@1lO7`408>3P`@0QHF51@1g
MgL40861P@T0O7al1020P80508B4Q0T0P8201021PH440820P0D0OWin1026QXH508>3P`@0PX:21021
PH450820P0@0Ph>31@1nOWh408>3P`@0PH611@1mOGd40861P@D0OWin1024Q8@407emO@D0Ph>3101o
Ogl507alO0@0Ph>31021PH4508>3P`@0PH611@1nOWh40820P0@0RHV91@1jNWX407emO@D0TI6A3@38
h=P407emO@@0IVIV1@2XZ:P408R8R0D0O7al1023Ph<407AdM0D0QXJ61027QhL507QhN0@0QhN71022
PX8508V9R@@0NWYj1021PH4507inOP@0NWYj1@29RHT407YjNP@0QHF51@1mOGd407moO`D0M7Ad2021
PH450820P0@0Ogmo1@28R8P40820P0@0MgMg1@1kNg/40820P0D0Ogmo201nOWh508B4Q0@0QHF51@1m
OGd407moO`@0Ng]k1@1lO7`40861P@D0OGem101nOWh408B4Q0D0PX:21020P80907emO@T0OWin101l
O7`507emO@@0OWin1024Q8@50861P@@0NWYj1@25QHD408B4Q0@0QHF51@1nOWh407]kN`@0O7al1@21
PH4F0<SPf0005@38h=P508R8R0@0MgMg102LW9`5079bLP@0O7al1@27QhL4075aL@T0Ph>31028R8P5
07EeM@@0NGUi101bLW850861P@@0MGEe1@22PX8408B4Q0@0OWin1@2>SXh406ATI0@0OWin1@1ZJVX4
09FEU@D0O7al1023Ph<408F5Q@D0MgMg1021PH4907alO0@0P8201@24Q8@90820P0@0PH611020P805
07inOP@0QXJ61@23Ph<408:2PP@0PH611@20P80408>3P`D0OWin1023Ph<40861P@D0OGem1021PH45
07inOP@0Q8B4101mOGd508>3P`@0Ogmo1@1lO7`408>3P`@0PH611@23Ph<40861P@D0OWin1020P804
08V9R@D0NWYj101mOGd5096AT@d0b>3H101mOGd406IVIPD0Z:RX1028R8P507alO0@0Ph>3101dM7@5
08J6QP@0QhN71@1hN7P408N7Q`@0PX:21@29RHT407YjNP@0PH611@1nOWh407YjNPD0RHV9101jNWX4
08F5Q@D0OGem101oOgl507AdM0P0PH611@20P80407moO`D0R8R81020P80407MgM`D0Ng]k1020P805
07moO`P0OWin1@24Q8@408F5Q@D0OGem101oOgl407]kN`D0O7al1021PH4507emO@@0OWin1024Q8@5
08:2PP@0P8202@1mOGd907inOP@0O7al1@1mOGd407inOP@0Q8B41@21PH4407YjNPD0QHF51024Q8@4
08F5Q@D0OWin101kNg/407alO0D0PH615P38h=P001D0b>3H1@28R8P407MgM`@0W9bL1@1bLW8407al
O0D0QhN7101aLG4908>3P`@0R8R81@1eMGD407UiN@@0LW9b1@21PH4407EeM@D0PX:21024Q8@407in
OPD0SXj>101TI6@407inOPD0JVYZ102EUID507alO0@0Ph>31025QHD507MgM`@0PH612@1lO7`40820
P0D0Q8B42@20P8040861P@@0P8201@1nOWh408J6QPD0Ph>31022PX840861P@D0P8201023Ph<507in
OP@0Ph>31021PH4507emO@@0PH611@1nOWh408B4Q0@0OGem1@23Ph<407moO`D0O7al1023Ph<40861
P@D0Ph>31021PH4507inOP@0P8201029RHT507YjNP@0OGem1@2ATI4=0<SPf0@0OGem101VIVH50:RX
Z0@0R8R81@1lO7`408>3P`@0M7Ad1@26QXH408N7Q`D0N7Qh1027QhL408:2PPD0RHV9101jNWX40861
P@D0OWin101jNWX508V9R@@0NWYj1025QHD507emO@@0Ogmo1@1dM7@80861P@D0P820101oOgl508R8
R0@0P820101gMgL507]kN`@0P8201@1oOgl807inOPD0Q8B41025QHD507emO@@0Ogmo101kNg/507al
O0@0PH611@1mOGd407inOP@0Q8B41@22PX840820P0T0OGem2@1nOWh407alO0D0OGem101nOWh408B4
Q0D0PH61101jNWX508F5Q@@0Q8B41025QHD507inOP@0Ng]k101lO7`50861PAH0b>3H000E0<SPf0D0
Ogmo102?Shl405QHF0D0YJFU101fMWH508>3P`@0P820101oOgl908F5Q@D0NWYj1026QXH407=cL`D0
LG5a1025QHD508Z:RP@0NGUi101mOGd508b<S0@0KFe]101oOgl505aLG0@0SHf=1@21PH4408>3P`@0
Ng]k1@21PH440820P0D0OWin1021PH4407emO@D0PX:2101mOGd507YjNP@0PX:2101oOgl508>3P`d0
PX:21024Q8@507emO@@0Ogmo1@1mOGd407YjNP@0PX:21@1oOgl40820P0D0O7al1021PH440820P0D0
QXJ6101nOWh908B4Q0@0P8201@1mOGd408:2PPD0PH61101lO7`408N7Q`D0N7Qh1022PX8508R8R0d0
b>3H101lO7`408b<S0D0Lg=c101dM7@509RHV0@0Ph>31020P80508V9R@@0LG5a2@21PH4408:2PPD0
R8R81025QHD408:2PPT0Q8B41@1nOWh807emO@D0PH611025QHD50861P@@0NWYj1023Ph<507UiN@@0
PX:21@1iNGT408>3P`@0OGem1@1gMgL408J6QPD0Ph>3101mOGd90861P@@0OGem1@1nOWh407emO@@0
QXJ61@21PH4408:2PPD0QHF51022PX8407moO`T0OWin1@1mOGd40820P0@0Ph>31@1gMgL40820P0D0
Ng]k1024Q8@407UiN@T0PX:21@1lO7`407UiN@@0P8201@25QHD408:2PP@0PH611@1mOGdF0<SPf000
5@38h=P507moO`@0Shn?101HF5P50:FUY@@0MWIf1@23Ph<40820P0@0Ogmo2@25QHD507YjNP@0QXJ6
101cLg<5075aL@@0QHF51@2:RXX407UiN@@0OGem1@2<S8`406e]K@@0Ogmo1@1LG5`408f=S@D0PH61
1023Ph<407]kN`D0PH611020P80507inOP@0PH61101mOGd508:2PP@0OGem1@1jNWX408:2PP@0Ogmo
1@23Ph<=08:2PP@0Q8B41@1mOGd407moO`D0OGem101jNWX408:2PPD0Ogmo1020P80507alO0@0PH61
1020P80508J6QP@0OWin2@24Q8@40820P0D0OGem1022PX850861P@@0O7al1027QhL507QhN0@0PX:2
1@28R8P=0<SPf0@0O7al102<S8`507=cL`@0M7Ad1@2HV9P408>3P`@0P8201@29RHT4075aL@T0PH61
1022PX8508R8R0@0QHF51022PX8908B4Q0D0OWin201mOGd50861P@@0QHF51@21PH4407YjNP@0Ph>3
1@1iNGT408:2PPD0NGUi1023Ph<407emO@D0MgMg1026QXH508>3P`@0OGem2@21PH4407emO@D0OWin
101mOGd408J6QPD0PH611022PX8508F5Q@@0PX:2101oOgl907inOPD0OGem1020P80408>3P`D0MgMg
1020P80507]kN`@0Q8B4101iNGT908:2PPD0O7al101iNGT40820P0D0QHF51022PX840861P@D0OGem
5P38h=P001D0b>3H1@1oOgl408n?S`@0F5QH1@2UYJD407IfMPD0Ph>31020P80407moO`T0QHF51@1j
NWX408J6QP@0Lg=c1@1aLG4408F5Q@D0RXZ:101iNGT407emO@D0S8b<101]KFd407moO`D0G5aL102=
SHd50861P@@0Ph>3101kNg/50861P@@0P8201@1nOWh40861P@@0OGem1@22PX8407emO@D0NWYj1022
PX8407moO`D0Ph>33@22PX8408B4Q0D0OGem101oOgl507emO@@0NWYj1022PX8507moO`@0P8201@1l
O7`40861P@@0P8201@26QXH407inOPT0Q8B41020P80507emO@@0PX:21@21PH4407alO0@0QhN71@1h
N7P408:2PPD0R8R83@38h=P407alO0@0S8b<1@1cLg<407AdM0D0V9RH1023Ph<40820P0D0RHV9101a
LG490861P@@0PX:21@28R8P408F5Q@@0PX:22@24Q8@507inOPP0OGem1@21PH4408F5Q@D0PH61101j
NWX408>3P`D0NGUi1022PX8507UiN@@0Ph>3101mOGd507MgM`@0QXJ61@23Ph<407emO@T0PH61101m
OGd507inOP@0OGem1026QXH50861P@@0PX:21@25QHD408:2PP@0Ogmo2@1nOWh507emO@@0P8201023
Ph<507MgM`@0P8201@1kNg/408B4Q0@0NGUi2@22PX8507alO0@0NGUi1020P80508F5Q@@0PX:21021
PH4507emOAH0b>3H000E0<SPf0D0Ogmo102?Shl405QHF0D0YJFU101fMWH508>3P`@0P820101oOgl9
08F5Q@D0NWYj1026QXH407=cL`D0LG5a1025QHD508Z:RP@0NGUi101mOGd508b<S0@0KFe]101oOgl5
05aLG0@0SHf=1@21PH4408>3P`@0Ng]k1@21PH440820P0D0OWin1021PH4407emO@D0PX:2101mOGd5
07YjNP@0PX:2101oOgl508>3P`d0PX:21024Q8@507emO@@0Ogmo1@1mOGd407YjNP@0PX:21@1oOgl4
0820P0D0O7al1021PH440820P0D0QXJ6101nOWh908B4Q0@0P8201@1mOGd408:2PPD0PH61101lO7`4
08N7Q`D0N7Qh1022PX8508R8R0d0b>3H101lO7`408b<S0D0Lg=c101dM7@509RHV0@0Ph>31020P805
08V9R@@0LG5a2@21PH4408:2PPD0R8R81025QHD408:2PPT0Q8B41@1nOWh807emO@D0PH611025QHD5
0861P@@0NWYj1023Ph<507UiN@@0PX:21@1iNGT408>3P`@0OGem1@1gMgL408J6QPD0Ph>3101mOGd9
0861P@@0OGem1@1nOWh407emO@@0QXJ61@21PH4408:2PPD0QHF51022PX8407moO`T0OWin1@1mOGd4
0820P0@0Ph>31@1gMgL40820P0D0Ng]k1024Q8@407UiN@T0PX:21@1lO7`407UiN@@0P8201@25QHD4
08:2PP@0PH611@1mOGdF0<SPf0005@38h=P507moO`@0Shn?101HF5P50:FUY@@0MWIf1@23Ph<40820
P0@0Ogmo2@25QHD507YjNP@0QXJ6101cLg<5075aL@@0QHF51@2:RXX407UiN@@0OGem1@2<S8`406e]
K@@0Ogmo1@1LG5`408f=S@D0PH611023Ph<407]kN`D0PH611020P80507inOP@0PH61101mOGd508:2
PP@0OGem1@1jNWX408:2PP@0Ogmo1@23Ph<=08:2PP@0Q8B41@1mOGd407moO`D0OGem101jNWX408:2
PPD0Ogmo1020P80507alO0@0PH611020P80508J6QP@0OWin2@24Q8@40820P0D0OGem1022PX850861
P@@0O7al1027QhL507QhN0@0PX:21@28R8P=0<SPf0@0O7al102<S8`507=cL`@0M7Ad1@2HV9P408>3
P`@0P8201@29RHT4075aL@T0PH611022PX8508R8R0@0QHF51022PX8908B4Q0D0OWin201mOGd50861
P@@0QHF51@21PH4407YjNP@0Ph>31@1iNGT408:2PPD0NGUi1023Ph<407emO@D0MgMg1026QXH508>3
P`@0OGem2@21PH4407emO@D0OWin101mOGd408J6QPD0PH611022PX8508F5Q@@0PX:2101oOgl907in
OPD0OGem1020P80408>3P`D0MgMg1020P80507]kN`@0Q8B4101iNGT908:2PPD0O7al101iNGT40820
P0D0QHF51022PX840861P@D0OGem5P38h=P001D0b>3H1@24Q8@40861P@@0TY:B1@1TI6@409NGU`D0
OGem1021PH4407alO0D0P8201021PH4507]kN`@0P820101mOGd506e]K@@0QXJ61@21PH4407]kN`@0
PH611@2<S8`4065QH@@0O7al1@1[Jf/407alO0T0P8202@21PH4407]kN`D0Ogmo101kNg/90861P@T0
O7al101nOWh407]kN`D0PX:2101jNWX508:2PP@0Ph>31022PX8507emO@@0O7al1@1kNg/407moO`@0
PH611@1oOgl40820P0D0Ng]k1020P80407alO0T0PH612@22PX8407inOPD0Q8B41020P80507alO0@0
NGUi1026QXH507UiN@@0OWin1@2=SHd=0<SPf0@0LW9b102<S8`508Z:RP@0O7al1@19BDT408^;R`@0
Ph>31@1fMWH407QhN0D0Q8B4101lO7`407moO`D0NWYj101oOgl407alO0D0Q8B41022PX8508B4Q0@0
O7al1024Q8@908>3P`D0Q8B4101oOgl407emO@D0O7al101nOWh507emO@P0PH611@25QHD408>3P`D0
PX:21024Q8@408J6QPD0NGUi1023Ph<507]kN`@0QHF5101oOgl50861P@@0QHF51@20P80407moO`@0
O7al1@25QHD407]kN`D0NWYj1022PX8407inOPD0Ph>31020P80507alO0P0Ogmo1@1nOWh408N7Q`D0
Ph>3101kNg/407alO0D0P8201022PX840820P0D0OWin5P38h=P001D0b>3H1@24Q8@40861P@@0TY:B
1@1TI6@409NGU`D0OGem1021PH4407alO0D0P8201021PH4507]kN`@0P820101mOGd506e]K@@0QXJ6
1@21PH4407]kN`@0PH611@2<S8`4065QH@@0O7al1@1[Jf/407alO0T0P8202@21PH4407]kN`D0Ogmo
101kNg/90861P@T0O7al101nOWh407]kN`D0PX:2101jNWX508:2PP@0Ph>31022PX8507emO@@0O7al
1@1kNg/407moO`@0PH611@1oOgl40820P0D0Ng]k1020P80407alO0T0PH612@22PX8407inOPD0Q8B4
1020P80507alO0@0NGUi1026QXH507UiN@@0OWin1@2=SHd=0<SPf0@0LW9b102<S8`508Z:RP@0O7al
1@19BDT408^;R`@0Ph>31@1fMWH407QhN0D0Q8B4101lO7`407moO`D0NWYj101oOgl407alO0D0Q8B4
1022PX8508B4Q0@0O7al1024Q8@908>3P`D0Q8B4101oOgl407emO@D0O7al101nOWh507emO@P0PH61
1@25QHD408>3P`D0PX:21024Q8@408J6QPD0NGUi1023Ph<507]kN`@0QHF5101oOgl50861P@@0QHF5
1@20P80407moO`@0O7al1@25QHD407]kN`D0NWYj1022PX8407inOPD0Ph>31020P80507alO0P0Ogmo
1@1nOWh408N7Q`D0Ph>3101kNg/407alO0D0P8201022PX840820P0D0OWin5P38h=P001D0b>3H1@24
Q8@40861P@@0TY:B1@1TI6@409NGU`D0OGem1021PH4407alO0D0P8201021PH4507]kN`@0P820101m
OGd506e]K@@0QXJ61@21PH4407]kN`@0PH611@2<S8`4065QH@@0O7al1@1[Jf/407alO0T0P8202@21
PH4407]kN`D0Ogmo101kNg/90861P@T0O7al101nOWh407]kN`D0PX:2101jNWX508:2PP@0Ph>31022
PX8507emO@@0O7al1@1kNg/407moO`@0PH611@1oOgl40820P0D0Ng]k1020P80407alO0T0PH612@22
PX8407inOPD0Q8B41020P80507alO0@0NGUi1026QXH507UiN@@0OWin1@2=SHd=0<SPf0@0LW9b102<
S8`508Z:RP@0O7al1@19BDT408^;R`@0Ph>31@1fMWH407QhN0D0Q8B4101lO7`407moO`D0NWYj101o
Ogl407alO0D0Q8B41022PX8508B4Q0@0O7al1024Q8@908>3P`D0Q8B4101oOgl407emO@D0O7al101n
OWh507emO@P0PH611@25QHD408>3P`D0PX:21024Q8@408J6QPD0NGUi1023Ph<507]kN`@0QHF5101o
Ogl50861P@@0QHF51@20P80407moO`@0O7al1@25QHD407]kN`D0NWYj1022PX8407inOPD0Ph>31020
P80507alO0P0Ogmo1@1nOWh408N7Q`D0Ph>3101kNg/407alO0D0P8201022PX840820P0D0OWin5P38
h=P001D0b>3H1@24Q8@40861P@@0TY:B1@1TI6@409NGU`D0OGem1021PH4407alO0D0P8201021PH45
07]kN`@0P820101mOGd506e]K@@0QXJ61@21PH4407]kN`@0PH611@2<S8`4065QH@@0O7al1@1[Jf/4
07alO0T0P8202@21PH4407]kN`D0Ogmo101kNg/90861P@T0O7al101nOWh407]kN`D0PX:2101jNWX5
08:2PP@0Ph>31022PX8507emO@@0O7al1@1kNg/407moO`@0PH611@1oOgl40820P0D0Ng]k1020P804
07alO0T0PH612@22PX8407inOPD0Q8B41020P80507alO0@0NGUi1026QXH507UiN@@0OWin1@2=SHd=
0<SPf0@0LW9b102<S8`508Z:RP@0O7al1@19BDT408^;R`@0Ph>31@1fMWH407QhN0D0Q8B4101lO7`4
07moO`D0NWYj101oOgl407alO0D0Q8B41022PX8508B4Q0@0O7al1024Q8@908>3P`D0Q8B4101oOgl4
07emO@D0O7al101nOWh507emO@P0PH611@25QHD408>3P`D0PX:21024Q8@408J6QPD0NGUi1023Ph<5
07]kN`@0QHF5101oOgl50861P@@0QHF51@20P80407moO`@0O7al1@25QHD407]kN`D0NWYj1022PX84
07inOPD0Ph>31020P80507alO0P0Ogmo1@1nOWh408N7Q`D0Ph>3101kNg/407alO0D0P8201022PX84
0820P0D0OWin5P38h=P001D0b>3H1@1`L70407inOP@0SXj>1@1`L70407YjNPD0Q8B41027QhL907Yj
NP@0PX:21@1mOGd40861P@@0NWYj1@1dM7@408:2PPD0QXJ6101mOGd407UiN@D0Ti>C101/K6`408:2
PPD0MGEe101mOGd508>3P`@0Ogmo2@22PX8407UiN@T0Ogmo1023Ph<507moO`@0O7al2@21PH4407Ui
N@T0OWin1@21PH4407moO`@0PH611@1kNg/407emO@d0PH611@1nOWh408>3P`D0NWYj101oOgl407in
OPD0PH611020P80507]kN`@0PH611020P80507inOP@0Ogmo1@20P80408:2PP@0P8202@1mOGd508^;
R`d0b>3H102;Rh/40861P@D0Ng]k101oOgl509ZJVP@0JFUY101oOgl507]kN`@0O7al1@24Q8@407em
O@@0QHF52@24Q8@407moO`D0QHF51022PX890861P@@0NWYj1@1kNg/407alO0D0NWYj1021PH4407em
O@D0P8201024Q8@507=cL`@0OGem1022PX8507moO`@0MWIf1@22PX8407emO@@0O7al2@1nOWh50861
P@@0OWin1021PH4508B4Q0@0Ph>31@21PH4807emO@D0Ogmo1023Ph<50861P@@0Ph>3101kNg/50820
P0@0PX:21@21PH440820P0@0OGem1@23Ph<407inOPD0PH61101kNg/40861P@D0Ng]k101mOGd907in
OQH0b>3H000E0<SPf0D0L71`101nOWh408j>SPD0L71`101jNWX508B4Q0@0QhN72@1jNWX408:2PPD0
OGem1021PH4407YjNPD0M7Ad1022PX8508J6QP@0OGem101iNGT509>CT`@0K6a/1022PX8507EeM@@0
OGem1@23Ph<407moO`T0PX:2101iNGT907moO`@0Ph>31@1oOgl407alO0T0PH61101iNGT907inOPD0
PH61101oOgl40861P@D0Ng]k101mOGd=0861P@D0OWin1023Ph<507YjNP@0Ogmo101nOWh50861P@@0
P8201@1kNg/40861P@@0P8201@1nOWh407moO`D0P8201022PX840820P0T0OGem1@2;Rh/=0<SPf0@0
Rh^;1021PH4507]kN`@0Ogmo1@2JVYX406UYJ@@0Ogmo1@1kNg/407alO0D0Q8B4101mOGd408F5Q@T0
Q8B4101oOgl508F5Q@@0PX:22@21PH4407YjNPD0Ng]k101lO7`507YjNP@0PH61101mOGd50820P0@0
Q8B41@1cLg<407emO@@0PX:21@1oOgl407IfMPD0PX:2101mOGd407alO0T0OWin1@21PH4407inOP@0
PH611@24Q8@408>3P`D0PH61201mOGd507moO`@0Ph>31@21PH4408>3P`@0Ng]k1@20P80408:2PPD0
PH611020P80407emO@D0Ph>3101nOWh50861P@@0Ng]k1021PH4507]kN`@0OGem2@1nOWhF0<SPf000
5@38h=P5071`L0@0OWin102>SXh5071`L0@0NWYj1@24Q8@408N7Q`T0NWYj1022PX8507emO@@0PH61
101jNWX507AdM0@0PX:21@26QXH407emO@@0NGUi1@2CTi<406a/K0@0PX:21@1eMGD407emO@D0Ph>3
101oOgl908:2PP@0NGUi2@1oOgl408>3P`D0Ogmo101lO7`90861P@@0NGUi2@1nOWh50861P@@0Ogmo
1021PH4507]kN`@0OGem3@21PH4507inOP@0Ph>31@1jNWX407moO`@0OWin1@21PH440820P0D0Ng]k
1021PH440820P0D0OWin101oOgl50820P0@0PX:21020P80907emO@D0Rh^;3@38h=P408^;R`@0PH61
1@1kNg/407moO`D0VYZJ101YJFT407moO`D0Ng]k101lO7`508B4Q0@0OGem1025QHD908B4Q0@0Ogmo
1@25QHD408:2PPT0PH61101jNWX507]kN`@0O7al1@1jNWX40861P@@0OGem1@20P80408B4Q0D0Lg=c
101mOGd408:2PPD0Ogmo101fMWH508:2PP@0OGem101lO7`907inOPD0PH61101nOWh40861P@D0Q8B4
1023Ph<50861P@P0OGem1@1oOgl408>3P`D0PH611023Ph<407]kN`D0P8201022PX850861P@@0P820
101mOGd508>3P`@0OWin1@21PH4407]kN`@0PH611@1kNg/407emO@T0OWin5P38h=P001D0b>3H1@1`
L70407inOP@0SXj>1@1`L70407YjNPD0Q8B41027QhL907YjNP@0PX:21@1mOGd40861P@@0NWYj1@1d
M7@408:2PPD0QXJ6101mOGd407UiN@D0Ti>C101/K6`408:2PPD0MGEe101mOGd508>3P`@0Ogmo2@22
PX8407UiN@T0Ogmo1023Ph<507moO`@0O7al2@21PH4407UiN@T0OWin1@21PH4407moO`@0PH611@1k
Ng/407emO@d0PH611@1nOWh408>3P`D0NWYj101oOgl407inOPD0PH611020P80507]kN`@0PH611020
P80507inOP@0Ogmo1@20P80408:2PP@0P8202@1mOGd508^;R`d0b>3H102;Rh/40861P@D0Ng]k101o
Ogl509ZJVP@0JFUY101oOgl507]kN`@0O7al1@24Q8@407emO@@0QHF52@24Q8@407moO`D0QHF51022
PX890861P@@0NWYj1@1kNg/407alO0D0NWYj1021PH4407emO@D0P8201024Q8@507=cL`@0OGem1022
PX8507moO`@0MWIf1@22PX8407emO@@0O7al2@1nOWh50861P@@0OWin1021PH4508B4Q0@0Ph>31@21
PH4807emO@D0Ogmo1023Ph<50861P@@0Ph>3101kNg/50820P0@0PX:21@21PH440820P0@0OGem1@23
Ph<407inOPD0PH61101kNg/40861P@D0Ng]k101mOGd907inOQH0b>3H000E0<SPf0D0L71`101nOWh4
08j>SPD0L71`101jNWX508B4Q0@0QhN72@1jNWX408:2PPD0OGem1021PH4407YjNPD0M7Ad1022PX85
08J6QP@0OGem101iNGT509>CT`@0K6a/1022PX8507EeM@@0OGem1@23Ph<407moO`T0PX:2101iNGT9
07moO`@0Ph>31@1oOgl407alO0T0PH61101iNGT907inOPD0PH61101oOgl40861P@D0Ng]k101mOGd=
0861P@D0OWin1023Ph<507YjNP@0Ogmo101nOWh50861P@@0P8201@1kNg/40861P@@0P8201@1nOWh4
07moO`D0P8201022PX840820P0T0OGem1@2;Rh/=0<SPf0@0Rh^;1021PH4507]kN`@0Ogmo1@2JVYX4
06UYJ@@0Ogmo1@1kNg/407alO0D0Q8B4101mOGd408F5Q@T0Q8B4101oOgl508F5Q@@0PX:22@21PH44
07YjNPD0Ng]k101lO7`507YjNP@0PH61101mOGd50820P0@0Q8B41@1cLg<407emO@@0PX:21@1oOgl4
07IfMPD0PX:2101mOGd407alO0T0OWin1@21PH4407inOP@0PH611@24Q8@408>3P`D0PH61201mOGd5
07moO`@0Ph>31@21PH4408>3P`@0Ng]k1@20P80408:2PPD0PH611020P80407emO@D0Ph>3101nOWh5
0861P@@0Ng]k1021PH4507]kN`@0OGem2@1nOWhF0<SPf0005@38h=P507IfMP@0R8R81022PX85092@
T0@0N7Qh1@23Ph<407QhN0@0P8201@1lO7`407emO@D0O7al101kNg/408N7Q`D0O7al101oOgl508B4
Q0@0N7Qh101iNGT509:BTP@0MGEe102DU9@508Z:RP@0N7Qh3@21PH4508>3P`@0Ng]k1@1mOGd40861
P@@0O7al1@1oOgl40861P@D0OGem1023Ph<407alO0D0OWin1021PH4507moO`@0PH611020P80507em
O@T0Ng]k101mOGd40820P0D0Ogmo1021PH4508>3P`P0PH611@1nOWh408:2PPD0P8201021PH4408:2
PPD0OWin2@1oOgl407inOP@0Q8B41@1mOGd407UiN@D0U9BD3@38h=P408:2PP@0NGUi1@22PX8407in
OPD0PH61102][Jd409BDU0D0OWin101iNGT50820P0@0Q8B41026QXH507]kN`@0M7Ad1023Ph<508:2
PP@0NWYj1@1kNg/407emO@@0Q8B41@28R8P408>3P`D0RXZ:101lO7`407YjNPD0OWin1021PH450820
P0P0PH611@22PX840861P@T0OWin1021PH4507inOP@0Ng]k1@22PX8408B4Q0@0QHF52@1kNg/507in
OP@0Ogmo1027QhL907moO`D0PH61101lO7`408:2PPD0Ogmo101mOGd50861P@@0Q8B4101nOWh507al
O0T0OWin101lO7`408F5Q@D0P8201024Q8@90820P1H0b>3H000E0<SPf0D0MWIf1028R8P408:2PPD0
T92@101hN7P508>3P`@0N7Qh1020P80507alO0@0OGem1@1lO7`407]kN`@0QhN71@1lO7`407moO`D0
Q8B4101hN7P407UiN@D0TY:B101eMGD409BDU0D0RXZ:101hN7P=0861P@D0Ph>3101kNg/507emO@@0
PH61101lO7`507moO`@0PH611@1mOGd408>3P`@0O7al1@1nOWh40861P@D0Ogmo1021PH440820P0D0
OGem2@1kNg/407emO@@0P8201@1oOgl40861P@D0Ph>32021PH4507inOP@0PX:21@20P8040861P@@0
PX:21@1nOWh907moO`@0OWin1024Q8@507emO@@0NGUi1@2DU9@=0<SPf0@0PX:2101iNGT508:2PP@0
OWin1@21PH440:f][@@0U9BD1@1nOWh407UiN@D0P8201024Q8@408J6QPD0Ng]k101dM7@408>3P`D0
PX:2101jNWX507]kN`@0OGem1024Q8@508R8R0@0Ph>31@2:RXX407alO0@0NWYj1@1nOWh40861P@D0
P8202021PH4508:2PP@0PH612@1nOWh40861P@D0OWin101kNg/508:2PP@0Q8B41025QHD907]kN`D0
OWin101oOgl408N7Q`T0Ogmo1@21PH4407alO0@0PX:21@1oOgl407emO@D0PH611024Q8@407inOPD0
O7al2@1nOWh407alO0@0QHF51@20P80408B4Q0T0P8205P38h=P001D0b>3H1@1fMWH408R8R0@0PX:2
1@2@T90407QhN0D0Ph>3101hN7P40820P0D0O7al101mOGd507alO0@0Ng]k1027QhL507alO0@0Ogmo
1@24Q8@407QhN0@0NGUi1@2BTY8407EeM@@0U9BD1@2:RXX407QhN0d0PH611@23Ph<407]kN`D0OGem
1021PH4407alO0D0Ogmo1021PH4507emO@@0Ph>3101lO7`507inOP@0PH611@1oOgl40861P@@0P820
1@1mOGd907]kN`@0OGem1020P80507moO`@0PH611@23Ph<80861P@D0OWin1022PX850820P0@0PH61
1022PX8507inOPT0Ogmo101nOWh408B4Q0D0OGem101iNGT509BDU0d0b>3H1022PX8407UiN@D0PX:2
101nOWh50861P@@0[Jf]102DU9@507inOP@0NGUi1@20P80408B4Q0@0QXJ61@1kNg/407AdM0@0Ph>3
1@22PX8407YjNPD0Ng]k101mOGd408B4Q0D0R8R81023Ph<508Z:RP@0O7al101jNWX507inOP@0PH61
1@20P8080861P@D0PX:21021PH4907inOP@0PH611@1nOWh407]kN`D0PX:21024Q8@408F5Q@T0Ng]k
1@1nOWh407moO`@0QhN72@1oOgl50861P@@0O7al1022PX8507moO`@0OGem1@21PH4408B4Q0@0OWin
1@1lO7`907inOP@0O7al1025QHD50820P0@0Q8B42@20P80F0<SPf0005@38h=P507IfMP@0R8R81022
PX85092@T0@0N7Qh1@23Ph<407QhN0@0P8201@1lO7`407emO@D0O7al101kNg/408N7Q`D0O7al101o
Ogl508B4Q0@0N7Qh101iNGT509:BTP@0MGEe102DU9@508Z:RP@0N7Qh3@21PH4508>3P`@0Ng]k1@1m
OGd40861P@@0O7al1@1oOgl40861P@D0OGem1023Ph<407alO0D0OWin1021PH4507moO`@0PH611020
P80507emO@T0Ng]k101mOGd40820P0D0Ogmo1021PH4508>3P`P0PH611@1nOWh408:2PPD0P8201021
PH4408:2PPD0OWin2@1oOgl407inOP@0Q8B41@1mOGd407UiN@D0U9BD3@38h=P408:2PP@0NGUi1@22
PX8407inOPD0PH61102][Jd409BDU0D0OWin101iNGT50820P0@0Q8B41026QXH507]kN`@0M7Ad1023
Ph<508:2PP@0NWYj1@1kNg/407emO@@0Q8B41@28R8P408>3P`D0RXZ:101lO7`407YjNPD0OWin1021
PH450820P0P0PH611@22PX840861P@T0OWin1021PH4507inOP@0Ng]k1@22PX8408B4Q0@0QHF52@1k
Ng/507inOP@0Ogmo1027QhL907moO`D0PH61101lO7`408:2PPD0Ogmo101mOGd50861P@@0Q8B4101n
OWh507alO0T0OWin101lO7`408F5Q@D0P8201024Q8@90820P1H0b>3H000E0<SPf0D0Y:BT101/K6`4
08:2PPD0Ogmo102:RXX506EUI@@0Z:RX101eMGD50861P@@0P8201@24Q8@40820P0@0QHF51@20P804
08B4Q0D0Ph>3101oOgl407alO0D0Ti>C101hN7P409VIV@D0RHV92@1kNg/40820P0@0OWin1@20P804
07moO`D0PH611020P80407moO`D0O7al1020P80508:2PP@0NWYj101nOWh508>3P`@0PH611@20P804
07moO`@0Ph>31@1lO7`907inOP@0Ogmo2@1mOGd40861P@D0Ng]k101oOgl408:2PPT0PH611@24Q8@4
07inOP@0PH611@24Q8@40820P0D0OGem101nOWh408:2PPD0QHF5101eMGD508^;R`d0b>3H1026QXH4
0820P0D0MgMg1027QhL5075aL@@0JVYZ101jNWX508j>SP@0N7Qh1@1nOWh407]kN`@0Q8B41@1YJFT4
08Z:RP@0P8201@1nOWh408V9R@D0O7al101kNg/408>3P`D0NWYj101nOWh50861P@@0RHV91022PX85
08B4Q0@0OGem2@1oOgl407QhN0D0O7al101kNg/508R8R0@0O7al2@1mOGd407alO0D0RHV9101nOWh4
08>3P`D0OWin101kNg/50861P@@0QXJ6101lO7`508:2PP@0Ogmo1@21PH4407moO`@0Ng]k2@1nOWh5
08F5Q@@0OWin101kNg/507moO`@0R8R81@20P80407YjNP@0OWin1@1oOgl407alO0@0Ogmo1@21PH4F
0<SPf0005@38h=P50:BTY0@0K6a/1022PX8507moO`@0RXZ:1@1UIFD40:RXZ0@0MGEe1@21PH440820
P0D0Q8B41020P80408F5Q@D0P8201024Q8@508>3P`@0Ogmo101lO7`509>CT`@0N7Qh102IVIT508V9
R@T0Ng]k1020P80407inOPD0P820101oOgl50861P@@0P820101oOgl507alO0@0P8201@22PX8407Yj
NP@0OWin1@23Ph<40861P@D0P820101oOgl408>3P`D0O7al2@1nOWh407moO`T0OGem1021PH4507]k
N`@0Ogmo1022PX890861P@D0Q8B4101nOWh40861P@D0Q8B41020P80507emO@@0OWin1022PX8508F5
Q@@0MGEe1@2;Rh/=0<SPf0@0QXJ61020P80507MgM`@0QhN71@1aLG4406YZJP@0NWYj1@2>SXh407Qh
N0D0OWin101kNg/408B4Q0D0JFUY102:RXX40820P0D0OWin1029RHT507alO0@0Ng]k1023Ph<507Yj
NP@0OWin1@21PH4408V9R@@0PX:21@24Q8@407emO@T0Ogmo101hN7P507alO0@0Ng]k1@28R8P407al
O0T0OGem101lO7`508V9R@@0OWin1023Ph<507inOP@0Ng]k1@21PH4408J6QP@0O7al1@22PX8407mo
O`D0PH61101oOgl407]kN`T0OWin1@25QHD407inOP@0Ng]k1@1oOgl408R8R0D0P820101jNWX407in
OPD0Ogmo101lO7`407moO`D0PH615P38h=P001D0b>3H1@2TY:@406a/K0@0PX:21@1oOgl408Z:RPD0
IFEU102XZ:P407EeM@D0PH611020P80508B4Q0@0P8201025QHD50820P0@0Q8B41@23Ph<407moO`@0
O7al1@2CTi<407QhN0@0VIVI1@29RHT907]kN`@0P820101nOWh50820P0@0Ogmo1@21PH440820P0@0
Ogmo1@1lO7`40820P0D0PX:2101jNWX407inOPD0Ph>31021PH450820P0@0Ogmo1023Ph<507alO0T0
OWin101oOgl907emO@@0PH611@1kNg/407moO`@0PX:22@21PH4508B4Q0@0OWin1021PH4508B4Q0@0
P8201@1mOGd407inOP@0PX:21@25QHD407EeM@D0Rh^;3@38h=P408J6QP@0P8201@1gMgL408N7Q`D0
LG5a101ZJVX407YjNPD0SXj>101hN7P507inOP@0Ng]k1024Q8@506UYJ@@0RXZ:1020P80507inOP@0
RHV91@1lO7`407]kN`@0Ph>31@1jNWX407inOPD0PH611029RHT408:2PPD0Q8B4101mOGd907moO`@0
N7Qh1@1lO7`407]kN`D0R8R8101lO7`907emO@@0O7al1@29RHT407inOP@0Ph>31@1nOWh407]kN`D0
PH611026QXH407alO0D0PX:2101oOgl50861P@@0Ogmo101kNg/907inOPD0QHF5101nOWh407]kN`D0
Ogmo1028R8P50820P0@0NWYj101nOWh507moO`@0O7al101oOgl50861PAH0b>3H000E0<SPf0D0Y:BT
101/K6`408:2PPD0Ogmo102:RXX506EUI@@0Z:RX101eMGD50861P@@0P8201@24Q8@40820P0@0QHF5
1@20P80408B4Q0D0Ph>3101oOgl407alO0D0Ti>C101hN7P409VIV@D0RHV92@1kNg/40820P0@0OWin
1@20P80407moO`D0PH611020P80407moO`D0O7al1020P80508:2PP@0NWYj101nOWh508>3P`@0PH61
1@20P80407moO`@0Ph>31@1lO7`907inOP@0Ogmo2@1mOGd40861P@D0Ng]k101oOgl408:2PPT0PH61
1@24Q8@407inOP@0PH611@24Q8@40820P0D0OGem101nOWh408:2PPD0QHF5101eMGD508^;R`d0b>3H
1026QXH40820P0D0MgMg1027QhL5075aL@@0JVYZ101jNWX508j>SP@0N7Qh1@1nOWh407]kN`@0Q8B4
1@1YJFT408Z:RP@0P8201@1nOWh408V9R@D0O7al101kNg/408>3P`D0NWYj101nOWh50861P@@0RHV9
1022PX8508B4Q0@0OGem2@1oOgl407QhN0D0O7al101kNg/508R8R0@0O7al2@1mOGd407alO0D0RHV9
101nOWh408>3P`D0OWin101kNg/50861P@@0QXJ6101lO7`508:2PP@0Ogmo1@21PH4407moO`@0Ng]k
2@1nOWh508F5Q@@0OWin101kNg/507moO`@0R8R81@20P80407YjNP@0OWin1@1oOgl407alO0@0Ogmo
1@21PH4F0<SPf0005@38h=P506UYJ@@0Ti>C1022PX8507UiN@@0R8R81@1fMWH405iNGP@0VIVI1@1j
NWX408B4Q0D0PH61101oOgl408J6QPD0QhN7101kNg/508B4Q0@0Ph>3101iNGT509VIV@@0N7Qh102D
U9@508n?S`T0P820101oOgl407inOPD0Q8B41021PH4507inOP@0PH61101nOWh508:2PP@0OGem1@24
Q8@407inOP@0PH611@24Q8@407moO`T0OGem2@20P80408>3P`D0NGUi1021PH4408:2PPD0OWin1020
P8050861P@@0OGem1023Ph<508:2PP@0OWin1@1jNWX408:2PP@0Ph>31@1nOWh408:2PPD0N7Qh1020
P80408:2PPD0Q8B4101mOGd507alO0d0b>3H101fMWH406UYJ@D0T92@101iNGT508N7Q`@0S8b<101o
Ogl505EEE@@0Ogmo1@1hN7P407alO0@0Ph>31@21PH4406YZJP@0S8b<1@1hN7P407alO0D0MWIf1025
QHD408^;R`D0PH611020P80507YjNP@0PX:2101mOGd507moO`@0PX:21@27QhL80820P0D0NGUi101h
N7P50861P@@0Ogmo2@20P80408:2PPD0QHF5101mOGd407inOPD0PH61101lO7`507moO`@0P820101o
Ogl507emO@@0Q8B41@1nOWh407YjNP@0OGem1@23Ph<408J6QPD0Ph>31020P80408B4Q0D0Ph>31027
QhL507alO0@0Ng]k1021PH4507inOPP0PH611@1oOglF0<SPf0005@38h=P506UYJ@@0Ti>C1022PX85
07UiN@@0R8R81@1fMWH405iNGP@0VIVI1@1jNWX408B4Q0D0PH61101oOgl408J6QPD0QhN7101kNg/5
08B4Q0@0Ph>3101iNGT509VIV@@0N7Qh102DU9@508n?S`T0P820101oOgl407inOPD0Q8B41021PH45
07inOP@0PH61101nOWh508:2PP@0OGem1@24Q8@407inOP@0PH611@24Q8@407moO`T0OGem2@20P804
08>3P`D0NGUi1021PH4408:2PPD0OWin1020P8050861P@@0OGem1023Ph<508:2PP@0OWin1@1jNWX4
08:2PP@0Ph>31@1nOWh408:2PPD0N7Qh1020P80408:2PPD0Q8B4101mOGd507alO0d0b>3H101fMWH4
06UYJ@D0T92@101iNGT508N7Q`@0S8b<101oOgl505EEE@@0Ogmo1@1hN7P407alO0@0Ph>31@21PH44
06YZJP@0S8b<1@1hN7P407alO0D0MWIf1025QHD408^;R`D0PH611020P80507YjNP@0PX:2101mOGd5
07moO`@0PX:21@27QhL80820P0D0NGUi101hN7P50861P@@0Ogmo2@20P80408:2PPD0QHF5101mOGd4
07inOPD0PH61101lO7`507moO`@0P820101oOgl507emO@@0Q8B41@1nOWh407YjNP@0OGem1@23Ph<4
08J6QPD0Ph>31020P80408B4Q0D0Ph>31027QhL507alO0@0Ng]k1021PH4507inOPP0PH611@1oOglF
0<SPf0005@38h=P506UYJ@@0Ti>C1022PX8507UiN@@0R8R81@1fMWH405iNGP@0VIVI1@1jNWX408B4
Q0D0PH61101oOgl408J6QPD0QhN7101kNg/508B4Q0@0Ph>3101iNGT509VIV@@0N7Qh102DU9@508n?
S`T0P820101oOgl407inOPD0Q8B41021PH4507inOP@0PH61101nOWh508:2PP@0OGem1@24Q8@407in
OP@0PH611@24Q8@407moO`T0OGem2@20P80408>3P`D0NGUi1021PH4408:2PPD0OWin1020P8050861
P@@0OGem1023Ph<508:2PP@0OWin1@1jNWX408:2PP@0Ph>31@1nOWh408:2PPD0N7Qh1020P80408:2
PPD0Q8B4101mOGd507alO0d0b>3H101fMWH406UYJ@D0T92@101iNGT508N7Q`@0S8b<101oOgl505EE
E@@0Ogmo1@1hN7P407alO0@0Ph>31@21PH4406YZJP@0S8b<1@1hN7P407alO0D0MWIf1025QHD408^;
R`D0PH611020P80507YjNP@0PX:2101mOGd507moO`@0PX:21@27QhL80820P0D0NGUi101hN7P50861
P@@0Ogmo2@20P80408:2PPD0QHF5101mOGd407inOPD0PH61101lO7`507moO`@0P820101oOgl507em
O@@0Q8B41@1nOWh407YjNP@0OGem1@23Ph<408J6QPD0Ph>31020P80408B4Q0D0Ph>31027QhL507al
O0@0Ng]k1021PH4507inOPP0PH611@1oOglF0<SPf0005@38h=P506UYJ@@0Ti>C1022PX8507UiN@@0
R8R81@1fMWH405iNGP@0VIVI1@1jNWX408B4Q0D0PH61101oOgl408J6QPD0QhN7101kNg/508B4Q0@0
Ph>3101iNGT509VIV@@0N7Qh102DU9@508n?S`T0P820101oOgl407inOPD0Q8B41021PH4507inOP@0
PH61101nOWh508:2PP@0OGem1@24Q8@407inOP@0PH611@24Q8@407moO`T0OGem2@20P80408>3P`D0
NGUi1021PH4408:2PPD0OWin1020P8050861P@@0OGem1023Ph<508:2PP@0OWin1@1jNWX408:2PP@0
Ph>31@1nOWh408:2PPD0N7Qh1020P80408:2PPD0Q8B4101mOGd507alO0d0b>3H101fMWH406UYJ@D0
T92@101iNGT508N7Q`@0S8b<101oOgl505EEE@@0Ogmo1@1hN7P407alO0@0Ph>31@21PH4406YZJP@0
S8b<1@1hN7P407alO0D0MWIf1025QHD408^;R`D0PH611020P80507YjNP@0PX:2101mOGd507moO`@0
PX:21@27QhL80820P0D0NGUi101hN7P50861P@@0Ogmo2@20P80408:2PPD0QHF5101mOGd407inOPD0
PH61101lO7`507moO`@0P820101oOgl507emO@@0Q8B41@1nOWh407YjNP@0OGem1@23Ph<408J6QPD0
Ph>31020P80408B4Q0D0Ph>31027QhL507alO0@0Ng]k1021PH4507inOPP0PH611@1oOglF0<SPf000
5@38h=P506UYJ@@0Ti>C1022PX8507UiN@@0R8R81@1fMWH405iNGP@0VIVI1@1jNWX408B4Q0D0PH61
101oOgl408J6QPD0QhN7101kNg/508B4Q0@0Ph>3101iNGT509VIV@@0N7Qh102DU9@508n?S`T0P820
101oOgl407inOPD0Q8B41021PH4507inOP@0PH61101nOWh508:2PP@0OGem1@24Q8@407inOP@0PH61
1@24Q8@407moO`T0OGem2@20P80408>3P`D0NGUi1021PH4408:2PPD0OWin1020P8050861P@@0OGem
1023Ph<508:2PP@0OWin1@1jNWX408:2PP@0Ph>31@1nOWh408:2PPD0N7Qh1020P80408:2PPD0Q8B4
101mOGd507alO0d0b>3H101fMWH406UYJ@D0T92@101iNGT508N7Q`@0S8b<101oOgl505EEE@@0Ogmo
1@1hN7P407alO0@0Ph>31@21PH4406YZJP@0S8b<1@1hN7P407alO0D0MWIf1025QHD408^;R`D0PH61
1020P80507YjNP@0PX:2101mOGd507moO`@0PX:21@27QhL80820P0D0NGUi101hN7P50861P@@0Ogmo
2@20P80408:2PPD0QHF5101mOGd407inOPD0PH61101lO7`507moO`@0P820101oOgl507emO@@0Q8B4
1@1nOWh407YjNP@0OGem1@23Ph<408J6QPD0Ph>31020P80408B4Q0D0Ph>31027QhL507alO0@0Ng]k
1021PH4507inOPP0PH611@1oOglF0<SPf0005@38h=P507inOP@0S8b<101gMgL507inOP@0R8R81@1n
OWh408^;R`@0TY:B1@20P80907moO`@0Ph>31021PH4908N7Q`D0Ogmo102;Rh/407IfMPD0V9RH101f
MWH408B4Q0D0Ph>3101mOGd507]kN`P0Ogmo1@22PX890820P0@0Ogmo101kNg/507inOP@0O7al1@1o
Ogl407YjNP@0Ogmo1@1mOGd407inOPD0Ng]k101nOWh407]kN`D0O7al1024Q8@507alO0@0QHF51023
Ph<507moO`@0P8201@1jNWXA07moO`D0PX:2101mOGd907inOP@0PH611@1mOGd40861P@@0Ph>31@1o
Ogl407inOPD0Ng]k3@38h=P408F5Q@@0S8b<1@1oOgl408:2PPD0OGem1020P80407QhN0D0Zj^[101R
HV8508B4Q0P0OGem1@2ATI440861P@@0QhN71@1kNg/407moO`D0Ph>31024Q8@407inOPD0QHF5101i
NGT507]kN`@0Q8B41029RHT508:2PP@0Ogmo1@1iNGT407YjNP@0P8201@1iNGT407emO@D0Ogmo1022
PX8407YjNPD0QXJ61028R8P507alO0@0NGUi1020P80508>3P`@0Q8B41@1lO7`40861P@@0Ogmo1@1m
OGd908:2PP@0Ng]k1026QXH507YjNP@0NGUi1@1nOWh408>3P`@0PH611@22PX8407]kN`D0Ogmo1020
P80408J6QPD0Ogmo101lO7`407moO`D0OWin5P38h=P001D0b>3H1@1nOWh408b<S0@0MgMg1@1nOWh4
08R8R0D0OWin102;Rh/409:BTPD0P8202@1oOgl408>3P`@0PH612@27QhL507moO`@0Rh^;101fMWH5
09RHV0@0MWIf1024Q8@508>3P`@0OGem1@1kNg/807moO`D0PX:22@20P80407moO`@0Ng]k1@1nOWh4
07alO0D0Ogmo101jNWX407moO`D0OGem101nOWh507]kN`@0OWin101kNg/507alO0@0Q8B41@1lO7`4
08F5Q@@0Ph>31@1oOgl40820P0D0NWYj4@1oOgl508:2PP@0OGem2@1nOWh40861P@D0OGem1021PH44
08>3P`D0Ogmo101nOWh507]kN`d0b>3H1025QHD408b<S0D0Ogmo1022PX8507emO@@0P820101hN7P5
0:^[Z`@0HV9R1@24Q8@807emO@D0TI6A1021PH4408N7Q`D0Ng]k101oOgl508>3P`@0Q8B4101nOWh5
08F5Q@@0NGUi1@1kNg/408B4Q0@0RHV91@22PX8407moO`D0NGUi101jNWX40820P0D0NGUi101mOGd5
07moO`@0PX:2101jNWX508J6QP@0R8R81@1lO7`407UiN@@0P8201@23Ph<408B4Q0D0O7al1021PH44
07moO`D0OGem2@22PX8407]kN`@0QXJ61@1jNWX407UiN@D0OWin1023Ph<40861P@D0PX:2101kNg/5
07moO`@0P8201026QXH507moO`@0O7al101oOgl507inOQH0b>3H000E0<SPf0D0OWin102<S8`407Mg
M`D0OWin1028R8P507inOP@0Rh^;102BTY850820P0T0Ogmo1023Ph<40861P@T0QhN71@1oOgl408^;
R`@0MWIf1@2HV9P407IfMP@0Q8B41@23Ph<407emO@D0Ng]k201oOgl508:2PPT0P820101oOgl407]k
N`D0OWin101lO7`507moO`@0NWYj101oOgl507emO@@0OWin1@1kNg/407inOP@0Ng]k1@1lO7`408B4
Q0D0O7al1025QHD408>3P`D0Ogmo1020P80507YjNQ40Ogmo1@22PX8407emO@T0OWin1021PH4507em
O@@0PH611023Ph<507moO`@0OWin1@1kNg/=0<SPf0@0QHF5102<S8`507moO`@0PX:21@1mOGd40820
P0@0N7Qh1@2[Zj/4069RHPD0Q8B4201mOGd5096AT@@0PH611027QhL507]kN`@0Ogmo1@23Ph<408B4
Q0@0OWin1@25QHD407UiN@D0Ng]k1024Q8@408V9R@D0PX:2101oOgl507UiN@@0NWYj1020P80507Ui
N@@0OGem1@1oOgl408:2PP@0NWYj1@26QXH408R8R0D0O7al101iNGT40820P0D0Ph>31024Q8@507al
O0@0PH61101oOgl507emO@T0PX:2101kNg/408J6QPD0NWYj101iNGT507inOP@0Ph>31021PH4508:2
PP@0Ng]k1@1oOgl40820P0@0QXJ61@1oOgl407alO0@0Ogmo1@1nOWhF0<SPf0005@38h=P507inOP@0
S8b<101gMgL507inOP@0R8R81@1nOWh408^;R`@0TY:B1@20P80907moO`@0Ph>31021PH4908N7Q`D0
Ogmo102;Rh/407IfMPD0V9RH101fMWH408B4Q0D0Ph>3101mOGd507]kN`P0Ogmo1@22PX890820P0@0
Ogmo101kNg/507inOP@0O7al1@1oOgl407YjNP@0Ogmo1@1mOGd407inOPD0Ng]k101nOWh407]kN`D0
O7al1024Q8@507alO0@0QHF51023Ph<507moO`@0P8201@1jNWXA07moO`D0PX:2101mOGd907inOP@0
PH611@1mOGd40861P@@0Ph>31@1oOgl407inOPD0Ng]k3@38h=P408F5Q@@0S8b<1@1oOgl408:2PPD0
OGem1020P80407QhN0D0Zj^[101RHV8508B4Q0P0OGem1@2ATI440861P@@0QhN71@1kNg/407moO`D0
Ph>31024Q8@407inOPD0QHF5101iNGT507]kN`@0Q8B41029RHT508:2PP@0Ogmo1@1iNGT407YjNP@0
P8201@1iNGT407emO@D0Ogmo1022PX8407YjNPD0QXJ61028R8P507alO0@0NGUi1020P80508>3P`@0
Q8B41@1lO7`40861P@@0Ogmo1@1mOGd908:2PP@0Ng]k1026QXH507YjNP@0NGUi1@1nOWh408>3P`@0
PH611@22PX8407]kN`D0Ogmo1020P80408J6QPD0Ogmo101lO7`407moO`D0OWin5P38h=P001D0b>3H
1@1gMgL407emO@@0Rh^;1@1nOWh407alO0T0PX:2101mOGd506][J`@0O7al1@1nOWh40820P0@0Ogmo
1@1iNGT40820P0D0PH611028R8P407emO@D0VYZJ101lO7`407UiN@D0P820101hN7P508>3P`@0Ng]k
1025QHD508B4Q0T0OWin2022PX8507inOP@0O7al1@21PH4407moO`@0PH611@23Ph<40861P@D0Ogmo
1021PH4407moO`D0NGUi1021PH4507alO0@0PH611022PX8507emO@@0O7al2@1oOgl40861P@D0OWin
101oOgl508>3P`@0Q8B41021PH4507moO`@0Q8B42@21PH4407alO0D0Ogmo2@1nOWh=0<SPf0@0OGem
102;Rh/507QhN0@0QHF51@1kNg/407emO@@0Ng]k1@1oOgl408n?S`D0OGem101kNg/40820P0D0PH61
101iNGT40861P@D0Ogmo1026QXH508F5Q@@0O7al2@1kNg/407inOPD0OGem101kNg/407alO0D0NWYj
101lO7`508>3P`@0PH612@1oOgl408>3P`D0P8201025QHD408B4Q0D0O7al101mOGd507alO0@0PH61
1024Q8@508F5Q@@0NGUi1@1mOGd408:2PP@0O7al1@20P80407inOPD0PX:22021PH4508V9R@@0NGUi
1@1nOWh407alO0@0OGem1@25QHD407moO`D0MgMg1023Ph<408:2PPD0Ng]k101oOgl408:2PPD0Ph>3
5P38h=P001D0b>3H1@1gMgL407emO@@0Rh^;1@1nOWh407alO0T0PX:2101mOGd506][J`@0O7al1@1n
OWh40820P0@0Ogmo1@1iNGT40820P0D0PH611028R8P407emO@D0VYZJ101lO7`407UiN@D0P820101h
N7P508>3P`@0Ng]k1025QHD508B4Q0T0OWin2022PX8507inOP@0O7al1@21PH4407moO`@0PH611@23
Ph<40861P@D0Ogmo1021PH4407moO`D0NGUi1021PH4507alO0@0PH611022PX8507emO@@0O7al2@1o
Ogl40861P@D0OWin101oOgl508>3P`@0Q8B41021PH4507moO`@0Q8B42@21PH4407alO0D0Ogmo2@1n
OWh=0<SPf0@0OGem102;Rh/507QhN0@0QHF51@1kNg/407emO@@0Ng]k1@1oOgl408n?S`D0OGem101k
Ng/40820P0D0PH61101iNGT40861P@D0Ogmo1026QXH508F5Q@@0O7al2@1kNg/407inOPD0OGem101k
Ng/407alO0D0NWYj101lO7`508>3P`@0PH612@1oOgl408>3P`D0P8201025QHD408B4Q0D0O7al101m
OGd507alO0@0PH611024Q8@508F5Q@@0NGUi1@1mOGd408:2PP@0O7al1@20P80407inOPD0PX:22021
PH4508V9R@@0NGUi1@1nOWh407alO0@0OGem1@25QHD407moO`D0MgMg1023Ph<408:2PPD0Ng]k101o
Ogl408:2PPD0Ph>35P38h=P001D0b>3H1@1gMgL407emO@@0Rh^;1@1nOWh407alO0T0PX:2101mOGd5
06][J`@0O7al1@1nOWh40820P0@0Ogmo1@1iNGT40820P0D0PH611028R8P407emO@D0VYZJ101lO7`4
07UiN@D0P820101hN7P508>3P`@0Ng]k1025QHD508B4Q0T0OWin2022PX8507inOP@0O7al1@21PH44
07moO`@0PH611@23Ph<40861P@D0Ogmo1021PH4407moO`D0NGUi1021PH4507alO0@0PH611022PX85
07emO@@0O7al2@1oOgl40861P@D0OWin101oOgl508>3P`@0Q8B41021PH4507moO`@0Q8B42@21PH44
07alO0D0Ogmo2@1nOWh=0<SPf0@0OGem102;Rh/507QhN0@0QHF51@1kNg/407emO@@0Ng]k1@1oOgl4
08n?S`D0OGem101kNg/40820P0D0PH61101iNGT40861P@D0Ogmo1026QXH508F5Q@@0O7al2@1kNg/4
07inOPD0OGem101kNg/407alO0D0NWYj101lO7`508>3P`@0PH612@1oOgl408>3P`D0P8201025QHD4
08B4Q0D0O7al101mOGd507alO0@0PH611024Q8@508F5Q@@0NGUi1@1mOGd408:2PP@0O7al1@20P804
07inOPD0PX:22021PH4508V9R@@0NGUi1@1nOWh407alO0@0OGem1@25QHD407moO`D0MgMg1023Ph<4
08:2PPD0Ng]k101oOgl408:2PPD0Ph>35P38h=P001D0b>3H1@1gMgL407emO@@0Rh^;1@1nOWh407al
O0T0PX:2101mOGd506][J`@0O7al1@1nOWh40820P0@0Ogmo1@1iNGT40820P0D0PH611028R8P407em
O@D0VYZJ101lO7`407UiN@D0P820101hN7P508>3P`@0Ng]k1025QHD508B4Q0T0OWin2022PX8507in
OP@0O7al1@21PH4407moO`@0PH611@23Ph<40861P@D0Ogmo1021PH4407moO`D0NGUi1021PH4507al
O0@0PH611022PX8507emO@@0O7al2@1oOgl40861P@D0OWin101oOgl508>3P`@0Q8B41021PH4507mo
O`@0Q8B42@21PH4407alO0D0Ogmo2@1nOWh=0<SPf0@0OGem102;Rh/507QhN0@0QHF51@1kNg/407em
O@@0Ng]k1@1oOgl408n?S`D0OGem101kNg/40820P0D0PH61101iNGT40861P@D0Ogmo1026QXH508F5
Q@@0O7al2@1kNg/407inOPD0OGem101kNg/407alO0D0NWYj101lO7`508>3P`@0PH612@1oOgl408>3
P`D0P8201025QHD408B4Q0D0O7al101mOGd507alO0@0PH611024Q8@508F5Q@@0NGUi1@1mOGd408:2
PP@0O7al1@20P80407inOPD0PX:22021PH4508V9R@@0NGUi1@1nOWh407alO0@0OGem1@25QHD407mo
O`D0MgMg1023Ph<408:2PPD0Ng]k101oOgl408:2PPD0Ph>35P38h=P001D0b>3H1@1lO7`409nOW`@0
L71`1@23Ph<408J6QPD0S8b<101oOgl408F5Q@D0IFEU102:RXX507moO`@0PH611020P8050861P@@0
QHF51@1oOgl40820P0@0OGem1@2DU9@407alO0@0M7Ad1@1oOgl407emO@D0PH611020P80907inOP@0
Ph>33@20P8050861P@@0OGem1@20P80807emO@D0P820101jNWX507]kN`@0Ogmo1022PX8507moO`@0
Ph>31@1lO7`40861P@@0PX:21@23Ph<40820P0D0Ogmo1021PH4408B4Q0D0OGem101oOgl50820P0@0
PX:21020P80508>3P`@0N7Qh1@21PH4408F5Q@T0PX:21023Ph<507MgM`d0b>3H1023Ph<407inOPD0
QhN7101kNg/508Z:RP@0Ogmo1025QHD508R8R0@0JFUY1@23Ph<408N7Q`@0P8201@25QHD40861P@@0
P8201@2>SXh407inOPD0Ng]k101oOgl40861P@D0Ng]k101bLW8508^;R`@0Ogmo1026QXH507inOP@0
QHF51@24Q8@407inOP@0P8201@1oOgl40820P0D0PX:2101oOgl408>3P`D0PH61101kNg/508R8R0@0
PH61101nOWh507]kN`@0P8201@1lO7`407inOP@0NWYj1@1lO7`90861P@@0O7al101jNWX507moO`@0
Q8B41@1mOGd=07inOP@0Ogmo1@20P80407EeM@@0QhN71@23Ph<408B4Q0@0MgMg1@29RHTF0<SPf000
5@38h=P507alO0@0WinO101`L70508>3P`@0QXJ61@2<S8`407moO`@0QHF51@1UIFD408Z:RPD0Ogmo
1021PH440820P0D0PH611025QHD507moO`@0P820101mOGd509BDU0@0O7al101dM7@507moO`@0OGem
1@21PH440820P0T0OWin1023Ph<=0820P0D0PH61101mOGd50820P0P0OGem1@20P80407YjNPD0Ng]k
101oOgl408:2PPD0Ogmo1023Ph<507alO0@0PH611022PX8508>3P`@0P8201@1oOgl40861P@@0Q8B4
1@1mOGd407moO`D0P8201022PX840820P0D0Ph>3101hN7P50861P@@0QHF52@22PX8408>3P`D0MgMg
3@38h=P408>3P`@0OWin1@27QhL407]kN`D0RXZ:101oOgl408F5Q@D0R8R8101YJFT508>3P`@0QhN7
1020P80508F5Q@@0PH611020P80508j>SP@0OWin1@1kNg/407moO`@0PH611@1kNg/4079bLPD0Rh^;
101oOgl408J6QPD0OWin1025QHD508B4Q0@0OWin1020P80507moO`@0P8201@22PX8407moO`@0Ph>3
1@21PH4407]kN`D0R8R81021PH4407inOPD0Ng]k1020P80507alO0@0OWin101jNWX507alO0T0PH61
101lO7`407YjNPD0Ogmo1024Q8@507emO@d0OWin101oOgl50820P0@0MGEe1027QhL508>3P`@0Q8B4
101gMgL508V9RAH0b>3H000E0<SPf0D0O7al102OWil4071`L0D0Ph>31026QXH508b<S0@0Ogmo1025
QHD506EUI@@0RXZ:1@1oOgl40861P@@0P8201@21PH4408F5Q@D0Ogmo1020P80407emO@D0U9BD101l
O7`407AdM0D0Ogmo101mOGd50861P@@0P8202@1nOWh408>3P`d0P8201@21PH4407emO@D0P820201m
OGd50820P0@0NWYj1@1kNg/407moO`@0PX:21@1oOgl408>3P`D0O7al1021PH4408:2PPD0Ph>31020
P80507moO`@0PH611024Q8@507emO@@0Ogmo1@20P80408:2PP@0P8201@23Ph<407QhN0D0PH611025
QHD908:2PP@0Ph>31@1gMgL=0<SPf0@0Ph>3101nOWh508N7Q`@0Ng]k1@2:RXX407moO`@0QHF51@28
R8P406UYJ@D0Ph>31027QhL40820P0D0QHF51021PH440820P0D0SXj>101nOWh507]kN`@0Ogmo1021
PH4507]kN`@0LW9b1@2;Rh/407moO`@0QXJ61@1nOWh408F5Q@D0Q8B4101nOWh40820P0D0Ogmo1020
P80508:2PP@0Ogmo1023Ph<50861P@@0Ng]k1@28R8P40861P@@0OWin1@1kNg/40820P0D0O7al101n
OWh407YjNPD0O7al2@21PH4407alO0@0NWYj1@1oOgl408B4Q0D0OGem3@1nOWh407moO`D0P820101e
MGD408N7Q`D0Ph>31024Q8@407MgM`D0RHV95P38h=P001D0b>3H1@1lO7`409nOW`@0L71`1@23Ph<4
08J6QPD0S8b<101oOgl408F5Q@D0IFEU102:RXX507moO`@0PH611020P8050861P@@0QHF51@1oOgl4
0820P0@0OGem1@2DU9@407alO0@0M7Ad1@1oOgl407emO@D0PH611020P80907inOP@0Ph>33@20P805
0861P@@0OGem1@20P80807emO@D0P820101jNWX507]kN`@0Ogmo1022PX8507moO`@0Ph>31@1lO7`4
0861P@@0PX:21@23Ph<40820P0D0Ogmo1021PH4408B4Q0D0OGem101oOgl50820P0@0PX:21020P805
08>3P`@0N7Qh1@21PH4408F5Q@T0PX:21023Ph<507MgM`d0b>3H1023Ph<407inOPD0QhN7101kNg/5
08Z:RP@0Ogmo1025QHD508R8R0@0JFUY1@23Ph<408N7Q`@0P8201@25QHD40861P@@0P8201@2>SXh4
07inOPD0Ng]k101oOgl40861P@D0Ng]k101bLW8508^;R`@0Ogmo1026QXH507inOP@0QHF51@24Q8@4
07inOP@0P8201@1oOgl40820P0D0PX:2101oOgl408>3P`D0PH61101kNg/508R8R0@0PH61101nOWh5
07]kN`@0P8201@1lO7`407inOP@0NWYj1@1lO7`90861P@@0O7al101jNWX507moO`@0Q8B41@1mOGd=
07inOP@0Ogmo1@20P80407EeM@@0QhN71@23Ph<408B4Q0@0MgMg1@29RHTF0<SPf0005@38h=P507al
O0@0WinO101`L70508>3P`@0QXJ61@2<S8`407moO`@0QHF51@1UIFD408Z:RPD0Ogmo1021PH440820
P0D0PH611025QHD507moO`@0P820101mOGd509BDU0@0O7al101dM7@507moO`@0OGem1@21PH440820
P0T0OWin1023Ph<=0820P0D0PH61101mOGd50820P0P0OGem1@20P80407YjNPD0Ng]k101oOgl408:2
PPD0Ogmo1023Ph<507alO0@0PH611022PX8508>3P`@0P8201@1oOgl40861P@@0Q8B41@1mOGd407mo
O`D0P8201022PX840820P0D0Ph>3101hN7P50861P@@0QHF52@22PX8408>3P`D0MgMg3@38h=P408>3
P`@0OWin1@27QhL407]kN`D0RXZ:101oOgl408F5Q@D0R8R8101YJFT508>3P`@0QhN71020P80508F5
Q@@0PH611020P80508j>SP@0OWin1@1kNg/407moO`@0PH611@1kNg/4079bLPD0Rh^;101oOgl408J6
QPD0OWin1025QHD508B4Q0@0OWin1020P80507moO`@0P8201@22PX8407moO`@0Ph>31@21PH4407]k
N`D0R8R81021PH4407inOPD0Ng]k1020P80507alO0@0OWin101jNWX507alO0T0PH61101lO7`407Yj
NPD0Ogmo1024Q8@507emO@d0OWin101oOgl50820P0@0MGEe1027QhL508>3P`@0Q8B4101gMgL508V9
RAH0b>3H000E0<SPf0D0Ogmo1028R8P404i>CPD0SHf=1028R8P508F5Q@@0OGem101oOgl508N7Q`@0
I6AT1@22PX8408B4Q0@0OWin1@20P80408:2PPD0Ng]k1027QhL407MgM`D0UYJF101`L70407IfMPD0
NGUi101lO7`50820P0@0PH611026QXH508:2PP@0OGem1@21PH480820P0D0PH611020P8090861P@@0
OWin1@21PH4407inOPD0PX:2101jNWX40861P@D0Ng]k1020P80507alO0@0Ng]k101oOglB07inOP@0
Ogmo1@23Ph<408J6QPD0Ng]k1027QhL407EeM@D0P820101hN7P508>3P`@0O7al101mOGd507moO`@0
Ph>31@1hN7P=0<SPf0@0O7al101mOGd508^;R`@0R8R81@1lO7`408B4Q0@0PX:21@1lO7`407moO`D0
KVi^102GUiL407UiN@D0Q8B41022PX8407QhN0D0Ph>3101oOgl508B4Q0@0PX:2101iNGT507]kN`@0
QhN71@1kNg/407UiN@@0PX:21@1kNg/407inOPD0Ph>31020P80407inOPD0Q8B4101iNGT507moO`@0
MgMg1023Ph<508F5Q@@0Ogmo1@1kNg/40861P@@0NGUi1@22PX8407moO`D0OGem1020P80408B4Q0D0
PH61101nOWh50820P0@0PH61101kNg/507YjNP@0N7Qh1@21PH4408V9R@@0Ph>31@21PH4408F5Q@D0
N7Qh1028R8P407MgM`D0P8201022PX8408N7Q`D0NWYj5P38h=P001D0b>3H1@1oOgl408R8R0@0CTi>
1@2=SHd408R8R0D0QHF5101mOGd407moO`D0QhN7101TI6@508:2PP@0Q8B4101nOWh50820P0@0PX:2
1@1kNg/408N7Q`@0MgMg1@2FUYH4071`L0@0MWIf1@1iNGT407alO0D0P8201021PH4408J6QPD0PX:2
101mOGd50861P@P0P8201@21PH440820P0T0PH61101nOWh50861P@@0OWin1@22PX8407YjNP@0PH61
1@1kNg/40820P0D0O7al101kNg/407moOa80OWin101oOgl508>3P`@0QXJ61@1kNg/408N7Q`@0MGEe
1@20P80407QhN0D0Ph>3101lO7`407emO@D0Ogmo1023Ph<507QhN0d0b>3H101lO7`407emO@D0Rh^;
1028R8P507alO0@0Q8B41022PX8507alO0@0Ogmo1@1^KVh409NGU`@0NGUi1@24Q8@408:2PP@0N7Qh
1@23Ph<407moO`D0Q8B41022PX8407UiN@D0Ng]k1027QhL507]kN`@0NGUi1022PX8507]kN`@0OWin
1@23Ph<40820P0@0OWin1@24Q8@407UiN@D0Ogmo101gMgL408>3P`D0QHF5101oOgl507]kN`@0PH61
101iNGT508:2PP@0Ogmo1@1mOGd40820P0@0Q8B41@21PH4407inOPD0P8201021PH4407]kN`D0NWYj
101hN7P50861P@@0RHV91023Ph<50861P@@0QHF51@1hN7P408R8R0@0MgMg1@20P80408:2PP@0QhN7
1@1jNWXF0<SPf0005@38h=P507moO`@0R8R8101>CTh508f=S@@0R8R81@25QHD407emO@@0Ogmo1@27
QhL406ATI0D0PX:21024Q8@407inOPD0P8201022PX8507]kN`@0QhN7101gMgL509JFUP@0L71`101f
MWH507UiN@@0O7al1@20P8040861P@@0QXJ61@22PX8407emO@D0PH612020P8050861P@@0P8202@21
PH4407inOPD0PH61101nOWh508:2PP@0NWYj1021PH4507]kN`@0P8201@1lO7`407]kN`@0Ogmo4P1n
OWh407moO`D0Ph>31026QXH507]kN`@0QhN7101eMGD50820P0@0N7Qh1@23Ph<407alO0@0OGem1@1o
Ogl408>3P`D0N7Qh3@38h=P407alO0@0OGem1@2;Rh/408R8R0D0O7al1024Q8@408:2PPD0O7al101o
Ogl506i^KP@0UiNG101iNGT508B4Q0@0PX:2101hN7P508>3P`@0Ogmo1@24Q8@408:2PP@0NGUi1@1k
Ng/408N7Q`D0Ng]k101iNGT408:2PPD0Ng]k101nOWh508>3P`@0P820101nOWh508B4Q0@0NGUi1@1o
Ogl407MgM`@0Ph>31@25QHD407moO`D0Ng]k1021PH4407UiN@D0PX:2101oOgl507emO@@0P8201024
Q8@50861P@@0OWin1@20P8040861P@@0Ng]k1@1jNWX407QhN0D0PH611029RHT408>3P`D0PH611025
QHD507QhN0@0R8R8101gMgL50820P0@0PX:21027QhL507YjNQH0b>3H000E0<SPf0D0Ogmo1028R8P4
04i>CPD0SHf=1028R8P508F5Q@@0OGem101oOgl508N7Q`@0I6AT1@22PX8408B4Q0@0OWin1@20P804
08:2PPD0Ng]k1027QhL407MgM`D0UYJF101`L70407IfMPD0NGUi101lO7`50820P0@0PH611026QXH5
08:2PP@0OGem1@21PH480820P0D0PH611020P8090861P@@0OWin1@21PH4407inOPD0PX:2101jNWX4
0861P@D0Ng]k1020P80507alO0@0Ng]k101oOglB07inOP@0Ogmo1@23Ph<408J6QPD0Ng]k1027QhL4
07EeM@D0P820101hN7P508>3P`@0O7al101mOGd507moO`@0Ph>31@1hN7P=0<SPf0@0O7al101mOGd5
08^;R`@0R8R81@1lO7`408B4Q0@0PX:21@1lO7`407moO`D0KVi^102GUiL407UiN@D0Q8B41022PX84
07QhN0D0Ph>3101oOgl508B4Q0@0PX:2101iNGT507]kN`@0QhN71@1kNg/407UiN@@0PX:21@1kNg/4
07inOPD0Ph>31020P80407inOPD0Q8B4101iNGT507moO`@0MgMg1023Ph<508F5Q@@0Ogmo1@1kNg/4
0861P@@0NGUi1@22PX8407moO`D0OGem1020P80408B4Q0D0PH61101nOWh50820P0@0PH61101kNg/5
07YjNP@0N7Qh1@21PH4408V9R@@0Ph>31@21PH4408F5Q@D0N7Qh1028R8P407MgM`D0P8201022PX84
08N7Q`D0NWYj5P38h=P001D0b>3H1@23Ph<407MgM`@0P8201@2DU9@407moO`D0NGUi101jNWX407in
OPD0Ph>3101jNWX508>3P`@0RHV9101oOgl507alO0@0Q8B41@29RHT40820P0@0Ogmo1@2>SXh407If
MP@0N7Qh1@21PH4407UiN@D0PH61101nOWh408>3P`D0OWin1020P80508B4Q0@0PH61101kNg/507mo
O`@0QHF51@1nOWh808>3P`D0QhN7101hN7P507moO`@0QXJ61020P80907moO`D0PH611020P80907mo
O`T0P8201022PX840861P@D0OGem1026QXH507moO`@0QHF5101jNWX507emO@@0Ph>31@1mOGd408B4
Q0@0Ng]k1@24Q8@407inOPD0QXJ63@38h=P407emO@@0QHF51@1]KFd407AdM0D0QXJ6101iNGT40861
P@D0NWYj1020P8050861P@@0OWin101fMWH508:2PP@0Ogmo101kNg/506i^KP@0OWin1@20P80408B4
Q0T0MgMg102:RXX508f=S@@0Ph>31020P8050861P@@0M7Ad1@1lO7`408Z:RP@0P8201@1lO7`40861
P@D0Q8B41020P80407emO@D0OWin101mOGd507MgM`@0NWYj2@23Ph<407UiN@D0MgMg1025QHD907em
O@@0QhN71@20P80407alO0@0Ogmo1@20P80408N7Q`D0R8R81025QHD408:2PPD0Ogmo101hN7P507mo
O`@0O7al101mOGd507UiN@@0QhN7101mOGd50820P1H0b>3H000E0<SPf0D0Ph>3101gMgL40820P0D0
U9BD101oOgl507UiN@@0NWYj101nOWh508>3P`@0NWYj1@23Ph<408V9R@@0Ogmo1@1lO7`408B4Q0D0
RHV91020P80407moO`D0SXj>101fMWH407QhN0D0PH61101iNGT50861P@@0OWin1023Ph<507inOP@0
P8201@24Q8@40861P@@0Ng]k1@1oOgl408F5Q@D0OWin2023Ph<508N7Q`@0N7Qh1@1oOgl408J6QP@0
P8202@1oOgl50861P@@0P8202@1oOgl90820P0@0PX:21021PH4507emO@@0QXJ61@1oOgl408F5Q@@0
NWYj1@1mOGd408>3P`D0OGem1024Q8@407]kN`D0Q8B4101nOWh508J6QPd0b>3H101mOGd408F5Q@D0
KFe]101dM7@508J6QP@0NGUi1021PH4507YjNP@0P8201@21PH4407inOP@0MWIf1@22PX8407moO`@0
Ng]k1@1^KVh407inOPD0P8201024Q8@907MgM`@0RXZ:1@2=SHd408>3P`@0P8201@21PH4407AdM0D0
O7al102:RXX40820P0D0O7al1021PH4508B4Q0@0P820101mOGd507inOP@0OGem1@1gMgL407YjNPT0
Ph>3101iNGT507MgM`@0QHF52@1mOGd408N7Q`D0P820101lO7`407moO`D0P8201027QhL508R8R0@0
QHF51022PX8507moO`@0N7Qh1@1oOgl407alO0@0OGem1@1iNGT408N7Q`@0OGem1@20P80F0<SPf000
5@38h=P508>3P`@0MgMg1020P80509BDU0@0Ogmo1@1iNGT407YjNP@0OWin1@23Ph<407YjNPD0Ph>3
1029RHT407moO`D0O7al1024Q8@508V9R@@0P820101oOgl508j>SP@0MWIf101hN7P50861P@@0NGUi
1@21PH4407inOP@0Ph>31@1nOWh40820P0D0Q8B41021PH4407]kN`D0Ogmo1025QHD507inOPP0Ph>3
1@27QhL407QhN0D0Ogmo1026QXH40820P0T0Ogmo1@21PH440820P0T0Ogmo2@20P80408:2PP@0PH61
1@1mOGd408J6QPD0Ogmo1025QHD407YjNPD0OGem1023Ph<507emO@@0Q8B4101kNg/508B4Q0@0OWin
1@26QXH=0<SPf0@0OGem1025QHD506e]K@@0M7Ad1@26QXH407UiN@@0PH611@1jNWX40820P0D0PH61
101nOWh407IfMPD0PX:2101oOgl407]kN`D0KVi^101nOWh50820P0@0Q8B42@1gMgL408Z:RPD0SHf=
1023Ph<40820P0D0PH61101dM7@507alO0@0RXZ:1020P80507alO0@0PH611@24Q8@40820P0@0OGem
1@1nOWh407emO@D0MgMg101jNWX908>3P`@0NGUi1@1gMgL408F5Q@T0OGem1027QhL50820P0@0O7al
101oOgl50820P0@0QhN71@28R8P408F5Q@@0PX:21@1oOgl407QhN0D0Ogmo101lO7`407emO@D0NGUi
1027QhL407emO@D0P8205P38h=P001D0b>3H1@23Ph<407MgM`@0P8201@2DU9@407moO`D0NGUi101j
NWX407inOPD0Ph>3101jNWX508>3P`@0RHV9101oOgl507alO0@0Q8B41@29RHT40820P0@0Ogmo1@2>
SXh407IfMP@0N7Qh1@21PH4407UiN@D0PH61101nOWh408>3P`D0OWin1020P80508B4Q0@0PH61101k
Ng/507moO`@0QHF51@1nOWh808>3P`D0QhN7101hN7P507moO`@0QXJ61020P80907moO`D0PH611020
P80907moO`T0P8201022PX840861P@D0OGem1026QXH507moO`@0QHF5101jNWX507emO@@0Ph>31@1m
OGd408B4Q0@0Ng]k1@24Q8@407inOPD0QXJ63@38h=P407emO@@0QHF51@1]KFd407AdM0D0QXJ6101i
NGT40861P@D0NWYj1020P8050861P@@0OWin101fMWH508:2PP@0Ogmo101kNg/506i^KP@0OWin1@20
P80408B4Q0T0MgMg102:RXX508f=S@@0Ph>31020P8050861P@@0M7Ad1@1lO7`408Z:RP@0P8201@1l
O7`40861P@D0Q8B41020P80407emO@D0OWin101mOGd507MgM`@0NWYj2@23Ph<407UiN@D0MgMg1025
QHD907emO@@0QhN71@20P80407alO0@0Ogmo1@20P80408N7Q`D0R8R81025QHD408:2PPD0Ogmo101h
N7P507moO`@0O7al101mOGd507UiN@@0QhN7101mOGd50820P1H0b>3H000E0<SPf0D0MGEe101mOGd4
0:>SX`D0IVIV1020P80508N7Q`@0N7Qh101iNGT50820P0@0MgMg1@1iNGT407moO`@0TI6A1@1kNg/4
07inOPD0NWYj1028R8P4071`L0D0UIFE101aLG4907emO@@0PH611@29RHT407moO`@0P8201@22PX84
08B4Q0D0OWin1021PH4407alO0D0P820101oOgl907alO0T0PH61101nOWh507moO`@0PH611022PX85
07UiN@d0PH611020P80507YjNP@0P8201@23Ph<407moO`@0PH611@1lO7`90861P@@0RHV9101oOgl5
07emO@@0OWin1@1mOGd407moO`@0QHF51@1oOgl40861P@D0PX:23@38h=P408N7Q`@0OGem1@28R8P4
092@T0D0N7Qh101nOWh408:2PPD0P8201026QXH507QhN0@0P820101oOgl507]kN`@0PH61101oOgl5
07]kN`@0M7Ad1@2RXZ8408:2PP@0R8R81@1nOWh407YjNPD0Q8B4101hN7P407emO@D0O7al1025QHD5
08Z:RP@0Ng]k1021PH4507alO0@0PX:21@25QHD408B4Q0T0OGem1020P80508N7Q`@0QXJ61021PH49
07moO`T0PX:2101kNg/50861P@@0PX:21@21PH4408>3P`@0PH611@1kNg/407inOPD0QHF51022PX84
0861P@D0P8202@1oOgl40861P@@0Ogmo2@1jNWX407moO`D0O7al5P38h=P001D0b>3H1@1eMGD407em
O@@0Xj>S1@1VIVH40820P0D0QhN7101hN7P407UiN@D0P820101gMgL507UiN@@0Ogmo102ATI4507]k
N`@0OWin1@1jNWX408R8R0@0L71`1@2EUID4075aL@T0OGem1021PH4508V9R@@0Ogmo1020P80508:2
PP@0Q8B41@1nOWh40861P@@0O7al1@20P80407moO`T0O7al2@21PH4407inOPD0Ogmo1021PH4408:2
PPD0NGUi3@21PH440820P0D0NWYj1020P80508>3P`@0Ogmo1021PH4507alO0T0PH611029RHT407mo
O`D0OGem101nOWh507emO@@0Ogmo1025QHD507moO`@0PH611@22PX8=0<SPf0@0QhN7101mOGd508R8
R0@0T92@1@1hN7P407inOP@0PX:21@20P80408J6QPD0N7Qh1020P80407moO`D0Ng]k1021PH4407mo
O`D0Ng]k101dM7@50::RXP@0PX:21028R8P507inOP@0NWYj1@24Q8@407QhN0@0OGem1@1lO7`408F5
Q@D0RXZ:101kNg/40861P@D0O7al1022PX8508F5Q@@0Q8B42@1mOGd40820P0D0QhN71026QXH40861
P@T0Ogmo2@22PX8407]kN`D0PH611022PX850861P@@0Ph>31021PH4507]kN`@0OWin1@25QHD408:2
PP@0PH611@20P80907moO`@0PH61101oOgl907YjNP@0Ogmo1@1lO7`F0<SPf0005@38h=P507EeM@@0
OGem102SXj<506IVIP@0P8201@27QhL407QhN0@0NGUi1@20P80407MgM`D0NGUi101oOgl4096AT@D0
Ng]k101nOWh507YjNP@0R8R8101`L70509FEU@@0LG5a2@1mOGd40861P@D0RHV9101oOgl40820P0D0
PX:21024Q8@507inOP@0PH61101lO7`50820P0@0Ogmo2@1lO7`90861P@@0OWin1@1oOgl40861P@@0
PX:21@1iNGT=0861P@@0P8201@1jNWX40820P0D0Ph>3101oOgl40861P@D0O7al2@21PH4408V9R@@0
Ogmo1@1mOGd407inOPD0OGem101oOgl408F5Q@D0Ogmo1021PH4508:2PPd0b>3H1027QhL407emO@D0
R8R8102@T90507QhN0@0OWin1022PX850820P0@0QXJ61@1hN7P40820P0@0Ogmo1@1kNg/40861P@@0
Ogmo1@1kNg/407AdM0D0XZ:R1022PX8408R8R0D0OWin101jNWX508B4Q0@0N7Qh101mOGd507alO0@0
QHF51@2:RXX407]kN`@0PH611@1lO7`408:2PPD0QHF51024Q8@907emO@@0P8201@27QhL408J6QP@0
PH612@1oOgl908:2PP@0Ng]k1@21PH4408:2PPD0PH611023Ph<40861P@D0Ng]k101nOWh508F5Q@@0
PX:21021PH450820P0T0Ogmo1021PH4407moO`T0NWYj101oOgl507alO1H0b>3H000E0<SPf0D0MGEe
101mOGd40:>SX`D0IVIV1020P80508N7Q`@0N7Qh101iNGT50820P0@0MgMg1@1iNGT407moO`@0TI6A
1@1kNg/407inOPD0NWYj1028R8P4071`L0D0UIFE101aLG4907emO@@0PH611@29RHT407moO`@0P820
1@22PX8408B4Q0D0OWin1021PH4407alO0D0P820101oOgl907alO0T0PH61101nOWh507moO`@0PH61
1022PX8507UiN@d0PH611020P80507YjNP@0P8201@23Ph<407moO`@0PH611@1lO7`90861P@@0RHV9
101oOgl507emO@@0OWin1@1mOGd407moO`@0QHF51@1oOgl40861P@D0PX:23@38h=P408N7Q`@0OGem
1@28R8P4092@T0D0N7Qh101nOWh408:2PPD0P8201026QXH507QhN0@0P820101oOgl507]kN`@0PH61
101oOgl507]kN`@0M7Ad1@2RXZ8408:2PP@0R8R81@1nOWh407YjNPD0Q8B4101hN7P407emO@D0O7al
1025QHD508Z:RP@0Ng]k1021PH4507alO0@0PX:21@25QHD408B4Q0T0OGem1020P80508N7Q`@0QXJ6
1021PH4907moO`T0PX:2101kNg/50861P@@0PX:21@21PH4408>3P`@0PH611@1kNg/407inOPD0QHF5
1022PX840861P@D0P8202@1oOgl40861P@@0Ogmo2@1jNWX407moO`D0O7al5P38h=P001D0b>3H1@1e
MGD407emO@@0Xj>S1@1VIVH40820P0D0QhN7101hN7P407UiN@D0P820101gMgL507UiN@@0Ogmo102A
TI4507]kN`@0OWin1@1jNWX408R8R0@0L71`1@2EUID4075aL@T0OGem1021PH4508V9R@@0Ogmo1020
P80508:2PP@0Q8B41@1nOWh40861P@@0O7al1@20P80407moO`T0O7al2@21PH4407inOPD0Ogmo1021
PH4408:2PPD0NGUi3@21PH440820P0D0NWYj1020P80508>3P`@0Ogmo1021PH4507alO0T0PH611029
RHT407moO`D0OGem101nOWh507emO@@0Ogmo1025QHD507moO`@0PH611@22PX8=0<SPf0@0QhN7101m
OGd508R8R0@0T92@1@1hN7P407inOP@0PX:21@20P80408J6QPD0N7Qh1020P80407moO`D0Ng]k1021
PH4407moO`D0Ng]k101dM7@50::RXP@0PX:21028R8P507inOP@0NWYj1@24Q8@407QhN0@0OGem1@1l
O7`408F5Q@D0RXZ:101kNg/40861P@D0O7al1022PX8508F5Q@@0Q8B42@1mOGd40820P0D0QhN71026
QXH40861P@T0Ogmo2@22PX8407]kN`D0PH611022PX850861P@@0Ph>31021PH4507]kN`@0OWin1@25
QHD408:2PP@0PH611@20P80907moO`@0PH61101oOgl907YjNP@0Ogmo1@1lO7`F0<SPf0005@38h=P5
08F5Q@@0Q8B4101oOgl50820P0@0O7al1@1oOgl408V9R@@0MWIf1@20P80408F5Q@D0Rh^;101/K6`4
096AT@D0Ogmo1022PX8508B4Q0@0QHF5101fMWH509FEU@@0KFe]1029RHT507UiN@@0Ogmo1@1lO7`4
0861P@@0Q8B41@22PX8407]kN`D0Q8B41023Ph<40861P@D0PX:2101mOGd507moO`@0P8201021PH45
08>3P`@0N7Qh1@20P80407moO`@0OGem1@23Ph<907alO0@0NWYj1023Ph<508:2PP@0OWin1@20P804
0861P@@0PX:21@20P8040861P@D0Ph>3101nOWh40820P0D0PH611022PX890861P@@0Ng]k1@1mOGd4
08:2PPD0OGem3@38h=P407QhN0@0Ogmo1@1jNWX406e]K@D0N7Qh1025QHD407UiN@D0NWYj1023Ph<5
07]kN`@0PX:2102JVYX508:2PP@0QHF5101mOGd508V9R@@0Ng]k1@1mOGd407IfMP@0OGem1@27QhL4
08J6QPD0Ogmo201mOGd508>3P`@0P8201@1nOWh407moO`@0PX:21@1nOWh407UiN@D0P8201023Ph<4
0820P0D0PX:21021PH4507YjNPP0Ogmo1@21PH4407moO`D0P820101hN7P40820P0D0PH612@1nOWh4
08>3P`@0Ogmo1@1mOGd407inOPT0PX:21020P8050861P@@0P8202@22PX840861P@D0Ng]k1028R8P4
0861P@D0Q8B45P38h=P001D0b>3H1@25QHD408B4Q0@0Ogmo1@20P80407alO0D0Ogmo1029RHT407If
MPD0P8201025QHD508^;R`@0K6a/102ATI4507moO`@0PX:21@24Q8@408F5Q@@0MWIf1@2EUID406e]
K@@0RHV91@1iNGT407moO`D0O7al1021PH4408B4Q0D0PX:2101kNg/508B4Q0@0Ph>31021PH4508:2
PP@0OGem1@1oOgl40820P0@0PH611@23Ph<407QhN0D0P820101oOgl407emO@D0Ph>32@1lO7`407Yj
NP@0Ph>31@22PX8407inOPD0P8201021PH4408:2PPD0P8201021PH4508>3P`@0OWin1020P8050861
P@@0PX:22@21PH4407]kN`D0OGem1022PX8507emO@d0b>3H101hN7P407moO`D0NWYj101]KFd507Qh
N0@0QHF5101iNGT507YjNP@0Ph>31@1kNg/408:2PP@0VYZJ1@22PX8408F5Q@@0OGem1@29RHT407]k
N`D0OGem101fMWH407emO@D0QhN71026QXH507moO`P0OGem1@23Ph<40820P0D0OWin101oOgl408:2
PPD0OWin101iNGT50820P0@0Ph>31020P80508:2PP@0PH611@1jNWX807moO`D0PH61101oOgl50820
P0@0N7Qh1020P8050861P@T0OWin1023Ph<407moO`D0OGem101nOWh908:2PP@0P8201@21PH440820
P0T0PX:21021PH4507]kN`@0R8R81021PH4508B4Q1H0b>3H000E0<SPf0D0QHF51024Q8@407moO`D0
P820101lO7`507moO`@0RHV9101fMWH50820P0@0QHF51@2;Rh/406a/K0@0TI6A1@1oOgl408:2PPD0
Q8B41025QHD407IfMPD0UIFE101]KFd408V9R@D0NGUi101oOgl507alO0@0PH611024Q8@508:2PP@0
Ng]k1@24Q8@408>3P`@0PH611@22PX8407emO@D0Ogmo1020P8040861P@D0Ph>3101hN7P50820P0@0
Ogmo101mOGd508>3P`T0O7al101jNWX408>3P`D0PX:2101nOWh50820P0@0PH611022PX850820P0@0
PH611@23Ph<407inOP@0P8201@21PH4408:2PPT0PH61101kNg/507emO@@0PX:21@1mOGd=0<SPf0@0
N7Qh101oOgl507YjNP@0KFe]1@1hN7P408F5Q@@0NGUi1@1jNWX408>3P`D0Ng]k1022PX8409ZJVPD0
PX:21025QHD407emO@D0RHV9101kNg/507emO@@0MWIf101mOGd508N7Q`@0QXJ61@1oOgl807emO@D0
Ph>31020P80507inOP@0Ogmo1022PX8507inOP@0NGUi1@20P80408>3P`@0P8201@22PX840861P@D0
NWYj201oOgl50861P@@0Ogmo1@20P80407QhN0@0P8201@21PH4907inOP@0Ph>3101oOgl507emO@@0
OWin2@22PX840820P0D0PH611020P80908:2PP@0PH611@1kNg/408R8R0@0PH611@24Q8@F0<SPf000
5@38h=P508F5Q@@0Q8B4101oOgl50820P0@0O7al1@1oOgl408V9R@@0MWIf1@20P80408F5Q@D0Rh^;
101/K6`4096AT@D0Ogmo1022PX8508B4Q0@0QHF5101fMWH509FEU@@0KFe]1029RHT507UiN@@0Ogmo
1@1lO7`40861P@@0Q8B41@22PX8407]kN`D0Q8B41023Ph<40861P@D0PX:2101mOGd507moO`@0P820
1021PH4508>3P`@0N7Qh1@20P80407moO`@0OGem1@23Ph<907alO0@0NWYj1023Ph<508:2PP@0OWin
1@20P8040861P@@0PX:21@20P8040861P@D0Ph>3101nOWh40820P0D0PH611022PX890861P@@0Ng]k
1@1mOGd408:2PPD0OGem3@38h=P407QhN0@0Ogmo1@1jNWX406e]K@D0N7Qh1025QHD407UiN@D0NWYj
1023Ph<507]kN`@0PX:2102JVYX508:2PP@0QHF5101mOGd508V9R@@0Ng]k1@1mOGd407IfMP@0OGem
1@27QhL408J6QPD0Ogmo201mOGd508>3P`@0P8201@1nOWh407moO`@0PX:21@1nOWh407UiN@D0P820
1023Ph<40820P0D0PX:21021PH4507YjNPP0Ogmo1@21PH4407moO`D0P820101hN7P40820P0D0PH61
2@1nOWh408>3P`@0Ogmo1@1mOGd407inOPT0PX:21020P8050861P@@0P8202@22PX840861P@D0Ng]k
1028R8P40861P@D0Q8B45P38h=P001D0b>3H1@1lO7`407EeM@@0RXZ:1@20P80406a/K0D0O7al102;
Rh/407=cL`D0SHf=101^KVh507EeM@@0QHF5102VYZH507EeM@@0Ogmo1@1jNWX408:2PP@0P8201@2F
UYH407=cL`@0Shn?1@1hN7P407moO`D0QHF51020P80407]kN`D0PX:2101nOWh507moO`P0PH611@1m
OGd408B4Q0D0Ng]k101oOgl408>3P`D0OWin101lO7`507moO`@0OWin1022PX8B0861P@@0OWin1@27
QhL407emO@D0PH611020P80407inOPD0Ng]k1022PX890820P0@0Q8B41@1oOgl407inOPD0NWYj1022
PX840861P@D0Ng]k101oOgl507alO0d0b>3H101fMWH408R8R0D0LG5a102FUYH50820P0@0RXZ:101n
OWh50820P0@0Ogmo1@24Q8@807YjNPD0Ph>31027QhL407UiN@D0Ogmo102:RXX507moO`@0QHF5101l
O7`508^;R`@0RXZ:1@25QHD408J6QPT0OGem101lO7`507inOP@0O7al1020P80507alO0@0NGUi1@1m
OGd407alO0@0QHF51@22PX840861P@D0OWin1024Q8@407alO0T0Ph>31@1mOGd408B4Q0@0O7al1@1m
OGd407inOPD0Ogmo1025QHD40861P@D0QHF5101mOGd507]kN`@0OGem101lO7`50820P0@0PH611@1o
Ogl408B4Q0@0Ng]k1@1nOWh40820P0T0Ng]k5P38h=P001D0b>3H1@1lO7`407EeM@@0RXZ:1@20P804
06a/K0D0O7al102;Rh/407=cL`D0SHf=101^KVh507EeM@@0QHF5102VYZH507EeM@@0Ogmo1@1jNWX4
08:2PP@0P8201@2FUYH407=cL`@0Shn?1@1hN7P407moO`D0QHF51020P80407]kN`D0PX:2101nOWh5
07moO`P0PH611@1mOGd408B4Q0D0Ng]k101oOgl408>3P`D0OWin101lO7`507moO`@0OWin1022PX8B
0861P@@0OWin1@27QhL407emO@D0PH611020P80407inOPD0Ng]k1022PX890820P0@0Q8B41@1oOgl4
07inOPD0NWYj1022PX840861P@D0Ng]k101oOgl507alO0d0b>3H101fMWH408R8R0D0LG5a102FUYH5
0820P0@0RXZ:101nOWh50820P0@0Ogmo1@24Q8@807YjNPD0Ph>31027QhL407UiN@D0Ogmo102:RXX5
07moO`@0QHF5101lO7`508^;R`@0RXZ:1@25QHD408J6QPT0OGem101lO7`507inOP@0O7al1020P805
07alO0@0NGUi1@1mOGd407alO0@0QHF51@22PX840861P@D0OWin1024Q8@407alO0T0Ph>31@1mOGd4
08B4Q0@0O7al1@1mOGd407inOPD0Ogmo1025QHD40861P@D0QHF5101mOGd507]kN`@0OGem101lO7`5
0820P0@0PH611@1oOgl408B4Q0@0Ng]k1@1nOWh40820P0T0Ng]k5P38h=P001D0b>3H1@1lO7`407Ee
M@@0RXZ:1@20P80406a/K0D0O7al102;Rh/407=cL`D0SHf=101^KVh507EeM@@0QHF5102VYZH507Ee
M@@0Ogmo1@1jNWX408:2PP@0P8201@2FUYH407=cL`@0Shn?1@1hN7P407moO`D0QHF51020P80407]k
N`D0PX:2101nOWh507moO`P0PH611@1mOGd408B4Q0D0Ng]k101oOgl408>3P`D0OWin101lO7`507mo
O`@0OWin1022PX8B0861P@@0OWin1@27QhL407emO@D0PH611020P80407inOPD0Ng]k1022PX890820
P0@0Q8B41@1oOgl407inOPD0NWYj1022PX840861P@D0Ng]k101oOgl507alO0d0b>3H101fMWH408R8
R0D0LG5a102FUYH50820P0@0RXZ:101nOWh50820P0@0Ogmo1@24Q8@807YjNPD0Ph>31027QhL407Ui
N@D0Ogmo102:RXX507moO`@0QHF5101lO7`508^;R`@0RXZ:1@25QHD408J6QPT0OGem101lO7`507in
OP@0O7al1020P80507alO0@0NGUi1@1mOGd407alO0@0QHF51@22PX840861P@D0OWin1024Q8@407al
O0T0Ph>31@1mOGd408B4Q0@0O7al1@1mOGd407inOPD0Ogmo1025QHD40861P@D0QHF5101mOGd507]k
N`@0OGem101lO7`50820P0@0PH611@1oOgl408B4Q0@0Ng]k1@1nOWh40820P0T0Ng]k5P38h=P001D0
b>3H1@1lO7`407EeM@@0RXZ:1@20P80406a/K0D0O7al102;Rh/407=cL`D0SHf=101^KVh507EeM@@0
QHF5102VYZH507EeM@@0Ogmo1@1jNWX408:2PP@0P8201@2FUYH407=cL`@0Shn?1@1hN7P407moO`D0
QHF51020P80407]kN`D0PX:2101nOWh507moO`P0PH611@1mOGd408B4Q0D0Ng]k101oOgl408>3P`D0
OWin101lO7`507moO`@0OWin1022PX8B0861P@@0OWin1@27QhL407emO@D0PH611020P80407inOPD0
Ng]k1022PX890820P0@0Q8B41@1oOgl407inOPD0NWYj1022PX840861P@D0Ng]k101oOgl507alO0d0
b>3H101fMWH408R8R0D0LG5a102FUYH50820P0@0RXZ:101nOWh50820P0@0Ogmo1@24Q8@807YjNPD0
Ph>31027QhL407UiN@D0Ogmo102:RXX507moO`@0QHF5101lO7`508^;R`@0RXZ:1@25QHD408J6QPT0
OGem101lO7`507inOP@0O7al1020P80507alO0@0NGUi1@1mOGd407alO0@0QHF51@22PX840861P@D0
OWin1024Q8@407alO0T0Ph>31@1mOGd408B4Q0@0O7al1@1mOGd407inOPD0Ogmo1025QHD40861P@D0
QHF5101mOGd507]kN`@0OGem101lO7`50820P0@0PH611@1oOgl408B4Q0@0Ng]k1@1nOWh40820P0T0
Ng]k5P38h=P001D0b>3H1@1lO7`407EeM@@0RXZ:1@20P80406a/K0D0O7al102;Rh/407=cL`D0SHf=
101^KVh507EeM@@0QHF5102VYZH507EeM@@0Ogmo1@1jNWX408:2PP@0P8201@2FUYH407=cL`@0Shn?
1@1hN7P407moO`D0QHF51020P80407]kN`D0PX:2101nOWh507moO`P0PH611@1mOGd408B4Q0D0Ng]k
101oOgl408>3P`D0OWin101lO7`507moO`@0OWin1022PX8B0861P@@0OWin1@27QhL407emO@D0PH61
1020P80407inOPD0Ng]k1022PX890820P0@0Q8B41@1oOgl407inOPD0NWYj1022PX840861P@D0Ng]k
101oOgl507alO0d0b>3H101fMWH408R8R0D0LG5a102FUYH50820P0@0RXZ:101nOWh50820P0@0Ogmo
1@24Q8@807YjNPD0Ph>31027QhL407UiN@D0Ogmo102:RXX507moO`@0QHF5101lO7`508^;R`@0RXZ:
1@25QHD408J6QPT0OGem101lO7`507inOP@0O7al1020P80507alO0@0NGUi1@1mOGd407alO0@0QHF5
1@22PX840861P@D0OWin1024Q8@407alO0T0Ph>31@1mOGd408B4Q0@0O7al1@1mOGd407inOPD0Ogmo
1025QHD40861P@D0QHF5101mOGd507]kN`@0OGem101lO7`50820P0@0PH611@1oOgl408B4Q0@0Ng]k
1@1nOWh40820P0T0Ng]k5P38h=P001D0b>3H1@25QHD407IfMP@0Ogmo2@1lO7`508n?S`@0JFUY1026
QXH508:2PP@0OWin1@25QHD408j>SP@0EeMG1@2EUID407QhN0D0Ogmo1021PH4407]kN`D0U9BD101a
LG4408j>SPD0MWIf101nOWh507moO`@0PX:21021PH4507moO`@0OWin1@23Ph<40861P@@0Ng]k1@20
P8040861P@D0MGEe101jNWX408>3P`D0Ng]k101mOGd507inOP@0P820101mOGd50861P@@0Q8B41@1m
OGd80861P@T0P8201@1oOgl408>3P`@0OWin1@20P80407]kN`D0OWin1021PH4407emO@D0Ogmo2@1k
Ng/408B4Q0@0PX:21@1mOGd408B4Q0D0MWIf3@38h=P408N7Q`@0O7al1@20P80407QhN0D0PH61101i
NGT407emO@D0Q8B41020P8050861P@@0Ogmo1026QXH507]kN`@0BTY:101oOgl508J6QP@0Q8B41@1f
MWH407alO0@0Rh^;2@1nOWh50820P0P0PH611@1kNg/407alO0D0NGUi1023Ph<407moO`D0OGem1020
P80507alO0@0N7Qh101iNGT508>3P`@0PH611@1jNWX407emO@@0P8201@1kNg/407emO@D0PX:2101n
OWh407moO`D0Ng]k101lO7`508>3P`@0OWin101jNWX507emO@@0PX:21@21PH4408Z:RPT0Ogmo1020
P80508>3P`@0PH61101jNWX508:2PP@0O7al101oOgl507UiNAH0b>3H000E0<SPf0D0QHF5101fMWH4
07moO`T0O7al1@2?Shl406UYJ@@0QXJ61@22PX8407inOPD0QHF5102>SXh405MGE`D0UIFE101hN7P5
07moO`@0PH61101kNg/509BDU0@0LG5a102>SXh507IfMP@0OWin1@1oOgl408:2PP@0PH611@1oOgl4
07inOPD0Ph>31021PH4407]kN`D0P8201021PH4507EeM@@0NWYj1023Ph<507]kN`@0OGem1@1nOWh4
0820P0@0OGem1@21PH4408B4Q0D0OGem2021PH490820P0D0Ogmo1023Ph<407inOPD0P820101kNg/5
07inOP@0PH61101mOGd507moO`T0Ng]k1024Q8@408:2PPD0OGem1024Q8@507IfMPd0b>3H1027QhL4
07alO0D0P820101hN7P50861P@@0NGUi101mOGd508B4Q0@0P8201@21PH4407moO`@0QXJ61@1kNg/4
04Y:BP@0Ogmo1@26QXH408B4Q0D0MWIf101lO7`408^;R`T0OWin1@20P8080861P@D0Ng]k101lO7`5
07UiN@@0Ph>3101oOgl507emO@@0P8201@1lO7`407QhN0@0NGUi1@23Ph<40861P@D0NWYj101mOGd4
0820P0D0Ng]k101mOGd508:2PP@0OWin101oOgl507]kN`@0O7al1@23Ph<407inOP@0NWYj1@1mOGd4
08:2PPD0PH61102:RXX907moO`@0P8201@23Ph<40861P@@0NWYj1@22PX8407alO0@0Ogmo1@1iNGTF
0<SPf0005@38h=P508F5Q@@0MWIf101oOgl907alO0D0Shn?101YJFT408J6QPD0PX:2101nOWh508F5
Q@@0SXj>101GEeL509FEU@@0N7Qh1@1oOgl40861P@@0Ng]k1@2DU9@4075aL@@0SXj>1@1fMWH407in
OPD0Ogmo1022PX840861P@D0Ogmo101nOWh508>3P`@0PH61101kNg/50820P0@0PH611@1eMGD407Yj
NP@0Ph>31@1kNg/407emO@D0OWin1020P80407emO@D0PH611024Q8@507emO@P0PH612@20P80507mo
O`@0Ph>3101nOWh50820P0@0Ng]k1@1nOWh40861P@@0OGem1@1oOgl907]kN`@0Q8B41022PX8507em
O@@0Q8B41@1fMWH=0<SPf0@0QhN7101lO7`50820P0@0N7Qh1@21PH4407UiN@@0OGem1@24Q8@40820
P0D0PH61101oOgl408J6QPD0Ng]k101:BTX407moO`D0QXJ61024Q8@507IfMP@0O7al102;Rh/907in
OPD0P8202021PH4507]kN`@0O7al1@1iNGT408>3P`@0Ogmo1@1mOGd40820P0D0O7al101hN7P407Ui
N@D0Ph>31021PH4507YjNP@0OGem1020P80507]kN`@0OGem1@22PX8407inOP@0Ogmo1@1kNg/407al
O0D0Ph>3101nOWh407YjNPD0OGem1022PX850861P@@0RXZ:2@1oOgl40820P0D0Ph>31021PH4407Yj
NPD0PX:2101lO7`407moO`D0NGUi5P38h=P001D0b>3H1@25QHD407IfMP@0Ogmo2@1lO7`508n?S`@0
JFUY1026QXH508:2PP@0OWin1@25QHD408j>SP@0EeMG1@2EUID407QhN0D0Ogmo1021PH4407]kN`D0
U9BD101aLG4408j>SPD0MWIf101nOWh507moO`@0PX:21021PH4507moO`@0OWin1@23Ph<40861P@@0
Ng]k1@20P8040861P@D0MGEe101jNWX408>3P`D0Ng]k101mOGd507inOP@0P820101mOGd50861P@@0
Q8B41@1mOGd80861P@T0P8201@1oOgl408>3P`@0OWin1@20P80407]kN`D0OWin1021PH4407emO@D0
Ogmo2@1kNg/408B4Q0@0PX:21@1mOGd408B4Q0D0MWIf3@38h=P408N7Q`@0O7al1@20P80407QhN0D0
PH61101iNGT407emO@D0Q8B41020P8050861P@@0Ogmo1026QXH507]kN`@0BTY:101oOgl508J6QP@0
Q8B41@1fMWH407alO0@0Rh^;2@1nOWh50820P0P0PH611@1kNg/407alO0D0NGUi1023Ph<407moO`D0
OGem1020P80507alO0@0N7Qh101iNGT508>3P`@0PH611@1jNWX407emO@@0P8201@1kNg/407emO@D0
PX:2101nOWh407moO`D0Ng]k101lO7`508>3P`@0OWin101jNWX507emO@@0PX:21@21PH4408Z:RPT0
Ogmo1020P80508>3P`@0PH61101jNWX508:2PP@0O7al101oOgl507UiNAH0b>3H000E0<SPf0D0QhN7
101NGUh409>CT`T0O7al1@2?Shl407=cL`@0SHf=1@1`L70409BDU0D0KVi^101nOWh408V9R@D0NWYj
1020P80507moO`@0PH61101lO7`509:BTP@0Jf][102?Shl507YjNP@0Q8B41@1lO7`40820P0@0Ph>3
1@1kNg/408B4Q0D0OWin101iNGT40820P0T0Ogmo1@22PX8407MgM`@0Ph>32@21PH4507UiN@@0P820
1023Ph<50820P0@0Ogmo1@22PX8407emO@@0Q8B41@20P80408:2PPD0Ng]k1020P80408F5Q@D0OWin
101oOgl50861P@@0OGem101nOWh50861P@@0OWin1@1lO7`40861P@d0P8201@1oOgl=0<SPf0@0MWIf
101hN7P507]kN`@0PH611@1oOgl408F5Q@@0O7al1@1hN7P408Z:RPD0PH61102;Rh/408:2PPD0P820
102VYZH907emO@@0R8R81@1hN7P408:2PP@0MgMg1@1lO7`40861P@D0Ogmo1021PH4407inOPD0MWIf
101mOGd507alO0@0PH611023Ph<507MgM`@0P8201@1iNGT40861P@@0PX:22@20P80507inOP@0QHF5
1023Ph<507UiN@@0PH611@1nOWh40820P0@0O7al1@23Ph<407alO0D0OWin1020P80407inOPD0P820
101oOgl508N7Q`@0Ogmo1021PH4508>3P`@0P8201@1mOGd40820P0@0PX:21@20P80408>3P`@0OWin
1@20P80F0<SPf0005@38h=P508N7Q`@0GUiN102CTi<907alO0D0Shn?101cLg<408f=S@D0L71`102D
U9@506i^KP@0OWin1029RHT507YjNP@0P8201@1oOgl40861P@@0O7al1@2BTY8406][J`@0Shn?1@1j
NWX408B4Q0D0O7al1020P80408>3P`D0Ng]k1024Q8@507inOP@0NGUi1020P80907moO`D0PX:2101g
MgL408>3P`T0PH611@1iNGT40820P0@0Ph>31@20P80407moO`D0PX:2101mOGd408B4Q0D0P8201022
PX8507]kN`@0P8201025QHD507inOP@0Ogmo1@21PH4407emO@@0OWin1@21PH4407inOPD0O7al1021
PH4=0820P0D0Ogmo3@38h=P407IfMP@0N7Qh1@1kNg/40861P@D0Ogmo1025QHD407alO0D0N7Qh102:
RXX50861P@@0Rh^;1022PX850820P0@0YZJV2@1mOGd408R8R0D0N7Qh1022PX8407MgM`D0O7al1021
PH4507moO`@0PH61101nOWh507IfMP@0OGem1@1lO7`40861P@@0Ph>31@1gMgL40820P0D0NGUi1021
PH4408:2PPT0P8201@1nOWh408F5Q@@0Ph>31@1iNGT40861P@D0OWin1020P80407alO0D0Ph>3101l
O7`507inOP@0P820101nOWh50820P0@0Ogmo1@27QhL407moO`@0PH611@23Ph<40820P0D0OGem1020
P80408:2PPD0P8201023Ph<407inOPD0P8205P38h=P001D0b>3H1@27QhL405iNGP@0Ti>C2@1lO7`5
08n?S`@0Lg=c102=SHd5071`L0@0U9BD1@1^KVh407inOP@0RHV91@1jNWX40820P0D0Ogmo1021PH44
07alO0D0TY:B101[Jf/408n?S`D0NWYj1024Q8@507alO0@0P8201023Ph<507]kN`@0Q8B41@1nOWh4
07UiN@@0P8202@1oOgl508:2PP@0MgMg1023Ph<90861P@D0NGUi1020P80408>3P`D0P820101oOgl5
08:2PP@0OGem1024Q8@50820P0@0PX:21@1kNg/40820P0@0QHF51@1nOWh407moO`D0PH61101mOGd4
07inOPD0PH61101nOWh507alO0@0PH613@20P80507moO`d0b>3H101fMWH407QhN0D0Ng]k1021PH45
07moO`@0QHF5101lO7`507QhN0@0RXZ:1@21PH4408^;R`@0PX:21@20P8040:JVYPT0OGem1028R8P5
07QhN0@0PX:2101gMgL507alO0@0PH611@1oOgl40861P@@0OWin1@1fMWH407emO@D0O7al1021PH44
08>3P`D0MgMg1020P80507UiN@@0PH611022PX890820P0D0OWin1025QHD408>3P`D0NGUi1021PH45
07inOP@0P820101lO7`508>3P`@0O7al1@1nOWh40820P0@0OWin1@20P80407moO`D0QhN7101oOgl4
0861P@D0Ph>31020P80507emO@@0P8201022PX850820P0@0Ph>3101nOWh50820P1H0b>3H000E0<SP
f0D0QhN7101NGUh409>CT`T0O7al1@2?Shl407=cL`@0SHf=1@1`L70409BDU0D0KVi^101nOWh408V9
R@D0NWYj1020P80507moO`@0PH61101lO7`509:BTP@0Jf][102?Shl507YjNP@0Q8B41@1lO7`40820
P0@0Ph>31@1kNg/408B4Q0D0OWin101iNGT40820P0T0Ogmo1@22PX8407MgM`@0Ph>32@21PH4507Ui
N@@0P8201023Ph<50820P0@0Ogmo1@22PX8407emO@@0Q8B41@20P80408:2PPD0Ng]k1020P80408F5
Q@D0OWin101oOgl50861P@@0OGem101nOWh50861P@@0OWin1@1lO7`40861P@d0P8201@1oOgl=0<SP
f0@0MWIf101hN7P507]kN`@0PH611@1oOgl408F5Q@@0O7al1@1hN7P408Z:RPD0PH61102;Rh/408:2
PPD0P820102VYZH907emO@@0R8R81@1hN7P408:2PP@0MgMg1@1lO7`40861P@D0Ogmo1021PH4407in
OPD0MWIf101mOGd507alO0@0PH611023Ph<507MgM`@0P8201@1iNGT40861P@@0PX:22@20P80507in
OP@0QHF51023Ph<507UiN@@0PH611@1nOWh40820P0@0O7al1@23Ph<407alO0D0OWin1020P80407in
OPD0P820101oOgl508N7Q`@0Ogmo1021PH4508>3P`@0P8201@1mOGd40820P0@0PX:21@20P80408>3
P`@0OWin1@20P80F0<SPf0005@38h=P507alO0@0KVi^101iNGT507moO`@0OGem1@1jNWX408Z:RP@0
Jf][1@1jNWX408J6QPD0NWYj1024Q8@408>3P`D0LG5a102JVYX507IfMPP0P8201@2;Rh/406e]K@@0
PX:21@1oOgl407YjNPD0MWIf2020P80507emO@@0Ng]k1@20P8080861P@D0Ogmo2@1mOGd407inOP@0
NGUi1@1mOGd408B4Q0D0PH61101mOGd40820P0T0Ph>31@20P80407emO@@0PX:21@1oOgl408:2PPD0
Ogmo1023Ph<407emO@T0OWin1@21PH440820P0T0Ogmo101lO7`50861P@@0Ph>3101oOgl50861P@@0
OWin1@1kNg/=0<SPf0@0P820101oOgl50861P@@0Ogmo1@26QXH407moO`@0M7Ad1@20P80408F5Q@T0
Ogmo101dM7@50820P0@0Lg=c102_[jl5096AT@@0O7al1@23Ph<408^;R`T0Ph>31027QhL507MgM`@0
NGUi101nOWh50820P0@0Ogmo1@1nOWh40820P0@0PH611@24Q8@40820P0D0QHF5101oOgl408:2PPD0
OWin1023Ph<508b<S0P0OGem2@27QhL507inOP@0O7al101nOWh508:2PP@0OWin1@20P80408J6QP@0
QHF51@21PH4407]kN`D0NWYj101gMgL408B4Q0D0PX:21023Ph<50820P0@0Ng]k1023Ph<90861P@@0
Ng]k1@25QHDF0<SPf0005@38h=P507alO0@0KVi^101iNGT507moO`@0OGem1@1jNWX408Z:RP@0Jf][
1@1jNWX408J6QPD0NWYj1024Q8@408>3P`D0LG5a102JVYX507IfMPP0P8201@2;Rh/406e]K@@0PX:2
1@1oOgl407YjNPD0MWIf2020P80507emO@@0Ng]k1@20P8080861P@D0Ogmo2@1mOGd407inOP@0NGUi
1@1mOGd408B4Q0D0PH61101mOGd40820P0T0Ph>31@20P80407emO@@0PX:21@1oOgl408:2PPD0Ogmo
1023Ph<407emO@T0OWin1@21PH440820P0T0Ogmo101lO7`50861P@@0Ph>3101oOgl50861P@@0OWin
1@1kNg/=0<SPf0@0P820101oOgl50861P@@0Ogmo1@26QXH407moO`@0M7Ad1@20P80408F5Q@T0Ogmo
101dM7@50820P0@0Lg=c102_[jl5096AT@@0O7al1@23Ph<408^;R`T0Ph>31027QhL507MgM`@0NGUi
101nOWh50820P0@0Ogmo1@1nOWh40820P0@0PH611@24Q8@40820P0D0QHF5101oOgl408:2PPD0OWin
1023Ph<508b<S0P0OGem2@27QhL507inOP@0O7al101nOWh508:2PP@0OWin1@20P80408J6QP@0QHF5
1@21PH4407]kN`D0NWYj101gMgL408B4Q0D0PX:21023Ph<50820P0@0Ng]k1023Ph<90861P@@0Ng]k
1@25QHDF0<SPf0005@38h=P507alO0@0KVi^101iNGT507moO`@0OGem1@1jNWX408Z:RP@0Jf][1@1j
NWX408J6QPD0NWYj1024Q8@408>3P`D0LG5a102JVYX507IfMPP0P8201@2;Rh/406e]K@@0PX:21@1o
Ogl407YjNPD0MWIf2020P80507emO@@0Ng]k1@20P8080861P@D0Ogmo2@1mOGd407inOP@0NGUi1@1m
OGd408B4Q0D0PH61101mOGd40820P0T0Ph>31@20P80407emO@@0PX:21@1oOgl408:2PPD0Ogmo1023
Ph<407emO@T0OWin1@21PH440820P0T0Ogmo101lO7`50861P@@0Ph>3101oOgl50861P@@0OWin1@1k
Ng/=0<SPf0@0P820101oOgl50861P@@0Ogmo1@26QXH407moO`@0M7Ad1@20P80408F5Q@T0Ogmo101d
M7@50820P0@0Lg=c102_[jl5096AT@@0O7al1@23Ph<408^;R`T0Ph>31027QhL507MgM`@0NGUi101n
OWh50820P0@0Ogmo1@1nOWh40820P0@0PH611@24Q8@40820P0D0QHF5101oOgl408:2PPD0OWin1023
Ph<508b<S0P0OGem2@27QhL507inOP@0O7al101nOWh508:2PP@0OWin1@20P80408J6QP@0QHF51@21
PH4407]kN`D0NWYj101gMgL408B4Q0D0PX:21023Ph<50820P0@0Ng]k1023Ph<90861P@@0Ng]k1@25
QHDF0<SPf0005@38h=P507alO0@0KVi^101iNGT507moO`@0OGem1@1jNWX408Z:RP@0Jf][1@1jNWX4
08J6QPD0NWYj1024Q8@408>3P`D0LG5a102JVYX507IfMPP0P8201@2;Rh/406e]K@@0PX:21@1oOgl4
07YjNPD0MWIf2020P80507emO@@0Ng]k1@20P8080861P@D0Ogmo2@1mOGd407inOP@0NGUi1@1mOGd4
08B4Q0D0PH61101mOGd40820P0T0Ph>31@20P80407emO@@0PX:21@1oOgl408:2PPD0Ogmo1023Ph<4
07emO@T0OWin1@21PH440820P0T0Ogmo101lO7`50861P@@0Ph>3101oOgl50861P@@0OWin1@1kNg/=
0<SPf0@0P820101oOgl50861P@@0Ogmo1@26QXH407moO`@0M7Ad1@20P80408F5Q@T0Ogmo101dM7@5
0820P0@0Lg=c102_[jl5096AT@@0O7al1@23Ph<408^;R`T0Ph>31027QhL507MgM`@0NGUi101nOWh5
0820P0@0Ogmo1@1nOWh40820P0@0PH611@24Q8@40820P0D0QHF5101oOgl408:2PPD0OWin1023Ph<5
08b<S0P0OGem2@27QhL507inOP@0O7al101nOWh508:2PP@0OWin1@20P80408J6QP@0QHF51@21PH44
07]kN`D0NWYj101gMgL408B4Q0D0PX:21023Ph<50820P0@0Ng]k1023Ph<90861P@@0Ng]k1@25QHDF
0<SPf0005@38h=P507alO0@0KVi^101iNGT507moO`@0OGem1@1jNWX408Z:RP@0Jf][1@1jNWX408J6
QPD0NWYj1024Q8@408>3P`D0LG5a102JVYX507IfMPP0P8201@2;Rh/406e]K@@0PX:21@1oOgl407Yj
NPD0MWIf2020P80507emO@@0Ng]k1@20P8080861P@D0Ogmo2@1mOGd407inOP@0NGUi1@1mOGd408B4
Q0D0PH61101mOGd40820P0T0Ph>31@20P80407emO@@0PX:21@1oOgl408:2PPD0Ogmo1023Ph<407em
O@T0OWin1@21PH440820P0T0Ogmo101lO7`50861P@@0Ph>3101oOgl50861P@@0OWin1@1kNg/=0<SP
f0@0P820101oOgl50861P@@0Ogmo1@26QXH407moO`@0M7Ad1@20P80408F5Q@T0Ogmo101dM7@50820
P0@0Lg=c102_[jl5096AT@@0O7al1@23Ph<408^;R`T0Ph>31027QhL507MgM`@0NGUi101nOWh50820
P0@0Ogmo1@1nOWh40820P0@0PH611@24Q8@40820P0D0QHF5101oOgl408:2PPD0OWin1023Ph<508b<
S0P0OGem2@27QhL507inOP@0O7al101nOWh508:2PP@0OWin1@20P80408J6QP@0QHF51@21PH4407]k
N`D0NWYj101gMgL408B4Q0D0PX:21023Ph<50820P0@0Ng]k1023Ph<90861P@@0Ng]k1@25QHDF0<SP
f0005@38h=P50861P@@0MWIf101gMgL50820P0@0NWYj1@20P80409NGU`@0K6a/1@29RHT407emO@D0
QHF5101cLg<407moO`D0R8R8101PH6050:BTY0@0MgMg1021PH4509:BTP@0IfMW1026QXH508B4Q0@0
Ogmo2@1lO7`408:2PPD0NGUi101mOGd508F5Q@@0Ogmo101nOWh507moO`@0PH611@1lO7`407inOP@0
P8201@22PX840861P@D0O7al1022PX840820P0D0Q8B4101lO7`507moO`@0Ng]k101nOWh50861P@@0
Ogmo1@22PX8408>3P`@0Ng]k1@1oOgl407inOPD0P8201021PH4407emO@D0PX:2101nOWh507YjNP@0
P8201021PH4908:2PPD0OWin3@38h=P407UiN@T0OWin101fMWH508F5Q@@0N7Qh1023Ph<508J6QP@0
LW9b1@2;Rh/407]kN`@0QHF51@20P80408>3P`@0M7Ad1@1QHF4407YjNPD0Ph>3201lO7`907inOPD0
Ogmo1020P80408>3P`D0OGem101jNWX507QhN0P0OGem1@21PH4408B4Q0D0Ogmo101kNg/407emO@D0
OWin1021PH4507moO`@0NGUi101jNWX507MgM`@0QHF51@1jNWX407emO@@0P8201@1mOGd408F5Q@D0
Ng]k1021PH4408J6QPD0P820101mOGd907moO`@0P8201@22PX890820P0@0RHV9101lO7`507emO@@0
NWYj1024Q8@50861PAH0b>3H000E0<SPf0D0PH61101fMWH407MgM`D0P820101jNWX50820P0@0UiNG
101/K6`508V9R@@0OGem1@25QHD407=cL`@0Ogmo1@28R8P4061PH0D0Y:BT101gMgL40861P@D0TY:B
101WIfL408J6QPD0Q8B4101oOgl907alO0@0PX:21@1iNGT407emO@D0QHF5101oOgl407inOPD0Ogmo
1021PH4507alO0@0OWin1020P80508:2PP@0PH611@1lO7`408:2PP@0P8201@24Q8@407alO0D0Ogmo
101kNg/407inOPD0PH61101oOgl508:2PP@0Ph>3101kNg/507moO`@0OWin1@20P8040861P@@0OGem
1@22PX8407inOPD0NWYj1020P8040861P@T0PX:21@1nOWh=0<SPf0@0NGUi2@1nOWh407IfMPD0QHF5
101hN7P408>3P`D0QXJ6101bLW8508^;R`@0Ng]k1025QHD50820P0@0Ph>3101dM7@5065QH@@0NWYj
1@23Ph<807alO0T0OWin1@1oOgl40820P0@0Ph>31@1mOGd407YjNPD0N7Qh201mOGd50861P@@0Q8B4
1@1oOgl407]kN`@0OGem1@1nOWh40861P@D0Ogmo101iNGT407YjNPD0MgMg1025QHD507YjNP@0OGem
1020P80507emO@@0QHF51@1kNg/40861P@@0QXJ61@20P80407emO@T0Ogmo1020P80508:2PPT0P820
1029RHT407alO0D0OGem101jNWX408B4Q0D0PH615P38h=P001D0b>3H1@21PH4407IfMP@0MgMg1@20
P80407YjNPD0P820102GUiL406a/K0D0RHV9101mOGd508F5Q@@0Lg=c101oOgl508R8R0@0H61P1@2T
Y:@407MgM`@0PH611@2BTY8406MWI`@0QXJ61@24Q8@407moO`T0O7al1022PX8507UiN@@0OGem1@25
QHD407moO`@0OWin1@1oOgl40861P@D0O7al101nOWh40820P0D0PX:21021PH4507alO0@0PX:21020
P80508B4Q0@0O7al1@1oOgl407]kN`@0OWin1@21PH4407moO`D0PX:21023Ph<407]kN`D0Ogmo101n
OWh50820P0@0PH61101mOGd508:2PP@0OWin1@1jNWX40820P0@0PH612@22PX8507inOPd0b>3H101i
NGT907inOP@0MWIf1@25QHD407QhN0@0Ph>31@26QXH4079bLPD0Rh^;101kNg/408F5Q@D0P8201023
Ph<407AdM0D0HF5Q101jNWX508>3P`P0O7al2@1nOWh507moO`@0P8201023Ph<507emO@@0NWYj1@1h
N7P807emO@D0PH611024Q8@507moO`@0Ng]k101mOGd507inOP@0PH611@1oOgl407UiN@@0NWYj1@1g
MgL408F5Q@D0NWYj101mOGd40820P0D0OGem1025QHD507]kN`@0PH611026QXH50820P0@0OGem2@1o
Ogl40820P0D0PX:22@20P80408V9R@@0O7al1@1mOGd407YjNP@0Q8B41@21PH4F0<SPf0005@38h=P5
0861P@@0MWIf101gMgL50820P0@0NWYj1@20P80409NGU`@0K6a/1@29RHT407emO@D0QHF5101cLg<4
07moO`D0R8R8101PH6050:BTY0@0MgMg1021PH4509:BTP@0IfMW1026QXH508B4Q0@0Ogmo2@1lO7`4
08:2PPD0NGUi101mOGd508F5Q@@0Ogmo101nOWh507moO`@0PH611@1lO7`407inOP@0P8201@22PX84
0861P@D0O7al1022PX840820P0D0Q8B4101lO7`507moO`@0Ng]k101nOWh50861P@@0Ogmo1@22PX84
08>3P`@0Ng]k1@1oOgl407inOPD0P8201021PH4407emO@D0PX:2101nOWh507YjNP@0P8201021PH49
08:2PPD0OWin3@38h=P407UiN@T0OWin101fMWH508F5Q@@0N7Qh1023Ph<508J6QP@0LW9b1@2;Rh/4
07]kN`@0QHF51@20P80408>3P`@0M7Ad1@1QHF4407YjNPD0Ph>3201lO7`907inOPD0Ogmo1020P804
08>3P`D0OGem101jNWX507QhN0P0OGem1@21PH4408B4Q0D0Ogmo101kNg/407emO@D0OWin1021PH45
07moO`@0NGUi101jNWX507MgM`@0QHF51@1jNWX407emO@@0P8201@1mOGd408F5Q@D0Ng]k1021PH44
08J6QPD0P820101mOGd907moO`@0P8201@22PX890820P0@0RHV9101lO7`507emO@@0NWYj1024Q8@5
0861PAH0b>3H000E0<SPf0D0QhN7101mOGd4096AT@D0LW9b1020P80508:2PP@0Ogmo1020P80506m_
K`@0QXJ61@1nOWh406=SH`@0RXZ:1@1nOWh408b<S0D0HV9R1022PX8407moO`D0QhN7101`L70408B4
Q0D0Ogmo1024Q8@50820P0P0Q8B41@1lO7`407moO`D0Q8B41022PX840820P0D0OWin1020P80507in
OPP0P8201@1mOGd40861P@D0QHF5101nOWh407alO0D0Q8B41022PX850820P0@0PX:21021PH450820
P0@0OWin1@24Q8@407emO@T0P820101oOgl507inOP@0OGem101lO7`50820P0@0PX:21@21PH4408B4
Q0T0OWin1022PX8507]kN`d0b>3H101gMgL408B4Q0D0QHF5101cLg<507inOP@0MgMg101oOgl508R8
R0@0QhN71@21PH4408F5Q@@0PX:21@1iNGT407inOP@0PX:21@25QHD408>3P`D0NWYj101bLW8407Yj
NPD0Ogmo1020P80508:2PP@0Ogmo1024Q8@508F5Q@@0PH611@1nOWh408R8R0@0PX:21@21PH4407in
OPD0QHF5201gMgL507moO`T0PH611023Ph<408:2PPD0PH61101mOGd907inOP@0Ph>31@1nOWh407al
O0D0OWin101mOGd408:2PPD0Ph>3101oOgl507QhN0@0OWin1021PH450820P0@0PH611@29RHT408:2
PP@0O7al1@1iNGT40861P@@0Q8B41@1nOWhF0<SPf0005@38h=P508N7Q`@0OGem102ATI45079bLP@0
P8201@22PX8407moO`@0P8201@1_Kfl408J6QPD0OWin101SHf<408Z:RPD0OWin102<S8`5069RHP@0
PX:2101oOgl508N7Q`@0L71`1024Q8@507moO`@0Q8B41@20P80808B4Q0D0O7al101oOgl508B4Q0@0
PX:21020P80507inOP@0P8201@1nOWh80820P0D0OGem1021PH4508F5Q@@0OWin101lO7`508B4Q0@0
PX:21@20P80408:2PP@0PH611@20P80407inOPD0Q8B4101mOGd90820P0@0Ogmo1@1nOWh407emO@@0
O7al1@20P80408:2PPD0PH611024Q8@907inOP@0PX:21@1kNg/=0<SPf0@0MgMg1024Q8@508F5Q@@0
Lg=c1@1nOWh407MgM`@0Ogmo1@28R8P408N7Q`D0PH611025QHD408:2PPD0NGUi101nOWh408:2PPD0
QHF51023Ph<507YjNP@0LW9b101jNWX507moO`@0P8201@22PX8407moO`@0Q8B41@25QHD40861P@D0
OWin1028R8P408:2PPD0PH61101nOWh508F5Q@P0MgMg1@1oOgl90861P@@0Ph>31022PX850861P@@0
OGem2@1nOWh408>3P`D0OWin101lO7`507inOP@0OGem1022PX8508>3P`@0Ogmo1@1hN7P407inOP@0
PH611@20P8040861P@D0RHV91022PX8407alO0D0NGUi1021PH4408B4Q0D0OWin5P38h=P001D0b>3H
1@27QhL407emO@@0TI6A1@1bLW840820P0D0PX:2101oOgl40820P0D0Kfm_1026QXH507inOP@0Hf=S
102:RXX507inOP@0S8b<1@1RHV8408:2PP@0Ogmo1@27QhL4071`L0@0Q8B41@1oOgl408B4Q0D0P820
2024Q8@507alO0@0Ogmo1@24Q8@408:2PP@0P8201@1nOWh40820P0D0OWin2020P80507emO@@0PH61
1@25QHD407inOP@0O7al1@24Q8@408:2PPD0P8201022PX840861P@D0P820101nOWh508B4Q0@0OGem
2@20P80407moO`D0OWin101mOGd407alO0D0P8201022PX850861P@@0Q8B42@1nOWh408:2PPD0Ng]k
3@38h=P407MgM`@0Q8B41@25QHD407=cL`D0OWin101gMgL407moO`D0R8R81027QhL50861P@@0QHF5
1022PX8507UiN@@0OWin1022PX8508F5Q@@0Ph>31@1jNWX4079bLP@0NWYj1@1oOgl40820P0D0PX:2
101oOgl408B4Q0D0QHF51021PH4507inOP@0R8R81022PX850861P@@0OWin1@25QHD807MgM`D0Ogmo
2@21PH4408>3P`@0PX:21@21PH4407emO@T0OWin1023Ph<507inOP@0O7al1@1nOWh407emO@@0PX:2
1@23Ph<407moO`D0N7Qh101nOWh40861P@D0P8201021PH4508V9R@@0PX:2101lO7`507UiN@@0PH61
1024Q8@507inOQH0b>3H000E0<SPf0D0QhN7101mOGd4096AT@D0LW9b1020P80508:2PP@0Ogmo1020
P80506m_K`@0QXJ61@1nOWh406=SH`@0RXZ:1@1nOWh408b<S0D0HV9R1022PX8407moO`D0QhN7101`
L70408B4Q0D0Ogmo1024Q8@50820P0P0Q8B41@1lO7`407moO`D0Q8B41022PX840820P0D0OWin1020
P80507inOPP0P8201@1mOGd40861P@D0QHF5101nOWh407alO0D0Q8B41022PX850820P0@0PX:21021
PH450820P0@0OWin1@24Q8@407emO@T0P820101oOgl507inOP@0OGem101lO7`50820P0@0PX:21@21
PH4408B4Q0T0OWin1022PX8507]kN`d0b>3H101gMgL408B4Q0D0QHF5101cLg<507inOP@0MgMg101o
Ogl508R8R0@0QhN71@21PH4408F5Q@@0PX:21@1iNGT407inOP@0PX:21@25QHD408>3P`D0NWYj101b
LW8407YjNPD0Ogmo1020P80508:2PP@0Ogmo1024Q8@508F5Q@@0PH611@1nOWh408R8R0@0PX:21@21
PH4407inOPD0QHF5201gMgL507moO`T0PH611023Ph<408:2PPD0PH61101mOGd907inOP@0Ph>31@1n
OWh407alO0D0OWin101mOGd408:2PPD0Ph>3101oOgl507QhN0@0OWin1021PH450820P0@0PH611@29
RHT408:2PP@0O7al1@1iNGT40861P@@0Q8B41@1nOWhF0<SPf0005@38h=P507alO0@0Q8B4101nOWh5
0861P@@0O7al1@1nOWh407MgM`@0UiNG1@1aLG4409ZJVPD0MWIf102ATI4408V9R@D0OGem1023Ph<5
07AdM0@0WinO101fMWH508N7Q`@0KVi^1023Ph<508:2PP@0QXJ61@20P80408>3P`@0P8201@1nOWh4
07moO`D0PH611022PX840820P0D0Ph>3101nOWh508B4Q0@0QHF51021PH4508F5Q@@0OGem1@1oOgl4
0820P0@0NGUi1@1nOWh907moO`@0Ph>31021PH4507moO`T0OWin1021PH4907inOP@0O7al1@1oOgl4
0820P0T0PX:21025QHD90861P@@0OGem1@1iNGT407]kN`D0OWin3@38h=P408N7Q`@0Ng]k1@25QHD4
08:2PPD0Ng]k1026QXH407YjNPD0PX:2101nOWh507IfMP@0O7al101fMWH508:2PP@0OWin2@1lO7`4
0:2PX0D0U9BD101iNGT408F5Q@D0MgMg101lO7`508J6QP@0O7al2@1mOGd408>3P`D0PH61101iNGT9
07moO`@0OWin1@1lO7`407inOP@0Ph>31@22PX8407EeM@D0OGem1024Q8@407alO0D0NWYj1025QHD5
07emO@@0PX:2101nOWh507moO`@0Ph>31@20P80408:2PP@0PH611@20P80407inOPD0RHV92020P805
07moO`@0O7al1@22PX8407inOP@0Ng]k1@1oOgl408f=S@@0O7al1@29RHTF0<SPf0005@38h=P507al
O0@0Q8B4101nOWh50861P@@0O7al1@1nOWh407MgM`@0UiNG1@1aLG4409ZJVPD0MWIf102ATI4408V9
R@D0OGem1023Ph<507AdM0@0WinO101fMWH508N7Q`@0KVi^1023Ph<508:2PP@0QXJ61@20P80408>3
P`@0P8201@1nOWh407moO`D0PH611022PX840820P0D0Ph>3101nOWh508B4Q0@0QHF51021PH4508F5
Q@@0OGem1@1oOgl40820P0@0NGUi1@1nOWh907moO`@0Ph>31021PH4507moO`T0OWin1021PH4907in
OP@0O7al1@1oOgl40820P0T0PX:21025QHD90861P@@0OGem1@1iNGT407]kN`D0OWin3@38h=P408N7
Q`@0Ng]k1@25QHD408:2PPD0Ng]k1026QXH407YjNPD0PX:2101nOWh507IfMP@0O7al101fMWH508:2
PP@0OWin2@1lO7`40:2PX0D0U9BD101iNGT408F5Q@D0MgMg101lO7`508J6QP@0O7al2@1mOGd408>3
P`D0PH61101iNGT907moO`@0OWin1@1lO7`407inOP@0Ph>31@22PX8407EeM@D0OGem1024Q8@407al
O0D0NWYj1025QHD507emO@@0PX:2101nOWh507moO`@0Ph>31@20P80408:2PP@0PH611@20P80407in
OPD0RHV92020P80507moO`@0O7al1@22PX8407inOP@0Ng]k1@1oOgl408f=S@@0O7al1@29RHTF0<SP
f0005@38h=P507alO0@0Q8B4101nOWh50861P@@0O7al1@1nOWh407MgM`@0UiNG1@1aLG4409ZJVPD0
MWIf102ATI4408V9R@D0OGem1023Ph<507AdM0@0WinO101fMWH508N7Q`@0KVi^1023Ph<508:2PP@0
QXJ61@20P80408>3P`@0P8201@1nOWh407moO`D0PH611022PX840820P0D0Ph>3101nOWh508B4Q0@0
QHF51021PH4508F5Q@@0OGem1@1oOgl40820P0@0NGUi1@1nOWh907moO`@0Ph>31021PH4507moO`T0
OWin1021PH4907inOP@0O7al1@1oOgl40820P0T0PX:21025QHD90861P@@0OGem1@1iNGT407]kN`D0
OWin3@38h=P408N7Q`@0Ng]k1@25QHD408:2PPD0Ng]k1026QXH407YjNPD0PX:2101nOWh507IfMP@0
O7al101fMWH508:2PP@0OWin2@1lO7`40:2PX0D0U9BD101iNGT408F5Q@D0MgMg101lO7`508J6QP@0
O7al2@1mOGd408>3P`D0PH61101iNGT907moO`@0OWin1@1lO7`407inOP@0Ph>31@22PX8407EeM@D0
OGem1024Q8@407alO0D0NWYj1025QHD507emO@@0PX:2101nOWh507moO`@0Ph>31@20P80408:2PP@0
PH611@20P80407inOPD0RHV92020P80507moO`@0O7al1@22PX8407inOP@0Ng]k1@1oOgl408f=S@@0
O7al1@29RHTF0<SPf0005@38h=P507alO0@0Q8B4101nOWh50861P@@0O7al1@1nOWh407MgM`@0UiNG
1@1aLG4409ZJVPD0MWIf102ATI4408V9R@D0OGem1023Ph<507AdM0@0WinO101fMWH508N7Q`@0KVi^
1023Ph<508:2PP@0QXJ61@20P80408>3P`@0P8201@1nOWh407moO`D0PH611022PX840820P0D0Ph>3
101nOWh508B4Q0@0QHF51021PH4508F5Q@@0OGem1@1oOgl40820P0@0NGUi1@1nOWh907moO`@0Ph>3
1021PH4507moO`T0OWin1021PH4907inOP@0O7al1@1oOgl40820P0T0PX:21025QHD90861P@@0OGem
1@1iNGT407]kN`D0OWin3@38h=P408N7Q`@0Ng]k1@25QHD408:2PPD0Ng]k1026QXH407YjNPD0PX:2
101nOWh507IfMP@0O7al101fMWH508:2PP@0OWin2@1lO7`40:2PX0D0U9BD101iNGT408F5Q@D0MgMg
101lO7`508J6QP@0O7al2@1mOGd408>3P`D0PH61101iNGT907moO`@0OWin1@1lO7`407inOP@0Ph>3
1@22PX8407EeM@D0OGem1024Q8@407alO0D0NWYj1025QHD507emO@@0PX:2101nOWh507moO`@0Ph>3
1@20P80408:2PP@0PH611@20P80407inOPD0RHV92020P80507moO`@0O7al1@22PX8407inOP@0Ng]k
1@1oOgl408f=S@@0O7al1@29RHTF0<SPf0005@38h=P507alO0@0Q8B4101nOWh50861P@@0O7al1@1n
OWh407MgM`@0UiNG1@1aLG4409ZJVPD0MWIf102ATI4408V9R@D0OGem1023Ph<507AdM0@0WinO101f
MWH508N7Q`@0KVi^1023Ph<508:2PP@0QXJ61@20P80408>3P`@0P8201@1nOWh407moO`D0PH611022
PX840820P0D0Ph>3101nOWh508B4Q0@0QHF51021PH4508F5Q@@0OGem1@1oOgl40820P0@0NGUi1@1n
OWh907moO`@0Ph>31021PH4507moO`T0OWin1021PH4907inOP@0O7al1@1oOgl40820P0T0PX:21025
QHD90861P@@0OGem1@1iNGT407]kN`D0OWin3@38h=P408N7Q`@0Ng]k1@25QHD408:2PPD0Ng]k1026
QXH407YjNPD0PX:2101nOWh507IfMP@0O7al101fMWH508:2PP@0OWin2@1lO7`40:2PX0D0U9BD101i
NGT408F5Q@D0MgMg101lO7`508J6QP@0O7al2@1mOGd408>3P`D0PH61101iNGT907moO`@0OWin1@1l
O7`407inOP@0Ph>31@22PX8407EeM@D0OGem1024Q8@407alO0D0NWYj1025QHD507emO@@0PX:2101n
OWh507moO`@0Ph>31@20P80408:2PP@0PH611@20P80407inOPD0RHV92020P80507moO`@0O7al1@22
PX8407inOP@0Ng]k1@1oOgl408f=S@@0O7al1@29RHTF0<SPf0005@38h=P507emO@@0Ogmo1020P809
0861P@D0Ng]k1022PX8408B4Q0D0NGUi1021PH4507UiN@@0U9BD101QHF4508F5Q@@0O7al1@2:RXX4
05IFEP@0X:2P1@20P804071`L0@0Ng]k1@25QHD90820P0@0PX:21020P8050861P@@0OWin1@23Ph<4
08B4Q0@0Ogmo1@20P80407inOPD0PX:21020P8090861P@@0O7al1@22PX8408>3P`@0Ogmo1@1nOWh4
07UiN@D0Ogmo1020P80408B4Q0D0OGem1024Q8@507moO`@0OGem101nOWh50820P0@0OGem1@1jNWX4
07moO`@0Ph>31@1mOGd408>3P`T0OWin1021PH450820P0@0Q8B41@21PH4=0<SPf0@0Ogmo1022PX8>
07moO`@0R8R8101kNg/507emO@@0R8R81@2;Rh/408Z:RP@0OGem1@2<S8`407]kN`@0QHF51@21PH44
07UiN@D0ADE51027QhL407emO@D0Ogmo101mOGd507alO0@0PX:22@20P80407]kN`D0PH611026QXH4
07moO`D0PH61101oOgl507emO@@0QXJ6101nOWh508>3P`@0PH611@1nOWh407emO@@0QXJ61@24Q8@4
07moO`D0N7Qh101mOGd408F5Q@D0OGem101oOgl508J6QP@0PX:21026QXH507UiN@@0Ogmo1@25QHD4
07emO@@0O7al1@1oOgl407alO0D0NGUi101gMgL40820P0D0N7Qh101kNg/408>3P`D0OWin5P38h=P0
01D0b>3H1@1mOGd407moO`@0P8202@21PH4507]kN`@0PX:21024Q8@507UiN@@0PH611@1iNGT409BD
U0@0HF5Q1@25QHD407alO0D0RXZ:101FEUH40:2PX0D0P820101`L70407]kN`D0QHF52@20P80408:2
PP@0P8201@21PH4407inOPD0Ph>31024Q8@407moO`D0P820101nOWh508:2PP@0P8202@21PH4407al
O0D0PX:21023Ph<407moO`D0OWin101iNGT507moO`@0P8201024Q8@507emO@@0Q8B41@1oOgl407em
O@@0OWin1@20P80407emO@D0NWYj101oOgl408>3P`D0OGem1023Ph<907inOP@0PH611@20P80408B4
Q0D0PH613@38h=P407moO`@0PX:23P1oOgl408R8R0@0Ng]k1@1mOGd408R8R0D0Rh^;102:RXX407em
O@D0S8b<101kNg/408F5Q@D0PH61101iNGT504E5A@@0QhN7101mOGd507moO`@0OGem1@1lO7`408:2
PPT0P820101kNg/50861P@@0QXJ6101oOgl50861P@@0Ogmo1@1mOGd408J6QP@0OWin1@23Ph<40861
P@D0OWin101mOGd408J6QPD0Q8B4101oOgl507QhN0@0OGem1025QHD507emO@@0Ogmo1@26QXH408:2
PP@0QXJ61@1iNGT407moO`D0QHF5101mOGd407alO0D0Ogmo101lO7`507UiN@@0MgMg1020P80507Qh
N0@0Ng]k1023Ph<507inOQH0b>3H000E0<SPf0D0OGem101oOgl40820P0T0PH611@1kNg/408:2PP@0
Q8B41@1iNGT40861P@D0NGUi102DU9@4065QH@D0QHF5101lO7`508Z:RP@0EUIF102PX:050820P0@0
L71`101kNg/508F5Q@T0P8201022PX840820P0D0PH61101nOWh508>3P`@0Q8B4101oOgl50820P0@0
OWin1@22PX840820P0T0PH61101lO7`508:2PP@0Ph>3101oOgl507inOP@0NGUi1@1oOgl40820P0@0
Q8B41@1mOGd408B4Q0D0Ogmo101mOGd407inOPD0P820101mOGd507YjNP@0Ogmo1023Ph<507emO@@0
Ph>32@1nOWh40861P@D0P8201024Q8@50861P@d0b>3H101oOgl408:2PPh0Ogmo1028R8P407]kN`D0
OGem1028R8P508^;R`@0RXZ:101mOGd508b<S0@0Ng]k1025QHD50861P@@0NGUi1@15ADD408N7Q`@0
OGem1@1oOgl407emO@D0O7al1022PX890820P0@0Ng]k1@21PH4408J6QP@0Ogmo1@21PH4407moO`D0
OGem1026QXH407inOPD0Ph>31021PH4507inOP@0OGem1026QXH508B4Q0@0Ogmo1@1hN7P407emO@@0
QHF51@1mOGd407moO`D0QXJ61022PX8408J6QPD0NGUi101oOgl508F5Q@@0OGem101lO7`507moO`@0
O7al1@1iNGT407MgM`@0P8201@1hN7P407]kN`@0Ph>31@1nOWhF0<SPf0005@38h=P507emO@@0Ogmo
1020P8090861P@D0Ng]k1022PX8408B4Q0D0NGUi1021PH4507UiN@@0U9BD101QHF4508F5Q@@0O7al
1@2:RXX405IFEP@0X:2P1@20P804071`L0@0Ng]k1@25QHD90820P0@0PX:21020P8050861P@@0OWin
1@23Ph<408B4Q0@0Ogmo1@20P80407inOPD0PX:21020P8090861P@@0O7al1@22PX8408>3P`@0Ogmo
1@1nOWh407UiN@D0Ogmo1020P80408B4Q0D0OGem1024Q8@507moO`@0OGem101nOWh50820P0@0OGem
1@1jNWX407moO`@0Ph>31@1mOGd408>3P`T0OWin1021PH450820P0@0Q8B41@21PH4=0<SPf0@0Ogmo
1022PX8>07moO`@0R8R8101kNg/507emO@@0R8R81@2;Rh/408Z:RP@0OGem1@2<S8`407]kN`@0QHF5
1@21PH4407UiN@D0ADE51027QhL407emO@D0Ogmo101mOGd507alO0@0PX:22@20P80407]kN`D0PH61
1026QXH407moO`D0PH61101oOgl507emO@@0QXJ6101nOWh508>3P`@0PH611@1nOWh407emO@@0QXJ6
1@24Q8@407moO`D0N7Qh101mOGd408F5Q@D0OGem101oOgl508J6QP@0PX:21026QXH507UiN@@0Ogmo
1@25QHD407emO@@0O7al1@1oOgl407alO0D0NGUi101gMgL40820P0D0N7Qh101kNg/408>3P`D0OWin
5P38h=P001D0b>3H1@2<S8`407emO@T0OWin1023Ph<507=cL`@0O7al101oOgl508j>SP@0Lg=c1@2D
U9@407=cL`@0P8201@27QhL407MgM`D0P8201023Ph<407UiN@D0PX:2101jNWX408:2PPD0Ng]k101o
Ogl508B4Q0@0QHF51024Q8@50861P@@0O7al1@27QhL408>3P`@0P8201@1lO7`907inOP@0PX:21020
P8050861P@@0Ogmo2@21PH4408:2PPD0P820101mOGd508:2PP@0P8201023Ph<907emO@D0P8201024
Q8@408>3P`D0Ogmo1021PH4507inOP@0PX:2101kNg/507alO0@0Ph>31@20P80408>3P`@0O7al1@20
P80407emO@D0O7al3@38h=P407alO0@0QhN71@29RHT40820P0D0PX:2101oOgl407EeM@D0PX:2101o
Ogl507YjNP@0NGUi102;Rh/507alO0P0Ph>31@24Q8@407UiN@D0VYZJ1020P80407YjNPD0OGem102:
RXX507inOP@0Ogmo101mOGd508B4Q0T0OGem1020P80408>3P`D0PH61101nOWh907moO`@0PH611@1k
Ng/408F5Q@D0P820101nOWh408:2PPD0QHF51022PX8508F5Q@@0Q8B4101oOgl507emO@@0O7al1@1m
OGd408:2PP@0Ogmo1@1gMgL408J6QPD0Ph>3101kNg/408B4Q0D0OGem1020P80508N7Q`@0Ph>31022
PX8507moO`@0NGUi101nOWh507emOAH0b>3H000E0<SPf0D0S8b<101mOGd907inOP@0Ph>31@1cLg<4
07alO0@0Ogmo1@2>SXh407=cL`D0U9BD101cLg<40820P0D0QhN7101gMgL50820P0@0Ph>3101iNGT5
08:2PP@0NWYj1022PX8507]kN`@0Ogmo1@24Q8@408F5Q@@0Q8B41@21PH4407alO0D0QhN71023Ph<4
0820P0D0O7al2@1nOWh408:2PP@0P8201@21PH4407moO`T0PH611022PX850820P0@0OGem1@22PX84
0820P0@0Ph>32@1mOGd50820P0@0Q8B41023Ph<507moO`@0PH611@1nOWh408:2PP@0Ng]k1@1lO7`4
08>3P`D0P8201023Ph<407alO0D0P820101mOGd507alO0d0b>3H101lO7`408N7Q`D0RHV91020P805
08:2PP@0Ogmo101eMGD508:2PP@0Ogmo1@1jNWX407UiN@@0Rh^;1@1lO7`808>3P`D0Q8B4101iNGT5
09ZJVP@0P820101jNWX507emO@@0RXZ:1@1nOWh407moO`@0OGem1@24Q8@907emO@@0P8201023Ph<5
0861P@@0OWin2@1oOgl40861P@D0Ng]k1025QHD50820P0@0OWin1022PX8508F5Q@@0PX:21@25QHD4
08B4Q0@0Ogmo1@1mOGd407alO0D0OGem1022PX8407moO`D0MgMg1026QXH508>3P`@0Ng]k1024Q8@5
07emO@@0P8201@27QhL408>3P`@0PX:21@1oOgl407UiN@@0OWin1@1mOGdF0<SPf0005@38h=P508b<
S0@0OGem2@1nOWh408>3P`D0Lg=c101lO7`407moO`D0SXj>101cLg<509BDU0@0Lg=c1020P80508N7
Q`@0MgMg1@20P80408>3P`@0NGUi1@22PX8407YjNP@0PX:21@1kNg/407moO`D0Q8B41025QHD408B4
Q0D0PH61101lO7`508N7Q`@0Ph>31020P80507alO0T0OWin1022PX840820P0D0PH61101oOgl90861
P@@0PX:21@20P80407emO@D0PX:21020P80408>3P`T0OGem1@20P80408B4Q0@0Ph>31@1oOgl40861
P@D0OWin1022PX8407]kN`D0O7al1023Ph<50820P0@0Ph>3101lO7`50820P0@0OGem1@1lO7`=0<SP
f0@0O7al1027QhL508V9R@@0P8201@22PX8407moO`@0MGEe1@22PX8407moO`D0NWYj101iNGT408^;
R`D0O7al2023Ph<508B4Q0@0NGUi1@2JVYX40820P0@0NWYj1@1mOGd408Z:RPD0OWin101oOgl407em
O@D0Q8B42@1mOGd40820P0@0Ph>31@21PH4407inOPT0Ogmo1021PH4507]kN`@0QHF51@20P80407in
OP@0PX:21@25QHD408:2PPD0QHF51024Q8@407moO`D0OGem101lO7`507emO@@0PX:2101oOgl507Mg
M`@0QXJ61@23Ph<407]kN`@0Q8B41@1mOGd40820P0D0QhN71023Ph<408:2PPD0Ogmo101iNGT407in
OPD0OGem5P38h=P001D0b>3H1@2<S8`407emO@T0OWin1023Ph<507=cL`@0O7al101oOgl508j>SP@0
Lg=c1@2DU9@407=cL`@0P8201@27QhL407MgM`D0P8201023Ph<407UiN@D0PX:2101jNWX408:2PPD0
Ng]k101oOgl508B4Q0@0QHF51024Q8@50861P@@0O7al1@27QhL408>3P`@0P8201@1lO7`907inOP@0
PX:21020P8050861P@@0Ogmo2@21PH4408:2PPD0P820101mOGd508:2PP@0P8201023Ph<907emO@D0
P8201024Q8@408>3P`D0Ogmo1021PH4507inOP@0PX:2101kNg/507alO0@0Ph>31@20P80408>3P`@0
O7al1@20P80407emO@D0O7al3@38h=P407alO0@0QhN71@29RHT40820P0D0PX:2101oOgl407EeM@D0
PX:2101oOgl507YjNP@0NGUi102;Rh/507alO0P0Ph>31@24Q8@407UiN@D0VYZJ1020P80407YjNPD0
OGem102:RXX507inOP@0Ogmo101mOGd508B4Q0T0OGem1020P80408>3P`D0PH61101nOWh907moO`@0
PH611@1kNg/408F5Q@D0P820101nOWh408:2PPD0QHF51022PX8508F5Q@@0Q8B4101oOgl507emO@@0
O7al1@1mOGd408:2PP@0Ogmo1@1gMgL408J6QPD0Ph>3101kNg/408B4Q0D0OGem1020P80508N7Q`@0
Ph>31022PX8507moO`@0NGUi101nOWh507emOAH0b>3H000E0<SPf0D0S8b<101mOGd907inOP@0Ph>3
1@1cLg<407alO0@0Ogmo1@2>SXh407=cL`D0U9BD101cLg<40820P0D0QhN7101gMgL50820P0@0Ph>3
101iNGT508:2PP@0NWYj1022PX8507]kN`@0Ogmo1@24Q8@408F5Q@@0Q8B41@21PH4407alO0D0QhN7
1023Ph<40820P0D0O7al2@1nOWh408:2PP@0P8201@21PH4407moO`T0PH611022PX850820P0@0OGem
1@22PX840820P0@0Ph>32@1mOGd50820P0@0Q8B41023Ph<507moO`@0PH611@1nOWh408:2PP@0Ng]k
1@1lO7`408>3P`D0P8201023Ph<407alO0D0P820101mOGd507alO0d0b>3H101lO7`408N7Q`D0RHV9
1020P80508:2PP@0Ogmo101eMGD508:2PP@0Ogmo1@1jNWX407UiN@@0Rh^;1@1lO7`808>3P`D0Q8B4
101iNGT509ZJVP@0P820101jNWX507emO@@0RXZ:1@1nOWh407moO`@0OGem1@24Q8@907emO@@0P820
1023Ph<50861P@@0OWin2@1oOgl40861P@D0Ng]k1025QHD50820P0@0OWin1022PX8508F5Q@@0PX:2
1@25QHD408B4Q0@0Ogmo1@1mOGd407alO0D0OGem1022PX8407moO`D0MgMg1026QXH508>3P`@0Ng]k
1024Q8@507emO@@0P8201@27QhL408>3P`@0PX:21@1oOgl407UiN@@0OWin1@1mOGdF0<SPf0005@38
h=P509BDU0P0N7Qh1@1mOGd408:2PPD0Ng]k1020P80908:2PP@0MWIf1@1gMgL408F5Q@@0VIVI1@1L
G5`408F5Q@D0PH61102:RXX406a/K0D0WYjN101gMgL407QhN0D0PX:2101lO7`50820P0P0Ogmo1@1m
OGd407inOPD0QHF51021PH4407moO`D0OWin1023Ph<50861P@P0PX:21@1nOWh408:2PPT0PH612@20
P80407alO0D0OWin1020P80408J6QPD0Q8B41021PH4508:2PP@0QHF52@1mOGd40820P0D0PH611023
Ph<407alO0D0PX:2101lO7`50820P0@0OGem101lO7`507inOP@0Ogmo1@22PX8=0<SPf0@0OGem1022
PX8508R8R0@0P8201@1iNGT407]kN`@0O7al1@27QhL90861P@@0QhN7101nOWh508R8R0@0QXJ6101n
OWh907emO@D0Lg=c102SXj<409>CT`D0NGUi1029RHT50861P@@0OGem101nOWh507MgM`@0P8201@22
PX8407emO@@0OWin1@23Ph<407emO@T0O7al1020P80507inOP@0OGem1@21PH4407alO0@0P8201@21
PH4908>3P`@0N7Qh101mOGd508>3P`@0QHF51@1mOGd408:2PP@0OGem1@20P80407alO0T0OGem1026
QXH507moO`@0P8201@1oOgl80820P0D0MgMg1025QHD407alO0D0PX:25P38h=P001D0b>3H1@2DU9@8
07QhN0D0OGem1022PX8507]kN`@0P8202@22PX8407IfMPD0MgMg1025QHD409VIV@D0G5aL1025QHD5
0861P@@0RXZ:101/K6`509jNWP@0MgMg101hN7P508:2PP@0O7al1@20P80807moO`D0OGem101nOWh5
08F5Q@@0PH61101oOgl507inOP@0Ph>31@21PH4808:2PPD0OWin1022PX890861P@T0P820101lO7`5
07inOP@0P8201026QXH508B4Q0@0PH611@22PX8408F5Q@T0OGem1020P8050861P@@0Ph>3101lO7`5
08:2PP@0O7al1@20P80407emO@@0O7al1@1nOWh407moO`D0PX:23@38h=P407emO@@0PX:21@28R8P4
0820P0D0NGUi101kNg/407alO0D0QhN72@21PH4408N7Q`@0OWin1@28R8P408J6QP@0OWin2@1mOGd5
07=cL`@0Xj>S102CTi<507UiN@@0RHV91@21PH4407emO@@0OWin1@1gMgL40820P0D0PX:2101mOGd4
07inOPD0Ph>3101mOGd907alO0@0P8201@1nOWh407emO@D0PH61101lO7`40820P0D0PH612@23Ph<4
07QhN0@0OGem1@23Ph<408F5Q@D0OGem1022PX8407emO@D0P820101lO7`907emO@@0QXJ61@1oOgl4
0820P0D0Ogmo2020P80507MgM`@0QHF5101lO7`508:2PQH0b>3H000E0<SPf0D0U9BD201hN7P507em
O@@0PX:21@1kNg/40820P0T0PX:2101fMWH507MgM`@0QHF5102IVIT505aLG0@0QHF51@21PH4408Z:
RP@0K6a/1@2NWYh407MgM`@0N7Qh1@22PX8407alO0D0P820201oOgl507emO@@0OWin1@25QHD40861
P@@0Ogmo1@1nOWh408>3P`D0PH612022PX8507inOP@0PX:22@21PH490820P0@0O7al1@1nOWh40820
P0@0QXJ61@24Q8@40861P@D0PX:21025QHD907emO@@0P8201@21PH4408>3P`@0O7al1@22PX8407al
O0D0P820101mOGd407alO0D0OWin101oOgl508:2PPd0b>3H101mOGd408:2PPD0R8R81020P80507Ui
N@@0Ng]k101lO7`508N7Q`T0PH611027QhL407inOPD0R8R81026QXH407inOPT0OGem1@1cLg<40:>S
X`@0Ti>C1@1iNGT408V9R@D0PH61101mOGd407inOPD0MgMg1020P80508:2PP@0OGem101nOWh508>3
P`@0OGem2@1lO7`40820P0D0OWin101mOGd50861P@@0O7al1020P8050861P@T0Ph>3101hN7P407em
O@D0Ph>31025QHD507emO@@0PX:2101mOGd50820P0@0O7al2@1mOGd408J6QPD0Ogmo1020P80507mo
O`P0P8201@1gMgL408F5Q@@0O7al1@22PX8F0<SPf0005@38h=P509BDU0P0N7Qh1@1mOGd408:2PPD0
Ng]k1020P80908:2PP@0MWIf1@1gMgL408F5Q@@0VIVI1@1LG5`408F5Q@D0PH61102:RXX406a/K0D0
WYjN101gMgL407QhN0D0PX:2101lO7`50820P0P0Ogmo1@1mOGd407inOPD0QHF51021PH4407moO`D0
OWin1023Ph<50861P@P0PX:21@1nOWh408:2PPT0PH612@20P80407alO0D0OWin1020P80408J6QPD0
Q8B41021PH4508:2PP@0QHF52@1mOGd40820P0D0PH611023Ph<407alO0D0PX:2101lO7`50820P0@0
OGem101lO7`507inOP@0Ogmo1@22PX8=0<SPf0@0OGem1022PX8508R8R0@0P8201@1iNGT407]kN`@0
O7al1@27QhL90861P@@0QhN7101nOWh508R8R0@0QXJ6101nOWh907emO@D0Lg=c102SXj<409>CT`D0
NGUi1029RHT50861P@@0OGem101nOWh507MgM`@0P8201@22PX8407emO@@0OWin1@23Ph<407emO@T0
O7al1020P80507inOP@0OGem1@21PH4407alO0@0P8201@21PH4908>3P`@0N7Qh101mOGd508>3P`@0
QHF51@1mOGd408:2PP@0OGem1@20P80407alO0T0OGem1026QXH507moO`@0P8201@1oOgl80820P0D0
MgMg1025QHD407alO0D0PX:25P38h=P001D0b>3H1@1kNg/407inOP@0Ng]k1@20P8040861P@D0OGem
1020P80408>3P`D0OGem102?Shl506m_K`@0VIVI101dM7@508N7Q`@0U9BD1@1jNWX407moO`@0QXJ6
1@1PH6040:2PX0@0MgMg1@21PH4407inOPD0Q8B41023Ph<40820P0D0PX:2101nOWh50861P@@0QhN7
1023Ph<507emO@@0Ph>31@1oOgl407inOP@0Q8B41@22PX840861P@D0OWin1023Ph<407moO`D0PH61
1022PX8507emO@@0OWin1022PX850820P0@0PH611@1mOGd407inOPT0P820101mOGd507alO0@0NWYj
1020P80507emO@@0N7Qh1@1lO7`408J6QP@0Ogmo1@20P80407inOPD0Ng]k3@38h=P407inOP@0Ng]k
1@1lO7`407UiN@D0P820101lO7`40861P@D0P820101lO7`508R8R0@0NWYj101aLG450820P0@0N7Qh
2@1mOGd408B4Q0D0PH61101[Jf/405aLG0D0PX:2101hN7P507moO`@0Ph>3101mOGd507alO0@0PH61
1@1nOWh408b<S0@0OWin1@1mOGd40820P0D0Ph>3101lO7`407UiN@D0PX:2101mOGd907inOP@0OGem
1@21PH4408J6QPD0P8201023Ph<407YjNPD0OGem1021PH4507]kN`@0PX:21020P80507moO`@0OGem
1@1oOgl408>3P`@0O7al1@1kNg/40861P@D0PX:21021PH4407inOPT0Ogmo101lO7`507moOaH0b>3H
000E0<SPf0D0Ng]k101nOWh407]kN`D0P8201021PH4507emO@@0P8201023Ph<507emO@@0Shn?1@1_
Kfl409VIV@@0M7Ad1@27QhL409BDU0D0NWYj101oOgl408J6QPD0H61P102PX:0407MgM`D0PH61101n
OWh508B4Q0@0Ph>31020P80508:2PP@0OWin1@21PH4408N7Q`@0Ph>31@1mOGd408>3P`D0Ogmo101n
OWh408B4Q0D0PX:21021PH4507inOP@0Ph>3101oOgl50861P@@0PX:21@1mOGd407inOP@0PX:21@20
P8040861P@D0OGem101nOWh90820P0@0OGem1@1lO7`407YjNP@0P8201@1mOGd407QhN0D0O7al1026
QXH407moO`D0P820101nOWh507]kN`d0b>3H101nOWh407]kN`D0O7al101iNGT50820P0@0O7al1021
PH450820P0@0O7al1@28R8P407YjNP@0LG5a1@20P80407QhN0T0OGem1024Q8@50861P@@0Jf][101L
G5`508:2PP@0N7Qh1@1oOgl408>3P`@0OGem1@1lO7`40861P@D0OWin102<S8`407inOPD0OGem1020
P80508>3P`@0O7al101iNGT508:2PP@0OGem2@1nOWh407emO@D0PH611026QXH50820P0@0Ph>3101j
NWX507emO@@0PH611@1kNg/408:2PP@0P8201@1oOgl407emO@D0Ogmo1023Ph<407alO0D0Ng]k1021
PH4508:2PP@0PH61101nOWh907moO`@0O7al1@1oOglF0<SPf0005@38h=P507]kN`@0OWin101kNg/5
0820P0@0PH611@1mOGd40820P0@0Ph>31@1mOGd408n?S`D0Kfm_102IVIT407AdM0D0QhN7102DU9@5
07YjNP@0Ogmo1026QXH5061PH0@0X:2P101gMgL50861P@@0OWin1@24Q8@408>3P`@0P8201@22PX84
07inOPD0PH611027QhL408>3P`D0OGem1023Ph<507moO`@0OWin1024Q8@508:2PP@0PH611@1nOWh4
08>3P`@0Ogmo1@21PH4408:2PPD0OGem101nOWh408:2PPD0P8201021PH4507emO@@0OWin2@20P804
07emO@D0O7al101jNWX40820P0D0OGem101hN7P507alO0@0QXJ6101oOgl50820P0@0OWin1@1kNg/=
0<SPf0@0OWin101kNg/507alO0@0NGUi1@20P80407alO0@0PH611@20P80407alO0D0R8R8101jNWX4
075aL@D0P820101hN7P907emO@@0Q8B41@21PH4406][J`@0G5aL1@22PX8407QhN0D0Ogmo1023Ph<4
07emO@D0O7al1021PH4507inOP@0S8b<101nOWh507emO@@0P8201@23Ph<407alO0@0NGUi1@22PX84
07emO@T0OWin101mOGd50861P@@0QXJ61@20P80408>3P`@0NWYj1@1mOGd40861P@D0Ng]k1022PX84
0820P0D0Ogmo101mOGd507moO`@0Ph>3101lO7`507]kN`@0PH611@22PX840861P@@0OWin2@1oOgl4
07alO0D0Ogmo5P38h=P001D0b>3H1@1kNg/407inOP@0Ng]k1@20P8040861P@D0OGem1020P80408>3
P`D0OGem102?Shl506m_K`@0VIVI101dM7@508N7Q`@0U9BD1@1jNWX407moO`@0QXJ61@1PH6040:2P
X0@0MgMg1@21PH4407inOPD0Q8B41023Ph<40820P0D0PX:2101nOWh50861P@@0QhN71023Ph<507em
O@@0Ph>31@1oOgl407inOP@0Q8B41@22PX840861P@D0OWin1023Ph<407moO`D0PH611022PX8507em
O@@0OWin1022PX850820P0@0PH611@1mOGd407inOPT0P820101mOGd507alO0@0NWYj1020P80507em
O@@0N7Qh1@1lO7`408J6QP@0Ogmo1@20P80407inOPD0Ng]k3@38h=P407inOP@0Ng]k1@1lO7`407Ui
N@D0P820101lO7`40861P@D0P820101lO7`508R8R0@0NWYj101aLG450820P0@0N7Qh2@1mOGd408B4
Q0D0PH61101[Jf/405aLG0D0PX:2101hN7P507moO`@0Ph>3101mOGd507alO0@0PH611@1nOWh408b<
S0@0OWin1@1mOGd40820P0D0Ph>3101lO7`407UiN@D0PX:2101mOGd907inOP@0OGem1@21PH4408J6
QPD0P8201023Ph<407YjNPD0OGem1021PH4507]kN`@0PX:21020P80507moO`@0OGem1@1oOgl408>3
P`@0O7al1@1kNg/40861P@D0PX:21021PH4407inOPT0Ogmo101lO7`507moOaH0b>3H000E0<SPf0D0
SHf=101lO7`407emO@D0N7Qh2@1oOgl40861P@@0Ng]k1@20P80907moO`@0NWYj1022PX8509FEU@@0
IfMW1@21PH4408>3P`@0Q8B41@27QhL406MWI`@0S8b<1@1nOWh407moO`D0P820101lO7`408:2PPD0
Ogmo1021PH4=0820P0D0Ng]k101oOgl50820P0P0OGem3P1nOWh407emO@@0O7al1@1oOgl407inOPD0
O7al1021PH4407alO0D0P8202@1nOWh=07emO@@0OWin1@1mOGd40861P@@0P8201@21PH4407inOPD0
Ng]k1021PH4407inOPD0QhN7101mOGd507alO0d0b>3H101nOWh408B4Q0D0RHV9101eMGD507inOP@0
Ogmo101mOGd507]kN`@0P8201@23Ph<407IfMP@0RHV91@23Ph<408B4Q0@0S8b<1@22PX8407inOPD0
PH611022PX8408>3P`D0CDe=101mOGd50861P@@0Rh^;1025QHD50861P@@0OGem1@20P80407]kN`@0
OGem1@20P80408:2PPD0PH61201mOGd507alO0@0Q8B41@1iNGT407emO@@0R8R81@21PH490820P0d0
OWin1021PH4908:2PP@0Q8B42@1oOgl508>3P`@0OWin1025QHD50861P@@0QHF51@21PH4407inOP@0
NWYj1@27QhL40820P0@0Ph>31@20P80F0<SPf0005@38h=P508f=S@@0O7al101mOGd507QhN0T0Ogmo
1021PH4407]kN`D0P8202@1oOgl407YjNP@0PX:21@2EUID406MWI`D0PH611023Ph<408B4Q0D0QhN7
101WIfL408b<S0D0OWin101oOgl50820P0@0O7al1022PX8507moO`@0PH613@20P80507]kN`@0Ogmo
1@20P80807emO@h0OWin101mOGd407alO0D0Ogmo101nOWh507alO0@0PH61101lO7`50820P0T0OWin
3@1mOGd407inOPD0OGem1021PH440820P0D0PH61101nOWh507]kN`@0PH61101nOWh508N7Q`@0OGem
1@1lO7`=0<SPf0@0OWin1024Q8@508V9R@@0MGEe1@1nOWh407moO`@0OGem1@1kNg/40820P0D0Ph>3
101fMWH408V9R@D0Ph>31024Q8@408b<S0D0PX:2101nOWh50861P@@0PX:21023Ph<504e=C@@0OGem
1@21PH4408^;R`@0QHF51@21PH4407emO@D0P820101kNg/407emO@D0P8201022PX850861P@P0OGem
1@1lO7`408B4Q0D0NGUi101mOGd408R8R0D0PH612@20P80=07inOP@0PH612@22PX8408B4Q0T0Ogmo
1@23Ph<407inOP@0QHF51@21PH4408F5Q@D0PH61101nOWh407YjNPD0QhN71020P80408>3P`D0P820
5P38h=P001D0b>3H1@2=SHd407alO0@0OGem1@1hN7P907moO`@0PH61101kNg/50820P0T0Ogmo101j
NWX408:2PPD0UIFE101WIfL50861P@@0Ph>31024Q8@508N7Q`@0IfMW102<S8`507inOP@0Ogmo1@20
P80407alO0@0PX:21@1oOgl40861P@d0P8201@1kNg/407moO`D0P820201mOGd>07inOP@0OGem101l
O7`507moO`@0OWin1@1lO7`40861P@@0O7al1@20P80907inOPd0OGem101nOWh507emO@@0PH611020
P8050861P@@0OWin1@1kNg/40861P@@0OWin1@27QhL407emO@D0O7al3@38h=P407inOP@0Q8B41@29
RHT407EeM@D0OWin101oOgl407emO@D0Ng]k1020P80508>3P`@0MWIf1029RHT508>3P`@0Q8B4102<
S8`508:2PP@0OWin1@21PH4408:2PP@0Ph>31@1=CDd407emO@D0PH61102;Rh/408F5Q@D0PH61101m
OGd50820P0@0Ng]k101mOGd50820P0@0PX:21@21PH4807emO@D0O7al1024Q8@507UiN@@0OGem1028
R8P50861P@T0P8203@1nOWh40861P@T0PX:21024Q8@907moO`D0Ph>3101nOWh408F5Q@D0PH611025
QHD50861P@@0OWin101jNWX508N7Q`@0P8201023Ph<50820P1H0b>3H000E0<SPf0D0SHf=101lO7`4
07emO@D0N7Qh2@1oOgl40861P@@0Ng]k1@20P80907moO`@0NWYj1022PX8509FEU@@0IfMW1@21PH44
08>3P`@0Q8B41@27QhL406MWI`@0S8b<1@1nOWh407moO`D0P820101lO7`408:2PPD0Ogmo1021PH4=
0820P0D0Ng]k101oOgl50820P0P0OGem3P1nOWh407emO@@0O7al1@1oOgl407inOPD0O7al1021PH44
07alO0D0P8202@1nOWh=07emO@@0OWin1@1mOGd40861P@@0P8201@21PH4407inOPD0Ng]k1021PH44
07inOPD0QhN7101mOGd507alO0d0b>3H101nOWh408B4Q0D0RHV9101eMGD507inOP@0Ogmo101mOGd5
07]kN`@0P8201@23Ph<407IfMP@0RHV91@23Ph<408B4Q0@0S8b<1@22PX8407inOPD0PH611022PX84
08>3P`D0CDe=101mOGd50861P@@0Rh^;1025QHD50861P@@0OGem1@20P80407]kN`@0OGem1@20P804
08:2PPD0PH61201mOGd507alO0@0Q8B41@1iNGT407emO@@0R8R81@21PH490820P0d0OWin1021PH49
08:2PP@0Q8B42@1oOgl508>3P`@0OWin1025QHD50861P@@0QHF51@21PH4407inOP@0NWYj1@27QhL4
0820P0@0Ph>31@20P80F0<SPf0005@38h=P508f=S@@0O7al101mOGd507QhN0T0Ogmo1021PH4407]k
N`D0P8202@1oOgl407YjNP@0PX:21@2EUID406MWI`D0PH611023Ph<408B4Q0D0QhN7101WIfL408b<
S0D0OWin101oOgl50820P0@0O7al1022PX8507moO`@0PH613@20P80507]kN`@0Ogmo1@20P80807em
O@h0OWin101mOGd407alO0D0Ogmo101nOWh507alO0@0PH61101lO7`50820P0T0OWin3@1mOGd407in
OPD0OGem1021PH440820P0D0PH61101nOWh507]kN`@0PH61101nOWh508N7Q`@0OGem1@1lO7`=0<SP
f0@0OWin1024Q8@508V9R@@0MGEe1@1nOWh407moO`@0OGem1@1kNg/40820P0D0Ph>3101fMWH408V9
R@D0Ph>31024Q8@408b<S0D0PX:2101nOWh50861P@@0PX:21023Ph<504e=C@@0OGem1@21PH4408^;
R`@0QHF51@21PH4407emO@D0P820101kNg/407emO@D0P8201022PX850861P@P0OGem1@1lO7`408B4
Q0D0NGUi101mOGd408R8R0D0PH612@20P80=07inOP@0PH612@22PX8408B4Q0T0Ogmo1@23Ph<407in
OP@0QHF51@21PH4408F5Q@D0PH61101nOWh407YjNPD0QhN71020P80408>3P`D0P8205P38h=P001D0
b>3H1@2<S8`40861P@@0Ogmo1@24Q8@407UiN@D0Ogmo101nOWh408>3P`D0PH61101kNg/509>CT`@0
KVi^102BTY8507YjNP@0MWIf1@2EUID407alO0@0PX:21@1nOWh40820P0@0PH611@1mOGd407alO0D0
PX:2101mOGd40861P@D0Ogmo1026QXH50861P@P0Ogmo1@22PX8407moO`D0QXJ62021PH450820P0@0
PX:21@25QHD407alO0@0Ng]k1@1nOWh907moO`@0OGem1022PX8507]kN`@0Q8B41@1mOGd807alO0D0
OWin1022PX8507moO`@0OGem1024Q8@908>3P`D0OGem101kNg/40820P0D0RHV91025QHD507UiN@d0
b>3H1023Ph<407emO@D0OWin1028R8P507moO`@0Ph>32@1iNGT407YjNPD0QXJ6101gMgL40820P0D0
KVi^101lO7`4075aL@D0MgMg101iNGT50861P@@0PX:2101mOGd50:f][@@0R8R81@1hN7P407MgM`@0
QHF51@26QXH40861P@D0Ng]k1020P80407moO`D0OWin101mOGd507moO`@0P820101iNGT508>3P`@0
Q8B41@21PH4408B4Q0@0Ph>31@20P80407moO`D0PH61101mOGd40861P@D0Ogmo1021PH4508>3P`@0
Ogmo1024Q8@507YjNP@0QhN71@20P80408>3P`@0PX:22@1nOWh507EeM@@0QhN71020P80507moO`@0
O7al101jNWX508B4Q1H0b>3H000E0<SPf0D0S8b<1021PH4407moO`D0Q8B4101iNGT507moO`@0OWin
1023Ph<50861P@@0Ng]k1@2CTi<406i^KP@0TY:B1@1jNWX407IfMPD0UIFE101lO7`408:2PPD0OWin
1020P8040861P@D0OGem101lO7`508:2PP@0OGem1021PH4507moO`@0QXJ61@21PH4807moO`D0PX:2
101oOgl508J6QPP0PH611@20P80408:2PPD0QHF5101lO7`407]kN`D0OWin2@1oOgl407emO@@0PX:2
1@1kNg/408B4Q0D0OGem201lO7`507inOP@0PX:21@1oOgl407emO@@0Q8B42@23Ph<507emO@@0Ng]k
1020P80508V9R@@0QHF51@1iNGT=0<SPf0@0Ph>3101mOGd507inOP@0R8R81@1oOgl408>3P`T0NGUi
101jNWX508J6QP@0MgMg1020P80506i^KP@0O7al101aLG4507MgM`@0NGUi1@21PH4408:2PP@0OGem
1@2][Jd408R8R0D0N7Qh101gMgL408F5Q@D0QXJ61021PH4507]kN`@0P820101oOgl507inOP@0OGem
1@1oOgl40820P0@0NGUi1@23Ph<408B4Q0D0PH611024Q8@408>3P`D0P820101oOgl50861P@@0OGem
1021PH4507moO`@0PH611@23Ph<407moO`@0Q8B41@1jNWX408N7Q`D0P8201023Ph<408:2PPT0OWin
1@1eMGD408N7Q`@0P8201@1oOgl407alO0@0NWYj1@24Q8@F0<SPf0005@38h=P508b<S0@0PH61101o
Ogl508B4Q0@0NGUi1@1oOgl407inOP@0Ph>31@21PH4407]kN`D0Ti>C101^KVh409:BTPD0NWYj101f
MWH509FEU@@0O7al1022PX8507inOP@0P8201021PH4507emO@@0O7al1@22PX8407emO@@0PH611@1o
Ogl408J6QPD0PH61201oOgl508:2PP@0Ogmo1@26QXH80861P@D0P8201022PX8508F5Q@@0O7al101k
Ng/507inOPT0Ogmo101mOGd408:2PPD0Ng]k1024Q8@507emO@P0O7al1@1nOWh408:2PPD0Ogmo101m
OGd408B4Q0T0Ph>31@1mOGd407]kN`@0P8201@29RHT408F5Q@D0NGUi3@38h=P408>3P`@0OGem1@1n
OWh408R8R0D0Ogmo1023Ph<907UiN@@0NWYj1@26QXH407MgM`@0P8201@1^KVh407alO0@0LG5a1@1g
MgL407UiN@D0PH611022PX8407emO@D0[Jf]1028R8P507QhN0@0MgMg1025QHD508J6QP@0PH611@1k
Ng/40820P0@0Ogmo1@1nOWh407emO@D0Ogmo1020P80407UiN@D0Ph>31024Q8@50861P@@0Q8B41023
Ph<50820P0@0Ogmo1@21PH4407emO@@0PH611@1oOgl40861P@D0Ph>3101oOgl408B4Q0D0NWYj1027
QhL50820P0@0Ph>31022PX8907inOPD0MGEe1027QhL40820P0D0Ogmo101lO7`407YjNPD0Q8B45P38
h=P001D0b>3H1@2<S8`40861P@@0Ogmo1@24Q8@407UiN@D0Ogmo101nOWh408>3P`D0PH61101kNg/5
09>CT`@0KVi^102BTY8507YjNP@0MWIf1@2EUID407alO0@0PX:21@1nOWh40820P0@0PH611@1mOGd4
07alO0D0PX:2101mOGd40861P@D0Ogmo1026QXH50861P@P0Ogmo1@22PX8407moO`D0QXJ62021PH45
0820P0@0PX:21@25QHD407alO0@0Ng]k1@1nOWh907moO`@0OGem1022PX8507]kN`@0Q8B41@1mOGd8
07alO0D0OWin1022PX8507moO`@0OGem1024Q8@908>3P`D0OGem101kNg/40820P0D0RHV91025QHD5
07UiN@d0b>3H1023Ph<407emO@D0OWin1028R8P507moO`@0Ph>32@1iNGT407YjNPD0QXJ6101gMgL4
0820P0D0KVi^101lO7`4075aL@D0MgMg101iNGT50861P@@0PX:2101mOGd50:f][@@0R8R81@1hN7P4
07MgM`@0QHF51@26QXH40861P@D0Ng]k1020P80407moO`D0OWin101mOGd507moO`@0P820101iNGT5
08>3P`@0Q8B41@21PH4408B4Q0@0Ph>31@20P80407moO`D0PH61101mOGd40861P@D0Ogmo1021PH45
08>3P`@0Ogmo1024Q8@507YjNP@0QhN71@20P80408>3P`@0PX:22@1nOWh507EeM@@0QhN71020P805
07moO`@0O7al101jNWX508B4Q1H0b>3H000E0<SPf0D0OGem1022PX8407]kN`D0PH61101nOWh507al
O0@0QXJ6101nOWh508>3P`@0MWIf1@24Q8@407alO0@0L71`1@1oOgl408j>SPD0JFUY101hN7P407em
O@D0Ph>31025QHD406e]K@D0UiNG101cLg<508:2PP@0Ph>31022PX8507alO0@0QHF51@22PX8407Qh
N0@0P8201@1lO7`407moO`D0Q8B41020P80408B4Q0D0OGem2@24Q8@407moO`@0N7Qh1@20P80408B4
Q0D0Ogmo1020P80407moO`D0P820101lO7`507moO`@0PH61101nOWh507UiN@T0OWin101oOgl408:2
PPT0PH611@20P8040861P@@0OGem1@25QHD408B4Q0D0MGEe3@38h=P407inOP@0Ogmo1@25QHD408>3
P`D0Ogmo101mOGd407moO`D0PX:2101mOGd508B4Q0@0RHV9101oOgl508n?S`@0OWin101kNg/508j>
SP@0RHV91@22PX840861P@@0OWin1@1]KFd40:n_[`D0UIFE101gMgL407alO0D0Ogmo101lO7`50820
P0@0M7Ad2@20P80407alO0T0Ogmo1028R8P507YjNP@0Ogmo1@1mOGd407YjNP@0PH611@22PX8907al
O0@0RHV91026QXH50861P@@0OGem1@24Q8@408F5Q@@0Q8B41@1mOGd408B4Q0D0Ph>31027QhL40820
P0D0Q8B4101kNg/90861P@@0Ogmo1@25QHD408N7Q`@0Ogmo1@1dM7@F0<SPf0005@38h=P507emO@@0
PX:2101kNg/50861P@@0OWin1@1lO7`408J6QP@0OWin1@23Ph<407IfMPD0Q8B4101lO7`4071`L0D0
Ogmo102>SXh506UYJ@@0N7Qh101mOGd508>3P`@0QHF5101]KFd509NGU`@0Lg=c1@22PX8408>3P`@0
PX:21@1lO7`408F5Q@D0PX:2101hN7P40820P0D0O7al101oOgl508B4Q0@0P8201024Q8@507emO@T0
Q8B4101oOgl407QhN0D0P8201024Q8@507moO`@0P820101oOgl50820P0@0O7al1@1oOgl40861P@@0
OWin1@1iNGT907inOP@0Ogmo1022PX890861P@D0P8201021PH4407emO@D0QHF51024Q8@507EeM@d0
b>3H101nOWh407moO`D0QHF51023Ph<507moO`@0OGem101oOgl508:2PP@0OGem1@24Q8@408V9R@@0
Ogmo1@2?Shl407inOP@0Ng]k1@2>SXh408V9R@D0PX:21021PH4407inOPD0KFe]102_[jl509FEU@@0
MgMg101lO7`507moO`@0O7al1@20P80407AdM0T0P820101lO7`907moO`@0R8R81@1jNWX407moO`D0
OGem101jNWX40861P@D0PX:22@1lO7`408V9R@@0QXJ61@21PH4407emO@D0Q8B41025QHD408B4Q0D0
OGem1024Q8@508>3P`@0QhN71020P80508B4Q0@0Ng]k2@21PH4407moO`D0QHF51027QhL407moO`D0
M7Ad5P38h=P001D0b>3H1@1mOGd408:2PP@0Ng]k1@21PH4407inOPD0O7al1026QXH407inOPD0Ph>3
101fMWH508B4Q0@0O7al101`L70507moO`@0SXj>1@1YJFT407QhN0@0OGem1@23Ph<408F5Q@@0KFe]
1@2GUiL407=cL`D0PX:21023Ph<408:2PPD0O7al1025QHD508:2PP@0N7Qh1020P80507alO0@0Ogmo
1@24Q8@40820P0@0Q8B41@1mOGd908B4Q0@0Ogmo101hN7P50820P0@0Q8B41@1oOgl40820P0@0Ogmo
1@20P80407alO0D0Ogmo1021PH4407inOPD0NGUi2@1nOWh407moO`@0PX:22@21PH450820P0@0PH61
101mOGd508F5Q@@0Q8B41@1eMGD=0<SPf0@0OWin101oOgl508F5Q@@0Ph>31@1oOgl407emO@@0Ogmo
1@22PX8407emO@D0Q8B41029RHT407moO`D0Shn?101nOWh407]kN`D0SXj>1029RHT508:2PP@0PH61
101nOWh506e]K@@0[jn_1@2EUID407MgM`@0O7al1@1oOgl407alO0D0P820101dM7@90820P0@0O7al
2@1oOgl408R8R0D0NWYj101oOgl507emO@@0NWYj1021PH4508:2PPT0O7al1029RHT408J6QPD0PH61
101mOGd508B4Q0@0QHF51024Q8@507emO@@0Q8B41@23Ph<408N7Q`@0P8201@24Q8@407]kN`T0PH61
101oOgl508F5Q@@0QhN7101oOgl507AdM1H0b>3H000E0<SPf0D0OGem1022PX8407]kN`D0PH61101n
OWh507alO0@0QXJ6101nOWh508>3P`@0MWIf1@24Q8@407alO0@0L71`1@1oOgl408j>SPD0JFUY101h
N7P407emO@D0Ph>31025QHD406e]K@D0UiNG101cLg<508:2PP@0Ph>31022PX8507alO0@0QHF51@22
PX8407QhN0@0P8201@1lO7`407moO`D0Q8B41020P80408B4Q0D0OGem2@24Q8@407moO`@0N7Qh1@20
P80408B4Q0D0Ogmo1020P80407moO`D0P820101lO7`507moO`@0PH61101nOWh507UiN@T0OWin101o
Ogl408:2PPT0PH611@20P8040861P@@0OGem1@25QHD408B4Q0D0MGEe3@38h=P407inOP@0Ogmo1@25
QHD408>3P`D0Ogmo101mOGd407moO`D0PX:2101mOGd508B4Q0@0RHV9101oOgl508n?S`@0OWin101k
Ng/508j>SP@0RHV91@22PX840861P@@0OWin1@1]KFd40:n_[`D0UIFE101gMgL407alO0D0Ogmo101l
O7`50820P0@0M7Ad2@20P80407alO0T0Ogmo1028R8P507YjNP@0Ogmo1@1mOGd407YjNP@0PH611@22
PX8907alO0@0RHV91026QXH50861P@@0OGem1@24Q8@408F5Q@@0Q8B41@1mOGd408B4Q0D0Ph>31027
QhL40820P0D0Q8B4101kNg/90861P@@0Ogmo1@25QHD408N7Q`@0Ogmo1@1dM7@F0<SPf0005@38h=P5
08F5Q@@0OGem1024Q8@907YjNPD0PH61101cLg<407moO`D0PX:2101oOgl507UiN@@0T92@101]KFd5
092@T0@0P8201@1bLW8408f=S@@0P8201@1mOGd407alO0@0QXJ61@1SHf<409RHV0D0MWIf1022PX84
07alO0D0Ogmo1022PX8507moO`@0O7al101mOGd507YjNP@0Ogmo1@20P80408J6QP@0P8201@1oOgl4
07alO0D0Ogmo1020P80407emO@D0O7al101nOWh50820P0@0Ph>31021PH4507emO@@0Ph>31@1oOgl4
08:2PP@0OGem1@27QhL407IfMPD0Ng]k1023Ph<40861P@D0OGem101nOWh508B4Q0@0Ogmo3@20P805
07=cL`d0b>3H1022PX8407moO`D0Ng]k1026QXH507]kN`@0OGem101oOgl50820P0@0OWin1@2:RXX4
0861P@@0QXJ61@21PH4407IfMP@0RXZ:1@1dM7@4079bLPD0O7al1022PX8408B4Q0D0PH61101[Jf/5
08N7Q`@0UiNG101oOgl508F5Q@@0OWin1@1oOgl40861P@@0P8201@25QHD40820P0D0Ng]k101lO7`4
08B4Q0D0QXJ6101jNWX507inOP@0QXJ6101nOWh507moO`@0Ph>31@22PX840820P0@0OGem1@1iNGT9
07inOP@0NWYj101kNg/508F5Q@@0Ng]k1@1oOgl408:2PP@0P8201@1nOWh407alO0T0PH61101nOWh5
07YjNP@0OGem1023Ph<508N7QaH0b>3H000E0<SPf0D0QHF5101mOGd408B4Q0T0NWYj1@21PH4407=c
L`@0Ogmo1@22PX8407moO`D0NGUi102@T90406e]K@D0T92@1020P805079bLP@0SHf=1020P80507em
O@@0O7al1026QXH506=SH`@0V9RH1@1fMWH408:2PP@0O7al1@1oOgl408:2PPD0Ogmo101lO7`407em
O@D0NWYj101oOgl50820P0@0QXJ61020P80507moO`@0O7al1@1oOgl40820P0@0OGem1@1lO7`407in
OPD0P8201023Ph<40861P@D0OGem1023Ph<507moO`@0PX:2101mOGd508N7Q`@0MWIf1@1kNg/408>3
P`@0PH611@1mOGd407inOPD0Q8B4101oOgl=0820P0D0Lg=c3@38h=P408:2PP@0Ogmo1@1kNg/408J6
QPD0Ng]k101mOGd407moO`D0P820101nOWh508Z:RP@0PH611026QXH50861P@@0MWIf102:RXX507Ad
M0@0LW9b1@1lO7`408:2PP@0Q8B41@21PH4406][J`D0QhN7102GUiL407moO`D0QHF5101nOWh507mo
O`@0PH611020P80508F5Q@@0P8201@1kNg/407alO0@0Q8B41@26QXH407YjNPD0OWin1026QXH407in
OPD0Ogmo1023Ph<508:2PP@0P820101mOGd507UiN@T0OWin101jNWX407]kN`D0QHF5101kNg/507mo
O`@0PX:21020P80507inOP@0O7al2@21PH4407inOPD0NWYj101mOGd408>3P`D0QhN75P38h=P001D0
b>3H1@25QHD407emO@@0Q8B42@1jNWX50861P@@0Lg=c101oOgl508:2PP@0Ogmo1@1iNGT4092@T0@0
KFe]1@2@T9040820P0D0LW9b102=SHd40820P0D0OGem101lO7`408J6QPD0Hf=S102HV9P507IfMP@0
PX:2101lO7`507moO`@0PX:21@1oOgl407alO0@0OGem1@1jNWX407moO`D0P8201026QXH40820P0D0
Ogmo101lO7`507moO`@0P820101mOGd507alO0@0OWin1@20P80408>3P`@0PH611@1mOGd408>3P`D0
Ogmo1022PX8407emO@D0QhN7101fMWH507]kN`@0Ph>31021PH4507emO@@0OWin1@24Q8@407moO`d0
P8201@1cLg<=0<SPf0@0PX:2101oOgl507]kN`@0QXJ61@1kNg/407emO@@0Ogmo1@20P80407inOPD0
RXZ:1021PH4408J6QPD0PH61101fMWH408Z:RPD0M7Ad101bLW8507alO0@0PX:21024Q8@50861P@@0
Jf][1@27QhL409NGU`@0Ogmo1@25QHD407inOPD0Ogmo1021PH440820P0D0QHF51020P80507]kN`@0
O7al1024Q8@508J6QP@0NWYj1@1nOWh408J6QP@0OWin1@1oOgl408>3P`D0PX:21020P80407emO@D0
NGUi2@1nOWh407YjNP@0Ng]k1@25QHD407]kN`D0Ogmo1022PX840820P0D0OWin101lO7`90861P@@0
OWin1@1jNWX407emO@@0Ph>31@27QhLF0<SPf0005@38h=P508F5Q@@0OGem1024Q8@907YjNPD0PH61
101cLg<407moO`D0PX:2101oOgl507UiN@@0T92@101]KFd5092@T0@0P8201@1bLW8408f=S@@0P820
1@1mOGd407alO0@0QXJ61@1SHf<409RHV0D0MWIf1022PX8407alO0D0Ogmo1022PX8507moO`@0O7al
101mOGd507YjNP@0Ogmo1@20P80408J6QP@0P8201@1oOgl407alO0D0Ogmo1020P80407emO@D0O7al
101nOWh50820P0@0Ph>31021PH4507emO@@0Ph>31@1oOgl408:2PP@0OGem1@27QhL407IfMPD0Ng]k
1023Ph<40861P@D0OGem101nOWh508B4Q0@0Ogmo3@20P80507=cL`d0b>3H1022PX8407moO`D0Ng]k
1026QXH507]kN`@0OGem101oOgl50820P0@0OWin1@2:RXX40861P@@0QXJ61@21PH4407IfMP@0RXZ:
1@1dM7@4079bLPD0O7al1022PX8408B4Q0D0PH61101[Jf/508N7Q`@0UiNG101oOgl508F5Q@@0OWin
1@1oOgl40861P@@0P8201@25QHD40820P0D0Ng]k101lO7`408B4Q0D0QXJ6101jNWX507inOP@0QXJ6
101nOWh507moO`@0Ph>31@22PX840820P0@0OGem1@1iNGT907inOP@0NWYj101kNg/508F5Q@@0Ng]k
1@1oOgl408:2PP@0P8201@1nOWh407alO0T0PH61101nOWh507YjNP@0OGem1023Ph<508N7QaH0b>3H
000E0<SPf0D0QHF5101mOGd408B4Q0T0NWYj1@21PH4407=cL`@0Ogmo1@22PX8407moO`D0NGUi102@
T90406e]K@D0T92@1020P805079bLP@0SHf=1020P80507emO@@0O7al1026QXH506=SH`@0V9RH1@1f
MWH408:2PP@0O7al1@1oOgl408:2PPD0Ogmo101lO7`407emO@D0NWYj101oOgl50820P0@0QXJ61020
P80507moO`@0O7al1@1oOgl40820P0@0OGem1@1lO7`407inOPD0P8201023Ph<40861P@D0OGem1023
Ph<507moO`@0PX:2101mOGd508N7Q`@0MWIf1@1kNg/408>3P`@0PH611@1mOGd407inOPD0Q8B4101o
Ogl=0820P0D0Lg=c3@38h=P408:2PP@0Ogmo1@1kNg/408J6QPD0Ng]k101mOGd407moO`D0P820101n
OWh508Z:RP@0PH611026QXH50861P@@0MWIf102:RXX507AdM0@0LW9b1@1lO7`408:2PP@0Q8B41@21
PH4406][J`D0QhN7102GUiL407moO`D0QHF5101nOWh507moO`@0PH611020P80508F5Q@@0P8201@1k
Ng/407alO0@0Q8B41@26QXH407YjNPD0OWin1026QXH407inOPD0Ogmo1023Ph<508:2PP@0P820101m
OGd507UiN@T0OWin101jNWX407]kN`D0QHF5101kNg/507moO`@0PX:21020P80507inOP@0O7al2@21
PH4407inOPD0NWYj101mOGd408>3P`D0QhN75P38h=P001D0b>3H2@1nOWh40861P@D0OWin101jNWX5
07alO0@0Ph>3101jNWX907moO`D0PH611020P80407emO@D0KFe]1028R8P508j>SP@0Kfm_101jNWX9
0820P0@0Ogmo1@2:RXX406MWI`D0WYjN101hN7P40820P0D0PH61101mOGd907inOPT0Ng]k101oOgl5
07inOP@0PX:2101mOGd507alO0T0Ng]k1022PX840820P0D0OGem101nOWh508>3P`@0O7al1022PX85
07]kN`@0PH611@22PX8807inOPD0P820101kNg/507UiN@@0QHF51021PH4907inOPD0Ph>31022PX84
0820P0D0Ogmo1020P80507IfMPd0b>3H1025QHD40861P@T0OWin1@22PX8407]kN`@0Ph>31@1oOgl9
08>3P`@0Ogmo1023Ph<507YjNP@0R8R81020P80507UiN@@0Shn?1@21PH4407emO@@0Ogmo1@20P804
08B4Q0D0M7Ad101QHF44096AT@D0Ng]k1023Ph<508N7Q`@0Ng]k1024Q8@50861P@@0NGUi1@20P804
07inOP@0NGUi1@2;Rh/408B4Q0D0P8201021PH4=07inOPD0QHF51024Q8@407moO`D0O7al101cLg<5
07moO`P0OGem1@1kNg/408:2PPT0Ogmo2@21PH490820P0@0Q8B41020P80508:2PP@0QhN71020P805
08:2PQH0b>3H000E0<SPf0T0OWin1021PH4507inOP@0NWYj1@1lO7`408>3P`@0NWYj2@1oOgl50861
P@@0P820101mOGd506e]K@@0R8R81@2>SXh406m_K`@0NWYj2@20P80407moO`D0RXZ:101WIfL509jN
WP@0N7Qh1020P8050861P@@0OGem2@1nOWh907]kN`@0Ogmo1@1nOWh408:2PP@0OGem1@1lO7`907]k
N`@0PX:21020P80507emO@@0OWin1@23Ph<407alO0@0PX:21@1kNg/40861P@D0PX:2201nOWh50820
P0@0Ng]k1@1iNGT408F5Q@@0PH612@1nOWh508>3P`@0PX:21020P80507moO`@0P8201@1fMWH=0<SP
f0@0QHF51021PH4907inOPD0PX:2101kNg/408>3P`D0Ogmo2@23Ph<407moO`@0Ph>31@1jNWX408R8
R0@0P8201@1iNGT408n?S`D0PH61101mOGd407moO`D0P8201024Q8@507AdM0@0HF5Q102ATI4507]k
N`@0Ph>31@27QhL407]kN`@0Q8B41@21PH4407UiN@D0P820101nOWh407UiN@D0Rh^;1024Q8@50820
P0@0PH613@1nOWh508F5Q@@0Q8B4101oOgl507alO0@0Lg=c1@1oOgl807emO@D0Ng]k1022PX8907mo
O`T0PH612@20P80408B4Q0@0P8201@22PX8408N7Q`@0P8201@22PX8F0<SPf0005@38h=P907inOP@0
PH611@1nOWh407YjNPD0O7al1023Ph<407YjNPT0Ogmo1@21PH440820P0@0OGem1@1]KFd408R8R0D0
SXj>101_Kfl407YjNPT0P820101oOgl508Z:RP@0IfMW1@2NWYh407QhN0@0P8201@21PH4407emO@T0
OWin2@1kNg/407moO`D0OWin1022PX8407emO@D0O7al2@1kNg/408:2PP@0P8201@1mOGd407inOPD0
Ph>3101lO7`408:2PPD0Ng]k1021PH4508:2PPP0OWin1@20P80407]kN`D0NGUi1025QHD40861P@T0
OWin1@23Ph<408:2PP@0P8201@1oOgl40820P0D0MWIf3@38h=P408F5Q@@0PH612@1nOWh508:2PP@0
Ng]k1023Ph<507moO`T0Ph>3101oOgl408>3P`D0NWYj1028R8P40820P0D0NGUi102?Shl50861P@@0
OGem101oOgl50820P0@0Q8B41@1dM7@4065QH@@0TI6A1@1kNg/408>3P`D0QhN7101kNg/408B4Q0D0
PH61101iNGT50820P0@0OWin101iNGT508^;R`@0Q8B41@20P8040861P@d0OWin1@25QHD408B4Q0@0
Ogmo1@1lO7`407=cL`D0Ogmo201mOGd507]kN`@0PX:22@1oOgl90861P@T0P8201024Q8@40820P0D0
PX:21027QhL40820P0D0PX:25P38h=P001D0b>3H2@1nOWh40861P@D0OWin101jNWX507alO0@0Ph>3
101jNWX907moO`D0PH611020P80407emO@D0KFe]1028R8P508j>SP@0Kfm_101jNWX90820P0@0Ogmo
1@2:RXX406MWI`D0WYjN101hN7P40820P0D0PH61101mOGd907inOPT0Ng]k101oOgl507inOP@0PX:2
101mOGd507alO0T0Ng]k1022PX840820P0D0OGem101nOWh508>3P`@0O7al1022PX8507]kN`@0PH61
1@22PX8807inOPD0P820101kNg/507UiN@@0QHF51021PH4907inOPD0Ph>31022PX840820P0D0Ogmo
1020P80507IfMPd0b>3H1025QHD40861P@T0OWin1@22PX8407]kN`@0Ph>31@1oOgl908>3P`@0Ogmo
1023Ph<507YjNP@0R8R81020P80507UiN@@0Shn?1@21PH4407emO@@0Ogmo1@20P80408B4Q0D0M7Ad
101QHF44096AT@D0Ng]k1023Ph<508N7Q`@0Ng]k1024Q8@50861P@@0NGUi1@20P80407inOP@0NGUi
1@2;Rh/408B4Q0D0P8201021PH4=07inOPD0QHF51024Q8@407moO`D0O7al101cLg<507moO`P0OGem
1@1kNg/408:2PPT0Ogmo2@21PH490820P0@0Q8B41020P80508:2PP@0QhN71020P80508:2PQH0b>3H
000E0<SPf0T0PH611022PX8507inOP@0PX:21@1iNGT40820P0@0PX:21@25QHD40861P@D0OWin101l
O7`409FEU@D0NWYj1022PX8508R8R0@0MGEe102<S8`507alO0@0Ogmo1027QhL507inOP@0R8R81@1b
LW8408j>SP@0O7al1@20P8040861P@D0P820101kNg/407moO`D0P8201022PX850820P0@0OWin101k
Ng/508>3P`@0O7al1@1nOWh408B4Q0@0Ogmo1@1lO7`40861P@D0P820101nOWh407moO`D0OGem3@21
PH4408:2PPD0Ng]k1021PH4507moO`@0OGem2@22PX8408>3P`D0OWin201mOGd507YjNP@0Ogmo1@1e
MGD=0<SPf0@0Ng]k1023Ph<507emO@@0R8R81@1mOGd407QhN0@0NWYj1@26QXH407emO@D0RXZ:101d
M7@408B4Q0D0PX:21029RHT408^;R`D0QHF5101jNWX507QhN0@0P820101jNWX507alO0@0OGem1@21
PH4408R8R0@0Fe]K1@25QHD407IfMPD0QhN71026QXH407]kN`D0Q8B42@20P80408J6QP@0PH611@1m
OGd407IfMPD0Ogmo1021PH4908>3P`@0MWIf1@1oOgl408:2PP@0Ng]k1@1mOGd408J6QPD0Ph>3101f
MWH40861P@D0P820101kNg/507YjNP@0P8201024Q8@508:2PP@0Ogmo1@25QHD408B4Q0@0O7al1@1j
NWX40861P@@0P8201@21PH4F0<SPf0005@38h=P90861P@@0PX:21@1nOWh408:2PPD0NGUi1020P804
08:2PPD0QHF51021PH4507inOP@0O7al102EUID507YjNP@0PX:21@28R8P407EeM@@0S8b<1@1lO7`4
07moO`@0QhN71@1nOWh408R8R0D0LW9b102>SXh407alO0D0P8201021PH450820P0@0Ng]k101oOgl5
0820P0@0PX:21@20P80407inOP@0Ng]k1@23Ph<407alO0D0OWin1024Q8@407moO`D0O7al1021PH45
0820P0@0OWin101oOgl507emO@d0PH611022PX8507]kN`@0PH611@1oOgl407emO@T0PX:21023Ph<5
07inOPP0OGem1@1jNWX407moO`D0MGEe3@38h=P407]kN`@0Ph>31@1mOGd408R8R0D0OGem101hN7P4
07YjNPD0QXJ6101mOGd508Z:RP@0M7Ad1024Q8@508:2PP@0RHV9102;Rh/508F5Q@@0NWYj1@1hN7P4
0820P0@0NWYj1@1lO7`407emO@D0PH611028R8P405]KF`D0QHF5101fMWH508N7Q`@0QXJ6101kNg/5
08B4Q0T0P8201026QXH40861P@D0OGem101fMWH507moO`@0PH612@23Ph<407IfMPD0Ogmo1022PX84
07]kN`D0OGem1026QXH508>3P`@0MWIf1021PH450820P0@0Ng]k1@1jNWX40820P0@0Q8B41@22PX84
07moO`D0QHF51024Q8@407alO0D0NWYj1021PH440820P0D0PH615P38h=P001D0b>3H2@21PH4408:2
PPD0OWin1022PX8507UiN@@0P8201022PX8508F5Q@@0PH611@1nOWh407alO0@0UIFE1@1jNWX408:2
PPD0R8R8101eMGD408b<S0D0O7al101oOgl408N7Q`D0OWin1028R8P5079bLP@0SXj>101lO7`50820
P0@0PH611@20P80407]kN`@0Ogmo1@20P80408:2PPD0P820101nOWh407]kN`D0Ph>3101lO7`507in
OP@0Q8B4101oOgl507alO0@0PH611@20P80407inOP@0Ogmo1@1mOGd=0861P@@0PX:21@1kNg/40861
P@D0Ogmo101mOGd908:2PP@0Ph>31@1nOWh807emO@D0NWYj101oOgl507EeM@d0b>3H101kNg/408>3
P`D0OGem1028R8P507emO@@0N7Qh101jNWX508J6QP@0OGem1@2:RXX407AdM0@0Q8B41@22PX8408V9
R@@0Rh^;1@25QHD407YjNPD0N7Qh1020P80407YjNPD0O7al101mOGd50861P@@0R8R8101KFe/508F5
Q@@0MWIf1@27QhL408J6QP@0Ng]k1@24Q8@90820P0@0QXJ61021PH4507emO@@0MWIf1@1oOgl40861
P@T0Ph>3101fMWH507moO`@0PX:2101kNg/507emO@@0QXJ61@23Ph<407IfMP@0PH611@20P80407]k
N`D0NWYj1020P80408B4Q0D0PX:2101oOgl508F5Q@@0Q8B4101lO7`507YjNP@0PH611020P8050861
PAH0b>3H000E0<SPf0T0PH611022PX8507inOP@0PX:21@1iNGT40820P0@0PX:21@25QHD40861P@D0
OWin101lO7`409FEU@D0NWYj1022PX8508R8R0@0MGEe102<S8`507alO0@0Ogmo1027QhL507inOP@0
R8R81@1bLW8408j>SP@0O7al1@20P8040861P@D0P820101kNg/407moO`D0P8201022PX850820P0@0
OWin101kNg/508>3P`@0O7al1@1nOWh408B4Q0@0Ogmo1@1lO7`40861P@D0P820101nOWh407moO`D0
OGem3@21PH4408:2PPD0Ng]k1021PH4507moO`@0OGem2@22PX8408>3P`D0OWin201mOGd507YjNP@0
Ogmo1@1eMGD=0<SPf0@0Ng]k1023Ph<507emO@@0R8R81@1mOGd407QhN0@0NWYj1@26QXH407emO@D0
RXZ:101dM7@408B4Q0D0PX:21029RHT408^;R`D0QHF5101jNWX507QhN0@0P820101jNWX507alO0@0
OGem1@21PH4408R8R0@0Fe]K1@25QHD407IfMPD0QhN71026QXH407]kN`D0Q8B42@20P80408J6QP@0
PH611@1mOGd407IfMPD0Ogmo1021PH4908>3P`@0MWIf1@1oOgl408:2PP@0Ng]k1@1mOGd408J6QPD0
Ph>3101fMWH40861P@D0P820101kNg/507YjNP@0P8201024Q8@508:2PP@0Ogmo1@25QHD408B4Q0@0
O7al1@1jNWX40861P@@0P8201@21PH4F0<SPf0005@38h=P508>3P`@0M7Ad101nOWh508>3P`@0OGem
2@22PX8407emO@D0Q8B4101oOgl508:2PP@0Ph>3101iNGT508:2PP@0JFUY1@2=SHd409:BTP@0L71`
1@25QHD407MgM`@0Ogmo1@21PH4408:2PPD0Q8B4101eMGD408J6QPD0NWYj1024Q8@507alO0@0P820
1022PX850820P0@0QXJ61@1mOGd407alO0@0OWin2@1lO7`90820P0@0Ng]k1@27QhL407inOPD0Ph>3
101hN7P407emO@D0O7al102CTi<507QhN0@0RHV91026QXH50820P0@0Ogmo1@22PX8407alO0@0OWin
1@1oOgl40820P0D0PH611026QXH407emO@D0PX:2101nOWh507MgM`d0b>3H1020P80409bLW0D0Ogmo
1028R8P507alO0@0PX:21025QHD507]kN`@0R8R82@1jNWX408B4Q0D0OGem101^KVh4075aL@D0N7Qh
1028R8P508:2PP@0N7Qh1022PX8507moO`@0OWin1@1mOGd40861P@@0Shn?1@1EEED4092@T0D0Q8B4
101jNWX407alO0D0OGem101lO7`507QhN0@0NWYj1020P80507emO@@0QHF52@1mOGd40820P0D0PX:2
101oOgl907alO0@0Q8B41@1lO7`408J6QPD0NGUi101nOWh407YjNPD0NGUi1024Q8@507alO0@0PX:2
1026QXH508:2PP@0P8201@25QHD40820P0@0Ph>31@25QHD407moO`@0P8201@23Ph<F0<SPf0005@38
h=P508>3P`@0M7Ad101nOWh508>3P`@0OGem2@22PX8407emO@D0Q8B4101oOgl508:2PP@0Ph>3101i
NGT508:2PP@0JFUY1@2=SHd409:BTP@0L71`1@25QHD407MgM`@0Ogmo1@21PH4408:2PPD0Q8B4101e
MGD408J6QPD0NWYj1024Q8@507alO0@0P8201022PX850820P0@0QXJ61@1mOGd407alO0@0OWin2@1l
O7`90820P0@0Ng]k1@27QhL407inOPD0Ph>3101hN7P407emO@D0O7al102CTi<507QhN0@0RHV91026
QXH50820P0@0Ogmo1@22PX8407alO0@0OWin1@1oOgl40820P0D0PH611026QXH407emO@D0PX:2101n
OWh507MgM`d0b>3H1020P80409bLW0D0Ogmo1028R8P507alO0@0PX:21025QHD507]kN`@0R8R82@1j
NWX408B4Q0D0OGem101^KVh4075aL@D0N7Qh1028R8P508:2PP@0N7Qh1022PX8507moO`@0OWin1@1m
OGd40861P@@0Shn?1@1EEED4092@T0D0Q8B4101jNWX407alO0D0OGem101lO7`507QhN0@0NWYj1020
P80507emO@@0QHF52@1mOGd40820P0D0PX:2101oOgl907alO0@0Q8B41@1lO7`408J6QPD0NGUi101n
OWh407YjNPD0NGUi1024Q8@507alO0@0PX:21026QXH508:2PP@0P8201@25QHD40820P0@0Ph>31@25
QHD407moO`@0P8201@23Ph<F0<SPf0005@38h=P508>3P`@0M7Ad101nOWh508>3P`@0OGem2@22PX84
07emO@D0Q8B4101oOgl508:2PP@0Ph>3101iNGT508:2PP@0JFUY1@2=SHd409:BTP@0L71`1@25QHD4
07MgM`@0Ogmo1@21PH4408:2PPD0Q8B4101eMGD408J6QPD0NWYj1024Q8@507alO0@0P8201022PX85
0820P0@0QXJ61@1mOGd407alO0@0OWin2@1lO7`90820P0@0Ng]k1@27QhL407inOPD0Ph>3101hN7P4
07emO@D0O7al102CTi<507QhN0@0RHV91026QXH50820P0@0Ogmo1@22PX8407alO0@0OWin1@1oOgl4
0820P0D0PH611026QXH407emO@D0PX:2101nOWh507MgM`d0b>3H1020P80409bLW0D0Ogmo1028R8P5
07alO0@0PX:21025QHD507]kN`@0R8R82@1jNWX408B4Q0D0OGem101^KVh4075aL@D0N7Qh1028R8P5
08:2PP@0N7Qh1022PX8507moO`@0OWin1@1mOGd40861P@@0Shn?1@1EEED4092@T0D0Q8B4101jNWX4
07alO0D0OGem101lO7`507QhN0@0NWYj1020P80507emO@@0QHF52@1mOGd40820P0D0PX:2101oOgl9
07alO0@0Q8B41@1lO7`408J6QPD0NGUi101nOWh407YjNPD0NGUi1024Q8@507alO0@0PX:21026QXH5
08:2PP@0P8201@25QHD40820P0@0Ph>31@25QHD407moO`@0P8201@23Ph<F0<SPf0005@38h=P508>3
P`@0M7Ad101nOWh508>3P`@0OGem2@22PX8407emO@D0Q8B4101oOgl508:2PP@0Ph>3101iNGT508:2
PP@0JFUY1@2=SHd409:BTP@0L71`1@25QHD407MgM`@0Ogmo1@21PH4408:2PPD0Q8B4101eMGD408J6
QPD0NWYj1024Q8@507alO0@0P8201022PX850820P0@0QXJ61@1mOGd407alO0@0OWin2@1lO7`90820
P0@0Ng]k1@27QhL407inOPD0Ph>3101hN7P407emO@D0O7al102CTi<507QhN0@0RHV91026QXH50820
P0@0Ogmo1@22PX8407alO0@0OWin1@1oOgl40820P0D0PH611026QXH407emO@D0PX:2101nOWh507Mg
M`d0b>3H1020P80409bLW0D0Ogmo1028R8P507alO0@0PX:21025QHD507]kN`@0R8R82@1jNWX408B4
Q0D0OGem101^KVh4075aL@D0N7Qh1028R8P508:2PP@0N7Qh1022PX8507moO`@0OWin1@1mOGd40861
P@@0Shn?1@1EEED4092@T0D0Q8B4101jNWX407alO0D0OGem101lO7`507QhN0@0NWYj1020P80507em
O@@0QHF52@1mOGd40820P0D0PX:2101oOgl907alO0@0Q8B41@1lO7`408J6QPD0NGUi101nOWh407Yj
NPD0NGUi1024Q8@507alO0@0PX:21026QXH508:2PP@0P8201@25QHD40820P0@0Ph>31@25QHD407mo
O`@0P8201@23Ph<F0<SPf0005@38h=P508>3P`@0M7Ad101nOWh508>3P`@0OGem2@22PX8407emO@D0
Q8B4101oOgl508:2PP@0Ph>3101iNGT508:2PP@0JFUY1@2=SHd409:BTP@0L71`1@25QHD407MgM`@0
Ogmo1@21PH4408:2PPD0Q8B4101eMGD408J6QPD0NWYj1024Q8@507alO0@0P8201022PX850820P0@0
QXJ61@1mOGd407alO0@0OWin2@1lO7`90820P0@0Ng]k1@27QhL407inOPD0Ph>3101hN7P407emO@D0
O7al102CTi<507QhN0@0RHV91026QXH50820P0@0Ogmo1@22PX8407alO0@0OWin1@1oOgl40820P0D0
PH611026QXH407emO@D0PX:2101nOWh507MgM`d0b>3H1020P80409bLW0D0Ogmo1028R8P507alO0@0
PX:21025QHD507]kN`@0R8R82@1jNWX408B4Q0D0OGem101^KVh4075aL@D0N7Qh1028R8P508:2PP@0
N7Qh1022PX8507moO`@0OWin1@1mOGd40861P@@0Shn?1@1EEED4092@T0D0Q8B4101jNWX407alO0D0
OGem101lO7`507QhN0@0NWYj1020P80507emO@@0QHF52@1mOGd40820P0D0PX:2101oOgl907alO0@0
Q8B41@1lO7`408J6QPD0NGUi101nOWh407YjNPD0NGUi1024Q8@507alO0@0PX:21026QXH508:2PP@0
P8201@25QHD40820P0@0Ph>31@25QHD407moO`@0P8201@23Ph<F0<SPf0005@38h=P50820P0@0OWin
1024Q8@507moO`@0P8201@1jNWX40820P0@0O7al1@20P80407emO@D0Ng]k1020P80407alO0D0S8b<
101hN7P507emO@@0S8b<101^KVh508J6QP@0MgMg101kNg/50820P0@0Q8B41@1lO7`407inOP@0Ng]k
1@2:RXX407moO`D0O7al1021PH4408B4Q0D0OWin1025QHD508:2PP@0PH61101nOWh508:2PP@0NWYj
2@22PX840861P@D0S8b<101hN7P50820P0@0Jf][1020P80506i^KP@0Shn?1@1eMGD408Z:RP@0QhN7
1@1oOgl408B4Q0D0Ph>31021PH4407inOPD0Ogmo1020P80507inOP@0Q8B41020P80>07inOPd0b>3H
101iNGT408>3P`D0Ng]k101jNWX50861P@@0P8201022PX8507inOP@0TI6A1@25QHD408f=S@@0PX:2
1@21PH4408>3P`@0Rh^;1@2ATI4408J6QPD0Q8B4102;Rh/408>3P`D0PH611026QXH50820P0@0Q8B4
101jNWX509BDU0@0IfMW1@29RHT407]kN`@0OWin1@23Ph<40820P0D0Ogmo1021PH4407inOPD0OGem
101oOgl50820P0@0QXJ61020P80507moO`@0S8b<1@26QXH407=cL`@0NWYj1@1nOWh407alO0D0P820
101hN7P407inOPD0Q8B4101fMWH50820P0@0Ogmo2@1nOWh408N7Q`D0P8201022PX8408N7Q`D0Ogmo
101mOGd40861P@D0QhN75P38h=P001D0b>3H1@20P80407inOP@0Q8B41@1oOgl40820P0D0NWYj1020
P80407alO0D0P820101mOGd507]kN`@0P820101lO7`508b<S0@0N7Qh1@1mOGd408b<S0@0KVi^1@26
QXH407MgM`@0Ng]k1@20P80408B4Q0D0O7al101nOWh407]kN`D0RXZ:101oOgl507alO0@0PH611024
Q8@507inOP@0QHF51@22PX840861P@@0OWin1@22PX8407YjNPT0PX:21021PH4508b<S0@0N7Qh1@20
P80406][J`@0P8201@1^KVh408n?S`D0MGEe102:RXX408N7Q`D0Ogmo1024Q8@508>3P`@0PH61101n
OWh507moO`@0P8201@1nOWh408B4Q0@0P8203P1nOWh=0<SPf0@0NGUi1023Ph<507]kN`@0NWYj1@21
PH440820P0@0PX:21@1nOWh4096AT@D0QHF5102=SHd408:2PPD0PH611023Ph<408^;R`D0TI6A1026
QXH508B4Q0@0Rh^;1023Ph<50861P@@0QXJ61@20P80408B4Q0@0NWYj1@2DU9@406MWI`D0RHV9101k
Ng/407inOPD0Ph>31020P80507moO`@0PH61101nOWh507emO@@0Ogmo1@20P80408J6QP@0P8201@1o
Ogl408b<S0D0QXJ6101cLg<407YjNPD0OWin101lO7`50820P0@0N7Qh101nOWh508B4Q0@0MWIf1@20
P80407moO`T0OWin1027QhL50820P0@0PX:21027QhL507moO`@0OGem1021PH4508N7QaH0b>3H000E
0<SPf0D0P820101nOWh408B4Q0D0Ogmo1020P80507YjNP@0P820101lO7`50820P0@0OGem1@1kNg/4
0820P0@0O7al1@2<S8`407QhN0D0OGem102<S8`406i^KPD0QXJ6101gMgL407]kN`D0P8201024Q8@5
07alO0@0OWin101kNg/508Z:RP@0Ogmo1@1lO7`40861P@@0Q8B41@1nOWh408F5Q@D0PX:21021PH44
07inOPD0PX:2101jNWX908:2PP@0PH611@2<S8`407QhN0D0P820101[Jf/40820P0D0KVi^102?Shl5
07EeM@@0RXZ:1027QhL507moO`@0Q8B41@23Ph<40861P@@0OWin1@1oOgl40820P0D0OWin1024Q8@4
0820P0h0OWin3@38h=P407UiN@@0Ph>31@1kNg/407YjNPD0PH611020P80408:2PPD0OWin102ATI45
08F5Q@@0SHf=1022PX850861P@@0Ph>3102;Rh/5096AT@@0QXJ61@24Q8@408^;R`@0Ph>31@21PH44
08J6QPD0P8201024Q8@407YjNPD0U9BD101WIfL508V9R@@0Ng]k101nOWh508>3P`@0P8201@1oOgl4
0861P@@0OWin1@1mOGd407moO`D0P8201026QXH40820P0D0Ogmo102<S8`508J6QP@0Lg=c101jNWX5
07inOP@0O7al1@20P80407QhN0@0OWin1@24Q8@407IfMPD0P820101oOgl907inOP@0QhN71@20P804
08:2PP@0QhN71@1oOgl407emO@@0PH611@27QhLF0<SPf0005@38h=P50820P0@0OWin1024Q8@507mo
O`@0P8201@1jNWX40820P0@0O7al1@20P80407emO@D0Ng]k1020P80407alO0D0S8b<101hN7P507em
O@@0S8b<101^KVh508J6QP@0MgMg101kNg/50820P0@0Q8B41@1lO7`407inOP@0Ng]k1@2:RXX407mo
O`D0O7al1021PH4408B4Q0D0OWin1025QHD508:2PP@0PH61101nOWh508:2PP@0NWYj2@22PX840861
P@D0S8b<101hN7P50820P0@0Jf][1020P80506i^KP@0Shn?1@1eMGD408Z:RP@0QhN71@1oOgl408B4
Q0D0Ph>31021PH4407inOPD0Ogmo1020P80507inOP@0Q8B41020P80>07inOPd0b>3H101iNGT408>3
P`D0Ng]k101jNWX50861P@@0P8201022PX8507inOP@0TI6A1@25QHD408f=S@@0PX:21@21PH4408>3
P`@0Rh^;1@2ATI4408J6QPD0Q8B4102;Rh/408>3P`D0PH611026QXH50820P0@0Q8B4101jNWX509BD
U0@0IfMW1@29RHT407]kN`@0OWin1@23Ph<40820P0D0Ogmo1021PH4407inOPD0OGem101oOgl50820
P0@0QXJ61020P80507moO`@0S8b<1@26QXH407=cL`@0NWYj1@1nOWh407alO0D0P820101hN7P407in
OPD0Q8B4101fMWH50820P0@0Ogmo2@1nOWh408N7Q`D0P8201022PX8408N7Q`D0Ogmo101mOGd40861
P@D0QhN75P38h=P001D0b>3H1@22PX8407]kN`@0OWin1@1hN7P407moO`D0PH611020P80407emO@D0
Ph>3102>SXh50820P0@0OWin1020P80507YjNP@0T92@1@1VIVH409FEU@@0QXJ61@1`L70408Z:RP@0
Ogmo1@1mOGd40861P@D0O7al101oOgl407inOPD0Ph>31022PX8507QhN0@0OGem1026QXH507IfMP@0
NGUi1@25QHD408>3P`T0Ogmo101lO7`508F5Q@@0Ng]k101oOgl508F5Q@@0QhN71@22PX8407MgM`@0
QhN71@1hN7P408V9R@D0NWYj101hN7P408>3P`T0PX:21@1iNGT80861P@D0Ng]k101iNGT50820P0@0
PX:21020P80508>3P`@0OWin1@1mOGd=0<SPf0@0OGem1023Ph<507emO@T0PX:2101hN7P40861P@D0
Shn?1026QXH507=cL`@0RXZ:101iNGT507IfMP@0PH611023Ph<507=cL`@0JVYZ1@23Ph<407inOP@0
N7Qh1@20P80408:2PPD0OWin1021PH440820P0D0O7al102KVi/506=SH`@0RHV9101mOGd>0820P0@0
OGem101oOgl50820P0@0OWin1@23Ph<407YjNP@0O7al1@27QhL908:2PP@0NWYj101mOGd507YjNP@0
RHV91@26QXH40820P0@0Ng]k1@27QhL408F5Q@D0P8201024Q8@408>3P`D0PH611020P80507YjNP@0
NGUi1024Q8@50820P0@0NWYj1020P80507alO1H0b>3H000E0<SPf0D0PX:2101kNg/407inOPD0N7Qh
101oOgl50861P@@0P820101mOGd508>3P`@0SXj>1@20P80407inOP@0P8201@1jNWX4092@T0D0IVIV
102EUID408J6QPD0L71`102:RXX407moO`D0OGem1021PH4507alO0@0Ogmo101nOWh508>3P`@0PX:2
1@1hN7P407emO@@0QXJ61@1fMWH407UiN@D0QHF51023Ph<907moO`@0O7al1@25QHD407]kN`@0Ogmo
1@25QHD408N7Q`D0PX:2101gMgL408N7Q`D0N7Qh1029RHT507YjNP@0N7Qh1023Ph<908:2PPD0NGUi
2021PH4507]kN`@0NGUi1@20P80408:2PP@0P8201@23Ph<407inOPD0OGem3@38h=P407emO@@0Ph>3
1@1mOGd908:2PP@0N7Qh1021PH4508n?S`@0QXJ61@1cLg<408Z:RP@0NGUi1@1fMWH40861P@@0Ph>3
1@1cLg<406YZJPD0Ph>3101nOWh407QhN0D0P8201022PX8507inOP@0PH611020P80507alO0@0Vi^K
1@1SHf<408V9R@@0OGem3P20P80407emO@@0Ogmo1@20P80407inOPD0Ph>3101jNWX407alO0D0QhN7
2@22PX8407YjNP@0OGem1@1jNWX408V9R@D0QXJ61020P80407]kN`D0QhN71025QHD50820P0@0Q8B4
1023Ph<50861P@@0P8201@1jNWX407UiN@@0Q8B41@20P80407YjNP@0P8201@1lO7`F0<SPf0005@38
h=P508:2PP@0Ng]k101nOWh507QhN0@0Ogmo1@21PH440820P0@0OGem1@23Ph<408j>SPD0P820101n
OWh40820P0D0NWYj102@T90506IVIP@0UIFE1026QXH5071`L0@0RXZ:101oOgl507emO@@0PH611@1l
O7`407moO`@0OWin1@23Ph<408:2PPD0N7Qh101mOGd408J6QPD0MWIf101iNGT508F5Q@@0Ph>32@1o
Ogl407alO0D0QHF5101kNg/407moO`D0QHF51027QhL508:2PP@0MgMg1027QhL507QhN0@0RHV91@1j
NWX407QhN0@0Ph>32@22PX8507UiN@P0PH611@1kNg/407UiN@D0P8201022PX840820P0D0Ph>3101n
OWh507emO@d0b>3H101mOGd408>3P`D0OGem2@22PX8407QhN0@0PH611@2?Shl408J6QPD0Lg=c102:
RXX407UiN@D0MWIf1021PH4408>3P`D0Lg=c101ZJVX508>3P`@0OWin101hN7P50820P0@0PX:21@1n
OWh40861P@@0P8201@1lO7`409^KV`D0Hf=S1029RHT407emO@h0P820101mOGd407moO`D0P820101n
OWh508>3P`@0NWYj101lO7`508N7Q`T0PX:2101jNWX407emO@D0NWYj1029RHT508J6QP@0P820101k
Ng/508N7Q`@0QHF51@20P80408B4Q0@0Ph>31@21PH440820P0D0NWYj101iNGT408B4Q0D0P820101j
NWX40820P0D0O7al5P38h=P001D0b>3H1@22PX8407]kN`@0OWin1@1hN7P407moO`D0PH611020P804
07emO@D0Ph>3102>SXh50820P0@0OWin1020P80507YjNP@0T92@1@1VIVH409FEU@@0QXJ61@1`L704
08Z:RP@0Ogmo1@1mOGd40861P@D0O7al101oOgl407inOPD0Ph>31022PX8507QhN0@0OGem1026QXH5
07IfMP@0NGUi1@25QHD408>3P`T0Ogmo101lO7`508F5Q@@0Ng]k101oOgl508F5Q@@0QhN71@22PX84
07MgM`@0QhN71@1hN7P408V9R@D0NWYj101hN7P408>3P`T0PX:21@1iNGT80861P@D0Ng]k101iNGT5
0820P0@0PX:21020P80508>3P`@0OWin1@1mOGd=0<SPf0@0OGem1023Ph<507emO@T0PX:2101hN7P4
0861P@D0Shn?1026QXH507=cL`@0RXZ:101iNGT507IfMP@0PH611023Ph<507=cL`@0JVYZ1@23Ph<4
07inOP@0N7Qh1@20P80408:2PPD0OWin1021PH440820P0D0O7al102KVi/506=SH`@0RHV9101mOGd>
0820P0@0OGem101oOgl50820P0@0OWin1@23Ph<407YjNP@0O7al1@27QhL908:2PP@0NWYj101mOGd5
07YjNP@0RHV91@26QXH40820P0@0Ng]k1@27QhL408F5Q@D0P8201024Q8@408>3P`D0PH611020P805
07YjNP@0NGUi1024Q8@50820P0@0NWYj1020P80507alO1H0b>3H000E0<SPf0D0PX:2101kNg/407in
OPD0N7Qh101oOgl50861P@@0P820101mOGd508>3P`@0SXj>1@20P80407inOP@0P8201@1jNWX4092@
T0D0IVIV102EUID408J6QPD0L71`102:RXX407moO`D0OGem1021PH4507alO0@0Ogmo101nOWh508>3
P`@0PX:21@1hN7P407emO@@0QXJ61@1fMWH407UiN@D0QHF51023Ph<907moO`@0O7al1@25QHD407]k
N`@0Ogmo1@25QHD408N7Q`D0PX:2101gMgL408N7Q`D0N7Qh1029RHT507YjNP@0N7Qh1023Ph<908:2
PPD0NGUi2021PH4507]kN`@0NGUi1@20P80408:2PP@0P8201@23Ph<407inOPD0OGem3@38h=P407em
O@@0Ph>31@1mOGd908:2PP@0N7Qh1021PH4508n?S`@0QXJ61@1cLg<408Z:RP@0NGUi1@1fMWH40861
P@@0Ph>31@1cLg<406YZJPD0Ph>3101nOWh407QhN0D0P8201022PX8507inOP@0PH611020P80507al
O0@0Vi^K1@1SHf<408V9R@@0OGem3P20P80407emO@@0Ogmo1@20P80407inOPD0Ph>3101jNWX407al
O0D0QhN72@22PX8407YjNP@0OGem1@1jNWX408V9R@D0QXJ61020P80407]kN`D0QhN71025QHD50820
P0@0Q8B41023Ph<50861P@@0P8201@1jNWX407UiN@@0Q8B41@20P80407YjNP@0P8201@1lO7`F0<SP
f0005@38h=P50861P@@0O7al101nOWh508B4Q0@0PH611@1nOWh40861P@T0OWin101hN7P508B4Q0@0
PH61101oOgl508B4Q0@0OGem1@21PH4406e]K@@0QXJ61@1oOgl807alO0D0OGem2@1lO7`407inOP@0
PH611@20P80407inOPD0R8R8101oOgl408>3P`D0OWin101mOGd507moO`@0OWin1023Ph<507YjNP@0
OWin1@22PX84071`L0@0SXj>1@1oOgl40820P0D0Ph>31020P80407alO0D0PH611022PX8507inOP@0
Ogmo1023Ph<50861P@T0Ogmo2023Ph<508:2PP@0Ph>31@21PH4407alO0@0PH611@23Ph<407alO0D0
NWYj3@38h=P40861P@@0QHF51@21PH4408J6QPD0OWin2020P80507inOP@0O7al1@1fMWH408b<S0@0
P8201@1hN7P40820P0@0XZ:R1@1dM7@407inOPD0QhN7101jNWX408:2PPD0Ogmo1021PH4508N7Q`@0
Ogmo2@20P80407UiN@D0UYJF101TI6@408B4Q0D0OGem1022PX8507moO`P0PX:21@1jNWX408B4Q0D0
P8201021PH4407MgM`D0Ti>C101nOWh508N7Q`@0PX:21020P80508R8R0T0P820101nOWh407moO`D0
PX:21023Ph<507YjNP@0N7Qh2@21PH4408B4Q0D0MgMg101nOWh408F5Q@D0P8202026QXH508R8R1H0
b>3H000E0<SPf0D0PH61101lO7`407inOPD0Q8B41021PH4507inOP@0PH612@1nOWh407QhN0D0Q8B4
1021PH4407moO`D0Q8B4101mOGd50861P@@0KFe]1026QXH507moO`P0O7al1@1mOGd907alO0@0OWin
1021PH450820P0@0OWin1@28R8P407moO`@0Ph>31@1nOWh407emO@D0Ogmo101nOWh408>3P`D0NWYj
101nOWh508:2PP@0L71`102>SXh507moO`@0P8201@23Ph<40820P0@0O7al1@21PH4408:2PPD0OWin
101oOgl408>3P`D0PH612@1oOgl808>3P`D0PX:21023Ph<50861P@@0O7al1021PH4508>3P`@0O7al
1@1jNWX=0<SPf0@0PH611025QHD50861P@@0QXJ61@1nOWh80820P0D0OWin101lO7`507IfMP@0S8b<
1020P80507QhN0@0P820102RXZ8507AdM0@0OWin1@27QhL407YjNP@0PX:21@1oOgl40861P@D0QhN7
101oOgl90820P0@0NGUi1@2FUYH406ATI0@0Q8B41@1mOGd408:2PPD0Ogmo2022PX8507YjNP@0Q8B4
1@20P8040861P@@0MgMg1@2CTi<407inOPD0QhN71022PX840820P0D0R8R82@20P80407inOP@0Ogmo
1@22PX8408>3P`D0NWYj101hN7P90861P@@0Q8B41@1gMgL407inOP@0QHF51@20P80808J6QPD0R8R8
5P38h=P001D0b>3H1@21PH4407alO0@0OWin1@24Q8@40861P@D0OWin1021PH4907inOP@0N7Qh1@24
Q8@40861P@@0Ogmo1@24Q8@407emO@D0PH61101]KFd408J6QPD0Ogmo201lO7`507emO@T0O7al101n
OWh40861P@D0P820101nOWh508R8R0@0Ogmo1023Ph<507inOP@0OGem1@1oOgl407inOP@0Ph>31@1j
NWX407inOPD0PX:2101`L70408j>SPD0Ogmo1020P80508>3P`@0P820101lO7`50861P@@0PX:21@1n
OWh407moO`@0Ph>31@21PH4907moO`P0Ph>31@22PX8408>3P`D0PH61101lO7`40861P@D0Ph>3101l
O7`507YjNPd0b>3H1021PH4408F5Q@D0PH611026QXH507inOPP0P8201@1nOWh407alO0D0MWIf102<
S8`40820P0D0N7Qh1020P8040::RXPD0M7Ad101nOWh508N7Q`@0NWYj1022PX8507moO`@0PH611@27
QhL407moO`T0P820101iNGT509JFUP@0I6AT1024Q8@507emO@@0PX:21@1oOgl808:2PPD0NWYj1024
Q8@50820P0@0PH61101gMgL509>CT`@0OWin1@27QhL408:2PP@0P8201@28R8P90820P0@0OWin101o
Ogl508:2PP@0Ph>31@1jNWX407QhN0T0PH611024Q8@507MgM`@0OWin1025QHD50820P0P0QXJ61@28
R8PF0<SPf0005@38h=P50861P@@0O7al101nOWh508B4Q0@0PH611@1nOWh40861P@T0OWin101hN7P5
08B4Q0@0PH61101oOgl508B4Q0@0OGem1@21PH4406e]K@@0QXJ61@1oOgl807alO0D0OGem2@1lO7`4
07inOP@0PH611@20P80407inOPD0R8R8101oOgl408>3P`D0OWin101mOGd507moO`@0OWin1023Ph<5
07YjNP@0OWin1@22PX84071`L0@0SXj>1@1oOgl40820P0D0Ph>31020P80407alO0D0PH611022PX85
07inOP@0Ogmo1023Ph<50861P@T0Ogmo2023Ph<508:2PP@0Ph>31@21PH4407alO0@0PH611@23Ph<4
07alO0D0NWYj3@38h=P40861P@@0QHF51@21PH4408J6QPD0OWin2020P80507inOP@0O7al1@1fMWH4
08b<S0@0P8201@1hN7P40820P0@0XZ:R1@1dM7@407inOPD0QhN7101jNWX408:2PPD0Ogmo1021PH45
08N7Q`@0Ogmo2@20P80407UiN@D0UYJF101TI6@408B4Q0D0OGem1022PX8507moO`P0PX:21@1jNWX4
08B4Q0D0P8201021PH4407MgM`D0Ti>C101nOWh508N7Q`@0PX:21020P80508R8R0T0P820101nOWh4
07moO`D0PX:21023Ph<507YjNP@0N7Qh2@21PH4408B4Q0D0MgMg101nOWh408F5Q@D0P8202026QXH5
08R8R1H0b>3H000E0<SPf0D0PX:21021PH4408B4Q0D0NGUi101nOWh508V9R@@0Lg=c1024Q8@50861
P@@0Q8B41@1bLW8408F5Q@@0O7al1@1mOGd407MgM`D0RXZ:101aLG4408n?S`D0Ti>C101VIVH408n?
S`D0N7Qh1020P80507inOP@0PX:2101mOGd50820P0@0O7al1@1mOGd408J6QP@0OGem1@24Q8@407Ui
N@D0Ogmo102;Rh/40820P0D0NGUi101lO7`508F5Q@@0Ogmo101mOGd508:2PP@0OWin1@22PX8407in
OP@0Ng]k1@1nOWh40820P0D0PH611020P80407UiN@D0Ph>3101mOGd506m_K`@0QXJ6101hN7P508>3
P`@0NWYj1@1mOGd407moO`@0O7al1@1mOGd408:2PPD0NGUi3@38h=P408^;R`@0S8b<1@29RHT408F5
Q@D0OWin1022PX8408F5Q@D0Ph>3101kNg/507MgM`@0PX:22@1oOgl807]kN`D0R8R81027QhL508B4
Q0@0S8b<1021PH4507QhN0@0QHF51@21PH4407alO0@0PH611@20P80407QhN0D0OGem102@T90406=S
H`D0S8b<1026QXH50820P0P0PH611@20P80407alO0D0Q8B4101hN7P408B4Q0D0NGUi1022PX8508>3
P`@0MWIf1026QXH508V9R@@0O7al1@1oOgl407alO0@0Ogmo1@1jNWX407alO0D0OGem101iNGT407in
OPD0NWYj101oOgl50820P0@0Ng]k1023Ph<508R8R0P0Ph>31@20P80F0<SPf0005@38h=P508:2PP@0
PH611024Q8@507UiN@@0OWin1@29RHT407=cL`@0Q8B41@21PH4408B4Q0D0LW9b1025QHD407alO0D0
OGem101gMgL508Z:RP@0LG5a102?Shl509>CT`@0IVIV102?Shl507QhN0@0P8201@1nOWh408:2PP@0
OGem1@20P80407alO0D0OGem1026QXH407emO@D0Q8B4101iNGT507moO`@0Rh^;1020P80507UiN@@0
O7al1@25QHD407moO`@0OGem1@22PX8407inOPD0PX:2101nOWh407]kN`D0OWin1020P8050861P@@0
P820101iNGT508>3P`@0OGem1@1_Kfl408J6QP@0N7Qh1@23Ph<407YjNPD0OGem101oOgl407alO0D0
OGem1022PX8507UiN@d0b>3H102;Rh/408b<S0D0RHV91025QHD507inOP@0PX:21025QHD508>3P`@0
Ng]k1@1gMgL408:2PPT0Ogmo201kNg/508R8R0@0QhN71@24Q8@408b<S0@0PH611@1hN7P408F5Q@D0
PH61101lO7`40861P@D0P820101hN7P507emO@@0T92@101SHf<508b<S0@0QXJ61@20P8080861P@D0
P820101lO7`508B4Q0@0N7Qh1024Q8@507UiN@@0PX:21@23Ph<407IfMP@0QXJ61@29RHT407alO0D0
Ogmo101lO7`407moO`D0NWYj101lO7`507emO@@0NGUi101nOWh507YjNP@0Ogmo1@20P80407]kN`@0
Ph>31@28R8P808>3P`D0P8205P38h=P001D0b>3H1@22PX840861P@@0Q8B41@1iNGT407inOPD0RHV9
101cLg<408B4Q0D0PH611024Q8@5079bLP@0QHF5101lO7`507emO@@0MgMg1@2:RXX4075aL@@0Shn?
1@2CTi<406IVIP@0Shn?1@1hN7P40820P0D0OWin1022PX8407emO@D0P820101lO7`507emO@@0QXJ6
101mOGd508B4Q0@0NGUi1@1oOgl408^;R`@0P8201@1iNGT407alO0D0QHF5101oOgl407emO@D0PX:2
101nOWh508:2PP@0OWin101kNg/507inOP@0P8201@21PH440820P0@0NGUi1@23Ph<407emO@D0Kfm_
1026QXH407QhN0D0Ph>3101jNWX507emO@@0Ogmo101lO7`507emO@@0PX:21@1iNGT=0<SPf0@0Rh^;
102<S8`508V9R@@0QHF51@1nOWh408:2PP@0QHF51@23Ph<407]kN`D0MgMg1022PX8907moO`P0Ng]k
1@28R8P408N7Q`D0Q8B4102<S8`40861P@D0N7Qh1025QHD50861P@@0O7al1021PH450820P0@0N7Qh
1@1mOGd4092@T0@0Hf=S1@2<S8`408J6QPD0P8202021PH450820P0@0O7al1@24Q8@407QhN0@0Q8B4
1@1iNGT408:2PPD0Ph>3101fMWH408J6QPD0RHV9101lO7`507moO`@0O7al101oOgl507YjNP@0O7al
1@1mOGd407UiN@@0OWin1@1jNWX407moO`D0P820101kNg/408>3P`D0R8R82023Ph<50820P1H0b>3H
000E0<SPf0D0PX:21021PH4408B4Q0D0NGUi101nOWh508V9R@@0Lg=c1024Q8@50861P@@0Q8B41@1b
LW8408F5Q@@0O7al1@1mOGd407MgM`D0RXZ:101aLG4408n?S`D0Ti>C101VIVH408n?S`D0N7Qh1020
P80507inOP@0PX:2101mOGd50820P0@0O7al1@1mOGd408J6QP@0OGem1@24Q8@407UiN@D0Ogmo102;
Rh/40820P0D0NGUi101lO7`508F5Q@@0Ogmo101mOGd508:2PP@0OWin1@22PX8407inOP@0Ng]k1@1n
OWh40820P0D0PH611020P80407UiN@D0Ph>3101mOGd506m_K`@0QXJ6101hN7P508>3P`@0NWYj1@1m
OGd407moO`@0O7al1@1mOGd408:2PPD0NGUi3@38h=P408^;R`@0S8b<1@29RHT408F5Q@D0OWin1022
PX8408F5Q@D0Ph>3101kNg/507MgM`@0PX:22@1oOgl807]kN`D0R8R81027QhL508B4Q0@0S8b<1021
PH4507QhN0@0QHF51@21PH4407alO0@0PH611@20P80407QhN0D0OGem102@T90406=SH`D0S8b<1026
QXH50820P0P0PH611@20P80407alO0D0Q8B4101hN7P408B4Q0D0NGUi1022PX8508>3P`@0MWIf1026
QXH508V9R@@0O7al1@1oOgl407alO0@0Ogmo1@1jNWX407alO0D0OGem101iNGT407inOPD0NWYj101o
Ogl50820P0@0Ng]k1023Ph<508R8R0P0Ph>31@20P80F0<SPf0005@38h=P508J6QP@0O7al1025QHD5
08N7Q`@0QHF51@1nOWh408F5Q@@0Q8B41@1nOWh407moO`D0P820101iNGT40861P@D0OGem101iNGT5
07inOP@0U9BD101YJFT509BDU0@0NGUi101kNg/90820P0D0MgMg101oOgl408:2PPD0PH611020P805
07alO0@0Ogmo1029RHT508:2PP@0P8201@1nOWh408>3P`@0PX:21@1fMWH408B4Q0D0PX:2101kNg/4
08>3P`D0NWYj1029RHT908:2PP@0Q8B41@1jNWX407moO`D0P820101lO7`407moO`T0PX:21@26QXH4
07AdM0@0P8201@1lO7`40861P@D0Ph>3101lO7`40820P0D0OWin1020P80507MgM`d0b>3H101oOgl4
08B4Q0D0PX:2101iNGT90861P@@0MgMg1@1oOgl408V9R@D0MWIf101kNg/408F5Q@D0QXJ6101mOGd4
08>3P`D0O7al1021PH4508:2PP@0K6a/1029RHT508Z:RP@0OWin1@1iNGT407moO`@0P8201@22PX89
07inOP@0P820102LW9`506EUI@@0NGUi1@1lO7`407]kN`@0OGem1@23Ph<408:2PPD0P820101lO7`4
07IfMPD0S8b<1025QHD507UiN@@0R8R8101gMgL507EeM@@0QXJ61@1iNGT40820P0@0OWin1@20P804
07alO0D0PX:21029RHT40820P0D0O7al101kNg/507moO`@0Ng]k3@1mOGd40820P0D0Ph>35P38h=P0
01D0b>3H1@26QXH407alO0@0QHF51@27QhL408F5Q@D0OWin1025QHD408B4Q0D0OWin101oOgl50820
P0@0NGUi1021PH4507emO@@0NGUi1@1nOWh409BDU0@0JFUY1@2DU9@407UiN@@0Ng]k2@20P80507Mg
M`@0Ogmo1022PX850861P@@0P8201@1lO7`407moO`@0RHV91@22PX840820P0D0OWin1023Ph<408:2
PPD0MWIf1024Q8@508:2PP@0Ng]k1023Ph<507YjNP@0RHV92@22PX8408B4Q0D0NWYj101oOgl50820
P0@0O7al101oOgl908:2PPD0QXJ6101dM7@40820P0D0O7al1021PH4508>3P`@0O7al1020P80507in
OP@0P8201@1gMgL=0<SPf0@0Ogmo1024Q8@508:2PP@0NGUi2@21PH4407MgM`D0Ogmo1029RHT507If
MP@0Ng]k1025QHD508J6QP@0OGem1023Ph<507alO0@0PH611@22PX8406a/K0@0RHV91@2:RXX407in
OPD0NGUi101oOgl40820P0D0PX:22@1nOWh40820P0@0W9bL1@1UIFD407UiN@D0O7al101kNg/407em
O@D0Ph>31022PX850820P0@0O7al101fMWH508b<S0@0QHF51@1iNGT408R8R0@0MgMg1@1eMGD408J6
QPD0NGUi1020P80407inOPD0P820101lO7`508:2PP@0RHV91020P80507alO0@0Ng]k1@1oOgl407]k
N`d0OGem1020P80508>3PaH0b>3H000E0<SPf0D0QXJ6101lO7`408F5Q@D0QhN71025QHD507inOP@0
QHF51024Q8@507inOP@0Ogmo1@20P80407UiN@@0PH611@1mOGd407UiN@D0OWin102DU9@406UYJ@D0
U9BD101iNGT407]kN`T0P8201@1gMgL407moO`@0PX:21@21PH440820P0D0O7al101oOgl408V9R@D0
PX:21020P80507inOP@0Ph>31022PX8507IfMP@0Q8B41@22PX8407]kN`@0Ph>31@1jNWX408V9R@T0
PX:21024Q8@507YjNP@0Ogmo1@20P80407alO0@0Ogmo2@22PX8508J6QP@0M7Ad1020P80507alO0@0
PH611@23Ph<407alO0@0P8201@1nOWh40820P0D0MgMg3@38h=P407moO`@0Q8B41@22PX8407UiN@T0
PH61101gMgL507moO`@0RHV91@1fMWH407]kN`@0QHF51@26QXH407emO@@0Ph>31@1lO7`40861P@D0
PX:2101/K6`408V9R@D0RXZ:101nOWh507UiN@@0Ogmo1020P80508:2PPT0OWin1020P80409bLW0D0
IFEU101iNGT507alO0@0Ng]k101mOGd508>3P`@0PX:21@20P80407alO0@0MWIf1@2<S8`408F5Q@D0
NGUi1028R8P407MgM`D0MGEe1026QXH507UiN@@0P820101nOWh50820P0@0O7al1@22PX8408V9R@@0
P8201@1lO7`407]kN`D0Ogmo101kNg/=07emO@@0P8201@23Ph<F0<SPf0005@38h=P508J6QP@0O7al
1025QHD508N7Q`@0QHF51@1nOWh408F5Q@@0Q8B41@1nOWh407moO`D0P820101iNGT40861P@D0OGem
101iNGT507inOP@0U9BD101YJFT509BDU0@0NGUi101kNg/90820P0D0MgMg101oOgl408:2PPD0PH61
1020P80507alO0@0Ogmo1029RHT508:2PP@0P8201@1nOWh408>3P`@0PX:21@1fMWH408B4Q0D0PX:2
101kNg/408>3P`D0NWYj1029RHT908:2PP@0Q8B41@1jNWX407moO`D0P820101lO7`407moO`T0PX:2
1@26QXH407AdM0@0P8201@1lO7`40861P@D0Ph>3101lO7`40820P0D0OWin1020P80507MgM`d0b>3H
101oOgl408B4Q0D0PX:2101iNGT90861P@@0MgMg1@1oOgl408V9R@D0MWIf101kNg/408F5Q@D0QXJ6
101mOGd408>3P`D0O7al1021PH4508:2PP@0K6a/1029RHT508Z:RP@0OWin1@1iNGT407moO`@0P820
1@22PX8907inOP@0P820102LW9`506EUI@@0NGUi1@1lO7`407]kN`@0OGem1@23Ph<408:2PPD0P820
101lO7`407IfMPD0S8b<1025QHD507UiN@@0R8R8101gMgL507EeM@@0QXJ61@1iNGT40820P0@0OWin
1@20P80407alO0D0PX:21029RHT40820P0D0O7al101kNg/507moO`@0Ng]k3@1mOGd40820P0D0Ph>3
5P38h=P001D0b>3H1@26QXH407alO0@0QHF51@27QhL408F5Q@D0OWin1025QHD408B4Q0D0OWin101o
Ogl50820P0@0NGUi1021PH4507emO@@0NGUi1@1nOWh409BDU0@0JFUY1@2DU9@407UiN@@0Ng]k2@20
P80507MgM`@0Ogmo1022PX850861P@@0P8201@1lO7`407moO`@0RHV91@22PX840820P0D0OWin1023
Ph<408:2PPD0MWIf1024Q8@508:2PP@0Ng]k1023Ph<507YjNP@0RHV92@22PX8408B4Q0D0NWYj101o
Ogl50820P0@0O7al101oOgl908:2PPD0QXJ6101dM7@40820P0D0O7al1021PH4508>3P`@0O7al1020
P80507inOP@0P8201@1gMgL=0<SPf0@0Ogmo1024Q8@508:2PP@0NGUi2@21PH4407MgM`D0Ogmo1029
RHT507IfMP@0Ng]k1025QHD508J6QP@0OGem1023Ph<507alO0@0PH611@22PX8406a/K0@0RHV91@2:
RXX407inOPD0NGUi101oOgl40820P0D0PX:22@1nOWh40820P0@0W9bL1@1UIFD407UiN@D0O7al101k
Ng/407emO@D0Ph>31022PX850820P0@0O7al101fMWH508b<S0@0QHF51@1iNGT408R8R0@0MgMg1@1e
MGD408J6QPD0NGUi1020P80407inOPD0P820101lO7`508:2PP@0RHV91020P80507alO0@0Ng]k1@1o
Ogl407]kN`d0OGem1020P80508>3PaH0b>3H000E0<SPf0D0R8R8101oOgl408J6QPD0I6AT102JVYX5
08B4Q0P0PX:21@1oOgl40861P@D0QHF5101oOgl407emO@D0Ogmo2@1lO7`408B4Q0@0P8201@1jNWX4
08B4Q0@0KVi^1@2;Rh/40820P0D0QHF5101nOWh907alO0@0OGem1@24Q8@407inOP@0Ph>31@28R8P4
07MgM`D0OGem1020P80407emO@D0O7al1021PH4507=cL`@0R8R8101cLg<508f=S@@0NGUi1@25QHD4
0820P0@0N7Qh1@2EUID406ATI0D0RHV9101lO7`407moO`D0Ng]k101oOgl508n?S`@0KFe]102:RXX5
07IfMP@0Q8B41@1nOWh40861P@@0P8201@1lO7`40861P@D0N7Qh3@38h=P406m_K`@0Ng]k1@1nOWh4
08b<S0D0P820101eMGD407YjNPD0PH61101bLW8508f=S@@0PX:21024Q8@508R8R0@0NGUi101jNWX5
08F5Q@@0R8R81@26QXH4096AT@@0N7Qh1@1nOWh40820P0D0PH61101hN7P408N7Q`D0PH611026QXH9
0820P0@0N7Qh1@2OWil406UYJ@D0Ogmo1022PX8408b<S0D0MgMg101iNGT507emO@@0QXJ62@20P804
06a/K0D0OWin1025QHD4075aL@D0Ph>3101jNWX508>3P`@0OWin1021PH4507emO@@0Ph>31@1lO7`4
08N7Q`@0OWin1@1oOgl40861P@D0OWin1023Ph<408:2PPD0PH611020P80408:2PPD0OWin5P38h=P0
01D0b>3H1@28R8P407moO`@0QXJ61@1TI6@409ZJVPD0Q8B42022PX8507moO`@0PH611@25QHD407mo
O`@0OGem1@1oOgl907alO0@0Q8B41020P80507YjNP@0Q8B4101^KVh508^;R`@0P8201@25QHD407in
OPT0O7al101mOGd508B4Q0@0OWin1023Ph<508R8R0@0MgMg1@1mOGd40820P0@0OGem1@1lO7`40861
P@D0Lg=c1028R8P407=cL`D0SHf=101iNGT508F5Q@@0P820101hN7P509FEU@@0I6AT1@29RHT407al
O0@0Ogmo1@1kNg/407moO`D0Shn?101]KFd408Z:RPD0MWIf1024Q8@507inOP@0PH611020P80507al
O0@0PH611@1hN7P=0<SPf0@0Kfm_101kNg/507inOP@0S8b<1@20P80407EeM@@0NWYj1@21PH44079b
LPD0SHf=1022PX8408B4Q0D0R8R8101iNGT407YjNPD0QHF51028R8P508J6QP@0TI6A101hN7P507in
OP@0P8201@21PH4407QhN0@0QhN71@21PH4408J6QPT0P820101hN7P509nOW`@0JFUY1@1oOgl408:2
PP@0S8b<1@1gMgL407UiN@D0OGem1026QXH90820P0@0K6a/1@1nOWh408F5Q@@0LG5a1@23Ph<407Yj
NPD0Ph>3101nOWh40861P@D0OGem1023Ph<507alO0@0QhN7101nOWh507moO`@0PH611@1nOWh408>3
P`@0PX:21@21PH440820P0@0PX:21@1nOWhF0<SPf0005@38h=P508R8R0@0Ogmo1026QXH506ATI0@0
VYZJ1@24Q8@808:2PPD0Ogmo1021PH4508F5Q@@0Ogmo101mOGd507moO`T0O7al1024Q8@40820P0D0
NWYj1024Q8@406i^KPD0Rh^;1020P80508F5Q@@0OWin2@1lO7`407emO@D0Q8B4101nOWh408>3P`D0
R8R8101gMgL507emO@@0P820101mOGd507alO0@0PH611@1cLg<408R8R0@0Lg=c1@2=SHd407UiN@D0
QHF51020P80407QhN0D0UIFE101TI6@508V9R@@0O7al101oOgl507]kN`@0Ogmo1@2?Shl406e]K@@0
RXZ:1@1fMWH408B4Q0D0OWin1021PH440820P0D0O7al1021PH4507QhN0d0b>3H101_Kfl407]kN`D0
OWin102<S8`50820P0@0MGEe101jNWX50861P@@0LW9b1@2=SHd408:2PP@0Q8B41@28R8P407UiN@@0
NWYj1@25QHD408R8R0D0QXJ6102ATI4407QhN0D0OWin1020P8050861P@@0N7Qh1027QhL50861P@@0
QXJ62@20P80407QhN0D0WinO101YJFT507moO`@0PX:2102<S8`507MgM`@0NGUi1@1mOGd408J6QPT0
P820101/K6`507inOP@0QHF5101aLG4508>3P`@0NWYj1@23Ph<407inOP@0PH611@1mOGd408>3P`D0
O7al1027QhL407inOPD0Ogmo1021PH4507inOP@0Ph>31022PX850861P@@0P8201022PX8507inOQH0
b>3H000E0<SPf0D0R8R8101oOgl408J6QPD0I6AT102JVYX508B4Q0P0PX:21@1oOgl40861P@D0QHF5
101oOgl407emO@D0Ogmo2@1lO7`408B4Q0@0P8201@1jNWX408B4Q0@0KVi^1@2;Rh/40820P0D0QHF5
101nOWh907alO0@0OGem1@24Q8@407inOP@0Ph>31@28R8P407MgM`D0OGem1020P80407emO@D0O7al
1021PH4507=cL`@0R8R8101cLg<508f=S@@0NGUi1@25QHD40820P0@0N7Qh1@2EUID406ATI0D0RHV9
101lO7`407moO`D0Ng]k101oOgl508n?S`@0KFe]102:RXX507IfMP@0Q8B41@1nOWh40861P@@0P820
1@1lO7`40861P@D0N7Qh3@38h=P406m_K`@0Ng]k1@1nOWh408b<S0D0P820101eMGD407YjNPD0PH61
101bLW8508f=S@@0PX:21024Q8@508R8R0@0NGUi101jNWX508F5Q@@0R8R81@26QXH4096AT@@0N7Qh
1@1nOWh40820P0D0PH61101hN7P408N7Q`D0PH611026QXH90820P0@0N7Qh1@2OWil406UYJ@D0Ogmo
1022PX8408b<S0D0MgMg101iNGT507emO@@0QXJ62@20P80406a/K0D0OWin1025QHD4075aL@D0Ph>3
101jNWX508>3P`@0OWin1021PH4507emO@@0Ph>31@1lO7`408N7Q`@0OWin1@1oOgl40861P@D0OWin
1023Ph<408:2PPD0PH611020P80408:2PPD0OWin5P38h=P001D0b>3H1@1gMgL407inOP@0Vi^K1@18
B4P409NGU`D0P8202022PX850820P0@0QHF51@24Q8@40820P0@0Q8B41@1kNg/408>3P`D0Rh^;101`
L70409VIV@D0J6QX102>SXh408>3P`D0Lg=c102?Shl507emO@@0NWYj101nOWh50861P@@0O7al2@22
PX8407UiN@D0QhN7101hN7P50861P@@0OGem1020P80507]kN`@0P8201@21PH4407inOP@0L71`1@2B
TY8407QhN0D0QXJ6102;Rh/405IFEPD0T92@101RHV8508R8R0@0PX:2101kNg/507IfMP@0QHF51@20
P80407inOP@0QXJ61@1lO7`407emO@D0QhN71022PX8407emO@D0QHF51024Q8@507AdM0d0b>3H1026
QXH407UiN@D0PH61101hN7P507IfMP@0N7Qh101mOGd50820P0@0Rh^;1@20P80407alO0@0R8R81@1k
Ng/40820P0@0Ph>31@1gMgL907inOP@0OGem101dM7@507UiN@@0Rh^;1@1hN7P407YjNP@0Ph>31@20
P80407UiN@D0PH611024Q8@407UiN@D0KVi^102XZ:P507UiN@@0Q8B4101nOWh507alO0@0R8R82@1m
OGd408B4Q0D0OWin1026QXH508Z:RP@0P820102@T90508>3P`@0MWIf1@2<S8`407YjNP@0Ng]k1@22
PX8407alO0D0QHF5102CTi<407inOPD0PX:2101kNg/50861P@@0Ph>31026QXH507inOP@0NGUi101j
NWX508>3PaH0b>3H000E0<SPf0D0MgMg101nOWh409^KV`D0B4Q8102GUiL50820P0P0PX:21@20P804
08F5Q@D0Q8B41020P80408B4Q0D0Ng]k1023Ph<508^;R`@0L71`102IVIT506QXJ0@0SXj>1023Ph<5
07=cL`@0Shn?1@1mOGd407YjNP@0OWin1@21PH4407alO0T0PX:2101iNGT508N7Q`@0N7Qh1@21PH44
07emO@@0P8201@1kNg/40820P0D0PH61101nOWh4071`L0D0TY:B101hN7P508J6QP@0Rh^;101FEUH5
092@T0@0HV9R1@28R8P408:2PP@0Ng]k1@1fMWH408F5Q@D0P820101nOWh408J6QPD0O7al101mOGd5
08N7Q`@0PX:2101mOGd508F5Q@@0Q8B41@1dM7@=0<SPf0@0QXJ6101iNGT50861P@@0N7Qh1@1fMWH4
07QhN0@0OGem1@20P80408^;R`D0P820101lO7`408R8R0D0Ng]k1020P80408>3P`D0MgMg2@1nOWh4
07emO@@0M7Ad1@1iNGT408^;R`D0N7Qh101jNWX408>3P`D0P820101iNGT50861P@@0Q8B4101iNGT5
06i^KP@0Z:RX1@1iNGT408B4Q0@0OWin1@1lO7`408R8R0T0OGem1024Q8@507inOP@0QXJ61@2:RXX4
0820P0@0T92@1@23Ph<407IfMPD0S8b<101jNWX407]kN`D0PX:2101lO7`508F5Q@@0Ti>C101nOWh5
08:2PP@0Ng]k1@21PH4408>3P`@0QXJ61@1nOWh407UiN@@0NWYj1@23Ph<F0<SPf0005@38h=P507Mg
M`@0OWin102KVi/504Q8B0@0UiNG1@20P80808:2PPD0P8201025QHD508B4Q0@0P8201024Q8@507]k
N`@0Ph>31@2;Rh/4071`L0@0VIVI1@1XJ6P408j>SP@0Ph>31@1cLg<408n?S`D0OGem101jNWX407in
OPD0PH61101lO7`908:2PP@0NGUi1@27QhL407QhN0D0PH61101mOGd40820P0D0Ng]k1020P8050861
P@@0OWin101`L70509:BTP@0N7Qh1@26QXH408^;R`@0EUIF1@2@T904069RHPD0R8R81022PX8407]k
N`D0MWIf1025QHD50820P0@0OWin1026QXH507alO0@0OGem1@27QhL408:2PP@0OGem1@25QHD408B4
Q0D0M7Ad3@38h=P408J6QP@0NGUi1@21PH4407QhN0D0MWIf101hN7P407emO@D0P820102;Rh/50820
P0@0O7al1028R8P507]kN`@0P8201023Ph<507MgM`T0OWin101mOGd407AdM0D0NGUi102;Rh/507Qh
N0@0NWYj1023Ph<50820P0@0NGUi1@21PH4408B4Q0@0NGUi1@1^KVh40:RXZ0D0NGUi1024Q8@407in
OPD0O7al1028R8P907emO@@0Q8B41@1nOWh408J6QPD0RXZ:1020P804092@T0D0Ph>3101fMWH508b<
S0@0NWYj101kNg/508:2PP@0O7al1@25QHD409>CT`@0OWin1@22PX8407]kN`D0PH611023Ph<408J6
QPD0OWin101iNGT407YjNPD0Ph>35P38h=P001D0b>3H1@1gMgL407inOP@0Vi^K1@18B4P409NGU`D0
P8202022PX850820P0@0QHF51@24Q8@40820P0@0Q8B41@1kNg/408>3P`D0Rh^;101`L70409VIV@D0
J6QX102>SXh408>3P`D0Lg=c102?Shl507emO@@0NWYj101nOWh50861P@@0O7al2@22PX8407UiN@D0
QhN7101hN7P50861P@@0OGem1020P80507]kN`@0P8201@21PH4407inOP@0L71`1@2BTY8407QhN0D0
QXJ6102;Rh/405IFEPD0T92@101RHV8508R8R0@0PX:2101kNg/507IfMP@0QHF51@20P80407inOP@0
QXJ61@1lO7`407emO@D0QhN71022PX8407emO@D0QHF51024Q8@507AdM0d0b>3H1026QXH407UiN@D0
PH61101hN7P507IfMP@0N7Qh101mOGd50820P0@0Rh^;1@20P80407alO0@0R8R81@1kNg/40820P0@0
Ph>31@1gMgL907inOP@0OGem101dM7@507UiN@@0Rh^;1@1hN7P407YjNP@0Ph>31@20P80407UiN@D0
PH611024Q8@407UiN@D0KVi^102XZ:P507UiN@@0Q8B4101nOWh507alO0@0R8R82@1mOGd408B4Q0D0
OWin1026QXH508Z:RP@0P820102@T90508>3P`@0MWIf1@2<S8`407YjNP@0Ng]k1@22PX8407alO0D0
QHF5102CTi<407inOPD0PX:2101kNg/50861P@@0Ph>31026QXH507inOP@0NGUi101jNWX508>3PaH0
b>3H000E0<SPf0T0NWYj102JVYX507EeM@@0NWYj1@21PH440820P0@0Ng]k1@21PH4407moO`D0N7Qh
102;Rh/408R8R0D0MWIf102;Rh/507moO`@0O7al1023Ph<507QhN0@0KFe]102>SXh5071`L0@0RXZ:
1@1kNg/407alO0@0QhN71@1nOWh407QhN0D0PH611023Ph<408F5Q@D0MGEe102:RXX507alO0@0OWin
1020P80507emO@@0OWin1@1mOGd408J6QP@0MgMg1@25QHD407UiN@D0Ogmo102DU9@407AdM0D0QHF5
101fMWH507moO`@0QHF5101XJ6P507moO`@0PX:21@1cLg<408f=S@@0N7Qh1@1mOGd407moO`D0P820
101hN7P907moO`@0Ph>31@1kNg/=0<SPf0@0Ogmo1023Ph<507IfMP@0MgMg1@22PX8407]kN`@0Ph>3
1@1nOWh407]kN`D0Ph>3102?Shl406e]K@D0JFUY102BTY8408V9R@D0OWin1023Ph<50861P@@0OGem
1020P80508V9R@@0MGEe1@26QXH408n?S`@0PH611@1lO7`407emO@D0Ogmo1022PX8408V9R@D0PX:2
101/K6`50:>SX`@0Ogmo101nOWh508F5Q@@0OGem1@25QHD407QhN0@0Ogmo1@23Ph<407emO@D0MgMg
101hN7P407emO@D0KVi^1020P805071`L0P0QhN71@1mOGd407QhN0D0PX:2101hN7P40820P0D0Ogmo
1020P80507inOP@0Ph>3101nOWh507IfMP@0MgMg101nOWh507YjNQH0b>3H000E0<SPf0T0NWYj102J
VYX507EeM@@0NWYj1@21PH440820P0@0Ng]k1@21PH4407moO`D0N7Qh102;Rh/408R8R0D0MWIf102;
Rh/507moO`@0O7al1023Ph<507QhN0@0KFe]102>SXh5071`L0@0RXZ:1@1kNg/407alO0@0QhN71@1n
OWh407QhN0D0PH611023Ph<408F5Q@D0MGEe102:RXX507alO0@0OWin1020P80507emO@@0OWin1@1m
OGd408J6QP@0MgMg1@25QHD407UiN@D0Ogmo102DU9@407AdM0D0QHF5101fMWH507moO`@0QHF5101X
J6P507moO`@0PX:21@1cLg<408f=S@@0N7Qh1@1mOGd407moO`D0P820101hN7P907moO`@0Ph>31@1k
Ng/=0<SPf0@0Ogmo1023Ph<507IfMP@0MgMg1@22PX8407]kN`@0Ph>31@1nOWh407]kN`D0Ph>3102?
Shl406e]K@D0JFUY102BTY8408V9R@D0OWin1023Ph<50861P@@0OGem1020P80508V9R@@0MGEe1@26
QXH408n?S`@0PH611@1lO7`407emO@D0Ogmo1022PX8408V9R@D0PX:2101/K6`50:>SX`@0Ogmo101n
OWh508F5Q@@0OGem1@25QHD407QhN0@0Ogmo1@23Ph<407emO@D0MgMg101hN7P407emO@D0KVi^1020
P805071`L0P0QhN71@1mOGd407QhN0D0PX:2101hN7P40820P0D0Ogmo1020P80507inOP@0Ph>3101n
OWh507IfMP@0MgMg101nOWh507YjNQH0b>3H000E0<SPf0T0NWYj102JVYX507EeM@@0NWYj1@21PH44
0820P0@0Ng]k1@21PH4407moO`D0N7Qh102;Rh/408R8R0D0MWIf102;Rh/507moO`@0O7al1023Ph<5
07QhN0@0KFe]102>SXh5071`L0@0RXZ:1@1kNg/407alO0@0QhN71@1nOWh407QhN0D0PH611023Ph<4
08F5Q@D0MGEe102:RXX507alO0@0OWin1020P80507emO@@0OWin1@1mOGd408J6QP@0MgMg1@25QHD4
07UiN@D0Ogmo102DU9@407AdM0D0QHF5101fMWH507moO`@0QHF5101XJ6P507moO`@0PX:21@1cLg<4
08f=S@@0N7Qh1@1mOGd407moO`D0P820101hN7P907moO`@0Ph>31@1kNg/=0<SPf0@0Ogmo1023Ph<5
07IfMP@0MgMg1@22PX8407]kN`@0Ph>31@1nOWh407]kN`D0Ph>3102?Shl406e]K@D0JFUY102BTY84
08V9R@D0OWin1023Ph<50861P@@0OGem1020P80508V9R@@0MGEe1@26QXH408n?S`@0PH611@1lO7`4
07emO@D0Ogmo1022PX8408V9R@D0PX:2101/K6`50:>SX`@0Ogmo101nOWh508F5Q@@0OGem1@25QHD4
07QhN0@0Ogmo1@23Ph<407emO@D0MgMg101hN7P407emO@D0KVi^1020P805071`L0P0QhN71@1mOGd4
07QhN0D0PX:2101hN7P40820P0D0Ogmo1020P80507inOP@0Ph>3101nOWh507IfMP@0MgMg101nOWh5
07YjNQH0b>3H000E0<SPf0T0NWYj102JVYX507EeM@@0NWYj1@21PH440820P0@0Ng]k1@21PH4407mo
O`D0N7Qh102;Rh/408R8R0D0MWIf102;Rh/507moO`@0O7al1023Ph<507QhN0@0KFe]102>SXh5071`
L0@0RXZ:1@1kNg/407alO0@0QhN71@1nOWh407QhN0D0PH611023Ph<408F5Q@D0MGEe102:RXX507al
O0@0OWin1020P80507emO@@0OWin1@1mOGd408J6QP@0MgMg1@25QHD407UiN@D0Ogmo102DU9@407Ad
M0D0QHF5101fMWH507moO`@0QHF5101XJ6P507moO`@0PX:21@1cLg<408f=S@@0N7Qh1@1mOGd407mo
O`D0P820101hN7P907moO`@0Ph>31@1kNg/=0<SPf0@0Ogmo1023Ph<507IfMP@0MgMg1@22PX8407]k
N`@0Ph>31@1nOWh407]kN`D0Ph>3102?Shl406e]K@D0JFUY102BTY8408V9R@D0OWin1023Ph<50861
P@@0OGem1020P80508V9R@@0MGEe1@26QXH408n?S`@0PH611@1lO7`407emO@D0Ogmo1022PX8408V9
R@D0PX:2101/K6`50:>SX`@0Ogmo101nOWh508F5Q@@0OGem1@25QHD407QhN0@0Ogmo1@23Ph<407em
O@D0MgMg101hN7P407emO@D0KVi^1020P805071`L0P0QhN71@1mOGd407QhN0D0PX:2101hN7P40820
P0D0Ogmo1020P80507inOP@0Ph>3101nOWh507IfMP@0MgMg101nOWh507YjNQH0b>3H000E0<SPf0T0
NWYj102JVYX507EeM@@0NWYj1@21PH440820P0@0Ng]k1@21PH4407moO`D0N7Qh102;Rh/408R8R0D0
MWIf102;Rh/507moO`@0O7al1023Ph<507QhN0@0KFe]102>SXh5071`L0@0RXZ:1@1kNg/407alO0@0
QhN71@1nOWh407QhN0D0PH611023Ph<408F5Q@D0MGEe102:RXX507alO0@0OWin1020P80507emO@@0
OWin1@1mOGd408J6QP@0MgMg1@25QHD407UiN@D0Ogmo102DU9@407AdM0D0QHF5101fMWH507moO`@0
QHF5101XJ6P507moO`@0PX:21@1cLg<408f=S@@0N7Qh1@1mOGd407moO`D0P820101hN7P907moO`@0
Ph>31@1kNg/=0<SPf0@0Ogmo1023Ph<507IfMP@0MgMg1@22PX8407]kN`@0Ph>31@1nOWh407]kN`D0
Ph>3102?Shl406e]K@D0JFUY102BTY8408V9R@D0OWin1023Ph<50861P@@0OGem1020P80508V9R@@0
MGEe1@26QXH408n?S`@0PH611@1lO7`407emO@D0Ogmo1022PX8408V9R@D0PX:2101/K6`50:>SX`@0
Ogmo101nOWh508F5Q@@0OGem1@25QHD407QhN0@0Ogmo1@23Ph<407emO@D0MgMg101hN7P407emO@D0
KVi^1020P805071`L0P0QhN71@1mOGd407QhN0D0PX:2101hN7P40820P0D0Ogmo1020P80507inOP@0
Ph>3101nOWh507IfMP@0MgMg101nOWh507YjNQH0b>3H000E0<SPf0D0RHV9101]KFd408N7Q`D0V9RH
101hN7P507moO`@0Q8B42@1nOWh408Z:RPD0MgMg1023Ph<408V9R@D0Ng]k1021PH4507emO@P0OWin
1@2@T90407MgM`@0Rh^;1@27QhL406e]K@D0S8b<101nOWh40820P0h0O7al1023Ph<40861P@D0PX:2
101`L705096AT@@0Lg=c1024Q8@507IfMP@0P8202@1nOWh408>3P`D0QXJ6101oOgl508>3P`@0Ogmo
1021PH4507UiN@@0NWYj1@26QXH408F5Q@@0OWin1@21PH4907emO@@0Q8B41021PH4507moO`@0P820
1@1mOGd407inOP@0PX:21@1oOgl407inOPD0O7al3@38h=P406m_K`@0LW9b1@27QhL407MgM`D0Ogmo
1021PH4408>3P`D0S8b<102:RXX509FEU@@0LW9b102=SHd506e]K@@0Rh^;101lO7`508:2PP@0RXZ:
1@1gMgL407YjNP@0RXZ:1@26QXH407MgM`D0Q8B4101dM7@407YjNPD0PH61101oOgl508B4Q0@0Ph>3
1020P80507moO`@0PH611@1[Jf/40:6QX@@0RXZ:1@1oOgl407AdM0D0PX:2101hN7P408B4Q0D0P820
1022PX8508V9R@@0Ogmo2@1nOWh409^KV`D0PX:21027QhL407inOPD0Q8B4101lO7`507IfMP@0Ph>3
2@21PH4407alO0D0OWin1022PX8407moO`D0Ng]k1025QHD407inOPD0PH615P38h=P001D0b>3H1@29
RHT406e]K@@0QhN71@2HV9P407QhN0D0Ogmo1024Q8@907inOP@0RXZ:1@1gMgL408>3P`@0RHV91@1k
Ng/40861P@D0OGem201nOWh5092@T0@0MgMg102;Rh/508N7Q`@0KFe]1@2<S8`407inOP@0P8203P1l
O7`408>3P`@0PH611@22PX84071`L0D0TI6A101cLg<408B4Q0D0MWIf1020P80907inOP@0Ph>31@26
QXH407moO`D0Ph>3101oOgl40861P@D0NGUi101jNWX508J6QP@0QHF5101nOWh50861P@T0OGem1024
Q8@40861P@D0Ogmo1020P80507emO@@0OWin1022PX8507moO`@0OWin1@1lO7`=0<SPf0@0Kfm_101b
LW8508N7Q`@0MgMg1@1oOgl40861P@@0Ph>31@2<S8`408Z:RPD0UIFE101bLW8408f=S@D0KFe]102;
Rh/407alO0D0PX:2102:RXX507MgM`@0NWYj102:RXX508J6QP@0MgMg1@24Q8@407AdM0@0NWYj1@21
PH4407moO`D0Q8B41023Ph<40820P0D0Ogmo1021PH4506][J`@0XJ6Q102:RXX507moO`@0M7Ad1@22
PX8407QhN0@0Q8B41@20P80408:2PPD0RHV9101oOgl907inOP@0Vi^K1@22PX8408N7Q`@0OWin1@24
Q8@407alO0D0MWIf1023Ph<90861P@@0O7al1@1nOWh408:2PP@0Ogmo1@1kNg/408F5Q@@0OWin1@21
PH4F0<SPf0005@38h=P508V9R@@0KFe]1027QhL509RHV0@0N7Qh1@1oOgl408B4Q0T0OWin102:RXX5
07MgM`@0Ph>31029RHT507]kN`@0PH611@1mOGd807inOPD0T92@101gMgL408^;R`D0QhN7101]KFd5
08b<S0@0OWin1020P80>07alO0@0Ph>31021PH4508:2PP@0L71`1@2ATI4407=cL`@0Q8B41@1fMWH4
0820P0T0OWin1023Ph<508J6QP@0Ogmo1@23Ph<407moO`@0PH611@1iNGT407YjNPD0QXJ61025QHD4
07inOPD0PH612@1mOGd408B4Q0@0PH611@1oOgl40820P0D0OGem101nOWh408:2PPD0Ogmo101nOWh5
07alO0d0b>3H101_Kfl4079bLPD0QhN7101gMgL507moO`@0PH611023Ph<508b<S0@0RXZ:1@2EUID4
079bLP@0SHf=1@1]KFd408^;R`@0O7al1@22PX8408Z:RPD0MgMg101jNWX408Z:RPD0QXJ6101gMgL5
08B4Q0@0M7Ad101jNWX50861P@@0Ogmo1@24Q8@408>3P`@0P8201@1oOgl40861P@D0Jf][102QXJ44
08Z:RPD0Ogmo101dM7@508:2PP@0N7Qh1024Q8@50820P0@0PX:21@29RHT407moO`T0OWin102KVi/5
08:2PP@0QhN7101nOWh508B4Q0@0O7al1@1fMWH408>3P`T0PH61101lO7`507inOP@0PX:2101oOgl5
07]kN`@0QHF5101nOWh50861PAH0b>3H000E0<SPf0D0RHV9101]KFd408N7Q`D0V9RH101hN7P507mo
O`@0Q8B42@1nOWh408Z:RPD0MgMg1023Ph<408V9R@D0Ng]k1021PH4507emO@P0OWin1@2@T90407Mg
M`@0Rh^;1@27QhL406e]K@D0S8b<101nOWh40820P0h0O7al1023Ph<40861P@D0PX:2101`L705096A
T@@0Lg=c1024Q8@507IfMP@0P8202@1nOWh408>3P`D0QXJ6101oOgl508>3P`@0Ogmo1021PH4507Ui
N@@0NWYj1@26QXH408F5Q@@0OWin1@21PH4907emO@@0Q8B41021PH4507moO`@0P8201@1mOGd407in
OP@0PX:21@1oOgl407inOPD0O7al3@38h=P406m_K`@0LW9b1@27QhL407MgM`D0Ogmo1021PH4408>3
P`D0S8b<102:RXX509FEU@@0LW9b102=SHd506e]K@@0Rh^;101lO7`508:2PP@0RXZ:1@1gMgL407Yj
NP@0RXZ:1@26QXH407MgM`D0Q8B4101dM7@407YjNPD0PH61101oOgl508B4Q0@0Ph>31020P80507mo
O`@0PH611@1[Jf/40:6QX@@0RXZ:1@1oOgl407AdM0D0PX:2101hN7P408B4Q0D0P8201022PX8508V9
R@@0Ogmo2@1nOWh409^KV`D0PX:21027QhL407inOPD0Q8B4101lO7`507IfMP@0Ph>32@21PH4407al
O0D0OWin1022PX8407moO`D0Ng]k1025QHD407inOPD0PH615P38h=P001D0b>3H1@1WIfL408F5Q@@0
MWIf1@2VYZH407UiN@D0Ph>31020P80407moO`D0UIFE101hN7P507emO@P0OWin1@1mOGd40820P0D0
NGUi1026QXH407EeM@D0OGem1025QHD405iNGPD0SHf=1024Q8@507AdM0@0Q8B42@1kNg/408:2PPD0
Ogmo1023Ph<407]kN`D0Ogmo102>SXh506e]K@@0T92@101lO7`507MgM`@0PX:21@1mOGd40861P@@0
P8201@1jNWX40861P@D0Ng]k101mOGd407moO`D0Lg=c1024Q8@50861P@P0Ph>31@21PH4407YjNPD0
Q8B41020P8040861P@D0Q8B4101lO7`507emO@@0PX:2101nOWh507alO0@0Q8B41@1nOWh=0<SPf0@0
QXJ61028R8P508Z:RP@0PX:21@1fMWH407alO0@0NGUi1@2:RXX408V9R@D0MgMg101nOWh908F5Q@@0
Ng]k1025QHD508:2PP@0Ogmo1@25QHD407moO`@0MWIf1@1YJFT408Z:RPD0P8201027QhL408:2PPD0
Q8B4101hN7P507inOP@0PH611022PX8907emO@D0PX:2101^KVh409^KV`D0QhN7101aLG4508F5Q@@0
PH611020P80508:2PP@0Ng]k1@21PH4408B4Q0@0QHF51@1hN7P408N7Q`D0SHf=101eMGD406a/K0D0
Ph>3102;Rh/506i^KP@0QHF5101nOWh507]kN`@0Q8B41@1dM7@408Z:RP@0SXj>1@1jNWX407]kN`@0
PH611@1oOglF0<SPf0005@38h=P506MWI`@0QHF5101fMWH50:JVYP@0NGUi1@23Ph<40820P0@0Ogmo
1@2EUID407QhN0D0OGem201nOWh507emO@@0P8201@1iNGT408J6QP@0MGEe1@1mOGd408F5Q@@0GUiN
1@2=SHd408B4Q0D0M7Ad1024Q8@907]kN`@0PX:21@1oOgl408>3P`@0Ng]k1@1oOgl408j>SPD0KFe]
102@T90407alO0D0MgMg1022PX8507emO@@0PH611020P80507YjNP@0PH611@1kNg/407emO@@0Ogmo
1@1cLg<408B4Q0D0PH612023Ph<50861P@@0NWYj1@24Q8@40820P0@0PH611@24Q8@407alO0D0OGem
1022PX8407inOPD0O7al1024Q8@507inOPd0b>3H1026QXH408R8R0D0RXZ:1022PX8507IfMP@0O7al
101iNGT508Z:RP@0RHV91@1gMgL407inOPT0QHF5101kNg/408F5Q@D0PX:2101oOgl508F5Q@@0Ogmo
101fMWH506UYJ@@0RXZ:1@20P80408N7Q`@0PX:21@24Q8@407QhN0D0OWin1021PH4408:2PPT0OGem
1@22PX8406i^KP@0Vi^K1@27QhL4075aL@D0QHF51021PH440820P0D0PX:2101kNg/50861P@@0Q8B4
1025QHD507QhN0@0QhN71@2=SHd407EeM@@0K6a/1@23Ph<408^;R`D0KVi^1025QHD407inOPD0Ng]k
1024Q8@507AdM0@0RXZ:102>SXh507YjNP@0Ng]k1021PH4507moOaH0b>3H000E0<SPf0D0IfMW1025
QHD407IfMPD0YZJV101iNGT508>3P`@0P820101oOgl509FEU@@0N7Qh1@1mOGd807inOPD0OGem1020
P80507UiN@@0QXJ6101eMGD507emO@@0QHF5101NGUh508f=S@@0Q8B41@1dM7@408B4Q0T0Ng]k1022
PX8507moO`@0Ph>3101kNg/507moO`@0SXj>1@1]KFd4092@T0@0O7al1@1gMgL408:2PPD0OGem1021
PH440820P0D0NWYj1021PH4507]kN`@0OGem101oOgl507=cL`@0Q8B41@21PH4808>3P`D0PH61101j
NWX508B4Q0@0P8201021PH4508B4Q0@0O7al1@1mOGd408:2PP@0OWin1@1lO7`408B4Q0D0OWin3@38
h=P408J6QP@0R8R81@2:RXX408:2PPD0MWIf101lO7`407UiN@D0RXZ:1029RHT507MgM`@0OWin2@25
QHD407]kN`@0QHF51@22PX8407moO`D0QHF5101oOgl407IfMPD0JFUY102:RXX50820P0@0QhN71022
PX8508B4Q0@0N7Qh1@1nOWh40861P@@0PX:22@1mOGd508:2PP@0KVi^102KVi/508N7Q`@0LG5a1@25
QHD40861P@@0P8201@22PX8407]kN`D0PH611024Q8@408F5Q@D0N7Qh1027QhL508f=S@@0MGEe101/
K6`508>3P`@0Rh^;1@1^KVh408F5Q@@0OWin1@1kNg/408B4Q0D0M7Ad102:RXX408j>SPD0NWYj101k
Ng/40861P@D0Ogmo5P38h=P001D0b>3H1@1WIfL408F5Q@@0MWIf1@2VYZH407UiN@D0Ph>31020P804
07moO`D0UIFE101hN7P507emO@P0OWin1@1mOGd40820P0D0NGUi1026QXH407EeM@D0OGem1025QHD4
05iNGPD0SHf=1024Q8@507AdM0@0Q8B42@1kNg/408:2PPD0Ogmo1023Ph<407]kN`D0Ogmo102>SXh5
06e]K@@0T92@101lO7`507MgM`@0PX:21@1mOGd40861P@@0P8201@1jNWX40861P@D0Ng]k101mOGd4
07moO`D0Lg=c1024Q8@50861P@P0Ph>31@21PH4407YjNPD0Q8B41020P8040861P@D0Q8B4101lO7`5
07emO@@0PX:2101nOWh507alO0@0Q8B41@1nOWh=0<SPf0@0QXJ61028R8P508Z:RP@0PX:21@1fMWH4
07alO0@0NGUi1@2:RXX408V9R@D0MgMg101nOWh908F5Q@@0Ng]k1025QHD508:2PP@0Ogmo1@25QHD4
07moO`@0MWIf1@1YJFT408Z:RPD0P8201027QhL408:2PPD0Q8B4101hN7P507inOP@0PH611022PX89
07emO@D0PX:2101^KVh409^KV`D0QhN7101aLG4508F5Q@@0PH611020P80508:2PP@0Ng]k1@21PH44
08B4Q0@0QHF51@1hN7P408N7Q`D0SHf=101eMGD406a/K0D0Ph>3102;Rh/506i^KP@0QHF5101nOWh5
07]kN`@0Q8B41@1dM7@408Z:RP@0SXj>1@1jNWX407]kN`@0PH611@1oOglF0<SPf0005@38h=P5096A
T@@0Ng]k101[Jf/509jNWP@0O7al1@22PX8407YjNP@0PX:21@1WIfL40861P@D0PX:21021PH4407mo
O`D0MWIf1020P80508B4Q0@0Ph>3101gMgL507=cL`@0SXj>101YJFT507]kN`@0T92@1@1WIfL4096A
T@@0O7al1@1oOgl40820P0D0PH611023Ph<407moO`D0P8201022PX8508>3P`@0KFe]102>SXh507]k
N`@0QhN71@22PX840861P@@0Ng]k1@26QXH407YjNPD0QHF51023Ph<407inOPD0Ng]k101nOWh908:2
PP@0OWin1@21PH4407=cL`D0PX:21020P80408B4Q0D0QHF5101nOWh508F5Q@@0O7al101mOGd50861
P@@0OGem1@1lO7`=0<SPf0@0OWin1022PX890820P0T0OGem101nOWh5079bLP@0OWin1@1fMWH407em
O@@0PX:21@1oOgl407UiN@@0O7al1@1gMgL407EeM@D0QXJ6102ATI4408V9R@D0UYJF102=SHd508b<
S0@0R8R81022PX8508b<S0@0QHF51@21PH4407inOP@0PH611@20P80408F5Q@D0O7al1026QXH406UY
J@D0Vi^K102<S8`507QhN0@0PX:2101kNg/508^;R`@0O7al1@21PH4407IfMP@0NWYj1@1oOgl408N7
Q`D0O7al1024Q8@40820P0D0Ogmo101cLg<50:BTY0@0P8202@1nOWh408J6QPD0Q8B41022PX840861
P@D0NWYj101nOWh40861P@D0Q8B45P38h=P001D0b>3H1@2ATI4407]kN`@0Jf][1@2NWYh407alO0D0
PX:2101jNWX408:2PPD0IfMW1021PH4508:2PP@0PH61101oOgl507IfMP@0P8201@24Q8@408>3P`@0
MgMg1@1cLg<408j>SP@0JFUY1@1kNg/4092@T0D0IfMW102ATI4407alO0D0Ogmo1020P8050861P@@0
Ph>3101oOgl50820P0@0PX:21@23Ph<406e]K@@0SXj>1@1kNg/408N7Q`D0PX:21021PH4407]kN`D0
QXJ6101jNWX508F5Q@@0Ph>3101nOWh507]kN`@0OWin2@22PX8407inOPD0PH61101cLg<508:2PP@0
P8201024Q8@508F5Q@@0OWin1@25QHD407alO0@0OGem1@21PH4407emO@D0O7al3@38h=P407inOP@0
PX:22@20P80907emO@@0OWin1@1bLW8407inOPD0MWIf101mOGd408:2PPD0Ogmo101iNGT407alO0D0
MgMg101eMGD508J6QP@0TI6A1029RHT509JFUP@0SHf=1@2<S8`408R8R0@0PX:21@2<S8`408F5Q@D0
PH61101nOWh40861P@D0P8201025QHD507alO0@0QXJ6101YJFT509^KV`@0S8b<1@1hN7P408:2PP@0
Ng]k1@2;Rh/407alO0D0PH61101fMWH407YjNPD0Ogmo1027QhL507alO0@0Q8B41020P80507moO`@0
Lg=c1@2TY:@40820P0T0OWin1026QXH508B4Q0@0PX:21021PH4507YjNP@0OWin1021PH4508B4Q1H0
b>3H000E0<SPf0D0TI6A101kNg/406][J`D0WYjN101lO7`508:2PP@0NWYj1022PX8506MWI`@0PH61
1@22PX840861P@@0Ogmo1@1fMWH40820P0D0Q8B41023Ph<407MgM`D0Lg=c102>SXh406UYJ@D0Ng]k
102@T90506MWI`@0TI6A101lO7`507moO`@0P8201@21PH4408>3P`@0Ogmo1@20P80408:2PPD0Ph>3
101]KFd408j>SPD0Ng]k1027QhL508:2PP@0PH61101kNg/508J6QP@0NWYj1@25QHD408>3P`@0OWin
1@1kNg/407inOPT0PX:2101nOWh50861P@@0Lg=c1@22PX840820P0@0Q8B41@25QHD407inOPD0QHF5
101lO7`407emO@D0PH61101mOGd507alO0d0b>3H101nOWh408:2PPT0P8202@1mOGd407inOPD0LW9b
101nOWh507IfMP@0OGem1022PX8507moO`@0NGUi101lO7`507MgM`@0MGEe1@26QXH4096AT@@0RHV9
1@2FUYH408f=S@D0S8b<1028R8P408:2PPD0S8b<1025QHD50861P@@0OWin1021PH450820P0@0QHF5
1@1lO7`408J6QP@0JFUY1@2KVi/408b<S0D0N7Qh1022PX8407]kN`D0Rh^;101lO7`50861P@@0MWIf
101jNWX507moO`@0QhN71@1lO7`408B4Q0@0P8201@1oOgl407=cL`D0Y:BT1020P80907inOP@0QXJ6
1@24Q8@408:2PP@0PH611@1jNWX407inOP@0PH611@24Q8@F0<SPf0005@38h=P5096AT@@0Ng]k101[
Jf/509jNWP@0O7al1@22PX8407YjNP@0PX:21@1WIfL40861P@D0PX:21021PH4407moO`D0MWIf1020
P80508B4Q0@0Ph>3101gMgL507=cL`@0SXj>101YJFT507]kN`@0T92@1@1WIfL4096AT@@0O7al1@1o
Ogl40820P0D0PH611023Ph<407moO`D0P8201022PX8508>3P`@0KFe]102>SXh507]kN`@0QhN71@22
PX840861P@@0Ng]k1@26QXH407YjNPD0QHF51023Ph<407inOPD0Ng]k101nOWh908:2PP@0OWin1@21
PH4407=cL`D0PX:21020P80408B4Q0D0QHF5101nOWh508F5Q@@0O7al101mOGd50861P@@0OGem1@1l
O7`=0<SPf0@0OWin1022PX890820P0T0OGem101nOWh5079bLP@0OWin1@1fMWH407emO@@0PX:21@1o
Ogl407UiN@@0O7al1@1gMgL407EeM@D0QXJ6102ATI4408V9R@D0UYJF102=SHd508b<S0@0R8R81022
PX8508b<S0@0QHF51@21PH4407inOP@0PH611@20P80408F5Q@D0O7al1026QXH406UYJ@D0Vi^K102<
S8`507QhN0@0PX:2101kNg/508^;R`@0O7al1@21PH4407IfMP@0NWYj1@1oOgl408N7Q`D0O7al1024
Q8@40820P0D0Ogmo101cLg<50:BTY0@0P8202@1nOWh408J6QPD0Q8B41022PX840861P@D0NWYj101n
OWh40861P@D0Q8B45P38h=P001D0b>3H1@2ATI4407]kN`@0Jf][1@2NWYh407alO0D0PX:2101jNWX4
08:2PPD0IfMW1021PH4508:2PP@0PH61101oOgl507IfMP@0P8201@24Q8@408>3P`@0MgMg1@1cLg<4
08j>SP@0JFUY1@1kNg/4092@T0D0IfMW102ATI4407alO0D0Ogmo1020P8050861P@@0Ph>3101oOgl5
0820P0@0PX:21@23Ph<406e]K@@0SXj>1@1kNg/408N7Q`D0PX:21021PH4407]kN`D0QXJ6101jNWX5
08F5Q@@0Ph>3101nOWh507]kN`@0OWin2@22PX8407inOPD0PH61101cLg<508:2PP@0P8201024Q8@5
08F5Q@@0OWin1@25QHD407alO0@0OGem1@21PH4407emO@D0O7al3@38h=P407inOP@0PX:22@20P809
07emO@@0OWin1@1bLW8407inOPD0MWIf101mOGd408:2PPD0Ogmo101iNGT407alO0D0MgMg101eMGD5
08J6QP@0TI6A1029RHT509JFUP@0SHf=1@2<S8`408R8R0@0PX:21@2<S8`408F5Q@D0PH61101nOWh4
0861P@D0P8201025QHD507alO0@0QXJ6101YJFT509^KV`@0S8b<1@1hN7P408:2PP@0Ng]k1@2;Rh/4
07alO0D0PH61101fMWH407YjNPD0Ogmo1027QhL507alO0@0Q8B41020P80507moO`@0Lg=c1@2TY:@4
0820P0T0OWin1026QXH508B4Q0@0PX:21021PH4507YjNP@0OWin1021PH4508B4Q1H0b>3H000E0<SP
f0D0P8201025QHD407AdM0D0VYZJ101jNWX50861P@@0Ogmo101gMgL5079bLP@0S8b<1@1hN7P408:2
PP@0OGem1@1iNGT40861P@D0PX:2101iNGT409:BTPD0MGEe101iNGT408j>SPD0J6QX102BTY8508Z:
RP@0KVi^102:RXX507]kN`@0PH612@20P80407]kN`D0PX:21026QXH508>3P`@0QhN7101bLW8508j>
SP@0QHF51@1nOWh40820P0@0OGem1@2:RXX407alO0D0NGUi101eMGD407moO`D0QhN7101aLG4507Mg
M`@0S8b<101eMGD50820P0@0MWIf1@2HV9P406YZJPT0Ogmo1021PH4507moO`P0P8201@21PH4407al
O0D0PX:23@38h=P407UiN@@0PH611@2CTi<407moO`D0OGem1022PX840861P@D0Ng]k1021PH4508:2
PP@0LW9b101jNWX508B4Q0@0O7al101bLW8507alO0@0QhN71@1`L704069RHP@0OWin1@1kNg/407Ee
M@D0IFEU1021PH4408B4Q0D0MWIf102ATI4508:2PP@0O7al101mOGd507]kN`@0P8201@21PH4407]k
N`@0Q8B41@1^KVh40:BTY0D0K6a/101kNg/40820P0D0PX:21029RHT507]kN`@0NWYj101iNGT507=c
L`@0NGUi1@28R8P408^;R`@0MgMg1@2>SXh409RHV0D0Q8B4102@T90408J6QPD0O7al101oOgl507Ee
M@@0Q8B4101kNg/508:2PP@0NWYj101nOWh50820P1H0b>3H000E0<SPf0D0P8201025QHD407AdM0D0
VYZJ101jNWX50861P@@0Ogmo101gMgL5079bLP@0S8b<1@1hN7P408:2PP@0OGem1@1iNGT40861P@D0
PX:2101iNGT409:BTPD0MGEe101iNGT408j>SPD0J6QX102BTY8508Z:RP@0KVi^102:RXX507]kN`@0
PH612@20P80407]kN`D0PX:21026QXH508>3P`@0QhN7101bLW8508j>SP@0QHF51@1nOWh40820P0@0
OGem1@2:RXX407alO0D0NGUi101eMGD407moO`D0QhN7101aLG4507MgM`@0S8b<101eMGD50820P0@0
MWIf1@2HV9P406YZJPT0Ogmo1021PH4507moO`P0P8201@21PH4407alO0D0PX:23@38h=P407UiN@@0
PH611@2CTi<407moO`D0OGem1022PX840861P@D0Ng]k1021PH4508:2PP@0LW9b101jNWX508B4Q0@0
O7al101bLW8507alO0@0QhN71@1`L704069RHP@0OWin1@1kNg/407EeM@D0IFEU1021PH4408B4Q0D0
MWIf102ATI4508:2PP@0O7al101mOGd507]kN`@0P8201@21PH4407]kN`@0Q8B41@1^KVh40:BTY0D0
K6a/101kNg/40820P0D0PX:21029RHT507]kN`@0NWYj101iNGT507=cL`@0NGUi1@28R8P408^;R`@0
MgMg1@2>SXh409RHV0D0Q8B4102@T90408J6QPD0O7al101oOgl507EeM@@0Q8B4101kNg/508:2PP@0
NWYj101nOWh50820P1H0b>3H000E0<SPf0D0P8201025QHD407AdM0D0VYZJ101jNWX50861P@@0Ogmo
101gMgL5079bLP@0S8b<1@1hN7P408:2PP@0OGem1@1iNGT40861P@D0PX:2101iNGT409:BTPD0MGEe
101iNGT408j>SPD0J6QX102BTY8508Z:RP@0KVi^102:RXX507]kN`@0PH612@20P80407]kN`D0PX:2
1026QXH508>3P`@0QhN7101bLW8508j>SP@0QHF51@1nOWh40820P0@0OGem1@2:RXX407alO0D0NGUi
101eMGD407moO`D0QhN7101aLG4507MgM`@0S8b<101eMGD50820P0@0MWIf1@2HV9P406YZJPT0Ogmo
1021PH4507moO`P0P8201@21PH4407alO0D0PX:23@38h=P407UiN@@0PH611@2CTi<407moO`D0OGem
1022PX840861P@D0Ng]k1021PH4508:2PP@0LW9b101jNWX508B4Q0@0O7al101bLW8507alO0@0QhN7
1@1`L704069RHP@0OWin1@1kNg/407EeM@D0IFEU1021PH4408B4Q0D0MWIf102ATI4508:2PP@0O7al
101mOGd507]kN`@0P8201@21PH4407]kN`@0Q8B41@1^KVh40:BTY0D0K6a/101kNg/40820P0D0PX:2
1029RHT507]kN`@0NWYj101iNGT507=cL`@0NGUi1@28R8P408^;R`@0MgMg1@2>SXh409RHV0D0Q8B4
102@T90408J6QPD0O7al101oOgl507EeM@@0Q8B4101kNg/508:2PP@0NWYj101nOWh50820P1H0b>3H
000E0<SPf0D0P8201025QHD407AdM0D0VYZJ101jNWX50861P@@0Ogmo101gMgL5079bLP@0S8b<1@1h
N7P408:2PP@0OGem1@1iNGT40861P@D0PX:2101iNGT409:BTPD0MGEe101iNGT408j>SPD0J6QX102B
TY8508Z:RP@0KVi^102:RXX507]kN`@0PH612@20P80407]kN`D0PX:21026QXH508>3P`@0QhN7101b
LW8508j>SP@0QHF51@1nOWh40820P0@0OGem1@2:RXX407alO0D0NGUi101eMGD407moO`D0QhN7101a
LG4507MgM`@0S8b<101eMGD50820P0@0MWIf1@2HV9P406YZJPT0Ogmo1021PH4507moO`P0P8201@21
PH4407alO0D0PX:23@38h=P407UiN@@0PH611@2CTi<407moO`D0OGem1022PX840861P@D0Ng]k1021
PH4508:2PP@0LW9b101jNWX508B4Q0@0O7al101bLW8507alO0@0QhN71@1`L704069RHP@0OWin1@1k
Ng/407EeM@D0IFEU1021PH4408B4Q0D0MWIf102ATI4508:2PP@0O7al101mOGd507]kN`@0P8201@21
PH4407]kN`@0Q8B41@1^KVh40:BTY0D0K6a/101kNg/40820P0D0PX:21029RHT507]kN`@0NWYj101i
NGT507=cL`@0NGUi1@28R8P408^;R`@0MgMg1@2>SXh409RHV0D0Q8B4102@T90408J6QPD0O7al101o
Ogl507EeM@@0Q8B4101kNg/508:2PP@0NWYj101nOWh50820P1H0b>3H000E0<SPf0D0Ogmo1027QhL4
06m_K`D0Rh^;101nOWh507YjNP@0SXj>101mOGd5075aL@T0PH61201nOWh508B4Q0@0Ogmo1@1iNGT4
08F5Q@@0Lg=c1@29RHT407QhN0@0QXJ61@1bLW8407EeM@D0Ph>3101lO7`407AdM0D0Q8B4101nOWh5
07moO`@0PX:2101oOgl507inOP@0P8201@1oOgl407IfMP@0QHF51@1fMWH908R8R0@0O7al2@21PH44
07QhN0D0QXJ6101iNGT407=cL`D0O7al101iNGT507=cL`@0Vi^K101VIVH508N7Q`@0Ph>31@1nOWh4
08F5Q@@0PX:21@1iNGT40861P@D0P820101kNg/407moO`D0Ph>3101lO7`507moO`d0b>3H101iNGT4
08B4Q0D0Ph>31024Q8@507emO@@0SXj>102;Rh/508N7Q`@0OGem1@1oOgl407UiN@@0OWin1@1fMWH4
07inOP@0RXZ:1@1mOGd40820P0D0JVYZ102?Shl908F5Q@@0MgMg1@29RHT807emO@D0Q8B4101eMGD5
07emO@@0P8201021PH4507emO@@0OWin1@24Q8@408N7Q`@0P8201@1oOgl407QhN0D0VIVI101SHf<4
08>3P`D0PX:2101nOWh508R8R0@0Ph>3101kNg/5092@T0@0QhN71@1iNGT408J6QP@0NGUi1@1hN7P4
07alO0D0PX:21021PH4407alO0D0Ph>32@1mOGd407EeM@@0O7al1@1oOgl407emO@T0PX:25P38h=P0
01D0b>3H1@1oOgl408N7Q`@0Kfm_1@2;Rh/407inOPD0NWYj102>SXh407emO@D0LG5a2@21PH4807in
OPD0Q8B4101oOgl507UiN@@0QHF5101cLg<508V9R@@0N7Qh1026QXH5079bLP@0MGEe1@23Ph<407al
O0@0M7Ad1@24Q8@407inOPD0Ogmo1022PX8407moO`D0OWin1020P80507moO`@0MWIf1025QHD507If
MPT0R8R8101lO7`90861P@@0N7Qh1@26QXH407UiN@@0Lg=c1@1lO7`407UiN@D0Lg=c102KVi/406IV
IPD0QhN71023Ph<507inOP@0QHF51022PX8507UiN@@0PH611@20P80407]kN`@0Ogmo1@23Ph<407al
O0D0Ogmo3@38h=P407UiN@@0Q8B41@23Ph<408B4Q0D0OGem102>SXh408^;R`D0QhN7101mOGd507mo
O`@0NGUi101nOWh507IfMP@0OWin102:RXX507emO@@0P8201@1ZJVX408n?S`T0QHF5101gMgL508V9
R@P0OGem1@24Q8@407EeM@D0OGem1020P8040861P@D0OGem101nOWh508B4Q0@0QhN71020P80507mo
O`@0N7Qh1@2IVIT406=SH`@0Ph>31@22PX8407inOPD0R8R81023Ph<407]kN`D0T92@1027QhL507Ui
N@@0QXJ6101iNGT507QhN0@0O7al1@22PX840861P@@0O7al1@23Ph<907emO@@0MGEe101lO7`507mo
O`@0OGem2@22PX8F0<SPf0005@38h=P507moO`@0QhN7101_Kfl508^;R`@0OWin1@1jNWX408j>SP@0
OGem1@1aLG490861P@P0OWin1@24Q8@407moO`D0NGUi1025QHD407=cL`D0RHV9101hN7P408J6QPD0
LW9b101eMGD508>3P`@0O7al101dM7@508B4Q0@0OWin1@1oOgl408:2PP@0Ogmo1@1nOWh40820P0D0
Ogmo101fMWH408F5Q@D0MWIf2@28R8P407alO0T0PH61101hN7P508J6QP@0NGUi101cLg<507alO0@0
NGUi1@1cLg<409^KV`@0IVIV1@27QhL408>3P`D0OWin1025QHD408:2PPD0NGUi1021PH450820P0@0
Ng]k101oOgl508>3P`@0O7al1@1oOgl=0<SPf0@0NGUi1024Q8@508>3P`@0Q8B41@1mOGd408j>SP@0
Rh^;1@27QhL407emO@D0Ogmo101iNGT407inOPD0MWIf101nOWh408Z:RPD0OGem1020P80506YZJP@0
Shn?2@25QHD407MgM`D0RHV9201mOGd508B4Q0@0MGEe1@1mOGd40820P0@0PH611@1mOGd407inOPD0
Q8B41027QhL40820P0D0Ogmo101hN7P509VIV@@0Hf=S1023Ph<508:2PP@0OWin1@28R8P408>3P`@0
Ng]k1@2@T90408N7Q`D0NGUi1026QXH407UiN@D0N7Qh101lO7`508:2PP@0PH61101lO7`508>3P`T0
OGem101eMGD407alO0D0Ogmo101mOGd908:2PQH0b>3H000E0<SPf0D0Ogmo1027QhL406m_K`D0Rh^;
101nOWh507YjNP@0SXj>101mOGd5075aL@T0PH61201nOWh508B4Q0@0Ogmo1@1iNGT408F5Q@@0Lg=c
1@29RHT407QhN0@0QXJ61@1bLW8407EeM@D0Ph>3101lO7`407AdM0D0Q8B4101nOWh507moO`@0PX:2
101oOgl507inOP@0P8201@1oOgl407IfMP@0QHF51@1fMWH908R8R0@0O7al2@21PH4407QhN0D0QXJ6
101iNGT407=cL`D0O7al101iNGT507=cL`@0Vi^K101VIVH508N7Q`@0Ph>31@1nOWh408F5Q@@0PX:2
1@1iNGT40861P@D0P820101kNg/407moO`D0Ph>3101lO7`507moO`d0b>3H101iNGT408B4Q0D0Ph>3
1024Q8@507emO@@0SXj>102;Rh/508N7Q`@0OGem1@1oOgl407UiN@@0OWin1@1fMWH407inOP@0RXZ:
1@1mOGd40820P0D0JVYZ102?Shl908F5Q@@0MgMg1@29RHT807emO@D0Q8B4101eMGD507emO@@0P820
1021PH4507emO@@0OWin1@24Q8@408N7Q`@0P8201@1oOgl407QhN0D0VIVI101SHf<408>3P`D0PX:2
101nOWh508R8R0@0Ph>3101kNg/5092@T0@0QhN71@1iNGT408J6QP@0NGUi1@1hN7P407alO0D0PX:2
1021PH4407alO0D0Ph>32@1mOGd407EeM@@0O7al1@1oOgl407emO@T0PX:25P38h=P001D0b>3H1@1o
Ogl408N7Q`@0Kfm_1@2;Rh/407inOPD0NWYj102>SXh407emO@D0LG5a2@21PH4807inOPD0Q8B4101o
Ogl507UiN@@0QHF5101cLg<508V9R@@0N7Qh1026QXH5079bLP@0MGEe1@23Ph<407alO0@0M7Ad1@24
Q8@407inOPD0Ogmo1022PX8407moO`D0OWin1020P80507moO`@0MWIf1025QHD507IfMPT0R8R8101l
O7`90861P@@0N7Qh1@26QXH407UiN@@0Lg=c1@1lO7`407UiN@D0Lg=c102KVi/406IVIPD0QhN71023
Ph<507inOP@0QHF51022PX8507UiN@@0PH611@20P80407]kN`@0Ogmo1@23Ph<407alO0D0Ogmo3@38
h=P407UiN@@0Q8B41@23Ph<408B4Q0D0OGem102>SXh408^;R`D0QhN7101mOGd507moO`@0NGUi101n
OWh507IfMP@0OWin102:RXX507emO@@0P8201@1ZJVX408n?S`T0QHF5101gMgL508V9R@P0OGem1@24
Q8@407EeM@D0OGem1020P8040861P@D0OGem101nOWh508B4Q0@0QhN71020P80507moO`@0N7Qh1@2I
VIT406=SH`@0Ph>31@22PX8407inOPD0R8R81023Ph<407]kN`D0T92@1027QhL507UiN@@0QXJ6101i
NGT507QhN0@0O7al1@22PX840861P@@0O7al1@23Ph<907emO@@0MGEe101lO7`507moO`@0OGem2@22
PX8F0<SPf0005@38h=P508:2PP@0S8b<101/K6`507emO@@0PH611@1cLg<408n?S`@0Ogmo1@2CTi<4
07UiN@D0P820101mOGd90820P0@0T92@1@2;Rh/405UIF@@0Vi^K1@1cLg<409VIV@@0MgMg1@2:RXX4
07EeM@D0Ogmo102:RXX407UiN@D0Ogmo101mOGd90820P0@0O7al1@1oOgl40861P@D0Ng]k101hN7P4
07alO0D0QHF5101kNg/507inOP@0R8R8101iNGT507moO`@0PH611@1nOWh407YjNP@0RHV91@1lO7`4
08:2PPD0NWYj102:RXX407AdM0D0V9RH1027QhL508B4Q0@0P8202@1jNWX407moO`D0Ph>3101lO7`4
08:2PPD0P820101lO7`507emO@d0b>3H101iNGT40861P@D0QXJ6101jNWX508J6QP@0UIFE101dM7@5
08B4Q0@0Ng]k1@24Q8@807inOPD0PX:2101iNGT40820P0D0RXZ:101YJFT508f=S@@0OGem101oOgl5
08J6QP@0QHF51@2=SHd408V9R@@0QhN71@23Ph<408B4Q0D0P820101iNGT407YjNPD0O7al1022PX85
07alO0@0MgMg2@1oOgl907alO0@0QHF5101QHF4508Z:RP@0Ph>31@1mOGd407]kN`@0Ogmo1@1aLG44
07inOPD0QhN71020P80908>3P`@0Q8B41@1jNWX407]kN`@0QXJ61@1kNg/408B4Q0D0QhN7101nOWh4
07moO`D0N7Qh101kNg/40861P@D0O7al5P38h=P001D0b>3H1@22PX8408b<S0@0K6a/1@1mOGd40861
P@D0Lg=c102?Shl407moO`D0Ti>C101iNGT50820P0@0OGem2@20P804092@T0D0Rh^;101IFET409^K
V`D0Lg=c102IVIT407MgM`D0RXZ:101eMGD507moO`@0RXZ:101iNGT507moO`@0OGem2@20P80407al
O0D0Ogmo1021PH4507]kN`@0N7Qh101lO7`508F5Q@@0Ng]k1@1nOWh408R8R0@0NGUi1@1oOgl40861
P@D0OWin101jNWX408V9R@D0O7al1022PX8507YjNP@0RXZ:101dM7@509RHV0@0QhN71@24Q8@40820
P0T0NWYj101oOgl508>3P`@0O7al1022PX850820P0@0O7al1@1mOGd=0<SPf0@0NGUi1021PH4508J6
QP@0NWYj1@26QXH409FEU@@0M7Ad1@24Q8@407]kN`D0Q8B4201nOWh508:2PP@0NGUi1020P80508Z:
RP@0JFUY1@2=SHd407emO@@0Ogmo1@26QXH408F5Q@D0SHf=1029RHT408N7Q`D0Ph>31024Q8@50820
P0@0NGUi101jNWX507alO0@0PX:21@1lO7`407MgM`T0Ogmo2@1lO7`408F5Q@@0HF5Q1@2:RXX408>3
P`D0OGem101kNg/407moO`D0LG5a101nOWh508N7Q`@0P8202@23Ph<408B4Q0D0NWYj101kNg/408J6
QPD0Ng]k1024Q8@508N7Q`@0OWin101oOgl507QhN0@0Ng]k1021PH4507alO1H0b>3H000E0<SPf0D0
PX:2102<S8`406a/K0D0OGem1021PH4507=cL`@0Shn?101oOgl509>CT`@0NGUi1@20P80407emO@T0
P820102@T90508^;R`@0FEUI102KVi/507=cL`@0VIVI101gMgL508Z:RP@0MGEe1@1oOgl408Z:RP@0
NGUi1@1oOgl407emO@T0P820101lO7`507moO`@0PH611@1kNg/407QhN0@0O7al1@25QHD407]kN`D0
OWin1028R8P407UiN@D0Ogmo1021PH4507inOP@0NWYj1029RHT507alO0@0PX:21@1jNWX408Z:RP@0
M7Ad1@2HV9P408N7Q`D0Q8B41020P80907YjNP@0Ogmo1@23Ph<407alO0@0PX:21@20P80407alO0D0
OGem3@38h=P407UiN@@0PH611@26QXH407YjNPD0QXJ6102EUID407AdM0D0Q8B4101kNg/508B4Q0P0
OWin1@22PX8407UiN@@0P8201@2:RXX406UYJ@D0SHf=101mOGd407moO`D0QXJ61025QHD508f=S@@0
RHV91027QhL508>3P`@0Q8B41@20P80407UiN@@0NWYj1@1lO7`408:2PPD0O7al101gMgL907moO`T0
O7al1025QHD4065QH@D0RXZ:1023Ph<507emO@@0Ng]k101oOgl5075aL@@0OWin1@27QhL40820P0T0
Ph>31024Q8@507YjNP@0Ng]k1026QXH507]kN`@0Q8B41@27QhL407inOP@0Ogmo1@1hN7P407]kN`@0
PH611@1lO7`F0<SPf0005@38h=P508:2PP@0S8b<101/K6`507emO@@0PH611@1cLg<408n?S`@0Ogmo
1@2CTi<407UiN@D0P820101mOGd90820P0@0T92@1@2;Rh/405UIF@@0Vi^K1@1cLg<409VIV@@0MgMg
1@2:RXX407EeM@D0Ogmo102:RXX407UiN@D0Ogmo101mOGd90820P0@0O7al1@1oOgl40861P@D0Ng]k
101hN7P407alO0D0QHF5101kNg/507inOP@0R8R8101iNGT507moO`@0PH611@1nOWh407YjNP@0RHV9
1@1lO7`408:2PPD0NWYj102:RXX407AdM0D0V9RH1027QhL508B4Q0@0P8202@1jNWX407moO`D0Ph>3
101lO7`408:2PPD0P820101lO7`507emO@d0b>3H101iNGT40861P@D0QXJ6101jNWX508J6QP@0UIFE
101dM7@508B4Q0@0Ng]k1@24Q8@807inOPD0PX:2101iNGT40820P0D0RXZ:101YJFT508f=S@@0OGem
101oOgl508J6QP@0QHF51@2=SHd408V9R@@0QhN71@23Ph<408B4Q0D0P820101iNGT407YjNPD0O7al
1022PX8507alO0@0MgMg2@1oOgl907alO0@0QHF5101QHF4508Z:RP@0Ph>31@1mOGd407]kN`@0Ogmo
1@1aLG4407inOPD0QhN71020P80908>3P`@0Q8B41@1jNWX407]kN`@0QXJ61@1kNg/408B4Q0D0QhN7
101nOWh407moO`D0N7Qh101kNg/40861P@D0O7al5P38h=P001D0b>3H1@1mOGd408F5Q@@0KVi^1@20
P80408^;R`D0GEeM102=SHd406e]K@D0SHf=101^KVh507moO`@0NGUi1027QhL508J6QP@0O7al1@20
P80406IVIP@0[:b/1@1BDU84096AT@@0Shn?1@1mOGd408N7Q`D0L71`1027QhL408J6QPD0LG5a1029
RHT507UiN@@0Q8B41021PH4507inOP@0Q8B41@22PX8407inOP@0P8201@1lO7`408F5Q@D0P820101k
Ng/408J6QPD0Ng]k101oOgl507inOP@0P820102;Rh/507]kN`@0PH612@1mOGd908:2PP@0Ng]k1@20
P80408>3P`@0OWin1@24Q8@407UiN@D0P8201022PX8407emO@D0Q8B4101oOgl507]kN`d0b>3H1023
Ph<408V9R@D0Kfm_101cLg<509RHV0@0J6QX101nOWh507IfMP@0RHV91@25QHD807moO`D0P820101e
MGD4092@T0D0GemO1028R8P507YjNP@0P820102:RXX507inOP@0Kfm_1@1eMGD406m_K`@0L71`1@23
Ph<407MgM`D0O7al1029RHT407inOPD0QHF52@1nOWh407YjNP@0Ogmo1@2<S8`408>3P`D0N7Qh101m
OGd407QhN0D0M7Ad1028R8P507alO0@0Ogmo101mOGd508J6QP@0OGem1@21PH4407emO@@0O7al1@25
QHD4075aL@D0Lg=c1021PH4408b<S0D0Ogmo101nOWh50820P0@0Ph>3101nOWh508>3P`@0Ogmo1023
Ph<50820P1H0b>3H000E0<SPf0D0OGem1025QHD406i^KPD0P820102;Rh/505eMG@@0SHf=101]KFd5
08f=S@@0KVi^1@1oOgl407UiN@@0QhN71@26QXH407alO0D0P820101VIVH40:b/[0D0DU9B102ATI44
08n?S`D0OGem1027QhL5071`L0@0QhN71026QXH5075aL@@0RHV91@1iNGT408B4Q0@0PH611@1nOWh4
08B4Q0D0PX:2101nOWh40820P0D0O7al1025QHD50820P0@0Ng]k1026QXH507]kN`@0Ogmo1@1nOWh4
0820P0@0Rh^;1@1kNg/40861P@T0OGem2@22PX8407]kN`D0P8201023Ph<407inOPD0Q8B4101iNGT5
0820P0@0PX:2101mOGd508B4Q0@0Ogmo1@1kNg/=0<SPf0@0Ph>31029RHT506m_K`@0Lg=c1@2HV9P4
06QXJ0@0OWin1@1fMWH408V9R@D0QHF5201oOgl50820P0@0MGEe102@T90505mOG`@0R8R81@1jNWX4
0820P0@0RXZ:1@1nOWh406m_K`D0MGEe101_Kfl4071`L0D0Ph>3101gMgL507alO0@0RHV9101nOWh5
08F5Q@T0OWin101jNWX407moO`D0S8b<1023Ph<507QhN0@0OGem101hN7P507AdM0@0R8R81@1lO7`4
07moO`@0OGem1@26QXH407emO@D0PH61101mOGd407alO0D0QHF5101aLG4507=cL`@0PH61102<S8`5
07moO`@0OWin1@20P80408>3P`@0OWin1@23Ph<407moO`@0Ph>31@20P80F0<SPf0005@38h=P507em
O@@0QHF5101^KVh50820P0@0Rh^;1@1MGEd408f=S@@0KFe]1@2=SHd406i^KPD0Ogmo101iNGT408N7
Q`D0QXJ6101lO7`50820P0@0IVIV102/[:`5059BDP@0TI6A102?Shl507emO@@0QhN71@1`L70408N7
Q`@0QXJ61@1aLG4408V9R@D0NGUi1024Q8@40861P@D0OWin1024Q8@508:2PP@0OWin1020P80507al
O0@0QHF51@20P80407]kN`@0QXJ61@1kNg/407moO`D0OWin1020P80408^;R`D0Ng]k1021PH4907em
O@T0PX:2101kNg/50820P0@0Ph>3101nOWh508B4Q0@0NGUi1@20P80408:2PP@0OGem1@24Q8@407mo
O`D0Ng]k3@38h=P408>3P`@0RHV91@1_Kfl407=cL`D0V9RH101XJ6P407inOPD0MWIf1029RHT508F5
Q@P0Ogmo1@20P80407EeM@@0T92@1@1OGel408R8R0D0NWYj1020P80408Z:RPD0OWin101_Kfl507Ee
M@@0Kfm_101`L70508>3P`@0MgMg1@1lO7`408V9R@@0OWin1@25QHD907inOP@0NWYj101oOgl508b<
S0@0Ph>31@1hN7P407emO@@0N7Qh1@1dM7@408R8R0D0O7al101oOgl407emO@D0QXJ6101mOGd50861
P@@0OGem101lO7`508F5Q@@0LG5a1@1cLg<40861P@@0S8b<1@1oOgl407inOPD0P8201023Ph<407in
OPD0Ph>3101oOgl408>3P`D0P8205P38h=P001D0b>3H1@1mOGd408F5Q@@0KVi^1@20P80408^;R`D0
GEeM102=SHd406e]K@D0SHf=101^KVh507moO`@0NGUi1027QhL508J6QP@0O7al1@20P80406IVIP@0
[:b/1@1BDU84096AT@@0Shn?1@1mOGd408N7Q`D0L71`1027QhL408J6QPD0LG5a1029RHT507UiN@@0
Q8B41021PH4507inOP@0Q8B41@22PX8407inOP@0P8201@1lO7`408F5Q@D0P820101kNg/408J6QPD0
Ng]k101oOgl507inOP@0P820102;Rh/507]kN`@0PH612@1mOGd908:2PP@0Ng]k1@20P80408>3P`@0
OWin1@24Q8@407UiN@D0P8201022PX8407emO@D0Q8B4101oOgl507]kN`d0b>3H1023Ph<408V9R@D0
Kfm_101cLg<509RHV0@0J6QX101nOWh507IfMP@0RHV91@25QHD807moO`D0P820101eMGD4092@T0D0
GemO1028R8P507YjNP@0P820102:RXX507inOP@0Kfm_1@1eMGD406m_K`@0L71`1@23Ph<407MgM`D0
O7al1029RHT407inOPD0QHF52@1nOWh407YjNP@0Ogmo1@2<S8`408>3P`D0N7Qh101mOGd407QhN0D0
M7Ad1028R8P507alO0@0Ogmo101mOGd508J6QP@0OGem1@21PH4407emO@@0O7al1@25QHD4075aL@D0
Lg=c1021PH4408b<S0D0Ogmo101nOWh50820P0@0Ph>3101nOWh508>3P`@0Ogmo1023Ph<50820P1H0
b>3H000E0<SPf0D0P8201027QhL407UiN@D0SXj>101oOgl507emO@@0MWIf1022PX8507inOP@0MWIf
1@27QhL408F5Q@@0MgMg1@27QhL406m_K`D0O7al1028R8P40;^k^`D0Hf=S102@T90408b<S0D0N7Qh
102=SHd507inOP@0JFUY1026QXH508Z:RP@0MGEe1@28R8P40861P@@0PX:21@1nOWh407YjNPD0Ph>3
101jNWX407alO0D0NGUi1024Q8@507inOP@0Q8B4101jNWX508N7Q`T0P8201023Ph<407inOPD0PX:2
101oOgl507inOP@0P8201022PX850861P@@0P8201@1oOgl407inOP@0P8201@1oOgl407alO0D0Ogmo
1021PH4907emO@T0P8203@38h=P407alO0@0Shn?2@24Q8@507MgM`@0KFe]1025QHD508V9R@@0R8R8
1@1kNg/407alO0@0Ogmo1@2;Rh/408R8R0@0Ogmo1@26QXH407MgM`D0O7al1027QhL40820P0D0Ogmo
1022PX850861P@@0P820102?Shl507moO`@0OWin1@27QhL406m_K`@0RHV91@21PH440820P0D0OWin
1020P80407inOPD0PX:21028R8P508:2PP@0Ogmo1021PH4507IfMP@0QhN71@1lO7`40820P0@0Q8B4
1@1lO7`407moO`D0Ng]k1020P80407YjNPD0RXZ:1020P8050861P@@0Ph>31024Q8@507]kN`@0P820
1@25QHD408:2PP@0Ng]k1@21PH440820P0@0Q8B41@1hN7PF0<SPf0005@38h=P50820P0@0QhN7101i
NGT508j>SP@0Ogmo1@1mOGd407IfMP@0PX:21@1nOWh407IfMPD0QhN71025QHD407MgM`D0QhN7101_
Kfl507alO0@0R8R8102k^k/506=SH`@0T92@102<S8`507QhN0@0SHf=1@1nOWh406UYJ@@0QXJ61@2:
RXX407EeM@D0R8R81021PH4408:2PPD0OWin101jNWX508>3P`@0NWYj101lO7`507UiN@@0Q8B41@1n
OWh408B4Q0@0NWYj1@27QhL90820P0@0Ph>3101nOWh508:2PP@0Ogmo1@1nOWh40820P0@0PX:21@21
PH440820P0D0Ogmo101nOWh40820P0D0Ogmo101lO7`507moO`@0PH612@1mOGd90820P0d0b>3H101l
O7`408n?S`T0Q8B41@1gMgL406e]K@@0QHF51@29RHT408R8R0D0Ng]k101lO7`407moO`D0Rh^;1028
R8P407moO`D0QXJ6101gMgL507alO0@0QhN71020P80507moO`@0PX:21@21PH440820P0@0Shn?1@1o
Ogl407inOPD0QhN7101_Kfl408V9R@D0PH611020P80507inOP@0P820101nOWh508:2PP@0R8R81@22
PX8407moO`@0PH611@1fMWH408N7Q`D0O7al1020P80408B4Q0D0O7al101oOgl507]kN`@0P820101j
NWX508Z:RP@0P8201@21PH4408>3P`@0Q8B41@1kNg/40820P0D0QHF51022PX8407]kN`D0PH611020
P80408B4Q0D0N7Qh5P38h=P001D0b>3H1@20P80408N7Q`@0NGUi1@2>SXh407moO`D0OGem101fMWH4
08:2PPD0OWin101fMWH508N7Q`@0QHF5101gMgL508N7Q`@0Kfm_1@1lO7`408R8R0@0^k^k1@1SHf<4
092@T0@0S8b<1@1hN7P408f=S@D0OWin101YJFT408J6QPD0RXZ:101eMGD508R8R0@0PH611022PX85
07inOP@0NWYj1@23Ph<407YjNP@0O7al1@1iNGT408B4Q0D0OWin1024Q8@407YjNPD0QhN72@20P804
08>3P`@0OWin1@22PX8407moO`D0OWin1020P80408:2PPD0PH611020P80507moO`@0OWin1020P805
07moO`@0O7al1@1oOgl40861P@T0OGem2@20P80=0<SPf0@0O7al102?Shl908B4Q0D0MgMg101]KFd4
08F5Q@D0RHV91028R8P507]kN`@0O7al101oOgl508^;R`@0R8R8101oOgl508J6QP@0MgMg1@1lO7`4
08N7Q`@0P8201@1oOgl408:2PPD0PH611020P80408n?S`D0Ogmo101nOWh508N7Q`@0Kfm_1029RHT5
0861P@@0P8201@1nOWh40820P0@0OWin1@22PX8408R8R0D0PX:2101oOgl40861P@D0MWIf1027QhL5
07alO0@0P8201024Q8@507alO0@0Ogmo1@1kNg/40820P0@0NWYj1@2:RXX40820P0D0PH611023Ph<4
08B4Q0D0Ng]k1020P80508F5Q@@0PX:2101kNg/50861P@@0P8201024Q8@507QhN1H0b>3H000E0<SP
f0D0P8201027QhL407UiN@D0SXj>101oOgl507emO@@0MWIf1022PX8507inOP@0MWIf1@27QhL408F5
Q@@0MgMg1@27QhL406m_K`D0O7al1028R8P40;^k^`D0Hf=S102@T90408b<S0D0N7Qh102=SHd507in
OP@0JFUY1026QXH508Z:RP@0MGEe1@28R8P40861P@@0PX:21@1nOWh407YjNPD0Ph>3101jNWX407al
O0D0NGUi1024Q8@507inOP@0Q8B4101jNWX508N7Q`T0P8201023Ph<407inOPD0PX:2101oOgl507in
OP@0P8201022PX850861P@@0P8201@1oOgl407inOP@0P8201@1oOgl407alO0D0Ogmo1021PH4907em
O@T0P8203@38h=P407alO0@0Shn?2@24Q8@507MgM`@0KFe]1025QHD508V9R@@0R8R81@1kNg/407al
O0@0Ogmo1@2;Rh/408R8R0@0Ogmo1@26QXH407MgM`D0O7al1027QhL40820P0D0Ogmo1022PX850861
P@@0P820102?Shl507moO`@0OWin1@27QhL406m_K`@0RHV91@21PH440820P0D0OWin1020P80407in
OPD0PX:21028R8P508:2PP@0Ogmo1021PH4507IfMP@0QhN71@1lO7`40820P0@0Q8B41@1lO7`407mo
O`D0Ng]k1020P80407YjNPD0RXZ:1020P8050861P@@0Ph>31024Q8@507]kN`@0P8201@25QHD408:2
PP@0Ng]k1@21PH440820P0@0Q8B41@1hN7PF0<SPf0005@38h=P50820P0@0QhN7101iNGT508j>SP@0
Ogmo1@1mOGd407IfMP@0PX:21@1nOWh407IfMPD0QhN71025QHD407MgM`D0QhN7101_Kfl507alO0@0
R8R8102k^k/506=SH`@0T92@102<S8`507QhN0@0SHf=1@1nOWh406UYJ@@0QXJ61@2:RXX407EeM@D0
R8R81021PH4408:2PPD0OWin101jNWX508>3P`@0NWYj101lO7`507UiN@@0Q8B41@1nOWh408B4Q0@0
NWYj1@27QhL90820P0@0Ph>3101nOWh508:2PP@0Ogmo1@1nOWh40820P0@0PX:21@21PH440820P0D0
Ogmo101nOWh40820P0D0Ogmo101lO7`507moO`@0PH612@1mOGd90820P0d0b>3H101lO7`408n?S`T0
Q8B41@1gMgL406e]K@@0QHF51@29RHT408R8R0D0Ng]k101lO7`407moO`D0Rh^;1028R8P407moO`D0
QXJ6101gMgL507alO0@0QhN71020P80507moO`@0PX:21@21PH440820P0@0Shn?1@1oOgl407inOPD0
QhN7101_Kfl408V9R@D0PH611020P80507inOP@0P820101nOWh508:2PP@0R8R81@22PX8407moO`@0
PH611@1fMWH408N7Q`D0O7al1020P80408B4Q0D0O7al101oOgl507]kN`@0P820101jNWX508Z:RP@0
P8201@21PH4408>3P`@0Q8B41@1kNg/40820P0D0QHF51022PX8407]kN`D0PH611020P80408B4Q0D0
N7Qh5P38h=P001D0b>3H2@28R8P407moO`D0PX:2101iNGT507moO`@0MWIf1024Q8@50861P@T0P820
101oOgl407UiN@D0TI6A101hN7P507YjNP@0TI6A102XZ:P508V9R@@0U9BD1024Q8@507]kN`@0OGem
1@2GUiL4075aL@@0N7Qh1@26QXH408:2PPD0LW9b1027QhL40820P0D0QHF5101oOgl507inOP@0O7al
101mOGd507alO0@0Ogmo1@20P80407inOP@0QHF51@1kNg/40820P0D0Q8B41021PH440820P0D0OGem
1025QHD=07YjNPD0PH612@20P80407moO`T0OGem2@1nOWh40820P0@0Ogmo1@23Ph<40820P0D0Ng]k
3@38h=P407moO`@0NWYj1@28R8P407alO0D0MgMg1025QHD408:2PPD0MgMg101mOGd507QhN0@0MWIf
1027QhL507]kN`@0QhN7101fMWH508:2PP@0MgMg1@1eMGD407emO@@0QhN71@1jNWX40820P0D0Q8B4
102<S8`409nOW`D0U9BD101hN7P507IfMP@0U9BD101dM7@507]kN`@0QhN71@21PH4407inOP@0Ng]k
1@1mOGd407]kN`D0PX:2101nOWh408:2PPD0Q8B4101dM7@509^KV`@0EeMG1026QXH508:2PP@0MWIf
1@27QhL407emO@@0O7al1@1gMgL40820P0D0QhN7101lO7`407QhN0D0QhN71020P80907alO0@0P820
1@25QHD40820P0@0Q8B41@1mOGdF0<SPf0005@38h=P908R8R0@0Ogmo1@22PX8407UiN@D0Ogmo101f
MWH408B4Q0D0PH612@20P80407moO`@0NGUi1@2ATI4407QhN0D0NWYj102ATI440:RXZ0D0RHV9102D
U9@408B4Q0D0Ng]k101mOGd509NGU`@0LG5a101hN7P508J6QP@0PX:21@1bLW8408N7Q`@0P8201@25
QHD407moO`D0OWin101lO7`407emO@D0O7al101oOgl50820P0@0OWin1025QHD507]kN`@0P8201@24
Q8@40861P@@0P8201@1mOGd408F5Q@d0NWYj1@21PH490820P0@0Ogmo2@1mOGd907inOP@0P820101o
Ogl508>3P`@0P8201@1kNg/=0<SPf0@0Ogmo101jNWX508R8R0@0O7al1@1gMgL408F5Q@@0PX:21@1g
MgL407emO@D0N7Qh101fMWH408N7Q`D0Ng]k1027QhL407IfMPD0PX:2101gMgL507EeM@@0OGem1027
QhL507YjNP@0P8201@24Q8@408b<S0@0WinO1@2DU9@407QhN0D0MWIf102DU9@407AdM0D0Ng]k1027
QhL50861P@@0OWin101kNg/507emO@@0Ng]k1@22PX8407inOP@0PX:21@24Q8@407AdM0D0Vi^K101G
EeL408J6QPD0PX:2101fMWH508N7Q`@0OGem101lO7`507MgM`@0P8201@27QhL407alO0@0N7Qh1@27
QhL40820P0T0O7al1020P80508F5Q@@0P8201024Q8@507emOAH0b>3H000E0<SPf0T0R8R8101oOgl5
08:2PP@0NGUi1@1oOgl407IfMP@0Q8B41@21PH490820P0@0Ogmo101iNGT5096AT@@0N7Qh1@1jNWX4
096AT@@0Z:RX1@29RHT409BDU0@0Q8B41@1kNg/407emO@D0UiNG101aLG4407QhN0D0QXJ61022PX85
079bLP@0QhN71020P80508F5Q@@0Ogmo1@1nOWh407alO0@0OGem1@1lO7`407moO`D0P820101nOWh4
08F5Q@D0Ng]k1020P80508B4Q0@0PH611020P80507emO@@0QHF53@1jNWX50861P@T0P820101oOgl9
07emO@T0OWin1020P80407moO`D0Ph>31020P80507]kN`d0b>3H101oOgl407YjNPD0R8R8101lO7`5
07MgM`@0QHF51022PX8507MgM`@0OGem1@1hN7P407IfMP@0QhN71@1kNg/408N7Q`@0MWIf1@22PX84
07MgM`D0MGEe101mOGd408N7Q`D0NWYj1020P80508B4Q0@0S8b<102OWil509BDU0@0N7Qh1@1fMWH4
09BDU0@0M7Ad1@1kNg/408N7Q`D0PH61101nOWh407]kN`D0OGem101kNg/508:2PP@0OWin1022PX85
08B4Q0@0M7Ad1@2KVi/405MGE`@0QXJ61@22PX8407IfMPD0QhN7101mOGd407alO0D0MgMg1020P805
08N7Q`@0O7al101hN7P508N7Q`@0P8202@1lO7`40820P0D0QHF51020P80408B4Q0D0OGem5P38h=P0
01D0b>3H2@28R8P407moO`D0PX:2101iNGT507moO`@0MWIf1024Q8@50861P@T0P820101oOgl407Ui
N@D0TI6A101hN7P507YjNP@0TI6A102XZ:P508V9R@@0U9BD1024Q8@507]kN`@0OGem1@2GUiL4075a
L@@0N7Qh1@26QXH408:2PPD0LW9b1027QhL40820P0D0QHF5101oOgl507inOP@0O7al101mOGd507al
O0@0Ogmo1@20P80407inOP@0QHF51@1kNg/40820P0D0Q8B41021PH440820P0D0OGem1025QHD=07Yj
NPD0PH612@20P80407moO`T0OGem2@1nOWh40820P0@0Ogmo1@23Ph<40820P0D0Ng]k3@38h=P407mo
O`@0NWYj1@28R8P407alO0D0MgMg1025QHD408:2PPD0MgMg101mOGd507QhN0@0MWIf1027QhL507]k
N`@0QhN7101fMWH508:2PP@0MgMg1@1eMGD407emO@@0QhN71@1jNWX40820P0D0Q8B4102<S8`409nO
W`D0U9BD101hN7P507IfMP@0U9BD101dM7@507]kN`@0QhN71@21PH4407inOP@0Ng]k1@1mOGd407]k
N`D0PX:2101nOWh408:2PPD0Q8B4101dM7@509^KV`@0EeMG1026QXH508:2PP@0MWIf1@27QhL407em
O@@0O7al1@1gMgL40820P0D0QhN7101lO7`407QhN0D0QhN71020P80907alO0@0P8201@25QHD40820
P0@0Q8B41@1mOGdF0<SPf0005@38h=P508J6QP@0O7al1025QHD507inOP@0PH611@2;Rh/406i^KP@0
Q8B41@21PH4407alO0D0PH61101oOgl407EeM@D0VIVI101jNWX507alO0@0TY:B101oOgl508V9R@@0
T92@101EEED508F5Q@@0O7al1@1oOgl408V9R@@0LG5a1@27QhL40820P0D0MWIf1021PH4907inOP@0
PX:22@23Ph<408B4Q0D0PH611022PX850820P0@0QHF52@21PH4408>3P`D0NWYj1025QHD408:2PPD0
MWIf101hN7P507alO0@0PH611023Ph<507emO@d0OWin1024Q8@507alO0@0P8201@1oOgl407alO0@0
P8201@21PH4407alO0D0NWYj3@38h=P408V9R@@0MGEe1@24Q8@407IfMPD0RXZ:101jNWX408R8R0D0
Rh^;1020P80508:2PP@0PH61101nOWh508F5Q@@0PX:2101aLG4507UiN@@0Ph>31@2DU9@408V9R@@0
OWin1@2>SXh408^;R`D0S8b<101iNGT406m_K`D0LW9b101jNWX508R8R0@0OGem1028R8P507IfMP@0
Q8B41@21PH4408:2PP@0Rh^;1@21PH4407inOPD0NWYj101oOgl407emO@D0PH61101iNGT507YjNP@0
P8201026QXH50820P0@0QXJ61@22PX8807moO`D0QHF5101lO7`507moO`@0NWYj1025QHD507moO`@0
NWYj1@20P80408:2PP@0MgMg1@1lO7`407moO`@0PH611@20P80F0<SPf0005@38h=P508J6QP@0O7al
1025QHD507inOP@0PH611@2;Rh/406i^KP@0Q8B41@21PH4407alO0D0PH61101oOgl407EeM@D0VIVI
101jNWX507alO0@0TY:B101oOgl508V9R@@0T92@101EEED508F5Q@@0O7al1@1oOgl408V9R@@0LG5a
1@27QhL40820P0D0MWIf1021PH4907inOP@0PX:22@23Ph<408B4Q0D0PH611022PX850820P0@0QHF5
2@21PH4408>3P`D0NWYj1025QHD408:2PPD0MWIf101hN7P507alO0@0PH611023Ph<507emO@d0OWin
1024Q8@507alO0@0P8201@1oOgl407alO0@0P8201@21PH4407alO0D0NWYj3@38h=P408V9R@@0MGEe
1@24Q8@407IfMPD0RXZ:101jNWX408R8R0D0Rh^;1020P80508:2PP@0PH61101nOWh508F5Q@@0PX:2
101aLG4507UiN@@0Ph>31@2DU9@408V9R@@0OWin1@2>SXh408^;R`D0S8b<101iNGT406m_K`D0LW9b
101jNWX508R8R0@0OGem1028R8P507IfMP@0Q8B41@21PH4408:2PP@0Rh^;1@21PH4407inOPD0NWYj
101oOgl407emO@D0PH61101iNGT507YjNP@0P8201026QXH50820P0@0QXJ61@22PX8807moO`D0QHF5
101lO7`507moO`@0NWYj1025QHD507moO`@0NWYj1@20P80408:2PP@0MgMg1@1lO7`407moO`@0PH61
1@20P80F0<SPf0005@38h=P508J6QP@0O7al1025QHD507inOP@0PH611@2;Rh/406i^KP@0Q8B41@21
PH4407alO0D0PH61101oOgl407EeM@D0VIVI101jNWX507alO0@0TY:B101oOgl508V9R@@0T92@101E
EED508F5Q@@0O7al1@1oOgl408V9R@@0LG5a1@27QhL40820P0D0MWIf1021PH4907inOP@0PX:22@23
Ph<408B4Q0D0PH611022PX850820P0@0QHF52@21PH4408>3P`D0NWYj1025QHD408:2PPD0MWIf101h
N7P507alO0@0PH611023Ph<507emO@d0OWin1024Q8@507alO0@0P8201@1oOgl407alO0@0P8201@21
PH4407alO0D0NWYj3@38h=P408V9R@@0MGEe1@24Q8@407IfMPD0RXZ:101jNWX408R8R0D0Rh^;1020
P80508:2PP@0PH61101nOWh508F5Q@@0PX:2101aLG4507UiN@@0Ph>31@2DU9@408V9R@@0OWin1@2>
SXh408^;R`D0S8b<101iNGT406m_K`D0LW9b101jNWX508R8R0@0OGem1028R8P507IfMP@0Q8B41@21
PH4408:2PP@0Rh^;1@21PH4407inOPD0NWYj101oOgl407emO@D0PH61101iNGT507YjNP@0P8201026
QXH50820P0@0QXJ61@22PX8807moO`D0QHF5101lO7`507moO`@0NWYj1025QHD507moO`@0NWYj1@20
P80408:2PP@0MgMg1@1lO7`407moO`@0PH611@20P80F0<SPf0005@38h=P508J6QP@0O7al1025QHD5
07inOP@0PH611@2;Rh/406i^KP@0Q8B41@21PH4407alO0D0PH61101oOgl407EeM@D0VIVI101jNWX5
07alO0@0TY:B101oOgl508V9R@@0T92@101EEED508F5Q@@0O7al1@1oOgl408V9R@@0LG5a1@27QhL4
0820P0D0MWIf1021PH4907inOP@0PX:22@23Ph<408B4Q0D0PH611022PX850820P0@0QHF52@21PH44
08>3P`D0NWYj1025QHD408:2PPD0MWIf101hN7P507alO0@0PH611023Ph<507emO@d0OWin1024Q8@5
07alO0@0P8201@1oOgl407alO0@0P8201@21PH4407alO0D0NWYj3@38h=P408V9R@@0MGEe1@24Q8@4
07IfMPD0RXZ:101jNWX408R8R0D0Rh^;1020P80508:2PP@0PH61101nOWh508F5Q@@0PX:2101aLG45
07UiN@@0Ph>31@2DU9@408V9R@@0OWin1@2>SXh408^;R`D0S8b<101iNGT406m_K`D0LW9b101jNWX5
08R8R0@0OGem1028R8P507IfMP@0Q8B41@21PH4408:2PP@0Rh^;1@21PH4407inOPD0NWYj101oOgl4
07emO@D0PH61101iNGT507YjNP@0P8201026QXH50820P0@0QXJ61@22PX8807moO`D0QHF5101lO7`5
07moO`@0NWYj1025QHD507moO`@0NWYj1@20P80408:2PP@0MgMg1@1lO7`407moO`@0PH611@20P80F
0<SPf0005@38h=P508:2PP@0L71`1024Q8@50861P@@0QXJ61@1cLg<408V9R@@0Ogmo1@23Ph<407in
OPD0Ogmo101iNGT407]kN`D0Ti>C101<C4`508>3P`@0QhN7101dM7@509FEU@@0PH61101^KVh50:NW
Y`@0NGUi1@1mOGd408F5Q@@0PX:21@1cLg<408:2PPD0RHV9101gMgL408B4Q0D0N7Qh101jNWX507em
O@P0O7al1@1oOgl407alO0D0P820101oOgl407YjNPD0PH61101mOGd90820P0@0PH611@1kNg/407em
O@D0Q8B41021PH4407inOPD0PH611023Ph<507UiN@@0PX:2101oOgl50861P@@0OWin1@20P80407in
OP@0O7al1@24Q8@40861P@D0P8203@38h=P40861P@@0OGem1@1eMGD408Z:RPD0MGEe1021PH4406AT
I0D0UIFE101kNg/50820P0@0R8R8101hN7P508>3P`@0PX:21025QHD508b<S0@0Ogmo1@1aLG4407in
OP@0MGEe1@1^KVh405UIF@D0QXJ61024Q8@407moO`D0N7Qh101/K6`507UiN@@0QHF5101cLg<50861
P@@0Ogmo1@1iNGT407alO0@0PX:21@1oOgl408>3P`D0PX:2101kNg/40861P@T0PX:21@1nOWh408V9
R@@0OGem1@20P80407EeM@D0OWin1021PH4407inOPD0Q8B41020P80507inOP@0P8201023Ph<507Yj
NP@0N7Qh1@20P80407inOPT0O7al1023Ph<407]kN`D0OGem5P38h=P001D0b>3H1@22PX84071`L0@0
Q8B41@21PH4408J6QPD0Lg=c1029RHT407moO`D0Ph>3101nOWh507moO`@0NGUi101kNg/509>CT`@0
C4a<1@23Ph<408N7Q`@0M7Ad1@2EUID40861P@@0KVi^1@2WYjL407UiN@D0OGem1025QHD408:2PPD0
Lg=c1022PX8508V9R@@0MgMg1024Q8@507QhN0@0NWYj1@1mOGd807alO0D0Ogmo101lO7`50820P0@0
Ogmo101jNWX50861P@@0OGem2@20P8040861P@D0Ng]k101mOGd508B4Q0@0PH61101nOWh50861P@@0
Ph>31@1iNGT408:2PP@0Ogmo1@21PH4407inOPD0P820101nOWh407alO0D0Q8B41021PH450820P0d0
b>3H1021PH4407emO@D0MGEe102:RXX507EeM@@0PH61101TI6@509FEU@@0Ng]k1@20P80408R8R0@0
N7Qh1@23Ph<408:2PP@0QHF51@2<S8`407moO`D0LG5a101nOWh407EeM@D0KVi^101IFET508J6QP@0
Q8B4101oOgl507QhN0@0K6a/1@1iNGT408F5Q@@0Lg=c1@21PH4407moO`D0NGUi101lO7`408:2PPD0
Ogmo1023Ph<508:2PP@0Ng]k1021PH4908:2PPD0OWin1029RHT407emO@D0P820101eMGD507inOP@0
PH61101nOWh508B4Q0@0P8201@1nOWh40820P0@0Ph>31@1jNWX407QhN0D0P820101nOWh907alO0@0
Ph>3101kNg/507emOAH0b>3H000E0<SPf0D0PX:2101`L70408B4Q0D0PH611026QXH507=cL`@0RHV9
101oOgl508>3P`@0OWin1@1oOgl407UiN@@0Ng]k1@2CTi<404a<C0D0Ph>31027QhL407AdM0D0UIFE
1021PH4406i^KPD0YjNW101iNGT507emO@@0QHF51022PX8507=cL`@0PX:21@29RHT407MgM`@0Q8B4
1@1hN7P407YjNPD0OGem201lO7`507moO`@0O7al1@20P80407moO`@0NWYj1@21PH4407emO@T0P820
1021PH4507]kN`@0OGem1@24Q8@40861P@@0OWin1@21PH4408>3P`D0NGUi1022PX8407moO`D0PH61
101nOWh50820P0@0OWin101lO7`508B4Q0@0PH611@20P80=0<SPf0@0PH61101mOGd507EeM@@0RXZ:
1@1eMGD40861P@@0I6AT1@2EUID407]kN`D0P8201028R8P407QhN0D0Ph>31022PX8408F5Q@D0S8b<
101oOgl5075aL@@0OWin101eMGD506i^KP@0FEUI1@26QXH408B4Q0@0Ogmo1@1hN7P406a/K0D0NGUi
1025QHD407=cL`D0PH61101oOgl507UiN@@0O7al1022PX8507moO`@0Ph>31@22PX8407]kN`@0PH61
2@22PX8507inOP@0RHV9101mOGd50820P0@0MGEe1@1nOWh40861P@@0OWin1@24Q8@40820P0D0OWin
1020P80408>3P`D0NWYj101hN7P50820P0@0OWin2@1lO7`408>3P`@0Ng]k1@1mOGdF0<SPf0005@38
h=P508:2PP@0L71`1024Q8@50861P@@0QXJ61@1cLg<408V9R@@0Ogmo1@23Ph<407inOPD0Ogmo101i
NGT407]kN`D0Ti>C101<C4`508>3P`@0QhN7101dM7@509FEU@@0PH61101^KVh50:NWY`@0NGUi1@1m
OGd408F5Q@@0PX:21@1cLg<408:2PPD0RHV9101gMgL408B4Q0D0N7Qh101jNWX507emO@P0O7al1@1o
Ogl407alO0D0P820101oOgl407YjNPD0PH61101mOGd90820P0@0PH611@1kNg/407emO@D0Q8B41021
PH4407inOPD0PH611023Ph<507UiN@@0PX:2101oOgl50861P@@0OWin1@20P80407inOP@0O7al1@24
Q8@40861P@D0P8203@38h=P40861P@@0OGem1@1eMGD408Z:RPD0MGEe1021PH4406ATI0D0UIFE101k
Ng/50820P0@0R8R8101hN7P508>3P`@0PX:21025QHD508b<S0@0Ogmo1@1aLG4407inOP@0MGEe1@1^
KVh405UIF@D0QXJ61024Q8@407moO`D0N7Qh101/K6`507UiN@@0QHF5101cLg<50861P@@0Ogmo1@1i
NGT407alO0@0PX:21@1oOgl408>3P`D0PX:2101kNg/40861P@T0PX:21@1nOWh408V9R@@0OGem1@20
P80407EeM@D0OWin1021PH4407inOPD0Q8B41020P80507inOP@0P8201023Ph<507YjNP@0N7Qh1@20
P80407inOPT0O7al1023Ph<407]kN`D0OGem5P38h=P001D0b>3H1@22PX84071`L0@0Q8B41@21PH44
08J6QPD0Lg=c1029RHT407moO`D0Ph>3101nOWh507moO`@0NGUi101kNg/509>CT`@0C4a<1@23Ph<4
08N7Q`@0M7Ad1@2EUID40861P@@0KVi^1@2WYjL407UiN@D0OGem1025QHD408:2PPD0Lg=c1022PX85
08V9R@@0MgMg1024Q8@507QhN0@0NWYj1@1mOGd807alO0D0Ogmo101lO7`50820P0@0Ogmo101jNWX5
0861P@@0OGem2@20P8040861P@D0Ng]k101mOGd508B4Q0@0PH61101nOWh50861P@@0Ph>31@1iNGT4
08:2PP@0Ogmo1@21PH4407inOPD0P820101nOWh407alO0D0Q8B41021PH450820P0d0b>3H1021PH44
07emO@D0MGEe102:RXX507EeM@@0PH61101TI6@509FEU@@0Ng]k1@20P80408R8R0@0N7Qh1@23Ph<4
08:2PP@0QHF51@2<S8`407moO`D0LG5a101nOWh407EeM@D0KVi^101IFET508J6QP@0Q8B4101oOgl5
07QhN0@0K6a/1@1iNGT408F5Q@@0Lg=c1@21PH4407moO`D0NGUi101lO7`408:2PPD0Ogmo1023Ph<5
08:2PP@0Ng]k1021PH4908:2PPD0OWin1029RHT407emO@D0P820101eMGD507inOP@0PH61101nOWh5
08B4Q0@0P8201@1nOWh40820P0@0Ph>31@1jNWX407QhN0D0P820101nOWh907alO0@0Ph>3101kNg/5
07emOAH0b>3H000E0<SPf0D0MgMg1027QhL409:BTPD0O7al101mOGd508R8R0@0KFe]1021PH4908R8
R0D0NWYj101fMWH408>3P`D0R8R8101HF5P509FEU@@0QHF5101fMWH509^KV`@0L71`102NWYh5069R
HP@0T92@1@1lO7`408:2PP@0SHf=1@1fMWH408R8R0D0PH611029RHT406m_K`D0RHV9101mOGd507mo
O`@0PX:21020P8050861P@@0NGUi1@1mOGd408:2PP@0NGUi1@1kNg/408J6QPD0MWIf1023Ph<408:2
PPD0O7al1022PX8507inOP@0O7al101nOWh50861P@T0PX:2101oOgl407inOPD0Ng]k1023Ph<50820
P0@0OWin1020P8050861P@@0PX:21@1kNg/=0<SPf0@0O7al101oOgl507inOP@0LG5a1@1iNGT408V9
R@@0RXZ:1@2?Shl40861P@T0MgMg1025QHD508R8R0@0OWin101]KFd507emO@@0Ogmo1@1nOWh406m_
K`@0QHF51@24Q8@408b<S0D0KFe]101oOgl408J6QPD0Ogmo1023Ph<5079bLP@0Q8B4101nOWh507Ee
M@@0Ng]k1@21PH4407alO0@0PH611@24Q8@40820P0D0PX:2101oOgl407UiN@D0OWin1022PX8907in
OP@0Ph>31@20P80407alO0D0OGem101oOgl407emO@D0Ph>3101lO7`908J6QP@0PX:21@1nOWh408>3
P`D0QHF5101nOWh408:2PPD0P8201021PH4407inOPD0P8205P38h=P001D0b>3H1@1gMgL408N7Q`@0
TY:B1@1lO7`407emO@D0R8R8101]KFd40861P@T0R8R81@1jNWX407IfMP@0Ph>31@28R8P405QHF0D0
UIFE1025QHD407IfMPD0Vi^K101`L70409jNWPD0HV9R102@T90507alO0@0PX:2102=SHd507IfMP@0
R8R81@21PH4408V9R@@0Kfm_1@29RHT407emO@D0Ogmo1022PX840820P0D0PH61101iNGT507emO@@0
PX:2101iNGT507]kN`@0QXJ61@1fMWH408>3P`@0PX:21@1lO7`408:2PPD0OWin101lO7`407inOPD0
PH612@22PX8407moO`@0OWin1@1kNg/408>3P`D0P820101nOWh40820P0D0PH611022PX8507]kN`d0
b>3H101lO7`407moO`D0OWin101aLG4507UiN@@0RHV9102:RXX508n?S`@0PH612@1gMgL408F5Q@D0
R8R8101nOWh406e]K@D0OGem101oOgl507inOP@0Kfm_1025QHD508B4Q0@0S8b<1@1]KFd407moO`@0
QXJ61@1oOgl408>3P`D0LW9b1024Q8@407inOPD0MGEe101kNg/50861P@@0O7al1021PH4508B4Q0@0
P8201@22PX8407moO`@0NGUi1@1nOWh408:2PPT0OWin1023Ph<50820P0@0O7al1@1mOGd407moO`@0
OGem1@23Ph<407alO0T0QXJ61022PX8507inOP@0Ph>31@25QHD407inOP@0PX:21@20P8040861P@@0
OWin1@20P80F0<SPf0005@38h=P507MgM`@0QhN7102BTY8507alO0@0OGem1@28R8P406e]K@@0PH61
2@28R8P507YjNP@0MWIf1023Ph<508R8R0@0F5QH1@2EUID408F5Q@@0MWIf1@2KVi/4071`L0@0WYjN
1@1RHV84092@T0D0O7al1022PX8408f=S@D0MWIf1028R8P50861P@@0RHV9101_Kfl508V9R@@0OGem
1@1oOgl408:2PP@0P8201@21PH4407UiN@D0OGem1022PX8407UiN@D0Ng]k1026QXH507IfMP@0Ph>3
1022PX8507alO0@0PX:21@1nOWh407alO0@0OWin1@21PH4908:2PP@0Ogmo101nOWh507]kN`@0Ph>3
1@20P80407inOP@0P8201@21PH4408:2PPD0Ng]k3@38h=P407alO0@0Ogmo1@1nOWh4075aL@D0NGUi
1029RHT408Z:RPD0Shn?1021PH4907MgM`@0QHF51@28R8P407inOP@0KFe]1@1mOGd407moO`D0OWin
101_Kfl408F5Q@D0Q8B4102<S8`506e]K@@0Ogmo1026QXH507moO`@0Ph>31@1bLW8408B4Q0@0OWin
1@1eMGD407]kN`D0PH61101lO7`40861P@D0Q8B41020P80508:2PP@0Ogmo101iNGT507inOP@0PX:2
2@1nOWh408>3P`D0P820101lO7`507emO@@0Ogmo101mOGd508>3P`@0O7al2@26QXH408:2PPD0OWin
1023Ph<508F5Q@@0OWin1022PX850820P0@0PH61101nOWh50820P1H0b>3H000E0<SPf0D0MgMg1027
QhL409:BTPD0O7al101mOGd508R8R0@0KFe]1021PH4908R8R0D0NWYj101fMWH408>3P`D0R8R8101H
F5P509FEU@@0QHF5101fMWH509^KV`@0L71`102NWYh5069RHP@0T92@1@1lO7`408:2PP@0SHf=1@1f
MWH408R8R0D0PH611029RHT406m_K`D0RHV9101mOGd507moO`@0PX:21020P8050861P@@0NGUi1@1m
OGd408:2PP@0NGUi1@1kNg/408J6QPD0MWIf1023Ph<408:2PPD0O7al1022PX8507inOP@0O7al101n
OWh50861P@T0PX:2101oOgl407inOPD0Ng]k1023Ph<50820P0@0OWin1020P8050861P@@0PX:21@1k
Ng/=0<SPf0@0O7al101oOgl507inOP@0LG5a1@1iNGT408V9R@@0RXZ:1@2?Shl40861P@T0MgMg1025
QHD508R8R0@0OWin101]KFd507emO@@0Ogmo1@1nOWh406m_K`@0QHF51@24Q8@408b<S0D0KFe]101o
Ogl408J6QPD0Ogmo1023Ph<5079bLP@0Q8B4101nOWh507EeM@@0Ng]k1@21PH4407alO0@0PH611@24
Q8@40820P0D0PX:2101oOgl407UiN@D0OWin1022PX8907inOP@0Ph>31@20P80407alO0D0OGem101o
Ogl407emO@D0Ph>3101lO7`908J6QP@0PX:21@1nOWh408>3P`D0QHF5101nOWh408:2PPD0P8201021
PH4407inOPD0P8205P38h=P001D0b>3H1@1JFUX408f=S@@0KVi^1@24Q8@40820P0D0NGUi1020P804
07IfMPD0SHf=101gMgL508:2PP@0OGem1023Ph<907emO@D0VIVI1026QXH408j>SPD0OWin101kNg/4
07YjNPD0OWin1023Ph<507inOPP0Ogmo1@23Ph<407IfMPD0PX:2101mOGd408F5Q@D0LW9b102;Rh/5
07YjNP@0PX:21021PH4507inOP@0N7Qh1@22PX880820P0D0PX:2102:RXX5079bLP@0OWin1029RHT5
0820P0@0PH611@20P8040861P@@0OGem1@20P8040861P@D0PX:21023Ph<40861P@D0Ph>31020P805
07moO`@0PX:2101nOWh508>3P`@0P8201@1kNg/=0<SPf0@0NGUi101]KFd508:2PP@0PH611@22PX84
07moO`@0PX:21@2=SHd408B4Q0D0O7al1027QhL407YjNPD0P820101lO7`407UiN@D0QXJ6101oOgl5
07IfMP@0NWYj101hN7P508f=S@@0LW9b1@27QhL408:2PP@0O7al1@1mOGd408f=S@D0UYJF102ATI44
08Z:RPD0Ph>31025QHD507QhN0@0PX:2101oOgl50861P@@0OWin1@23Ph<407moO`@0OWin2@22PX85
08Z:RP@0Q8B4101hN7P508>3P`@0OGem1@1nOWh408J6QP@0Ogmo1@20P80407]kN`D0P820101kNg/4
08F5Q@D0QhN71022PX8507inOP@0O7al1023Ph<508J6QP@0P820101nOWh507alO1H0b>3H000E0<SP
f0D0FUYJ102=SHd406i^KPD0Q8B41020P80507UiN@@0P820101fMWH508f=S@@0MgMg1@22PX8407em
O@@0Ph>32@1mOGd509VIV@@0QXJ6102>SXh507inOP@0Ng]k101jNWX507inOP@0Ph>31@1nOWh807mo
O`D0Ph>3101fMWH508:2PP@0OGem1025QHD5079bLP@0Rh^;1@1jNWX408:2PP@0PH611@1nOWh407Qh
N0D0PX:22020P80508:2PP@0RXZ:1@1bLW8407inOP@0RHV91@20P8040861P@D0P8201021PH4407em
O@D0P8201021PH4508:2PP@0Ph>31021PH4508>3P`@0P8201@1oOgl408:2PP@0OWin1@23Ph<40820
P0D0Ng]k3@38h=P407UiN@@0KFe]1@22PX840861P@D0PX:2101oOgl408:2PPD0SHf=1024Q8@507al
O0@0QhN7101jNWX50820P0@0O7al101iNGT508J6QP@0Ogmo1@1fMWH407YjNP@0N7Qh1@2=SHd4079b
LPD0QhN71022PX8407alO0D0OGem102=SHd509JFUP@0TI6A102:RXX508>3P`@0QHF51@1hN7P408:2
PP@0Ogmo1@21PH4407inOPD0Ph>3101oOgl407inOPT0PX:21@2:RXX408B4Q0@0N7Qh1@23Ph<407em
O@D0OWin1026QXH407moO`D0P820101kNg/50820P0@0Ng]k1025QHD508N7Q`@0PX:21@1nOWh407al
O0@0Ph>31@26QXH40820P0@0OWin1@1lO7`F0<SPf0005@38h=P505YJFP@0SHf=101^KVh508B4Q0@0
P8201@1iNGT40820P0@0MWIf1@2=SHd407MgM`D0PX:2101mOGd408>3P`T0OGem1@2IVIT408J6QP@0
SXj>1@1nOWh407]kN`@0NWYj1@1nOWh408>3P`D0OWin201oOgl508>3P`@0MWIf1@22PX8407emO@@0
QHF51@1bLW8408^;R`D0NWYj1022PX840861P@D0OWin101hN7P508:2PPP0P8201@22PX8408Z:RPD0
LW9b101nOWh408V9R@D0P8201021PH450820P0@0PH61101mOGd50820P0@0PH611@22PX8408>3P`@0
PH611@23Ph<40820P0D0Ogmo1022PX8407inOPD0Ph>31020P80507]kN`d0b>3H101iNGT406e]K@D0
PX:21021PH4508:2PP@0Ogmo1022PX8508f=S@@0Q8B41@1lO7`408N7Q`@0NWYj1@20P80407alO0@0
NGUi1@26QXH407moO`D0MWIf101jNWX407QhN0D0SHf=101bLW8508N7Q`@0PX:2101lO7`507emO@@0
SHf=1@2FUYH4096AT@@0RXZ:1@23Ph<408F5Q@D0N7Qh1022PX8407moO`D0PH61101nOWh508>3P`@0
Ogmo101nOWh908:2PPD0RXZ:1024Q8@407QhN0D0Ph>3101mOGd507inOP@0QXJ6101oOgl50820P0@0
Ng]k1@20P80407]kN`@0QHF51@27QhL408:2PPD0OWin101lO7`408>3P`D0QXJ61020P80407inOPD0
O7al5P38h=P001D0b>3H1@1JFUX408f=S@@0KVi^1@24Q8@40820P0D0NGUi1020P80407IfMPD0SHf=
101gMgL508:2PP@0OGem1023Ph<907emO@D0VIVI1026QXH408j>SPD0OWin101kNg/407YjNPD0OWin
1023Ph<507inOPP0Ogmo1@23Ph<407IfMPD0PX:2101mOGd408F5Q@D0LW9b102;Rh/507YjNP@0PX:2
1021PH4507inOP@0N7Qh1@22PX880820P0D0PX:2102:RXX5079bLP@0OWin1029RHT50820P0@0PH61
1@20P8040861P@@0OGem1@20P8040861P@D0PX:21023Ph<40861P@D0Ph>31020P80507moO`@0PX:2
101nOWh508>3P`@0P8201@1kNg/=0<SPf0@0NGUi101]KFd508:2PP@0PH611@22PX8407moO`@0PX:2
1@2=SHd408B4Q0D0O7al1027QhL407YjNPD0P820101lO7`407UiN@D0QXJ6101oOgl507IfMP@0NWYj
101hN7P508f=S@@0LW9b1@27QhL408:2PP@0O7al1@1mOGd408f=S@D0UYJF102ATI4408Z:RPD0Ph>3
1025QHD507QhN0@0PX:2101oOgl50861P@@0OWin1@23Ph<407moO`@0OWin2@22PX8508Z:RP@0Q8B4
101hN7P508>3P`@0OGem1@1nOWh408J6QP@0Ogmo1@20P80407]kN`D0P820101kNg/408F5Q@D0QhN7
1022PX8507inOP@0O7al1023Ph<508J6QP@0P820101nOWh507alO1H0b>3H000E0<SPf0T0QXJ6101g
MgL50861P@@0RXZ:1@1WIfL408B4Q0@0PX:21@1gMgL408F5Q@D0PX:2101kNg/407=cL`D0NGUi102=
SHd508B4Q0@0Ogmo102IVIT506m_K`@0QHF5101cLg<908B4Q0D0OWin101mOGd408j>SPD0FEUI102?
Shl506m_K`@0Ph>31021PH4508j>SP@0M7Ad1@21PH4408F5Q@@0P8202@1kNg/507moO`@0Ng]k101n
OWh508J6QP@0TY:B1@1VIVH408>3P`T0OWin101oOgl50820P0P0O7al1@1nOWh408>3P`d0OGem1@1l
O7`408:2PPT0PH611022PX850861P@@0Q8B41@1mOGd=0<SPf0@0NWYj1029RHT507UiN@@0QHF51@1/
K6`4071`L0@0MGEe1@1fMWH408b<S0D0MgMg101eMGD407QhN0D0QHF51027QhL407inOPD0MgMg101k
Ng/50820P0@0PH61101/K6`507IfMP@0Ph>31@27QhL408:2PP@0PH611@1nOWh408J6QPD0JVYZ101a
LG4407inOPD0PH61101jNWX509nOW`@0Kfm_1024Q8@90861P@D0O7al101oOgl407]kN`D0PH61101k
Ng/507emO@@0PH611023Ph<507moO`@0PH611@28R8P408:2PP@0NWYj1@1oOgl408F5Q@D0N7Qh1023
Ph<408N7Q`D0OWin1021PH4507inOP@0O7al101kNg/508>3P`@0O7al1023Ph<507YjNQH0b>3H000E
0<SPf0T0QXJ6101gMgL50861P@@0RXZ:1@1WIfL408B4Q0@0PX:21@1gMgL408F5Q@D0PX:2101kNg/4
07=cL`D0NGUi102=SHd508B4Q0@0Ogmo102IVIT506m_K`@0QHF5101cLg<908B4Q0D0OWin101mOGd4
08j>SPD0FEUI102?Shl506m_K`@0Ph>31021PH4508j>SP@0M7Ad1@21PH4408F5Q@@0P8202@1kNg/5
07moO`@0Ng]k101nOWh508J6QP@0TY:B1@1VIVH408>3P`T0OWin101oOgl50820P0P0O7al1@1nOWh4
08>3P`d0OGem1@1lO7`408:2PPT0PH611022PX850861P@@0Q8B41@1mOGd=0<SPf0@0NWYj1029RHT5
07UiN@@0QHF51@1/K6`4071`L0@0MGEe1@1fMWH408b<S0D0MgMg101eMGD407QhN0D0QHF51027QhL4
07inOPD0MgMg101kNg/50820P0@0PH61101/K6`507IfMP@0Ph>31@27QhL408:2PP@0PH611@1nOWh4
08J6QPD0JVYZ101aLG4407inOPD0PH61101jNWX509nOW`@0Kfm_1024Q8@90861P@D0O7al101oOgl4
07]kN`D0PH61101kNg/507emO@@0PH611023Ph<507moO`@0PH611@28R8P408:2PP@0NWYj1@1oOgl4
08F5Q@D0N7Qh1023Ph<408N7Q`D0OWin1021PH4507inOP@0O7al101kNg/508>3P`@0O7al1023Ph<5
07YjNQH0b>3H000E0<SPf0T0QXJ6101gMgL50861P@@0RXZ:1@1WIfL408B4Q0@0PX:21@1gMgL408F5
Q@D0PX:2101kNg/407=cL`D0NGUi102=SHd508B4Q0@0Ogmo102IVIT506m_K`@0QHF5101cLg<908B4
Q0D0OWin101mOGd408j>SPD0FEUI102?Shl506m_K`@0Ph>31021PH4508j>SP@0M7Ad1@21PH4408F5
Q@@0P8202@1kNg/507moO`@0Ng]k101nOWh508J6QP@0TY:B1@1VIVH408>3P`T0OWin101oOgl50820
P0P0O7al1@1nOWh408>3P`d0OGem1@1lO7`408:2PPT0PH611022PX850861P@@0Q8B41@1mOGd=0<SP
f0@0NWYj1029RHT507UiN@@0QHF51@1/K6`4071`L0@0MGEe1@1fMWH408b<S0D0MgMg101eMGD407Qh
N0D0QHF51027QhL407inOPD0MgMg101kNg/50820P0@0PH61101/K6`507IfMP@0Ph>31@27QhL408:2
PP@0PH611@1nOWh408J6QPD0JVYZ101aLG4407inOPD0PH61101jNWX509nOW`@0Kfm_1024Q8@90861
P@D0O7al101oOgl407]kN`D0PH61101kNg/507emO@@0PH611023Ph<507moO`@0PH611@28R8P408:2
PP@0NWYj1@1oOgl408F5Q@D0N7Qh1023Ph<408N7Q`D0OWin1021PH4507inOP@0O7al101kNg/508>3
P`@0O7al1023Ph<507YjNQH0b>3H000E0<SPf0T0QXJ6101gMgL50861P@@0RXZ:1@1WIfL408B4Q0@0
PX:21@1gMgL408F5Q@D0PX:2101kNg/407=cL`D0NGUi102=SHd508B4Q0@0Ogmo102IVIT506m_K`@0
QHF5101cLg<908B4Q0D0OWin101mOGd408j>SPD0FEUI102?Shl506m_K`@0Ph>31021PH4508j>SP@0
M7Ad1@21PH4408F5Q@@0P8202@1kNg/507moO`@0Ng]k101nOWh508J6QP@0TY:B1@1VIVH408>3P`T0
OWin101oOgl50820P0P0O7al1@1nOWh408>3P`d0OGem1@1lO7`408:2PPT0PH611022PX850861P@@0
Q8B41@1mOGd=0<SPf0@0NWYj1029RHT507UiN@@0QHF51@1/K6`4071`L0@0MGEe1@1fMWH408b<S0D0
MgMg101eMGD407QhN0D0QHF51027QhL407inOPD0MgMg101kNg/50820P0@0PH61101/K6`507IfMP@0
Ph>31@27QhL408:2PP@0PH611@1nOWh408J6QPD0JVYZ101aLG4407inOPD0PH61101jNWX509nOW`@0
Kfm_1024Q8@90861P@D0O7al101oOgl407]kN`D0PH61101kNg/507emO@@0PH611023Ph<507moO`@0
PH611@28R8P408:2PP@0NWYj1@1oOgl408F5Q@D0N7Qh1023Ph<408N7Q`D0OWin1021PH4507inOP@0
O7al101kNg/508>3P`@0O7al1023Ph<507YjNQH0b>3H000E0<SPf0T0QXJ6101gMgL50861P@@0RXZ:
1@1WIfL408B4Q0@0PX:21@1gMgL408F5Q@D0PX:2101kNg/407=cL`D0NGUi102=SHd508B4Q0@0Ogmo
102IVIT506m_K`@0QHF5101cLg<908B4Q0D0OWin101mOGd408j>SPD0FEUI102?Shl506m_K`@0Ph>3
1021PH4508j>SP@0M7Ad1@21PH4408F5Q@@0P8202@1kNg/507moO`@0Ng]k101nOWh508J6QP@0TY:B
1@1VIVH408>3P`T0OWin101oOgl50820P0P0O7al1@1nOWh408>3P`d0OGem1@1lO7`408:2PPT0PH61
1022PX850861P@@0Q8B41@1mOGd=0<SPf0@0NWYj1029RHT507UiN@@0QHF51@1/K6`4071`L0@0MGEe
1@1fMWH408b<S0D0MgMg101eMGD407QhN0D0QHF51027QhL407inOPD0MgMg101kNg/50820P0@0PH61
101/K6`507IfMP@0Ph>31@27QhL408:2PP@0PH611@1nOWh408J6QPD0JVYZ101aLG4407inOPD0PH61
101jNWX509nOW`@0Kfm_1024Q8@90861P@D0O7al101oOgl407]kN`D0PH61101kNg/507emO@@0PH61
1023Ph<507moO`@0PH611@28R8P408:2PP@0NWYj1@1oOgl408F5Q@D0N7Qh1023Ph<408N7Q`D0OWin
1021PH4507inOP@0O7al101kNg/508>3P`@0O7al1023Ph<507YjNQH0b>3H000E0<SPf0D0PH61101i
NGT407emO@D0QXJ6101^KVh5096AT@P0Ph>31@1kNg/408B4Q0D0PX:2101nOWh407=cL`D0O7al102;
Rh/506YZJP@0PX:2102;Rh/507moO`@0MWIf102PX:05075aL@@0OGem1@1kNg/407emO@@0W9bL1@1c
Lg<409NGU`D0N7Qh101gMgL408f=S@D0MgMg101oOgl507alO0@0Ng]k101mOGd50861P@@0OGem1@25
QHD407inOP@0N7Qh1@2JVYX409:BTPD0IFEU1023Ph<40861P@D0O7al2@1oOgl40861P@@0MgMg1@29
RHT40861P@D0QHF51024Q8@407alO0D0PH61101oOgl508:2PP@0Ph>31022PX8507YjNP@0Ph>31@1i
NGT=0<SPf0@0NWYj1022PX8508F5Q@@0M7Ad1@27QhL407inOP@0P8201@1fMWH407UiN@D0SHf=1024
Q8@40861P@D0Shn?1020P80908>3P`@0P8201@2=SHd40820P0@0Q8B41@1kNg/408V9R@T0P8202@26
QXH908Z:RP@0LG5a101ZJVX506a/K0@0R8R81@1eMGD409^KV`@0M7Ad1@22PX840820P0D0QXJ6101i
NGT407moO`D0P820101lO7`508F5Q@@0OWin1025QHD50820P0@0QHF51@1iNGT407inOP@0PX:21@1f
MWH408J6QPD0OWin101oOgl408B4Q0D0Ng]k101nOWh507emO@@0O7al1021PH4507IfMP@0Q8B4101h
N7P507YjNQH0b>3H000E0<SPf0D0PH61101iNGT407emO@D0QXJ6101^KVh5096AT@P0Ph>31@1kNg/4
08B4Q0D0PX:2101nOWh407=cL`D0O7al102;Rh/506YZJP@0PX:2102;Rh/507moO`@0MWIf102PX:05
075aL@@0OGem1@1kNg/407emO@@0W9bL1@1cLg<409NGU`D0N7Qh101gMgL408f=S@D0MgMg101oOgl5
07alO0@0Ng]k101mOGd50861P@@0OGem1@25QHD407inOP@0N7Qh1@2JVYX409:BTPD0IFEU1023Ph<4
0861P@D0O7al2@1oOgl40861P@@0MgMg1@29RHT40861P@D0QHF51024Q8@407alO0D0PH61101oOgl5
08:2PP@0Ph>31022PX8507YjNP@0Ph>31@1iNGT=0<SPf0@0NWYj1022PX8508F5Q@@0M7Ad1@27QhL4
07inOP@0P8201@1fMWH407UiN@D0SHf=1024Q8@40861P@D0Shn?1020P80908>3P`@0P8201@2=SHd4
0820P0@0Q8B41@1kNg/408V9R@T0P8202@26QXH908Z:RP@0LG5a101ZJVX506a/K0@0R8R81@1eMGD4
09^KV`@0M7Ad1@22PX840820P0D0QXJ6101iNGT407moO`D0P820101lO7`508F5Q@@0OWin1025QHD5
0820P0@0QHF51@1iNGT407inOP@0PX:21@1fMWH408J6QPD0OWin101oOgl408B4Q0D0Ng]k101nOWh5
07emO@@0O7al1021PH4507IfMP@0Q8B4101hN7P507YjNQH0b>3H000E0<SPf0D0PH61101iNGT407em
O@D0QXJ6101^KVh5096AT@P0Ph>31@1kNg/408B4Q0D0PX:2101nOWh407=cL`D0O7al102;Rh/506YZ
JP@0PX:2102;Rh/507moO`@0MWIf102PX:05075aL@@0OGem1@1kNg/407emO@@0W9bL1@1cLg<409NG
U`D0N7Qh101gMgL408f=S@D0MgMg101oOgl507alO0@0Ng]k101mOGd50861P@@0OGem1@25QHD407in
OP@0N7Qh1@2JVYX409:BTPD0IFEU1023Ph<40861P@D0O7al2@1oOgl40861P@@0MgMg1@29RHT40861
P@D0QHF51024Q8@407alO0D0PH61101oOgl508:2PP@0Ph>31022PX8507YjNP@0Ph>31@1iNGT=0<SP
f0@0NWYj1022PX8508F5Q@@0M7Ad1@27QhL407inOP@0P8201@1fMWH407UiN@D0SHf=1024Q8@40861
P@D0Shn?1020P80908>3P`@0P8201@2=SHd40820P0@0Q8B41@1kNg/408V9R@T0P8202@26QXH908Z:
RP@0LG5a101ZJVX506a/K0@0R8R81@1eMGD409^KV`@0M7Ad1@22PX840820P0D0QXJ6101iNGT407mo
O`D0P820101lO7`508F5Q@@0OWin1025QHD50820P0@0QHF51@1iNGT407inOP@0PX:21@1fMWH408J6
QPD0OWin101oOgl408B4Q0D0Ng]k101nOWh507emO@@0O7al1021PH4507IfMP@0Q8B4101hN7P507Yj
NQH0b>3H000E0<SPf0D0PH61101iNGT407emO@D0QXJ6101^KVh5096AT@P0Ph>31@1kNg/408B4Q0D0
PX:2101nOWh407=cL`D0O7al102;Rh/506YZJP@0PX:2102;Rh/507moO`@0MWIf102PX:05075aL@@0
OGem1@1kNg/407emO@@0W9bL1@1cLg<409NGU`D0N7Qh101gMgL408f=S@D0MgMg101oOgl507alO0@0
Ng]k101mOGd50861P@@0OGem1@25QHD407inOP@0N7Qh1@2JVYX409:BTPD0IFEU1023Ph<40861P@D0
O7al2@1oOgl40861P@@0MgMg1@29RHT40861P@D0QHF51024Q8@407alO0D0PH61101oOgl508:2PP@0
Ph>31022PX8507YjNP@0Ph>31@1iNGT=0<SPf0@0NWYj1022PX8508F5Q@@0M7Ad1@27QhL407inOP@0
P8201@1fMWH407UiN@D0SHf=1024Q8@40861P@D0Shn?1020P80908>3P`@0P8201@2=SHd40820P0@0
Q8B41@1kNg/408V9R@T0P8202@26QXH908Z:RP@0LG5a101ZJVX506a/K0@0R8R81@1eMGD409^KV`@0
M7Ad1@22PX840820P0D0QXJ6101iNGT407moO`D0P820101lO7`508F5Q@@0OWin1025QHD50820P0@0
QHF51@1iNGT407inOP@0PX:21@1fMWH408J6QPD0OWin101oOgl408B4Q0D0Ng]k101nOWh507emO@@0
O7al1021PH4507IfMP@0Q8B4101hN7P507YjNQH0b>3H000E0<SPf0D0P8201023Ph<40820P0D0SHf=
101fMWH507QhN0@0MGEe1026QXH508B4Q0@0Lg=c1@21PH4408:2PP@0OGem1@1iNGT408>3P`D0NGUi
1029RHT408B4Q0D0Ph>3101KFe/40:b/[0D0Shn?101bLW8508:2PP@0RHV9101IFET508R8R0@0O7al
1@2=SHd407UiN@@0K6a/1@23Ph<407inOPD0NWYj101oOgl40861P@D0QHF51023Ph<507YjNP@0Ng]k
101hN7P509FEU@@0Q8B41@1_Kfl408B4Q0@0Ph>31@1oOgl40820P0T0OGem1024Q8@50820P0@0PH61
1@1mOGd407]kN`@0NWYj1@1kNg/90861P@@0Ph>3101oOgl507inOP@0PH611@1lO7`=0<SPf0@0OWin
102>SXh50861P@@0Ng]k2@1mOGd407UiN@D0OGem1028R8P507IfMP@0MGEe1026QXH507MgM`@0Shn?
101mOGd507moO`@0PX:21@20P80407YjNPT0OWin101oOgl507UiN@@0R8R81025QHD506m_K`@0QHF5
1@1oOgl408Z:RP@0M7Ad1@1cLg<406i^KPD0QhN7101XJ6P408b<S0D0L71`2@1nOWh408B4Q0T0Ph>3
101nOWh908J6QPT0Ogmo1021PH4507inOP@0P8201021PH4508N7Q`@0Ng]k1@2CTi<407QhN0@0PX:2
2@20P80507inOP@0Ogmo101mOGd507moO`@0N7Qh101oOgl50820P1H0b>3H000E0<SPf0D0P8201023
Ph<40820P0D0SHf=101fMWH507QhN0@0MGEe1026QXH508B4Q0@0Lg=c1@21PH4408:2PP@0OGem1@1i
NGT408>3P`D0NGUi1029RHT408B4Q0D0Ph>3101KFe/40:b/[0D0Shn?101bLW8508:2PP@0RHV9101I
FET508R8R0@0O7al1@2=SHd407UiN@@0K6a/1@23Ph<407inOPD0NWYj101oOgl40861P@D0QHF51023
Ph<507YjNP@0Ng]k101hN7P509FEU@@0Q8B41@1_Kfl408B4Q0@0Ph>31@1oOgl40820P0T0OGem1024
Q8@50820P0@0PH611@1mOGd407]kN`@0NWYj1@1kNg/90861P@@0Ph>3101oOgl507inOP@0PH611@1l
O7`=0<SPf0@0OWin102>SXh50861P@@0Ng]k2@1mOGd407UiN@D0OGem1028R8P507IfMP@0MGEe1026
QXH507MgM`@0Shn?101mOGd507moO`@0PX:21@20P80407YjNPT0OWin101oOgl507UiN@@0R8R81025
QHD506m_K`@0QHF51@1oOgl408Z:RP@0M7Ad1@1cLg<406i^KPD0QhN7101XJ6P408b<S0D0L71`2@1n
OWh408B4Q0T0Ph>3101nOWh908J6QPT0Ogmo1021PH4507inOP@0P8201021PH4508N7Q`@0Ng]k1@2C
Ti<407QhN0@0PX:22@20P80507inOP@0Ogmo101mOGd507moO`@0N7Qh101oOgl50820P1H0b>3H000E
0<SPf0D0P8201023Ph<40820P0D0SHf=101fMWH507QhN0@0MGEe1026QXH508B4Q0@0Lg=c1@21PH44
08:2PP@0OGem1@1iNGT408>3P`D0NGUi1029RHT408B4Q0D0Ph>3101KFe/40:b/[0D0Shn?101bLW85
08:2PP@0RHV9101IFET508R8R0@0O7al1@2=SHd407UiN@@0K6a/1@23Ph<407inOPD0NWYj101oOgl4
0861P@D0QHF51023Ph<507YjNP@0Ng]k101hN7P509FEU@@0Q8B41@1_Kfl408B4Q0@0Ph>31@1oOgl4
0820P0T0OGem1024Q8@50820P0@0PH611@1mOGd407]kN`@0NWYj1@1kNg/90861P@@0Ph>3101oOgl5
07inOP@0PH611@1lO7`=0<SPf0@0OWin102>SXh50861P@@0Ng]k2@1mOGd407UiN@D0OGem1028R8P5
07IfMP@0MGEe1026QXH507MgM`@0Shn?101mOGd507moO`@0PX:21@20P80407YjNPT0OWin101oOgl5
07UiN@@0R8R81025QHD506m_K`@0QHF51@1oOgl408Z:RP@0M7Ad1@1cLg<406i^KPD0QhN7101XJ6P4
08b<S0D0L71`2@1nOWh408B4Q0T0Ph>3101nOWh908J6QPT0Ogmo1021PH4507inOP@0P8201021PH45
08N7Q`@0Ng]k1@2CTi<407QhN0@0PX:22@20P80507inOP@0Ogmo101mOGd507moO`@0N7Qh101oOgl5
0820P1H0b>3H000E0<SPf0D0P8201023Ph<40820P0D0SHf=101fMWH507QhN0@0MGEe1026QXH508B4
Q0@0Lg=c1@21PH4408:2PP@0OGem1@1iNGT408>3P`D0NGUi1029RHT408B4Q0D0Ph>3101KFe/40:b/
[0D0Shn?101bLW8508:2PP@0RHV9101IFET508R8R0@0O7al1@2=SHd407UiN@@0K6a/1@23Ph<407in
OPD0NWYj101oOgl40861P@D0QHF51023Ph<507YjNP@0Ng]k101hN7P509FEU@@0Q8B41@1_Kfl408B4
Q0@0Ph>31@1oOgl40820P0T0OGem1024Q8@50820P0@0PH611@1mOGd407]kN`@0NWYj1@1kNg/90861
P@@0Ph>3101oOgl507inOP@0PH611@1lO7`=0<SPf0@0OWin102>SXh50861P@@0Ng]k2@1mOGd407Ui
N@D0OGem1028R8P507IfMP@0MGEe1026QXH507MgM`@0Shn?101mOGd507moO`@0PX:21@20P80407Yj
NPT0OWin101oOgl507UiN@@0R8R81025QHD506m_K`@0QHF51@1oOgl408Z:RP@0M7Ad1@1cLg<406i^
KPD0QhN7101XJ6P408b<S0D0L71`2@1nOWh408B4Q0T0Ph>3101nOWh908J6QPT0Ogmo1021PH4507in
OP@0P8201021PH4508N7Q`@0Ng]k1@2CTi<407QhN0@0PX:22@20P80507inOP@0Ogmo101mOGd507mo
O`@0N7Qh101oOgl50820P1H0b>3H000E0<SPf0D0P8201023Ph<40820P0D0SHf=101fMWH507QhN0@0
MGEe1026QXH508B4Q0@0Lg=c1@21PH4408:2PP@0OGem1@1iNGT408>3P`D0NGUi1029RHT408B4Q0D0
Ph>3101KFe/40:b/[0D0Shn?101bLW8508:2PP@0RHV9101IFET508R8R0@0O7al1@2=SHd407UiN@@0
K6a/1@23Ph<407inOPD0NWYj101oOgl40861P@D0QHF51023Ph<507YjNP@0Ng]k101hN7P509FEU@@0
Q8B41@1_Kfl408B4Q0@0Ph>31@1oOgl40820P0T0OGem1024Q8@50820P0@0PH611@1mOGd407]kN`@0
NWYj1@1kNg/90861P@@0Ph>3101oOgl507inOP@0PH611@1lO7`=0<SPf0@0OWin102>SXh50861P@@0
Ng]k2@1mOGd407UiN@D0OGem1028R8P507IfMP@0MGEe1026QXH507MgM`@0Shn?101mOGd507moO`@0
PX:21@20P80407YjNPT0OWin101oOgl507UiN@@0R8R81025QHD506m_K`@0QHF51@1oOgl408Z:RP@0
M7Ad1@1cLg<406i^KPD0QhN7101XJ6P408b<S0D0L71`2@1nOWh408B4Q0T0Ph>3101nOWh908J6QPT0
Ogmo1021PH4507inOP@0P8201021PH4508N7Q`@0Ng]k1@2CTi<407QhN0@0PX:22@20P80507inOP@0
Ogmo101mOGd507moO`@0N7Qh101oOgl50820P1H0b>3H000E0<SPf0D0PX:2101oOgl407inOPD0NWYj
102@T90507YjNP@0QhN7101lO7`508R8R0@0Q8B41@23Ph<407inOP@0PH611@1mOGd40820P0D0S8b<
101kNg/408F5Q@D0PX:2101`L70407UiN@D0WIfM2@20P8040:2PX0@0EeMG1@1iNGT408:2PPD0NGUi
102;Rh/407IfMPD0NGUi101lO7`508R8R0@0NGUi1020P8050861P@T0QHF51020P8040861P@D0OWin
1025QHD507emO@@0Ph>31021PH4507emO@@0NGUi2@22PX8407alO0D0Ph>3101kNg/507inOP@0QHF5
1020P8050861P@@0Ogmo1@20P80407moO`T0PH612@20P80=0<SPf0@0N7Qh1020P80508^;R`@0NGUi
1@25QHD407inOP@0RXZ:1@20P80407moO`D0S8b<102:RXX407inOPD0R8R8101iNGT4075aL@D0QHF5
1029RHT506m_K`@0Ph>3102=SHd507emO@@0RHV91@1lO7`408F5Q@@0OGem1@2=SHd407UiN@D0OGem
1020P804092@T0D0OGem1023Ph<907emO@@0NGUi1@25QHD408B4Q0D0Ogmo101mOGd40861P@D0MgMg
101kNg/508:2PP@0Ng]k101gMgL508F5Q@@0Ogmo1@20P80407alO0@0P8201@23Ph<407moO`D0PH61
1026QXH407UiN@D0QHF5101nOWh508:2PPP0PH611@1oOgl407inOP@0Ph>31@1jNWXF0<SPf0005@38
h=P508:2PP@0Ogmo101nOWh507YjNP@0T92@1@1jNWX408N7Q`@0O7al1@28R8P408B4Q0D0Ph>3101n
OWh40861P@D0OGem1020P80508b<S0@0Ng]k1025QHD508:2PP@0L71`101iNGT509fMW@T0P820102P
X:0405MGE`D0NGUi1022PX8507UiN@@0Rh^;101fMWH507UiN@@0O7al1@28R8P407UiN@@0P8201@21
PH4908F5Q@@0P8201021PH4507inOP@0QHF51@1mOGd408>3P`@0PH611@1mOGd407UiN@T0PX:2101l
O7`508>3P`@0Ng]k1@1nOWh408F5Q@@0P8201@21PH4407moO`D0P820101oOgl90861P@T0P8203@38
h=P407QhN0@0P8201@2;Rh/407UiN@D0QHF5101nOWh408Z:RPD0P820101oOgl508b<S0@0RXZ:101n
OWh508R8R0@0NGUi101aLG4508F5Q@@0RHV91@1_Kfl408>3P`@0SHf=1@1mOGd408V9R@D0O7al1025
QHD407emO@D0SHf=101iNGT507emO@@0P820102@T90507emO@@0Ph>32@1mOGd407UiN@D0QHF51024
Q8@507moO`@0OGem1021PH4507MgM`@0Ng]k1@22PX8407]kN`@0MgMg1@25QHD407moO`D0P820101l
O7`40820P0D0Ph>3101oOgl50861P@@0QXJ6101iNGT508F5Q@@0OWin1@22PX880861P@D0Ogmo101n
OWh408>3P`D0NWYj5P38h=P001D0b>3H1@22PX8407moO`@0OWin1@1jNWX4092@T0D0NWYj1027QhL4
07alO0D0R8R81024Q8@508>3P`@0OWin1021PH4507emO@@0P8201@2<S8`407]kN`@0QHF51@22PX84
071`L0@0NGUi1@2MWId90820P0@0X:2P101GEeL507UiN@@0PX:21@1iNGT408^;R`@0MWIf1@1iNGT4
07alO0D0R8R8101iNGT40820P0D0PH612@25QHD40820P0@0PH611@1nOWh408F5Q@D0OGem1023Ph<4
0861P@D0OGem101iNGT908:2PP@0O7al1@23Ph<407]kN`D0OWin1025QHD40820P0D0PH61101oOgl5
0820P0@0Ogmo2@21PH490820P0d0b>3H101hN7P40820P0D0Rh^;101iNGT508F5Q@@0OWin102:RXX5
0820P0@0Ogmo1@2<S8`408Z:RP@0OWin1@28R8P407UiN@@0LG5a1@25QHD408V9R@D0Kfm_1023Ph<4
08f=S@D0OGem1029RHT507alO0@0QHF5101mOGd508f=S@@0NGUi1@1mOGd40820P0@0T92@1@1mOGd4
08>3P`T0OGem101iNGT508F5Q@@0Q8B41@1oOgl407emO@@0PH611@1gMgL407]kN`D0PX:2101kNg/4
07MgM`D0QHF5101oOgl50820P0@0O7al1020P80508>3P`@0Ogmo1@21PH4408J6QP@0NGUi1@25QHD4
07inOPD0PX:22021PH4507moO`@0OWin1023Ph<507YjNQH0b>3H000E0<SPf0D0PX:2101oOgl407in
OPD0NWYj102@T90507YjNP@0QhN7101lO7`508R8R0@0Q8B41@23Ph<407inOP@0PH611@1mOGd40820
P0D0S8b<101kNg/408F5Q@D0PX:2101`L70407UiN@D0WIfM2@20P8040:2PX0@0EeMG1@1iNGT408:2
PPD0NGUi102;Rh/407IfMPD0NGUi101lO7`508R8R0@0NGUi1020P8050861P@T0QHF51020P8040861
P@D0OWin1025QHD507emO@@0Ph>31021PH4507emO@@0NGUi2@22PX8407alO0D0Ph>3101kNg/507in
OP@0QHF51020P8050861P@@0Ogmo1@20P80407moO`T0PH612@20P80=0<SPf0@0N7Qh1020P80508^;
R`@0NGUi1@25QHD407inOP@0RXZ:1@20P80407moO`D0S8b<102:RXX407inOPD0R8R8101iNGT4075a
L@D0QHF51029RHT506m_K`@0Ph>3102=SHd507emO@@0RHV91@1lO7`408F5Q@@0OGem1@2=SHd407Ui
N@D0OGem1020P804092@T0D0OGem1023Ph<907emO@@0NGUi1@25QHD408B4Q0D0Ogmo101mOGd40861
P@D0MgMg101kNg/508:2PP@0Ng]k101gMgL508F5Q@@0Ogmo1@20P80407alO0@0P8201@23Ph<407mo
O`D0PH611026QXH407UiN@D0QHF5101nOWh508:2PPP0PH611@1oOgl407inOP@0Ph>31@1jNWXF0<SP
f0005@38h=P508N7Q`@0R8R8101kNg/506i^KP@0RXZ:1@1hN7P407YjNP@0OWin1@1lO7`408R8R0D0
LW9b1024Q8@407alO0D0N7Qh101oOgl50861P@@0MgMg1025QHD507]kN`@0Q8B4101eMGD508B4Q0@0
Ti>C1@26QXH40:2PX0@0De=C1@2FUYH407EeM@T0O7al1023Ph<507=cL`@0QXJ61@20P80408N7Q`@0
LG5a1@25QHD407IfMPD0Ph>31022PX8407QhN0D0PX:2102:RXX507MgM`P0Q8B41@21PH4907emO@@0
QHF5101lO7`507moO`@0Ph>31@1iNGT407alO0T0P820101mOGd507moO`@0Q8B41023Ph<50820P0@0
OGem1@24Q8@=0<SPf0@0P8201028R8P507EeM@@0O7al1@2:RXX408>3P`@0Ng]k1@1jNWX40820P0D0
PH61101oOgl408B4Q0D0MGEe101aLG44071`L0D0Ogmo101mOGd=08>3P`D0M7Ad101ZJVX507YjNP@0
P820101fMWH50820P0@0Ogmo1@23Ph<40861P@@0Ph>31@2<S8`408V9R@D0QXJ6101kNg/408B4Q0D0
P820102:RXX508>3P`@0OGem101gMgL507AdM0@0OWin1@1oOgl40820P0@0Ogmo1@1nOWh407alO0D0
RXZ:201oOgl50861P@@0OWin1@1mOGd40820P0@0R8R81@1iNGT408>3P`D0N7Qh201nOWh507emO@@0
Ng]k101oOgl507]kNaH0b>3H000E0<SPf0D0QhN71028R8P407]kN`D0KVi^102:RXX507QhN0@0NWYj
101nOWh507alO0@0R8R81@1bLW8408B4Q0@0O7al1@1hN7P407moO`D0PH61101gMgL408F5Q@D0Ng]k
1024Q8@407EeM@D0Q8B4102CTi<508J6QP@0X:2P101CDe<509JFUP@0MGEe2@1lO7`408>3P`D0Lg=c
1026QXH50820P0@0QhN7101aLG4508F5Q@@0MWIf1@23Ph<408:2PP@0N7Qh1@22PX8408Z:RPD0MgMg
2024Q8@50861P@T0OGem1025QHD407alO0D0Ogmo1023Ph<507UiN@@0O7al2@20P80407emO@D0Ogmo
1024Q8@408>3P`D0P820101mOGd508B4Q0d0b>3H1020P80408R8R0D0MGEe101lO7`508Z:RP@0Ph>3
101kNg/507YjNP@0P8201@21PH4407moO`@0Q8B41@1eMGD4075aL@@0L71`1@1oOgl407emO@d0Ph>3
1@1dM7@406YZJPD0NWYj1020P80407IfMPD0P820101oOgl508>3P`@0PH611023Ph<508b<S0@0RHV9
1@26QXH407]kN`@0Q8B41@20P80408Z:RPD0Ph>3101mOGd407MgM`D0M7Ad101nOWh507moO`@0P820
101oOgl507inOP@0O7al1@2:RXX807moO`D0PH61101nOWh507emO@@0P8201028R8P507UiN@@0Ph>3
1@1hN7P807inOPD0OGem101kNg/407moO`D0Ng]k5P38h=P001D0b>3H1@27QhL408R8R0@0Ng]k1@1^
KVh408Z:RPD0N7Qh101jNWX407inOPD0O7al1028R8P5079bLP@0Q8B4101lO7`507QhN0@0Ogmo1@21
PH4407MgM`@0QHF51@1kNg/408B4Q0@0MGEe1@24Q8@409>CT`D0QXJ6102PX:0405=CD`D0UYJF101e
MGD907alO0@0Ph>31@1cLg<408J6QPD0P8201027QhL4075aL@D0QHF5101fMWH508>3P`@0PX:2101h
N7P508:2PP@0RXZ:1@1gMgL808B4Q0D0PH612@1mOGd408F5Q@@0O7al1@1oOgl408>3P`D0NGUi101l
O7`90820P0@0OGem1@1oOgl408B4Q0@0Ph>31@20P80407emO@D0Q8B43@38h=P40820P0@0R8R81@1e
MGD407alO0D0RXZ:1023Ph<407]kN`D0NWYj1020P8050861P@@0Ogmo1024Q8@507EeM@@0LG5a101`
L70507moO`@0OGem3@23Ph<507AdM0@0JVYZ1@1jNWX40820P0@0MWIf1@20P80407moO`D0Ph>31021
PH4408>3P`D0S8b<1029RHT508J6QP@0Ng]k1024Q8@50820P0@0RXZ:1@23Ph<407emO@@0MgMg1@1d
M7@407inOPD0Ogmo1020P80407moO`D0OWin101lO7`508Z:RPP0Ogmo1@21PH4407inOPD0OGem1020
P80408R8R0D0NGUi1023Ph<507QhN0P0OWin1@1mOGd407]kN`@0Ogmo1@1kNg/F0<SPf0005@38h=P5
08N7Q`@0R8R8101kNg/506i^KP@0RXZ:1@1hN7P407YjNP@0OWin1@1lO7`408R8R0D0LW9b1024Q8@4
07alO0D0N7Qh101oOgl50861P@@0MgMg1025QHD507]kN`@0Q8B4101eMGD508B4Q0@0Ti>C1@26QXH4
0:2PX0@0De=C1@2FUYH407EeM@T0O7al1023Ph<507=cL`@0QXJ61@20P80408N7Q`@0LG5a1@25QHD4
07IfMPD0Ph>31022PX8407QhN0D0PX:2102:RXX507MgM`P0Q8B41@21PH4907emO@@0QHF5101lO7`5
07moO`@0Ph>31@1iNGT407alO0T0P820101mOGd507moO`@0Q8B41023Ph<50820P0@0OGem1@24Q8@=
0<SPf0@0P8201028R8P507EeM@@0O7al1@2:RXX408>3P`@0Ng]k1@1jNWX40820P0D0PH61101oOgl4
08B4Q0D0MGEe101aLG44071`L0D0Ogmo101mOGd=08>3P`D0M7Ad101ZJVX507YjNP@0P820101fMWH5
0820P0@0Ogmo1@23Ph<40861P@@0Ph>31@2<S8`408V9R@D0QXJ6101kNg/408B4Q0D0P820102:RXX5
08>3P`@0OGem101gMgL507AdM0@0OWin1@1oOgl40820P0@0Ogmo1@1nOWh407alO0D0RXZ:201oOgl5
0861P@@0OWin1@1mOGd40820P0@0R8R81@1iNGT408>3P`D0N7Qh201nOWh507emO@@0Ng]k101oOgl5
07]kNaH0b>3H000E0<SPf0D0O7al1024Q8@408>3P`D0LG5a1027QhL507alO0@0P8201025QHD507Mg
M`@0QhN71@1iNGT408F5Q@@0Ogmo1@2:RXX40861P@D0QHF51028R8P407emO@D0QhN7101jNWX406e]
K@T0UiNG1@1fMWH409ZJVP@0I6AT1@24Q8@907inOP@0O7al101iNGT508b<S0@0KFe]1@1oOgl80820
P0D0M7Ad1021PH4508:2PP@0PH611020P80507emO@@0QhN71@1jNWX408>3P`@0Ng]k1@1mOGd407al
O0D0NWYj1025QHD407moO`h0P820201nOWh508>3P`@0N7Qh1@24Q8@40861P@@0P8201@25QHD407mo
O`D0Q8B43@38h=P407alO0@0Ogmo1@1jNWX406i^KPD0RHV91023Ph<40861P@D0Ng]k1024Q8@508F5
Q@@0SHf=1026QXH507moO`@0OWin1029RHT50861P@@0N7Qh1@28R8P407UiN@@0QXJ61@1dM7@407in
OPD0P8201026QXH408N7Q`D0PH611028R8P507inOP@0PX:2101lO7`507emO@@0RXZ:1@23Ph<408R8
R0@0P8201@29RHT407alO0D0SHf=1024Q8@40820P0D0Ph>3101oOgl508:2PP@0OGem101jNWX50861
P@@0P8201@1oOgl408b<S0d0OWin2@20P80407alO0D0PX:2101mOGd508>3P`@0OGem1022PX8507]k
N`@0PH61101lO7`507QhN1H0b>3H000E0<SPf0D0O7al1024Q8@408>3P`D0LG5a1027QhL507alO0@0
P8201025QHD507MgM`@0QhN71@1iNGT408F5Q@@0Ogmo1@2:RXX40861P@D0QHF51028R8P407emO@D0
QhN7101jNWX406e]K@T0UiNG1@1fMWH409ZJVP@0I6AT1@24Q8@907inOP@0O7al101iNGT508b<S0@0
KFe]1@1oOgl80820P0D0M7Ad1021PH4508:2PP@0PH611020P80507emO@@0QhN71@1jNWX408>3P`@0
Ng]k1@1mOGd407alO0D0NWYj1025QHD407moO`h0P820201nOWh508>3P`@0N7Qh1@24Q8@40861P@@0
P8201@25QHD407moO`D0Q8B43@38h=P407alO0@0Ogmo1@1jNWX406i^KPD0RHV91023Ph<40861P@D0
Ng]k1024Q8@508F5Q@@0SHf=1026QXH507moO`@0OWin1029RHT50861P@@0N7Qh1@28R8P407UiN@@0
QXJ61@1dM7@407inOPD0P8201026QXH408N7Q`D0PH611028R8P507inOP@0PX:2101lO7`507emO@@0
RXZ:1@23Ph<408R8R0@0P8201@29RHT407alO0D0SHf=1024Q8@40820P0D0Ph>3101oOgl508:2PP@0
OGem101jNWX50861P@@0P8201@1oOgl408b<S0d0OWin2@20P80407alO0D0PX:2101mOGd508>3P`@0
OGem1022PX8507]kN`@0PH61101lO7`507QhN1H0b>3H000E0<SPf0D0O7al1024Q8@408>3P`D0LG5a
1027QhL507alO0@0P8201025QHD507MgM`@0QhN71@1iNGT408F5Q@@0Ogmo1@2:RXX40861P@D0QHF5
1028R8P407emO@D0QhN7101jNWX406e]K@T0UiNG1@1fMWH409ZJVP@0I6AT1@24Q8@907inOP@0O7al
101iNGT508b<S0@0KFe]1@1oOgl80820P0D0M7Ad1021PH4508:2PP@0PH611020P80507emO@@0QhN7
1@1jNWX408>3P`@0Ng]k1@1mOGd407alO0D0NWYj1025QHD407moO`h0P820201nOWh508>3P`@0N7Qh
1@24Q8@40861P@@0P8201@25QHD407moO`D0Q8B43@38h=P407alO0@0Ogmo1@1jNWX406i^KPD0RHV9
1023Ph<40861P@D0Ng]k1024Q8@508F5Q@@0SHf=1026QXH507moO`@0OWin1029RHT50861P@@0N7Qh
1@28R8P407UiN@@0QXJ61@1dM7@407inOPD0P8201026QXH408N7Q`D0PH611028R8P507inOP@0PX:2
101lO7`507emO@@0RXZ:1@23Ph<408R8R0@0P8201@29RHT407alO0D0SHf=1024Q8@40820P0D0Ph>3
101oOgl508:2PP@0OGem101jNWX50861P@@0P8201@1oOgl408b<S0d0OWin2@20P80407alO0D0PX:2
101mOGd508>3P`@0OGem1022PX8507]kN`@0PH61101lO7`507QhN1H0b>3H000E0<SPf0D0O7al1024
Q8@408>3P`D0LG5a1027QhL507alO0@0P8201025QHD507MgM`@0QhN71@1iNGT408F5Q@@0Ogmo1@2:
RXX40861P@D0QHF51028R8P407emO@D0QhN7101jNWX406e]K@T0UiNG1@1fMWH409ZJVP@0I6AT1@24
Q8@907inOP@0O7al101iNGT508b<S0@0KFe]1@1oOgl80820P0D0M7Ad1021PH4508:2PP@0PH611020
P80507emO@@0QhN71@1jNWX408>3P`@0Ng]k1@1mOGd407alO0D0NWYj1025QHD407moO`h0P820201n
OWh508>3P`@0N7Qh1@24Q8@40861P@@0P8201@25QHD407moO`D0Q8B43@38h=P407alO0@0Ogmo1@1j
NWX406i^KPD0RHV91023Ph<40861P@D0Ng]k1024Q8@508F5Q@@0SHf=1026QXH507moO`@0OWin1029
RHT50861P@@0N7Qh1@28R8P407UiN@@0QXJ61@1dM7@407inOPD0P8201026QXH408N7Q`D0PH611028
R8P507inOP@0PX:2101lO7`507emO@@0RXZ:1@23Ph<408R8R0@0P8201@29RHT407alO0D0SHf=1024
Q8@40820P0D0Ph>3101oOgl508:2PP@0OGem101jNWX50861P@@0P8201@1oOgl408b<S0d0OWin2@20
P80407alO0D0PX:2101mOGd508>3P`@0OGem1022PX8507]kN`@0PH61101lO7`507QhN1H0b>3H000E
0<SPf0D0O7al1024Q8@408>3P`D0LG5a1027QhL507alO0@0P8201025QHD507MgM`@0QhN71@1iNGT4
08F5Q@@0Ogmo1@2:RXX40861P@D0QHF51028R8P407emO@D0QhN7101jNWX406e]K@T0UiNG1@1fMWH4
09ZJVP@0I6AT1@24Q8@907inOP@0O7al101iNGT508b<S0@0KFe]1@1oOgl80820P0D0M7Ad1021PH45
08:2PP@0PH611020P80507emO@@0QhN71@1jNWX408>3P`@0Ng]k1@1mOGd407alO0D0NWYj1025QHD4
07moO`h0P820201nOWh508>3P`@0N7Qh1@24Q8@40861P@@0P8201@25QHD407moO`D0Q8B43@38h=P4
07alO0@0Ogmo1@1jNWX406i^KPD0RHV91023Ph<40861P@D0Ng]k1024Q8@508F5Q@@0SHf=1026QXH5
07moO`@0OWin1029RHT50861P@@0N7Qh1@28R8P407UiN@@0QXJ61@1dM7@407inOPD0P8201026QXH4
08N7Q`D0PH611028R8P507inOP@0PX:2101lO7`507emO@@0RXZ:1@23Ph<408R8R0@0P8201@29RHT4
07alO0D0SHf=1024Q8@40820P0D0Ph>3101oOgl508:2PP@0OGem101jNWX50861P@@0P8201@1oOgl4
08b<S0d0OWin2@20P80407alO0D0PX:2101mOGd508>3P`@0OGem1022PX8507]kN`@0PH61101lO7`5
07QhN1H0b>3H000E0<SPf0D0OWin1027QhL40820P0D0MWIf101aLG4508B4Q0@0PH611023Ph<507in
OP@0QHF51@1kNg/408B4Q0@0PH611@20P80407]kN`D0QHF51024Q8@407AdM0D0PH61102ATI4406m_
K`D0SHf=1022PX8509:BTP@0KVi^101mOGd507MgM`@0QXJ62@20P80408:2PPD0O7al102:RXX506m_
K`@0RHV91024Q8@50861P@@0NGUi1@23Ph<407inOP@0P8201@26QXH408f=S@D0NGUi101lO7`408^;
R`D0MWIf1021PH4508N7Q`@0Q8B4101jNWX508:2PP@0QhN71@26QXH408N7Q`@0Q8B41@1fMWH408N7
Q`D0Ogmo1021PH4407YjNPD0PX:2101jNWX507]kN`d0b>3H102=SHd908:2PP@0QhN71@1hN7P408J6
QP@0QHF51@22PX840861P@D0PX:2201kNg/908R8R0@0S8b<1@1gMgL408>3P`D0NWYj1024Q8@407]k
N`D0Ogmo1026QXH508:2PP@0S8b<101mOGd507moO`@0MGEe1@21PH4407moO`@0NWYj1@1nOWh407em
O@D0MWIf1022PX8408>3P`D0O7al101mOGd50820P0@0R8R8102:RXX507alO0@0Ng]k1@20P80407]k
N`@0QXJ61@23Ph<408B4Q0D0O7al101iNGT408:2PPD0OWin101mOGd507alO0@0Ogmo1021PH4507em
O@@0P8201@28R8P408B4Q0@0QXJ61@1oOgl807inOPD0QXJ65P38h=P001D0b>3H1@1nOWh408N7Q`@0
P8201@1fMWH4075aL@D0Q8B41021PH4408>3P`D0OWin1025QHD507]kN`@0Q8B41021PH450820P0@0
Ng]k1@25QHD408B4Q0@0M7Ad1@21PH44096AT@@0Kfm_1@2=SHd408:2PPD0TY:B101^KVh407emO@D0
MgMg1026QXH90820P0@0PX:21@1lO7`408Z:RPD0Kfm_1029RHT408B4Q0D0PH61101iNGT508>3P`@0
OWin1020P80508J6QP@0SHf=1@1iNGT407alO0@0Rh^;1@1fMWH40861P@D0QhN71024Q8@407YjNPD0
PX:21027QhL508J6QP@0QhN71024Q8@507IfMP@0QhN71@1oOgl40861P@@0NWYj1@22PX8407YjNPD0
Ng]k3@38h=P408f=S@T0PX:21027QhL507QhN0@0QXJ61025QHD508:2PP@0PH611@22PX8807]kN`T0
R8R8102<S8`507MgM`@0Ph>31@1jNWX408B4Q0@0Ng]k1@1oOgl408J6QPD0PX:2102<S8`407emO@D0
Ogmo101eMGD50861P@@0Ogmo101jNWX507inOP@0OGem1@1fMWH408:2PP@0Ph>31@1lO7`407emO@D0
P8201028R8P408Z:RPD0O7al101kNg/50820P0@0Ng]k1026QXH508>3P`@0Q8B41@1lO7`407UiN@@0
PX:21@1nOWh407emO@D0O7al101oOgl40861P@D0OGem1020P80508R8R0@0Q8B41026QXH507moO`P0
OWin1@26QXHF0<SPf0005@38h=P507inOP@0QhN71020P80507IfMP@0LG5a1@24Q8@40861P@@0Ph>3
1@1nOWh408F5Q@D0Ng]k1024Q8@40861P@D0P820101kNg/508F5Q@@0Q8B4101dM7@50861P@@0TI6A
101_Kfl508f=S@@0PX:21@2BTY8406i^KP@0OGem1@1gMgL408J6QPT0P8201022PX8507alO0@0RXZ:
1@1_Kfl408V9R@@0Q8B41@21PH4407UiN@D0Ph>3101nOWh40820P0D0QXJ6102=SHd507UiN@@0O7al
102;Rh/507IfMP@0PH611@27QhL408B4Q0@0NWYj1@22PX8408N7Q`D0QXJ61027QhL408B4Q0D0MWIf
1027QhL507moO`@0PH61101jNWX508:2PP@0NWYj1@1kNg/=0<SPf0@0SHf=2@22PX8408N7Q`D0N7Qh
1026QXH408F5Q@D0PX:21021PH4508:2PPP0Ng]k2@28R8P408b<S0D0MgMg1023Ph<507YjNP@0Q8B4
101kNg/507moO`@0QXJ61@22PX8408b<S0@0OGem1@1oOgl407EeM@D0PH61101oOgl407YjNPD0OWin
101mOGd507IfMP@0PX:21023Ph<507alO0@0OGem1@20P80408R8R0@0RXZ:1@1lO7`407]kN`D0P820
101kNg/408J6QPD0Ph>31024Q8@507alO0@0NGUi1022PX8507inOP@0OGem1@1lO7`407moO`@0PH61
1@1mOGd40820P0D0R8R81024Q8@408J6QPD0Ogmo201nOWh508J6QQH0b>3H000E0<SPf0D0OWin1027
QhL40820P0D0MWIf101aLG4508B4Q0@0PH611023Ph<507inOP@0QHF51@1kNg/408B4Q0@0PH611@20
P80407]kN`D0QHF51024Q8@407AdM0D0PH61102ATI4406m_K`D0SHf=1022PX8509:BTP@0KVi^101m
OGd507MgM`@0QXJ62@20P80408:2PPD0O7al102:RXX506m_K`@0RHV91024Q8@50861P@@0NGUi1@23
Ph<407inOP@0P8201@26QXH408f=S@D0NGUi101lO7`408^;R`D0MWIf1021PH4508N7Q`@0Q8B4101j
NWX508:2PP@0QhN71@26QXH408N7Q`@0Q8B41@1fMWH408N7Q`D0Ogmo1021PH4407YjNPD0PX:2101j
NWX507]kN`d0b>3H102=SHd908:2PP@0QhN71@1hN7P408J6QP@0QHF51@22PX840861P@D0PX:2201k
Ng/908R8R0@0S8b<1@1gMgL408>3P`D0NWYj1024Q8@407]kN`D0Ogmo1026QXH508:2PP@0S8b<101m
OGd507moO`@0MGEe1@21PH4407moO`@0NWYj1@1nOWh407emO@D0MWIf1022PX8408>3P`D0O7al101m
OGd50820P0@0R8R8102:RXX507alO0@0Ng]k1@20P80407]kN`@0QXJ61@23Ph<408B4Q0D0O7al101i
NGT408:2PPD0OWin101mOGd507alO0@0Ogmo1021PH4507emO@@0P8201@28R8P408B4Q0@0QXJ61@1o
Ogl807inOPD0QXJ65P38h=P001D0b>3H1@1hN7P408^;R`@0NWYj1@22PX8407UiN@D0U9BD101mOGd4
08N7Q`D0PX:2101mOGd508B4Q0@0OWin101kNg/508J6QP@0NGUi1@24Q8@40820P0@0OWin1@1eMGD4
08b<S0@0Kfm_1@24Q8@407=cL`D0Rh^;101PH60408R8R0D0Ng]k2@1hN7P408:2PP@0OWin1@1lO7`9
0820P0@0Ng]k1020P80507emO@@0R8R81@1cLg<408j>SP@0NWYj1@27QhL40861P@D0M7Ad1026QXH4
08Z:RPD0OGem1025QHD907inOP@0PH611@27QhL407moO`D0OWin1024Q8@407emO@D0P8201024Q8@9
07moO`@0OGem1@23Ph<40861P@D0MWIf3@38h=P407=cL`@0KVi^1@1lO7`407inOPD0S8b<101oOgl4
08Z:RPD0NGUi101jNWX50820P0@0QHF51027QhL508>3P`@0NGUi101^KVh507EeM@@0PH611@24Q8@4
08F5Q@@0N7Qh1@1jNWX407moO`D0Ph>3101eMGD408N7Q`D0OGem101aLG4507moO`@0SHf=101mOGd5
08R8R0@0QHF51@1oOgl407IfMP@0Rh^;1@2<S8`407MgM`D0QhN7201oOgl508b<S0@0Q8B41@1_Kfl4
07inOP@0Ng]k1@2<S8`408N7Q`D0P820101oOgl407YjNPD0P8202@1mOGd807UiN@D0OWin1028R8P5
0820P0@0RXZ:101mOGd50861P@@0QHF51021PH4508F5QAH0b>3H000E0<SPf0D0N7Qh102;Rh/407Yj
NPD0PX:2101iNGT509BDU0@0OGem1027QhL508:2PP@0OGem1@24Q8@407inOP@0Ng]k1@26QXH407Ui
N@D0Q8B41020P80407inOPD0MGEe102<S8`406m_K`D0Q8B4101cLg<508^;R`@0H61P1028R8P507]k
N`T0N7Qh1022PX8407inOPD0O7al2@20P80407]kN`@0P8201@1mOGd408R8R0D0Lg=c102>SXh407Yj
NPD0QhN71021PH4507AdM0@0QXJ6102:RXX507emO@@0QHF52@1nOWh40861P@D0QhN7101oOgl507in
OP@0Q8B4101mOGd50820P0@0Q8B42@1oOgl407emO@D0Ph>31021PH4507IfMPd0b>3H101cLg<406i^
KPD0O7al101nOWh508b<S0@0Ogmo102:RXX507UiN@@0NWYj1@20P80408F5Q@@0QhN71@23Ph<407Ui
N@@0KVi^1@1eMGD40861P@D0Q8B41025QHD407QhN0D0NWYj101oOgl508>3P`@0MGEe1027QhL507em
O@@0LG5a1@1oOgl408f=S@@0OGem1@28R8P408F5Q@D0Ogmo101fMWH408^;R`D0S8b<101gMgL508N7
Q`P0Ogmo1@2<S8`408B4Q0D0Kfm_101nOWh407]kN`D0S8b<1027QhL50820P0@0Ogmo101jNWX50820
P0T0OGem201iNGT507inOP@0R8R81@20P80408Z:RP@0OGem1@21PH4408F5Q@@0PH611@25QHDF0<SP
f0005@38h=P507QhN0@0Rh^;101jNWX508:2PP@0NGUi1@2DU9@407emO@@0QhN71@22PX8407emO@D0
Q8B4101nOWh407]kN`D0QXJ6101iNGT508B4Q0@0P820101nOWh507EeM@@0S8b<101_Kfl508B4Q0@0
Lg=c1@2;Rh/4061PH0@0R8R81@1kNg/907QhN0@0PX:2101nOWh507alO0T0P820101kNg/40820P0D0
OGem1028R8P507=cL`@0SXj>101jNWX508N7Q`@0PH611@1dM7@408J6QP@0RXZ:1@1mOGd408F5Q@T0
OWin1021PH4508N7Q`@0Ogmo1@1nOWh408B4Q0@0OGem1@20P80408B4Q0T0Ogmo101mOGd508>3P`@0
PH611@1fMWH=0<SPf0@0Lg=c101^KVh507alO0@0OWin1@2<S8`407moO`@0RXZ:1@1iNGT407YjNPD0
P8201025QHD408N7Q`D0Ph>3101iNGT406i^KPD0MGEe1021PH4508B4Q0@0QHF5101hN7P507YjNP@0
Ogmo1@23Ph<407EeM@@0QhN71@1mOGd4075aL@D0Ogmo102=SHd407emO@D0R8R81025QHD507moO`@0
MWIf102;Rh/508b<S0@0MgMg1@27QhL807moO`D0S8b<1024Q8@506m_K`@0OWin101kNg/508b<S0@0
QhN71@20P80407moO`@0NWYj1@20P80907emO@P0NGUi1@1nOWh408R8R0D0P820102:RXX407emO@D0
PH611025QHD40861P@D0QHF55P38h=P001D0b>3H1@1hN7P408^;R`@0NWYj1@22PX8407UiN@D0U9BD
101mOGd408N7Q`D0PX:2101mOGd508B4Q0@0OWin101kNg/508J6QP@0NGUi1@24Q8@40820P0@0OWin
1@1eMGD408b<S0@0Kfm_1@24Q8@407=cL`D0Rh^;101PH60408R8R0D0Ng]k2@1hN7P408:2PP@0OWin
1@1lO7`90820P0@0Ng]k1020P80507emO@@0R8R81@1cLg<408j>SP@0NWYj1@27QhL40861P@D0M7Ad
1026QXH408Z:RPD0OGem1025QHD907inOP@0PH611@27QhL407moO`D0OWin1024Q8@407emO@D0P820
1024Q8@907moO`@0OGem1@23Ph<40861P@D0MWIf3@38h=P407=cL`@0KVi^1@1lO7`407inOPD0S8b<
101oOgl408Z:RPD0NGUi101jNWX50820P0@0QHF51027QhL508>3P`@0NGUi101^KVh507EeM@@0PH61
1@24Q8@408F5Q@@0N7Qh1@1jNWX407moO`D0Ph>3101eMGD408N7Q`D0OGem101aLG4507moO`@0SHf=
101mOGd508R8R0@0QHF51@1oOgl407IfMP@0Rh^;1@2<S8`407MgM`D0QhN7201oOgl508b<S0@0Q8B4
1@1_Kfl407inOP@0Ng]k1@2<S8`408N7Q`D0P820101oOgl407YjNPD0P8202@1mOGd807UiN@D0OWin
1028R8P50820P0@0RXZ:101mOGd50861P@@0QHF51021PH4508F5QAH0b>3H000E0<SPf0D0OWin1021
PH4408>3P`D0MGEe1021PH4508R8R0@0Ogmo101nOWh508:2PP@0Ph>32@21PH4408J6QPD0M7Ad101i
NGT508F5Q@@0QXJ6101lO7`508>3P`@0TY:B101_Kfl50861P@@0MGEe1@23Ph<407EeM@@0Shn?1@25
QHD407UiN@D0OWin1023Ph<407YjNPD0PX:2101oOgl508F5Q@@0PH61101gMgL508J6QP@0PX:21@27
QhL407]kN`@0MWIf1@2@T90408Z:RPD0NGUi1022PX8407emO@T0P8201@21PH440820P0@0O7al1@1n
OWh407alO0D0PH61101nOWh407moO`D0Ph>32@1nOWh808:2PPD0OWin1023Ph<507UiN@d0b>3H101k
Ng/407moO`D0NGUi101kNg/50820P0@0OWin102<S8`507inOP@0OGem1@23Ph<407moO`T0PH61101j
NWX407MgM`D0OWin1021PH45092@T0@0OGem1024Q8@508b<S0@0Ph>31@1aLG4407inOP@0O7al1@23
Ph<408V9R@D0MgMg101iNGT407QhN0D0MWIf101kNg/507inOP@0Rh^;101/K6`507MgM`@0MWIf1@26
QXH407emO@@0Lg=c1@23Ph<407inOPD0P820101nOWh90820P0@0Ogmo1@1lO7`407moO`@0PH611@1j
NWX407inOPD0QHF5101mOGd90861P@@0Ogmo1@20P80407inOP@0Ng]k1@22PX8407QhN0@0Ogmo1@1f
MWHF0<SPf0005@38h=P507inOP@0PH611023Ph<507EeM@@0PH611@28R8P407moO`@0OWin1@22PX84
08>3P`T0PH611026QXH507AdM0@0NGUi1@25QHD408J6QP@0O7al1@23Ph<409:BTP@0Kfm_1@21PH44
07EeM@D0Ph>3101eMGD408n?S`D0QHF5101iNGT507inOP@0Ph>3101jNWX508:2PP@0Ogmo1@25QHD4
0861P@@0MgMg1@26QXH408:2PPD0QhN7101kNg/407IfMPD0T92@102:RXX507UiN@@0PX:2101mOGd9
0820P0D0PH611020P80407alO0D0OWin101lO7`50861P@@0OWin101oOgl508>3P`T0OWin2022PX85
07inOP@0Ph>31@1iNGT=0<SPf0@0Ng]k101oOgl507UiN@@0Ng]k1@20P80407inOP@0S8b<1@1nOWh4
07emO@D0Ph>3101oOgl90861P@@0NWYj101gMgL507inOP@0PH611@2@T90407emO@@0Q8B41@2<S8`4
08>3P`D0LG5a101nOWh407alO0D0Ph>31029RHT507MgM`@0NGUi101hN7P507IfMP@0Ng]k1@1nOWh4
08^;R`@0K6a/1@1gMgL407IfMPD0QXJ6101mOGd407=cL`D0Ph>3101nOWh50820P0@0OWin2@20P804
07moO`D0O7al101oOgl40861P@D0NWYj101nOWh508F5Q@@0OGem2@21PH4407moO`D0P820101nOWh4
07]kN`D0PX:2101hN7P407moO`D0MWIf5P38h=P001D0b>3H1@1nOWh40861P@@0Ph>31@1eMGD40861
P@D0R8R8101oOgl407inOPD0PX:21023Ph<90861P@@0QXJ61@1dM7@407UiN@D0QHF51026QXH407al
O0D0Ph>3102BTY8406m_K`D0PH61101eMGD508>3P`@0MGEe102?Shl508F5Q@@0NGUi1@1nOWh408>3
P`@0NWYj1@22PX8407moO`D0QHF51021PH4407MgM`D0QXJ61022PX8508N7Q`@0Ng]k101fMWH5092@
T0@0RXZ:1@1iNGT408:2PP@0OGem2@20P8050861P@@0P820101lO7`507inOP@0O7al1@21PH4407in
OP@0Ogmo1@23Ph<907inOPP0PX:21@1nOWh408>3P`D0NGUi3@38h=P407]kN`@0Ogmo1@1iNGT407]k
N`D0P820101nOWh408b<S0D0OWin101mOGd508>3P`@0Ogmo2@21PH4407YjNP@0MgMg1@1nOWh40861
P@D0T92@101mOGd408B4Q0D0S8b<1023Ph<5075aL@@0OWin101lO7`508>3P`@0RHV91@1gMgL407Ui
N@@0N7Qh1@1fMWH407]kN`D0OWin102;Rh/406a/K0D0MgMg101fMWH508J6QP@0OGem101cLg<508>3
P`@0OWin1@20P80407inOPT0P820101oOgl507alO0@0Ogmo1021PH4507YjNP@0OWin1@25QHD407em
O@T0PH61101oOgl50820P0@0OWin101kNg/508:2PP@0N7Qh101oOgl507IfMQH0b>3H000E0<SPf0D0
OWin1021PH4408>3P`D0MGEe1021PH4508R8R0@0Ogmo101nOWh508:2PP@0Ph>32@21PH4408J6QPD0
M7Ad101iNGT508F5Q@@0QXJ6101lO7`508>3P`@0TY:B101_Kfl50861P@@0MGEe1@23Ph<407EeM@@0
Shn?1@25QHD407UiN@D0OWin1023Ph<407YjNPD0PX:2101oOgl508F5Q@@0PH61101gMgL508J6QP@0
PX:21@27QhL407]kN`@0MWIf1@2@T90408Z:RPD0NGUi1022PX8407emO@T0P8201@21PH440820P0@0
O7al1@1nOWh407alO0D0PH61101nOWh407moO`D0Ph>32@1nOWh808:2PPD0OWin1023Ph<507UiN@d0
b>3H101kNg/407moO`D0NGUi101kNg/50820P0@0OWin102<S8`507inOP@0OGem1@23Ph<407moO`T0
PH61101jNWX407MgM`D0OWin1021PH45092@T0@0OGem1024Q8@508b<S0@0Ph>31@1aLG4407inOP@0
O7al1@23Ph<408V9R@D0MgMg101iNGT407QhN0D0MWIf101kNg/507inOP@0Rh^;101/K6`507MgM`@0
MWIf1@26QXH407emO@@0Lg=c1@23Ph<407inOPD0P820101nOWh90820P0@0Ogmo1@1lO7`407moO`@0
PH611@1jNWX407inOPD0QHF5101mOGd90861P@@0Ogmo1@20P80407inOP@0Ng]k1@22PX8407QhN0@0
Ogmo1@1fMWHF0<SPf0005@38h=P507inOP@0PH611023Ph<507EeM@@0PH611@28R8P407moO`@0OWin
1@22PX8408>3P`T0PH611026QXH507AdM0@0NGUi1@25QHD408J6QP@0O7al1@23Ph<409:BTP@0Kfm_
1@21PH4407EeM@D0Ph>3101eMGD408n?S`D0QHF5101iNGT507inOP@0Ph>3101jNWX508:2PP@0Ogmo
1@25QHD40861P@@0MgMg1@26QXH408:2PPD0QhN7101kNg/407IfMPD0T92@102:RXX507UiN@@0PX:2
101mOGd90820P0D0PH611020P80407alO0D0OWin101lO7`50861P@@0OWin101oOgl508>3P`T0OWin
2022PX8507inOP@0Ph>31@1iNGT=0<SPf0@0Ng]k101oOgl507UiN@@0Ng]k1@20P80407inOP@0S8b<
1@1nOWh407emO@D0Ph>3101oOgl90861P@@0NWYj101gMgL507inOP@0PH611@2@T90407emO@@0Q8B4
1@2<S8`408>3P`D0LG5a101nOWh407alO0D0Ph>31029RHT507MgM`@0NGUi101hN7P507IfMP@0Ng]k
1@1nOWh408^;R`@0K6a/1@1gMgL407IfMPD0QXJ6101mOGd407=cL`D0Ph>3101nOWh50820P0@0OWin
2@20P80407moO`D0O7al101oOgl40861P@D0NWYj101nOWh508F5Q@@0OGem2@21PH4407moO`D0P820
101nOWh407]kN`D0PX:2101hN7P407moO`D0MWIf5P38h=P001D0b>3H2@25QHD407QhN0D0Ph>31026
QXH506e]K@@0QhN71026QXH507UiN@@0QhN71@22PX8407emO@@0QXJ61@21PH4408J6QPD0OWin1028
R8P408>3P`D0Ng]k1021PH4407alO0D0MgMg2@28R8P4079bLP@0SXj>1@1kNg/40861P@D0Ogmo101n
OWh407moO`D0Ng]k1020P80507alO0@0QXJ6101oOgl507emO@@0KVi^1@2<S8`408:2PP@0JFUY1@2Y
ZJT408V9R@D0IFEU1025QHD908>3P`@0OWin1@21PH4407inOP@0PH611@22PX8407]kN`D0P8201022
PX840861P@D0OWin1020P8050861P@@0P8201026QXH507YjNP@0PX:21@1mOGd=0<SPf0@0NGUi101m
OGd508b<S0@0OGem1@1jNWX408N7Q`@0OWin1@1iNGT408J6QPD0PX:2101mOGd408N7Q`D0Ng]k101h
N7P408J6QPD0Ti>C101mOGd508j>SP@0R8R8101mOGd507QhN0@0Shn?1@2GUiL408V9R@@0NWYj1@1h
N7P407moO`D0O7al1029RHT407QhN0D0Ogmo101kNg/907moO`@0PH611@1ZJVX40820P0D0MgMg101l
O7`408:2PPD0Ogmo101kNg/508:2PP@0RHV9101oOgl507inOP@0NWYj1@27QhL408>3P`T0OGem2@1o
Ogl40861P@@0Ogmo1@22PX8407]kN`T0Ogmo101nOWh508B4Q0@0OGem101nOWh507]kNaH0b>3H000E
0<SPf0T0QHF5101hN7P508>3P`@0QXJ61@1]KFd408N7Q`@0QXJ61@1iNGT408N7Q`D0PX:2101mOGd4
08J6QPD0PH611026QXH507inOP@0R8R81023Ph<507]kN`@0PH61101lO7`507MgM`T0R8R8101bLW84
08j>SPD0Ng]k1021PH4507moO`@0OWin101oOgl507]kN`@0P8201@1lO7`408J6QP@0Ogmo1@1mOGd4
06i^KPD0S8b<1022PX8406UYJ@D0ZJVY1029RHT506EUI@@0QHF52@23Ph<407inOPD0PH61101nOWh4
0861P@D0PX:2101kNg/50820P0@0PX:21021PH4507inOP@0P8201@21PH440820P0@0QXJ61@1jNWX4
08:2PPD0OGem3@38h=P407UiN@@0OGem1@2<S8`407emO@D0NWYj1027QhL407inOPD0NGUi1026QXH5
08:2PP@0OGem1027QhL507]kN`@0N7Qh1026QXH509>CT`@0OGem1@2>SXh408R8R0@0OGem1@1hN7P4
08n?S`D0UiNG1029RHT407YjNPD0N7Qh101oOgl507alO0@0RHV9101hN7P507moO`@0Ng]k2@1oOgl4
0861P@D0JVYZ1020P80507MgM`@0O7al1022PX8507moO`@0Ng]k1@22PX8408V9R@@0Ogmo1@1nOWh4
07YjNPD0QhN71023Ph<907emO@T0Ogmo1021PH4407moO`D0PX:2101kNg/907moO`@0OWin1@24Q8@4
07emO@@0OWin1@1kNg/F0<SPf0005@38h=P908F5Q@@0N7Qh1@23Ph<408J6QPD0KFe]1027QhL408J6
QPD0NGUi1027QhL508:2PP@0OGem1026QXH50861P@@0QXJ61@1nOWh408R8R0@0Ph>31@1kNg/40861
P@@0O7al1@1gMgL908R8R0@0LW9b102>SXh507]kN`@0PH611@1oOgl407inOP@0Ogmo1@1kNg/40820
P0D0O7al1026QXH407moO`D0OGem101^KVh508b<S0@0PX:2101YJFT50:VYZ@@0RHV91@1UIFD408F5
Q@T0Ph>3101nOWh50861P@@0OWin1021PH4508:2PP@0Ng]k1@20P80408:2PP@0PH611@1nOWh40820
P0D0PH611020P80408J6QPD0NWYj1022PX8507emO@d0b>3H101iNGT407emO@D0S8b<101mOGd507Yj
NP@0QhN7101nOWh507UiN@@0QXJ61@22PX8407emO@@0QhN71@1kNg/407QhN0@0QXJ61@2CTi<407em
O@D0SXj>1028R8P407emO@D0N7Qh102?Shl509NGU`@0RHV9101jNWX507QhN0@0Ogmo1@1lO7`408V9
R@@0N7Qh1@1oOgl407]kN`T0Ogmo1021PH4506YZJP@0P8201@1gMgL407alO0@0PX:21@1oOgl407]k
N`D0PX:21029RHT407moO`D0OWin101jNWX508N7Q`@0Ph>32@1mOGd907moO`@0PH61101oOgl508:2
PP@0Ng]k2@1oOgl407inOPD0Q8B4101mOGd407inOPD0Ng]k5P38h=P001D0b>3H2@25QHD407QhN0D0
Ph>31026QXH506e]K@@0QhN71026QXH507UiN@@0QhN71@22PX8407emO@@0QXJ61@21PH4408J6QPD0
OWin1028R8P408>3P`D0Ng]k1021PH4407alO0D0MgMg2@28R8P4079bLP@0SXj>1@1kNg/40861P@D0
Ogmo101nOWh407moO`D0Ng]k1020P80507alO0@0QXJ6101oOgl507emO@@0KVi^1@2<S8`408:2PP@0
JFUY1@2YZJT408V9R@D0IFEU1025QHD908>3P`@0OWin1@21PH4407inOP@0PH611@22PX8407]kN`D0
P8201022PX840861P@D0OWin1020P8050861P@@0P8201026QXH507YjNP@0PX:21@1mOGd=0<SPf0@0
NGUi101mOGd508b<S0@0OGem1@1jNWX408N7Q`@0OWin1@1iNGT408J6QPD0PX:2101mOGd408N7Q`D0
Ng]k101hN7P408J6QPD0Ti>C101mOGd508j>SP@0R8R8101mOGd507QhN0@0Shn?1@2GUiL408V9R@@0
NWYj1@1hN7P407moO`D0O7al1029RHT407QhN0D0Ogmo101kNg/907moO`@0PH611@1ZJVX40820P0D0
MgMg101lO7`408:2PPD0Ogmo101kNg/508:2PP@0RHV9101oOgl507inOP@0NWYj1@27QhL408>3P`T0
OGem2@1oOgl40861P@@0Ogmo1@22PX8407]kN`T0Ogmo101nOWh508B4Q0@0OGem101nOWh507]kNaH0
b>3H000E0<SPf0D0Ng]k102ATI4407inOPD0Q8B41025QHD507QhN0@0PX:21029RHT507inOP@0Ogmo
1@24Q8@80820P0D0OGem101bLW8508>3P`@0MWIf1021PH4508j>SP@0NWYj101mOGd508j>SP@0UIFE
1@1fMWH4075aL@@0R8R82@20P80=07inOPD0P8201025QHD508J6QP@0NWYj101nOWh508>3P`@0MWIf
1@2:RXX407emO@@0KFe]1@2EUID407inOPD0MGEe2026QXH507emO@@0Ogmo1@20P80407inOP@0P820
1@1lO7`407emO@D0P820101lO7`40861P@D0Ph>3101nOWh507YjNP@0Ph>3101lO7`508N7Q`@0O7al
1@21PH4=0<SPf0P0PH611@1lO7`407]kN`D0TY:B101cLg<407emO@D0Ogmo1027QhL508B4Q0@0OWin
101gMgL508F5Q@@0RHV9101SHf<507]kN`@0KVi^1@20P80408>3P`@0P8201@1hN7P408>3P`D0MGEe
101nOWh408B4Q0D0P820101lO7`509BDU0@0Ng]k101oOgl508R8R0@0M7Ad1@25QHD408j>SP@0M7Ad
1@1mOGd408B4Q0D0G5aL1027QhL407MgM`D0QHF51026QXH508j>SP@0NGUi1022PX8507moO`@0Ph>3
1@1mOGd40861P@@0OWin1@23Ph<407]kN`D0OGem101kNg/407MgM`D0PH61101kNg/50820P0@0MWIf
1026QXH507EeM@@0O7al1021PH4508F5QAH0b>3H000E0<SPf0D0Ng]k102ATI4407inOPD0Q8B41025
QHD507QhN0@0PX:21029RHT507inOP@0Ogmo1@24Q8@80820P0D0OGem101bLW8508>3P`@0MWIf1021
PH4508j>SP@0NWYj101mOGd508j>SP@0UIFE1@1fMWH4075aL@@0R8R82@20P80=07inOPD0P8201025
QHD508J6QP@0NWYj101nOWh508>3P`@0MWIf1@2:RXX407emO@@0KFe]1@2EUID407inOPD0MGEe2026
QXH507emO@@0Ogmo1@20P80407inOP@0P8201@1lO7`407emO@D0P820101lO7`40861P@D0Ph>3101n
OWh507YjNP@0Ph>3101lO7`508N7Q`@0O7al1@21PH4=0<SPf0P0PH611@1lO7`407]kN`D0TY:B101c
Lg<407emO@D0Ogmo1027QhL508B4Q0@0OWin101gMgL508F5Q@@0RHV9101SHf<507]kN`@0KVi^1@20
P80408>3P`@0P8201@1hN7P408>3P`D0MGEe101nOWh408B4Q0D0P820101lO7`509BDU0@0Ng]k101o
Ogl508R8R0@0M7Ad1@25QHD408j>SP@0M7Ad1@1mOGd408B4Q0D0G5aL1027QhL407MgM`D0QHF51026
QXH508j>SP@0NGUi1022PX8507moO`@0Ph>31@1mOGd40861P@@0OWin1@23Ph<407]kN`D0OGem101k
Ng/407MgM`D0PH61101kNg/50820P0@0MWIf1026QXH507EeM@@0O7al1021PH4508F5QAH0b>3H000E
0<SPf0D0Ng]k102ATI4407inOPD0Q8B41025QHD507QhN0@0PX:21029RHT507inOP@0Ogmo1@24Q8@8
0820P0D0OGem101bLW8508>3P`@0MWIf1021PH4508j>SP@0NWYj101mOGd508j>SP@0UIFE1@1fMWH4
075aL@@0R8R82@20P80=07inOPD0P8201025QHD508J6QP@0NWYj101nOWh508>3P`@0MWIf1@2:RXX4
07emO@@0KFe]1@2EUID407inOPD0MGEe2026QXH507emO@@0Ogmo1@20P80407inOP@0P8201@1lO7`4
07emO@D0P820101lO7`40861P@D0Ph>3101nOWh507YjNP@0Ph>3101lO7`508N7Q`@0O7al1@21PH4=
0<SPf0P0PH611@1lO7`407]kN`D0TY:B101cLg<407emO@D0Ogmo1027QhL508B4Q0@0OWin101gMgL5
08F5Q@@0RHV9101SHf<507]kN`@0KVi^1@20P80408>3P`@0P8201@1hN7P408>3P`D0MGEe101nOWh4
08B4Q0D0P820101lO7`509BDU0@0Ng]k101oOgl508R8R0@0M7Ad1@25QHD408j>SP@0M7Ad1@1mOGd4
08B4Q0D0G5aL1027QhL407MgM`D0QHF51026QXH508j>SP@0NGUi1022PX8507moO`@0Ph>31@1mOGd4
0861P@@0OWin1@23Ph<407]kN`D0OGem101kNg/407MgM`D0PH61101kNg/50820P0@0MWIf1026QXH5
07EeM@@0O7al1021PH4508F5QAH0b>3H000E0<SPf0D0Ng]k102ATI4407inOPD0Q8B41025QHD507Qh
N0@0PX:21029RHT507inOP@0Ogmo1@24Q8@80820P0D0OGem101bLW8508>3P`@0MWIf1021PH4508j>
SP@0NWYj101mOGd508j>SP@0UIFE1@1fMWH4075aL@@0R8R82@20P80=07inOPD0P8201025QHD508J6
QP@0NWYj101nOWh508>3P`@0MWIf1@2:RXX407emO@@0KFe]1@2EUID407inOPD0MGEe2026QXH507em
O@@0Ogmo1@20P80407inOP@0P8201@1lO7`407emO@D0P820101lO7`40861P@D0Ph>3101nOWh507Yj
NP@0Ph>3101lO7`508N7Q`@0O7al1@21PH4=0<SPf0P0PH611@1lO7`407]kN`D0TY:B101cLg<407em
O@D0Ogmo1027QhL508B4Q0@0OWin101gMgL508F5Q@@0RHV9101SHf<507]kN`@0KVi^1@20P80408>3
P`@0P8201@1hN7P408>3P`D0MGEe101nOWh408B4Q0D0P820101lO7`509BDU0@0Ng]k101oOgl508R8
R0@0M7Ad1@25QHD408j>SP@0M7Ad1@1mOGd408B4Q0D0G5aL1027QhL407MgM`D0QHF51026QXH508j>
SP@0NGUi1022PX8507moO`@0Ph>31@1mOGd40861P@@0OWin1@23Ph<407]kN`D0OGem101kNg/407Mg
M`D0PH61101kNg/50820P0@0MWIf1026QXH507EeM@@0O7al1021PH4508F5QAH0b>3H003o0<SPf?l0
b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P0
0?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38
h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000
o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SP
f6d0b>3H000E0<SPf0D0Fe]K1020P8040:j^[PD0:BTY100^;Rh502@T90@0?Cdm100h>3P903@d=0D0
<30`100f=SH403<c<`D0>CTi101=CDd50451@@@0=SHf100/;2`502TY:@@0@d=3101XJ6P506=SH`@0
IFEU1@1HF5P406IVIP@0LW9b1@1fMWH407emO@D0OWin1020P80407inOPD0Ogmo1022PX8508N7Q`@0
RHV91028R8P508^;R`@0Shn?1@2;Rh/408j>SP@0RHV91@28R8P408^;R`D0S8b<102=SHd408n?S`h0
TI6A102@T90409:BTPD0U9BD102@T90509>CT`@0T92@102FUYH509BDU0@0V9RH1@2KVi/40:2PX0@0
ZJVY1@31`L440<k>cPD0bLW93@38h=P408:2PP@0RXZ:1@1XJ6P408Z:RPD0MgMg1023Ph<408V9R@D0
QHF51024Q8@50820P0@0Ogmo1021PH4507moO`@0PH61101kNg/B07inOP@0OGem1@23Ph<407alO0D0
OWin2023Ph<507]kN`@0PH611@1oOgl408F5Q@@0O7al1@22PX8408>3P`D0OGem101oOgl907inOP@0
Ogmo1@20P8040861P@@0OWin1@1oOgl40861P@D0PX:2101lO7`907moO`@0O7al1@21PH4408>3P`@0
Ogmo1@1nOWh407moO`D0OGem1020P80407moO`D0OWin101mOGd50861P@@0OGem101kNg/50820P0@0
PH61101oOgl508:2PQH0b>3H000E0<SPf0D0Fe]K1020P8040:j^[PD0:BTY100^;Rh502@T90@0?Cdm
100h>3P903@d=0D0<30`100f=SH403<c<`D0>CTi101=CDd50451@@@0=SHf100/;2`502TY:@@0@d=3
101XJ6P506=SH`@0IFEU1@1HF5P406IVIP@0LW9b1@1fMWH407emO@D0OWin1020P80407inOPD0Ogmo
1022PX8508N7Q`@0RHV91028R8P508^;R`@0Shn?1@2;Rh/408j>SP@0RHV91@28R8P408^;R`D0S8b<
102=SHd408n?S`h0TI6A102@T90409:BTPD0U9BD102@T90509>CT`@0T92@102FUYH509BDU0@0V9RH
1@2KVi/40:2PX0@0ZJVY1@31`L440<k>cPD0bLW93@38h=P408:2PP@0RXZ:1@1XJ6P408Z:RPD0MgMg
1023Ph<408V9R@D0QHF51024Q8@50820P0@0Ogmo1021PH4507moO`@0PH61101kNg/B07inOP@0OGem
1@23Ph<407alO0D0OWin2023Ph<507]kN`@0PH611@1oOgl408F5Q@@0O7al1@22PX8408>3P`D0OGem
101oOgl907inOP@0Ogmo1@20P8040861P@@0OWin1@1oOgl40861P@D0PX:2101lO7`907moO`@0O7al
1@21PH4408>3P`@0Ogmo1@1nOWh407moO`D0OGem1020P80407moO`D0OWin101mOGd50861P@@0OGem
101kNg/50820P0@0PH61101oOgl508:2PQH0b>3H000E0<SPf0D0Fe]K1020P8040:j^[PD0:BTY100^
;Rh502@T90@0?Cdm100h>3P903@d=0D0<30`100f=SH403<c<`D0>CTi101=CDd50451@@@0=SHf100/
;2`502TY:@@0@d=3101XJ6P506=SH`@0IFEU1@1HF5P406IVIP@0LW9b1@1fMWH407emO@D0OWin1020
P80407inOPD0Ogmo1022PX8508N7Q`@0RHV91028R8P508^;R`@0Shn?1@2;Rh/408j>SP@0RHV91@28
R8P408^;R`D0S8b<102=SHd408n?S`h0TI6A102@T90409:BTPD0U9BD102@T90509>CT`@0T92@102F
UYH509BDU0@0V9RH1@2KVi/40:2PX0@0ZJVY1@31`L440<k>cPD0bLW93@38h=P408:2PP@0RXZ:1@1X
J6P408Z:RPD0MgMg1023Ph<408V9R@D0QHF51024Q8@50820P0@0Ogmo1021PH4507moO`@0PH61101k
Ng/B07inOP@0OGem1@23Ph<407alO0D0OWin2023Ph<507]kN`@0PH611@1oOgl408F5Q@@0O7al1@22
PX8408>3P`D0OGem101oOgl907inOP@0Ogmo1@20P8040861P@@0OWin1@1oOgl40861P@D0PX:2101l
O7`907moO`@0O7al1@21PH4408>3P`@0Ogmo1@1nOWh407moO`D0OGem1020P80407moO`D0OWin101m
OGd50861P@@0OGem101kNg/50820P0@0PH61101oOgl508:2PQH0b>3H000E0<SPf0D0Fe]K1020P804
0:j^[PD0:BTY100^;Rh502@T90@0?Cdm100h>3P903@d=0D0<30`100f=SH403<c<`D0>CTi101=CDd5
0451@@@0=SHf100/;2`502TY:@@0@d=3101XJ6P506=SH`@0IFEU1@1HF5P406IVIP@0LW9b1@1fMWH4
07emO@D0OWin1020P80407inOPD0Ogmo1022PX8508N7Q`@0RHV91028R8P508^;R`@0Shn?1@2;Rh/4
08j>SP@0RHV91@28R8P408^;R`D0S8b<102=SHd408n?S`h0TI6A102@T90409:BTPD0U9BD102@T905
09>CT`@0T92@102FUYH509BDU0@0V9RH1@2KVi/40:2PX0@0ZJVY1@31`L440<k>cPD0bLW93@38h=P4
08:2PP@0RXZ:1@1XJ6P408Z:RPD0MgMg1023Ph<408V9R@D0QHF51024Q8@50820P0@0Ogmo1021PH45
07moO`@0PH61101kNg/B07inOP@0OGem1@23Ph<407alO0D0OWin2023Ph<507]kN`@0PH611@1oOgl4
08F5Q@@0O7al1@22PX8408>3P`D0OGem101oOgl907inOP@0Ogmo1@20P8040861P@@0OWin1@1oOgl4
0861P@D0PX:2101lO7`907moO`@0O7al1@21PH4408>3P`@0Ogmo1@1nOWh407moO`D0OGem1020P804
07moO`D0OWin101mOGd50861P@@0OGem101kNg/50820P0@0PH61101oOgl508:2PQH0b>3H000E0<SP
f0D0Fe]K1020P8040:j^[PD0:BTY100^;Rh502@T90@0?Cdm100h>3P903@d=0D0<30`100f=SH403<c
<`D0>CTi101=CDd50451@@@0=SHf100/;2`502TY:@@0@d=3101XJ6P506=SH`@0IFEU1@1HF5P406IV
IP@0LW9b1@1fMWH407emO@D0OWin1020P80407inOPD0Ogmo1022PX8508N7Q`@0RHV91028R8P508^;
R`@0Shn?1@2;Rh/408j>SP@0RHV91@28R8P408^;R`D0S8b<102=SHd408n?S`h0TI6A102@T90409:B
TPD0U9BD102@T90509>CT`@0T92@102FUYH509BDU0@0V9RH1@2KVi/40:2PX0@0ZJVY1@31`L440<k>
cPD0bLW93@38h=P408:2PP@0RXZ:1@1XJ6P408Z:RPD0MgMg1023Ph<408V9R@D0QHF51024Q8@50820
P0@0Ogmo1021PH4507moO`@0PH61101kNg/B07inOP@0OGem1@23Ph<407alO0D0OWin2023Ph<507]k
N`@0PH611@1oOgl408F5Q@@0O7al1@22PX8408>3P`D0OGem101oOgl907inOP@0Ogmo1@20P8040861
P@@0OWin1@1oOgl40861P@D0PX:2101lO7`907moO`@0O7al1@21PH4408>3P`@0Ogmo1@1nOWh407mo
O`D0OGem1020P80407moO`D0OWin101mOGd50861P@@0OGem101kNg/50820P0@0PH61101oOgl508:2
PQH0b>3H000E0<SPf0D0Fe]K101NGUh409jNWPD0Rh^;100X:2P502XZ:P@0<S8b100^;Rh503hn?P@0
<C4a1@0b<S84030`<0@0=CDe1@0l?3`404A4A0D0?3`l100^;Rh4034a<@D09bLW1013@d<406IVIPD0
IfMW101PH60505]KF`@0L71`101_Kfl507IfMP@0O7al1@1nOWh=0861P@@0PX:21@26QXH408R8R0@0
RHV92@2=SHd508Z:RP@0RHV9102?Shl508V9R@@0Shn?1@2=SHd4092@T0@0Ti>C1@2EUID409>CT`T0
U9BD102GUiL509ZJVP@0UIFE1@2DU9@409:BTP@0U9BD1@2FUYH909ZJVP@0WinO102XZ:P50<?3``@0
d];B1@39bLT=0<SPf0@0OGem101kNg/508R8R0@0N7Qh1@2;Rh/407emO@@0Q8B41@22PX8407YjNPD0
O7al1021PH4408>3P`D0NWYj1022PX8407alO0D0OWin1020P8050861P@@0Ph>31021PH4507alO0@0
QHF52@1mOGd408>3P`D0P8201023Ph<507inOP@0PX:22@20P8040861P@D0OGem3@1nOWh90820P0P0
Ogmo1@1mOGd407moO`D0OWin101mOGd407moO`D0PH61101mOGd90861P@@0O7al1@21PH4407emO@D0
O7al1020P80407inOPD0PX:21021PH450820P0@0PH61101nOWh50861P@@0OGem1022PX8507moOaH0
b>3H000E0<SPf0D0Fe]K101NGUh409jNWPD0Rh^;100X:2P502XZ:P@0<S8b100^;Rh503hn?P@0<C4a
1@0b<S84030`<0@0=CDe1@0l?3`404A4A0D0?3`l100^;Rh4034a<@D09bLW1013@d<406IVIPD0IfMW
101PH60505]KF`@0L71`101_Kfl507IfMP@0O7al1@1nOWh=0861P@@0PX:21@26QXH408R8R0@0RHV9
2@2=SHd508Z:RP@0RHV9102?Shl508V9R@@0Shn?1@2=SHd4092@T0@0Ti>C1@2EUID409>CT`T0U9BD
102GUiL509ZJVP@0UIFE1@2DU9@409:BTP@0U9BD1@2FUYH909ZJVP@0WinO102XZ:P50<?3``@0d];B
1@39bLT=0<SPf0@0OGem101kNg/508R8R0@0N7Qh1@2;Rh/407emO@@0Q8B41@22PX8407YjNPD0O7al
1021PH4408>3P`D0NWYj1022PX8407alO0D0OWin1020P8050861P@@0Ph>31021PH4507alO0@0QHF5
2@1mOGd408>3P`D0P8201023Ph<507inOP@0PX:22@20P8040861P@D0OGem3@1nOWh90820P0P0Ogmo
1@1mOGd407moO`D0OWin101mOGd407moO`D0PH61101mOGd90861P@@0O7al1@21PH4407emO@D0O7al
1020P80407inOPD0PX:21021PH450820P0@0PH61101nOWh50861P@@0OGem1022PX8507moOaH0b>3H
000E0<SPf0D0Fe]K101NGUh409jNWPD0Rh^;100X:2P502XZ:P@0<S8b100^;Rh503hn?P@0<C4a1@0b
<S84030`<0@0=CDe1@0l?3`404A4A0D0?3`l100^;Rh4034a<@D09bLW1013@d<406IVIPD0IfMW101P
H60505]KF`@0L71`101_Kfl507IfMP@0O7al1@1nOWh=0861P@@0PX:21@26QXH408R8R0@0RHV92@2=
SHd508Z:RP@0RHV9102?Shl508V9R@@0Shn?1@2=SHd4092@T0@0Ti>C1@2EUID409>CT`T0U9BD102G
UiL509ZJVP@0UIFE1@2DU9@409:BTP@0U9BD1@2FUYH909ZJVP@0WinO102XZ:P50<?3``@0d];B1@39
bLT=0<SPf0@0OGem101kNg/508R8R0@0N7Qh1@2;Rh/407emO@@0Q8B41@22PX8407YjNPD0O7al1021
PH4408>3P`D0NWYj1022PX8407alO0D0OWin1020P8050861P@@0Ph>31021PH4507alO0@0QHF52@1m
OGd408>3P`D0P8201023Ph<507inOP@0PX:22@20P8040861P@D0OGem3@1nOWh90820P0P0Ogmo1@1m
OGd407moO`D0OWin101mOGd407moO`D0PH61101mOGd90861P@@0O7al1@21PH4407emO@D0O7al1020
P80407inOPD0PX:21021PH450820P0@0PH61101nOWh50861P@@0OGem1022PX8507moOaH0b>3H000E
0<SPf0D0Fe]K101NGUh409jNWPD0Rh^;100X:2P502XZ:P@0<S8b100^;Rh503hn?P@0<C4a1@0b<S84
030`<0@0=CDe1@0l?3`404A4A0D0?3`l100^;Rh4034a<@D09bLW1013@d<406IVIPD0IfMW101PH605
05]KF`@0L71`101_Kfl507IfMP@0O7al1@1nOWh=0861P@@0PX:21@26QXH408R8R0@0RHV92@2=SHd5
08Z:RP@0RHV9102?Shl508V9R@@0Shn?1@2=SHd4092@T0@0Ti>C1@2EUID409>CT`T0U9BD102GUiL5
09ZJVP@0UIFE1@2DU9@409:BTP@0U9BD1@2FUYH909ZJVP@0WinO102XZ:P50<?3``@0d];B1@39bLT=
0<SPf0@0OGem101kNg/508R8R0@0N7Qh1@2;Rh/407emO@@0Q8B41@22PX8407YjNPD0O7al1021PH44
08>3P`D0NWYj1022PX8407alO0D0OWin1020P8050861P@@0Ph>31021PH4507alO0@0QHF52@1mOGd4
08>3P`D0P8201023Ph<507inOP@0PX:22@20P8040861P@D0OGem3@1nOWh90820P0P0Ogmo1@1mOGd4
07moO`D0OWin101mOGd407moO`D0PH61101mOGd90861P@@0O7al1@21PH4407emO@D0O7al1020P804
07inOPD0PX:21021PH450820P0@0PH61101nOWh50861P@@0OGem1022PX8507moOaH0b>3H000E0<SP
f0D0GUiN101KFe/406][J`D0]KFe101RHV8502DU9@@0:BTY100a<C45038b<P@0;2`/1@0b<S8402`/
;0@0=3@d1@0i>CT404A4A0D0=cLg100a<C44030`<0D09bLW101?Cdl406UYJ@D0J6QX101LG5`5069R
HP@0KFe]101bLW8507QhN0@0NWYj2@1oOgl408>3P`D0PH611020P80508V9R@@0R8R81029RHT>08^;
R`d0SHf=102>SXh5092@T0P0UIFE1@2FUYH409NGU`D0UIFE202HV9P509^KV`@0UYJF1@2ATI4409>C
T`@0V9RH1@2DU9@409FEU@D0V9RH102KVi/40:FUY@D0_Kfm103@d=050<K6aPd0b>3H1023Ph<40820
P0D0Ogmo1024Q8@507QhN0@0RHV91023Ph<507]kN`T0Ogmo101kNg/407alO0D0NGUi101dM7@40820
P0D0MGEe101mOGd50861P@@0MgMg101oOgl507emO@@0Q8B41@22PX8408J6QP@0O7al2@20P80507al
O0@0Ogmo101mOGd50820P0@0O7al1@1mOGd807inOPD0Ogmo101mOGd507inOPP0P8202@21PH450820
P0@0OWin101mOGd507inOP@0P8201@1nOWh407moO`@0PX:21@23Ph<40861P@T0OWin1022PX8507mo
O`@0PH611@20P80407alO0@0OWin1@1lO7`40861P@@0P8201@1nOWhF0<SPf0005@38h=P505iNGP@0
Fe]K101[Jf/50;Fe]@@0HV9R1@0U9BD402TY:@@0<C4a1@0b<S8402`/;0D0<S8b100/;2`403@d=0D0
>CTi1014A4@503Lg=`@0<C4a100`<30502LW9`@0Cdm?101YJFT506QXJ0@0G5aL1@1RHV8406e]K@@0
LW9b1@1hN7P407YjNPT0Ogmo1023Ph<50861P@@0P8201@29RHT408R8R0@0RHV93P2;Rh/=08f=S@@0
SXj>1@2@T90809FEU@D0UYJF102GUiL509FEU@P0V9RH1@2KVi/409JFUPD0TI6A102CTi<409RHV0D0
U9BD102EUID509RHV0@0Vi^K102UYJD50;fm_@@0d=3@1@36a/H=0<SPf0@0Ph>31020P80507moO`@0
Q8B41@1hN7P408V9R@@0Ph>31@1kNg/907moO`@0Ng]k101lO7`507UiN@@0M7Ad1020P80507EeM@@0
OGem1@21PH4407MgM`@0Ogmo1@1mOGd408B4Q0D0PX:21026QXH407alO0T0P8201@1lO7`407moO`@0
OGem1@20P80407alO0D0OGem201nOWh507moO`@0OGem1@1nOWh80820P0T0PH611@20P80407inOP@0
OGem1@1nOWh40820P0D0OWin101oOgl408:2PPD0Ph>31021PH4907inOP@0PX:21@1oOgl40861P@D0
P820101lO7`407inOPD0O7al1021PH440820P0D0OWin5P38h=P001D0b>3H1@1NGUh405]KF`@0Jf][
1@2e]KD4069RHPD09BDU100Y:BT4034a<@D0<S8b100/;2`5038b<P@0;2`/100d=3@503Ti>@@0A4A4
1@0g=cL4034a<@@0<30`1@0W9bL404m?C`@0JFUY1@1XJ6P405aLG0D0HV9R101]KFd4079bLPD0N7Qh
101jNWX907moO`@0Ph>31@21PH440820P0D0RHV91028R8P408V9R@h0Rh^;3@2=SHd408j>SPD0T92@
202EUID509JFUP@0UiNG1@2EUID809RHV0D0Vi^K102FUYH5096AT@@0Ti>C102HV9P509BDU0@0UIFE
1@2HV9P409^KV`@0YJFU1@2m_Kd40=3@d0D0a/K63@38h=P408>3P`@0P8201@1oOgl408B4Q0D0N7Qh
1029RHT408>3P`D0Ng]k2@1oOgl407]kN`@0O7al1@1iNGT407AdM0@0P8201@1eMGD407emO@D0PH61
101gMgL407moO`D0OGem1024Q8@508:2PP@0QXJ6101lO7`90820P0D0O7al101oOgl407emO@D0P820
101lO7`507emO@P0OWin1@1oOgl407emO@D0OWin2020P8090861P@D0P820101nOWh407emO@D0OWin
1020P80507inOP@0Ogmo1022PX8508>3P`@0PH612@1nOWh408:2PPD0Ogmo1021PH450820P0@0O7al
101nOWh507alO0@0PH611020P80507inOQH0b>3H000E0<SPf0D0GUiN101KFe/406][J`D0]KFe101R
HV8502DU9@@0:BTY100a<C45038b<P@0;2`/1@0b<S8402`/;0@0=3@d1@0i>CT404A4A0D0=cLg100a
<C44030`<0D09bLW101?Cdl406UYJ@D0J6QX101LG5`5069RHP@0KFe]101bLW8507QhN0@0NWYj2@1o
Ogl408>3P`D0PH611020P80508V9R@@0R8R81029RHT>08^;R`d0SHf=102>SXh5092@T0P0UIFE1@2F
UYH409NGU`D0UIFE202HV9P509^KV`@0UYJF1@2ATI4409>CT`@0V9RH1@2DU9@409FEU@D0V9RH102K
Vi/40:FUY@D0_Kfm103@d=050<K6aPd0b>3H1023Ph<40820P0D0Ogmo1024Q8@507QhN0@0RHV91023
Ph<507]kN`T0Ogmo101kNg/407alO0D0NGUi101dM7@40820P0D0MGEe101mOGd50861P@@0MgMg101o
Ogl507emO@@0Q8B41@22PX8408J6QP@0O7al2@20P80507alO0@0Ogmo101mOGd50820P0@0O7al1@1m
OGd807inOPD0Ogmo101mOGd507inOPP0P8202@21PH450820P0@0OWin101mOGd507inOP@0P8201@1n
OWh407moO`@0PX:21@23Ph<40861P@T0OWin1022PX8507moO`@0PH611@20P80407alO0@0OWin1@1l
O7`40861P@@0P8201@1nOWhF0<SPf0005@38h=P505iNGP@0Fe]K101[Jf/50;Fe]@@0HV9R1@0U9BD4
02TY:@@0<C4a1@0b<S8402`/;0D0<S8b100/;2`403@d=0D0>CTi1014A4@503Lg=`@0<C4a100`<305
02LW9`@0Cdm?101YJFT506QXJ0@0G5aL1@1RHV8406e]K@@0LW9b1@1hN7P407YjNPT0Ogmo1023Ph<5
0861P@@0P8201@29RHT408R8R0@0RHV93P2;Rh/=08f=S@@0SXj>1@2@T90809FEU@D0UYJF102GUiL5
09FEU@P0V9RH1@2KVi/409JFUPD0TI6A102CTi<409RHV0D0U9BD102EUID509RHV0@0Vi^K102UYJD5
0;fm_@@0d=3@1@36a/H=0<SPf0@0Ph>31020P80507moO`@0Q8B41@1hN7P408V9R@@0Ph>31@1kNg/9
07moO`@0Ng]k101lO7`507UiN@@0M7Ad1020P80507EeM@@0OGem1@21PH4407MgM`@0Ogmo1@1mOGd4
08B4Q0D0PX:21026QXH407alO0T0P8201@1lO7`407moO`@0OGem1@20P80407alO0D0OGem201nOWh5
07moO`@0OGem1@1nOWh80820P0T0PH611@20P80407inOP@0OGem1@1nOWh40820P0D0OWin101oOgl4
08:2PPD0Ph>31021PH4907inOP@0PX:21@1oOgl40861P@D0P820101lO7`407inOPD0O7al1021PH44
0820P0D0OWin5P38h=P001D0b>3H1@1SHf<405]KF`@0GUiN1@2=SHd40<71`@D0@d=3100[:b/402`/
;0D0:b/[100`<30503<c<`@0<S8b100f=SH503`l?0@0@4101@0m?Cd403<c<`@0;bl_1@0/;2`404e=
C@@0LW9b1@1XJ6P405YJFPD0J6QX101`L704079bLPD0OGem101lO7`507emO@@0P820101nOWh50820
P0@0QHF51@24Q8@408Z:RP@0Rh^;1@2<S8`408f=S@D0Rh^;102:RXX408b<S0D0SXj>102@T90509JF
UP@0VIVI102GUiL509VIV@@0UYJF1@2HV9P409ZJVP@0Vi^K1@2JVYX409NGU`D0UIFE102GUiL409BD
U0D0TY:B102CTi<5096AT@@0UiNG102NWYh50;Fe]@@0bl_;1@30`<0=0<SPf0@0OWin1026QXH508R8
R0@0Ng]k1@20P80407inOP@0Rh^;2@27QhL508J6QP@0Ng]k101eMGD507=cL`@0LW9b101fMWH507=c
L`@0LW9b1@1gMgL406i^KP@0MGEe1@1lO7`407]kN`D0NGUi101mOGd408:2PPT0Ng]k1@1nOWh407em
O@@0NGUi2@1jNWX507moO`@0O7al101nOWh507emO@@0P8201@23Ph<407moO`@0P8201@22PX8407mo
O`D0PH61101nOWh407moO`D0O7al1020P80907moO`@0OWin1@1mOGd407moO`D0OGem101nOWh40861
P@D0O7al1021PH4507moO`@0Ph>32@1oOgl40861P@@0P8201@1oOglF0<SPf0005@38h=P506=SH`@0
Fe]K101NGUh508f=S@@0`L711@13@d<402/[:`@0;2`/1@0[:b/4030`<0D0<c<c100b<S8403Hf=PD0
?3`l1010@40503dm?@@0<c<c100_;bl502`/;0@0CDe=101bLW8506QXJ0@0FUYJ1@1XJ6P4071`L0@0
LW9b1@1mOGd407alO0D0OGem1020P80407inOPD0P8201025QHD508B4Q0@0RXZ:102;Rh/508b<S0@0
SHf=1@2;Rh/408Z:RP@0S8b<1@2>SXh4092@T0D0UYJF102IVIT409NGU`D0VIVI102FUYH509RHV0@0
VYZJ102KVi/509ZJVP@0UiNG1@2EUID409NGU`@0U9BD1@2BTY8409>CT`D0TI6A102GUiL409jNWPD0
]KFe103;bl/50<30`0d0b>3H101nOWh408J6QPD0R8R8101kNg/50820P0@0OWin102;Rh/908N7Q`D0
QXJ6101kNg/407EeM@D0Lg=c101bLW8407IfMPD0Lg=c101bLW8507MgM`@0KVi^101eMGD507alO0@0
Ng]k1@1iNGT407emO@@0PX:22@1kNg/507inOP@0OGem101iNGT907YjNPD0Ogmo101lO7`407inOPD0
OGem1020P80508>3P`@0Ogmo1020P80508:2PP@0Ogmo1@21PH4407inOP@0Ogmo1@1lO7`40820P0T0
Ogmo101nOWh507emO@@0Ogmo1@1mOGd407inOP@0PH611@1lO7`40861P@D0Ogmo1023Ph<907moO`@0
PH611020P80507moOaH0b>3H000E0<SPf0D0Hf=S101KFe/405iNGPD0SHf=1031`L4504=3@`@0:b/[
100/;2`502/[:`@0<30`1@0c<c<4038b<P@0=SHf1@0l?3`40410@0D0?Cdm100c<c<402l_;`D0;2`/
101=CDd4079bLPD0J6QX101JFUX506QXJ0@0L71`101bLW8507emO@@0O7al1@1mOGd40820P0@0OWin
1@20P80408F5Q@D0Q8B4102:RXX408^;R`D0S8b<102=SHd508^;R`@0RXZ:102<S8`508j>SP@0T92@
1@2FUYH409VIV@@0UiNG1@2IVIT409JFUPD0V9RH102JVYX409^KV`D0VYZJ102GUiL509FEU@@0UiNG
102DU9@509:BTP@0Ti>C1@2ATI4409NGU`@0WYjN1@2e]KD40<_;b`D0`<303@38h=P407inOP@0QXJ6
1@28R8P407]kN`D0P820101nOWh408^;R`T0QhN71@26QXH407]kN`@0MGEe1@1cLg<4079bLP@0MWIf
1@1cLg<4079bLPD0MgMg101^KVh407EeM@D0O7al101kNg/507UiN@@0OGem1022PX8907]kN`D0OWin
101mOGd407UiN@T0NWYj1@1oOgl407alO0@0OWin1@1mOGd40820P0D0Ph>3101oOgl40820P0D0PX:2
101oOgl50861P@@0OWin101oOgl507alO0@0P8202@1oOgl407inOPD0OGem101oOgl507emO@@0OWin
1021PH4507alO0@0PH611@1oOgl408>3P`T0Ogmo1021PH440820P0D0Ogmo5P38h=P001D0b>3H1@1S
Hf<405]KF`@0GUiN1@2=SHd40<71`@D0@d=3100[:b/402`/;0D0:b/[100`<30503<c<`@0<S8b100f
=SH503`l?0@0@4101@0m?Cd403<c<`@0;bl_1@0/;2`404e=C@@0LW9b1@1XJ6P405YJFPD0J6QX101`
L704079bLPD0OGem101lO7`507emO@@0P820101nOWh50820P0@0QHF51@24Q8@408Z:RP@0Rh^;1@2<
S8`408f=S@D0Rh^;102:RXX408b<S0D0SXj>102@T90509JFUP@0VIVI102GUiL509VIV@@0UYJF1@2H
V9P409ZJVP@0Vi^K1@2JVYX409NGU`D0UIFE102GUiL409BDU0D0TY:B102CTi<5096AT@@0UiNG102N
WYh50;Fe]@@0bl_;1@30`<0=0<SPf0@0OWin1026QXH508R8R0@0Ng]k1@20P80407inOP@0Rh^;2@27
QhL508J6QP@0Ng]k101eMGD507=cL`@0LW9b101fMWH507=cL`@0LW9b1@1gMgL406i^KP@0MGEe1@1l
O7`407]kN`D0NGUi101mOGd408:2PPT0Ng]k1@1nOWh407emO@@0NGUi2@1jNWX507moO`@0O7al101n
OWh507emO@@0P8201@23Ph<407moO`@0P8201@22PX8407moO`D0PH61101nOWh407moO`D0O7al1020
P80907moO`@0OWin1@1mOGd407moO`D0OGem101nOWh40861P@D0O7al1021PH4507moO`@0Ph>32@1o
Ogl40861P@@0P8201@1oOglF0<SPf0005@38h=P505IFEP@0Hf=S101QHF4508j>SP@0][Jf1@2e]KD4
03Xj>P@0=CDe1@0c<c<403/k>`D0=cLg100e=CD403Ph>0D0?Shn100k>c/503De=@@0<S8b100^;Rh5
02l_;`@0F5QH101/K6`506EUI@@0F5QH1@1VIVH406m_K`@0MWIf1@1jNWX407inOPD0OGem1021PH44
0820P0D0PX:21023Ph<508V9R@@0Rh^;4P2<S8`8092@T0D0TY:B102FUYH909VIV@T0VYZJ102KVi/9
09jNWPT0W9bL102GUiL909RHV0@0UIFE1@2DU9@409:BTPT0T92@102LW9`50:^[Z`@0`/;21@2g]kL=
0<SPf0@0SXj>101dM7@507alO0@0Ogmo1@23Ph<407UiN@@0SXj>1@21PH4408F5Q@D0Rh^;1026QXH9
08R8R0P0PX:21@1oOgl40820P0T0PX:21021PH4508:2PP@0Ogmo1@1nOWh40861P@@0Ogmo1@21PH44
07moO`D0Ng]k1020P80907inOP@0PX:21@20P80407alO0@0Ogmo1@22PX8407alO0D0Ogmo101mOGd4
0820P0D0O7al1025QHD50820P0@0Ogmo1020P80507moO`@0O7al1@1oOgl407]kN`d0P8201@1nOWh4
08:2PP@0OWin1@24Q8@40861P@D0Ph>31020P80407moO`D0P820101nOWh407moO`D0P8205P38h=P0
01D0b>3H1@1FEUH406=SH`@0HF5Q1@2>SXh40;Jf]PD0]KFe100j>SX403De=@D0<c<c100k>c/503Lg
=`@0=CDe100h>3P503hn?P@0>c/k1@0e=CD4038b<P@0;Rh^1@0_;bl405QHF0@0K6a/1@1UIFD405QH
F0D0IVIV101_Kfl407IfMPD0NWYj101nOWh507emO@@0PH611020P80508:2PP@0Ph>31@29RHT408^;
Ra80S8b<202@T90509:BTP@0UYJF2@2IVIT909ZJVP@0Vi^K2@2NWYh909bLW0@0UiNG2@2HV9P409FE
U@D0U9BD102BTY89092@T0@0W9bL1@2[Zj/40<;2`PD0]kNg3@38h=P408j>SP@0M7Ad1@1lO7`407mo
O`D0Ph>3101iNGT408j>SPD0PH611025QHD508^;R`@0QXJ62@28R8P808:2PPD0Ogmo1020P80908:2
PP@0PH611@22PX8407moO`D0OWin1021PH4407moO`D0PH61101oOgl507]kN`@0P8202@1nOWh408:2
PPD0P820101lO7`407moO`D0PX:2101lO7`507moO`@0OGem1020P80507alO0@0QHF51@20P80407mo
O`@0P8201@1oOgl407alO0D0Ogmo101kNg/=0820P0D0OWin1022PX8407inOPD0Q8B41021PH4508>3
P`@0P820101oOgl50820P0@0OWin101oOgl50820P1H0b>3H000E0<SPf0D0EUIF101SHf<4065QH@D0
SXj>102f][H50;Fe]@@0>SXj100e=CD503<c<`@0>c/k1@0g=cL403De=@@0>3Ph1@0n?Sh403/k>`D0
=CDe100b<S8402h^;PD0;bl_101HF5P406a/K0D0IFEU101HF5P506IVIP@0Kfm_101fMWH507YjNP@0
OWin1@1mOGd40861P@@0P8201@22PX8408>3P`D0RHV9102;Rh/B08b<S0P0T92@1@2BTY8409JFUPT0
VIVI2@2JVYX409^KV`T0WYjN2@2LW9`409NGU`T0V9RH102EUID509BDU0@0TY:B2@2@T90409bLW0D0
Zj^[1032`/850;Ng]`d0b>3H102>SXh407AdM0D0O7al101oOgl508>3P`@0NGUi102>SXh50861P@@0
QHF51@2;Rh/408J6QPT0R8R82022PX8507moO`@0P8202@22PX840861P@D0PX:2101oOgl507inOP@0
PH61101oOgl50861P@@0Ogmo1@1kNg/40820P0T0OWin1022PX850820P0@0O7al101oOgl508:2PP@0
O7al1@1oOgl407emO@@0P8201@1lO7`408F5Q@D0P820101oOgl40820P0D0Ogmo101lO7`507moO`@0
Ng]k3@20P80507inOP@0PX:2101nOWh508B4Q0@0PH611@23Ph<40820P0@0Ogmo1@20P80407inOP@0
Ogmo1@20P80F0<SPf0005@38h=P505IFEP@0Hf=S101QHF4508j>SP@0][Jf1@2e]KD403Xj>P@0=CDe
1@0c<c<403/k>`D0=cLg100e=CD403Ph>0D0?Shn100k>c/503De=@@0<S8b100^;Rh502l_;`@0F5QH
101/K6`506EUI@@0F5QH1@1VIVH406m_K`@0MWIf1@1jNWX407inOPD0OGem1021PH440820P0D0PX:2
1023Ph<508V9R@@0Rh^;4P2<S8`8092@T0D0TY:B102FUYH909VIV@T0VYZJ102KVi/909jNWPT0W9bL
102GUiL909RHV0@0UIFE1@2DU9@409:BTPT0T92@102LW9`50:^[Z`@0`/;21@2g]kL=0<SPf0@0SXj>
101dM7@507alO0@0Ogmo1@23Ph<407UiN@@0SXj>1@21PH4408F5Q@D0Rh^;1026QXH908R8R0P0PX:2
1@1oOgl40820P0T0PX:21021PH4508:2PP@0Ogmo1@1nOWh40861P@@0Ogmo1@21PH4407moO`D0Ng]k
1020P80907inOP@0PX:21@20P80407alO0@0Ogmo1@22PX8407alO0D0Ogmo101mOGd40820P0D0O7al
1025QHD50820P0@0Ogmo1020P80507moO`@0O7al1@1oOgl407]kN`d0P8201@1nOWh408:2PP@0OWin
1@24Q8@40861P@D0Ph>31020P80407moO`D0P820101nOWh407moO`D0P8205P38h=P001D0b>3H1@20
P804069RHP@0IfMW1@1eMGD408^;R`D0b/[:102ATI4402`/;0D0<30`100c<c<5034a<@@0=3@d100g
=cL503dm?@@0=cLg1@0f=SH403<c<`@0;bl_1@0^;Rh405]KF`@0MGEe1@1MGEd405ADE0D0I6AT101^
KVh407AdM0D0NGUi101kNg/907alO0@0NWYj1@22PX840861P@D0Q8B41027QhL408Z:RPD0S8b<2@2@
T90408j>SP@0T92@2@2ATI4509RHV0P0VYZJ1@2KVi/409jNWPD0X:2P102LW9`909fMW@@0VYZJ1@2K
Vi/409JFUP@0UIFE1@2BTY84096AT@T0Rh^;102>SXh509^KV`@0/K6a1@2UYJD=0<SPf0@0MgMg102:
RXX508:2PP@0Q8B41@1mOGd408:2PP@0OWin1@2:RXX407emO@D0Ph>31020P80408:2PPD0RXZ:101m
OGd407]kN`D0Ogmo101nOWh507moO`@0P8201021PH4508B4Q0@0PH611@1mOGd408>3P`@0PH611@1o
Ogl407emO@D0Ng]k101oOgl40861P@T0OGem1@24Q8@408F5Q@@0Ogmo1@24Q8@407emO@D0P820101l
O7`407inOPD0P820101nOWh507moO`@0OGem101oOgl507inOP@0PX:21@1nOWh407emO@@0Ph>31@1m
OGd907moO`P0P8201@21PH4408B4Q0D0P8202021PH4507YjNP@0OGem101nOWh507emOAH0b>3H000E
0<SPf0D0P820101RHV8406MWI`D0MGEe102;Rh/50<[:bP@0TI6A100/;2`5030`<0@0<c<c1@0a<C44
03@d=0@0=cLg1@0m?Cd403Lg=`D0=SHf100c<c<402l_;`D0;Rh^101KFe/407EeM@D0GEeM101DE5@5
06ATI0@0KVi^101dM7@507UiN@@0Ng]k2@1lO7`407YjNPD0PX:21021PH4508B4Q0@0QhN7102:RXX5
08b<S0T0T92@102>SXh4092@T0T0TI6A1@2HV9P809ZJVPD0Vi^K102NWYh50:2PX0@0W9bL2@2MWId4
09ZJVPD0Vi^K102FUYH409FEU@D0TY:B102ATI4908^;R`@0SXj>1@2KVi/40;6a/@D0YJFU3@38h=P4
07MgM`@0RXZ:1@22PX8408B4Q0D0OGem1022PX8407inOPD0RXZ:101mOGd508>3P`@0P8201022PX85
08Z:RP@0OGem101kNg/507moO`@0OWin1@1oOgl40820P0@0PH611@24Q8@40861P@D0OGem1023Ph<4
0861P@D0Ogmo101mOGd507]kN`@0Ogmo1021PH4907emO@D0Q8B41025QHD407moO`D0Q8B4101mOGd5
0820P0@0O7al101nOWh50820P0@0OWin1@1oOgl407emO@@0Ogmo1@1nOWh408:2PPD0OWin101mOGd4
08>3P`D0OGem2@1oOgl80820P0D0PH611024Q8@50820P0P0PH611@1jNWX407emO@@0OWin1@1mOGdF
0<SPf0005@38h=P50820P0@0HV9R101WIfL507EeM@@0Rh^;1@3:b/X4096AT@@0;2`/1@0`<30403<c
<`D0<C4a100d=3@403Lg=`D0?Cdm100g=cL503Hf=P@0<c<c100_;bl502h^;P@0Fe]K101eMGD505eM
G@@0E5AD1@1TI6@406i^KP@0M7Ad1@1iNGT407]kN`T0O7al101jNWX508:2PP@0PH611@24Q8@408N7
Q`@0RXZ:1@2<S8`9092@T0@0SXj>102@T909096AT@D0V9RH202JVYX509^KV`@0WYjN1@2PX:0409bL
W0T0WIfM102JVYX509^KV`@0UYJF102EUID509:BTP@0TI6A2@2;Rh/408j>SPD0Vi^K102a/K450:FU
Y@d0b>3H101gMgL408Z:RPD0PX:21024Q8@507emO@@0PX:2101nOWh508Z:RP@0OGem1@23Ph<40820
P0@0PX:21@2:RXX407emO@@0Ng]k1@1oOgl407inOPD0Ogmo1020P8040861P@D0Q8B41021PH4507em
O@@0Ph>31021PH4507moO`@0OGem1@1kNg/407moO`@0PH612@1mOGd508B4Q0@0QHF5101oOgl508B4
Q0@0OGem1@20P80407alO0@0OWin1@20P80407inOPD0Ogmo101mOGd407moO`D0OWin1022PX8507in
OP@0OGem1023Ph<507emO@T0Ogmo2020P8050861P@@0Q8B41@20P8080861P@D0NWYj101mOGd407in
OPD0OGem5P38h=P001D0b>3H1@20P804069RHP@0IfMW1@1eMGD408^;R`D0b/[:102ATI4402`/;0D0
<30`100c<c<5034a<@@0=3@d100g=cL503dm?@@0=cLg1@0f=SH403<c<`@0;bl_1@0^;Rh405]KF`@0
MGEe1@1MGEd405ADE0D0I6AT101^KVh407AdM0D0NGUi101kNg/907alO0@0NWYj1@22PX840861P@D0
Q8B41027QhL408Z:RPD0S8b<2@2@T90408j>SP@0T92@2@2ATI4509RHV0P0VYZJ1@2KVi/409jNWPD0
X:2P102LW9`909fMW@@0VYZJ1@2KVi/409JFUP@0UIFE1@2BTY84096AT@T0Rh^;102>SXh509^KV`@0
/K6a1@2UYJD=0<SPf0@0MgMg102:RXX508:2PP@0Q8B41@1mOGd408:2PP@0OWin1@2:RXX407emO@D0
Ph>31020P80408:2PPD0RXZ:101mOGd407]kN`D0Ogmo101nOWh507moO`@0P8201021PH4508B4Q0@0
PH611@1mOGd408>3P`@0PH611@1oOgl407emO@D0Ng]k101oOgl40861P@T0OGem1@24Q8@408F5Q@@0
Ogmo1@24Q8@407emO@D0P820101lO7`407inOPD0P820101nOWh507moO`@0OGem101oOgl507inOP@0
PX:21@1nOWh407emO@@0Ph>31@1mOGd907moO`P0P8201@21PH4408B4Q0D0P8202021PH4507YjNP@0
OGem101nOWh507emOAH0b>3H000E0<SPf0D0P820101RHV8406MWI`D0MGEe102;Rh/50<[:bP@0TI6A
100/;2`5030`<0@0<c<c1@0a<C4403@d=0@0=cLg1@0m?Cd403Lg=`D0=SHf100c<c<402l_;`D0;Rh^
101KFe/407EeM@D0GEeM101DE5@506ATI0@0KVi^101dM7@507UiN@@0Ng]k2@1lO7`407YjNPD0PX:2
1021PH4508B4Q0@0QhN7102:RXX508b<S0T0T92@102>SXh4092@T0T0TI6A1@2HV9P809ZJVPD0Vi^K
102NWYh50:2PX0@0W9bL2@2MWId409ZJVPD0Vi^K102FUYH409FEU@D0TY:B102ATI4908^;R`@0SXj>
1@2KVi/40;6a/@D0YJFU3@38h=P407MgM`@0RXZ:1@22PX8408B4Q0D0OGem1022PX8407inOPD0RXZ:
101mOGd508>3P`@0P8201022PX8508Z:RP@0OGem101kNg/507moO`@0OWin1@1oOgl40820P0@0PH61
1@24Q8@40861P@D0OGem1023Ph<40861P@D0Ogmo101mOGd507]kN`@0Ogmo1021PH4907emO@D0Q8B4
1025QHD407moO`D0Q8B4101mOGd50820P0@0O7al101nOWh50820P0@0OWin1@1oOgl407emO@@0Ogmo
1@1nOWh408:2PPD0OWin101mOGd408>3P`D0OGem2@1oOgl80820P0D0PH611024Q8@50820P0P0PH61
1@1jNWX407emO@@0OWin1@1mOGdF0<SPf0005@38h=P50:j^[P@0N7Qh101/K6`506EUI@@0Lg=c1@2Q
XJ440=SHf0@0GUiN1@0V9RH402XZ:PD09bLW100^;Rh403De=@D0@T92100`<30502l_;`@0;Rh^100W
9bL502HV9P@0GemO101aLG4505]KF`@0DU9B1@1UIFD4075aL@@0Lg=c1@1fMWH407YjNPD0Ng]k101n
OWh40861P@D0Ogmo1021PH4508F5Q@@0RHV91027QhL508f=S@T0Shn?102@T904096AT@D0U9BD102G
UiL509JFUP@0Vi^K102IVIT509bLW0@0V9RH1@2MWId409jNWP@0WIfM2@2KVi/509NGU`@0UIFE102B
TY8508n?S`@0Rh^;1@24Q8@408>3P`@0QHF51@2;Rh/409BDU0D0QXJ63@38h=P408J6QP@0Kfm_1@26
QXH40861P@D0RHV91027QhL407IfMPD0LG5a1023Ph<507QhN0@0O7al101hN7P50820P0@0LW9b1027
QhL508:2PP@0PH611@24Q8@407emO@@0MgMg1@20P80407inOPD0PX:2101kNg/407emO@D0Ph>3101l
O7`50820P0@0PX:2101jNWX508:2PP@0OGem1@20P8040861P@@0O7al1@1oOgl407inOPT0PH61101m
OGd50820P0@0Ogmo1@1mOGd407inOP@0O7al2@1oOgl507]kN`@0PH612@1nOWh407alO0D0OWin1025
QHD407moO`D0O7al1020P80507YjNP@0PX:21023Ph<908B4Q0@0PX:21@25QHDF0<SPf0005@38h=P5
0:j^[P@0N7Qh101/K6`506EUI@@0Lg=c1@2QXJ440=SHf0@0GUiN1@0V9RH402XZ:PD09bLW100^;Rh4
03De=@D0@T92100`<30502l_;`@0;Rh^100W9bL502HV9P@0GemO101aLG4505]KF`@0DU9B1@1UIFD4
075aL@@0Lg=c1@1fMWH407YjNPD0Ng]k101nOWh40861P@D0Ogmo1021PH4508F5Q@@0RHV91027QhL5
08f=S@T0Shn?102@T904096AT@D0U9BD102GUiL509JFUP@0Vi^K102IVIT509bLW0@0V9RH1@2MWId4
09jNWP@0WIfM2@2KVi/509NGU`@0UIFE102BTY8508n?S`@0Rh^;1@24Q8@408>3P`@0QHF51@2;Rh/4
09BDU0D0QXJ63@38h=P408J6QP@0Kfm_1@26QXH40861P@D0RHV91027QhL407IfMPD0LG5a1023Ph<5
07QhN0@0O7al101hN7P50820P0@0LW9b1027QhL508:2PP@0PH611@24Q8@407emO@@0MgMg1@20P804
07inOPD0PX:2101kNg/407emO@D0Ph>3101lO7`50820P0@0PX:2101jNWX508:2PP@0OGem1@20P804
0861P@@0O7al1@1oOgl407inOPT0PH61101mOGd50820P0@0Ogmo1@1mOGd407inOP@0O7al2@1oOgl5
07]kN`@0PH612@1nOWh407alO0D0OWin1025QHD407moO`D0O7al1020P80507YjNP@0PX:21023Ph<9
08B4Q0@0PX:21@25QHDF0<SPf0005@38h=P50:j^[P@0N7Qh101/K6`506EUI@@0Lg=c1@2QXJ440=SH
f0@0GUiN1@0V9RH402XZ:PD09bLW100^;Rh403De=@D0@T92100`<30502l_;`@0;Rh^100W9bL502HV
9P@0GemO101aLG4505]KF`@0DU9B1@1UIFD4075aL@@0Lg=c1@1fMWH407YjNPD0Ng]k101nOWh40861
P@D0Ogmo1021PH4508F5Q@@0RHV91027QhL508f=S@T0Shn?102@T904096AT@D0U9BD102GUiL509JF
UP@0Vi^K102IVIT509bLW0@0V9RH1@2MWId409jNWP@0WIfM2@2KVi/509NGU`@0UIFE102BTY8508n?
S`@0Rh^;1@24Q8@408>3P`@0QHF51@2;Rh/409BDU0D0QXJ63@38h=P408J6QP@0Kfm_1@26QXH40861
P@D0RHV91027QhL407IfMPD0LG5a1023Ph<507QhN0@0O7al101hN7P50820P0@0LW9b1027QhL508:2
PP@0PH611@24Q8@407emO@@0MgMg1@20P80407inOPD0PX:2101kNg/407emO@D0Ph>3101lO7`50820
P0@0PX:2101jNWX508:2PP@0OGem1@20P8040861P@@0O7al1@1oOgl407inOPT0PH61101mOGd50820
P0@0Ogmo1@1mOGd407inOP@0O7al2@1oOgl507]kN`@0PH612@1nOWh407alO0D0OWin1025QHD407mo
O`D0O7al1020P80507YjNP@0PX:21023Ph<908B4Q0@0PX:21@25QHDF0<SPf0005@38h=P50:j^[P@0
N7Qh101/K6`506EUI@@0Lg=c1@2QXJ440=SHf0@0GUiN1@0V9RH402XZ:PD09bLW100^;Rh403De=@D0
@T92100`<30502l_;`@0;Rh^100W9bL502HV9P@0GemO101aLG4505]KF`@0DU9B1@1UIFD4075aL@@0
Lg=c1@1fMWH407YjNPD0Ng]k101nOWh40861P@D0Ogmo1021PH4508F5Q@@0RHV91027QhL508f=S@T0
Shn?102@T904096AT@D0U9BD102GUiL509JFUP@0Vi^K102IVIT509bLW0@0V9RH1@2MWId409jNWP@0
WIfM2@2KVi/509NGU`@0UIFE102BTY8508n?S`@0Rh^;1@24Q8@408>3P`@0QHF51@2;Rh/409BDU0D0
QXJ63@38h=P408J6QP@0Kfm_1@26QXH40861P@D0RHV91027QhL407IfMPD0LG5a1023Ph<507QhN0@0
O7al101hN7P50820P0@0LW9b1027QhL508:2PP@0PH611@24Q8@407emO@@0MgMg1@20P80407inOPD0
PX:2101kNg/407emO@D0Ph>3101lO7`50820P0@0PX:2101jNWX508:2PP@0OGem1@20P8040861P@@0
O7al1@1oOgl407inOPT0PH61101mOGd50820P0@0Ogmo1@1mOGd407inOP@0O7al2@1oOgl507]kN`@0
PH612@1nOWh407alO0D0OWin1025QHD407moO`D0O7al1020P80507YjNP@0PX:21023Ph<908B4Q0@0
PX:21@25QHDF0<SPf0005@38h=P506IVIP@0Ng]k101ZJVX50820P0@0PH611@27QhL40:n_[`@0YJFU
1@0d=3@402PX:0D092@T100/;2`404Q8B0D0ATI6100i>CT502XZ:P@0:b/[100`<30502l_;`@0EUIF
101eMGD505YJFP@0DU9B1@1TI6@406a/K0@0Lg=c1@1dM7@407alO0D0OWin101lO7`407moO`D0Ph>3
1021PH4508J6QP@0R8R81029RHT509:BTP@0T92@1@2BTY8409BDU0@0TI6A1@2@T90409BDU0D0UYJF
102IVIT409JFUPD0Vi^K102MWId50:2PX0@0Vi^K102MWId509^KV`T0UIFE102ATI4408R8R0D0Q8B4
101oOgl507]kN`@0PH611023Ph<508B4Q0@0PX:21@1fMWH=0<SPf0@0Lg=c101lO7`508Z:RP@0OWin
1@1kNg/407inOP@0SXj>2@2=SHd508:2PP@0Q8B41021PH4508N7Q`@0SHf=102:RXX50861P@@0Ogmo
1@23Ph<408N7Q`@0MgMg1@1nOWh408>3P`D0PX:2101mOGd40820P0D0QHF5101oOgl507inOP@0O7al
1024Q8@508:2PP@0Ph>31@21PH4407inOP@0Ogmo2@21PH4507YjNP@0OWin1021PH4507moO`@0RXZ:
1@20P80408B4Q0@0PX:21@1nOWh90820P0P0Ogmo1@21PH4907moO`P0P8201@1mOGd408:2PPD0P820
101oOgl407inOPD0Ogmo101nOWh407alO0D0NWYj5P38h=P001D0b>3H1@1VIVH407]kN`@0JVYZ1@20
P8040861P@D0QhN7102_[jl40:FUY@D0=3@d100X:2P502@T90@0;2`/1018B4P504I6AP@0>CTi1@0Z
:RX402/[:`@0<30`1@0_;bl405IFEP@0MGEe1@1JFUX4059BDPD0I6AT101/K6`407=cL`D0M7Ad101l
O7`507inOP@0O7al101oOgl508>3P`@0PH611@26QXH408R8R0@0RHV91@2BTY84092@T0D0TY:B102D
U9@4096AT@D0T92@102DU9@509JFUP@0VIVI102FUYH509^KV`@0WIfM1@2PX:0409^KV`@0WIfM1@2K
Vi/909FEU@@0TI6A1028R8P508B4Q0@0Ogmo1@1kNg/40861P@@0Ph>31@24Q8@408:2PPD0MWIf3@38
h=P407=cL`@0O7al1@2:RXX407inOPD0Ng]k101nOWh408j>SPT0SHf=1@22PX8408B4Q0@0PH611@27
QhL408f=S@@0RXZ:1@21PH4407moO`D0Ph>31027QhL407MgM`D0OWin1023Ph<508:2PP@0OGem1020
P80508F5Q@@0Ogmo1@1nOWh407alO0@0Q8B41@22PX8408>3P`D0PH61101nOWh407moO`T0PH611@1j
NWX407inOP@0PH611@1oOgl408Z:RPD0P8201024Q8@408:2PPD0OWin2@20P80807moO`D0PH612@1o
Ogl80820P0D0OGem1022PX850820P0@0Ogmo101nOWh507moO`@0OWin101lO7`507YjNQH0b>3H000E
0<SPf0D0IVIV101kNg/406YZJPD0P8201021PH4508N7Q`@0[jn_102UYJD503@d=0@0:2PX1@0T92@4
02`/;0@0B4Q81@16ATH403Ti>@D0:RXZ100[:b/4030`<0D0;bl_101FEUH407EeM@D0FUYJ101BDU85
06ATI0@0K6a/101cLg<507AdM0@0O7al1@1nOWh407alO0@0Ogmo1@23Ph<40861P@D0QXJ61028R8P4
08V9R@D0TY:B102@T90509:BTP@0U9BD102ATI45092@T0@0U9BD1@2FUYH409VIV@@0UYJF1@2KVi/4
09fMW@D0X:2P102KVi/409fMW@D0Vi^K2@2EUID4096AT@@0R8R81@24Q8@407moO`D0Ng]k1021PH44
08>3P`D0Q8B41022PX8507IfMPd0b>3H101cLg<407alO0D0RXZ:101nOWh507]kN`@0OWin102>SXh9
08f=S@D0PX:21024Q8@40861P@D0QhN7102=SHd408Z:RPD0PH61101oOgl508>3P`@0QhN7101gMgL5
07inOP@0Ph>31@22PX8407emO@@0P8201@25QHD407moO`D0OWin101lO7`408B4Q0D0PX:21023Ph<5
0861P@@0OWin101oOgl90861P@D0NWYj101nOWh40861P@D0Ogmo102:RXX50820P0@0Q8B41022PX85
07inOPT0P820201oOgl50861P@T0Ogmo2020P80507emO@@0PX:21@20P80407moO`@0OWin1@1oOgl4
07inOP@0O7al1@1jNWXF0<SPf0005@38h=P506IVIP@0Ng]k101ZJVX50820P0@0PH611@27QhL40:n_
[`@0YJFU1@0d=3@402PX:0D092@T100/;2`404Q8B0D0ATI6100i>CT502XZ:P@0:b/[100`<30502l_
;`@0EUIF101eMGD505YJFP@0DU9B1@1TI6@406a/K0@0Lg=c1@1dM7@407alO0D0OWin101lO7`407mo
O`D0Ph>31021PH4508J6QP@0R8R81029RHT509:BTP@0T92@1@2BTY8409BDU0@0TI6A1@2@T90409BD
U0D0UYJF102IVIT409JFUPD0Vi^K102MWId50:2PX0@0Vi^K102MWId509^KV`T0UIFE102ATI4408R8
R0D0Q8B4101oOgl507]kN`@0PH611023Ph<508B4Q0@0PX:21@1fMWH=0<SPf0@0Lg=c101lO7`508Z:
RP@0OWin1@1kNg/407inOP@0SXj>2@2=SHd508:2PP@0Q8B41021PH4508N7Q`@0SHf=102:RXX50861
P@@0Ogmo1@23Ph<408N7Q`@0MgMg1@1nOWh408>3P`D0PX:2101mOGd40820P0D0QHF5101oOgl507in
OP@0O7al1024Q8@508:2PP@0Ph>31@21PH4407inOP@0Ogmo2@21PH4507YjNP@0OWin1021PH4507mo
O`@0RXZ:1@20P80408B4Q0@0PX:21@1nOWh90820P0P0Ogmo1@21PH4907moO`P0P8201@1mOGd408:2
PPD0P820101oOgl407inOPD0Ogmo101nOWh407alO0D0NWYj5P38h=P001D0b>3H1@0f=SH404M7A`@0
Ph>31@2ATI440:2PX0D0[Zj^102c/k<40;Vi^@D0Y:BT100f=SH502LW9`@09RHV100/;2`502XZ:PT0
;2`/200^;Rh502PX:0@0FEUI101^KVh5055AD@@0De=C1@1VIVH406][J`T0Lg=c101kNg/507YjNP@0
OWin1021PH4508:2PP@0QHF51@28R8P408V9R@@0Shn?2@2@T905096AT@P0UIFE1@2CTi<409RHV0D0
VYZJ102IVIT909^KV`T0WYjN102LW9`409jNWPD0V9RH2@2CTi<408b<S0@0Ng]k1@1iNGT407inOPD0
Ogmo201mOGd50861P@@0OGem1@1aLG4=0<SPf0@0Q8B4102;Rh/507UiN@@0Ogmo1@28R8P407]kN`@0
O7al1@1jNWX407]kN`D0QHF5101mOGd407inOPT0P8201021PH4508:2PP@0Q8B41@1mOGd408N7Q`T0
P820101mOGd50820P0@0Ogmo1020P80508>3P`@0OWin1@24Q8@40820P0@0PH611@20P80407inOPD0
PH61101nOWh40820P0D0OGem1021PH4507]kN`P0P8201@1oOgl408>3P`T0Ogmo101nOWh50820P0@0
OWin2@1oOgl407emO@D0Ph>3101oOgl50820P0@0Ogmo1020P80507moO`@0OGem1@21PH4408>3P`T0
O7al101hN7P407YjNPD0OWin5P38h=P001D0b>3H1@0f=SH404M7A`@0Ph>31@2ATI440:2PX0D0[Zj^
102c/k<40;Vi^@D0Y:BT100f=SH502LW9`@09RHV100/;2`502XZ:PT0;2`/200^;Rh502PX:0@0FEUI
101^KVh5055AD@@0De=C1@1VIVH406][J`T0Lg=c101kNg/507YjNP@0OWin1021PH4508:2PP@0QHF5
1@28R8P408V9R@@0Shn?2@2@T905096AT@P0UIFE1@2CTi<409RHV0D0VYZJ102IVIT909^KV`T0WYjN
102LW9`409jNWPD0V9RH2@2CTi<408b<S0@0Ng]k1@1iNGT407inOPD0Ogmo201mOGd50861P@@0OGem
1@1aLG4=0<SPf0@0Q8B4102;Rh/507UiN@@0Ogmo1@28R8P407]kN`@0O7al1@1jNWX407]kN`D0QHF5
101mOGd407inOPT0P8201021PH4508:2PP@0Q8B41@1mOGd408N7Q`T0P820101mOGd50820P0@0Ogmo
1020P80508>3P`@0OWin1@24Q8@40820P0@0PH611@20P80407inOPD0PH61101nOWh40820P0D0OGem
1021PH4507]kN`P0P8201@1oOgl408>3P`T0Ogmo101nOWh50820P0@0OWin2@1oOgl407emO@D0Ph>3
101oOgl50820P0@0Ogmo1020P80507moO`@0OGem1@21PH4408>3P`T0O7al101hN7P407YjNPD0OWin
5P38h=P001D0b>3H1@0f=SH404M7A`@0Ph>31@2ATI440:2PX0D0[Zj^102c/k<40;Vi^@D0Y:BT100f
=SH502LW9`@09RHV100/;2`502XZ:PT0;2`/200^;Rh502PX:0@0FEUI101^KVh5055AD@@0De=C1@1V
IVH406][J`T0Lg=c101kNg/507YjNP@0OWin1021PH4508:2PP@0QHF51@28R8P408V9R@@0Shn?2@2@
T905096AT@P0UIFE1@2CTi<409RHV0D0VYZJ102IVIT909^KV`T0WYjN102LW9`409jNWPD0V9RH2@2C
Ti<408b<S0@0Ng]k1@1iNGT407inOPD0Ogmo201mOGd50861P@@0OGem1@1aLG4=0<SPf0@0Q8B4102;
Rh/507UiN@@0Ogmo1@28R8P407]kN`@0O7al1@1jNWX407]kN`D0QHF5101mOGd407inOPT0P8201021
PH4508:2PP@0Q8B41@1mOGd408N7Q`T0P820101mOGd50820P0@0Ogmo1020P80508>3P`@0OWin1@24
Q8@40820P0@0PH611@20P80407inOPD0PH61101nOWh40820P0D0OGem1021PH4507]kN`P0P8201@1o
Ogl408>3P`T0Ogmo101nOWh50820P0@0OWin2@1oOgl407emO@D0Ph>3101oOgl50820P0@0Ogmo1020
P80507moO`@0OGem1@21PH4408>3P`T0O7al101hN7P407YjNPD0OWin5P38h=P001D0b>3H1@0f=SH4
04M7A`@0Ph>31@2ATI440:2PX0D0[Zj^102c/k<40;Vi^@D0Y:BT100f=SH502LW9`@09RHV100/;2`5
02XZ:PT0;2`/200^;Rh502PX:0@0FEUI101^KVh5055AD@@0De=C1@1VIVH406][J`T0Lg=c101kNg/5
07YjNP@0OWin1021PH4508:2PP@0QHF51@28R8P408V9R@@0Shn?2@2@T905096AT@P0UIFE1@2CTi<4
09RHV0D0VYZJ102IVIT909^KV`T0WYjN102LW9`409jNWPD0V9RH2@2CTi<408b<S0@0Ng]k1@1iNGT4
07inOPD0Ogmo201mOGd50861P@@0OGem1@1aLG4=0<SPf0@0Q8B4102;Rh/507UiN@@0Ogmo1@28R8P4
07]kN`@0O7al1@1jNWX407]kN`D0QHF5101mOGd407inOPT0P8201021PH4508:2PP@0Q8B41@1mOGd4
08N7Q`T0P820101mOGd50820P0@0Ogmo1020P80508>3P`@0OWin1@24Q8@40820P0@0PH611@20P804
07inOPD0PH61101nOWh40820P0D0OGem1021PH4507]kN`P0P8201@1oOgl408>3P`T0Ogmo101nOWh5
0820P0@0OWin2@1oOgl407emO@D0Ph>3101oOgl50820P0@0Ogmo1020P80507moO`@0OGem1@21PH44
08>3P`T0O7al101hN7P407YjNPD0OWin5P38h=P001D0b>3H1@0f=SH404M7A`@0Ph>31@2ATI440:2P
X0D0[Zj^102c/k<40;Vi^@D0Y:BT100f=SH502LW9`@09RHV100/;2`502XZ:PT0;2`/200^;Rh502PX
:0@0FEUI101^KVh5055AD@@0De=C1@1VIVH406][J`T0Lg=c101kNg/507YjNP@0OWin1021PH4508:2
PP@0QHF51@28R8P408V9R@@0Shn?2@2@T905096AT@P0UIFE1@2CTi<409RHV0D0VYZJ102IVIT909^K
V`T0WYjN102LW9`409jNWPD0V9RH2@2CTi<408b<S0@0Ng]k1@1iNGT407inOPD0Ogmo201mOGd50861
P@@0OGem1@1aLG4=0<SPf0@0Q8B4102;Rh/507UiN@@0Ogmo1@28R8P407]kN`@0O7al1@1jNWX407]k
N`D0QHF5101mOGd407inOPT0P8201021PH4508:2PP@0Q8B41@1mOGd408N7Q`T0P820101mOGd50820
P0@0Ogmo1020P80508>3P`@0OWin1@24Q8@40820P0@0PH611@20P80407inOPD0PH61101nOWh40820
P0D0OGem1021PH4507]kN`P0P8201@1oOgl408>3P`T0Ogmo101nOWh50820P0@0OWin2@1oOgl407em
O@D0Ph>3101oOgl50820P0@0Ogmo1020P80507moO`@0OGem1@21PH4408>3P`T0O7al101hN7P407Yj
NPD0OWin5P38h=P001D0b>3H1@0T92@401dM7@@0MgMg1@2WYjL40:b/[0D0_[jn102k^k/40;no_`D0
^k^k101^KVh502DU9@@0:2PX100W9bL502HV9P@0:2PX1@0_;bl4034a<@@0;Rh^1@0U9BD405=CD`@0
Kfm_1@1>CTh405EEE@D0HF5Q101UIFD406i^KPD0M7Ad101iNGT907alO0@0PX:21@21PH4408B4Q0D0
QhN7102:RXX408b<S0D0TY:B102@T90509BDU0@0UiNG102FUYH509NGU`@0UIFE1@2HV9P409bLW0T0
WYjN102MWId509jNWP@0WIfM102NWYh509FEU@@0U9BD1@2?Shl408B4Q0@0MgMg1@21PH4408B4Q0D0
JFUY1016ATH404M7A`D0GUiN101MGEd505UIF@d0b>3H101gMgL407emO@D0Ph>3101mOGd507]kN`@0
OWin2@21PH4408B4Q0D0Jf][1027QhL407moO`D0Ph>3101kNg/408:2PPD0PH61101oOgl507alO0@0
Ng]k1024Q8@508>3P`@0PH611@20P80407moO`@0PX:21@21PH440820P0T0PX:2101oOgl507inOPT0
Ogmo1020P80908:2PP@0Ph>31@20P80407moO`@0PH611@1mOGd407inOPD0OGem101oOgl408:2PPD0
Ph>3101nOWh507emO@@0OWin101lO7`507moO`@0PX:21@23Ph<407emO@@0P8201@1nOWh40861P@D0
O7al102<S8`408V9R@D0QXJ6102;Rh/408J6QPD0PH615P38h=P001D0b>3H1@0T92@401dM7@@0MgMg
1@2WYjL40:b/[0D0_[jn102k^k/40;no_`D0^k^k101^KVh502DU9@@0:2PX100W9bL502HV9P@0:2PX
1@0_;bl4034a<@@0;Rh^1@0U9BD405=CD`@0Kfm_1@1>CTh405EEE@D0HF5Q101UIFD406i^KPD0M7Ad
101iNGT907alO0@0PX:21@21PH4408B4Q0D0QhN7102:RXX408b<S0D0TY:B102@T90509BDU0@0UiNG
102FUYH509NGU`@0UIFE1@2HV9P409bLW0T0WYjN102MWId509jNWP@0WIfM102NWYh509FEU@@0U9BD
1@2?Shl408B4Q0@0MgMg1@21PH4408B4Q0D0JFUY1016ATH404M7A`D0GUiN101MGEd505UIF@d0b>3H
101gMgL407emO@D0Ph>3101mOGd507]kN`@0OWin2@21PH4408B4Q0D0Jf][1027QhL407moO`D0Ph>3
101kNg/408:2PPD0PH61101oOgl507alO0@0Ng]k1024Q8@508>3P`@0PH611@20P80407moO`@0PX:2
1@21PH440820P0T0PX:2101oOgl507inOPT0Ogmo1020P80908:2PP@0Ph>31@20P80407moO`@0PH61
1@1mOGd407inOPD0OGem101oOgl408:2PPD0Ph>3101nOWh507emO@@0OWin101lO7`507moO`@0PX:2
1@23Ph<407emO@@0P8201@1nOWh40861P@D0O7al102<S8`408V9R@D0QXJ6102;Rh/408J6QPD0PH61
5P38h=P001D0b>3H1@0T92@401dM7@@0MgMg1@2WYjL40:b/[0D0_[jn102k^k/40;no_`D0^k^k101^
KVh502DU9@@0:2PX100W9bL502HV9P@0:2PX1@0_;bl4034a<@@0;Rh^1@0U9BD405=CD`@0Kfm_1@1>
CTh405EEE@D0HF5Q101UIFD406i^KPD0M7Ad101iNGT907alO0@0PX:21@21PH4408B4Q0D0QhN7102:
RXX408b<S0D0TY:B102@T90509BDU0@0UiNG102FUYH509NGU`@0UIFE1@2HV9P409bLW0T0WYjN102M
WId509jNWP@0WIfM102NWYh509FEU@@0U9BD1@2?Shl408B4Q0@0MgMg1@21PH4408B4Q0D0JFUY1016
ATH404M7A`D0GUiN101MGEd505UIF@d0b>3H101gMgL407emO@D0Ph>3101mOGd507]kN`@0OWin2@21
PH4408B4Q0D0Jf][1027QhL407moO`D0Ph>3101kNg/408:2PPD0PH61101oOgl507alO0@0Ng]k1024
Q8@508>3P`@0PH611@20P80407moO`@0PX:21@21PH440820P0T0PX:2101oOgl507inOPT0Ogmo1020
P80908:2PP@0Ph>31@20P80407moO`@0PH611@1mOGd407inOPD0OGem101oOgl408:2PPD0Ph>3101n
OWh507emO@@0OWin101lO7`507moO`@0PX:21@23Ph<407emO@@0P8201@1nOWh40861P@D0O7al102<
S8`408V9R@D0QXJ6102;Rh/408J6QPD0PH615P38h=P001D0b>3H1@0T92@401dM7@@0MgMg1@2WYjL4
0:b/[0D0_[jn102k^k/40;no_`D0^k^k101^KVh502DU9@@0:2PX100W9bL502HV9P@0:2PX1@0_;bl4
034a<@@0;Rh^1@0U9BD405=CD`@0Kfm_1@1>CTh405EEE@D0HF5Q101UIFD406i^KPD0M7Ad101iNGT9
07alO0@0PX:21@21PH4408B4Q0D0QhN7102:RXX408b<S0D0TY:B102@T90509BDU0@0UiNG102FUYH5
09NGU`@0UIFE1@2HV9P409bLW0T0WYjN102MWId509jNWP@0WIfM102NWYh509FEU@@0U9BD1@2?Shl4
08B4Q0@0MgMg1@21PH4408B4Q0D0JFUY1016ATH404M7A`D0GUiN101MGEd505UIF@d0b>3H101gMgL4
07emO@D0Ph>3101mOGd507]kN`@0OWin2@21PH4408B4Q0D0Jf][1027QhL407moO`D0Ph>3101kNg/4
08:2PPD0PH61101oOgl507alO0@0Ng]k1024Q8@508>3P`@0PH611@20P80407moO`@0PX:21@21PH44
0820P0T0PX:2101oOgl507inOPT0Ogmo1020P80908:2PP@0Ph>31@20P80407moO`@0PH611@1mOGd4
07inOPD0OGem101oOgl408:2PPD0Ph>3101nOWh507emO@@0OWin101lO7`507moO`@0PX:21@23Ph<4
07emO@@0P8201@1nOWh40861P@D0O7al102<S8`408V9R@D0QXJ6102;Rh/408J6QPD0PH615P38h=P0
01D0b>3H1@0S8b<401lO7`@0AdM71@2d];@40:RXZ0D0^KVi102a/K440;Vi^@D0/K6a102/[:`506IV
IP@0=3@d100T92@502<S8`@092@T2@0/;2`402PX:0D09BDU101HF5P4065QH@D0CDe=101@D50505eM
G@@0I6AT101bLW8507IfMP@0Ng]k1@1jNWX40861P@@0OWin1@21PH4408J6QPD0Rh^;102:RXX408f=
S@D0Shn?102@T90509RHV0@0U9BD102GUiL509VIV@@0UiNG1@2IVIT409^KV`@0W9bL2@2MWId509jN
WP@0W9bL102NWYh509FEU@@0T92@1@29RHT407emO@@0N7Qh1@24Q8@408J6QPD0MWIf1015ADD404A4
A0D0GEeM101_Kfl507IfMPd0b>3H101mOGd407]kN`D0OGem101oOgl508B4Q0@0OWin2@24Q8@407mo
O`D0QHF5101/K6`40861P@D0PX:21021PH4408B4Q0D0OWin1024Q8@508:2PP@0Ogmo101kNg/507If
MPT0Ng]k1021PH4407moO`D0PX:21020P80507inOP@0PH61101nOWh50820P0@0OWin1@20P80408:2
PP@0O7al1@1oOgl408:2PPD0Ogmo1020P80407moO`D0O7al1023Ph<50820P0@0PH612@1oOgl40820
P0D0Ogmo201mOGd90820P0D0Ogmo1022PX8408F5Q@D0Q8B41020P8050861P@@0N7Qh101UIFD506QX
J0@0KVi^101iNGT507emOAH0b>3H000E0<SPf0D08b<S100O7al404M7A`D0];Bd102XZ:P50;Vi^@@0
/K6a102i^KT50;6a/@@0[:b/1@1VIVH403@d=0@092@T1@0S8b<402@T90T0;2`/100X:2P502DU9@@0
F5QH101QHF4504e=C@@0D51@1@1MGEd406ATI0@0LW9b1@1fMWH407]kN`D0NWYj1021PH4407inOPD0
PH611026QXH508^;R`@0RXZ:102=SHd508n?S`@0T92@1@2HV9P409BDU0@0UiNG1@2IVIT409NGU`D0
VIVI102KVi/409bLW0T0WIfM1@2NWYh409bLW0@0WYjN1@2EUID4092@T0D0RHV9101mOGd407QhN0D0
Q8B41026QXH507IfMP@0ADE51014A4@505eMG@@0Kfm_1@1fMWH=0<SPf0@0OGem101kNg/507emO@@0
Ogmo1@24Q8@407inOPT0Q8B4101oOgl508F5Q@@0K6a/1021PH4508:2PP@0PH611024Q8@507inOP@0
Q8B41@22PX8407moO`@0Ng]k1@1fMWH907]kN`@0PH61101oOgl508:2PP@0P8201@1nOWh40861P@@0
OWin1@20P80407inOPD0P8201022PX8407alO0D0Ogmo1022PX8507moO`@0P820101oOgl507alO0@0
Ph>31@20P8040861P@T0Ogmo1020P80507moO`P0OGem2@20P80507moO`@0PX:21025QHD508B4Q0@0
P8201@21PH4407QhN0@0IFEU1@1XJ6P406i^KP@0NGUi1@1mOGdF0<SPf0005@38h=P502<S8`@07alO
1017AdL50;Bd]0@0Z:RX1@2i^KT40;6a/@@0^KVi1@2a/K440:b/[0D0IVIV100d=3@402@T90D08b<S
100T92@902`/;0@0:2PX1@0U9BD405QHF0@0HF5Q1@1=CDd4051@D0D0GEeM101TI6@4079bLPD0MWIf
101kNg/507YjNP@0PH61101nOWh50861P@@0QXJ61@2;Rh/408Z:RP@0SHf=1@2?Shl4092@T0D0V9RH
102DU9@409NGU`D0VIVI102GUiL509VIV@@0Vi^K102LW9`909fMW@D0WYjN102LW9`409jNWPD0UIFE
102@T90508V9R@@0OGem101hN7P508B4Q0@0QXJ61@1fMWH404E5A@@0A4A41@1MGEd406m_K`D0MWIf
3@38h=P407emO@@0Ng]k1@1mOGd407moO`D0Q8B4101nOWh908B4Q0@0Ogmo1@25QHD406a/K0@0PH61
1@22PX840861P@@0Q8B41@1nOWh408B4Q0D0PX:2101oOgl407]kN`D0MWIf2@1kNg/40861P@@0Ogmo
1@22PX840820P0D0OWin1021PH4407inOPD0P820101nOWh50820P0@0PX:2101lO7`507moO`@0PX:2
1@1oOgl40820P0@0Ogmo1@1lO7`408>3P`D0P8201021PH4907moO`@0P8201@1oOgl807emO@T0P820
1@1oOgl408:2PP@0QHF51@24Q8@40820P0D0PH61101hN7P406EUI@D0J6QX101^KVh407UiN@D0OGem
5P38h=P001D0b>3H1@0S8b<401lO7`@0AdM71@2d];@40:RXZ0D0^KVi102a/K440;Vi^@D0/K6a102/
[:`506IVIP@0=3@d100T92@502<S8`@092@T2@0/;2`402PX:0D09BDU101HF5P4065QH@D0CDe=101@
D50505eMG@@0I6AT101bLW8507IfMP@0Ng]k1@1jNWX40861P@@0OWin1@21PH4408J6QPD0Rh^;102:
RXX408f=S@D0Shn?102@T90509RHV0@0U9BD102GUiL509VIV@@0UiNG1@2IVIT409^KV`@0W9bL2@2M
WId509jNWP@0W9bL102NWYh509FEU@@0T92@1@29RHT407emO@@0N7Qh1@24Q8@408J6QPD0MWIf1015
ADD404A4A0D0GEeM101_Kfl507IfMPd0b>3H101mOGd407]kN`D0OGem101oOgl508B4Q0@0OWin2@24
Q8@407moO`D0QHF5101/K6`40861P@D0PX:21021PH4408B4Q0D0OWin1024Q8@508:2PP@0Ogmo101k
Ng/507IfMPT0Ng]k1021PH4407moO`D0PX:21020P80507inOP@0PH61101nOWh50820P0@0OWin1@20
P80408:2PP@0O7al1@1oOgl408:2PPD0Ogmo1020P80407moO`D0O7al1023Ph<50820P0@0PH612@1o
Ogl40820P0D0Ogmo201mOGd90820P0D0Ogmo1022PX8408F5Q@D0Q8B41020P8050861P@@0N7Qh101U
IFD506QXJ0@0KVi^101iNGT507emOAH0b>3H000E0<SPf0D08b<S100O7al404M7A`D0];Bd102XZ:P5
0;Vi^@@0/K6a102i^KT50;6a/@@0[:b/1@1VIVH403@d=0@092@T1@0S8b<402@T90T0;2`/100X:2P5
02DU9@@0F5QH101QHF4504e=C@@0D51@1@1MGEd406ATI0@0LW9b1@1fMWH407]kN`D0NWYj1021PH44
07inOPD0PH611026QXH508^;R`@0RXZ:102=SHd508n?S`@0T92@1@2HV9P409BDU0@0UiNG1@2IVIT4
09NGU`D0VIVI102KVi/409bLW0T0WIfM1@2NWYh409bLW0@0WYjN1@2EUID4092@T0D0RHV9101mOGd4
07QhN0D0Q8B41026QXH507IfMP@0ADE51014A4@505eMG@@0Kfm_1@1fMWH=0<SPf0@0OGem101kNg/5
07emO@@0Ogmo1@24Q8@407inOPT0Q8B4101oOgl508F5Q@@0K6a/1021PH4508:2PP@0PH611024Q8@5
07inOP@0Q8B41@22PX8407moO`@0Ng]k1@1fMWH907]kN`@0PH61101oOgl508:2PP@0P8201@1nOWh4
0861P@@0OWin1@20P80407inOPD0P8201022PX8407alO0D0Ogmo1022PX8507moO`@0P820101oOgl5
07alO0@0Ph>31@20P8040861P@T0Ogmo1020P80507moO`P0OGem2@20P80507moO`@0PX:21025QHD5
08B4Q0@0P8201@21PH4407QhN0@0IFEU1@1XJ6P406i^KP@0NGUi1@1mOGdF0<SPf0005@38h=P502HV
9P@07QhN100V9RH509^KV`@0XJ6Q1@2WYjL40:^[Z`@0ZZZZ1@2b/[840;Ng]`D0[Jf]101^KVh403@d
=0D09BDU100S8b<502`/;0@0;Bd]100/;2`502HV9P@0EUIF101RHV8504A4A0@0AdM71@1JFUX406IV
IP@0LW9b1@1eMGD407emO@D0Ogmo1021PH4407moO`D0PX:21025QHD508V9R@@0SXj>102;Rh/5096A
T@@0T92@1@2BTY8409RHV0@0UIFE1@2GUiL409JFUPD0VYZJ102MWId409VIV@D0WinO2@2NWYh409bL
W0@0VYZJ1@2CTi<408n?S`D0SXj>101bLW8407=cL`D0Ogmo1029RHT908N7Q`@0RHV91@2:RXX408R8
R0D0OGem3@38h=P808:2PPD0Q8B4101kNg/508F5Q@@0QhN7101jNWX5079bLP@0NGUi1@1_Kfl407If
MPT0SHf=1021PH4408J6QPD0NGUi2@21PH4407alO0@0Ogmo1@1lO7`407UiN@D0Q8B4101oOgl407em
O@D0OWin1023Ph<507inOPP0Ogmo1@21PH4407inOPD0Ogmo1021PH440820P0D0OWin1021PH4507in
OP@0Ph>3101lO7`50820P0@0O7al1@1oOgl408:2PP@0PH611@1mOGd40820P0D0OWin101oOgl407em
O@D0P820101jNWX=07emO@D0Ogmo1021PH4507]kN`@0P8201026QXH507moO`@0PH61101oOgl50820
P1H0b>3H000E0<SPf0D09RHV100N7Qh402HV9PD0Vi^K102QXJ450:NWY`@0Zj^[102ZZZX50;:b/P@0
]kNg1@2][Jd406i^KP@0=3@d1@0U9BD402<S8`D0;2`/100];Bd402`/;0D09RHV101FEUH4069RHPD0
A4A41017AdL505YJFP@0IVIV101bLW8507EeM@@0OGem1@1oOgl40861P@@0Ogmo1@22PX8408F5Q@D0
RHV9102>SXh408^;R`D0TI6A102@T90509:BTP@0V9RH102EUID509NGU`@0UYJF1@2JVYX409fMW@@0
VIVI1@2OWil909jNWP@0W9bL102JVYX509>CT`@0Shn?1@2>SXh4079bLP@0Lg=c1@1oOgl408V9R@T0
QhN71029RHT508Z:RP@0R8R81@1mOGd=0<SPf0P0PX:21@24Q8@407]kN`D0QHF51027QhL407YjNPD0
LW9b101iNGT506m_K`@0MWIf2@2=SHd40861P@@0QXJ61@1iNGT90861P@@0O7al101oOgl507alO0@0
NGUi1@24Q8@407moO`@0OGem1@1nOWh408>3P`D0OWin201oOgl50861P@@0OWin1@1oOgl40861P@@0
P8201@1nOWh40861P@D0OWin1023Ph<407alO0D0P820101lO7`507moO`@0PX:21021PH4507emO@@0
P8201@1nOWh407moO`@0OGem1@20P80407YjNPd0OGem1@1oOgl40861P@D0Ng]k1020P80408J6QPD0
Ogmo1021PH4407moO`D0P8205P38h=P001D0b>3H1@0V9RH401hN7P@09RHV1@2KVi/40:6QX@D0YjNW
102[Zj/40:ZZZPD0/[:b102g]kL50:f][@@0KVi^100d=3@502DU9@@08b<S1@0/;2`402d];@@0;2`/
1@0V9RH405IFEP@0HV9R1@14A4@404M7A`D0FUYJ101VIVH4079bLPD0MGEe101mOGd507moO`@0PH61
101oOgl508:2PP@0QHF51@29RHT408j>SP@0Rh^;1@2ATI44092@T0D0TY:B102HV9P409FEU@D0UiNG
102FUYH509ZJVP@0WIfM102IVIT509nOW`T0WYjN102LW9`409ZJVPD0Ti>C102?Shl508j>SP@0LW9b
101cLg<507moO`@0RHV92@27QhL408V9R@D0RXZ:1028R8P507emO@d0b>3H2022PX8508B4Q0@0Ng]k
1@25QHD408N7Q`@0NWYj1@1bLW8407UiN@D0Kfm_101fMWH908f=S@@0PH611026QXH507UiN@T0PH61
101lO7`407moO`D0O7al101iNGT508B4Q0@0Ogmo101mOGd507inOP@0Ph>31@1nOWh807moO`D0PH61
101nOWh507moO`@0PH611020P80507inOP@0PH611@1nOWh408>3P`@0O7al1@20P80407alO0D0Ogmo
1022PX840861P@D0OGem1020P80507inOP@0Ogmo101mOGd50820P0@0NWYj3@1mOGd507moO`@0PH61
1@1kNg/40820P0@0QXJ61@1oOgl40861P@@0Ogmo1@20P80F0<SPf0005@38h=P502HV9P@07QhN100V
9RH509^KV`@0XJ6Q1@2WYjL40:^[Z`@0ZZZZ1@2b/[840;Ng]`D0[Jf]101^KVh403@d=0D09BDU100S
8b<502`/;0@0;Bd]100/;2`502HV9P@0EUIF101RHV8504A4A0@0AdM71@1JFUX406IVIP@0LW9b1@1e
MGD407emO@D0Ogmo1021PH4407moO`D0PX:21025QHD508V9R@@0SXj>102;Rh/5096AT@@0T92@1@2B
TY8409RHV0@0UIFE1@2GUiL409JFUPD0VYZJ102MWId409VIV@D0WinO2@2NWYh409bLW0@0VYZJ1@2C
Ti<408n?S`D0SXj>101bLW8407=cL`D0Ogmo1029RHT908N7Q`@0RHV91@2:RXX408R8R0D0OGem3@38
h=P808:2PPD0Q8B4101kNg/508F5Q@@0QhN7101jNWX5079bLP@0NGUi1@1_Kfl407IfMPT0SHf=1021
PH4408J6QPD0NGUi2@21PH4407alO0@0Ogmo1@1lO7`407UiN@D0Q8B4101oOgl407emO@D0OWin1023
Ph<507inOPP0Ogmo1@21PH4407inOPD0Ogmo1021PH440820P0D0OWin1021PH4507inOP@0Ph>3101l
O7`50820P0@0O7al1@1oOgl408:2PP@0PH611@1mOGd40820P0D0OWin101oOgl407emO@D0P820101j
NWX=07emO@D0Ogmo1021PH4507]kN`@0P8201026QXH507moO`@0PH61101oOgl50820P1H0b>3H000E
0<SPf0D0:b/[100Y:BT401dM7@D0Lg=c102TY:@509jNWP@0UIFE1027QhL507UiN@@0QhN71@2YZJT4
0:ZZZP@0Fe]K1@0R8R8402DU9@T0:BTY100[:b/502HV9P@0EeMG101UIFD504Q8B0@0ATI61@1GEeL4
06EUI@@0LG5a1@1fMWH407emO@D0O7al1021PH440820P0D0Ph>31026QXH508R8R0@0SHf=102?Shl5
08j>SP@0TI6A1@2DU9@409NGU`@0UYJF1@2JVYX=09fMW@@0WYjN2@2OWil509fMW@@0WinO102IVIT5
09:BTP@0Shn?1@29RHT407AdM0@0KVi^1@1mOGd408R8R0D0SHf=1028R8P408b<S0D0SHf=1028R8P5
07alO0d0b>3H101kNg/40820P0T0OGem1@1eMGD407alO0@0QHF51@26QXH408R8R0D0VYZJ102FUYH4
07AdM0D0R8R8102=SHd407emO@D0QXJ6101nOWh5075aL@@0MGEe2@22PX8407inOPD0QhN7101oOgl4
08>3P`D0OGem2@1oOgl407emO@@0P8201@21PH4407inOPD0Ogmo1020P80407alO0D0PH611023Ph<5
07alO0@0P8201021PH4508:2PP@0Ogmo1@1mOGd407inOP@0P8201@22PX8407inOPD0PH611023Ph<4
0861P@D0P8201024Q8@508:2PP@0PH611022PX850861P@@0Ogmo1@20P80407moO`@0PH612@1nOWh4
0820P0D0OGem5P38h=P001D0b>3H1@0[:b/402TY:@@07AdM1@1cLg<40:BTY0D0WYjN102EUID408N7
Q`D0NGUi1027QhL50:VYZ@@0ZZZZ101KFe/5028R8P@09BDU2@0Y:BT402/[:`D09RHV101GEeL406EU
I@D0B4Q81016ATH505MGE`@0IFEU101aLG4507IfMP@0OGem1@1lO7`40861P@@0P8201@23Ph<408J6
QPD0R8R8102=SHd408n?S`D0SXj>102ATI4509BDU0@0UiNG102FUYH509ZJVPd0WIfM102NWYh909nO
W`D0WIfM102OWil409VIV@D0TY:B102?Shl508V9R@@0M7Ad101^KVh507emO@@0R8R81@2=SHd408R8
R0@0S8b<1@2=SHd408R8R0D0O7al3@38h=P407]kN`@0P8202@1mOGd507EeM@@0O7al1025QHD508J6
QP@0R8R81@2JVYX409JFUP@0M7Ad1@28R8P408f=S@@0OGem1@26QXH407inOPD0LG5a101eMGD908:2
PP@0OWin1@27QhL407moO`@0Ph>31@1mOGd907moO`@0OGem1020P8050861P@@0OWin1@1oOgl40820
P0@0O7al1@21PH4408>3P`D0O7al1020P8040861P@D0PX:2101oOgl507emO@@0OWin1020P80508:2
PP@0OWin1@21PH4408>3P`@0PH611@20P80408B4Q0D0PX:21021PH4408:2PPD0PH61101oOgl50820
P0@0Ogmo1021PH4907inOP@0P8201@1mOGdF0<SPf0005@38h=P502/[:`@0:BTY100M7Ad507=cL`@0
Y:BT1@2NWYh409FEU@@0QhN71@1iNGT408N7Q`D0ZJVY102ZZZX405]KF`D08R8R100U9BD902TY:@@0
:b/[1@0V9RH405MGE`@0IFEU1@18B4P404I6APD0EeMG101UIFD4075aL@D0MWIf101mOGd507alO0@0
PH611020P80508>3P`@0QXJ61@28R8P408f=S@@0Shn?1@2>SXh4096AT@D0U9BD102GUiL409JFUPD0
VYZJ3@2MWId409jNWPT0WinO1@2MWId409nOW`@0VIVI1@2BTY8408n?S`D0RHV9101dM7@406i^KPD0
OGem1028R8P508f=S@@0R8R8102<S8`508f=S@@0R8R81@1lO7`=0<SPf0@0Ng]k1020P80907emO@D0
MGEe101lO7`408F5Q@D0QXJ61028R8P509ZJVP@0UYJF101dM7@508R8R0@0SHf=101mOGd508J6QP@0
OWin1@1aLG4407EeM@T0PX:2101nOWh508N7Q`@0Ogmo1023Ph<507emO@T0Ogmo101mOGd40820P0D0
PH61101nOWh507moO`@0P820101lO7`50861P@@0Ph>31@1lO7`40820P0@0PH611@22PX8407moO`D0
OGem101nOWh40820P0D0PX:2101nOWh50861P@@0Ph>31021PH450820P0@0Q8B41@22PX840861P@@0
PX:21@21PH4407moO`D0P820101oOgl40861P@T0OWin1020P80507emOAH0b>3H000E0<SPf0D0:b/[
100Y:BT401dM7@D0Lg=c102TY:@509jNWP@0UIFE1027QhL507UiN@@0QhN71@2YZJT40:ZZZP@0Fe]K
1@0R8R8402DU9@T0:BTY100[:b/502HV9P@0EeMG101UIFD504Q8B0@0ATI61@1GEeL406EUI@@0LG5a
1@1fMWH407emO@D0O7al1021PH440820P0D0Ph>31026QXH508R8R0@0SHf=102?Shl508j>SP@0TI6A
1@2DU9@409NGU`@0UYJF1@2JVYX=09fMW@@0WYjN2@2OWil509fMW@@0WinO102IVIT509:BTP@0Shn?
1@29RHT407AdM0@0KVi^1@1mOGd408R8R0D0SHf=1028R8P408b<S0D0SHf=1028R8P507alO0d0b>3H
101kNg/40820P0T0OGem1@1eMGD407alO0@0QHF51@26QXH408R8R0D0VYZJ102FUYH407AdM0D0R8R8
102=SHd407emO@D0QXJ6101nOWh5075aL@@0MGEe2@22PX8407inOPD0QhN7101oOgl408>3P`D0OGem
2@1oOgl407emO@@0P8201@21PH4407inOPD0Ogmo1020P80407alO0D0PH611023Ph<507alO0@0P820
1021PH4508:2PP@0Ogmo1@1mOGd407inOP@0P8201@22PX8407inOPD0PH611023Ph<40861P@D0P820
1024Q8@508:2PP@0PH611022PX850861P@@0Ogmo1@20P80407moO`@0PH612@1nOWh40820P0D0OGem
5P38h=P001D0b>3H1@0R8R8402d];@@08b<S1@0[:b/407EeM@D0Ng]k101hN7P406QXJ0D0L71`102X
Z:P509jNWP@0TI6A101lO7`503Lg=`@092@T1@0U9BD402PX:0@0:b/[1@0T92@405IFEP@0FUYJ1@10
@40404a<C0D0EEEE101QHF44075aL@D0M7Ad101kNg/507emO@P0P8201@25QHD408N7Q`D0Rh^;102<
S8`9096AT@@0U9BD2@2HV9P409JFUPT0VIVI1@2LW9`409fMW@@0WYjN2@2PX:050::RXP@0WinO102I
VIT509JFUP@0S8b<1@2;Rh/407IfMP@0L71`1@1jNWX408B4Q0D0R8R81027QhL408Z:RPD0QhN71020
P80507emO@d0b>3H1025QHD40861P@D0OWin101lO7`508J6QP@0NWYj101iNGT507emO@@0P8201@1c
Lg<4079bLPT0TY:B102@T90408:2PPD0Q8B42@22PX8407inOP@0P8201@1nOWh408F5Q@D0Ph>31020
P80407]kN`D0Q8B4101nOWh508>3P`@0OWin101lO7`507moO`@0PH612@20P80407inOPD0Ph>31021
PH4507moO`@0O7al1020P80507inOP@0P8202@21PH4407alO0D0P820101mOGd50861P@@0OWin101m
OGd507inOP@0OGem1@1kNg/40820P0@0Ogmo1@1lO7`408>3P`D0P8201024Q8@408:2PPD0Q8B4101o
Ogl40861P@D0P8205P38h=P001D0b>3H1@0R8R8402d];@@08b<S1@0[:b/407EeM@D0Ng]k101hN7P4
06QXJ0D0L71`102XZ:P509jNWP@0TI6A101lO7`503Lg=`@092@T1@0U9BD402PX:0@0:b/[1@0T92@4
05IFEP@0FUYJ1@10@40404a<C0D0EEEE101QHF44075aL@D0M7Ad101kNg/507emO@P0P8201@25QHD4
08N7Q`D0Rh^;102<S8`9096AT@@0U9BD2@2HV9P409JFUPT0VIVI1@2LW9`409fMW@@0WYjN2@2PX:05
0::RXP@0WinO102IVIT509JFUP@0S8b<1@2;Rh/407IfMP@0L71`1@1jNWX408B4Q0D0R8R81027QhL4
08Z:RPD0QhN71020P80507emO@d0b>3H1025QHD40861P@D0OWin101lO7`508J6QP@0NWYj101iNGT5
07emO@@0P8201@1cLg<4079bLPT0TY:B102@T90408:2PPD0Q8B42@22PX8407inOP@0P8201@1nOWh4
08F5Q@D0Ph>31020P80407]kN`D0Q8B4101nOWh508>3P`@0OWin101lO7`507moO`@0PH612@20P804
07inOPD0Ph>31021PH4507moO`@0O7al1020P80507inOP@0P8202@21PH4407alO0D0P820101mOGd5
0861P@@0OWin101mOGd507inOP@0OGem1@1kNg/40820P0@0Ogmo1@1lO7`408>3P`D0P8201024Q8@4
08:2PPD0Q8B4101oOgl40861P@D0P8205P38h=P001D0b>3H1@0R8R8402d];@@08b<S1@0[:b/407Ee
M@D0Ng]k101hN7P406QXJ0D0L71`102XZ:P509jNWP@0TI6A101lO7`503Lg=`@092@T1@0U9BD402PX
:0@0:b/[1@0T92@405IFEP@0FUYJ1@10@40404a<C0D0EEEE101QHF44075aL@D0M7Ad101kNg/507em
O@P0P8201@25QHD408N7Q`D0Rh^;102<S8`9096AT@@0U9BD2@2HV9P409JFUPT0VIVI1@2LW9`409fM
W@@0WYjN2@2PX:050::RXP@0WinO102IVIT509JFUP@0S8b<1@2;Rh/407IfMP@0L71`1@1jNWX408B4
Q0D0R8R81027QhL408Z:RPD0QhN71020P80507emO@d0b>3H1025QHD40861P@D0OWin101lO7`508J6
QP@0NWYj101iNGT507emO@@0P8201@1cLg<4079bLPT0TY:B102@T90408:2PPD0Q8B42@22PX8407in
OP@0P8201@1nOWh408F5Q@D0Ph>31020P80407]kN`D0Q8B4101nOWh508>3P`@0OWin101lO7`507mo
O`@0PH612@20P80407inOPD0Ph>31021PH4507moO`@0O7al1020P80507inOP@0P8202@21PH4407al
O0D0P820101mOGd50861P@@0OWin101mOGd507inOP@0OGem1@1kNg/40820P0@0Ogmo1@1lO7`408>3
P`D0P8201024Q8@408:2PPD0Q8B4101oOgl40861P@D0P8205P38h=P001D0b>3H1@0R8R8402d];@@0
8b<S1@0[:b/407EeM@D0Ng]k101hN7P406QXJ0D0L71`102XZ:P509jNWP@0TI6A101lO7`503Lg=`@0
92@T1@0U9BD402PX:0@0:b/[1@0T92@405IFEP@0FUYJ1@10@40404a<C0D0EEEE101QHF44075aL@D0
M7Ad101kNg/507emO@P0P8201@25QHD408N7Q`D0Rh^;102<S8`9096AT@@0U9BD2@2HV9P409JFUPT0
VIVI1@2LW9`409fMW@@0WYjN2@2PX:050::RXP@0WinO102IVIT509JFUP@0S8b<1@2;Rh/407IfMP@0
L71`1@1jNWX408B4Q0D0R8R81027QhL408Z:RPD0QhN71020P80507emO@d0b>3H1025QHD40861P@D0
OWin101lO7`508J6QP@0NWYj101iNGT507emO@@0P8201@1cLg<4079bLPT0TY:B102@T90408:2PPD0
Q8B42@22PX8407inOP@0P8201@1nOWh408F5Q@D0Ph>31020P80407]kN`D0Q8B4101nOWh508>3P`@0
OWin101lO7`507moO`@0PH612@20P80407inOPD0Ph>31021PH4507moO`@0O7al1020P80507inOP@0
P8202@21PH4407alO0D0P820101mOGd50861P@@0OWin101mOGd507inOP@0OGem1@1kNg/40820P0@0
Ogmo1@1lO7`408>3P`D0P8201024Q8@408:2PPD0Q8B4101oOgl40861P@D0P8205P38h=P001D0b>3H
1@0R8R8402d];@@08b<S1@0[:b/407EeM@D0Ng]k101hN7P406QXJ0D0L71`102XZ:P509jNWP@0TI6A
101lO7`503Lg=`@092@T1@0U9BD402PX:0@0:b/[1@0T92@405IFEP@0FUYJ1@10@40404a<C0D0EEEE
101QHF44075aL@D0M7Ad101kNg/507emO@P0P8201@25QHD408N7Q`D0Rh^;102<S8`9096AT@@0U9BD
2@2HV9P409JFUPT0VIVI1@2LW9`409fMW@@0WYjN2@2PX:050::RXP@0WinO102IVIT509JFUP@0S8b<
1@2;Rh/407IfMP@0L71`1@1jNWX408B4Q0D0R8R81027QhL408Z:RPD0QhN71020P80507emO@d0b>3H
1025QHD40861P@D0OWin101lO7`508J6QP@0NWYj101iNGT507emO@@0P8201@1cLg<4079bLPT0TY:B
102@T90408:2PPD0Q8B42@22PX8407inOP@0P8201@1nOWh408F5Q@D0Ph>31020P80407]kN`D0Q8B4
101nOWh508>3P`@0OWin101lO7`507moO`@0PH612@20P80407inOPD0Ph>31021PH4507moO`@0O7al
1020P80507inOP@0P8202@21PH4407alO0D0P820101mOGd50861P@@0OWin101mOGd507inOP@0OGem
1@1kNg/40820P0@0Ogmo1@1lO7`408>3P`D0P8201024Q8@408:2PPD0Q8B4101oOgl40861P@D0P820
5P38h=P001D0b>3H1@0X:2P802l_;`D07QhN100e=CD5055AD@@0PH61101dM7@507]kN`@0XZ:R1@3=
cLd40:ZZZP@0Shn?1@0T92@402<S8`D09bLW100U9BD402TY:@D092@T101DE5@405YJFPD0?3`l101;
Bd/505IFEP@0HV9R101]KFd507EeM@@0NWYj1@1nOWh408:2PP@0Ph>31@26QXH408N7Q`D0QXJ6102:
RXX4096AT@T0UIFE1@2GUiL809JFUPD0VIVI102KVi/509nOW`P0XJ6Q1@2SXj<90::RXP@0WinO102K
Vi/509FEU@@0T92@1@2>SXh408:2PPT0MgMg1021PH4908J6QP@0Ogmo1@1lO7`407YjNPD0Ng]k3@38
h=P407moO`@0Ph>31@1mOGd407MgM`D0OGem1029RHT407emO@T0PH611@1kNg/408F5Q@@0MWIf1@1d
M7@807emO@D0O7al1024Q8@507moO`@0NWYj101oOgl507emO@@0QHF51@23Ph<40861P@@0QHF51@1n
OWh407moO`D0O7al101oOgl407alO0D0Ogmo1020P80507moO`@0OWin1022PX850820P0T0Ogmo1021
PH4408:2PPT0OWin1@22PX840861P@@0OGem2@21PH4507emO@@0O7al101nOWh507moO`@0P8202@1o
Ogl40861P@D0Ogmo1020P80508>3P`d0P820101oOgl90820P1H0b>3H000E0<SPf0D0:2PX200_;bl5
01hN7P@0=CDe1@1ADE440861P@@0M7Ad1@1kNg/40::RXPD0cLg=102ZZZX408n?S`D092@T100S8b<5
02LW9`@09BDU100Y:BT502@T90@0E5AD101JFUX503`l?0@0Bd];1@1FEUH4069RHP@0KFe]1@1eMGD4
07YjNPD0OWin1022PX8408>3P`D0QXJ61027QhL508J6QP@0RXZ:102ATI4909FEU@D0UiNG202FUYH5
09VIV@@0Vi^K1@2OWil80:6QX@D0Xj>S2@2RXZ8409nOW`@0Vi^K1@2EUID4092@T0D0SXj>1022PX89
07MgM`@0PH612@26QXH407moO`D0O7al101jNWX507]kN`d0b>3H101oOgl408>3P`D0OGem101gMgL5
07emO@@0RHV9101mOGd90861P@D0Ng]k1025QHD407IfMPD0M7Ad201mOGd507alO0@0Q8B41@1oOgl4
07YjNP@0Ogmo1@1mOGd408F5Q@D0Ph>31021PH4408F5Q@D0OWin101oOgl507alO0@0Ogmo101lO7`5
07moO`@0P8201@1oOgl407inOP@0PX:21@20P80907moO`@0PH611022PX8907inOPD0PX:21021PH44
07emO@T0PH611@1mOGd407alO0@0OWin1@1oOgl40820P0T0Ogmo1021PH4507moO`@0P8201@23Ph<=
0820P0@0Ogmo2@20P80F0<SPf0005@38h=P502PX:0P0;bl_1@0N7Qh403De=@D0DE5A1021PH4407Ad
M0D0Ng]k102RXZ850<g=c@@0ZZZZ102?Shl502@T90@08b<S1@0W9bL402DU9@@0:BTY1@0T92@405AD
E0@0FUYJ1@0l?3`404];B`D0EUIF101RHV8406e]K@D0MGEe101jNWX507inOP@0PX:21023Ph<508J6
QP@0QhN71@26QXH408Z:RP@0TI6A2@2EUID509NGU`P0UYJF1@2IVIT409^KV`D0WinO202QXJ450:>S
X`T0XZ:R102OWil409^KV`D0UIFE102@T90508j>SP@0PX:22@1gMgL40861P@T0QXJ6101oOgl507al
O0@0NWYj1@1kNg/=0<SPf0@0Ogmo1023Ph<507emO@@0MgMg1@1mOGd408V9R@@0OGem2@21PH4507]k
N`@0QHF5101fMWH507AdM0P0OGem1@1lO7`408B4Q0D0Ogmo101jNWX407moO`D0OGem1025QHD508>3
P`@0PH611025QHD507inOP@0Ogmo1@1lO7`407moO`@0O7al1@1oOgl40820P0D0Ogmo101nOWh408:2
PPD0P8202@1oOgl40861P@@0PX:22@1nOWh508:2PP@0PH61101mOGd90861P@D0OGem101lO7`407in
OPD0Ogmo1020P80907moO`@0PH611@1oOgl40820P0D0Ph>33@20P80407moO`T0P8205P38h=P001D0
b>3H1@0X:2P802l_;`D07QhN100e=CD5055AD@@0PH61101dM7@507]kN`@0XZ:R1@3=cLd40:ZZZP@0
Shn?1@0T92@402<S8`D09bLW100U9BD402TY:@D092@T101DE5@405YJFPD0?3`l101;Bd/505IFEP@0
HV9R101]KFd507EeM@@0NWYj1@1nOWh408:2PP@0Ph>31@26QXH408N7Q`D0QXJ6102:RXX4096AT@T0
UIFE1@2GUiL809JFUPD0VIVI102KVi/509nOW`P0XJ6Q1@2SXj<90::RXP@0WinO102KVi/509FEU@@0
T92@1@2>SXh408:2PPT0MgMg1021PH4908J6QP@0Ogmo1@1lO7`407YjNPD0Ng]k3@38h=P407moO`@0
Ph>31@1mOGd407MgM`D0OGem1029RHT407emO@T0PH611@1kNg/408F5Q@@0MWIf1@1dM7@807emO@D0
O7al1024Q8@507moO`@0NWYj101oOgl507emO@@0QHF51@23Ph<40861P@@0QHF51@1nOWh407moO`D0
O7al101oOgl407alO0D0Ogmo1020P80507moO`@0OWin1022PX850820P0T0Ogmo1021PH4408:2PPT0
OWin1@22PX840861P@@0OGem2@21PH4507emO@@0O7al101nOWh507moO`@0P8202@1oOgl40861P@D0
Ogmo1020P80508>3P`d0P820101oOgl90820P1H0b>3H000E0<SPf0D08b<S200a<C45028R8P@08b<S
1@0R8R8407alO0@0OWin1@1cLg<408>3P`D0alO7103:b/X40<o?c`D0G5aL100T92@502TY:@@09bLW
100V9RH5024Q8@@0CTi>101BDU8503lo?`@0Bd];1@1JFUX406ATI0@0L71`1@1gMgL407YjNPD0Ogmo
1023Ph<408:2PPD0QHF51027QhL508n?S`@0SXj>102@T90509BDU0@0UIFE2@2GUiL409bLW0D0Vi^K
102LW9`509fMW@@0X:2P102VYZH50:>SX`@0XJ6Q1@2PX:040::RXP@0WYjN1@2IVIT409:BTPD0Rh^;
1025QHD907moO`@0OGem2@23Ph<407alO0D0OWin2@1iNGT=0<SPf0@0OGem1020P80508R8R0T0PX:2
101nOWh908:2PP@0PH611@23Ph<407emO@@0PX:21@25QHD407QhN0@0RHV91@1nOWh40861P@D0O7al
1023Ph<407inOPT0OGem1@25QHD408B4Q0@0OWin1@21PH4907moO`@0P8201023Ph<907emO@D0P820
101mOGd40861P@D0OWin1023Ph<507alO0P0PX:21@1nOWh40820P0D0OWin2020P80507moO`@0PH61
1@1oOgl40861P@@0OWin1@1mOGd407inOPD0Ogmo101mOGd40861P@D0OGem1020P80507emO@@0Ph>3
2@1mOGd40820P0@0Ogmo1@1nOWhF0<SPf0005@38h=P502<S8`P0<C4a1@0R8R8402<S8`D08R8R101l
O7`407inOPD0Lg=c1023Ph<50<O7a`@0b/[:103?cll505aLG0@092@T1@0Y:BT402LW9`@09RHV1@0Q
8B4404i>CP@0DU9B1@0o?cl404];B`D0FUYJ101TI6@4071`L0D0MgMg101jNWX507moO`@0Ph>31022
PX8508F5Q@@0QhN71@2?Shl408j>SP@0T92@1@2DU9@409FEU@T0UiNG102LW9`509^KV`@0W9bL1@2M
WId40:2PX0@0YZJV1@2SXj<40:6QX@D0X:2P102RXZ8409jNWPD0VIVI102BTY8508^;R`@0QHF52@1o
Ogl407emO@T0Ph>3101lO7`507inOPT0NGUi3@38h=P407emO@@0P8201@28R8P908:2PP@0OWin2@22
PX840861P@D0Ph>3101mOGd408:2PPD0QHF5101hN7P408V9R@D0OWin1021PH4507alO0@0Ph>3101n
OWh907emO@D0QHF51024Q8@407inOPD0PH612@1oOgl40820P0@0Ph>32@1mOGd50820P0@0OGem1021
PH4507inOP@0Ph>31@1lO7`808:2PPD0OWin1020P80507inOPP0P8201@1oOgl40861P@D0Ogmo1021
PH4407inOPD0OGem101nOWh507moO`@0OGem1021PH4507emO@@0P8201@1mOGd408>3P`T0OGem1020
P80407moO`D0OWin5P38h=P001D0b>3H1@0S8b<8034a<@D08R8R100S8b<5028R8P@0O7al101nOWh5
07=cL`@0Ph>31@37alL40<[:bP@0clo?1@1LG5`402@T90D0:BTY100W9bL402HV9PD08B4Q101>CTh4
059BDPD0?clo101;Bd/505YJFP@0I6AT101`L70507MgM`@0NWYj1@1oOgl408>3P`@0PX:21@25QHD4
08N7Q`D0Shn?102>SXh4092@T0D0U9BD102EUID909NGU`@0W9bL1@2KVi/409bLW0D0WIfM102PX:04
0:JVYPD0Xj>S102QXJ450:2PX0@0XZ:R102NWYh509VIV@@0TY:B1@2;Rh/408F5Q@T0Ogmo101mOGd9
08>3P`@0O7al1@1nOWh907UiN@d0b>3H101mOGd40820P0D0R8R82@22PX8407inOPT0PX:21021PH45
08>3P`@0OGem1022PX8508F5Q@@0N7Qh1029RHT507inOP@0PH611@1lO7`408>3P`@0OWin2@1mOGd5
08F5Q@@0Q8B4101nOWh50861P@T0Ogmo1020P80408>3P`T0OGem1@20P80407emO@@0PH611@1nOWh4
08>3P`D0O7al2022PX8507inOP@0P8201@1nOWh80820P0D0Ogmo1021PH4507moO`@0PH61101nOWh5
07emO@@0OWin1@1oOgl407emO@@0PH611@1mOGd40820P0D0OGem1023Ph<907emO@@0P820101oOgl5
07inOQH0b>3H000E0<SPf0D08b<S200a<C45028R8P@08b<S1@0R8R8407alO0@0OWin1@1cLg<408>3
P`D0alO7103:b/X40<o?c`D0G5aL100T92@502TY:@@09bLW100V9RH5024Q8@@0CTi>101BDU8503lo
?`@0Bd];1@1JFUX406ATI0@0L71`1@1gMgL407YjNPD0Ogmo1023Ph<408:2PPD0QHF51027QhL508n?
S`@0SXj>102@T90509BDU0@0UIFE2@2GUiL409bLW0D0Vi^K102LW9`509fMW@@0X:2P102VYZH50:>S
X`@0XJ6Q1@2PX:040::RXP@0WYjN1@2IVIT409:BTPD0Rh^;1025QHD907moO`@0OGem2@23Ph<407al
O0D0OWin2@1iNGT=0<SPf0@0OGem1020P80508R8R0T0PX:2101nOWh908:2PP@0PH611@23Ph<407em
O@@0PX:21@25QHD407QhN0@0RHV91@1nOWh40861P@D0O7al1023Ph<407inOPT0OGem1@25QHD408B4
Q0@0OWin1@21PH4907moO`@0P8201023Ph<907emO@D0P820101mOGd40861P@D0OWin1023Ph<507al
O0P0PX:21@1nOWh40820P0D0OWin2020P80507moO`@0PH611@1oOgl40861P@@0OWin1@1mOGd407in
OPD0Ogmo101mOGd40861P@D0OGem1020P80507emO@@0Ph>32@1mOGd40820P0@0Ogmo1@1nOWhF0<SP
f0005@38h=P502PX:0P0DU9B1@0N7Qh401lO7`D07AdM101?Cdl408j>SPD0LG5a101gMgL50:>SX`@0
bLW91038b<P50<?3``@0>c/k1@0W9bL402DU9@T092@T1018B4P404U9B@D0>c/k1019BDT505MGE`@0
IfMW101`L70507MgM`@0P8201@1lO7`408>3P`@0PH611@27QhL408Z:RPD0QhN7102ATI4909>CT`@0
VIVI1@2HV9P409nOW`@0XJ6Q1@2MWId40:2PX0D0Xj>S102VYZH40:FUY@D0YZJV102WYjL50:FUY@@0
Xj>S102TY:@509jNWP@0UIFE1@2?Shl408V9R@@0Q8B41@21PH4408B4Q0D0PX:2201mOGd507QhN0@0
NWYj1@1lO7`=0<SPf0@0O7al101nOWh506e]K@@0OGem1@21PH4407emO@@0P8201@1kNg/407inOPD0
N7Qh101oOgl40861P@D0Ph>3101mOGd408F5Q@D0P820101mOGd508F5Q@@0Ogmo101mOGd50861P@@0
P8201@1kNg/40820P0@0O7al1@23Ph<407inOPD0QHF5101mOGd40820P0D0Ogmo101nOWh507moO`@0
PH61101mOGd50861P@@0Ogmo1@22PX8407moO`T0PX:21023Ph<508:2PP@0Ng]k101iNGT50820P0@0
Ogmo1@20P80407moO`@0Ph>31@21PH4407inOPD0P8203@1nOWh40861P@D0OWin101mOGd=07moO`@0
OWin1@20P80F0<SPf0005@38h=P502PX:0P0DU9B1@0N7Qh401lO7`D07AdM101?Cdl408j>SPD0LG5a
101gMgL50:>SX`@0bLW91038b<P50<?3``@0>c/k1@0W9bL402DU9@T092@T1018B4P404U9B@D0>c/k
1019BDT505MGE`@0IfMW101`L70507MgM`@0P8201@1lO7`408>3P`@0PH611@27QhL408Z:RPD0QhN7
102ATI4909>CT`@0VIVI1@2HV9P409nOW`@0XJ6Q1@2MWId40:2PX0D0Xj>S102VYZH40:FUY@D0YZJV
102WYjL50:FUY@@0Xj>S102TY:@509jNWP@0UIFE1@2?Shl408V9R@@0Q8B41@21PH4408B4Q0D0PX:2
201mOGd507QhN0@0NWYj1@1lO7`=0<SPf0@0O7al101nOWh506e]K@@0OGem1@21PH4407emO@@0P820
1@1kNg/407inOPD0N7Qh101oOgl40861P@D0Ph>3101mOGd408F5Q@D0P820101mOGd508F5Q@@0Ogmo
101mOGd50861P@@0P8201@1kNg/40820P0@0O7al1@23Ph<407inOPD0QHF5101mOGd40820P0D0Ogmo
101nOWh507moO`@0PH61101mOGd50861P@@0Ogmo1@22PX8407moO`T0PX:21023Ph<508:2PP@0Ng]k
101iNGT50820P0@0Ogmo1@20P80407moO`@0Ph>31@21PH4407inOPD0P8203@1nOWh40861P@D0OWin
101mOGd=07moO`@0OWin1@20P80F0<SPf0005@38h=P502PX:0P0DU9B1@0N7Qh401lO7`D07AdM101?
Cdl408j>SPD0LG5a101gMgL50:>SX`@0bLW91038b<P50<?3``@0>c/k1@0W9bL402DU9@T092@T1018
B4P404U9B@D0>c/k1019BDT505MGE`@0IfMW101`L70507MgM`@0P8201@1lO7`408>3P`@0PH611@27
QhL408Z:RPD0QhN7102ATI4909>CT`@0VIVI1@2HV9P409nOW`@0XJ6Q1@2MWId40:2PX0D0Xj>S102V
YZH40:FUY@D0YZJV102WYjL50:FUY@@0Xj>S102TY:@509jNWP@0UIFE1@2?Shl408V9R@@0Q8B41@21
PH4408B4Q0D0PX:2201mOGd507QhN0@0NWYj1@1lO7`=0<SPf0@0O7al101nOWh506e]K@@0OGem1@21
PH4407emO@@0P8201@1kNg/407inOPD0N7Qh101oOgl40861P@D0Ph>3101mOGd408F5Q@D0P820101m
OGd508F5Q@@0Ogmo101mOGd50861P@@0P8201@1kNg/40820P0@0O7al1@23Ph<407inOPD0QHF5101m
OGd40820P0D0Ogmo101nOWh507moO`@0PH61101mOGd50861P@@0Ogmo1@22PX8407moO`T0PX:21023
Ph<508:2PP@0Ng]k101iNGT50820P0@0Ogmo1@20P80407moO`@0Ph>31@21PH4407inOPD0P8203@1n
OWh40861P@D0OWin101mOGd=07moO`@0OWin1@20P80F0<SPf0005@38h=P502PX:0P0DU9B1@0N7Qh4
01lO7`D07AdM101?Cdl408j>SPD0LG5a101gMgL50:>SX`@0bLW91038b<P50<?3``@0>c/k1@0W9bL4
02DU9@T092@T1018B4P404U9B@D0>c/k1019BDT505MGE`@0IfMW101`L70507MgM`@0P8201@1lO7`4
08>3P`@0PH611@27QhL408Z:RPD0QhN7102ATI4909>CT`@0VIVI1@2HV9P409nOW`@0XJ6Q1@2MWId4
0:2PX0D0Xj>S102VYZH40:FUY@D0YZJV102WYjL50:FUY@@0Xj>S102TY:@509jNWP@0UIFE1@2?Shl4
08V9R@@0Q8B41@21PH4408B4Q0D0PX:2201mOGd507QhN0@0NWYj1@1lO7`=0<SPf0@0O7al101nOWh5
06e]K@@0OGem1@21PH4407emO@@0P8201@1kNg/407inOPD0N7Qh101oOgl40861P@D0Ph>3101mOGd4
08F5Q@D0P820101mOGd508F5Q@@0Ogmo101mOGd50861P@@0P8201@1kNg/40820P0@0O7al1@23Ph<4
07inOPD0QHF5101mOGd40820P0D0Ogmo101nOWh507moO`@0PH61101mOGd50861P@@0Ogmo1@22PX84
07moO`T0PX:21023Ph<508:2PP@0Ng]k101iNGT50820P0@0Ogmo1@20P80407moO`@0Ph>31@21PH44
07inOPD0P8203@1nOWh40861P@D0OWin101mOGd=07moO`@0OWin1@20P80F0<SPf0005@38h=P502PX
:0P0DU9B1@0N7Qh401lO7`D07AdM101?Cdl408j>SPD0LG5a101gMgL50:>SX`@0bLW91038b<P50<?3
``@0>c/k1@0W9bL402DU9@T092@T1018B4P404U9B@D0>c/k1019BDT505MGE`@0IfMW101`L70507Mg
M`@0P8201@1lO7`408>3P`@0PH611@27QhL408Z:RPD0QhN7102ATI4909>CT`@0VIVI1@2HV9P409nO
W`@0XJ6Q1@2MWId40:2PX0D0Xj>S102VYZH40:FUY@D0YZJV102WYjL50:FUY@@0Xj>S102TY:@509jN
WP@0UIFE1@2?Shl408V9R@@0Q8B41@21PH4408B4Q0D0PX:2201mOGd507QhN0@0NWYj1@1lO7`=0<SP
f0@0O7al101nOWh506e]K@@0OGem1@21PH4407emO@@0P8201@1kNg/407inOPD0N7Qh101oOgl40861
P@D0Ph>3101mOGd408F5Q@D0P820101mOGd508F5Q@@0Ogmo101mOGd50861P@@0P8201@1kNg/40820
P0@0O7al1@23Ph<407inOPD0QHF5101mOGd40820P0D0Ogmo101nOWh507moO`@0PH61101mOGd50861
P@@0Ogmo1@22PX8407moO`T0PX:21023Ph<508:2PP@0Ng]k101iNGT50820P0@0Ogmo1@20P80407mo
O`@0Ph>31@21PH4407inOPD0P8203@1nOWh40861P@D0OWin101mOGd=07moO`@0OWin1@20P80F0<SP
f0005@38h=P503dm?@@0Jf][101iNGT502TY:@@07QhN1@0M7Ad402/[:`@0Shn?1@1iNGT4075aL@D0
QhN71032`/840<S8b0D0b/[:102TY:@502PX:0P09BDU1@0Q8B4404I6AP@0@d=31@0h>3P404M7A`D0
FUYJ101XJ6P406m_K`D0N7Qh101mOGd50861P@P0PX:21@24Q8@408V9R@D0S8b<102ATI4409FEU@D0
V9RH102KVi/509bLW0@0XJ6Q102RXZ8509nOW`@0YZJV1@2YZJT40:FUY@@0Zj^[1@2XZ:P40:VYZ@D0
Z:RX202SXj<509bLW0@0VIVI1@2BTY8408R8R0@0QXJ61@23Ph<408F5Q@D0Q8B42020P80507UiN@@0
Ng]k1@1lO7`=0<SPf0@0Ogmo1024Q8@508j>SP@0P8201@1mOGd407moO`@0OWin1@1jNWX408:2PPD0
Ogmo201lO7`50820P0@0Ph>3101cLg<508F5Q@@0Ng]k1@26QXH408:2PP@0PH611@1mOGd407moO`D0
Ph>3101oOgl408:2PPT0P8201@21PH4408:2PP@0P8201@1lO7`40820P0D0Ogmo101mOGd40820P0D0
Ph>31022PX8507moO`@0Ph>3101kNg/507moO`@0PH611@20P80407inOP@0PX:21@1lO7`408B4Q0T0
Ogmo101kNg/507inOP@0OGem1@1lO7`408:2PP@0Ph>31@21PH4407emO@D0OWin101oOgl407emO@D0
OWin1022PX8407inOPD0Ogmo5P38h=P001D0b>3H1@0m?Cd406][J`@0NGUi1@0Y:BT401hN7PD07AdM
100[:b/408n?S`D0NGUi101aLG4508N7Q`@0`/;21038b<P50<[:bP@0Y:BT1@0X:2P802DU9@D08B4Q
1016ATH404=3@`D0>3Ph1017AdL505YJFP@0J6QX101_Kfl507QhN0@0OGem1@21PH4808:2PPD0Q8B4
1029RHT508b<S0@0TI6A102EUID509RHV0@0Vi^K1@2LW9`40:6QX@@0XZ:R1@2OWil40:JVYPD0ZJVY
102UYJD40:^[Z`D0Z:RX102YZJT50:RXZ0P0Xj>S1@2LW9`409VIV@D0TY:B1028R8P408J6QPD0Ph>3
1025QHD508B4Q0P0P8201@1iNGT407]kN`D0O7al3@38h=P407moO`@0Q8B41@2>SXh40820P0D0OGem
101oOgl407inOPD0NWYj1022PX8507moO`P0O7al1@20P80408>3P`@0Lg=c1@25QHD407]kN`D0QXJ6
1022PX840861P@D0OGem101oOgl508>3P`@0Ogmo1022PX890820P0D0PH611022PX840820P0D0O7al
1020P80507moO`@0OGem1020P80508>3P`@0PX:21@1oOgl408>3P`@0Ng]k1@1oOgl40861P@D0P820
101nOWh408:2PPD0O7al1024Q8@907moO`@0Ng]k1@1nOWh407emO@D0O7al1022PX8408>3P`D0PH61
101mOGd507inOP@0Ogmo101mOGd507inOP@0PX:2101nOWh507moOaH0b>3H000E0<SPf0D0?Cdm101[
Jf/407UiN@D0:BTY100N7Qh501dM7@@0:b/[102?Shl507UiN@@0LG5a1@27QhL40<;2`P@0b<S81@3:
b/X40:BTY0D0:2PX200U9BD5024Q8@@0ATI61013@d<503Ph>0@0AdM71@1JFUX406QXJ0@0Kfm_1@1h
N7P407emO@D0PH612022PX8508B4Q0@0RHV91@2<S8`4096AT@@0UIFE1@2HV9P409^KV`D0W9bL102Q
XJ440::RXPD0WinO102VYZH50:VYZ@@0YJFU102[Zj/50:RXZ0@0ZJVY1@2XZ:P80:>SX`D0W9bL102I
VIT509:BTP@0R8R81026QXH508>3P`@0QHF51@24Q8@80820P0D0NGUi101kNg/507alO0d0b>3H101o
Ogl408B4Q0D0SXj>1020P80507emO@@0Ogmo101nOWh507YjNP@0PX:21@1oOgl807alO0D0P8201023
Ph<407=cL`D0QHF5101kNg/508J6QP@0PX:21021PH4507emO@@0Ogmo1@23Ph<407moO`@0PX:22@20
P8050861P@@0PX:21020P80507alO0@0P8201@1oOgl407emO@@0P8201@23Ph<408:2PPD0Ogmo1023
Ph<407]kN`D0Ogmo1021PH450820P0@0OWin1022PX8507alO0@0Q8B42@1oOgl407]kN`D0OWin101m
OGd507alO0@0PX:21023Ph<50861P@@0OGem1@1nOWh407moO`@0OGem1@1nOWh408:2PP@0OWin1@1o
OglF0<SPf0005@38h=P503dm?@@0Jf][101iNGT502TY:@@07QhN1@0M7Ad402/[:`@0Shn?1@1iNGT4
075aL@D0QhN71032`/840<S8b0D0b/[:102TY:@502PX:0P09BDU1@0Q8B4404I6AP@0@d=31@0h>3P4
04M7A`D0FUYJ101XJ6P406m_K`D0N7Qh101mOGd50861P@P0PX:21@24Q8@408V9R@D0S8b<102ATI44
09FEU@D0V9RH102KVi/509bLW0@0XJ6Q102RXZ8509nOW`@0YZJV1@2YZJT40:FUY@@0Zj^[1@2XZ:P4
0:VYZ@D0Z:RX202SXj<509bLW0@0VIVI1@2BTY8408R8R0@0QXJ61@23Ph<408F5Q@D0Q8B42020P805
07UiN@@0Ng]k1@1lO7`=0<SPf0@0Ogmo1024Q8@508j>SP@0P8201@1mOGd407moO`@0OWin1@1jNWX4
08:2PPD0Ogmo201lO7`50820P0@0Ph>3101cLg<508F5Q@@0Ng]k1@26QXH408:2PP@0PH611@1mOGd4
07moO`D0Ph>3101oOgl408:2PPT0P8201@21PH4408:2PP@0P8201@1lO7`40820P0D0Ogmo101mOGd4
0820P0D0Ph>31022PX8507moO`@0Ph>3101kNg/507moO`@0PH611@20P80407inOP@0PX:21@1lO7`4
08B4Q0T0Ogmo101kNg/507inOP@0OGem1@1lO7`408:2PP@0Ph>31@21PH4407emO@D0OWin101oOgl4
07emO@D0OWin1022PX8407inOPD0Ogmo5P38h=P001D0b>3H1@1HF5P409RHV0@0T92@1@0^;Rh4028R
8PD08b<S100O7al405YJFPD0Shn?101^KVh507MgM`@0]KFe1039bLT50<_;b`@0c/k>1@24Q8@402<S
8`@09bLW1@0S8b<40492@P@0?Cdm1@0c<c<404U9B@D0Fe]K101VIVH4071`L0D0MWIf101kNg/908:2
PPT0QHF5102:RXX508n?S`@0TI6A2@2GUiL409fMW@D0WYjN102OWil40:2PX0D0YJFU102/[:`50:^[
Z`@0ZJVY102ZZZX50:f][@@0ZJVY1@2ZZZX40:FUY@@0Y:BT1@2PX:0409VIV@D0U9BD1029RHT908F5
Q@@0QhN71@24Q8@40861P@@0OWin1@1iNGT407YjNPD0P8203@38h=P408V9R@@0NGUi1@1nOWh407al
O0D0Ogmo1023Ph<407inOPD0QHF52@1nOWh40820P0@0OGem1@1oOgl40820P0@0Q8B41@1mOGd408:2
PPD0Ogmo1025QHD40861P@D0Ogmo1020P80507moO`@0PH611024Q8@508>3P`d0PH61101mOGd50820
P0@0PX:21@1lO7`408F5Q@@0Ogmo1@1lO7`407inOPD0Ogmo1022PX8407moO`T0P8201@1nOWh40861
P@@0OGem1@22PX8407moO`D0P8201022PX8407moO`D0PH611022PX8508B4Q0P0Ogmo1@1nOWh40861
P@D0P820101oOgl90861P@@0Ng]k2@21PH4F0<SPf0005@38h=P505QHF0@0V9RH102@T90502h^;P@0
8R8R1@0S8b<401lO7`@0FUYJ1@2?Shl406i^KPD0MgMg102e]KD40<W9b@D0bl_;103>c/h508B4Q0@0
8b<S100W9bL502<S8`@0@T92100m?Cd503<c<`@0BDU91@1KFe/406IVIP@0L71`1@1fMWH407]kN`T0
PX:22@25QHD408Z:RPD0Shn?102ATI4909NGU`@0WIfM1@2NWYh409nOW`@0X:2P1@2UYJD40:b/[0D0
Zj^[102YZJT40:ZZZPD0[Jf]102YZJT50:ZZZP@0YJFU102TY:@50:2PX0@0VIVI1@2DU9@408V9R@T0
QHF51027QhL508B4Q0@0PH61101nOWh507UiN@@0NWYj1@20P80=0<SPf0@0RHV9101iNGT507inOP@0
O7al1@1oOgl408>3P`@0OWin1@25QHD907inOP@0P820101mOGd507moO`@0P8201024Q8@507emO@@0
PX:21@1oOgl408F5Q@@0PH611@1oOgl40820P0D0Ogmo1021PH4408B4Q0D0Ph>33@21PH4407emO@D0
P8201022PX8507alO0@0QHF5101oOgl507alO0@0OWin1@1oOgl408:2PP@0Ogmo2@20P80507inOP@0
PH61101mOGd508:2PP@0Ogmo1@20P80408:2PP@0Ogmo1@21PH4408:2PPD0Q8B4201oOgl507inOP@0
PH611@20P80407moO`T0PH61101kNg/90861PAH0b>3H000E0<SPf0D0F5QH102HV9P4092@T0D0;Rh^
100R8R8502<S8`@07alO101JFUX508n?S`@0KVi^1@1gMgL40;Fe]@@0bLW91@3;bl/40<k>cPD0Q8B4
100S8b<402LW9`D08b<S1012@T8403dm?@D0<c<c1019BDT505]KF`@0IVIV101`L70507IfMP@0Ng]k
2@22PX8908F5Q@@0RXZ:1@2?Shl4096AT@T0UiNG102MWId509jNWP@0WinO102PX:050:FUY@@0[:b/
1@2[Zj/40:VYZ@@0ZZZZ1@2][Jd40:VYZ@D0ZZZZ102UYJD40:BTY0D0X:2P102IVIT509BDU0@0RHV9
2@25QHD408N7Q`D0Q8B41021PH4407inOPD0NGUi101jNWX50820P0d0b>3H1029RHT407UiN@D0OWin
101lO7`507moO`@0Ph>3101nOWh508F5Q@T0OWin1020P80407emO@D0Ogmo1020P80408B4Q0D0OGem
1022PX8507moO`@0QHF51021PH4507moO`@0P8201@1oOgl40861P@@0Q8B41@23Ph<=0861P@@0OGem
1@20P80408:2PPD0O7al1025QHD407moO`D0O7al101nOWh507moO`@0PX:2101oOgl90820P0D0OWin
1021PH4407emO@D0PX:2101oOgl50820P0@0PX:2101oOgl50861P@@0PX:21@24Q8@807moO`D0OWin
1021PH450820P0@0Ogmo2@21PH4407]kN`T0PH615P38h=P001D0b>3H1@1HF5P409RHV0@0T92@1@0^
;Rh4028R8PD08b<S100O7al405YJFPD0Shn?101^KVh507MgM`@0]KFe1039bLT50<_;b`@0c/k>1@24
Q8@402<S8`@09bLW1@0S8b<40492@P@0?Cdm1@0c<c<404U9B@D0Fe]K101VIVH4071`L0D0MWIf101k
Ng/908:2PPT0QHF5102:RXX508n?S`@0TI6A2@2GUiL409fMW@D0WYjN102OWil40:2PX0D0YJFU102/
[:`50:^[Z`@0ZJVY102ZZZX50:f][@@0ZJVY1@2ZZZX40:FUY@@0Y:BT1@2PX:0409VIV@D0U9BD1029
RHT908F5Q@@0QhN71@24Q8@40861P@@0OWin1@1iNGT407YjNPD0P8203@38h=P408V9R@@0NGUi1@1n
OWh407alO0D0Ogmo1023Ph<407inOPD0QHF52@1nOWh40820P0@0OGem1@1oOgl40820P0@0Q8B41@1m
OGd408:2PPD0Ogmo1025QHD40861P@D0Ogmo1020P80507moO`@0PH611024Q8@508>3P`d0PH61101m
OGd50820P0@0PX:21@1lO7`408F5Q@@0Ogmo1@1lO7`407inOPD0Ogmo1022PX8407moO`T0P8201@1n
OWh40861P@@0OGem1@22PX8407moO`D0P8201022PX8407moO`D0PH611022PX8508B4Q0P0Ogmo1@1n
OWh40861P@D0P820101oOgl90861P@@0Ng]k2@21PH4F0<SPf0005@38h=P507alO0@0Z:RX101XJ6P5
02DU9@@09RHV1@0X:2P402TY:@@0=3@d1@2<S8`4075aL@D0Kfm_102ATI440<[:bPD0aLG51039bLT5
0<o?c`@0ADE5100X:2P502DU9@@0?3`l2@0i>CT404e=C@D0GEeM101ZJVX4079bLPD0NGUi1020P809
0861P@@0QXJ61@29RHT408f=S@D0Shn?102EUID409NGU`D0V9RH2@2LW9`40:BTY0@0Z:RX1@2ZZZX4
0;6a/@D0[:b/102`/;040:n_[`D0[Jf]102XZ:P50:ZZZP@0YjNW102SXj<509nOW`@0VIVI1@2EUID4
08b<S0@0R8R81@27QhL408J6QPD0S8b<1021PH440820P0D0OGem101lO7`508:2PPd0b>3H101gMgL4
0820P0D0Ogmo2@22PX840861P@T0OGem101oOgl508:2PP@0OWin101lO7`90820P0@0OWin1@1oOgl9
07UiN@@0PX:2101iNGT508>3P`@0QhN71@28R8P407alO0T0Ogmo1020P80507alO0@0P8201023Ph<5
07YjNPd0OWin1022PX890861P@D0Ogmo101lO7`407inOPh0P820101oOgl408:2PPD0P820101kNg/5
0820P0@0OWin1021PH450820P0T0PH614@1lO7`507moO`@0PX:21020P8050861P@@0OWin101lO7`5
0820P1H0b>3H000E0<SPf0D0O7al102XZ:P406QXJ0D09BDU100V9RH502PX:0@0:BTY100d=3@508b<
S0@0LG5a1@1_Kfl4096AT@@0b/[:1@35aLD40<W9b@D0clo?1015ADD402PX:0D09BDU100l?3`903Ti
>@@0CDe=1@1MGEd406YZJP@0LW9b1@1iNGT40820P0T0PH611026QXH508V9R@@0SHf=1@2?Shl409FE
U@@0UiNG1@2HV9P909bLW0@0Y:BT102XZ:P50:ZZZP@0/K6a1@2/[:`40;2`/0@0[jn_1@2][Jd40:RX
Z0D0ZZZZ102WYjL40:>SX`D0WinO102IVIT509FEU@@0S8b<1028R8P508N7Q`@0QXJ61@2<S8`40861
P@@0P8201@1mOGd407alO0D0PX:23@38h=P407MgM`@0P8201@1oOgl908:2PP@0PH612@1mOGd407mo
O`D0PX:2101nOWh407alO0T0P820101nOWh507moO`T0NGUi1022PX8407UiN@D0Ph>31027QhL508R8
R0@0O7al2@1oOgl40820P0D0O7al1020P80408>3P`D0NWYj3@1nOWh408:2PPT0PH611@1oOgl407al
O0@0OWin3P20P80407moO`@0PX:21@20P80407]kN`D0P820101nOWh40861P@D0P8202@21PH4A07al
O0D0Ogmo1022PX840820P0D0PH61101nOWh407alO0D0P8205P38h=P001D0b>3H1@1lO7`40:RXZ0@0
J6QX1@0U9BD402HV9PD0:2PX100Y:BT403@d=0D0S8b<101aLG4506m_K`@0TI6A103:b/X50<G5a@@0
bLW91@3?cll404E5A@@0:2PX1@0U9BD403`l?0T0>CTi101=CDd505eMG@@0JVYZ101bLW8507UiN@@0
P8202@21PH4408J6QPD0RHV9102=SHd508n?S`@0UIFE102GUiL509RHV0T0W9bL102TY:@40:RXZ0D0
ZZZZ102a/K450:b/[0@0/;2`102_[jl50:f][@@0Z:RX1@2ZZZX40:NWY`@0Xj>S1@2OWil409VIV@D0
UIFE102<S8`408R8R0D0QhN71026QXH508b<S0@0PH611020P80507emO@@0O7al1@22PX8=0<SPf0@0
MgMg1020P80507moO`T0PX:21021PH4907emO@@0Ogmo1@22PX8407inOP@0O7al2@20P80407inOPD0
Ogmo2@1iNGT408:2PP@0NGUi1@23Ph<408N7Q`D0R8R8101lO7`907moO`@0P8201@1lO7`40820P0@0
Ph>31@1jNWX=07inOP@0PX:22@21PH4507moO`@0O7al101nOWh>0820P0@0Ogmo1022PX850820P0@0
Ng]k1@20P80407inOP@0PH611@20P8090861PA40O7al1@1oOgl408:2PP@0P8201@21PH4407inOP@0
O7al1@20P80F0<SPf0005@38h=P507alO0@0Z:RX101XJ6P502DU9@@09RHV1@0X:2P402TY:@@0=3@d
1@2<S8`4075aL@D0Kfm_102ATI440<[:bPD0aLG51039bLT50<o?c`@0ADE5100X:2P502DU9@@0?3`l
2@0i>CT404e=C@D0GEeM101ZJVX4079bLPD0NGUi1020P8090861P@@0QXJ61@29RHT408f=S@D0Shn?
102EUID409NGU`D0V9RH2@2LW9`40:BTY0@0Z:RX1@2ZZZX40;6a/@D0[:b/102`/;040:n_[`D0[Jf]
102XZ:P50:ZZZP@0YjNW102SXj<509nOW`@0VIVI1@2EUID408b<S0@0R8R81@27QhL408J6QPD0S8b<
1021PH440820P0D0OGem101lO7`508:2PPd0b>3H101gMgL40820P0D0Ogmo2@22PX840861P@T0OGem
101oOgl508:2PP@0OWin101lO7`90820P0@0OWin1@1oOgl907UiN@@0PX:2101iNGT508>3P`@0QhN7
1@28R8P407alO0T0Ogmo1020P80507alO0@0P8201023Ph<507YjNPd0OWin1022PX890861P@D0Ogmo
101lO7`407inOPh0P820101oOgl408:2PPD0P820101kNg/50820P0@0OWin1021PH450820P0T0PH61
4@1lO7`507moO`@0PX:21020P8050861P@@0OWin101lO7`50820P1H0b>3H000E0<SPf0D0O7al102X
Z:P406QXJ0D09BDU100V9RH502PX:0@0:BTY100d=3@508b<S0@0LG5a1@1_Kfl4096AT@@0b/[:1@35
aLD40<W9b@D0clo?1015ADD402PX:0D09BDU100l?3`903Ti>@@0CDe=1@1MGEd406YZJP@0LW9b1@1i
NGT40820P0T0PH611026QXH508V9R@@0SHf=1@2?Shl409FEU@@0UiNG1@2HV9P909bLW0@0Y:BT102X
Z:P50:ZZZP@0/K6a1@2/[:`40;2`/0@0[jn_1@2][Jd40:RXZ0D0ZZZZ102WYjL40:>SX`D0WinO102I
VIT509FEU@@0S8b<1028R8P508N7Q`@0QXJ61@2<S8`40861P@@0P8201@1mOGd407alO0D0PX:23@38
h=P407MgM`@0P8201@1oOgl908:2PP@0PH612@1mOGd407moO`D0PX:2101nOWh407alO0T0P820101n
OWh507moO`T0NGUi1022PX8407UiN@D0Ph>31027QhL508R8R0@0O7al2@1oOgl40820P0D0O7al1020
P80408>3P`D0NWYj3@1nOWh408:2PPT0PH611@1oOgl407alO0@0OWin3P20P80407moO`@0PX:21@20
P80407]kN`D0P820101nOWh40861P@D0P8202@21PH4A07alO0D0Ogmo1022PX840820P0D0PH61101n
OWh407alO0D0P8205P38h=P001D0b>3H1@2SXj<406YZJP@0<30`1@0[:b/4028R8PD092@T100V9RH4
02LW9`D0JVYZ1027QhL506m_K`@0NWYj102j^[X50;bl_0@0a/K61@3=cLd40:FUY@@0:RXZ1@0W9bL4
03De=@@0<S8b1@0i>CT404U9B@D0GemO101[Jf/407QhN0D0NGUi101kNg/50820P0@0QHF51023Ph<5
08Z:RP@0S8b<1@2@T90409FEU@T0V9RH102IVIT509fMW@@0Y:BT102VYZH50:VYZ@@0/;2`1@2][Jd8
0;6a/@D0[Zj^102YZJT50:^[Z`@0Z:RX102VYZH50:2PX0@0W9bL1@2DU9@409:BTP@0S8b<1@29RHT4
08b<S0D0RXZ:1025QHD40820P0D0O7al101mOGd508:2PPd0b>3H1024Q8@408:2PPD0P820101fMWH5
0820P0@0Ogmo101jNWX90820P0D0Ng]k101nOWh407emO@D0OWin1021PH440820P0D0PH61101eMGD5
08J6QP@0OGem101jNWX50861P@@0OWin1@21PH4408F5Q@@0PH611@1lO7`908:2PP@0PH61101mOGd5
07moO`T0PH611020P80407moO`D0OGem2@21PH4408B4Q0@0OWin1@22PX840861P@D0P820101nOWh4
08B4Q0D0OGem101oOgl508:2PP@0OWin1023Ph<50861P@@0Q8B41@21PH4407moO`@0PX:21@20P80=
0861P@@0OGem1@20P80408>3P`@0O7al1@1oOglF0<SPf0005@38h=P50:>SX`@0JVYZ100`<30502/[
:`@08R8R1@0T92@402HV9P@09bLW1@1ZJVX408N7Q`D0Kfm_101jNWX40;Zj^PD0_;bl1036a/H50<g=
c@@0YJFU100Z:RX502LW9`@0=CDe100b<S8503Ti>@@0BDU91@1OGel406][J`@0N7Qh1@1iNGT407]k
N`D0P8201025QHD408>3P`D0RXZ:102<S8`5092@T0@0UIFE2@2HV9P409VIV@D0WIfM102TY:@40:JV
YPD0ZJVY102`/;050:f][@P0/K6a1@2^[Zh40:VYZ@D0Zj^[102XZ:P40:JVYPD0X:2P102LW9`509BD
U0@0TY:B102<S8`508V9R@@0S8b<1@2:RXX408F5Q@@0P8201@1lO7`407emO@D0PX:23@38h=P408B4
Q0@0PX:21@20P80407IfMPD0P820101oOgl407YjNPT0P8201@1kNg/407inOP@0OGem1@1nOWh40861
P@@0P8201@21PH4407EeM@D0QXJ6101mOGd407YjNPD0PH61101nOWh50861P@@0QHF51021PH4507al
O0T0PX:21021PH4407emO@D0Ogmo2@21PH440820P0@0Ogmo1@1mOGd90861P@@0Q8B4101nOWh508:2
PP@0PH611@20P80407inOP@0Q8B41@1mOGd407moO`D0PX:2101nOWh408>3P`D0PH611024Q8@50861
P@@0Ogmo1022PX850820P0d0PH61101mOGd50820P0@0Ph>3101lO7`507moOaH0b>3H000E0<SPf0D0
Xj>S101ZJVX4030`<0D0:b/[100R8R8502@T90@09RHV100W9bL506YZJP@0QhN71@1_Kfl407YjNP@0
^[Zj1@2l_;`40<K6aPD0cLg=102UYJD402XZ:PD09bLW100e=CD4038b<PD0>CTi1019BDT505mOG`@0
Jf][101hN7P507UiN@@0Ng]k1@20P80408F5Q@@0Ph>31@2:RXX408b<S0D0T92@102EUID909RHV0@0
VIVI1@2MWId40:BTY0@0YZJV1@2YZJT40;2`/0D0[Jf]202a/K450:j^[P@0ZJVY1@2[Zj/40:RXZ0@0
YZJV1@2PX:0409bLW0D0U9BD102BTY8408b<S0D0RHV9102<S8`508Z:RP@0QHF51020P80507alO0@0
OGem1@22PX8=0<SPf0@0Q8B41022PX850820P0@0MWIf1@20P80407moO`@0NWYj2@20P80507]kN`@0
OWin101mOGd507inOP@0PH611020P8050861P@@0MGEe1@26QXH407emO@@0NWYj1@21PH4407inOPD0
PH611025QHD40861P@D0O7al2@22PX840861P@@0OGem1@1oOgl90861P@@0P820101oOgl507emO@T0
PH611024Q8@407inOPD0PX:21021PH450820P0@0OWin1024Q8@507emO@@0Ogmo1@22PX8407inOP@0
Ph>31@21PH4408B4Q0D0PH61101oOgl408:2PPD0P8203@21PH4407emO@D0P8201023Ph<407alO0D0
Ogmo5P38h=P001D0b>3H1@2SXj<406YZJP@0<30`1@0[:b/4028R8PD092@T100V9RH402LW9`D0JVYZ
1027QhL506m_K`@0NWYj102j^[X50;bl_0@0a/K61@3=cLd40:FUY@@0:RXZ1@0W9bL403De=@@0<S8b
1@0i>CT404U9B@D0GemO101[Jf/407QhN0D0NGUi101kNg/50820P0@0QHF51023Ph<508Z:RP@0S8b<
1@2@T90409FEU@T0V9RH102IVIT509fMW@@0Y:BT102VYZH50:VYZ@@0/;2`1@2][Jd80;6a/@D0[Zj^
102YZJT50:^[Z`@0Z:RX102VYZH50:2PX0@0W9bL1@2DU9@409:BTP@0S8b<1@29RHT408b<S0D0RXZ:
1025QHD40820P0D0O7al101mOGd508:2PPd0b>3H1024Q8@408:2PPD0P820101fMWH50820P0@0Ogmo
101jNWX90820P0D0Ng]k101nOWh407emO@D0OWin1021PH440820P0D0PH61101eMGD508J6QP@0OGem
101jNWX50861P@@0OWin1@21PH4408F5Q@@0PH611@1lO7`908:2PP@0PH61101mOGd507moO`T0PH61
1020P80407moO`D0OGem2@21PH4408B4Q0@0OWin1@22PX840861P@D0P820101nOWh408B4Q0D0OGem
101oOgl508:2PP@0OWin1023Ph<50861P@@0Q8B41@21PH4407moO`@0PX:21@20P80=0861P@@0OGem
1@20P80408>3P`@0O7al1@1oOglF0<SPf0005@38h=P506m_K`@0<C4a100S8b<502HV9P@08b<S2@0T
92@4024Q8@D0?Shn102CTi<507AdM0@0L71`102MWId90;no_`D0`<30103<c<`406i^KPD0:b/[200c
<c<503Hf=P@0Bd];1@1SHf<406m_K`@0N7Qh1@1fMWH407emO@D0Ph>31026QXH408B4Q0D0QhN73@2@
T90409BDU0D0VIVI102MWId50:6QX@@0YJFU102ZZZX50:n_[`@0/k>c1@2`/;040;6a/@@0];Bd1@2^
[Zh40:b/[0D0/;2`102YZJT40:JVYPD0XJ6Q102MWId509JFUP@0SHf=102?Shl508b<S0@0TY:B1@2;
Rh/408N7Q`@0PX:21@1lO7`40861P@D0Ph>33@38h=P40820P0@0Q8B41@21PH4407UiN@D0Ph>3101m
OGd407alO0h0Ogmo1028R8P40861P@D0OWin101kNg/407inOPD0PX:21023Ph<50861P@@0R8R8101j
NWX507inOPT0Ogmo101mOGd40861P@D0Q8B4101nOWh507emO@@0Q8B4101kNg/507emO@@0P8201@1m
OGd408>3P`@0PH611@1oOgl408>3P`D0OGem101lO7`40861P@D0P820101mOGd507alO0@0Ph>31024
Q8@508>3P`@0Ogmo1@20P80807alO0D0PH611020P80508>3P`P0PH611@1oOgl408:2PPD0P820101m
OGd40861P@T0Ogmo1021PH4507moOaH0b>3H000E0<SPf0D0Kfm_100a<C4402<S8`D09RHV100S8b<9
02@T90@08B4Q1@0n?Sh409>CT`D0M7Ad101`L70409fMW@T0_kno1@30`<040<c<c0@0KVi^1@0[:b/8
03<c<`D0=SHf101;Bd/506=SH`@0Kfm_101hN7P507IfMP@0OGem1@23Ph<408J6QP@0Q8B41@27QhL=
092@T0@0U9BD1@2IVIT409fMW@D0XJ6Q102UYJD40:ZZZPD0[jn_102c/k<50;2`/0@0/K6a102d];@5
0:j^[P@0[:b/1@2`/;040:VYZ@@0YZJV1@2QXJ4409fMW@D0UYJF102=SHd408n?S`D0S8b<102BTY85
08^;R`@0QhN71022PX8507alO0@0PH611@23Ph<=0<SPf0@0P8201024Q8@50861P@@0NGUi1@23Ph<4
07emO@@0O7al3P1oOgl408R8R0@0PH611@1nOWh407]kN`@0OWin1@22PX8408>3P`D0PH611028R8P4
07YjNPD0OWin2@1oOgl407emO@@0PH611@24Q8@407inOPD0OGem1024Q8@407]kN`D0OGem1020P805
07emO@@0Ph>31021PH4507moO`@0Ph>31@1mOGd407alO0@0PH611@20P80407emO@D0O7al1023Ph<4
08B4Q0D0Ph>3101oOgl50820P0P0O7al1@21PH440820P0D0Ph>32021PH4507moO`@0PX:21@20P804
07emO@@0PH612@1oOgl40861P@D0Ogmo5P38h=P001D0b>3H1@1_Kfl4034a<@@08b<S1@0V9RH402<S
8`T092@T100Q8B4503hn?P@0Ti>C1@1dM7@4071`L0@0WIfM2@2o_kl50<30`0@0c<c<101^KVh502/[
:`P0<c<c1@0f=SH404];B`D0Hf=S101_Kfl407QhN0D0MWIf101mOGd508>3P`@0QXJ61024Q8@508N7
Q`d0T92@102DU9@509VIV@@0WIfM1@2QXJ440:FUY@@0ZZZZ1@2_[jl40;>c/`D0/;2`102a/K440;Bd
]0D0[Zj^102/[:`50;2`/0@0ZJVY102VYZH50:6QX@@0WIfM1@2FUYH408f=S@@0Shn?1@2<S8`409:B
TPD0Rh^;1027QhL408:2PPD0O7al1021PH4508>3P`d0b>3H1020P80408B4Q0D0PH61101iNGT508>3
P`@0OGem101lO7`>07moO`@0R8R81021PH4507inOP@0Ng]k101nOWh508:2PP@0Ph>31@21PH4408R8
R0@0NWYj1@1nOWh907moO`@0OGem1021PH4508B4Q0@0OWin1@1mOGd408B4Q0@0Ng]k1@1mOGd40820
P0D0OGem1023Ph<40861P@D0Ogmo1023Ph<507emO@@0O7al1021PH450820P0@0OGem1@1lO7`408>3
P`@0Q8B41@23Ph<407moO`D0P820201lO7`50861P@@0P8201@23Ph<80861P@D0Ogmo1022PX850820
P0@0OGem1021PH4907moO`@0PH611@1oOglF0<SPf0005@38h=P506m_K`@0<C4a100S8b<502HV9P@0
8b<S2@0T92@4024Q8@D0?Shn102CTi<507AdM0@0L71`102MWId90;no_`D0`<30103<c<`406i^KPD0
:b/[200c<c<503Hf=P@0Bd];1@1SHf<406m_K`@0N7Qh1@1fMWH407emO@D0Ph>31026QXH408B4Q0D0
QhN73@2@T90409BDU0D0VIVI102MWId50:6QX@@0YJFU102ZZZX50:n_[`@0/k>c1@2`/;040;6a/@@0
];Bd1@2^[Zh40:b/[0D0/;2`102YZJT40:JVYPD0XJ6Q102MWId509JFUP@0SHf=102?Shl508b<S0@0
TY:B1@2;Rh/408N7Q`@0PX:21@1lO7`40861P@D0Ph>33@38h=P40820P0@0Q8B41@21PH4407UiN@D0
Ph>3101mOGd407alO0h0Ogmo1028R8P40861P@D0OWin101kNg/407inOPD0PX:21023Ph<50861P@@0
R8R8101jNWX507inOPT0Ogmo101mOGd40861P@D0Q8B4101nOWh507emO@@0Q8B4101kNg/507emO@@0
P8201@1mOGd408>3P`@0PH611@1oOgl408>3P`D0OGem101lO7`40861P@D0P820101mOGd507alO0@0
Ph>31024Q8@508>3P`@0Ogmo1@20P80807alO0D0PH611020P80508>3P`P0PH611@1oOgl408:2PPD0
P820101mOGd40861P@T0Ogmo1021PH4507moOaH0b>3H000E0<SPf0D0Kfm_100a<C4402<S8`D09RHV
100S8b<902@T90@08B4Q1@0n?Sh409>CT`D0M7Ad101`L70409fMW@T0_kno1@30`<040<c<c0@0KVi^
1@0[:b/803<c<`D0=SHf101;Bd/506=SH`@0Kfm_101hN7P507IfMP@0OGem1@23Ph<408J6QP@0Q8B4
1@27QhL=092@T0@0U9BD1@2IVIT409fMW@D0XJ6Q102UYJD40:ZZZPD0[jn_102c/k<50;2`/0@0/K6a
102d];@50:j^[P@0[:b/1@2`/;040:VYZ@@0YZJV1@2QXJ4409fMW@D0UYJF102=SHd408n?S`D0S8b<
102BTY8508^;R`@0QhN71022PX8507alO0@0PH611@23Ph<=0<SPf0@0P8201024Q8@50861P@@0NGUi
1@23Ph<407emO@@0O7al3P1oOgl408R8R0@0PH611@1nOWh407]kN`@0OWin1@22PX8408>3P`D0PH61
1028R8P407YjNPD0OWin2@1oOgl407emO@@0PH611@24Q8@407inOPD0OGem1024Q8@407]kN`D0OGem
1020P80507emO@@0Ph>31021PH4507moO`@0Ph>31@1mOGd407alO0@0PH611@20P80407emO@D0O7al
1023Ph<408B4Q0D0Ph>3101oOgl50820P0P0O7al1@21PH440820P0D0Ph>32021PH4507moO`@0PX:2
1@20P80407emO@@0PH612@1oOgl40861P@D0Ogmo5P38h=P001D0b>3H1@0o?cl402h^;P@0;2`/1@0Y
:BT402LW9`D0:RXZ100Y:BT402@T90D08b<S101bLW8508^;R`@0LW9b101lO7`50<?3``@0^KVi1@30
`<040;Zj^P@0`/;21@0o?cl402XZ:P@0;2`/1@0g=cL404i>CPD0H61P101aLG4407EeM@D0NWYj1020
P80507moO`@0PH611025QHD508J6QP@0Rh^;1@2EUID409BDU0@0UYJF1@2KVi/40:>SX`D0ZJVY102[
Zj/40:j^[PD0/K6a102b/[850;>c/`@0^[Zj102c/k<50:j^[P@0ZZZZ1@2/[:`40:ZZZP@0Zj^[1@2Q
XJ4409fMW@D0Vi^K102FUYH409>CT`D0TI6A102BTY8508b<S0@0RHV91025QHD507inOP@0PH611@25
QHD=0<SPf0@0OWin1020P80506e]K@@0Ph>31@1nOWh407emO@@0Q8B41@1lO7`407moO`D0NGUi101g
MgL407inOPD0Ph>3101lO7`408:2PPD0O7al1020P80507]kN`@0QhN7101kNg/508:2PP@0PH611@1o
Ogl408:2PPT0OWin1021PH4507emO@@0OWin1022PX8507inOP@0OGem1@1nOWh407moO`@0OWin1@1o
Ogl40861P@D0Ph>3101oOgl407emO@D0PH61101lO7`508:2PPd0OGem2@20P80407inOQ80P820101m
OGd908:2PP@0P8201@1lO7`407moO`@0OGem2@1oOgl407inOPD0PH615P38h=P001D0b>3H1@0o?cl4
02h^;P@0;2`/1@0Y:BT402LW9`D0:RXZ100Y:BT402@T90D08b<S101bLW8508^;R`@0LW9b101lO7`5
0<?3``@0^KVi1@30`<040;Zj^P@0`/;21@0o?cl402XZ:P@0;2`/1@0g=cL404i>CPD0H61P101aLG44
07EeM@D0NWYj1020P80507moO`@0PH611025QHD508J6QP@0Rh^;1@2EUID409BDU0@0UYJF1@2KVi/4
0:>SX`D0ZJVY102[Zj/40:j^[PD0/K6a102b/[850;>c/`@0^[Zj102c/k<50:j^[P@0ZZZZ1@2/[:`4
0:ZZZP@0Zj^[1@2QXJ4409fMW@D0Vi^K102FUYH409>CT`D0TI6A102BTY8508b<S0@0RHV91025QHD5
07inOP@0PH611@25QHD=0<SPf0@0OWin1020P80506e]K@@0Ph>31@1nOWh407emO@@0Q8B41@1lO7`4
07moO`D0NGUi101gMgL407inOPD0Ph>3101lO7`408:2PPD0O7al1020P80507]kN`@0QhN7101kNg/5
08:2PP@0PH611@1oOgl408:2PPT0OWin1021PH4507emO@@0OWin1022PX8507inOP@0OGem1@1nOWh4
07moO`@0OWin1@1oOgl40861P@D0Ph>3101oOgl407emO@D0PH61101lO7`508:2PPd0OGem2@20P804
07inOQ80P820101mOGd908:2PP@0P8201@1lO7`407moO`@0OGem2@1oOgl407inOPD0PH615P38h=P0
01D0b>3H1@0o?cl402h^;P@0;2`/1@0Y:BT402LW9`D0:RXZ100Y:BT402@T90D08b<S101bLW8508^;
R`@0LW9b101lO7`50<?3``@0^KVi1@30`<040;Zj^P@0`/;21@0o?cl402XZ:P@0;2`/1@0g=cL404i>
CPD0H61P101aLG4407EeM@D0NWYj1020P80507moO`@0PH611025QHD508J6QP@0Rh^;1@2EUID409BD
U0@0UYJF1@2KVi/40:>SX`D0ZJVY102[Zj/40:j^[PD0/K6a102b/[850;>c/`@0^[Zj102c/k<50:j^
[P@0ZZZZ1@2/[:`40:ZZZP@0Zj^[1@2QXJ4409fMW@D0Vi^K102FUYH409>CT`D0TI6A102BTY8508b<
S0@0RHV91025QHD507inOP@0PH611@25QHD=0<SPf0@0OWin1020P80506e]K@@0Ph>31@1nOWh407em
O@@0Q8B41@1lO7`407moO`D0NGUi101gMgL407inOPD0Ph>3101lO7`408:2PPD0O7al1020P80507]k
N`@0QhN7101kNg/508:2PP@0PH611@1oOgl408:2PPT0OWin1021PH4507emO@@0OWin1022PX8507in
OP@0OGem1@1nOWh407moO`@0OWin1@1oOgl40861P@D0Ph>3101oOgl407emO@D0PH61101lO7`508:2
PPd0OGem2@20P80407inOQ80P820101mOGd908:2PP@0P8201@1lO7`407moO`@0OGem2@1oOgl407in
OPD0PH615P38h=P001D0b>3H1@0o?cl402h^;P@0;2`/1@0Y:BT402LW9`D0:RXZ100Y:BT402@T90D0
8b<S101bLW8508^;R`@0LW9b101lO7`50<?3``@0^KVi1@30`<040;Zj^P@0`/;21@0o?cl402XZ:P@0
;2`/1@0g=cL404i>CPD0H61P101aLG4407EeM@D0NWYj1020P80507moO`@0PH611025QHD508J6QP@0
Rh^;1@2EUID409BDU0@0UYJF1@2KVi/40:>SX`D0ZJVY102[Zj/40:j^[PD0/K6a102b/[850;>c/`@0
^[Zj102c/k<50:j^[P@0ZZZZ1@2/[:`40:ZZZP@0Zj^[1@2QXJ4409fMW@D0Vi^K102FUYH409>CT`D0
TI6A102BTY8508b<S0@0RHV91025QHD507inOP@0PH611@25QHD=0<SPf0@0OWin1020P80506e]K@@0
Ph>31@1nOWh407emO@@0Q8B41@1lO7`407moO`D0NGUi101gMgL407inOPD0Ph>3101lO7`408:2PPD0
O7al1020P80507]kN`@0QhN7101kNg/508:2PP@0PH611@1oOgl408:2PPT0OWin1021PH4507emO@@0
OWin1022PX8507inOP@0OGem1@1nOWh407moO`@0OWin1@1oOgl40861P@D0Ph>3101oOgl407emO@D0
PH61101lO7`508:2PPd0OGem2@20P80407inOQ80P820101mOGd908:2PP@0P8201@1lO7`407moO`@0
OGem2@1oOgl407inOPD0PH615P38h=P001D0b>3H1@1>CTh402h^;PT0:b/[100];Bd502PX:0@0<C4a
100V9RH502PX:0@0A4A41@2FUYH407MgM`@0M7Ad1@2SXj<40;Vi^@D0_;bl102j^[X40<W9b@D0X:2P
100X:2P4030`<0D0=SHf1015ADD5061PH0@0KVi^2@1hN7P407alO0D0NWYj1020P80408F5Q@D0SXj>
102?Shl509JFUP@0V9RH102KVi/509jNWP@0Y:BT1@2/[:`40:f][@@0[jn_1@2d];@=0;:b/P@0[Jf]
1@2b/[840:b/[0D0/K6a102][Jd40:^[Z`D0YjNW102QXJ4509bLW0P0UYJF1@2BTY8409>CT`D0SXj>
102;Rh/408F5Q@D0Ph>3101nOWh508:2PPd0b>3H101lO7`407inOPD0P820101oOgl507]kN`@0Ogmo
1022PX8508F5Q@T0P820101lO7`408J6QPD0OWin1024Q8@407moO`D0PH611020P80508:2PP@0MGEe
102<S8`507emO@@0Ogmo1@23Ph<40820P0@0Ogmo2@20P80=07moO`D0P8201024Q8@50861P@@0PX:2
101nOWh50861P@@0OGem1@1oOgl40861P@@0PX:22@1nOWh50820P0@0PX:21024Q8@508>3P`@0OGem
1@24Q8@80820P0T0Ph>32@21PH4407alO0D0Ph>31021PH4508B4Q0@0PH611023Ph<508:2PP@0Q8B4
2@1oOglF0<SPf0005@38h=P504i>CP@0;Rh^2@0[:b/402d];@D0:2PX100a<C4402HV9PD0:2PX1014
A4@509JFUP@0MgMg101dM7@50:>SX`@0^KVi1@2l_;`40;Zj^P@0bLW91@2PX:0402PX:0@0<30`1@0f
=SH404E5A@D0H61P101^KVh907QhN0@0O7al1@1jNWX40820P0@0QHF51@2>SXh408n?S`D0UYJF102H
V9P409^KV`D0WYjN102TY:@50:b/[0@0[Jf]102_[jl50;Bd]0d0/[:b102][Jd50;:b/P@0[:b/1@2a
/K440:f][@@0Zj^[1@2WYjL40:6QX@D0W9bL202FUYH509:BTP@0Ti>C1@2>SXh408^;R`@0QHF51@23
Ph<407inOPD0PX:23@38h=P407alO0@0OWin1@20P80407moO`D0Ng]k101oOgl408:2PPD0QHF52@20
P80407alO0@0QXJ61@1nOWh408B4Q0@0Ogmo1@21PH440820P0D0PX:2101eMGD408b<S0D0OGem101o
Ogl508>3P`@0P820101oOgl90820P0d0Ogmo1@20P80408B4Q0D0PH611022PX8407inOPD0PH61101m
OGd507moO`@0PH611022PX8907inOPD0P8201022PX8408B4Q0D0Ph>3101mOGd508B4Q0P0P8202@23
Ph<90861P@@0O7al1@23Ph<40861P@D0Q8B41021PH4408>3P`D0PX:21024Q8@907moOaH0b>3H000E
0<SPf0D0CTi>100^;Rh902/[:`@0;Bd]1@0X:2P4034a<@@09RHV1@0X:2P404A4A0D0UYJF101gMgL4
07AdM0D0Xj>S102i^KT50;bl_0@0^[Zj1039bLT50:2PX0@0:2PX100`<30503Hf=P@0ADE51@1PH604
06i^KPT0N7Qh101lO7`507YjNP@0P8201025QHD508j>SP@0Shn?1@2FUYH409RHV0@0Vi^K1@2NWYh4
0:BTY0D0[:b/102][Jd40:n_[`D0];Bd3@2b/[840:f][@D0/[:b102/[:`50;6a/@@0[Jf]102[Zj/5
0:NWY`@0XJ6Q1@2LW9`809JFUPD0TY:B102CTi<508j>SP@0Rh^;1025QHD508>3P`@0OWin1@22PX8=
0<SPf0@0O7al101nOWh50820P0@0Ogmo1@1kNg/407moO`@0PX:21@25QHD90820P0@0O7al1026QXH5
07inOP@0Q8B4101oOgl50861P@@0P8201@22PX8407EeM@@0S8b<1@1mOGd407moO`D0Ph>31020P804
07moO`T0P8203@1oOgl50820P0@0Q8B41@21PH4408:2PP@0OWin1@21PH4407emO@D0Ogmo1021PH44
08:2PPT0OWin1@20P80408:2PP@0Q8B41@23Ph<407emO@D0Q8B42020P80908>3P`T0PH61101lO7`5
08>3P`@0PH611@24Q8@40861P@@0Ph>31@22PX8408B4Q0T0Ogmo5P38h=P001D0b>3H1@1>CTh402h^
;PT0:b/[100];Bd502PX:0@0<C4a100V9RH502PX:0@0A4A41@2FUYH407MgM`@0M7Ad1@2SXj<40;Vi
^@D0_;bl102j^[X40<W9b@D0X:2P100X:2P4030`<0D0=SHf1015ADD5061PH0@0KVi^2@1hN7P407al
O0D0NWYj1020P80408F5Q@D0SXj>102?Shl509JFUP@0V9RH102KVi/509jNWP@0Y:BT1@2/[:`40:f]
[@@0[jn_1@2d];@=0;:b/P@0[Jf]1@2b/[840:b/[0D0/K6a102][Jd40:^[Z`D0YjNW102QXJ4509bL
W0P0UYJF1@2BTY8409>CT`D0SXj>102;Rh/408F5Q@D0Ph>3101nOWh508:2PPd0b>3H101lO7`407in
OPD0P820101oOgl507]kN`@0Ogmo1022PX8508F5Q@T0P820101lO7`408J6QPD0OWin1024Q8@407mo
O`D0PH611020P80508:2PP@0MGEe102<S8`507emO@@0Ogmo1@23Ph<40820P0@0Ogmo2@20P80=07mo
O`D0P8201024Q8@50861P@@0PX:2101nOWh50861P@@0OGem1@1oOgl40861P@@0PX:22@1nOWh50820
P0@0PX:21024Q8@508>3P`@0OGem1@24Q8@80820P0T0Ph>32@21PH4407alO0D0Ph>31021PH4508B4
Q0@0PH611023Ph<508:2PP@0Q8B42@1oOglF0<SPf0005@38h=P503/k>`@0;Bd]2@0^;Rh402`/;0D0
;Rh^100[:b/402h^;PD0:RXZ100_;bl506a/K0@0T92@101cLg<507YjNP@0[jn_1@2c/k<80<;2`PD0
dM7A101jNWX402<S8`D0<C4a1015ADD505aLG0@0JFUY101fMWH507UiN@@0OGem1@1oOgl408>3P`@0
QhN71@2<S8`909>CT`@0VIVI102LW9`50:>SX`@0YZJV1@2ZZZX40:b/[0@0[jn_2@2b/[850:n_[`@0
/[:b102a/K450:j^[P@0/K6a1@2`/;040;:b/P@0[:b/1@2WYjL40::RXPD0Vi^K102JVYX4096AT@D0
Ti>C102@T90508b<S0@0QhN71024Q8@508>3P`@0PX:21@1nOWh=0<SPf0@0PH61101mOGd508J6QP@0
PX:21@21PH4407inOP@0P8201@1oOgl407UiN@D0OGem201hN7P507inOP@0OGem1020P80507emO@@0
Ogmo1@1nOWh408F5Q@@0N7Qh1@25QHD407alO0D0PH611022PX8407moO`D0P8201022PX850861P@P0
Ogmo1@1nOWh40820P0D0OGem101lO7`=0820P0D0PH611020P80407inOPD0PH611020P80507alO0@0
PX:2101oOgl508:2PP@0OWin1@22PX840861P@@0P8201@1oOgl407inOPD0O7al1020P80408:2PPD0
Ogmo101kNg/50861P@@0Ogmo1021PH4507emO@@0PX:2101nOWh507emOAH0b>3H000E0<SPf0D0>c/k
100];Bd902h^;P@0;2`/1@0^;Rh402/[:`@0;Rh^1@0Z:RX402l_;`D0K6a/102@T90407=cL`D0NWYj
102_[jl50;>c/`P0`/;21@3AdM4407YjNP@08b<S1@0a<C4404E5A@D0G5aL101YJFT407IfMPD0NGUi
101mOGd507moO`@0Ph>31027QhL508b<S0T0Ti>C102IVIT409bLW0D0Xj>S102VYZH50:ZZZP@0[:b/
102_[jl90;:b/PD0[jn_102b/[840;6a/@D0[Zj^102a/K450;2`/0@0/[:b102/[:`50:NWY`@0XZ:R
1@2KVi/409ZJVP@0TI6A1@2CTi<4092@T0D0S8b<1027QhL408B4Q0D0Ph>31022PX8507inOPd0b>3H
1021PH4407emO@D0QXJ61022PX850861P@@0OWin1020P80507moO`@0NGUi1@1mOGd807QhN0D0OWin
101mOGd40820P0D0OGem101oOgl507inOP@0QHF5101hN7P508F5Q@@0O7al1@21PH4408:2PP@0Ogmo
1@20P80408:2PPD0PH61201oOgl507inOP@0P8201@1mOGd407alO0d0P8201@21PH440820P0@0OWin
1@21PH440820P0D0O7al1022PX8407moO`D0PX:2101nOWh508:2PP@0PH611020P80507moO`@0OWin
1@1lO7`40820P0@0PX:21@1oOgl407]kN`D0PH61101oOgl40861P@D0OGem1022PX8407inOPD0OGem
5P38h=P001D0b>3H1@0k>c/402d];@T0;Rh^100/;2`502h^;P@0:b/[100^;Rh502XZ:P@0;bl_1@1/
K6`4092@T0@0Lg=c1@1jNWX40:n_[`D0/k>c2032`/850=7Ad@@0NWYj100S8b<5034a<@@0ADE51@1L
G5`406UYJ@@0MWIf1@1iNGT407emO@D0Ogmo1023Ph<408N7Q`D0S8b<2@2CTi<409VIV@@0W9bL1@2S
Xj<40:JVYPD0ZZZZ102/[:`40:n_[`T0/[:b1@2_[jl40;:b/P@0/K6a1@2^[Zh40;6a/@D0/;2`102b
/[840:b/[0D0YjNW102RXZ8509^KV`@0VYZJ102ATI4509>CT`@0T92@1@2<S8`408N7Q`@0Q8B41@23
Ph<408:2PPD0OWin3@38h=P40861P@@0OGem1@26QXH408:2PPD0PH61101nOWh40820P0D0Ogmo101i
NGT507emO@P0N7Qh1@1nOWh407emO@@0P8201@1mOGd407moO`D0OWin1025QHD407QhN0D0QHF5101l
O7`50861P@@0PX:2101oOgl50820P0@0PX:21@21PH4807moO`D0OWin1020P80507emO@@0O7al3@20
P8050861P@@0P820101nOWh50861P@@0P8201@1lO7`408:2PP@0Ogmo1@22PX8407inOPD0PX:21021
PH440820P0D0Ogmo101nOWh507alO0@0P8201022PX8507moO`@0Ng]k1@21PH4407moO`@0PH611@1m
OGd408:2PP@0OWin1@1mOGdF0<SPf0005@38h=P503/k>`@0;Bd]2@0^;Rh402`/;0D0;Rh^100[:b/4
02h^;PD0:RXZ100_;bl506a/K0@0T92@101cLg<507YjNP@0[jn_1@2c/k<80<;2`PD0dM7A101jNWX4
02<S8`D0<C4a1015ADD505aLG0@0JFUY101fMWH507UiN@@0OGem1@1oOgl408>3P`@0QhN71@2<S8`9
09>CT`@0VIVI102LW9`50:>SX`@0YZJV1@2ZZZX40:b/[0@0[jn_2@2b/[850:n_[`@0/[:b102a/K45
0:j^[P@0/K6a1@2`/;040;:b/P@0[:b/1@2WYjL40::RXPD0Vi^K102JVYX4096AT@D0Ti>C102@T905
08b<S0@0QhN71024Q8@508>3P`@0PX:21@1nOWh=0<SPf0@0PH61101mOGd508J6QP@0PX:21@21PH44
07inOP@0P8201@1oOgl407UiN@D0OGem201hN7P507inOP@0OGem1020P80507emO@@0Ogmo1@1nOWh4
08F5Q@@0N7Qh1@25QHD407alO0D0PH611022PX8407moO`D0P8201022PX850861P@P0Ogmo1@1nOWh4
0820P0D0OGem101lO7`=0820P0D0PH611020P80407inOPD0PH611020P80507alO0@0PX:2101oOgl5
08:2PP@0OWin1@22PX840861P@@0P8201@1oOgl407inOPD0O7al1020P80408:2PPD0Ogmo101kNg/5
0861P@@0Ogmo1021PH4507emO@@0PX:2101nOWh507emOAH0b>3H000E0<SPf0D0>c/k100];Bd902h^
;P@0;2`/1@0^;Rh402/[:`@0;Rh^1@0Z:RX402l_;`D0K6a/102@T90407=cL`D0NWYj102_[jl50;>c
/`P0`/;21@3AdM4407YjNP@08b<S1@0a<C4404E5A@D0G5aL101YJFT407IfMPD0NGUi101mOGd507mo
O`@0Ph>31027QhL508b<S0T0Ti>C102IVIT409bLW0D0Xj>S102VYZH50:ZZZP@0[:b/102_[jl90;:b
/PD0[jn_102b/[840;6a/@D0[Zj^102a/K450;2`/0@0/[:b102/[:`50:NWY`@0XZ:R1@2KVi/409ZJ
VP@0TI6A1@2CTi<4092@T0D0S8b<1027QhL408B4Q0D0Ph>31022PX8507inOPd0b>3H1021PH4407em
O@D0QXJ61022PX850861P@@0OWin1020P80507moO`@0NGUi1@1mOGd807QhN0D0OWin101mOGd40820
P0D0OGem101oOgl507inOP@0QHF5101hN7P508F5Q@@0O7al1@21PH4408:2PP@0Ogmo1@20P80408:2
PPD0PH61201oOgl507inOP@0P8201@1mOGd407alO0d0P8201@21PH440820P0@0OWin1@21PH440820
P0D0O7al1022PX8407moO`D0PX:2101nOWh508:2PP@0PH611020P80507moO`@0OWin1@1lO7`40820
P0@0PX:21@1oOgl407]kN`D0PH61101oOgl40861P@D0OGem1022PX8407inOPD0OGem5P38h=P001D0
b>3H1@11@D4402`/;0@0<c<c2@0`<30502d];@@0<C4a2@0/;2`402XZ:PD0>SXj102IVIT407AdM0D0
K6a/102RXZ850;>c/`@0^[Zj1031`L450<C4a0@0b/[:101?Cdl502d];@@0@D511@1DE5@406EUI@@0
M7Ad1@1fMWH407]kN`D0Ogmo1021PH4408V9R@D0SHf=102BTY8909NGU`@0WinO1@2PX:040:NWY`D0
[:b/102ZZZX40:n_[`D0/k>c102ZZZX50:j^[P@0/[:b102`/;050;:b/P@0[Jf]1@2^[Zh80:n_[`D0
ZZZZ102UYJD509jNWP@0U9BD2@2CTi<4096AT@D0SHf=1026QXH908B4Q0@0P8201@23Ph<=0<SPf0@0
MGEe1020P80507moO`@0Q8B41@1kNg/40820P0@0N7Qh2@21PH490820P0@0O7al1@24Q8@407inOP@0
PH612@1nOWh907moO`@0PH611@1kNg/408>3P`D0Ogmo101iNGT408>3P`D0P820101kNg/508:2PP@0
Ogmo101nOWh50861P@@0Ph>31@1oOgl40861P@T0Ogmo101nOWh507moO`@0P8201022PX8507inOP@0
P8201@21PH4407QhN0@0Ogmo1@1nOWh408>3P`D0QHF5101nOWh40820P0D0Q8B41021PH4507moO`@0
PX:2101mOGd>0861P@@0P820101oOgl508B4Q0@0OWin2@20P80F0<SPf0005@38h=P50451@@@0;2`/
100c<c<9030`<0D0;Bd]100a<C4902`/;0@0:RXZ1@0j>SX409VIV@@0M7Ad1@1/K6`40::RXPD0/k>c
102j^[X40<71`@D0a<C4103:b/X404m?C`D0;Bd]1011@D4505ADE0@0IFEU101dM7@507IfMP@0Ng]k
1@1oOgl40861P@@0RHV91@2=SHd409:BTPT0UiNG102OWil50:2PX0@0YjNW1@2/[:`40:ZZZP@0[jn_
1@2c/k<40:ZZZPD0[Zj^102b/[840;2`/0D0/[:b102][Jd50:j^[PP0[jn_1@2ZZZX40:FUY@D0WYjN
102DU9@909>CT`@0TI6A1@2=SHd408J6QPT0Q8B41020P80508>3P`d0b>3H101eMGD40820P0D0Ogmo
1024Q8@507]kN`@0P820101hN7P90861P@T0P820101lO7`508B4Q0@0OWin1021PH4907inOPT0Ogmo
1021PH4507]kN`@0Ph>31@1oOgl407UiN@@0Ph>31@20P80407]kN`D0PX:2101oOgl407inOPD0PH61
1023Ph<507moO`@0PH612@1oOgl407inOPD0Ogmo1020P80408:2PPD0OWin1020P8050861P@@0N7Qh
101oOgl507inOP@0Ph>31@25QHD407inOP@0P8201@24Q8@40861P@D0Ogmo1022PX8407emO@h0PH61
1020P80407moO`D0Q8B4101nOWh90820P1H0b>3H000E0<SPf0D0@D51100/;2`403<c<`T0<30`1@0]
;Bd4034a<@T0;2`/100Z:RX503Xj>P@0VIVI101dM7@506a/K0@0XZ:R1@2c/k<40;Zj^P@0`L711@34
a<@40<[:bP@0Cdm?1@0];Bd40451@@D0E5AD101UIFD407AdM0D0MWIf101kNg/507moO`@0PH611029
RHT508f=S@@0TY:B2@2GUiL409nOW`D0X:2P102WYjL50:b/[0@0ZZZZ102_[jl50;>c/`@0ZZZZ1@2^
[Zh40;:b/P@0/;2`1@2b/[840:f][@D0[Zj^202_[jl50:ZZZP@0YJFU1@2NWYh409BDU0T0Ti>C102A
TI4508f=S@@0QXJ62@24Q8@40820P0D0Ph>33@38h=P407EeM@@0P8201@1oOgl408B4Q0D0Ng]k1020
P80407QhN0T0PH612@20P80407alO0D0Q8B4101nOWh40861P@T0OWin2@1oOgl40861P@D0Ng]k1023
Ph<507moO`@0NGUi1023Ph<50820P0@0Ng]k1@22PX8407moO`@0OWin1@21PH4408>3P`D0Ogmo1021
PH4907moO`@0OWin1@1oOgl40820P0@0PX:21@1nOWh40820P0D0PH61101hN7P407moO`D0OWin1023
Ph<508F5Q@@0OWin1020P80508B4Q0@0PH611@1oOgl408:2PP@0OGem3P21PH440820P0@0Ogmo1@24
Q8@407inOPT0P8205P38h=P001D0b>3H1@11@D4402`/;0@0<c<c2@0`<30502d];@@0<C4a2@0/;2`4
02XZ:PD0>SXj102IVIT407AdM0D0K6a/102RXZ850;>c/`@0^[Zj1031`L450<C4a0@0b/[:101?Cdl5
02d];@@0@D511@1DE5@406EUI@@0M7Ad1@1fMWH407]kN`D0Ogmo1021PH4408V9R@D0SHf=102BTY89
09NGU`@0WinO1@2PX:040:NWY`D0[:b/102ZZZX40:n_[`D0/k>c102ZZZX50:j^[P@0/[:b102`/;05
0;:b/P@0[Jf]1@2^[Zh80:n_[`D0ZZZZ102UYJD509jNWP@0U9BD2@2CTi<4096AT@D0SHf=1026QXH9
08B4Q0@0P8201@23Ph<=0<SPf0@0MGEe1020P80507moO`@0Q8B41@1kNg/40820P0@0N7Qh2@21PH49
0820P0@0O7al1@24Q8@407inOP@0PH612@1nOWh907moO`@0PH611@1kNg/408>3P`D0Ogmo101iNGT4
08>3P`D0P820101kNg/508:2PP@0Ogmo101nOWh50861P@@0Ph>31@1oOgl40861P@T0Ogmo101nOWh5
07moO`@0P8201022PX8507inOP@0P8201@21PH4407QhN0@0Ogmo1@1nOWh408>3P`D0QHF5101nOWh4
0820P0D0Q8B41021PH4507moO`@0PX:2101mOGd>0861P@@0P820101oOgl508B4Q0@0OWin2@20P80F
0<SPf0005@38h=P503Ph>0@092@T100b<S85030`<0@0:RXZ1@0/;2`802d];@D0;Rh^100Z:RX502d]
;@@0Lg=c102ATI4506=SH`@0OGem1@2f][H40:n_[`@0_[jn1@2m_Kd40<S8b0@0]kNg1@0n?Sh40410
@0D0CTi>101SHf<4071`L0D0M7Ad101jNWX90861P@@0QhN71@2=SHd409:BTPD0VIVI102JVYX409jN
WPD0Xj>S102WYjL50:RXZ0@0ZZZZ102][Jd50:j^[P@0[:b/1@2b/[840:j^[P@0[:b/1@2[Zj/40:JV
YPD0Zj^[102`/;040:n_[`D0Zj^[102QXJ4509VIV@@0UYJF102?Shl508^;R`@0TI6A1@2;Rh/408F5
Q@@0PH611@22PX8407emO@D0Ogmo3@38h=P408R8R0@0OGem2@20P80507emO@@0Ogmo101lO7`507mo
O`@0NGUi1@20P80407inOP@0QXJ61@1jNWX408>3P`@0PH612@1nOWh50820P0@0Ogmo1022PX8507Ui
N@@0S8b<2@1nOWh408:2PPD0OWin1024Q8@907inOP@0OGem1@1nOWh40861P@D0PX:2101mOGd407al
O0D0P8201022PX8507inOP@0PH611020P80508:2PPd0Ogmo101nOWh507moO`T0P8201021PH4408>3
P`D0Ng]k2@20P8040861P@T0OWin101oOgl907emO@@0Ph>31@1nOWh408B4Q0@0OWin1@21PH4F0<SP
f0005@38h=P503Ph>0@092@T100b<S85030`<0@0:RXZ1@0/;2`802d];@D0;Rh^100Z:RX502d];@@0
Lg=c102ATI4506=SH`@0OGem1@2f][H40:n_[`@0_[jn1@2m_Kd40<S8b0@0]kNg1@0n?Sh40410@0D0
CTi>101SHf<4071`L0D0M7Ad101jNWX90861P@@0QhN71@2=SHd409:BTPD0VIVI102JVYX409jNWPD0
Xj>S102WYjL50:RXZ0@0ZZZZ102][Jd50:j^[P@0[:b/1@2b/[840:j^[P@0[:b/1@2[Zj/40:JVYPD0
Zj^[102`/;040:n_[`D0Zj^[102QXJ4509VIV@@0UYJF102?Shl508^;R`@0TI6A1@2;Rh/408F5Q@@0
PH611@22PX8407emO@D0Ogmo3@38h=P408R8R0@0OGem2@20P80507emO@@0Ogmo101lO7`507moO`@0
NGUi1@20P80407inOP@0QXJ61@1jNWX408>3P`@0PH612@1nOWh50820P0@0Ogmo1022PX8507UiN@@0
S8b<2@1nOWh408:2PPD0OWin1024Q8@907inOP@0OGem1@1nOWh40861P@D0PX:2101mOGd407alO0D0
P8201022PX8507inOP@0PH611020P80508:2PPd0Ogmo101nOWh507moO`T0P8201021PH4408>3P`D0
Ng]k2@20P8040861P@T0OWin101oOgl907emO@@0Ph>31@1nOWh408B4Q0@0OWin1@21PH4F0<SPf000
5@38h=P503Ph>0@092@T100b<S85030`<0@0:RXZ1@0/;2`802d];@D0;Rh^100Z:RX502d];@@0Lg=c
102ATI4506=SH`@0OGem1@2f][H40:n_[`@0_[jn1@2m_Kd40<S8b0@0]kNg1@0n?Sh40410@0D0CTi>
101SHf<4071`L0D0M7Ad101jNWX90861P@@0QhN71@2=SHd409:BTPD0VIVI102JVYX409jNWPD0Xj>S
102WYjL50:RXZ0@0ZZZZ102][Jd50:j^[P@0[:b/1@2b/[840:j^[P@0[:b/1@2[Zj/40:JVYPD0Zj^[
102`/;040:n_[`D0Zj^[102QXJ4509VIV@@0UYJF102?Shl508^;R`@0TI6A1@2;Rh/408F5Q@@0PH61
1@22PX8407emO@D0Ogmo3@38h=P408R8R0@0OGem2@20P80507emO@@0Ogmo101lO7`507moO`@0NGUi
1@20P80407inOP@0QXJ61@1jNWX408>3P`@0PH612@1nOWh50820P0@0Ogmo1022PX8507UiN@@0S8b<
2@1nOWh408:2PPD0OWin1024Q8@907inOP@0OGem1@1nOWh40861P@D0PX:2101mOGd407alO0D0P820
1022PX8507inOP@0PH611020P80508:2PPd0Ogmo101nOWh507moO`T0P8201021PH4408>3P`D0Ng]k
2@20P8040861P@T0OWin101oOgl907emO@@0Ph>31@1nOWh408B4Q0@0OWin1@21PH4F0<SPf0005@38
h=P503Ph>0@092@T100b<S85030`<0@0:RXZ1@0/;2`802d];@D0;Rh^100Z:RX502d];@@0Lg=c102A
TI4506=SH`@0OGem1@2f][H40:n_[`@0_[jn1@2m_Kd40<S8b0@0]kNg1@0n?Sh40410@0D0CTi>101S
Hf<4071`L0D0M7Ad101jNWX90861P@@0QhN71@2=SHd409:BTPD0VIVI102JVYX409jNWPD0Xj>S102W
YjL50:RXZ0@0ZZZZ102][Jd50:j^[P@0[:b/1@2b/[840:j^[P@0[:b/1@2[Zj/40:JVYPD0Zj^[102`
/;040:n_[`D0Zj^[102QXJ4509VIV@@0UYJF102?Shl508^;R`@0TI6A1@2;Rh/408F5Q@@0PH611@22
PX8407emO@D0Ogmo3@38h=P408R8R0@0OGem2@20P80507emO@@0Ogmo101lO7`507moO`@0NGUi1@20
P80407inOP@0QXJ61@1jNWX408>3P`@0PH612@1nOWh50820P0@0Ogmo1022PX8507UiN@@0S8b<2@1n
OWh408:2PPD0OWin1024Q8@907inOP@0OGem1@1nOWh40861P@D0PX:2101mOGd407alO0D0P8201022
PX8507inOP@0PH611020P80508:2PPd0Ogmo101nOWh507moO`T0P8201021PH4408>3P`D0Ng]k2@20
P8040861P@T0OWin101oOgl907emO@@0Ph>31@1nOWh408B4Q0@0OWin1@21PH4F0<SPf0005@38h=P5
034a<@@0<30`100f=SH502`/;0@0;Rh^1@0Y:BT4030`<0@0<S8b1@0`<304034a<@D0:b/[100m?Cd4
09BDU0D0N7Qh101[Jf/90:VYZ@@0^KVi1@2n_[h40<30`0@0a/K61@2QXJ4403Ti>@D0D51@101LG5`4
06a/K0D0M7Ad101kNg/507inOP@0PX:22@2<S8`409BDU0D0UiNG102LW9`409fMW@D0YJFU102WYjL5
0:6QX@@0Z:RX102^[Zh50:f][@@0Z:RX1@2UYJD40:NWY`@0ZJVY1@2^[Zh40:f][@T0YjNW102YZJT5
0:RXZ0@0Xj>S1@2MWId409FEU@@0RHV91@2;Rh/408j>SPD0QXJ61024Q8@408:2PPD0PH612@22PX8=
0<SPf0@0OGem1021PH4507inOP@0QXJ61@20P80408>3P`@0PX:21@21PH4407YjNPD0OGem101jNWX4
0861P@D0OWin1023Ph<90820P0@0PX:21@1lO7`40861P@@0P8201@25QHD4079bLPD0S8b<101iNGT4
08>3P`D0PX:21020P80907emO@@0Ogmo1@1nOWh907emO@@0Ogmo1021PH4907moO`D0P820101mOGd4
07moO`D0PH61101oOgl507inOP@0Ogmo1020P80507inOPT0OGem1025QHD40861P@D0P8201025QHD5
08:2PP@0Q8B4101lO7`508:2PP@0P8202@1mOGd40820P0D0O7al2020P80507alO1H0b>3H000E0<SP
f0D0<C4a100`<30403Hf=PD0;2`/100^;Rh502TY:@@0<30`100b<S85030`<0@0<C4a1@0[:b/403dm
?@@0U9BD1@1hN7P406][J`T0ZJVY102i^KT50;jn_P@0`<301036a/H50:6QX@@0>CTi1@1@D50405aL
G0@0K6a/1@1dM7@407]kN`D0OWin1022PX8908b<S0@0U9BD1@2GUiL409bLW0@0WIfM1@2UYJD40:NW
Y`D0XJ6Q102XZ:P40:j^[PD0[Jf]102XZ:P50:FUY@@0YjNW102YZJT50:j^[P@0[Jf]2@2WYjL40:VY
Z@D0Z:RX102SXj<509fMW@@0UIFE1029RHT508^;R`@0SXj>1@26QXH408B4Q0@0PX:21@21PH4908:2
PPd0b>3H101mOGd40861P@D0OWin1026QXH50820P0@0Ph>31022PX850861P@@0NWYj1@1mOGd407Yj
NP@0PH611@1nOWh408>3P`T0P8201022PX8507alO0@0PH611020P80508F5Q@@0LW9b1@2<S8`407Ui
N@@0Ph>31@22PX840820P0T0OGem101oOgl507inOPT0OGem101oOgl40861P@T0Ogmo1@20P80407em
O@@0Ogmo1@21PH4407moO`D0OWin101oOgl40820P0D0OWin2@1mOGd408F5Q@@0PH611@20P80408F5
Q@D0PX:21024Q8@407alO0D0PX:21020P80907emO@@0P8201@1lO7`80820P0D0O7al5P38h=P001D0
b>3H1@0a<C44030`<0@0=SHf1@0/;2`402h^;PD0:BTY100`<304038b<PD0<30`100a<C4502/[:`@0
?Cdm102DU9@507QhN0@0Jf][2@2YZJT40;Vi^@D0_[jn1030`<040<K6aPD0XJ6Q100i>CT5051@D0@0
G5aL101/K6`507AdM0@0Ng]k1@1nOWh408:2PPT0S8b<102DU9@509NGU`@0W9bL102MWId50:FUY@@0
YjNW1@2QXJ440:RXZ0@0[Zj^1@2][Jd40:RXZ0D0YJFU102WYjL40:VYZ@D0[Zj^102][Jd90:NWY`@0
ZJVY1@2XZ:P40:>SX`D0WIfM102EUID408V9R@D0Rh^;102>SXh508J6QP@0Q8B41022PX850861P@T0
PX:23@38h=P407emO@@0PH611@1nOWh408J6QPD0P8201023Ph<408:2PPD0PH61101jNWX507emO@@0
NWYj1021PH4507inOP@0Ph>32@20P80408:2PPD0O7al1021PH440820P0D0QHF5101bLW8508b<S0@0
NGUi1023Ph<508:2PP@0P8202@1mOGd407moO`D0OWin2@1mOGd407moO`@0PH612@1oOgl50820P0@0
OGem101oOgl50861P@@0Ogmo1@1nOWh407moO`@0P8201@1nOWh907emO@@0QHF51021PH450820P0@0
QHF51@22PX8408B4Q0@0O7al1@22PX840820P0T0OGem1020P80507alO0P0P8201@1lO7`F0<SPf000
5@38h=P5034a<@@0<30`100f=SH502`/;0@0;Rh^1@0Y:BT4030`<0@0<S8b1@0`<304034a<@D0:b/[
100m?Cd409BDU0D0N7Qh101[Jf/90:VYZ@@0^KVi1@2n_[h40<30`0@0a/K61@2QXJ4403Ti>@D0D51@
101LG5`406a/K0D0M7Ad101kNg/507inOP@0PX:22@2<S8`409BDU0D0UiNG102LW9`409fMW@D0YJFU
102WYjL50:6QX@@0Z:RX102^[Zh50:f][@@0Z:RX1@2UYJD40:NWY`@0ZJVY1@2^[Zh40:f][@T0YjNW
102YZJT50:RXZ0@0Xj>S1@2MWId409FEU@@0RHV91@2;Rh/408j>SPD0QXJ61024Q8@408:2PPD0PH61
2@22PX8=0<SPf0@0OGem1021PH4507inOP@0QXJ61@20P80408>3P`@0PX:21@21PH4407YjNPD0OGem
101jNWX40861P@D0OWin1023Ph<90820P0@0PX:21@1lO7`40861P@@0P8201@25QHD4079bLPD0S8b<
101iNGT408>3P`D0PX:21020P80907emO@@0Ogmo1@1nOWh907emO@@0Ogmo1021PH4907moO`D0P820
101mOGd407moO`D0PH61101oOgl507inOP@0Ogmo1020P80507inOPT0OGem1025QHD40861P@D0P820
1025QHD508:2PP@0Q8B4101lO7`508:2PP@0P8202@1mOGd40820P0D0O7al2020P80507alO1H0b>3H
000E0<SPf0D0<C4a100`<30403Hf=PD0;2`/100^;Rh502TY:@@0<30`100b<S85030`<0@0<C4a1@0[
:b/403dm?@@0U9BD1@1hN7P406][J`T0ZJVY102i^KT50;jn_P@0`<301036a/H50:6QX@@0>CTi1@1@
D50405aLG0@0K6a/1@1dM7@407]kN`D0OWin1022PX8908b<S0@0U9BD1@2GUiL409bLW0@0WIfM1@2U
YJD40:NWY`D0XJ6Q102XZ:P40:j^[PD0[Jf]102XZ:P50:FUY@@0YjNW102YZJT50:j^[P@0[Jf]2@2W
YjL40:VYZ@D0Z:RX102SXj<509fMW@@0UIFE1029RHT508^;R`@0SXj>1@26QXH408B4Q0@0PX:21@21
PH4908:2PPd0b>3H101mOGd40861P@D0OWin1026QXH50820P0@0Ph>31022PX850861P@@0NWYj1@1m
OGd407YjNP@0PH611@1nOWh408>3P`T0P8201022PX8507alO0@0PH611020P80508F5Q@@0LW9b1@2<
S8`407UiN@@0Ph>31@22PX840820P0T0OGem101oOgl507inOPT0OGem101oOgl40861P@T0Ogmo1@20
P80407emO@@0Ogmo1@21PH4407moO`D0OWin101oOgl40820P0D0OWin2@1mOGd408F5Q@@0PH611@20
P80408F5Q@D0PX:21024Q8@407alO0D0PX:21020P80907emO@@0P8201@1lO7`80820P0D0O7al5P38
h=P001D0b>3H2@0^;Rh402l_;`D0;2`/100Z:RX502`/;0@0=3@d100b<S89034a<@T0;2`/101WIfL5
08n?S`@0HV9R1@1kNg/40:n_[`@0/;2`1@2i^KT40;no_`@0a/K61@3?cll408N7Q`D0@410101KFe/4
06UYJ@D0LW9b101eMGD507inOPP0QhN71@2?Shl409FEU@D0V9RH102MWId409nOW`D0Y:BT102UYJD5
0::RXP@0YZJV102[Zj/50:JVYP@0XZ:R1@2VYZH40:BTY0@0YZJV1@2][Jd40:VYZ@D0[Jf]102YZJT4
0:FUY@D0Zj^[102TY:@50:FUY@@0U9BD102;Rh/508V9R@@0Shn?1@2;Rh/408N7Q`@0PX:21@21PH44
0820P0D0PX:23@38h=P408B4Q0@0OGem1@23Ph<40861P@D0Ogmo1024Q8@407moO`D0PX:2101kNg/5
0820P0@0OWin101mOGd508:2PP@0NWYj1023Ph<50820P0@0PH611@20P80407moO`@0OGem1@20P804
08B4Q0D0LW9b102;Rh/407QhN0D0O7al101nOWh508B4Q0@0Ng]k3@20P80508:2PP@0O7al101oOgl5
07alO0@0P8201@21PH440820P0@0Ogmo1@21PH4408:2PPT0OWin1023Ph<507emO@@0Ng]k1@22PX84
07alO0@0OGem1@23Ph<407inOPD0PH61101oOgl40861P@T0Ogmo1@20P80407emO@@0PH611@1oOgl4
0861P@@0PX:21@24Q8@F0<SPf0005@38h=P902h^;P@0;bl_1@0/;2`402XZ:PD0;2`/100d=3@4038b
<PT0<C4a2@0/;2`406MWI`D0Shn?101RHV8507]kN`@0[jn_102`/;050;Vi^@@0_kno1036a/H50<o?
c`@0QhN71@10@40405]KF`@0JFUY1@1bLW8407EeM@D0OWin2027QhL508n?S`@0UIFE1@2HV9P409fM
W@@0WinO1@2TY:@40:FUY@D0XZ:R102VYZH40:^[Z`D0YZJV102RXZ850:JVYP@0Y:BT102VYZH50:f]
[@@0ZJVY1@2][Jd40:VYZ@@0YJFU1@2[Zj/40:BTY0D0YJFU102DU9@408^;R`D0RHV9102?Shl508^;
R`@0QhN71022PX850861P@@0P8201@22PX8=0<SPf0@0Q8B4101mOGd508>3P`@0PH611@1oOgl408B4
Q0@0Ogmo1@22PX8407]kN`D0P820101nOWh407emO@D0PX:2101jNWX408>3P`D0P8201021PH450820
P0@0Ogmo101mOGd50820P0@0Q8B41@1bLW8408^;R`@0N7Qh1@1lO7`407inOPD0Q8B4101kNg/=0820
P0D0PX:2101lO7`407moO`D0O7al1020P8050861P@@0P820101oOgl50861P@@0PX:22@1nOWh408>3
P`D0OGem101kNg/508:2PP@0O7al101mOGd508>3P`@0OWin1@21PH4407moO`@0PH612@1oOgl50820
P0@0OGem1021PH4507moO`@0PH611022PX8508B4Q1H0b>3H000E0<SPf0T0;Rh^100_;bl502`/;0@0
:RXZ1@0/;2`403@d=0@0<S8b2@0a<C4902`/;0@0IfMW1@2?Shl4069RHPD0Ng]k102_[jl40;2`/0D0
^KVi102o_kl40<K6aPD0clo?1027QhL50410@0@0Fe]K101YJFT5079bLP@0MGEe1@1nOWh808N7Q`D0
Shn?102EUID509RHV0@0WIfM102OWil50:BTY0@0YJFU1@2RXZ840:JVYP@0Zj^[1@2VYZH40::RXPD0
YZJV102TY:@40:JVYPD0[Jf]102YZJT50:f][@@0ZJVY102UYJD50:^[Z`@0Y:BT1@2UYJD409BDU0@0
Rh^;1@29RHT408n?S`D0Rh^;1027QhL408:2PPD0PH611020P80508:2PPd0b>3H1024Q8@407emO@D0
Ph>31021PH4507moO`@0Q8B4101oOgl508:2PP@0Ng]k1@20P80407inOP@0OGem1@22PX8407YjNP@0
Ph>31@20P8040861P@D0P820101oOgl407emO@D0P8201024Q8@5079bLP@0Rh^;101hN7P507alO0@0
OWin1@24Q8@407]kN`d0P8201@22PX8407alO0@0Ogmo1@1lO7`40820P0D0PH611020P80407moO`D0
PH611022PX8907inOP@0Ph>31@1mOGd407]kN`D0PX:2101lO7`407emO@D0Ph>3101nOWh50861P@@0
Ogmo1021PH4907moO`D0P820101mOGd40861P@D0Ogmo1021PH4408:2PPD0Q8B45P38h=P001D0b>3H
2@0^;Rh402l_;`D0;2`/100Z:RX502`/;0@0=3@d100b<S89034a<@T0;2`/101WIfL508n?S`@0HV9R
1@1kNg/40:n_[`@0/;2`1@2i^KT40;no_`@0a/K61@3?cll408N7Q`D0@410101KFe/406UYJ@D0LW9b
101eMGD507inOPP0QhN71@2?Shl409FEU@D0V9RH102MWId409nOW`D0Y:BT102UYJD50::RXP@0YZJV
102[Zj/50:JVYP@0XZ:R1@2VYZH40:BTY0@0YZJV1@2][Jd40:VYZ@D0[Jf]102YZJT40:FUY@D0Zj^[
102TY:@50:FUY@@0U9BD102;Rh/508V9R@@0Shn?1@2;Rh/408N7Q`@0PX:21@21PH440820P0D0PX:2
3@38h=P408B4Q0@0OGem1@23Ph<40861P@D0Ogmo1024Q8@407moO`D0PX:2101kNg/50820P0@0OWin
101mOGd508:2PP@0NWYj1023Ph<50820P0@0PH611@20P80407moO`@0OGem1@20P80408B4Q0D0LW9b
102;Rh/407QhN0D0O7al101nOWh508B4Q0@0Ng]k3@20P80508:2PP@0O7al101oOgl507alO0@0P820
1@21PH440820P0@0Ogmo1@21PH4408:2PPT0OWin1023Ph<507emO@@0Ng]k1@22PX8407alO0@0OGem
1@23Ph<407inOPD0PH61101oOgl40861P@T0Ogmo1@20P80407emO@@0PH611@1oOgl40861P@@0PX:2
1@24Q8@F0<SPf0005@38h=P502h^;P@0:RXZ100^;Rh502d];@@0:b/[1@0];Bd403De=@@0;bl_1@0^
;Rh402l_;`D092@T100U9BD403@d=0D0SXj>101mOGd506QXJ0@0Xj>S2@2a/K440;Jf]P@0_kno1@37
alL40<g=c@D0M7Ad101:BTX4065QH@D0Jf][101cLg<507]kN`@0QHF51027QhL5092@T0@0UiNG1@2I
VIT409NGU`@0VYZJ1@2NWYh90:2PX0@0WIfM102IVIT509BDU0@0UYJF1@2HV9P409NGU`@0Vi^K1@2N
WYh40:2PX0D0Y:BT102XZ:P40:JVYPD0YJFU102PX:050:FUY@@0Vi^K1028R8P508:2PP@0QXJ61@2;
Rh/408J6QP@0OWin1@22PX840820P0D0QXJ63@38h=P407emO@@0P8201@1kNg/407YjNPD0QHF5201k
Ng/907inOPT0PX:2101oOgl508:2PP@0PH61101oOgl507emO@@0NGUi1@21PH4408>3P`@0Q8B41@1o
Ogl407emO@D0PX:2101cLg<408^;R`D0NWYj1022PX850861P@@0P8201022PX8507emO@@0Ogmo1@1m
OGd40820P0@0Ph>31@20P80408>3P`T0Ogmo101lO7`507moO`@0PH611@22PX8408B4Q0@0Ph>31@24
Q8@40861P@D0Ph>3101nOWh407]kN`D0OGem1021PH4=07moO`D0Ph>3101jNWX508:2PP@0P820101o
Ogl50820P0P0PX:21@20P80F0<SPf0005@38h=P502h^;P@0:RXZ100^;Rh502d];@@0:b/[1@0];Bd4
03De=@@0;bl_1@0^;Rh402l_;`D092@T100U9BD403@d=0D0SXj>101mOGd506QXJ0@0Xj>S2@2a/K44
0;Jf]P@0_kno1@37alL40<g=c@D0M7Ad101:BTX4065QH@D0Jf][101cLg<507]kN`@0QHF51027QhL5
092@T0@0UiNG1@2IVIT409NGU`@0VYZJ1@2NWYh90:2PX0@0WIfM102IVIT509BDU0@0UYJF1@2HV9P4
09NGU`@0Vi^K1@2NWYh40:2PX0D0Y:BT102XZ:P40:JVYPD0YJFU102PX:050:FUY@@0Vi^K1028R8P5
08:2PP@0QXJ61@2;Rh/408J6QP@0OWin1@22PX840820P0D0QXJ63@38h=P407emO@@0P8201@1kNg/4
07YjNPD0QHF5201kNg/907inOPT0PX:2101oOgl508:2PP@0PH61101oOgl507emO@@0NGUi1@21PH44
08>3P`@0Q8B41@1oOgl407emO@D0PX:2101cLg<408^;R`D0NWYj1022PX850861P@@0P8201022PX85
07emO@@0Ogmo1@1mOGd40820P0@0Ph>31@20P80408>3P`T0Ogmo101lO7`507moO`@0PH611@22PX84
08B4Q0@0Ph>31@24Q8@40861P@D0Ph>3101nOWh407]kN`D0OGem1021PH4=07moO`D0Ph>3101jNWX5
08:2PP@0P820101oOgl50820P0P0PX:21@20P80F0<SPf0005@38h=P502h^;P@0:RXZ100^;Rh502d]
;@@0:b/[1@0];Bd403De=@@0;bl_1@0^;Rh402l_;`D092@T100U9BD403@d=0D0SXj>101mOGd506QX
J0@0Xj>S2@2a/K440;Jf]P@0_kno1@37alL40<g=c@D0M7Ad101:BTX4065QH@D0Jf][101cLg<507]k
N`@0QHF51027QhL5092@T0@0UiNG1@2IVIT409NGU`@0VYZJ1@2NWYh90:2PX0@0WIfM102IVIT509BD
U0@0UYJF1@2HV9P409NGU`@0Vi^K1@2NWYh40:2PX0D0Y:BT102XZ:P40:JVYPD0YJFU102PX:050:FU
Y@@0Vi^K1028R8P508:2PP@0QXJ61@2;Rh/408J6QP@0OWin1@22PX840820P0D0QXJ63@38h=P407em
O@@0P8201@1kNg/407YjNPD0QHF5201kNg/907inOPT0PX:2101oOgl508:2PP@0PH61101oOgl507em
O@@0NGUi1@21PH4408>3P`@0Q8B41@1oOgl407emO@D0PX:2101cLg<408^;R`D0NWYj1022PX850861
P@@0P8201022PX8507emO@@0Ogmo1@1mOGd40820P0@0Ph>31@20P80408>3P`T0Ogmo101lO7`507mo
O`@0PH611@22PX8408B4Q0@0Ph>31@24Q8@40861P@D0Ph>3101nOWh407]kN`D0OGem1021PH4=07mo
O`D0Ph>3101jNWX508:2PP@0P820101oOgl50820P0P0PX:21@20P80F0<SPf0005@38h=P502h^;P@0
:RXZ100^;Rh502d];@@0:b/[1@0];Bd403De=@@0;bl_1@0^;Rh402l_;`D092@T100U9BD403@d=0D0
SXj>101mOGd506QXJ0@0Xj>S2@2a/K440;Jf]P@0_kno1@37alL40<g=c@D0M7Ad101:BTX4065QH@D0
Jf][101cLg<507]kN`@0QHF51027QhL5092@T0@0UiNG1@2IVIT409NGU`@0VYZJ1@2NWYh90:2PX0@0
WIfM102IVIT509BDU0@0UYJF1@2HV9P409NGU`@0Vi^K1@2NWYh40:2PX0D0Y:BT102XZ:P40:JVYPD0
YJFU102PX:050:FUY@@0Vi^K1028R8P508:2PP@0QXJ61@2;Rh/408J6QP@0OWin1@22PX840820P0D0
QXJ63@38h=P407emO@@0P8201@1kNg/407YjNPD0QHF5201kNg/907inOPT0PX:2101oOgl508:2PP@0
PH61101oOgl507emO@@0NGUi1@21PH4408>3P`@0Q8B41@1oOgl407emO@D0PX:2101cLg<408^;R`D0
NWYj1022PX850861P@@0P8201022PX8507emO@@0Ogmo1@1mOGd40820P0@0Ph>31@20P80408>3P`T0
Ogmo101lO7`507moO`@0PH611@22PX8408B4Q0@0Ph>31@24Q8@40861P@D0Ph>3101nOWh407]kN`D0
OGem1021PH4=07moO`D0Ph>3101jNWX508:2PP@0P820101oOgl50820P0P0PX:21@20P80F0<SPf000
5@38h=P502XZ:Pd0;bl_100/;2`5038b<P@0<C4a100_;bl502d];@@0;2`/1@0W9bL402HV9P@08B4Q
1@1IFET409NGU`D0Jf][1022PX840;Rh^0D0X:2P102b/[840;Fe]@D0_kno2@36a/H406QXJ0@0EEEE
1@1SHf<4079bLPD0Ng]k1024Q8@408V9R@D0TI6A102CTi<509VIV@@0V9RH2@2FUYH409NGU`D0UIFE
202CTi<508j>SP@0TY:B1@2>SXh408f=S@@0SXj>1@2@T90409NGU`D0V9RH102LW9`40:2PX0D0YJFU
102LW9`509nOW`@0X:2P102:RXX50820P0@0Q8B41@27QhL408J6QP@0PX:22@1oOgl508F5Q@d0b>3H
101hN7P408B4Q0D0NWYj101nOWh508F5Q@@0NWYj101mOGd507YjNP@0O7al2@20P80408J6QPD0OGem
1021PH4407alO0D0PX:21020P8090861P@@0OGem1@20P8040861P@D0OGem1022PX8407IfMPD0RHV9
101mOGd907moO`@0O7al1@1oOgl408B4Q0D0PX:2101kNg/40820P0D0Ph>3101mOGd507moO`@0Q8B4
1021PH4507moO`@0O7al1@1mOGd407YjNP@0Ogmo2@1lO7`507YjNPP0OGem1@20P80407]kN`D0OWin
1022PX8907inOP@0PH611@22PX840820P0T0Ogmo1020P8040861P@D0Ogmo5P38h=P001D0b>3H1@0Z
:RX=02l_;`@0;2`/1@0b<S84034a<@@0;bl_1@0];Bd402`/;0D09bLW100V9RH4024Q8@D0FEUI102G
UiL506][J`@0PX:2102h^;P50:2PX0@0/[:b102e]KD50;no_`T0a/K6101XJ6P405EEE@D0Hf=S101b
LW8507]kN`@0Q8B41029RHT5096AT@@0Ti>C1@2IVIT409RHV0T0UYJF102GUiL509FEU@P0Ti>C1@2>
SXh409:BTPD0SXj>102=SHd408j>SPD0T92@102GUiL509RHV0@0W9bL102PX:050:FUY@@0W9bL1@2O
Wil40:2PX0@0RXZ:1@20P80408B4Q0D0QhN71026QXH408:2PPT0Ogmo1@25QHD=0<SPf0@0N7Qh1024
Q8@507YjNP@0OWin1@25QHD407YjNP@0OGem1@1jNWX407alO0T0P8201026QXH507emO@@0PH61101l
O7`508:2PP@0P8202@21PH4407emO@D0P8201021PH4507emO@@0PX:2101fMWH508V9R@@0OGem2@1o
Ogl407alO0D0Ogmo1024Q8@508:2PP@0Ng]k1020P80508>3P`@0OGem1@1oOgl408B4Q0@0PH611@1o
Ogl407alO0D0OGem101jNWX407moO`T0O7al1@1jNWX807emO@D0P820101kNg/507inOP@0PX:22@1n
OWh40861P@D0PX:21020P80907moO`@0P8201021PH4507moOaH0b>3H000E0<SPf0D0:RXZ3@0_;bl4
02`/;0D0<S8b100a<C4402l_;`D0;Bd]100/;2`502LW9`@09RHV100Q8B4505UIF@@0UiNG1@1[Jf/4
08:2PP@0^;Rh1@2PX:040;:b/P@0]KFe1@2o_kl90<K6aP@0J6QX101EEED506=SH`@0LW9b1@1kNg/4
08B4Q0@0RHV91@2ATI4409>CT`D0VIVI102HV9P909JFUP@0UiNG1@2EUID809>CT`D0SXj>102BTY85
08j>SP@0SHf=102>SXh5092@T0@0UiNG1@2HV9P409bLW0@0X:2P1@2UYJD409bLW0D0WinO102PX:04
08Z:RPD0P8201024Q8@508N7Q`@0QXJ61022PX8907moO`D0QHF53@38h=P407QhN0@0Q8B41@1jNWX4
07inOPD0QHF5101jNWX407emO@D0NWYj101lO7`90820P0@0QXJ61@1mOGd40861P@@0O7al1@22PX84
0820P0T0PH61101mOGd50820P0@0PH611@1mOGd408:2PP@0MWIf1@29RHT407emO@T0Ogmo101lO7`5
07moO`@0Q8B41@22PX8407]kN`@0P8201@23Ph<407emO@D0Ogmo1024Q8@40861P@D0Ogmo101lO7`5
07emO@@0NWYj101oOgl907alO0D0NWYj201mOGd50820P0@0Ng]k1@1nOWh408:2PPT0OWin1021PH45
08:2PP@0P8202@1oOgl40820P0@0PH611@1oOglF0<SPf0005@38h=P502XZ:Pd0;bl_100/;2`5038b
<P@0<C4a100_;bl502d];@@0;2`/1@0W9bL402HV9P@08B4Q1@1IFET409NGU`D0Jf][1022PX840;Rh
^0D0X:2P102b/[840;Fe]@D0_kno2@36a/H406QXJ0@0EEEE1@1SHf<4079bLPD0Ng]k1024Q8@408V9
R@D0TI6A102CTi<509VIV@@0V9RH2@2FUYH409NGU`D0UIFE202CTi<508j>SP@0TY:B1@2>SXh408f=
S@@0SXj>1@2@T90409NGU`D0V9RH102LW9`40:2PX0D0YJFU102LW9`509nOW`@0X:2P102:RXX50820
P0@0Q8B41@27QhL408J6QP@0PX:22@1oOgl508F5Q@d0b>3H101hN7P408B4Q0D0NWYj101nOWh508F5
Q@@0NWYj101mOGd507YjNP@0O7al2@20P80408J6QPD0OGem1021PH4407alO0D0PX:21020P8090861
P@@0OGem1@20P8040861P@D0OGem1022PX8407IfMPD0RHV9101mOGd907moO`@0O7al1@1oOgl408B4
Q0D0PX:2101kNg/40820P0D0Ph>3101mOGd507moO`@0Q8B41021PH4507moO`@0O7al1@1mOGd407Yj
NP@0Ogmo2@1lO7`507YjNPP0OGem1@20P80407]kN`D0OWin1022PX8907inOP@0PH611@22PX840820
P0T0Ogmo1020P8040861P@D0Ogmo5P38h=P001D0b>3H1@0Z:RX=02l_;`@0;2`/1@0b<S84034a<@@0
;bl_1@0];Bd402`/;0D09bLW100V9RH4024Q8@D0FEUI102GUiL506][J`@0PX:2102h^;P50:2PX0@0
/[:b102e]KD50;no_`T0a/K6101XJ6P405EEE@D0Hf=S101bLW8507]kN`@0Q8B41029RHT5096AT@@0
Ti>C1@2IVIT409RHV0T0UYJF102GUiL509FEU@P0Ti>C1@2>SXh409:BTPD0SXj>102=SHd408j>SPD0
T92@102GUiL509RHV0@0W9bL102PX:050:FUY@@0W9bL1@2OWil40:2PX0@0RXZ:1@20P80408B4Q0D0
QhN71026QXH408:2PPT0Ogmo1@25QHD=0<SPf0@0N7Qh1024Q8@507YjNP@0OWin1@25QHD407YjNP@0
OGem1@1jNWX407alO0T0P8201026QXH507emO@@0PH61101lO7`508:2PP@0P8202@21PH4407emO@D0
P8201021PH4507emO@@0PX:2101fMWH508V9R@@0OGem2@1oOgl407alO0D0Ogmo1024Q8@508:2PP@0
Ng]k1020P80508>3P`@0OGem1@1oOgl408B4Q0@0PH611@1oOgl407alO0D0OGem101jNWX407moO`T0
O7al1@1jNWX807emO@D0P820101kNg/507inOP@0PX:22@1nOWh40861P@D0PX:21020P80907moO`@0
P8201021PH4507moOaH0b>3H000E0<SPf0D0;Rh^100_;bl4038b<PD0<30`100/;2`5030`<0@0;Rh^
100_;bl903<c<`D09bLW100S8b<4024Q8@D0;Bd]1025QHD50861P@@0Hf=S102RXZ850:NWY`@0ZJVY
102`/;050;Jf]P@0a<C41@36a/H40;jn_P@0IVIV1@1EEED406YZJPD0N7Qh1020P80408F5Q@D0Rh^;
102ATI4508f=S@@0TI6A2@2DU9@408j>SPD0SHf=102BTY8409JFUPD0QXJ61029RHT508:2PP@0Ogmo
1024Q8@508^;R`@0Ph>31@2;Rh/4096AT@@0Vi^K1@2HV9P409JFUPD0TY:B102DU9@408f=S@D0N7Qh
101oOgl508F5Q@@0Ph>31021PH4507moO`@0P8201@2:RXX=0<SPf0@0O7al101bLW8507inOP@0Ph>3
1@1lO7`408J6QP@0PH612@24Q8@907emO@@0Ogmo1@1mOGd40861P@@0Ph>31@1oOgl407emO@D0P820
101nOWh40861P@D0OGem101kNg/50820P0@0Ogmo1020P80507UiN@@0Q8B41@1nOWh408:2PPT0Ogmo
2@21PH4408>3P`@0Ogmo1@1nOWh40861P@D0Ogmo101nOWh407emO@T0OWin1@21PH4408B4Q0@0OGem
1@1nOWh407YjNPD0Ng]k101mOGd407IfMPD0Ogmo1022PX8508B4Q0@0P8201025QHD508:2PP@0PH61
1@1kNg/40820P0@0Ogmo1@20P8040861P@@0O7al1@23Ph<F0<SPf0005@38h=P502h^;P@0;bl_100b
<S85030`<0@0;2`/1@0`<30402h^;P@0;bl_2@0c<c<502LW9`@08b<S100Q8B4502d];@@0QHF51@21
PH4406=SH`@0XZ:R1@2WYjL40:VYZ@@0/;2`1@2f][H40<C4a0D0a/K6102n_[h406IVIPD0EEEE101Z
JVX507QhN0@0P8201025QHD508^;R`@0TI6A1@2=SHd4096AT@T0U9BD102>SXh508f=S@@0TY:B102F
UYH508J6QP@0RHV91@22PX8407moO`@0Q8B41@2;Rh/408>3P`D0Rh^;102ATI4409^KV`D0V9RH102F
UYH509:BTP@0U9BD102=SHd507QhN0@0Ogmo1@25QHD408>3P`@0PH611@1oOgl40820P0D0RXZ:3@38
h=P407alO0@0LW9b1@1nOWh408>3P`D0O7al1026QXH40861P@T0Q8B42@1mOGd407moO`D0OGem1021
PH4408>3P`D0Ogmo101mOGd50820P0@0OWin1021PH4507emO@@0Ng]k1@20P80407moO`@0P8201@1i
NGT408B4Q0D0OWin1022PX8907moO`T0PH611023Ph<407moO`D0OWin1021PH4507moO`@0OWin101m
OGd907inOPD0PH611024Q8@407emO@D0OWin101jNWX507]kN`@0OGem101fMWH507moO`@0PX:21@24
Q8@40820P0@0QHF51@22PX840861P@D0Ng]k1020P80407moO`D0P8201021PH4407alO0D0Ph>35P38
h=P001D0b>3H1@0^;Rh402l_;`@0<S8b1@0`<30402`/;0D0<30`100^;Rh402l_;`T0<c<c1@0W9bL4
02<S8`@08B4Q1@0];Bd408F5Q@D0PH61101SHf<40::RXPD0YjNW102YZJT40;2`/0D0][Jf1034a<@5
0<K6aP@0_[jn101VIVH505EEE@@0JVYZ1@1hN7P40820P0@0QHF51@2;Rh/4096AT@D0SHf=102ATI49
09BDU0@0SXj>1@2=SHd409:BTP@0UYJF1@26QXH408V9R@D0PX:2101oOgl408B4Q0D0Rh^;1023Ph<5
08^;R`@0TI6A102KVi/509RHV0@0UYJF1@2BTY8409BDU0@0SHf=1@1hN7P407moO`D0QHF51023Ph<4
0861P@D0Ogmo1020P80508Z:RPd0b>3H101lO7`4079bLPD0OWin1023Ph<507alO0@0QXJ61021PH49
08B4Q0T0OGem101oOgl507emO@@0PH611023Ph<507moO`@0OGem1@20P80407inOP@0PH611@1mOGd4
07]kN`D0P820101oOgl40820P0D0NGUi1024Q8@507inOP@0PX:22@1oOgl90861P@@0Ph>3101oOgl5
07inOP@0PH611@1oOgl407inOP@0OGem2@1nOWh50861P@@0Q8B4101mOGd507inOP@0NWYj1@1kNg/4
07emO@@0MWIf1@1oOgl408:2PPD0Q8B41020P80408F5Q@D0PX:21021PH4507]kN`@0P820101oOgl5
0820P0@0PH61101lO7`508>3PaH0b>3H000E0<SPf0D0;Rh^100_;bl4038b<PD0<30`100/;2`5030`
<0@0;Rh^100_;bl903<c<`D09bLW100S8b<4024Q8@D0;Bd]1025QHD50861P@@0Hf=S102RXZ850:NW
Y`@0ZJVY102`/;050;Jf]P@0a<C41@36a/H40;jn_P@0IVIV1@1EEED406YZJPD0N7Qh1020P80408F5
Q@D0Rh^;102ATI4508f=S@@0TI6A2@2DU9@408j>SPD0SHf=102BTY8409JFUPD0QXJ61029RHT508:2
PP@0Ogmo1024Q8@508^;R`@0Ph>31@2;Rh/4096AT@@0Vi^K1@2HV9P409JFUPD0TY:B102DU9@408f=
S@D0N7Qh101oOgl508F5Q@@0Ph>31021PH4507moO`@0P8201@2:RXX=0<SPf0@0O7al101bLW8507in
OP@0Ph>31@1lO7`408J6QP@0PH612@24Q8@907emO@@0Ogmo1@1mOGd40861P@@0Ph>31@1oOgl407em
O@D0P820101nOWh40861P@D0OGem101kNg/50820P0@0Ogmo1020P80507UiN@@0Q8B41@1nOWh408:2
PPT0Ogmo2@21PH4408>3P`@0Ogmo1@1nOWh40861P@D0Ogmo101nOWh407emO@T0OWin1@21PH4408B4
Q0@0OGem1@1nOWh407YjNPD0Ng]k101mOGd407IfMPD0Ogmo1022PX8508B4Q0@0P8201025QHD508:2
PP@0PH611@1kNg/40820P0@0Ogmo1@20P8040861P@@0O7al1@23Ph<F0<SPf0005@38h=P502TY:@@0
;Rh^2@0[:b/402`/;0D0<C4a100/;2`402l_;`D0=CDe100`<30502LW9`@09RHV100S8b<5024Q8@@0
AdM71@2BTY8406ATI0@0P8201@2n_[h40:2PX0@0[Jf]1@2d];@40;no_`D0alO71033`l<40;bl_0D0
I6AT101VIVH507AdM0@0OWin1025QHD508V9R@T0Rh^;102?Shl4092@T0D0SXj>102ATI4508n?S`@0
SXj>102<S8`507alO0@0MGEe1@1kNg/406IVIP@0Ph>31@28R8P4075aL@D0Ng]k101/K6`409bLW0D0
UIFE102SXj<50:2PX0@0Ti>C1023Ph<507UiN@@0NWYj1@21PH4408:2PPT0PH611020P805092@T0d0
b>3H1023Ph<407moO`D0O7al101nOWh908:2PP@0O7al1@1kNg/407moO`D0O7al101nOWh407alO0D0
PH611020P80408:2PPD0OGem1020P80508>3P`@0Ogmo1024Q8@90820P0D0OWin101lO7`408:2PPD0
OGem101gMgL50861P@@0OWin1024Q8@50820P0@0Ogmo1@22PX8407moO`@0PX:22@1mOGd507inOP@0
PH612@1nOWh408>3P`D0PX:2101mOGd408B4Q0D0PX:21029RHT509JFUP@0U9BD102CTi<508F5Q@@0
NWYj1@1iNGT407]kN`@0Ogmo1@20P80408>3P`D0P820101nOWh407moO`T0Ng]k1021PH4508:2PQH0
b>3H000E0<SPf0D0:BTY100^;Rh902/[:`@0;2`/1@0a<C4402`/;0@0;bl_1@0e=CD4030`<0D09bLW
100V9RH402<S8`D08B4Q1017AdL509:BTP@0I6AT1020P8050;jn_P@0X:2P102][Jd50;Bd]0@0_kno
1@37alL40<?3``@0_;bl1@1TI6@406IVIPD0M7Ad101nOWh408F5Q@D0RHV92@2;Rh/408n?S`@0T92@
1@2>SXh4096AT@D0Shn?102>SXh408b<S0D0O7al101eMGD507]kN`@0IVIV1023Ph<508R8R0@0LG5a
1@1kNg/406a/K0@0W9bL1@2EUID40:>SX`D0X:2P102CTi<408>3P`D0NGUi101jNWX50861P@@0PX:2
2@21PH440820P0D0T92@3@38h=P408>3P`@0Ogmo1@1lO7`407inOPT0PX:2101lO7`507]kN`@0Ogmo
1@1lO7`407inOP@0O7al1@21PH440820P0@0PX:21@1mOGd40820P0D0Ph>3101oOgl408B4Q0T0P820
1@1nOWh407alO0@0PX:21@1mOGd407MgM`D0PH61101nOWh408B4Q0D0P820101oOgl508:2PP@0Ogmo
1022PX8907emO@D0OWin1021PH4907inOP@0Ph>31@22PX8407emO@@0Q8B41@22PX8408V9R@D0UYJF
102DU9@409>CT`D0QHF5101jNWX507UiN@@0Ng]k101oOgl50820P0@0Ph>31@20P80407inOP@0Ogmo
2@1kNg/40861P@D0PX:25P38h=P001D0b>3H1@0Y:BT402h^;PT0:b/[100/;2`5034a<@@0;2`/100_
;bl503De=@@0<30`1@0W9bL402HV9P@08b<S1@0Q8B4404M7A`D0TY:B101TI6@40820P0D0_[jn102P
X:040:f][@D0];Bd102o_kl50<O7a`@0`l?3102l_;`506ATI0@0IVIV1@1dM7@407inOP@0QHF51@29
RHT908^;R`@0Shn?102@T90508j>SP@0TI6A1@2?Shl408j>SP@0S8b<1@1lO7`407EeM@D0Ng]k101V
IVH408>3P`D0R8R8101aLG4507]kN`@0K6a/102LW9`509FEU@@0Xj>S1@2PX:0409>CT`@0Ph>31@1i
NGT407YjNPD0PH611022PX890861P@@0P8201@2@T90=0<SPf0@0Ph>3101oOgl507alO0@0OWin2@22
PX8407alO0D0Ng]k101oOgl507alO0@0OWin101lO7`50861P@@0P8201022PX8507emO@@0P8201@23
Ph<407moO`@0Q8B42@20P80507inOP@0O7al1022PX8507emO@@0MgMg1@21PH4407inOP@0Q8B41@20
P80407moO`D0PX:2101oOgl408:2PPT0OGem1@1nOWh40861P@T0OWin1023Ph<508:2PP@0OGem1024
Q8@508:2PP@0RHV91@2FUYH409BDU0@0Ti>C1@25QHD407YjNPD0NGUi101kNg/407moO`D0P8201023
Ph<50820P0@0OWin101oOgl907]kN`@0PH611@22PX8F0<SPf0005@38h=P502TY:@@0;Rh^2@0[:b/4
02`/;0D0<C4a100/;2`402l_;`D0=CDe100`<30502LW9`@09RHV100S8b<5024Q8@@0AdM71@2BTY84
06ATI0@0P8201@2n_[h40:2PX0@0[Jf]1@2d];@40;no_`D0alO71033`l<40;bl_0D0I6AT101VIVH5
07AdM0@0OWin1025QHD508V9R@T0Rh^;102?Shl4092@T0D0SXj>102ATI4508n?S`@0SXj>102<S8`5
07alO0@0MGEe1@1kNg/406IVIP@0Ph>31@28R8P4075aL@D0Ng]k101/K6`409bLW0D0UIFE102SXj<5
0:2PX0@0Ti>C1023Ph<507UiN@@0NWYj1@21PH4408:2PPT0PH611020P805092@T0d0b>3H1023Ph<4
07moO`D0O7al101nOWh908:2PP@0O7al1@1kNg/407moO`D0O7al101nOWh407alO0D0PH611020P804
08:2PPD0OGem1020P80508>3P`@0Ogmo1024Q8@90820P0D0OWin101lO7`408:2PPD0OGem101gMgL5
0861P@@0OWin1024Q8@50820P0@0Ogmo1@22PX8407moO`@0PX:22@1mOGd507inOP@0PH612@1nOWh4
08>3P`D0PX:2101mOGd408B4Q0D0PX:21029RHT509JFUP@0U9BD102CTi<508F5Q@@0NWYj1@1iNGT4
07]kN`@0Ogmo1@20P80408>3P`D0P820101nOWh407moO`T0Ng]k1021PH4508:2PQH0b>3H000E0<SP
f0D0:BTY100^;Rh902/[:`@0;2`/1@0a<C4402`/;0@0;bl_1@0e=CD4030`<0D09bLW100V9RH402<S
8`D08B4Q1017AdL509:BTP@0I6AT1020P8050;jn_P@0X:2P102][Jd50;Bd]0@0_kno1@37alL40<?3
``@0_;bl1@1TI6@406IVIPD0M7Ad101nOWh408F5Q@D0RHV92@2;Rh/408n?S`@0T92@1@2>SXh4096A
T@D0Shn?102>SXh408b<S0D0O7al101eMGD507]kN`@0IVIV1023Ph<508R8R0@0LG5a1@1kNg/406a/
K0@0W9bL1@2EUID40:>SX`D0X:2P102CTi<408>3P`D0NGUi101jNWX50861P@@0PX:22@21PH440820
P0D0T92@3@38h=P408>3P`@0Ogmo1@1lO7`407inOPT0PX:2101lO7`507]kN`@0Ogmo1@1lO7`407in
OP@0O7al1@21PH440820P0@0PX:21@1mOGd40820P0D0Ph>3101oOgl408B4Q0T0P8201@1nOWh407al
O0@0PX:21@1mOGd407MgM`D0PH61101nOWh408B4Q0D0P820101oOgl508:2PP@0Ogmo1022PX8907em
O@D0OWin1021PH4907inOP@0Ph>31@22PX8407emO@@0Q8B41@22PX8408V9R@D0UYJF102DU9@409>C
T`D0QHF5101jNWX507UiN@@0Ng]k101oOgl50820P0@0Ph>31@20P80407inOP@0Ogmo2@1kNg/40861
P@D0PX:25P38h=P001D0b>3H1@0[:b/402HV9P@0:b/[2@0_;bl502h^;P@0<30`100/;2`5030`<0T0
<C4a100T92@402HV9PT08b<S1@1bLW8408F5Q@@0GUiN1@2b/[840;Ng]`@0YJFU1@2`/;040;Zj^PD0
`l?31039bLT40<71`@D0]kNg101XJ6P506YZJP@0NGUi101oOgl508:2PP@0Q8B41@22PX8408j>SP@0
Shn?2@2>SXh508B4Q0@0MgMg101nOWh507YjNP@0J6QX1@1hN7P406YZJP@0QXJ61@2?Shl408b<S0D0
WIfM102?Shl40:FUY@D0/;2`2@2[Zj/409fMW@@0RXZ:1@1nOWh407alO0D0N7Qh101nOWh407moO`D0
PX:21024Q8@5096AT@d0b>3H1027QhL407emO@D0Ph>31020P80507]kN`@0P8201022PX8507emO@@0
NWYj1@29RHT408B4Q0@0Ph>31@1jNWX408B4Q0@0P8201@26QXH407]kN`D0R8R8101oOgl407inOPD0
Ogmo101nOWh507emO@@0PH612@20P80407alO0D0N7Qh1026QXH407emO@D0Ph>3101oOgl908:2PPT0
OWin101oOgl508:2PP@0OWin1021PH4507]kN`@0O7al1@29RHT408F5Q@@0M7Ad1@1jNWX407moO`D0
Ng]k1020P80407inOPD0LG5a101/K6`507inOP@0Ph>31021PH4507emO@@0Ogmo1@25QHD407moO`@0
QXJ61@1lO7`408F5Q@@0Q8B41@1oOglF0<SPf0005@38h=P502/[:`@09RHV100[:b/902l_;`D0;Rh^
100`<30402`/;0D0<30`2@0a<C4402@T90@09RHV2@0S8b<5079bLP@0QHF5101NGUh50;:b/P@0]kNg
102UYJD50;2`/0@0^[Zj1@33`l<40<W9b@@0`L711@2g]kL406QXJ0D0JVYZ101iNGT407moO`D0PX:2
1024Q8@508:2PP@0SXj>102?Shl908j>SPD0Q8B4101gMgL407inOPD0NWYj101XJ6P507QhN0@0JVYZ
1026QXH508n?S`@0S8b<1@2MWId408n?S`@0YJFU1@2`/;090:^[Z`@0WIfM102:RXX507inOP@0O7al
1@1hN7P407inOP@0Ogmo1@22PX8408B4Q0D0TI6A3@38h=P408N7Q`@0OGem1@23Ph<40820P0D0Ng]k
1020P80408:2PPD0OGem101jNWX508V9R@@0Q8B41023Ph<507YjNP@0Q8B41020P80508J6QP@0Ng]k
1@28R8P407moO`@0OWin1@1oOgl407inOPD0OGem1021PH490820P0@0O7al1@1hN7P408J6QP@0OGem
1@23Ph<407moO`T0PX:22@1nOWh407moO`D0PX:2101nOWh40861P@D0Ng]k101lO7`508V9R@@0QHF5
101dM7@507YjNP@0Ogmo1@1kNg/40820P0@0OWin1@1aLG4406a/K0D0OWin1023Ph<40861P@D0OGem
101oOgl508F5Q@@0Ogmo1026QXH507alO0@0QHF51024Q8@507moOaH0b>3H000E0<SPf0D0:b/[100V
9RH402/[:`T0;bl_1@0^;Rh4030`<0@0;2`/1@0`<309034a<@@092@T100V9RH902<S8`D0LW9b1025
QHD405iNGPD0/[:b102g]kL40:FUY@D0/;2`102j^[X50<?3``@0bLW91031`L450;Ng]`@0J6QX1@1Z
JVX407UiN@@0Ogmo1@22PX8408B4Q0D0PX:2102>SXh408n?S`T0SXj>1@24Q8@407MgM`@0OWin1@1j
NWX406QXJ0D0N7Qh101ZJVX408J6QPD0Shn?102<S8`509fMW@@0Shn?102UYJD50;2`/0T0Zj^[102M
WId408Z:RPD0OWin101lO7`507QhN0@0OWin101oOgl508:2PP@0Q8B41@2ATI4=0<SPf0@0QhN7101m
OGd508>3P`@0P8201@1kNg/40820P0@0PX:21@1mOGd407YjNPD0RHV91024Q8@408>3P`D0NWYj1024
Q8@40820P0D0QXJ6101kNg/508R8R0@0Ogmo101nOWh507moO`@0OWin1@1mOGd40861P@T0P820101l
O7`507QhN0@0QXJ6101mOGd508>3P`@0Ogmo2@22PX8907inOP@0Ogmo1@22PX8407inOP@0PH611@1k
Ng/407alO0D0RHV91025QHD407AdM0D0NWYj101oOgl507]kN`@0P820101nOWh5075aL@@0K6a/1@1n
OWh408>3P`@0PH611@1mOGd407moO`D0QHF5101oOgl408J6QPD0O7al1025QHD408B4Q0D0Ogmo5P38
h=P001D0b>3H1@0[:b/402HV9P@0:b/[2@0_;bl502h^;P@0<30`100/;2`5030`<0T0<C4a100T92@4
02HV9PT08b<S1@1bLW8408F5Q@@0GUiN1@2b/[840;Ng]`@0YJFU1@2`/;040;Zj^PD0`l?31039bLT4
0<71`@D0]kNg101XJ6P506YZJP@0NGUi101oOgl508:2PP@0Q8B41@22PX8408j>SP@0Shn?2@2>SXh5
08B4Q0@0MgMg101nOWh507YjNP@0J6QX1@1hN7P406YZJP@0QXJ61@2?Shl408b<S0D0WIfM102?Shl4
0:FUY@D0/;2`2@2[Zj/409fMW@@0RXZ:1@1nOWh407alO0D0N7Qh101nOWh407moO`D0PX:21024Q8@5
096AT@d0b>3H1027QhL407emO@D0Ph>31020P80507]kN`@0P8201022PX8507emO@@0NWYj1@29RHT4
08B4Q0@0Ph>31@1jNWX408B4Q0@0P8201@26QXH407]kN`D0R8R8101oOgl407inOPD0Ogmo101nOWh5
07emO@@0PH612@20P80407alO0D0N7Qh1026QXH407emO@D0Ph>3101oOgl908:2PPT0OWin101oOgl5
08:2PP@0OWin1021PH4507]kN`@0O7al1@29RHT408F5Q@@0M7Ad1@1jNWX407moO`D0Ng]k1020P804
07inOPD0LG5a101/K6`507inOP@0Ph>31021PH4507emO@@0Ogmo1@25QHD407moO`@0QXJ61@1lO7`4
08F5Q@@0Q8B41@1oOglF0<SPf0005@38h=P502XZ:P@09BDU100X:2P5034a<@@0<S8b1@0`<30403hn
?P@0<c<c1@0`<304034a<@D0=cLg100];Bd402HV9PD08b<S100X:2P503`l?0@0TI6A101WIfL507in
OP@0alO7102QXJ450:NWY`@0];Bd1@2k^k/40<S8b0@0a/K61@31`L440;Fe]@D0J6QX101cLg<407]k
N`D0OWin1020P80507inOP@0Shn?102>SXh508b<S0@0PH611@1cLg<406MWI`@0F5QH1@1_Kfl408:2
PPD0S8b<102JVYX40:2PX0D0[:b/102h^;P50;no_`@0`L71102e]KD50:RXZ0@0Ti>C1@2;Rh/407Mg
M`@0Ogmo1@22PX8407YjNPD0MWIf101jNWX408:2PPD0PH611023Ph<509BDU0d0b>3H101hN7P408B4
Q0D0QXJ61023Ph<507UiN@@0P820101iNGT508B4Q0@0M7Ad1@25QHD408B4Q0@0Ph>31@22PX840820
P0@0OWin1@25QHD407MgM`D0OGem101nOWh407alO0D0R8R82@22PX840861P@@0Ogmo2@21PH4507in
OP@0Ogmo1029RHT507MgM`@0PH611@1nOWh40861P@@0P8201@24Q8@40820P0D0Ogmo101lO7`407in
OPD0P820101gMgL507alO0@0OGem101lO7`507QhN0@0O7al1@1mOGd407alO0@0NWYj1@1fMWH408b<
S0D0PH61101eMGD407inOPT0P8201@1oOgl408>3P`@0OGem1@1nOWh40820P0@0OGem1@21PH4F0<SP
f0005@38h=P502XZ:P@09BDU100X:2P5034a<@@0<S8b1@0`<30403hn?P@0<c<c1@0`<304034a<@D0
=cLg100];Bd402HV9PD08b<S100X:2P503`l?0@0TI6A101WIfL507inOP@0alO7102QXJ450:NWY`@0
];Bd1@2k^k/40<S8b0@0a/K61@31`L440;Fe]@D0J6QX101cLg<407]kN`D0OWin1020P80507inOP@0
Shn?102>SXh508b<S0@0PH611@1cLg<406MWI`@0F5QH1@1_Kfl408:2PPD0S8b<102JVYX40:2PX0D0
[:b/102h^;P50;no_`@0`L71102e]KD50:RXZ0@0Ti>C1@2;Rh/407MgM`@0Ogmo1@22PX8407YjNPD0
MWIf101jNWX408:2PPD0PH611023Ph<509BDU0d0b>3H101hN7P408B4Q0D0QXJ61023Ph<507UiN@@0
P820101iNGT508B4Q0@0M7Ad1@25QHD408B4Q0@0Ph>31@22PX840820P0@0OWin1@25QHD407MgM`D0
OGem101nOWh407alO0D0R8R82@22PX840861P@@0Ogmo2@21PH4507inOP@0Ogmo1029RHT507MgM`@0
PH611@1nOWh40861P@@0P8201@24Q8@40820P0D0Ogmo101lO7`407inOPD0P820101gMgL507alO0@0
OGem101lO7`507QhN0@0O7al1@1mOGd407alO0@0NWYj1@1fMWH408b<S0D0PH61101eMGD407inOPT0
P8201@1oOgl408>3P`@0OGem1@1nOWh40820P0@0OGem1@21PH4F0<SPf0005@38h=P502XZ:P@09BDU
100X:2P5034a<@@0<S8b1@0`<30403hn?P@0<c<c1@0`<304034a<@D0=cLg100];Bd402HV9PD08b<S
100X:2P503`l?0@0TI6A101WIfL507inOP@0alO7102QXJ450:NWY`@0];Bd1@2k^k/40<S8b0@0a/K6
1@31`L440;Fe]@D0J6QX101cLg<407]kN`D0OWin1020P80507inOP@0Shn?102>SXh508b<S0@0PH61
1@1cLg<406MWI`@0F5QH1@1_Kfl408:2PPD0S8b<102JVYX40:2PX0D0[:b/102h^;P50;no_`@0`L71
102e]KD50:RXZ0@0Ti>C1@2;Rh/407MgM`@0Ogmo1@22PX8407YjNPD0MWIf101jNWX408:2PPD0PH61
1023Ph<509BDU0d0b>3H101hN7P408B4Q0D0QXJ61023Ph<507UiN@@0P820101iNGT508B4Q0@0M7Ad
1@25QHD408B4Q0@0Ph>31@22PX840820P0@0OWin1@25QHD407MgM`D0OGem101nOWh407alO0D0R8R8
2@22PX840861P@@0Ogmo2@21PH4507inOP@0Ogmo1029RHT507MgM`@0PH611@1nOWh40861P@@0P820
1@24Q8@40820P0D0Ogmo101lO7`407inOPD0P820101gMgL507alO0@0OGem101lO7`507QhN0@0O7al
1@1mOGd407alO0@0NWYj1@1fMWH408b<S0D0PH61101eMGD407inOPT0P8201@1oOgl408>3P`@0OGem
1@1nOWh40820P0@0OGem1@21PH4F0<SPf0005@38h=P502XZ:P@09BDU100X:2P5034a<@@0<S8b1@0`
<30403hn?P@0<c<c1@0`<304034a<@D0=cLg100];Bd402HV9PD08b<S100X:2P503`l?0@0TI6A101W
IfL507inOP@0alO7102QXJ450:NWY`@0];Bd1@2k^k/40<S8b0@0a/K61@31`L440;Fe]@D0J6QX101c
Lg<407]kN`D0OWin1020P80507inOP@0Shn?102>SXh508b<S0@0PH611@1cLg<406MWI`@0F5QH1@1_
Kfl408:2PPD0S8b<102JVYX40:2PX0D0[:b/102h^;P50;no_`@0`L71102e]KD50:RXZ0@0Ti>C1@2;
Rh/407MgM`@0Ogmo1@22PX8407YjNPD0MWIf101jNWX408:2PPD0PH611023Ph<509BDU0d0b>3H101h
N7P408B4Q0D0QXJ61023Ph<507UiN@@0P820101iNGT508B4Q0@0M7Ad1@25QHD408B4Q0@0Ph>31@22
PX840820P0@0OWin1@25QHD407MgM`D0OGem101nOWh407alO0D0R8R82@22PX840861P@@0Ogmo2@21
PH4507inOP@0Ogmo1029RHT507MgM`@0PH611@1nOWh40861P@@0P8201@24Q8@40820P0D0Ogmo101l
O7`407inOPD0P820101gMgL507alO0@0OGem101lO7`507QhN0@0O7al1@1mOGd407alO0@0NWYj1@1f
MWH408b<S0D0PH61101eMGD407inOPT0P8201@1oOgl408>3P`@0OGem1@1nOWh40820P0@0OGem1@21
PH4F0<SPf0005@38h=P902l_;`@0:RXZ1@0d=3@403`l?0D0;2`/100g=cL4034a<@T0:RXZ1@0b<S84
02PX:0@0:BTY1@0S8b<402DU9@D0=3@d101MGEd408j>SPD0EUIF102PX:040:b/[0D0W9bL102d];@5
0;Fe]@@0`/;22@36a/H40<71`@D0^[Zj101eMGD407AdM0D0N7Qh101gMgL507inOPP0QhN71@1mOGd4
06EUI@D0ADE5101BDU84071`L0D0MWIf1020P80506a/K0@0IFEU1027QhL50;Ng]`@0aLG51@3;bl/4
0<o?c`@0bLW91@2][Jd408^;R`D0Ti>C101eMGD407YjNPD0O7al101cLg<507MgM`@0Ng]k101nOWh5
08>3P`@0QXJ61@2@T90=0<SPf0@0MWIf1023Ph<507inOP@0P8201@28R8P40820P0@0Ph>31@1nOWh4
07emO@D0PH61101lO7`407inOPD0QXJ61024Q8@907]kN`@0O7al1@1gMgL408B4Q0@0PH611@1bLW84
07UiN@D0N7Qh101lO7`40820P0D0Ogmo101nOWh50820P0@0OGem101iNGT508F5Q@@0Ng]k1@20P804
07emO@@0OWin1@23Ph<407emO@D0Ogmo1026QXH408:2PPD0OWin1027QhL507emO@@0OWin102=SHd5
08N7Q`@0MWIf1@22PX8408F5Q@@0Q8B41@27QhL407emO@D0P8201021PH4408:2PPD0Ogmo1023Ph<5
07emO@@0O7al1020P80508>3P`d0O7al5P38h=P001D0b>3H2@0_;bl402XZ:PD0=3@d100l?3`502`/
;0@0=cLg100a<C4902XZ:PD0<S8b100X:2P402TY:@D08b<S100U9BD503@d=0@0GEeM102>SXh505IF
EP@0X:2P102/[:`509bLW0@0];Bd1@2e]KD40<;2`PT0a/K61031`L450;Zj^P@0MGEe101dM7@507Qh
N0@0MgMg1@1nOWh808N7Q`D0OGem101UIFD504E5A@@0DU9B101`L70507IfMP@0P8201@1/K6`406EU
I@@0QhN71@2g]kL40<G5a@D0bl_;103?cll40<W9b@D0[Jf]102;Rh/509>CT`@0MGEe101jNWX507al
O0@0Lg=c1@1gMgL407]kN`@0OWin1@23Ph<408J6QPD0T92@3@38h=P407IfMP@0Ph>31@1nOWh40820
P0D0R8R81020P80408>3P`D0OWin101mOGd50861P@@0O7al101nOWh508J6QP@0Q8B42@1kNg/407al
O0D0MgMg1024Q8@40861P@D0LW9b101iNGT507QhN0@0O7al1020P80507moO`@0OWin1@20P80407em
O@@0NGUi1@25QHD407]kN`D0P820101mOGd407inOPD0Ph>3101mOGd507moO`@0QXJ61022PX8507in
OP@0QhN71@1mOGd407inOP@0SHf=1@27QhL407IfMPD0PX:21025QHD408B4Q0D0QhN7101mOGd50820
P0@0PH611022PX8507moO`@0Ph>31@1mOGd407alO0@0P8201@23Ph<=07alO1H0b>3H000E0<SPf0T0
;bl_100Z:RX503@d=0@0?3`l1@0/;2`403Lg=`@0<C4a2@0Z:RX5038b<P@0:2PX100Y:BT502<S8`@0
9BDU1@0d=3@405eMG@@0SXj>1@1FEUH40:2PX0@0[:b/1@2LW9`40;Bd]0D0]KFe1032`/890<K6aP@0
`L711@2j^[X407EeM@@0M7Ad1@1hN7P407MgM`D0OWin2027QhL507emO@@0IFEU1@15ADD4059BDP@0
L71`1@1fMWH40820P0D0K6a/101UIFD408N7Q`D0]kNg1035aLD50<_;b`@0clo?1039bLT50:f][@@0
Rh^;1@2CTi<407EeM@@0NWYj1@1lO7`407=cL`D0MgMg101kNg/407inOPD0Ph>31026QXH5092@T0d0
b>3H101fMWH408>3P`D0OWin1020P80508R8R0@0P8201023Ph<507inOP@0OGem1@21PH4407alO0@0
OWin1@26QXH408B4Q0T0Ng]k101lO7`507MgM`@0Q8B41021PH45079bLP@0NGUi1@1hN7P407alO0@0
P8201@1oOgl407inOPD0P820101mOGd407UiN@D0QHF5101kNg/50820P0@0OGem101nOWh508>3P`@0
OGem1@1oOgl408J6QP@0PX:21@1nOWh408N7Q`D0OGem101nOWh408f=S@D0QhN7101fMWH508:2PP@0
QHF51024Q8@508N7Q`@0OGem1@20P8040861P@@0PX:21@1oOgl408>3P`D0OGem101lO7`40820P0D0
Ph>33@1lO7`F0<SPf0005@38h=P902l_;`@0:RXZ1@0d=3@403`l?0D0;2`/100g=cL4034a<@T0:RXZ
1@0b<S8402PX:0@0:BTY1@0S8b<402DU9@D0=3@d101MGEd408j>SPD0EUIF102PX:040:b/[0D0W9bL
102d];@50;Fe]@@0`/;22@36a/H40<71`@D0^[Zj101eMGD407AdM0D0N7Qh101gMgL507inOPP0QhN7
1@1mOGd406EUI@D0ADE5101BDU84071`L0D0MWIf1020P80506a/K0@0IFEU1027QhL50;Ng]`@0aLG5
1@3;bl/40<o?c`@0bLW91@2][Jd408^;R`D0Ti>C101eMGD407YjNPD0O7al101cLg<507MgM`@0Ng]k
101nOWh508>3P`@0QXJ61@2@T90=0<SPf0@0MWIf1023Ph<507inOP@0P8201@28R8P40820P0@0Ph>3
1@1nOWh407emO@D0PH61101lO7`407inOPD0QXJ61024Q8@907]kN`@0O7al1@1gMgL408B4Q0@0PH61
1@1bLW8407UiN@D0N7Qh101lO7`40820P0D0Ogmo101nOWh50820P0@0OGem101iNGT508F5Q@@0Ng]k
1@20P80407emO@@0OWin1@23Ph<407emO@D0Ogmo1026QXH408:2PPD0OWin1027QhL507emO@@0OWin
102=SHd508N7Q`@0MWIf1@22PX8408F5Q@@0Q8B41@27QhL407emO@D0P8201021PH4408:2PPD0Ogmo
1023Ph<507emO@@0O7al1020P80508>3P`d0O7al5P38h=P001D0b>3H2@0_;bl402XZ:PD0=3@d100l
?3`502`/;0@0=cLg100a<C4902XZ:PD0<S8b100X:2P402TY:@D08b<S100U9BD503@d=0@0GEeM102>
SXh505IFEP@0X:2P102/[:`509bLW0@0];Bd1@2e]KD40<;2`PT0a/K61031`L450;Zj^P@0MGEe101d
M7@507QhN0@0MgMg1@1nOWh808N7Q`D0OGem101UIFD504E5A@@0DU9B101`L70507IfMP@0P8201@1/
K6`406EUI@@0QhN71@2g]kL40<G5a@D0bl_;103?cll40<W9b@D0[Jf]102;Rh/509>CT`@0MGEe101j
NWX507alO0@0Lg=c1@1gMgL407]kN`@0OWin1@23Ph<408J6QPD0T92@3@38h=P407IfMP@0Ph>31@1n
OWh40820P0D0R8R81020P80408>3P`D0OWin101mOGd50861P@@0O7al101nOWh508J6QP@0Q8B42@1k
Ng/407alO0D0MgMg1024Q8@40861P@D0LW9b101iNGT507QhN0@0O7al1020P80507moO`@0OWin1@20
P80407emO@@0NGUi1@25QHD407]kN`D0P820101mOGd407inOPD0Ph>3101mOGd507moO`@0QXJ61022
PX8507inOP@0QhN71@1mOGd407inOP@0SHf=1@27QhL407IfMPD0PX:21025QHD408B4Q0D0QhN7101m
OGd50820P0@0PH611022PX8507moO`@0Ph>31@1mOGd407alO0@0P8201@23Ph<=07alO1H0b>3H000E
0<SPf0D0>3Ph100X:2P402XZ:PD0>3Ph101VIVH502h^;P@0<C4a100b<S8502/[:`@0;Bd]1@0e=CD4
02/[:`@0:RXZ1@0W9bL402XZ:PT0;2`/101eMGD506EUI@@0IfMW102UYJD509BDU0@0XJ6Q1@2/[:`4
0;Vi^@@0`l?31@37alL40<G5a@D0`/;2102m_Kd4075aL@D0Kfm_101gMgL50820P0@0MWIf101cLg<5
06IVIP@0BTY:1@0^;Rh404Q8B0@0J6QX1@1gMgL405IFEPD0?Cdm1010@40404A4A0D0KVi^1031`L45
0<c<c0@0clo?1039bLT50;no_`@0Vi^K1@1`L70406QXJ0@0OGem1@1YJFT4079bLPD0NGUi101cLg<4
07moO`D0QXJ6102:RXX509FEU@d0b>3H1027QhL408B4Q0D0Ph>3101nOWh507alO0@0OWin101oOgl5
07emO@@0PH612@1mOGd40861P@D0P820101nOWh408:2PPD0OGem101nOWh908V9R@@0OWin1@24Q8@4
08R8R0D0Rh^;1028R8P408F5Q@T0P8201@1nOWh807moO`D0P8201022PX850861P@@0P820101kNg/5
08>3P`@0Ng]k1@22PX8807IfMPD0PX:2101kNg/508^;R`@0O7al101^KVh507inOP@0S8b<1@1hN7P4
07emO@@0O7al1@1nOWh407emO@D0Ogmo101nOWh40861P@D0Ogmo1020P80908:2PP@0OWin1@1oOgl8
0820P0D0O7al5P38h=P001D0b>3H1@0h>3P402PX:0@0:RXZ1@0h>3P406IVIPD0;Rh^100a<C44038b
<PD0:b/[100];Bd503De=@@0:b/[100Z:RX502LW9`@0:RXZ2@0/;2`407EeM@D0IFEU101WIfL40:FU
Y@D0U9BD102QXJ450:b/[0@0^KVi1033`l<50<O7a`@0aLG51@32`/840;fm_@@0LG5a1@1_Kfl407Mg
M`D0P820101fMWH407=cL`D0IVIV101:BTX502h^;P@0B4Q8101XJ6P507MgM`@0EUIF1@0m?Cd40410
@0@0A4A41@1^KVh40<71`@D0c<c<103?cll40<W9b@D0_kno102KVi/5071`L0@0J6QX101mOGd506UY
J@@0LW9b1@1iNGT407=cL`@0Ogmo1@26QXH408Z:RPD0UIFE3@38h=P408N7Q`@0Q8B41@23Ph<407in
OPD0O7al101nOWh407moO`D0OGem1021PH4907emO@@0PH611@20P80407inOP@0PX:21@1mOGd407in
OPT0RHV9101nOWh508B4Q0@0R8R81@2;Rh/408R8R0@0QHF52@20P80507inOPP0Ogmo1@20P80408:2
PPD0PH611020P80407]kN`D0Ph>3101kNg/508:2PPP0MWIf1@22PX8407]kN`D0Rh^;101lO7`406i^
KPD0OWin102<S8`507QhN0@0OGem101lO7`507inOP@0OGem1@1oOgl407inOP@0PH611@1oOgl40820
P0T0PX:2101nOWh507moO`P0P8201@1lO7`F0<SPf0005@38h=P503Ph>0@0:2PX100Z:RX503Ph>0@0
IVIV1@0^;Rh4034a<@@0<S8b1@0[:b/402d];@D0=CDe100[:b/402XZ:PD09bLW100Z:RX902`/;0@0
MGEe1@1UIFD406MWI`@0YJFU1@2DU9@40:6QX@D0[:b/102i^KT40<?3``D0alO71035aLD50<;2`P@0
_Kfm101aLG4506m_K`@0MgMg1@20P80407IfMP@0Lg=c1@1VIVH404Y:BPD0;Rh^1018B4P406QXJ0D0
MgMg101FEUH503dm?@@0@4101014A4@506i^KP@0`L711@3<c<`40<o?c`@0bLW91@2o_kl409^KV`D0
L71`101XJ6P407emO@D0JFUY101bLW8507UiN@@0Lg=c101oOgl508J6QP@0RXZ:1@2EUID=0<SPf0@0
QhN71024Q8@508>3P`@0OWin1@1lO7`407inOP@0Ogmo1@1mOGd40861P@T0OGem1021PH450820P0@0
OWin1022PX8507emO@@0OWin2@29RHT407inOPD0Q8B41028R8P508^;R`@0R8R81025QHD90820P0D0
OWin201oOgl50820P0@0PX:21@21PH440820P0@0Ng]k1@23Ph<407]kN`D0PX:2201fMWH508:2PP@0
Ng]k1@2;Rh/407alO0@0KVi^1@1nOWh408b<S0D0N7Qh101mOGd407alO0D0OWin101mOGd507moO`@0
OWin1021PH4507moO`@0P8202@22PX8407inOPD0Ogmo2020P80507alO1H0b>3H000E0<SPf0D0>3Ph
100X:2P402XZ:PD0>3Ph101VIVH502h^;P@0<C4a100b<S8502/[:`@0;Bd]1@0e=CD402/[:`@0:RXZ
1@0W9bL402XZ:PT0;2`/101eMGD506EUI@@0IfMW102UYJD509BDU0@0XJ6Q1@2/[:`40;Vi^@@0`l?3
1@37alL40<G5a@D0`/;2102m_Kd4075aL@D0Kfm_101gMgL50820P0@0MWIf101cLg<506IVIP@0BTY:
1@0^;Rh404Q8B0@0J6QX1@1gMgL405IFEPD0?Cdm1010@40404A4A0D0KVi^1031`L450<c<c0@0clo?
1039bLT50;no_`@0Vi^K1@1`L70406QXJ0@0OGem1@1YJFT4079bLPD0NGUi101cLg<407moO`D0QXJ6
102:RXX509FEU@d0b>3H1027QhL408B4Q0D0Ph>3101nOWh507alO0@0OWin101oOgl507emO@@0PH61
2@1mOGd40861P@D0P820101nOWh408:2PPD0OGem101nOWh908V9R@@0OWin1@24Q8@408R8R0D0Rh^;
1028R8P408F5Q@T0P8201@1nOWh807moO`D0P8201022PX850861P@@0P820101kNg/508>3P`@0Ng]k
1@22PX8807IfMPD0PX:2101kNg/508^;R`@0O7al101^KVh507inOP@0S8b<1@1hN7P407emO@@0O7al
1@1nOWh407emO@D0Ogmo101nOWh40861P@D0Ogmo1020P80908:2PP@0OWin1@1oOgl80820P0D0O7al
5P38h=P001D0b>3H1@0b<S8402XZ:P@0:2PX1@1;Bd/406e]K@D0=cLg100[:b/402XZ:PT0:b/[1@0g
=cL802PX:0D0;Rh^2@0V9RH402PX:0@0Bd];1@1oOgl4061PH0@0TI6A1@2i^KT409fMW@D0V9RH102X
Z:P40;Fe]@D0`l?3103:b/X50<G5a@@0`l?3102l_;`506i^KP@0Jf][1@1_Kfl405mOG`@0DE5A1@13
@d<4034a<@D0<c<c101=CDd4075aL@D0H61P1010@40505eMG@@0EUIF101HF5P503dm?@@0PX:21@3A
dM440<k>cP@0cLg=1@35aLD409>CT`D0CTi>201[Jf/506=SH`T0L71`101gMgL407emO@D0QHF51028
R8P509FEU@d0b>3H1021PH4407moO`D0QHF51021PH4508^;R`@0OWin101lO7`508J6QP@0PH612@1n
OWh40820P0D0OGem101dM7@40861P@T0OWin1@1`L704075aL@@0NGUi1@22PX8407UiN@D0O7al101e
MGD407UiN@D0O7al101oOgl908:2PPT0O7al1023Ph<507UiN@@0Ogmo101kNg/50820P0@0RHV91@1l
O7`80861P@D0O7al1026QXH507AdM0@0OWin1021PH45079bLP@0MGEe1@21PH4407moO`@0P8201@21
PH4407moO`D0OWin101oOgl407emO@D0P820101mOGd507moO`@0OWin1027QhL507inOPd0P8205P38
h=P001D0b>3H1@0b<S8402XZ:P@0:2PX1@1;Bd/406e]K@D0=cLg100[:b/402XZ:PT0:b/[1@0g=cL8
02PX:0D0;Rh^2@0V9RH402PX:0@0Bd];1@1oOgl4061PH0@0TI6A1@2i^KT409fMW@D0V9RH102XZ:P4
0;Fe]@D0`l?3103:b/X50<G5a@@0`l?3102l_;`506i^KP@0Jf][1@1_Kfl405mOG`@0DE5A1@13@d<4
034a<@D0<c<c101=CDd4075aL@D0H61P1010@40505eMG@@0EUIF101HF5P503dm?@@0PX:21@3AdM44
0<k>cP@0cLg=1@35aLD409>CT`D0CTi>201[Jf/506=SH`T0L71`101gMgL407emO@D0QHF51028R8P5
09FEU@d0b>3H1021PH4407moO`D0QHF51021PH4508^;R`@0OWin101lO7`508J6QP@0PH612@1nOWh4
0820P0D0OGem101dM7@40861P@T0OWin1@1`L704075aL@@0NGUi1@22PX8407UiN@D0O7al101eMGD4
07UiN@D0O7al101oOgl908:2PPT0O7al1023Ph<507UiN@@0Ogmo101kNg/50820P0@0RHV91@1lO7`8
0861P@D0O7al1026QXH507AdM0@0OWin1021PH45079bLP@0MGEe1@21PH4407moO`@0P8201@21PH44
07moO`D0OWin101oOgl407emO@D0P820101mOGd507moO`@0OWin1027QhL507inOPd0P8205P38h=P0
01D0b>3H1@0b<S8402XZ:P@0:2PX1@1;Bd/406e]K@D0=cLg100[:b/402XZ:PT0:b/[1@0g=cL802PX
:0D0;Rh^2@0V9RH402PX:0@0Bd];1@1oOgl4061PH0@0TI6A1@2i^KT409fMW@D0V9RH102XZ:P40;Fe
]@D0`l?3103:b/X50<G5a@@0`l?3102l_;`506i^KP@0Jf][1@1_Kfl405mOG`@0DE5A1@13@d<4034a
<@D0<c<c101=CDd4075aL@D0H61P1010@40505eMG@@0EUIF101HF5P503dm?@@0PX:21@3AdM440<k>
cP@0cLg=1@35aLD409>CT`D0CTi>201[Jf/506=SH`T0L71`101gMgL407emO@D0QHF51028R8P509FE
U@d0b>3H1021PH4407moO`D0QHF51021PH4508^;R`@0OWin101lO7`508J6QP@0PH612@1nOWh40820
P0D0OGem101dM7@40861P@T0OWin1@1`L704075aL@@0NGUi1@22PX8407UiN@D0O7al101eMGD407Ui
N@D0O7al101oOgl908:2PPT0O7al1023Ph<507UiN@@0Ogmo101kNg/50820P0@0RHV91@1lO7`80861
P@D0O7al1026QXH507AdM0@0OWin1021PH45079bLP@0MGEe1@21PH4407moO`@0P8201@21PH4407mo
O`D0OWin101oOgl407emO@D0P820101mOGd507moO`@0OWin1027QhL507inOPd0P8205P38h=P001D0
b>3H1@0b<S8402XZ:P@0:2PX1@1;Bd/406e]K@D0=cLg100[:b/402XZ:PT0:b/[1@0g=cL802PX:0D0
;Rh^2@0V9RH402PX:0@0Bd];1@1oOgl4061PH0@0TI6A1@2i^KT409fMW@D0V9RH102XZ:P40;Fe]@D0
`l?3103:b/X50<G5a@@0`l?3102l_;`506i^KP@0Jf][1@1_Kfl405mOG`@0DE5A1@13@d<4034a<@D0
<c<c101=CDd4075aL@D0H61P1010@40505eMG@@0EUIF101HF5P503dm?@@0PX:21@3AdM440<k>cP@0
cLg=1@35aLD409>CT`D0CTi>201[Jf/506=SH`T0L71`101gMgL407emO@D0QHF51028R8P509FEU@d0
b>3H1021PH4407moO`D0QHF51021PH4508^;R`@0OWin101lO7`508J6QP@0PH612@1nOWh40820P0D0
OGem101dM7@40861P@T0OWin1@1`L704075aL@@0NGUi1@22PX8407UiN@D0O7al101eMGD407UiN@D0
O7al101oOgl908:2PPT0O7al1023Ph<507UiN@@0Ogmo101kNg/50820P0@0RHV91@1lO7`80861P@D0
O7al1026QXH507AdM0@0OWin1021PH45079bLP@0MGEe1@21PH4407moO`@0P8201@21PH4407moO`D0
OWin101oOgl407emO@D0P820101mOGd507moO`@0OWin1027QhL507inOPd0P8205P38h=P001D0b>3H
1@0^;Rh4030`<0@09bLW1@1XJ6P4051@D0D0=SHf100[:b/402HV9PD0;2`/100^;Rh503De=@@0;bl_
100Z:RX503De=@@0<c<c1@0[:b/403lo?`@0>CTi1@1aLG4408f=S@@0HV9R1@2l_;`40;:b/PD0[Zj^
102f][H90;Rh^0@0b/[:1@39bLT40<S8b0@0a<C41@2d];@405UIF@D0GemO101BDU8403`l?0D0<c<c
100^;Rh5034a<@@0ADE5101WIfL503Ph>0@0FEUI1@18B4P402TY:@@0BTY:1@1ADE4404];B`D0bLW9
1033`l<40<C4a0D0Zj^[101VIVH504I6AP@0Ng]k101FEUH5079bLP@0MWIf1@1bLW8407moO`@0Ph>3
1@29RHT408f=S@D0T92@3@38h=P407inOP@0Ng]k1@22PX8907]kN`@0Ph>31024Q8@50820P0@0PX:2
1@1kNg/408:2PP@0Q8B41@21PH4408N7Q`@0Q8B41@1bLW8409>CT`D0Rh^;1022PX8407]kN`D0PH61
2@22PX840820P0@0Ogmo1@24Q8@40820P0D0OWin1020P8040861P@D0PX:2101eMGD508Z:RPP0OGem
1@1nOWh408F5Q@D0O7al1024Q8@407alO0D0Ogmo101gMgL507emO@@0RHV9101mOGd509BDU0@0S8b<
1@2DU9@80820P0D0NGUi101lO7`507]kN`@0NWYj101hN7P508>3P`@0OWin1@20P80407]kN`@0PH61
2@22PX8407emO@D0P8205P38h=P001D0b>3H1@0^;Rh4030`<0@09bLW1@1XJ6P4051@D0D0=SHf100[
:b/402HV9PD0;2`/100^;Rh503De=@@0;bl_100Z:RX503De=@@0<c<c1@0[:b/403lo?`@0>CTi1@1a
LG4408f=S@@0HV9R1@2l_;`40;:b/PD0[Zj^102f][H90;Rh^0@0b/[:1@39bLT40<S8b0@0a<C41@2d
];@405UIF@D0GemO101BDU8403`l?0D0<c<c100^;Rh5034a<@@0ADE5101WIfL503Ph>0@0FEUI1@18
B4P402TY:@@0BTY:1@1ADE4404];B`D0bLW91033`l<40<C4a0D0Zj^[101VIVH504I6AP@0Ng]k101F
EUH5079bLP@0MWIf1@1bLW8407moO`@0Ph>31@29RHT408f=S@D0T92@3@38h=P407inOP@0Ng]k1@22
PX8907]kN`@0Ph>31024Q8@50820P0@0PX:21@1kNg/408:2PP@0Q8B41@21PH4408N7Q`@0Q8B41@1b
LW8409>CT`D0Rh^;1022PX8407]kN`D0PH612@22PX840820P0@0Ogmo1@24Q8@40820P0D0OWin1020
P8040861P@D0PX:2101eMGD508Z:RPP0OGem1@1nOWh408F5Q@D0O7al1024Q8@407alO0D0Ogmo101g
MgL507emO@@0RHV9101mOGd509BDU0@0S8b<1@2DU9@80820P0D0NGUi101lO7`507]kN`@0NWYj101h
N7P508>3P`@0OWin1@20P80407]kN`@0PH612@22PX8407emO@D0P8205P38h=P001D0b>3H1@0^;Rh4
030`<0@09bLW1@1XJ6P4051@D0D0=SHf100[:b/402HV9PD0;2`/100^;Rh503De=@@0;bl_100Z:RX5
03De=@@0<c<c1@0[:b/403lo?`@0>CTi1@1aLG4408f=S@@0HV9R1@2l_;`40;:b/PD0[Zj^102f][H9
0;Rh^0@0b/[:1@39bLT40<S8b0@0a<C41@2d];@405UIF@D0GemO101BDU8403`l?0D0<c<c100^;Rh5
034a<@@0ADE5101WIfL503Ph>0@0FEUI1@18B4P402TY:@@0BTY:1@1ADE4404];B`D0bLW91033`l<4
0<C4a0D0Zj^[101VIVH504I6AP@0Ng]k101FEUH5079bLP@0MWIf1@1bLW8407moO`@0Ph>31@29RHT4
08f=S@D0T92@3@38h=P407inOP@0Ng]k1@22PX8907]kN`@0Ph>31024Q8@50820P0@0PX:21@1kNg/4
08:2PP@0Q8B41@21PH4408N7Q`@0Q8B41@1bLW8409>CT`D0Rh^;1022PX8407]kN`D0PH612@22PX84
0820P0@0Ogmo1@24Q8@40820P0D0OWin1020P8040861P@D0PX:2101eMGD508Z:RPP0OGem1@1nOWh4
08F5Q@D0O7al1024Q8@407alO0D0Ogmo101gMgL507emO@@0RHV9101mOGd509BDU0@0S8b<1@2DU9@8
0820P0D0NGUi101lO7`507]kN`@0NWYj101hN7P508>3P`@0OWin1@20P80407]kN`@0PH612@22PX84
07emO@D0P8205P38h=P001D0b>3H1@0^;Rh4030`<0@09bLW1@1XJ6P4051@D0D0=SHf100[:b/402HV
9PD0;2`/100^;Rh503De=@@0;bl_100Z:RX503De=@@0<c<c1@0[:b/403lo?`@0>CTi1@1aLG4408f=
S@@0HV9R1@2l_;`40;:b/PD0[Zj^102f][H90;Rh^0@0b/[:1@39bLT40<S8b0@0a<C41@2d];@405UI
F@D0GemO101BDU8403`l?0D0<c<c100^;Rh5034a<@@0ADE5101WIfL503Ph>0@0FEUI1@18B4P402TY
:@@0BTY:1@1ADE4404];B`D0bLW91033`l<40<C4a0D0Zj^[101VIVH504I6AP@0Ng]k101FEUH5079b
LP@0MWIf1@1bLW8407moO`@0Ph>31@29RHT408f=S@D0T92@3@38h=P407inOP@0Ng]k1@22PX8907]k
N`@0Ph>31024Q8@50820P0@0PX:21@1kNg/408:2PP@0Q8B41@21PH4408N7Q`@0Q8B41@1bLW8409>C
T`D0Rh^;1022PX8407]kN`D0PH612@22PX840820P0@0Ogmo1@24Q8@40820P0D0OWin1020P8040861
P@D0PX:2101eMGD508Z:RPP0OGem1@1nOWh408F5Q@D0O7al1024Q8@407alO0D0Ogmo101gMgL507em
O@@0RHV9101mOGd509BDU0@0S8b<1@2DU9@80820P0D0NGUi101lO7`507]kN`@0NWYj101hN7P508>3
P`@0OWin1@20P80407]kN`@0PH612@22PX8407emO@D0P8205P38h=P001D0b>3H1@0^;Rh4030`<0@0
9bLW1@1XJ6P4051@D0D0=SHf100[:b/402HV9PD0;2`/100^;Rh503De=@@0;bl_100Z:RX503De=@@0
<c<c1@0[:b/403lo?`@0>CTi1@1aLG4408f=S@@0HV9R1@2l_;`40;:b/PD0[Zj^102f][H90;Rh^0@0
b/[:1@39bLT40<S8b0@0a<C41@2d];@405UIF@D0GemO101BDU8403`l?0D0<c<c100^;Rh5034a<@@0
ADE5101WIfL503Ph>0@0FEUI1@18B4P402TY:@@0BTY:1@1ADE4404];B`D0bLW91033`l<40<C4a0D0
Zj^[101VIVH504I6AP@0Ng]k101FEUH5079bLP@0MWIf1@1bLW8407moO`@0Ph>31@29RHT408f=S@D0
T92@3@38h=P407inOP@0Ng]k1@22PX8907]kN`@0Ph>31024Q8@50820P0@0PX:21@1kNg/408:2PP@0
Q8B41@21PH4408N7Q`@0Q8B41@1bLW8409>CT`D0Rh^;1022PX8407]kN`D0PH612@22PX840820P0@0
Ogmo1@24Q8@40820P0D0OWin1020P8040861P@D0PX:2101eMGD508Z:RPP0OGem1@1nOWh408F5Q@D0
O7al1024Q8@407alO0D0Ogmo101gMgL507emO@@0RHV9101mOGd509BDU0@0S8b<1@2DU9@80820P0D0
NGUi101lO7`507]kN`@0NWYj101hN7P508>3P`@0OWin1@20P80407]kN`@0PH612@22PX8407emO@D0
P8205P38h=P001D0b>3H1@0_;bl4030`<0@0;Rh^1@1eMGD403Hf=PT0;Rh^100[:b/502`/;0@0;Rh^
1@0e=CD403`l?0@0<c<c1@1DE5@404U9B@D0;2`/100R8R8401lO7`D0>3Ph102HV9P4071`L0D0OGem
1031`L450:FUY@@0[Jf]102b/[850;Bd]0@0^[Zj1@3<c<`40<C4a0@0`l?31@34a<@40:FUY@D0Cdm?
101GEeL404];B`D0?3`l100[:b/502`/;0@0=SHf1018B4P5030`<0@0?3`l1@0_;bl402<S8`@0Bd];
1@16ATH407MgM`D0alO7102k^k/40:BTY0D0J6QX100a<C4503Xj>P@0B4Q8101>CTh907alO0D0N7Qh
1020P80408N7Q`D0Rh^;102ATI4509FEU@d0b>3H101lO7`408V9R@D0PH61101nOWh507moO`@0Q8B4
1020P80508>3P`@0QHF51@1oOgl408:2PP@0MgMg1@1nOWh405]KF`@0QhN71@20P80407]kN`D0OGem
1020P80407YjNPD0PX:21021PH4507alO0@0Ogmo1020P80507inOP@0P8201@23Ph<408:2PP@0PH61
1@1mOGd408R8R0D0LG5a102<S8`40820P0D0Ogmo101eMGD508>3P`@0Ng]k1022PX8508N7Q`@0PH61
1@23Ph<407alO0@0Ng]k2@1iNGT5071`L0@0NWYj101gMgL50820P0@0R8R81@22PX8408Z:RP@0S8b<
1@26QXH907moO`@0OGem1021PH4508:2PP@0PH611020P80507emOAH0b>3H000E0<SPf0D0;bl_100`
<30402h^;PD0MGEe100f=SH902h^;P@0:b/[1@0/;2`402h^;PD0=CDe100l?3`403<c<`D0E5AD1019
BDT502`/;0@08R8R100O7al503Ph>0@0V9RH101`L70507emO@@0`L711@2UYJD40:f][@@0/[:b1@2d
];@40;Zj^PD0c<c<1034a<@40<?3``D0a<C4102UYJD504m?C`@0EeMG101;Bd/503`l?0@0:b/[1@0/
;2`403Hf=P@0B4Q81@0`<30403`l?0D0;bl_100S8b<404];B`D0ATI6101gMgL50<O7a`@0^k^k102T
Y:@506QXJ0@0<C4a1@0j>SX404Q8B0@0CTi>2@1lO7`507QhN0@0P8201027QhL508^;R`@0TI6A1@2E
UID=0<SPf0@0O7al1029RHT50861P@@0OWin1@1oOgl408B4Q0@0P8201@23Ph<408F5Q@D0Ogmo1022
PX8407MgM`D0OWin101KFe/408N7Q`D0P820101kNg/507emO@@0P820101jNWX508:2PP@0PH611@1l
O7`407moO`@0P8201@1nOWh40820P0D0Ph>31022PX840861P@D0OGem1028R8P5075aL@@0S8b<1020
P80507moO`@0MGEe1@23Ph<407]kN`@0PX:21@27QhL40861P@D0Ph>3101lO7`407]kN`T0NGUi1@1`
L70407YjNP@0MgMg1@20P80408R8R0D0PX:2102:RXX408b<S0D0QXJ62@1oOgl407emO@@0PH611@22
PX840861P@@0P8201@1mOGdF0<SPf0005@38h=P502l_;`@0<30`100^;Rh507EeM@@0=SHf2@0^;Rh4
02/[:`D0;2`/100^;Rh503De=@@0?3`l100c<c<505ADE0@0BDU91@0/;2`4028R8P@07alO1@0h>3P4
09RHV0@0L71`1@1mOGd40<71`@D0YJFU102][Jd40;:b/PD0];Bd102j^[X50<c<c0@0a<C41033`l<5
0<C4a0@0YJFU1@1?Cdl405MGE`@0Bd];1@0l?3`402/[:`D0;2`/100f=SH404Q8B0D0<30`100l?3`5
02l_;`@08b<S101;Bd/504I6AP@0MgMg1@37alL40;^k^`@0Y:BT1@1XJ6P4034a<@D0>SXj1018B4P4
04i>CPT0O7al1@1hN7P40820P0@0QhN71@2;Rh/4096AT@D0UIFE3@38h=P407alO0@0RHV91@21PH44
07inOPD0Ogmo1024Q8@40820P0D0Ph>31025QHD507moO`@0PX:2101gMgL507inOP@0Fe]K1027QhL5
0820P0@0Ng]k1@1mOGd40820P0@0NWYj1@22PX840861P@D0O7al101oOgl40820P0D0OWin1020P805
08>3P`@0PX:21021PH4507emO@@0R8R81@1aLG4408b<S0@0P8201@1oOgl407EeM@D0Ph>3101kNg/4
08:2PPD0QhN71021PH4508>3P`@0O7al101kNg/907UiN@D0L71`101jNWX407MgM`D0P8201028R8P5
08:2PP@0RXZ:102<S8`508J6QPT0Ogmo101mOGd40861P@D0PX:21021PH440820P0D0OGem5P38h=P0
01D0b>3H1@0_;bl4030`<0@0;Rh^1@1eMGD403Hf=PT0;Rh^100[:b/502`/;0@0;Rh^1@0e=CD403`l
?0@0<c<c1@1DE5@404U9B@D0;2`/100R8R8401lO7`D0>3Ph102HV9P4071`L0D0OGem1031`L450:FU
Y@@0[Jf]102b/[850;Bd]0@0^[Zj1@3<c<`40<C4a0@0`l?31@34a<@40:FUY@D0Cdm?101GEeL404];
B`D0?3`l100[:b/502`/;0@0=SHf1018B4P5030`<0@0?3`l1@0_;bl402<S8`@0Bd];1@16ATH407Mg
M`D0alO7102k^k/40:BTY0D0J6QX100a<C4503Xj>P@0B4Q8101>CTh907alO0D0N7Qh1020P80408N7
Q`D0Rh^;102ATI4509FEU@d0b>3H101lO7`408V9R@D0PH61101nOWh507moO`@0Q8B41020P80508>3
P`@0QHF51@1oOgl408:2PP@0MgMg1@1nOWh405]KF`@0QhN71@20P80407]kN`D0OGem1020P80407Yj
NPD0PX:21021PH4507alO0@0Ogmo1020P80507inOP@0P8201@23Ph<408:2PP@0PH611@1mOGd408R8
R0D0LG5a102<S8`40820P0D0Ogmo101eMGD508>3P`@0Ng]k1022PX8508N7Q`@0PH611@23Ph<407al
O0@0Ng]k2@1iNGT5071`L0@0NWYj101gMgL50820P0@0R8R81@22PX8408Z:RP@0S8b<1@26QXH907mo
O`@0OGem1021PH4508:2PP@0PH611020P80507emOAH0b>3H000E0<SPf0D0;2`/101?Cdl403/k>`D0
MgMg100X:2P5038b<P@0:RXZ100X:2P502TY:@@0;bl_1@1VIVH4071`L0@0GUiN1@11@D4402LW9`D0
:b/[100T92@402HV9PD08R8R101WIfL409VIV@D0HV9R102[Zj/50;Zj^P@0YZJV102/[:`50;>c/`@0
^[Zj2@38b<P40<;2`PD0_;bl1033`l<509bLW0@0AdM7101:BTX50410@0@0=CDe1@0a<C48030`<0D0
<c<c100b<S8502h^;P@0;Bd]100b<S8503`l?0@0HV9R1@2LW9`408J6QP@0D51@1@0];Bd402/[:`D0
9bLW100_;bl405mOG`D0Ph>31024Q8@507moO`@0PX:21029RHT508b<S0@0TY:B1@2FUYH=0<SPf0@0
SXj>101kNg/508N7Q`@0O7al1@1kNg/408>3P`@0PX:21@1oOgl40861P@D0QXJ6201kNg/508>3P`@0
SHf=101nOWh508>3P`@0OGem3@1oOgl507emO@T0Ph>3101oOgl408:2PPD0P820101oOgl507emO@d0
Ogmo101nOWh508J6QP@0LG5a1026QXH507emO@@0O7al1@1nOWh40861P@@0P8201@1jNWX407moO`D0
O7al1020P80408B4Q0D0OGem101kNg/507inOP@0PH611024Q8@507moO`@0OGem1@1kNg/407inOP@0
PH611@20P80907alO0d0Ogmo101iNGT407inOPD0Ogmo5P38h=P001D0b>3H1@0/;2`404m?C`@0>c/k
1@1gMgL402PX:0D0<S8b100Z:RX402PX:0D0:BTY100_;bl506IVIP@0L71`101NGUh50451@@@09bLW
1@0[:b/402@T90@09RHV1@0R8R8406MWI`@0VIVI1@1RHV840:^[Z`D0^[Zj102VYZH40:b/[0D0/k>c
102j^[X90<S8b0@0`/;21@2l_;`40<?3``D0W9bL1017AdL404Y:BPD0@410100e=CD5034a<@P0<30`
1@0c<c<4038b<PD0;Rh^100];Bd4038b<PD0?3`l101RHV8509bLW0@0QXJ6101@D50502d];@@0:b/[
1@0W9bL402l_;`@0GemO1@23Ph<408B4Q0D0Ogmo1022PX8408V9R@D0S8b<102BTY8509JFUPd0b>3H
102>SXh407]kN`D0QhN7101lO7`507]kN`@0Ph>31022PX8507moO`@0PH611@26QXH807]kN`D0Ph>3
102=SHd407inOPD0Ph>3101mOGd=07moO`D0OGem2@23Ph<407moO`@0PX:21@20P80407moO`D0OGem
3@1oOgl407inOPD0QXJ6101aLG4408J6QPD0OGem101lO7`507inOP@0PH611020P80507YjNP@0Ogmo
1@1lO7`40820P0@0Q8B41@1mOGd407]kN`D0OWin1021PH4408B4Q0D0Ogmo101mOGd507]kN`@0OWin
1021PH450820P0T0O7al3@1oOgl407UiN@@0OWin1@1oOglF0<SPf0005@38h=P502`/;0@0Cdm?100k
>c/507MgM`@0:2PX1@0b<S8402XZ:P@0:2PX1@0Y:BT402l_;`D0IVIV101`L70405iNGPD0@D51100W
9bL502/[:`@092@T100V9RH5028R8P@0IfMW102IVIT5069RHP@0Zj^[1@2j^[X40:JVYP@0[:b/1@2c
/k<40;Zj^PT0b<S81032`/850;bl_0@0`l?31@2LW9`404M7A`@0BTY:1@10@40403De=@D0<C4a200`
<30503<c<`@0<S8b1@0^;Rh402d];@@0<S8b1@0l?3`4069RHPD0W9bL1026QXH4051@D0D0;Bd]100[
:b/502LW9`@0;bl_101OGel508>3P`@0Q8B41@1oOgl408:2PP@0RHV91@2<S8`409:BTPD0UYJF3@38
h=P408j>SP@0Ng]k1@27QhL407alO0D0Ng]k1023Ph<408:2PPD0Ogmo1021PH4508J6QPP0Ng]k1@23
Ph<408f=S@@0OWin1@23Ph<407emO@d0Ogmo1@1mOGd908>3P`@0Ogmo1022PX850820P0@0Ogmo1@1m
OGd=07moO`@0OWin1@26QXH4075aL@@0QXJ61@1mOGd407alO0D0OWin1021PH440820P0D0NWYj101o
Ogl507alO0@0P8201024Q8@507emO@@0Ng]k1@1nOWh40861P@@0Q8B41@1oOgl407emO@D0Ng]k101n
OWh40861P@D0P8202@1lO7`=07moO`@0NGUi101nOWh507moOaH0b>3H000E0<SPf0D0;2`/101?Cdl4
03/k>`D0MgMg100X:2P5038b<P@0:RXZ100X:2P502TY:@@0;bl_1@1VIVH4071`L0@0GUiN1@11@D44
02LW9`D0:b/[100T92@402HV9PD08R8R101WIfL409VIV@D0HV9R102[Zj/50;Zj^P@0YZJV102/[:`5
0;>c/`@0^[Zj2@38b<P40<;2`PD0_;bl1033`l<509bLW0@0AdM7101:BTX50410@0@0=CDe1@0a<C48
030`<0D0<c<c100b<S8502h^;P@0;Bd]100b<S8503`l?0@0HV9R1@2LW9`408J6QP@0D51@1@0];Bd4
02/[:`D09bLW100_;bl405mOG`D0Ph>31024Q8@507moO`@0PX:21029RHT508b<S0@0TY:B1@2FUYH=
0<SPf0@0SXj>101kNg/508N7Q`@0O7al1@1kNg/408>3P`@0PX:21@1oOgl40861P@D0QXJ6201kNg/5
08>3P`@0SHf=101nOWh508>3P`@0OGem3@1oOgl507emO@T0Ph>3101oOgl408:2PPD0P820101oOgl5
07emO@d0Ogmo101nOWh508J6QP@0LG5a1026QXH507emO@@0O7al1@1nOWh40861P@@0P8201@1jNWX4
07moO`D0O7al1020P80408B4Q0D0OGem101kNg/507inOP@0PH611024Q8@507moO`@0OGem1@1kNg/4
07inOP@0PH611@20P80907alO0d0Ogmo101iNGT407inOPD0Ogmo5P38h=P001D0b>3H1@13@d<40410
@0@0=CDe1@1TI6@402@T90D0:BTY200U9BD502TY:@@0Hf=S1@1dM7@405YJFP@0;Bd]1@0T92@402XZ
:PD0<C4a200X:2P5028R8P@0;2`/102@T90507moO`@0NGUi1@2l_;`40:ZZZP@0[:b/1@2`/;040;Jf
]PD0`l?31038b<P40<71`@D0_;bl102i^KT50<71`@@0W9bL1012@T8504I6AP@0?Shn1@0g=cL=03De
=@@0=3@d1@0a<C4402h^;P@0;bl_1@0a<C4403Ti>@D0D51@100n?Sh402l_;`D0:b/[100Z:RX502d]
;@@0FEUI1020P80508F5Q@@0PH611@1mOGd408:2PP@0Rh^;1@2>SXh409>CT`D0VYZJ3@38h=P407al
O0@0PH611@1iNGT40820P0D0OGem101kNg/40820P0D0PH611026QXH507alO0@0L71`102?Shl507Ui
N@@0OGem1024Q8@908:2PPD0MgMg101kNg/408>3P`D0Ogmo101hN7P507moO`P0OGem1@1lO7`907in
OPP0Ogmo1@23Ph<908:2PP@0QhN7101`L70509NGU`@0NGUi1@23Ph<407inOP@0PH611@1nOWh408B4
Q180P820101lO7`507]kN`@0Ogmo101aLG4507emO@@0Ogmo1@23Ph<40861P@@0L71`1@1lO7`408>3
P`D0PH61201nOWh507alO0P0PH611@1oOglF0<SPf0005@38h=P504=3@`@0@410100e=CD506ATI0@0
92@T1@0Y:BT802DU9@D0:BTY101SHf<507AdM0@0FUYJ100];Bd502@T90@0:RXZ1@0a<C4802PX:0D0
8R8R100/;2`4092@T0D0Ogmo101iNGT50;bl_0@0ZZZZ102/[:`50;2`/0@0][Jf1@33`l<40<S8b0@0
`L711@2l_;`40;Vi^@D0`L71102LW9`40492@PD0ATI6100n?Sh503Lg=`d0=CDe100d=3@5034a<@@0
;Rh^100_;bl5034a<@@0>CTi1@1@D50403hn?P@0;bl_1@0[:b/402XZ:PD0;Bd]101IFET40820P0D0
QHF51021PH4507emO@@0PX:2102;Rh/508j>SP@0Ti>C1@2JVYX=0<SPf0@0O7al1021PH4507UiN@@0
P8201@1mOGd407]kN`@0P8201@21PH4408J6QPD0O7al101`L70408n?S`D0NGUi101mOGd408B4Q0T0
PX:21@1gMgL407]kN`@0Ph>31@1oOgl407QhN0D0Ogmo201mOGd507alO0T0OWin201oOgl508>3P`T0
PX:21027QhL4071`L0D0UiNG101iNGT508>3P`@0OWin1021PH4507inOP@0Q8B44P20P80407alO0D0
Ng]k101oOgl4075aL@D0OGem101oOgl508>3P`@0PH61101`L70507alO0@0Ph>31@21PH4807inOPD0
O7al2021PH4507moOaH0b>3H000E0<SPf0D0@d=31010@40403De=@D0I6AT100T92@502TY:@P09BDU
1@0Y:BT406=SH`D0M7Ad101JFUX402d];@D092@T100Z:RX5034a<@P0:2PX1@0R8R8402`/;0@0T92@
1@1oOgl407UiN@D0_;bl102ZZZX40:b/[0D0/;2`102f][H50<?3``@0b<S81031`L450;bl_0@0^KVi
1@31`L4409bLW0@0@T921@16ATH403hn?PD0=cLg3@0e=CD403@d=0D0<C4a100^;Rh402l_;`D0<C4a
100i>CT5051@D0@0?Shn100_;bl502/[:`@0:RXZ1@0];Bd405UIF@@0P8201@25QHD40861P@D0OGem
1022PX8408^;R`D0SXj>102CTi<509ZJVPd0b>3H101lO7`40861P@D0NGUi1020P80507emO@@0Ng]k
1020P8050861P@@0QXJ61@1lO7`4071`L0@0Shn?1@1iNGT407emO@@0Q8B42@22PX8507MgM`@0Ng]k
1023Ph<507moO`@0N7Qh1@1oOgl807emO@D0O7al2@1nOWh807moO`D0Ph>32@22PX8408N7Q`@0L71`
1@2GUiL407UiN@D0Ph>3101nOWh40861P@D0OWin1024Q8@B0820P0@0O7al1@1kNg/407moO`@0LG5a
1@1mOGd407moO`D0Ph>31021PH44071`L0D0O7al1023Ph<50861P@P0OWin1@1lO7`80861P@D0Ogmo
5P38h=P001D0b>3H1@13@d<40410@0@0=CDe1@1TI6@402@T90D0:BTY200U9BD502TY:@@0Hf=S1@1d
M7@405YJFP@0;Bd]1@0T92@402XZ:PD0<C4a200X:2P5028R8P@0;2`/102@T90507moO`@0NGUi1@2l
_;`40:ZZZP@0[:b/1@2`/;040;Jf]PD0`l?31038b<P40<71`@D0_;bl102i^KT50<71`@@0W9bL1012
@T8504I6AP@0?Shn1@0g=cL=03De=@@0=3@d1@0a<C4402h^;P@0;bl_1@0a<C4403Ti>@D0D51@100n
?Sh402l_;`D0:b/[100Z:RX502d];@@0FEUI1020P80508F5Q@@0PH611@1mOGd408:2PP@0Rh^;1@2>
SXh409>CT`D0VYZJ3@38h=P407alO0@0PH611@1iNGT40820P0D0OGem101kNg/40820P0D0PH611026
QXH507alO0@0L71`102?Shl507UiN@@0OGem1024Q8@908:2PPD0MgMg101kNg/408>3P`D0Ogmo101h
N7P507moO`P0OGem1@1lO7`907inOPP0Ogmo1@23Ph<908:2PP@0QhN7101`L70509NGU`@0NGUi1@23
Ph<407inOP@0PH611@1nOWh408B4Q180P820101lO7`507]kN`@0Ogmo101aLG4507emO@@0Ogmo1@23
Ph<40861P@@0L71`1@1lO7`408>3P`D0PH61201nOWh507alO0P0PH611@1oOglF0<SPf0005@38h=P5
04=3@`@0@410100e=CD506ATI0@092@T1@0Y:BT802DU9@D0:BTY101SHf<507AdM0@0FUYJ100];Bd5
02@T90@0:RXZ1@0a<C4802PX:0D08R8R100/;2`4092@T0D0Ogmo101iNGT50;bl_0@0ZZZZ102/[:`5
0;2`/0@0][Jf1@33`l<40<S8b0@0`L711@2l_;`40;Vi^@D0`L71102LW9`40492@PD0ATI6100n?Sh5
03Lg=`d0=CDe100d=3@5034a<@@0;Rh^100_;bl5034a<@@0>CTi1@1@D50403hn?P@0;bl_1@0[:b/4
02XZ:PD0;Bd]101IFET40820P0D0QHF51021PH4507emO@@0PX:2102;Rh/508j>SP@0Ti>C1@2JVYX=
0<SPf0@0O7al1021PH4507UiN@@0P8201@1mOGd407]kN`@0P8201@21PH4408J6QPD0O7al101`L704
08n?S`D0NGUi101mOGd408B4Q0T0PX:21@1gMgL407]kN`@0Ph>31@1oOgl407QhN0D0Ogmo201mOGd5
07alO0T0OWin201oOgl508>3P`T0PX:21027QhL4071`L0D0UiNG101iNGT508>3P`@0OWin1021PH45
07inOP@0Q8B44P20P80407alO0D0Ng]k101oOgl4075aL@D0OGem101oOgl508>3P`@0PH61101`L705
07alO0@0Ph>31@21PH4807inOPD0O7al2021PH4507moOaH0b>3H000E0<SPf0D0ATI6100Y:BT403Ti
>@D0FUYJ100S8b<502HV9P@0:2PX100_;bl504e=C@@0M7Ad1@14A4@402PX:0T0;Bd]100_;bl502h^
;P@09RHV100W9bL902@T90@0DE5A1@2MWId406i^KPD0SXj>102l_;`40:NWY`D0[Zj^102c/k<50<71
`@@0bLW91036a/H50;^k^`@0^;Rh1@2c/k<40<K6aP@0V9RH1@19BDT405=CD`D0CDe=1013@d<403Lg
=`D0@410100g=cL503Hf=P@0=3@d100b<S8503<c<`@0=3@d2@0a<C4402`/;0D0:2PX100i>CT504m?
C`@0Q8B41026QXH507alO0@0PH611@1lO7`408J6QP@0S8b<1@2BTY8409^KV`D0W9bL3@38h=P408N7
Q`@0Ph>31@1nOWh408B4Q0D0QXJ6101oOgl407inOPD0RHV9101nOWh508b<S0@0RXZ:2@1iNGT408J6
QP@0PX:21@1lO7`407]kN`D0Ogmo1025QHD407UiN@D0QXJ61021PH450820P0@0Ph>3101kNg/508B4
Q0@0OGem2@20P80907emO@@0Ogmo1@21PH440820P0@0QXJ61@1YJFT4096AT@D0OWin101lO7`408N7
Q`D0QHF5101hN7P507inOP@0OGem1026QXH507moO`@0Ph>31@2;Rh/408b<S0@0NWYj2@25QHD507Ui
N@@0NWYj1023Ph<50820P0@0PH611@20P80408:2PPT0Ogmo1021PH4407emO@D0PX:25P38h=P001D0
b>3H1@16ATH402TY:@@0>CTi1@1JFUX402<S8`D09RHV100X:2P402l_;`D0CDe=101dM7@504A4A0@0
:2PX2@0];Bd402l_;`D0;Rh^100V9RH402LW9`T092@T101ADE4509fMW@@0KVi^1@2>SXh40;bl_0@0
YjNW1@2^[Zh40;>c/`D0`L711039bLT40<K6aPD0^k^k102h^;P50;>c/`@0a/K6102HV9P504U9B@@0
De=C1@1=CDd404=3@`@0=cLg1@10@40403Lg=`D0=SHf100d=3@4038b<PD0<c<c100d=3@9034a<@@0
;2`/1@0X:2P403Ti>@D0Cdm?1024Q8@408J6QPD0O7al1021PH4507alO0@0QXJ6102<S8`509:BTP@0
Vi^K1@2LW9`=0<SPf0@0QhN71023Ph<507inOP@0Q8B41@26QXH407moO`@0OWin1@29RHT407inOPD0
S8b<102:RXX907UiN@@0QXJ61022PX8507alO0@0Ng]k1@1oOgl408F5Q@@0NGUi1@26QXH40861P@D0
P8201023Ph<407]kN`D0Q8B4101mOGd90820P0T0OGem101oOgl50861P@@0P8201026QXH506UYJ@@0
TI6A1@1nOWh407alO0@0QhN71@25QHD407QhN0D0OWin101mOGd408J6QPD0Ogmo1023Ph<508^;R`@0
S8b<101jNWX908F5Q@D0NGUi101jNWX408>3P`D0P8201021PH450820P0@0PX:22@1oOgl40861P@@0
OGem1@22PX8F0<SPf0005@38h=P504I6AP@0:BTY100i>CT505YJFP@08b<S1@0V9RH402PX:0@0;bl_
1@1=CDd407AdM0D0A4A4100X:2P902d];@@0;bl_1@0^;Rh402HV9P@09bLW2@0T92@4055AD@D0WIfM
101^KVh508j>SP@0_;bl102WYjL50:j^[P@0/k>c1@31`L440<W9b@@0a/K61@2k^k/40;Rh^0D0/k>c
1036a/H409RHV0D0BDU9101CDe<504e=C@@0@d=3100g=cL50410@0@0=cLg1@0f=SH403@d=0@0<S8b
1@0c<c<403@d=0T0<C4a100/;2`502PX:0@0>CTi1@1?Cdl408B4Q0@0QXJ61@1lO7`40861P@D0O7al
1026QXH408b<S0D0TY:B102KVi/509bLW0d0b>3H1027QhL408>3P`D0OWin1024Q8@508J6QP@0Ogmo
101nOWh508V9R@@0OWin1@2<S8`408Z:RPT0NGUi1026QXH408:2PPD0O7al101kNg/507moO`@0QHF5
101iNGT508J6QP@0PH611@20P80408>3P`@0Ng]k1@24Q8@407emO@T0P8202@1mOGd407moO`D0PH61
1020P80408J6QPD0JFUY102ATI4507inOP@0O7al1027QhL508F5Q@@0N7Qh1@1nOWh407emO@@0QXJ6
1@1oOgl408>3P`D0Rh^;102<S8`407YjNPT0QHF51@1iNGT407YjNP@0Ph>31@20P8040861P@D0P820
1022PX8907moO`@0PH61101mOGd508:2PQH0b>3H000E0<SPf0D0ATI6100Y:BT403Ti>@D0FUYJ100S
8b<502HV9P@0:2PX100_;bl504e=C@@0M7Ad1@14A4@402PX:0T0;Bd]100_;bl502h^;P@09RHV100W
9bL902@T90@0DE5A1@2MWId406i^KPD0SXj>102l_;`40:NWY`D0[Zj^102c/k<50<71`@@0bLW91036
a/H50;^k^`@0^;Rh1@2c/k<40<K6aP@0V9RH1@19BDT405=CD`D0CDe=1013@d<403Lg=`D0@410100g
=cL503Hf=P@0=3@d100b<S8503<c<`@0=3@d2@0a<C4402`/;0D0:2PX100i>CT504m?C`@0Q8B41026
QXH507alO0@0PH611@1lO7`408J6QP@0S8b<1@2BTY8409^KV`D0W9bL3@38h=P408N7Q`@0Ph>31@1n
OWh408B4Q0D0QXJ6101oOgl407inOPD0RHV9101nOWh508b<S0@0RXZ:2@1iNGT408J6QP@0PX:21@1l
O7`407]kN`D0Ogmo1025QHD407UiN@D0QXJ61021PH450820P0@0Ph>3101kNg/508B4Q0@0OGem2@20
P80907emO@@0Ogmo1@21PH440820P0@0QXJ61@1YJFT4096AT@D0OWin101lO7`408N7Q`D0QHF5101h
N7P507inOP@0OGem1026QXH507moO`@0Ph>31@2;Rh/408b<S0@0NWYj2@25QHD507UiN@@0NWYj1023
Ph<50820P0@0PH611@20P80408:2PPT0Ogmo1021PH4407emO@D0PX:25P38h=P001D0b>3H1@0_;bl4
02`/;0@0>SXj1@1DE5@402XZ:PD09bLW100X:2P40410@0D0IFEU101?Cdl502LW9`P0;Bd]1@0^;Rh9
02d];@@0;2`/100S8b<503hn?P@09BDU100S8b<507alO0@0S8b<1@1VIVH40:^[Z`@0];Bd1@2WYjL4
0:b/[0D0^k^k1034a<@40<W9b@D0`<30102a/K450:^[Z`@0];Bd1036a/H50::RXP@0E5AD1@1PH604
05iNGP@0HV9R1@1JFUX904];B`@0D51@1011@D4502l_;`@0DE5A1@1QHF4403Hf=PT0@d=3101[Jf/5
07AdM0@0IFEU101lO7`>07AdM0@0P820102=SHd509VIV@@0WYjN1@2OWil=0<SPf0@0QHF5101kNg/5
08N7Q`T0O7al1022PX8408N7Q`D0OGem101kNg/508V9R@@0O7al1024Q8@50820P0@0O7al101oOgl5
07inOP@0Ph>31@2BTY8407UiN@@0QXJ61@1nOWh407]kN`D0OGem1025QHD408>3P`D0O7al2@20P804
07YjNP@0PH611@1lO7`40820P0D0O7al101oOgl407alO0D0Rh^;101_Kfl508Z:RP@0P820101oOgl5
08>3P`@0S8b<1@1mOGd407UiN@@0MgMg1@20P8040861P@D0N7Qh101_Kfl407alO0D0MgMg101jNWX5
07moO`P0PH611@1oOgl907emO@@0QHF51020P8050861P@@0O7al1022PX8507inOQH0b>3H000E0<SP
f0D0;bl_100/;2`403Xj>PD0E5AD100Z:RX502LW9`@0:2PX1010@40506EUI@@0Cdm?1@0W9bL802d]
;@D0;Rh^2@0];Bd402`/;0@08b<S1@0n?Sh402DU9@@08b<S1@1lO7`408b<S0D0IVIV102[Zj/40;Bd
]0D0YjNW102/[:`50;^k^`@0a<C41039bLT50<30`0@0/K6a1@2[Zj/40;Bd]0@0a/K61@2RXZ8405AD
E0D0H61P101NGUh4069RHPD0FUYJ2@1;Bd/4051@D0@0@D511@0_;bl4055AD@D0HF5Q100f=SH904=3
@`@0Jf][1@1dM7@406EUI@@0O7al3P1dM7@40820P0@0SHf=1@2IVIT409jNWPD0WinO3@38h=P408F5
Q@@0Ng]k1@27QhL907alO0@0PX:21027QhL507emO@@0Ng]k1@29RHT407alO0@0Q8B41@20P80407al
O0@0Ogmo1@1nOWh408>3P`D0TY:B101iNGT408J6QPD0OWin101kNg/507emO@@0QHF51023Ph<507al
O0T0P820101jNWX40861P@D0O7al1020P80507alO0@0Ogmo101lO7`508^;R`@0Kfm_1@2:RXX40820
P0@0Ogmo1@23Ph<408b<S0D0OGem101iNGT407MgM`D0P8201021PH4507QhN0@0Kfm_101lO7`507Mg
M`@0NWYj1@1oOgl80861P@D0Ogmo2@1mOGd408F5Q@@0P8201@21PH4407alO0@0PX:21@1nOWhF0<SP
f0005@38h=P502l_;`@0;2`/100j>SX505ADE0@0:RXZ1@0W9bL402PX:0@0@4101@1UIFD404m?C`D0
9bLW200];Bd502h^;PT0;Bd]100/;2`402<S8`D0?Shn100U9BD402<S8`D0O7al102<S8`506IVIP@0
Zj^[102d];@50:NWY`@0[:b/1@2k^k/40<C4a0@0bLW91@30`<040;6a/@D0Zj^[102d];@40<K6aPD0
XZ:R101DE5@5061PH0@0GUiN101RHV8505YJFPT0Bd];101@D5040451@@D0;bl_101ADE45065QH@@0
=SHf2@13@d<406][J`D0M7Ad101UIFD407alO0h0M7Ad1020P80408f=S@D0VIVI102NWYh509nOW`d0
b>3H1025QHD407]kN`D0QhN72@1lO7`408:2PP@0QhN71@1mOGd407]kN`D0RHV9101lO7`408B4Q0D0
P820101lO7`407moO`D0OWin1023Ph<509:BTP@0NGUi1026QXH507inOP@0Ng]k1@1mOGd408F5Q@@0
Ph>31@1lO7`90820P0@0NWYj1021PH4507alO0@0P8201@1lO7`407moO`@0O7al1@2;Rh/406m_K`D0
RXZ:1020P80407moO`D0Ph>3102<S8`507emO@@0NGUi101gMgL50820P0@0PH611@1hN7P406m_K`@0
O7al1@1gMgL407YjNPD0Ogmo2021PH4507moO`T0OGem1025QHD40820P0D0PH61101lO7`408:2PPD0
OWin5P38h=P001D0b>3H1@0_;bl402`/;0@0>SXj1@1DE5@402XZ:PD09bLW100X:2P40410@0D0IFEU
101?Cdl502LW9`P0;Bd]1@0^;Rh902d];@@0;2`/100S8b<503hn?P@09BDU100S8b<507alO0@0S8b<
1@1VIVH40:^[Z`@0];Bd1@2WYjL40:b/[0D0^k^k1034a<@40<W9b@D0`<30102a/K450:^[Z`@0];Bd
1036a/H50::RXP@0E5AD1@1PH60405iNGP@0HV9R1@1JFUX904];B`@0D51@1011@D4502l_;`@0DE5A
1@1QHF4403Hf=PT0@d=3101[Jf/507AdM0@0IFEU101lO7`>07AdM0@0P820102=SHd509VIV@@0WYjN
1@2OWil=0<SPf0@0QHF5101kNg/508N7Q`T0O7al1022PX8408N7Q`D0OGem101kNg/508V9R@@0O7al
1024Q8@50820P0@0O7al101oOgl507inOP@0Ph>31@2BTY8407UiN@@0QXJ61@1nOWh407]kN`D0OGem
1025QHD408>3P`D0O7al2@20P80407YjNP@0PH611@1lO7`40820P0D0O7al101oOgl407alO0D0Rh^;
101_Kfl508Z:RP@0P820101oOgl508>3P`@0S8b<1@1mOGd407UiN@@0MgMg1@20P8040861P@D0N7Qh
101_Kfl407alO0D0MgMg101jNWX507moO`P0PH611@1oOgl907emO@@0QHF51020P8050861P@@0O7al
1022PX8507inOQH0b>3H000E0<SPf0D0;bl_100/;2`403Xj>PD0E5AD100Z:RX502LW9`@0:2PX1010
@40506EUI@@0Cdm?1@0W9bL802d];@D0;Rh^2@0];Bd402`/;0@08b<S1@0n?Sh402DU9@@08b<S1@1l
O7`408b<S0D0IVIV102[Zj/40;Bd]0D0YjNW102/[:`50;^k^`@0a<C41039bLT50<30`0@0/K6a1@2[
Zj/40;Bd]0@0a/K61@2RXZ8405ADE0D0H61P101NGUh4069RHPD0FUYJ2@1;Bd/4051@D0@0@D511@0_
;bl4055AD@D0HF5Q100f=SH904=3@`@0Jf][1@1dM7@406EUI@@0O7al3P1dM7@40820P0@0SHf=1@2I
VIT409jNWPD0WinO3@38h=P408F5Q@@0Ng]k1@27QhL907alO0@0PX:21027QhL507emO@@0Ng]k1@29
RHT407alO0@0Q8B41@20P80407alO0@0Ogmo1@1nOWh408>3P`D0TY:B101iNGT408J6QPD0OWin101k
Ng/507emO@@0QHF51023Ph<507alO0T0P820101jNWX40861P@D0O7al1020P80507alO0@0Ogmo101l
O7`508^;R`@0Kfm_1@2:RXX40820P0@0Ogmo1@23Ph<408b<S0D0OGem101iNGT407MgM`D0P8201021
PH4507QhN0@0Kfm_101lO7`507MgM`@0NWYj1@1oOgl80861P@D0Ogmo2@1mOGd408F5Q@@0P8201@21
PH4407alO0@0PX:21@1nOWhF0<SPf0005@38h=P502h^;P@0:BTY100i>CT504a<C0@09RHV1@0X:2P4
02TY:@@0Cdm?1@1XJ6P403@d=0D0:2PX100V9RH402/[:`D0;bl_100X:2P502/[:`@0;Rh^101ADE45
03hn?P@0820P100S8b<503dm?@@0U9BD1@1fMWH407YjNP@0^[Zj2@2ZZZX50;6a/@@0_Kfm2@33`l<4
0:n_[`D0XZ:R102YZJT40;Rh^0D0alO7102][Jd506YZJP@0K6a/2@1aLG4407EeM@D0N7Qh101kNg/4
079bLPD0@4101022PX8509BDU0@0LG5a101eMGD5069RHP@0JVYZ1@1eMGD406EUI@@0JVYZ1@1PH604
06IVIPD0KFe]1027QhL409bLW0D0WIfM102QXJ450:BTY0d0b>3H1025QHD908:2PP@0Q8B41@23Ph<4
0820P0@0Q8B41@1oOgl40820P0D0Ng]k1024Q8@407UiN@D0Ogmo101mOGd408:2PPD0RXZ:1026QXH5
06YZJP@0RXZ:102=SHd507inOP@0QHF51@24Q8@407moO`@0QhN71@1mOGd907moO`@0Ph>31021PH45
07inOP@0PX:22@1mOGd40820P0D0OGem1024Q8@507MgM`@0OGem1022PX8507]kN`@0P8201@22PX84
07moO`@0Q8B41@1hN7P407moO`D0Ng]k1022PX8407emO@D0Ogmo101lO7`908>3P`@0PH611@1nOWh4
07emO@D0N7Qh1021PH440820P0D0Ogmo101nOWh407emO@D0Q8B45P38h=P001D0b>3H1@0^;Rh402TY
:@@0>CTi1@1<C4`402HV9PD0:2PX100Y:BT404m?C`D0J6QX100d=3@502PX:0@09RHV100[:b/502l_
;`@0:2PX1@0[:b/402h^;P@0DE5A1@0n?Sh4020P80@08b<S1@0m?Cd409BDU0D0MWIf101jNWX40;Zj
^PT0ZZZZ1@2a/K440;fm_@T0`l?3102_[jl50::RXP@0ZJVY102h^;P50<O7a`@0[Jf]1@1ZJVX406a/
K0T0LG5a101eMGD507QhN0@0Ng]k101bLW850410@0@0PX:21@2DU9@4075aL@@0MGEe1@1RHV8406YZ
JPD0MGEe101UIFD406YZJPD0H61P101VIVH506e]K@@0QhN7102LW9`509fMW@@0XJ6Q1@2TY:@=0<SP
f0@0QHF52@22PX8408B4Q0D0Ph>31020P80408B4Q0D0Ogmo1020P80507]kN`@0Q8B4101iNGT507mo
O`@0OGem1022PX8508Z:RP@0QXJ61@1ZJVX408Z:RP@0SHf=1@1nOWh408F5Q@D0Q8B4101oOgl408N7
Q`D0OGem2@1oOgl408>3P`@0PH611@1nOWh408:2PPT0OGem1020P80507emO@@0Q8B41@1gMgL407em
O@@0PX:21@1kNg/40820P0D0PX:2101oOgl408B4Q0D0N7Qh101oOgl507]kN`@0PX:2101mOGd507mo
O`@0O7al2@23Ph<40861P@D0OWin101mOGd507QhN0@0PH611020P80507moO`@0OWin101mOGd508B4
Q1H0b>3H000E0<SPf0D0;Rh^100Y:BT403Ti>@D0C4a<100V9RH502PX:0@0:BTY101?Cdl506QXJ0@0
=3@d1@0X:2P402HV9P@0:b/[1@0_;bl402PX:0D0:b/[100^;Rh4055AD@D0?Shn100P820402<S8`D0
?Cdm102DU9@507IfMP@0NWYj102j^[X90:ZZZPD0/K6a102m_Kd90<?3``@0[jn_1@2RXZ840:VYZ@@0
^;Rh1@37alL40:f][@D0JVYZ101/K6`9075aL@@0MGEe1@1hN7P407]kN`@0LW9b1@10@40408:2PPD0
U9BD101aLG4407EeM@D0HV9R101ZJVX507EeM@@0IFEU101ZJVX5061PH0@0IVIV1@1]KFd408N7Q`@0
W9bL1@2MWId40:6QX@D0Y:BT3@38h=P408F5Q@T0PX:21024Q8@508>3P`@0P8201024Q8@507moO`@0
P8201@1kNg/408B4Q0@0NGUi1@1oOgl407emO@@0PX:21@2:RXX408J6QPD0JVYZ102:RXX408f=S@D0
OWin1025QHD508B4Q0@0Ogmo1027QhL507emO@T0Ogmo1023Ph<40861P@D0OWin1022PX8907emO@@0
P8201@1mOGd408B4Q0D0MgMg101mOGd408:2PPD0Ng]k1020P80508:2PP@0Ogmo1024Q8@507QhN0@0
Ogmo1@1kNg/408:2PP@0OGem1@1oOgl407alO0T0Ph>31021PH4507inOP@0OGem1@1hN7P40861P@@0
P8201@1oOgl407inOP@0OGem1@24Q8@F0<SPf0005@38h=P502h^;P@0:BTY100i>CT504a<C0@09RHV
1@0X:2P402TY:@@0Cdm?1@1XJ6P403@d=0D0:2PX100V9RH402/[:`D0;bl_100X:2P502/[:`@0;Rh^
101ADE4503hn?P@0820P100S8b<503dm?@@0U9BD1@1fMWH407YjNP@0^[Zj2@2ZZZX50;6a/@@0_Kfm
2@33`l<40:n_[`D0XZ:R102YZJT40;Rh^0D0alO7102][Jd506YZJP@0K6a/2@1aLG4407EeM@D0N7Qh
101kNg/4079bLPD0@4101022PX8509BDU0@0LG5a101eMGD5069RHP@0JVYZ1@1eMGD406EUI@@0JVYZ
1@1PH60406IVIPD0KFe]1027QhL409bLW0D0WIfM102QXJ450:BTY0d0b>3H1025QHD908:2PP@0Q8B4
1@23Ph<40820P0@0Q8B41@1oOgl40820P0D0Ng]k1024Q8@407UiN@D0Ogmo101mOGd408:2PPD0RXZ:
1026QXH506YZJP@0RXZ:102=SHd507inOP@0QHF51@24Q8@407moO`@0QhN71@1mOGd907moO`@0Ph>3
1021PH4507inOP@0PX:22@1mOGd40820P0D0OGem1024Q8@507MgM`@0OGem1022PX8507]kN`@0P820
1@22PX8407moO`@0Q8B41@1hN7P407moO`D0Ng]k1022PX8407emO@D0Ogmo101lO7`908>3P`@0PH61
1@1nOWh407emO@D0N7Qh1021PH440820P0D0Ogmo101nOWh407emO@D0Q8B45P38h=P001D0b>3H1@0T
92@402`/;0@0>CTi1@13@d<403Hf=PD0<30`100f=SH905EEE@@0=CDe1@0W9bL402PX:0T0:BTY100[
:b/504I6AP@0IFEU101IFET502XZ:P@0CDe=100N7Qh5024Q8@@0GEeM1@2NWYh407moO`@0Ph>31@2n
_[h40:FUY@D0[Jf]102c/k<40;fm_@D0aLG5102i^KT509^KV`@0WIfM102_[jl50;fm_@@0`l?31@2j
^[X407]kN`@0N7Qh1@21PH4408>3P`T0Shn?1027QhL507UiN@@0X:2P1@2NWYh408b<S0@0PX:21@1h
N7P4065QH@D0Fe]K101CDe<404e=C@D0Bd];101DE5@507IfMP@0UIFE102XZ:P50:JVYP@0Z:RX1@2Y
ZJT=0<SPf0@0P820101lO7`506][J`@0Kfm_1@1jNWX406i^KP@0Hf=S1@1iNGT408N7Q`D0Ph>3201k
Ng/50820P0@0Ogmo1025QHD5092@T0@0Kfm_1@28R8P407]kN`@0MWIf2@22PX8508J6QP@0OWin101m
OGd508B4Q0@0Ng]k1@22PX8407]kN`@0Ogmo1@1mOGd407inOPD0PH61101lO7`40861P@D0OWin101m
OGd907moO`@0LW9b1@2@T90407inOPD0PH61101nOWh407alO0D0R8R8101nOWh508>3P`@0O7al101o
Ogl507UiN@@0Ng]k1@1dM7@807alO0D0Q8B4102;Rh/508N7Q`@0PH611023Ph<50861P@@0P8201022
PX850820P1H0b>3H000E0<SPf0D092@T100/;2`403Ti>@D0@d=3100f=SH5030`<0@0=SHf2@1EEED4
03De=@D09bLW100X:2P902TY:@@0:b/[1@16ATH406EUI@@0FEUI1@0Z:RX404e=C@@07QhN1@0Q8B44
05eMG@D0WYjN101oOgl408>3P`D0_[jn102UYJD50:f][@@0/k>c102m_Kd50<G5a@@0^KVi1@2KVi/4
09fMW@@0[jn_1@2m_Kd40<?3``D0^[Zj101kNg/407QhN0D0PH611023Ph<908n?S`@0QhN71@1iNGT4
0:2PX0D0WYjN102<S8`408:2PPD0N7Qh101QHF4505]KF`@0De=C101=CDd504];B`@0E5AD1@1fMWH4
09FEU@@0Z:RX1@2VYZH40:RXZ0D0ZJVY3@38h=P40820P0@0O7al1@1[Jf/406m_K`D0NWYj101^KVh4
06=SH`D0NGUi1027QhL508>3P`P0Ng]k1@20P80407moO`@0QHF51@2@T90406m_K`D0R8R8101kNg/4
07IfMPT0PX:21@26QXH407inOP@0OGem1@24Q8@407]kN`D0PX:2101kNg/407moO`D0OGem101nOWh5
0861P@@0O7al1021PH4507inOP@0OGem2@1oOgl4079bLPD0T92@101nOWh50861P@@0OWin101lO7`5
08R8R0@0OWin1@23Ph<407alO0@0Ogmo1@1iNGT407]kN`D0M7Ad201lO7`508B4Q0@0Rh^;1@27QhL4
0861P@@0Ph>31@21PH440820P0@0PX:21@20P80F0<SPf0005@38h=P502@T90@0;2`/100i>CT504=3
@`@0=SHf1@0`<30403Hf=PT0EEEE100e=CD502LW9`@0:2PX2@0Y:BT402/[:`D0ATI6101UIFD405UI
F@D0:RXZ101=CDd401hN7PD08B4Q101MGEd509jNWP@0Ogmo1023Ph<50;jn_P@0YJFU1@2][Jd40;>c
/`@0_Kfm1@35aLD40;Vi^@D0Vi^K102MWId40:n_[`D0_Kfm1033`l<50;Zj^P@0Ng]k101hN7P50861
P@@0Ph>32@2?Shl408N7Q`D0NGUi102PX:0509jNWP@0S8b<1022PX8507QhN0@0HF5Q1@1KFe/405=C
D`@0CDe=1@1;Bd/405ADE0D0MWIf102EUID40:RXZ0D0YZJV102XZ:P50:VYZ@d0b>3H1020P80407al
O0D0Jf][101_Kfl507YjNP@0KVi^101SHf<507UiN@@0QhN71@23Ph<807]kN`D0P820101oOgl408F5
Q@D0T92@101_Kfl508R8R0@0Ng]k101fMWH908:2PPD0QXJ6101nOWh407emO@D0Q8B4101kNg/508:2
PP@0Ng]k101oOgl507emO@@0OWin1@21PH4407alO0@0PH611@1nOWh407emO@T0Ogmo101bLW85092@
T0@0OWin1@21PH4407inOP@0O7al1@28R8P407inOPD0Ph>3101lO7`407moO`D0NGUi101kNg/507Ad
M0P0O7al1@24Q8@408^;R`D0QhN71021PH4408>3P`D0PH611020P80408:2PPD0P8205P38h=P001D0
b>3H1@0T92@402`/;0@0>CTi1@13@d<403Hf=PD0<30`100f=SH905EEE@@0=CDe1@0W9bL402PX:0T0
:BTY100[:b/504I6AP@0IFEU101IFET502XZ:P@0CDe=100N7Qh5024Q8@@0GEeM1@2NWYh407moO`@0
Ph>31@2n_[h40:FUY@D0[Jf]102c/k<40;fm_@D0aLG5102i^KT509^KV`@0WIfM102_[jl50;fm_@@0
`l?31@2j^[X407]kN`@0N7Qh1@21PH4408>3P`T0Shn?1027QhL507UiN@@0X:2P1@2NWYh408b<S0@0
PX:21@1hN7P4065QH@D0Fe]K101CDe<404e=C@D0Bd];101DE5@507IfMP@0UIFE102XZ:P50:JVYP@0
Z:RX1@2YZJT=0<SPf0@0P820101lO7`506][J`@0Kfm_1@1jNWX406i^KP@0Hf=S1@1iNGT408N7Q`D0
Ph>3201kNg/50820P0@0Ogmo1025QHD5092@T0@0Kfm_1@28R8P407]kN`@0MWIf2@22PX8508J6QP@0
OWin101mOGd508B4Q0@0Ng]k1@22PX8407]kN`@0Ogmo1@1mOGd407inOPD0PH61101lO7`40861P@D0
OWin101mOGd907moO`@0LW9b1@2@T90407inOPD0PH61101nOWh407alO0D0R8R8101nOWh508>3P`@0
O7al101oOgl507UiN@@0Ng]k1@1dM7@807alO0D0Q8B4102;Rh/508N7Q`@0PH611023Ph<50861P@@0
P8201022PX850820P1H0b>3H000E0<SPf0D09RHV100W9bL403Ti>@D0BTY:100j>SX504=3@`@0=cLg
101=CDd503Ph>0@0<c<c1@0^;Rh402HV9P@0:2PX1@0U9BD403De=@D0G5aL1018B4P405IFEPD0>3Ph
1013@d<403@d=0D092@T100_;bl508>3P`@0T92@101UIFD509ZJVP@0^KVi1@2QXJ440;6a/@@0]kNg
1@30`<040<71`@D0YZJV102FUYH40:BTY0D0/k>c102m_Kd50<;2`P@0_Kfm102=SHd507QhN0@0S8b<
1@2BTY8409VIV@@0TY:B1@2IVIT409ZJVPD0U9BD1022PX8406e]K@D0FUYJ101<C4`504I6AP@0@D51
1018B4P505]KF`@0Ogmo1@2NWYh40:^[Z`@0ZZZZ1@2[Zj/40:VYZ@D0[:b/3@38h=P808:2PPD0QXJ6
101eMGD507MgM`@0OWin102=SHd507alO0@0NGUi1@22PX8408>3P`@0Q8B41@21PH4408>3P`T0Ogmo
102EUID907emO@@0Ogmo1@1jNWX408B4Q0D0Ng]k101hN7P407moO`T0PX:21@1lO7`408:2PP@0OGem
1@1nOWh40861P@D0OGem2021PH4507moO`@0O7al1@20P80407emO@@0Ph>31@1`L70408^;R`D0MgMg
201mOGd907moO`D0NGUi101mOGd407inOPD0P8201028R8P508>3P`@0R8R81021PH4507alO0@0MWIf
1@1kNg/40861P@@0Ogmo1@1nOWh407emO@@0P8201@1lO7`F0<SPf0005@38h=P502HV9P@09bLW100i
>CT504Y:BP@0>SXj1@13@d<403Lg=`@0CDe=1@0h>3P403<c<`D0;Rh^100V9RH402PX:0D09BDU100e
=CD505aLG0@0B4Q8101FEUH503Ph>0@0@d=3100d=3@502@T90@0;bl_1@23Ph<4092@T0@0IFEU1@2J
VYX40;Vi^@D0XJ6Q102a/K440;Ng]`D0`<301031`L450:JVYP@0UYJF102TY:@50;>c/`@0_Kfm1@32
`/840;fm_@@0SHf=1@1hN7P408b<S0D0TY:B102IVIT409:BTPD0VIVI102JVYX509BDU0@0PX:2101]
KFd505YJFP@0C4a<1@16ATH40451@@@0B4Q81@1KFe/407moO`D0WYjN102[Zj/40:ZZZPD0Zj^[102Y
ZJT50:b/[0d0b>3H2022PX8508J6QP@0MGEe1@1gMgL407inOP@0SHf=1@1lO7`407UiN@D0PX:21023
Ph<408B4Q0D0PH611023Ph<907moO`@0UIFE2@1mOGd407moO`D0NWYj1024Q8@507]kN`@0N7Qh101o
Ogl908:2PPD0O7al1022PX8407emO@D0OWin1021PH4507emO@P0PH611@1oOgl407alO0D0P820101m
OGd408>3P`D0L71`102;Rh/507MgM`P0OGem2@1oOgl507UiN@@0OGem101nOWh50820P0@0R8R81@23
Ph<408R8R0@0PH611@1lO7`407IfMPD0Ng]k1021PH4407moO`D0OWin101mOGd40820P0D0O7al5P38
h=P001D0b>3H1@0V9RH402LW9`@0>CTi1@1:BTX403Xj>PD0@d=3100g=cL404e=C@D0>3Ph100c<c<5
02h^;P@09RHV100X:2P502DU9@@0=CDe1@1LG5`404Q8B0@0EUIF1@0h>3P404=3@`@0=3@d1@0T92@4
02l_;`D0Ph>3102@T90406EUI@D0VYZJ102i^KT50:6QX@@0/K6a102g]kL50<30`0@0`L711@2VYZH4
09JFUP@0Y:BT1@2c/k<40;fm_@D0`/;2102m_Kd408f=S@D0N7Qh102<S8`509:BTP@0VIVI102BTY85
09VIV@@0VYZJ1@2DU9@408:2PP@0KFe]1@1JFUX404a<C0D0ATI61011@D4404Q8B0D0Fe]K101oOgl5
09jNWP@0Zj^[102ZZZX50:^[Z`@0ZJVY1@2/[:`=0<SPf0P0PX:21@26QXH407EeM@D0MgMg101nOWh4
08f=S@D0O7al101iNGT508:2PP@0Ph>31024Q8@50861P@@0Ph>32@1oOgl409FEU@T0OGem101oOgl5
07YjNP@0Q8B41@1kNg/407QhN0@0Ogmo2@22PX8507alO0@0PX:2101mOGd507inOP@0PH611@1mOGd8
0861P@D0Ogmo101lO7`50820P0@0OGem1023Ph<5071`L0@0Rh^;1@1gMgL807emO@T0Ogmo1@1iNGT4
07emO@@0OWin1@20P80408R8R0D0Ph>31028R8P40861P@D0O7al101fMWH507]kN`@0PH61101oOgl5
07inOP@0OGem1020P80507alO1H0b>3H000E0<SPf0D09RHV100W9bL403Ti>@D0BTY:100j>SX504=3
@`@0=cLg101=CDd503Ph>0@0<c<c1@0^;Rh402HV9P@0:2PX1@0U9BD403De=@D0G5aL1018B4P405IF
EPD0>3Ph1013@d<403@d=0D092@T100_;bl508>3P`@0T92@101UIFD509ZJVP@0^KVi1@2QXJ440;6a
/@@0]kNg1@30`<040<71`@D0YZJV102FUYH40:BTY0D0/k>c102m_Kd50<;2`P@0_Kfm102=SHd507Qh
N0@0S8b<1@2BTY8409VIV@@0TY:B1@2IVIT409ZJVPD0U9BD1022PX8406e]K@D0FUYJ101<C4`504I6
AP@0@D511018B4P505]KF`@0Ogmo1@2NWYh40:^[Z`@0ZZZZ1@2[Zj/40:VYZ@D0[:b/3@38h=P808:2
PPD0QXJ6101eMGD507MgM`@0OWin102=SHd507alO0@0NGUi1@22PX8408>3P`@0Q8B41@21PH4408>3
P`T0Ogmo102EUID907emO@@0Ogmo1@1jNWX408B4Q0D0Ng]k101hN7P407moO`T0PX:21@1lO7`408:2
PP@0OGem1@1nOWh40861P@D0OGem2021PH4507moO`@0O7al1@20P80407emO@@0Ph>31@1`L70408^;
R`D0MgMg201mOGd907moO`D0NGUi101mOGd407inOPD0P8201028R8P508>3P`@0R8R81021PH4507al
O0@0MWIf1@1kNg/40861P@@0Ogmo1@1nOWh407emO@@0P8201@1lO7`F0<SPf0005@38h=P502HV9P@0
9bLW100i>CT504Y:BP@0>SXj1@13@d<403Lg=`@0CDe=1@0h>3P403<c<`D0;Rh^100V9RH402PX:0D0
9BDU100e=CD505aLG0@0B4Q8101FEUH503Ph>0@0@d=3100d=3@502@T90@0;bl_1@23Ph<4092@T0@0
IFEU1@2JVYX40;Vi^@D0XJ6Q102a/K440;Ng]`D0`<301031`L450:JVYP@0UYJF102TY:@50;>c/`@0
_Kfm1@32`/840;fm_@@0SHf=1@1hN7P408b<S0D0TY:B102IVIT409:BTPD0VIVI102JVYX509BDU0@0
PX:2101]KFd505YJFP@0C4a<1@16ATH40451@@@0B4Q81@1KFe/407moO`D0WYjN102[Zj/40:ZZZPD0
Zj^[102YZJT50:b/[0d0b>3H2022PX8508J6QP@0MGEe1@1gMgL407inOP@0SHf=1@1lO7`407UiN@D0
PX:21023Ph<408B4Q0D0PH611023Ph<907moO`@0UIFE2@1mOGd407moO`D0NWYj1024Q8@507]kN`@0
N7Qh101oOgl908:2PPD0O7al1022PX8407emO@D0OWin1021PH4507emO@P0PH611@1oOgl407alO0D0
P820101mOGd408>3P`D0L71`102;Rh/507MgM`P0OGem2@1oOgl507UiN@@0OGem101nOWh50820P0@0
R8R81@23Ph<408R8R0@0PH611@1lO7`407IfMPD0Ng]k1021PH4407moO`D0OWin101mOGd40820P0D0
O7al5P38h=P001D0b>3H1@0U9BD402d];@@0:BTY1@0g=cL404Y:BPD0=cLg100h>3P404I6APD0<30`
100_;bl503@d=0@0:b/[100_;bl503@d=0@0G5aL1@1@D50403@d=0@0BTY:1@1ADE4402d];@@0B4Q8
1@0P820402XZ:PD0@T92102EUID407AdM0D0HV9R102UYJD50:j^[P@0ZZZZ102a/K450;Ng]`@0`/;2
1@2d];@409ZJVP@0Vi^K1@2YZJT40;^k^`D0_Kfm2030`<0509^KV`@0MGEe1@22PX8408j>SP@0Rh^;
1@27QhL407UiN@D0LG5a101TI6@4051@D0D0@T92101;Bd/5051@D0@0JFUY101lO7`509^KV`@0Z:RX
1@2a/K440:j^[P@0/K6a1@2c/k<40:n_[`D0[:b/3@38h=P407moO`@0Ph>31@1nOWh408B4Q0D0SHf=
101kNg/407MgM`D0OWin1021PH4507alO0@0Ph>31026QXH50861P@@0IFEU101iNGT508V9R@@0LW9b
1@2<S8`407alO0T0PH611024Q8@507MgM`@0PX:22@1nOWh407moO`D0PH61101hN7P408>3P`D0PH61
1020P80508>3P`@0OWin1023Ph<507moO`@0PH611@1mOGd80820P0D0QhN7101^KVh509JFUP@0Ogmo
101iNGT507inOP@0Ogmo1@27QhL407emO@@0QXJ61@20P80407YjNPD0N7Qh101cLg<407alO0D0NWYj
1024Q8@907inOP@0P8201@23Ph<407moO`@0PX:21@1nOWhF0<SPf0005@38h=P502DU9@@0;Bd]100Y
:BT503Lg=`@0BTY:1@0g=cL403Ph>0@0ATI61@0`<30402l_;`D0=3@d100[:b/402l_;`D0=3@d101L
G5`5051@D0@0=3@d101:BTX5055AD@@0;Bd]1018B4P5020P80@0:RXZ1@12@T8409FEU@@0M7Ad1@1R
HV840:FUY@D0[Zj^102ZZZX40;6a/@D0]kNg1032`/850;Bd]0@0VYZJ102KVi/50:VYZ@@0^k^k1@2m
_Kd80<30`0D0Vi^K101eMGD508:2PP@0SXj>102;Rh/508N7Q`@0NGUi1@1aLG4406ATI0@0D51@1@12
@T8404];B`D0D51@101YJFT407alO0D0Vi^K102XZ:P50;6a/@@0[Zj^102a/K450;>c/`@0[jn_1@2/
[:`=0<SPf0@0Ogmo1023Ph<507inOP@0Q8B41@2=SHd407]kN`@0MgMg1@1nOWh40861P@D0O7al1023
Ph<408J6QPD0PH61101UIFD407UiN@D0RHV9101bLW8508b<S0@0O7al2@21PH4408B4Q0D0MgMg1022
PX8907inOP@0Ogmo1@21PH4407QhN0@0Ph>31@21PH440820P0D0Ph>3101nOWh408>3P`D0Ogmo1021
PH4507emO@P0P8201@27QhL406i^KPD0UYJF101oOgl407UiN@D0OWin101oOgl508N7Q`@0OGem1026
QXH50820P0@0NWYj1@1hN7P407=cL`@0O7al1@1jNWX408B4Q0T0OWin1020P80508>3P`@0Ogmo1022
PX8507inOQH0b>3H000E0<SPf0D09BDU100];Bd402TY:@D0=cLg101:BTX503Lg=`@0>3Ph1016ATH5
030`<0@0;bl_1@0d=3@402/[:`@0;bl_1@0d=3@405aLG0D0D51@100d=3@404Y:BPD0DE5A100];Bd4
04Q8B0D0820P100Z:RX50492@P@0UIFE101dM7@5069RHP@0YJFU1@2^[Zh40:ZZZP@0/K6a1@2g]kL4
0<;2`PD0];Bd102JVYX409^KV`D0ZJVY102k^k/50;fm_@P0`<301@2KVi/407EeM@D0PX:2102>SXh4
08^;R`D0QhN7101iNGT5075aL@@0I6AT101@D5050492@P@0Bd];1@1@D50406UYJ@@0O7al1@2KVi/4
0:RXZ0D0/K6a102^[Zh40;6a/@D0/k>c102_[jl50:b/[0d0b>3H101oOgl408>3P`D0OWin1024Q8@5
08f=S@@0Ng]k101gMgL507inOP@0PH611@1lO7`408>3P`@0QXJ61@21PH4406EUI@@0NGUi1@29RHT4
079bLPD0S8b<101lO7`90861P@@0Q8B41@1gMgL408:2PPT0OWin101oOgl50861P@@0N7Qh1023Ph<5
0861P@@0P8201@23Ph<407inOP@0Ph>31@1oOgl40861P@D0OGem2020P80508N7Q`@0KVi^1@2FUYH4
07moO`@0NGUi1@1nOWh407moO`D0QhN7101mOGd408J6QPD0P820101jNWX507QhN0@0Lg=c101lO7`5
07YjNP@0Q8B42@1nOWh40820P0D0Ph>3101oOgl408:2PPD0OWin5P38h=P001D0b>3H1@0U9BD402d]
;@@0:BTY1@0g=cL404Y:BPD0=cLg100h>3P404I6APD0<30`100_;bl503@d=0@0:b/[100_;bl503@d
=0@0G5aL1@1@D50403@d=0@0BTY:1@1ADE4402d];@@0B4Q81@0P820402XZ:PD0@T92102EUID407Ad
M0D0HV9R102UYJD50:j^[P@0ZZZZ102a/K450;Ng]`@0`/;21@2d];@409ZJVP@0Vi^K1@2YZJT40;^k
^`D0_Kfm2030`<0509^KV`@0MGEe1@22PX8408j>SP@0Rh^;1@27QhL407UiN@D0LG5a101TI6@4051@
D0D0@T92101;Bd/5051@D0@0JFUY101lO7`509^KV`@0Z:RX1@2a/K440:j^[P@0/K6a1@2c/k<40:n_
[`D0[:b/3@38h=P407moO`@0Ph>31@1nOWh408B4Q0D0SHf=101kNg/407MgM`D0OWin1021PH4507al
O0@0Ph>31026QXH50861P@@0IFEU101iNGT508V9R@@0LW9b1@2<S8`407alO0T0PH611024Q8@507Mg
M`@0PX:22@1nOWh407moO`D0PH61101hN7P408>3P`D0PH611020P80508>3P`@0OWin1023Ph<507mo
O`@0PH611@1mOGd80820P0D0QhN7101^KVh509JFUP@0Ogmo101iNGT507inOP@0Ogmo1@27QhL407em
O@@0QXJ61@20P80407YjNPD0N7Qh101cLg<407alO0D0NWYj1024Q8@907inOP@0P8201@23Ph<407mo
O`@0PX:21@1nOWhF0<SPf0005@38h=P502<S8`@0>3Ph100[:b/503De=@@0<C4a1@0`<30403Ti>@@0
<c<c2@0];Bd503Lg=`@0;Bd]2@0f=SH404E5A@D0<S8b100_;bl404m?C`D0Fe]K100[:b/405=CD`D0
;2`/100T92@5020P80@0Hf=S102CTi<506MWI`@0Kfm_1@2b/[840:f][@@0ZZZZ1@2_[jl40;^k^`D0
^KVi102MWId409^KV`D0WYjN102g]kL50<30`0@0`l?31031`L450<30`0@0XJ6Q1@1OGel405EEE@d0
Hf=S1@1RHV8406MWI`@0GemO1@1_Kfl407UiN@D0QhN7102IVIT40:FUY@D0[Jf]102c/k<50;Jf]P@0
/[:b102a/K490;2`/0D0[:b/3@38h=P408:2PP@0OWin1@1kNg/40820P0D0RXZ:2023Ph<507UiN@@0
OGem2@20P8090861P@@0Q8B4102:RXX507inOP@0P8201@1jNWX408:2PP@0OWin1@1kNg/407emO@D0
RXZ:1021PH4408B4Q0D0NWYj1023Ph<507moO`@0PH612@1oOgl408F5Q@D0OWin1023Ph<407inOPD0
P8202@22PX8407emO@@0PX:21@20P80408F5Q@D0MgMg101oOgl409jNWPD0MgMg1023Ph<507]kN`@0
P820101lO7`507QhN0T0P820101oOgl408:2PPD0PH611020P80507inOP@0P820101lO7`50820P0@0
O7al1022PX8507alO1H0b>3H000E0<SPf0D08b<S100h>3P402/[:`D0=CDe100a<C45030`<0@0>CTi
100c<c<902d];@D0=cLg100];Bd903Hf=P@0ADE51@0b<S8402l_;`@0Cdm?1@1KFe/402/[:`@0De=C
1@0/;2`402@T90D0820P101SHf<409>CT`D0IfMW101_Kfl50;:b/P@0[Jf]102ZZZX50:n_[`@0^k^k
1@2i^KT409fMW@@0Vi^K1@2NWYh40;Ng]`D0`<301033`l<40<71`@D0`<30102QXJ4505mOG`@0EEEE
3@1SHf<5069RHP@0IfMW101OGel506m_K`@0NGUi1@27QhL409VIV@@0YJFU1@2][Jd40;>c/`D0][Jf
102b/[840;6a/@T0/;2`1@2/[:`=0<SPf0@0PX:2101nOWh507]kN`@0P8201@2:RXX808>3P`D0NGUi
101mOGd90820P0T0PH611024Q8@408Z:RPD0OWin1020P80507YjNP@0PX:2101nOWh507]kN`@0OGem
1@2:RXX40861P@@0Q8B41@1jNWX408>3P`D0Ogmo1021PH4907moO`@0QHF51@1nOWh408>3P`@0OWin
1@20P80908:2PP@0OGem1022PX850820P0@0QHF51@1gMgL407moO`@0WYjN1@1gMgL408>3P`D0Ng]k
1020P80407alO0D0N7Qh2@20P80407moO`@0PX:21@21PH440820P0D0OWin1020P80407alO0D0P820
101lO7`408:2PPD0O7al5P38h=P001D0b>3H1@0S8b<403Ph>0@0:b/[1@0e=CD4034a<@D0<30`100i
>CT403<c<`T0;Bd]1@0g=cL402d];@T0=SHf1015ADD5038b<P@0;bl_101?Cdl505]KF`@0:b/[101C
De<502`/;0@092@T1@0P820406=SH`@0Ti>C1@1WIfL406m_K`D0/[:b102][Jd40:ZZZPD0[jn_102k
^k/50;Vi^@@0WIfM102KVi/509jNWP@0]kNg1@30`<040<?3``@0`L711@30`<040:6QX@D0GemO101E
EED=06=SH`D0HV9R101WIfL405mOG`D0Kfm_101iNGT508N7Q`@0VIVI102UYJD50:f][@@0/k>c1@2f
][H40;:b/P@0/K6a2@2`/;050:b/[0d0b>3H1022PX8407inOPD0Ng]k1020P80508Z:RPP0Ph>31@1i
NGT407emO@T0P8202@21PH4408B4Q0@0RXZ:1@1nOWh40820P0D0NWYj1022PX8407inOPD0Ng]k101m
OGd508Z:RP@0PH611024Q8@507YjNP@0Ph>31@1oOgl40861P@T0Ogmo1025QHD507inOP@0Ph>3101n
OWh50820P0T0PX:2101mOGd408:2PPD0P8201025QHD507MgM`@0Ogmo102NWYh507MgM`@0Ph>31@1k
Ng/40820P0@0O7al1@1hN7P90820P0@0Ogmo1022PX850861P@@0P8201@1nOWh40820P0@0O7al1@20
P80407alO0@0PX:21@1lO7`F0<SPf0005@38h=P502<S8`@0>3Ph100[:b/503De=@@0<C4a1@0`<304
03Ti>@@0<c<c2@0];Bd503Lg=`@0;Bd]2@0f=SH404E5A@D0<S8b100_;bl404m?C`D0Fe]K100[:b/4
05=CD`D0;2`/100T92@5020P80@0Hf=S102CTi<506MWI`@0Kfm_1@2b/[840:f][@@0ZZZZ1@2_[jl4
0;^k^`D0^KVi102MWId409^KV`D0WYjN102g]kL50<30`0@0`l?31031`L450<30`0@0XJ6Q1@1OGel4
05EEE@d0Hf=S1@1RHV8406MWI`@0GemO1@1_Kfl407UiN@D0QhN7102IVIT40:FUY@D0[Jf]102c/k<5
0;Jf]P@0/[:b102a/K490;2`/0D0[:b/3@38h=P408:2PP@0OWin1@1kNg/40820P0D0RXZ:2023Ph<5
07UiN@@0OGem2@20P8090861P@@0Q8B4102:RXX507inOP@0P8201@1jNWX408:2PP@0OWin1@1kNg/4
07emO@D0RXZ:1021PH4408B4Q0D0NWYj1023Ph<507moO`@0PH612@1oOgl408F5Q@D0OWin1023Ph<4
07inOPD0P8202@22PX8407emO@@0PX:21@20P80408F5Q@D0MgMg101oOgl409jNWPD0MgMg1023Ph<5
07]kN`@0P820101lO7`507QhN0T0P820101oOgl408:2PPD0PH611020P80507inOP@0P820101lO7`5
0820P0@0O7al1022PX8507alO1H0b>3H000E0<SPf0D08R8R200a<C450410@0@0AdM72@0l?3`4038b
<PD0:b/[100W9bL502XZ:P@0;Rh^100e=CD502h^;P@0C4a<1@0/;2`402@T90@0CDe=1@1QHF44028R
8P@0CTi>1@16ATH404=3@`D0:b/[100];Bd407QhN0D0TY:B101OGel507moO`@0_kno102WYjL50:RX
Z0@0/K6a1@2c/k<40:BTY0@0VYZJ1@2LW9`40;2`/0T0_[jn1032`/850;^k^`@0^KVi1@2`/;04075a
L@@0Cdm?1@1UIFD407AdM0D0O7al1029RHT4092@T0D0U9BD102HV9P50::RXP@0Z:RX102/[:`50;2`
/0@0/K6a1@2e]KD40;:b/P@0[jn_2@2`/;050;:b/Pd0b>3H101mOGd407]kN`D0Ph>3102:RXX506i^
KP@0M7Ad1026QXH508>3P`@0PH612@20P80408F5Q@D0P8201022PX8407UiN@D0OWin1021PH4508B4
Q0@0R8R82@1nOWh4092@T0D0Q8B4101hN7P407YjNPD0PX:2101hN7P908B4Q0@0Ng]k1@21PH4407al
O0T0OWin1020P80>07moO`@0PH61101oOgl50861P@@0QHF51@21PH4408F5Q@@0JFUY2@26QXH907mo
O`@0PX:21@23Ph<407YjNPD0OGem1020P80408B4Q0D0OGem101oOgl50861P@@0Ogmo1022PX8507mo
O`@0PH61101oOgl507emOAH0b>3H000E0<SPf0D08R8R200a<C450410@0@0AdM72@0l?3`4038b<PD0
:b/[100W9bL502XZ:P@0;Rh^100e=CD502h^;P@0C4a<1@0/;2`402@T90@0CDe=1@1QHF44028R8P@0
CTi>1@16ATH404=3@`D0:b/[100];Bd407QhN0D0TY:B101OGel507moO`@0_kno102WYjL50:RXZ0@0
/K6a1@2c/k<40:BTY0@0VYZJ1@2LW9`40;2`/0T0_[jn1032`/850;^k^`@0^KVi1@2`/;04075aL@@0
Cdm?1@1UIFD407AdM0D0O7al1029RHT4092@T0D0U9BD102HV9P50::RXP@0Z:RX102/[:`50;2`/0@0
/K6a1@2e]KD40;:b/P@0[jn_2@2`/;050;:b/Pd0b>3H101mOGd407]kN`D0Ph>3102:RXX506i^KP@0
M7Ad1026QXH508>3P`@0PH612@20P80408F5Q@D0P8201022PX8407UiN@D0OWin1021PH4508B4Q0@0
R8R82@1nOWh4092@T0D0Q8B4101hN7P407YjNPD0PX:2101hN7P908B4Q0@0Ng]k1@21PH4407alO0T0
OWin1020P80>07moO`@0PH61101oOgl50861P@@0QHF51@21PH4408F5Q@@0JFUY2@26QXH907moO`@0
PX:21@23Ph<407YjNPD0OGem1020P80408B4Q0D0OGem101oOgl50861P@@0Ogmo1022PX8507moO`@0
PH61101oOgl507emOAH0b>3H000E0<SPf0D08R8R200a<C450410@0@0AdM72@0l?3`4038b<PD0:b/[
100W9bL502XZ:P@0;Rh^100e=CD502h^;P@0C4a<1@0/;2`402@T90@0CDe=1@1QHF44028R8P@0CTi>
1@16ATH404=3@`D0:b/[100];Bd407QhN0D0TY:B101OGel507moO`@0_kno102WYjL50:RXZ0@0/K6a
1@2c/k<40:BTY0@0VYZJ1@2LW9`40;2`/0T0_[jn1032`/850;^k^`@0^KVi1@2`/;04075aL@@0Cdm?
1@1UIFD407AdM0D0O7al1029RHT4092@T0D0U9BD102HV9P50::RXP@0Z:RX102/[:`50;2`/0@0/K6a
1@2e]KD40;:b/P@0[jn_2@2`/;050;:b/Pd0b>3H101mOGd407]kN`D0Ph>3102:RXX506i^KP@0M7Ad
1026QXH508>3P`@0PH612@20P80408F5Q@D0P8201022PX8407UiN@D0OWin1021PH4508B4Q0@0R8R8
2@1nOWh4092@T0D0Q8B4101hN7P407YjNPD0PX:2101hN7P908B4Q0@0Ng]k1@21PH4407alO0T0OWin
1020P80>07moO`@0PH61101oOgl50861P@@0QHF51@21PH4408F5Q@@0JFUY2@26QXH907moO`@0PX:2
1@23Ph<407YjNPD0OGem1020P80408B4Q0D0OGem101oOgl50861P@@0Ogmo1022PX8507moO`@0PH61
101oOgl507emOAH0b>3H000E0<SPf0D08R8R200a<C450410@0@0AdM72@0l?3`4038b<PD0:b/[100W
9bL502XZ:P@0;Rh^100e=CD502h^;P@0C4a<1@0/;2`402@T90@0CDe=1@1QHF44028R8P@0CTi>1@16
ATH404=3@`D0:b/[100];Bd407QhN0D0TY:B101OGel507moO`@0_kno102WYjL50:RXZ0@0/K6a1@2c
/k<40:BTY0@0VYZJ1@2LW9`40;2`/0T0_[jn1032`/850;^k^`@0^KVi1@2`/;04075aL@@0Cdm?1@1U
IFD407AdM0D0O7al1029RHT4092@T0D0U9BD102HV9P50::RXP@0Z:RX102/[:`50;2`/0@0/K6a1@2e
]KD40;:b/P@0[jn_2@2`/;050;:b/Pd0b>3H101mOGd407]kN`D0Ph>3102:RXX506i^KP@0M7Ad1026
QXH508>3P`@0PH612@20P80408F5Q@D0P8201022PX8407UiN@D0OWin1021PH4508B4Q0@0R8R82@1n
OWh4092@T0D0Q8B4101hN7P407YjNPD0PX:2101hN7P908B4Q0@0Ng]k1@21PH4407alO0T0OWin1020
P80>07moO`@0PH61101oOgl50861P@@0QHF51@21PH4408F5Q@@0JFUY2@26QXH907moO`@0PX:21@23
Ph<407YjNPD0OGem1020P80408B4Q0D0OGem101oOgl50861P@@0Ogmo1022PX8507moO`@0PH61101o
Ogl507emOAH0b>3H000E0<SPf0D08R8R200a<C450410@0@0AdM72@0l?3`4038b<PD0:b/[100W9bL5
02XZ:P@0;Rh^100e=CD502h^;P@0C4a<1@0/;2`402@T90@0CDe=1@1QHF44028R8P@0CTi>1@16ATH4
04=3@`D0:b/[100];Bd407QhN0D0TY:B101OGel507moO`@0_kno102WYjL50:RXZ0@0/K6a1@2c/k<4
0:BTY0@0VYZJ1@2LW9`40;2`/0T0_[jn1032`/850;^k^`@0^KVi1@2`/;04075aL@@0Cdm?1@1UIFD4
07AdM0D0O7al1029RHT4092@T0D0U9BD102HV9P50::RXP@0Z:RX102/[:`50;2`/0@0/K6a1@2e]KD4
0;:b/P@0[jn_2@2`/;050;:b/Pd0b>3H101mOGd407]kN`D0Ph>3102:RXX506i^KP@0M7Ad1026QXH5
08>3P`@0PH612@20P80408F5Q@D0P8201022PX8407UiN@D0OWin1021PH4508B4Q0@0R8R82@1nOWh4
092@T0D0Q8B4101hN7P407YjNPD0PX:2101hN7P908B4Q0@0Ng]k1@21PH4407alO0T0OWin1020P80>
07moO`@0PH61101oOgl50861P@@0QHF51@21PH4408F5Q@@0JFUY2@26QXH907moO`@0PX:21@23Ph<4
07YjNPD0OGem1020P80408B4Q0D0OGem101oOgl50861P@@0Ogmo1022PX8507moO`@0PH61101oOgl5
07emOAH0b>3H000E0<SPf0D08b<S100/;2`402/[:`D0;Bd]101;Bd/506=SH`@0FUYJ101<C4`503dm
?@T0;2`/100_;bl403Xj>PD0:2PX101@D50503/k>`@09RHV100k>c/506QXJ0@0:2PX100d=3@505UI
F@@092@T1@0g=cL402`/;0@0<c<c1@2=SHd407QhN0D0FUYJ102ATI440;Jf]PD0XZ:R102[Zj/50:b/
[0@0ZJVY2@2PX:040;6a/@D0_[jn102k^k/40;Zj^PD0^k^k102b/[890;6a/@@0WIfM1@21PH4408^;
R`D0UYJF102JVYX409nOW`D0Xj>S102UYJD50:NWY`@0Z:RX102][Jd50:j^[PT0/K6a102d];@40;:b
/PD0/;2`102d];@50;Jf]Pd0b>3H1025QHD407UiN@D0OGem101oOgl507QhN0@0PX:2101bLW8508B4
Q0@0M7Ad2@20P80408F5Q@D0Ng]k1022PX8407YjNPD0QXJ6101nOWh507emO@@0O7al1020P80508:2
PP@0MGEe1@2<S8`408>3P`@0MgMg1@26QXH407emO@D0MGEe1022PX8408R8R0D0MgMg1028R8P507al
O0@0Ph>3101kNg/50820P0T0OWin1020P80407inOPD0Ogmo101mOGd508B4Q0@0OWin1028R8P507Mg
M`@0MGEe1@21PH4407YjNP@0PH612@1oOgl50820P0@0Ogmo1021PH450820P0@0PH612@1oOgl408>3
P`D0Ogmo1022PX8407inOPD0P8205P38h=P001D0b>3H1@0S8b<402`/;0@0:b/[1@0];Bd404];B`D0
Hf=S101JFUX404a<C0D0?Cdm2@0/;2`402l_;`@0>SXj1@0X:2P4051@D0D0>c/k100V9RH403/k>`D0
J6QX100X:2P403@d=0D0FEUI100T92@503Lg=`@0;2`/100c<c<508f=S@@0N7Qh1@1JFUX4096AT@@0
][Jf1@2RXZ840:^[Z`D0[:b/102YZJT90:2PX0@0/K6a1@2n_[h40;^k^`@0^[Zj1@2k^k/40;:b/PT0
/K6a102MWId50861P@@0Rh^;1@2FUYH409ZJVP@0WinO1@2SXj<40:FUY@D0YjNW102XZ:P40:f][@D0
[Zj^2@2a/K440;Bd]0@0/[:b1@2`/;040;Bd]0D0][Jf3@38h=P408F5Q@@0NGUi1@1mOGd407moO`D0
N7Qh1022PX84079bLPD0Q8B4101dM7@90820P0@0QHF51@1kNg/408:2PP@0NWYj1@26QXH407inOPD0
OGem101lO7`40820P0D0PX:2101eMGD508b<S0@0Ph>3101gMgL508J6QP@0OGem1@1eMGD408:2PP@0
R8R81@1gMgL408R8R0D0O7al1023Ph<407]kN`D0P8202@1nOWh40820P0@0OWin1@1oOgl407emO@D0
Q8B4101nOWh408R8R0D0MgMg101eMGD50861P@@0NWYj1021PH4907moO`D0P820101oOgl40861P@D0
P8201021PH4907moO`@0Ph>31@1oOgl408:2PP@0OWin1@20P80F0<SPf0005@38h=P502<S8`@0;2`/
100[:b/502d];@@0Bd];1@1SHf<405YJFP@0C4a<1@0m?Cd902`/;0@0;bl_100j>SX502PX:0@0D51@
1@0k>c/402HV9P@0>c/k1@1XJ6P402PX:0@0=3@d1@1IFET402@T90D0=cLg100/;2`403<c<`D0SHf=
101hN7P505YJFP@0TI6A102f][H50::RXP@0Zj^[1@2/[:`40:VYZ@T0X:2P102a/K450;jn_P@0^k^k
102j^[X50;^k^`@0/[:b2@2a/K4409fMW@D0PH61102;Rh/509JFUP@0VYZJ102OWil50:>SX`@0YJFU
1@2WYjL40:RXZ0@0[Jf]1@2^[Zh90;6a/@@0];Bd102b/[850;2`/0@0];Bd1@2f][H=0<SPf0@0QHF5
101iNGT507emO@@0Ogmo1@1hN7P408:2PP@0LW9b1@24Q8@407AdM0T0P8201025QHD507]kN`@0PX:2
101jNWX508J6QP@0OWin1@1mOGd407alO0@0P8201@22PX8407EeM@D0S8b<1023Ph<407MgM`D0QXJ6
101mOGd507EeM@@0PX:21028R8P507MgM`@0R8R81@1lO7`408>3P`@0Ng]k1@20P80907inOP@0P820
101nOWh507moO`@0OGem1@24Q8@407inOP@0R8R81@1gMgL407EeM@D0PH61101jNWX40861P@T0Ogmo
1@20P80407moO`@0PH611@20P8040861P@T0Ogmo1023Ph<507moO`@0PX:2101nOWh50820P1H0b>3H
000E0<SPf0D08b<S100/;2`402/[:`D0;Bd]101;Bd/506=SH`@0FUYJ101<C4`503dm?@T0;2`/100_
;bl403Xj>PD0:2PX101@D50503/k>`@09RHV100k>c/506QXJ0@0:2PX100d=3@505UIF@@092@T1@0g
=cL402`/;0@0<c<c1@2=SHd407QhN0D0FUYJ102ATI440;Jf]PD0XZ:R102[Zj/50:b/[0@0ZJVY2@2P
X:040;6a/@D0_[jn102k^k/40;Zj^PD0^k^k102b/[890;6a/@@0WIfM1@21PH4408^;R`D0UYJF102J
VYX409nOW`D0Xj>S102UYJD50:NWY`@0Z:RX102][Jd50:j^[PT0/K6a102d];@40;:b/PD0/;2`102d
];@50;Jf]Pd0b>3H1025QHD407UiN@D0OGem101oOgl507QhN0@0PX:2101bLW8508B4Q0@0M7Ad2@20
P80408F5Q@D0Ng]k1022PX8407YjNPD0QXJ6101nOWh507emO@@0O7al1020P80508:2PP@0MGEe1@2<
S8`408>3P`@0MgMg1@26QXH407emO@D0MGEe1022PX8408R8R0D0MgMg1028R8P507alO0@0Ph>3101k
Ng/50820P0T0OWin1020P80407inOPD0Ogmo101mOGd508B4Q0@0OWin1028R8P507MgM`@0MGEe1@21
PH4407YjNP@0PH612@1oOgl50820P0@0Ogmo1021PH450820P0@0PH612@1oOgl408>3P`D0Ogmo1022
PX8407inOPD0P8205P38h=P001D0b>3H1@0h>3P402PX:0@0=3@d1@0h>3P403hn?PD0=SHf101WIfL4
04i>CPD0@D51100a<C4502HV9P@0;Rh^100g=cL502@T90@0@D511@1>CTh402@T90@0@d=31@1IFET4
03/k>`@0:RXZ1@1JFUX404E5A@D0:BTY100V9RH402@T90D0CDe=1022PX85069RHP@0IFEU102LW9`5
0:f][@@0WinO1@2SXj<40::RXP@0WIfM1@2QXJ440:n_[`D0_[jn102l_;`40;Jf]PD0^KVi2@2^[Zh4
0;>c/`@0ZJVY1@2VYZH409bLW0D0Vi^K102RXZ890:BTY0T0Xj>S202WYjL50:f][@@0/K6a1@2^[Zh4
0;2`/0@0/K6a1@2b/[840:j^[PD0]kNg3@38h=P407YjNP@0PX:21@21PH4407QhN0D0PH61101lO7`4
092@T0D0IfMW1029RHT507]kN`@0QHF51023Ph<90820P0@0Ogmo1@1kNg/408:2PPD0OGem101iNGT4
07EeM@D0Ng]k1025QHD507QhN0@0OWin1023Ph<508:2PP@0P8201@2<S8`408F5Q@@0QhN71@22PX84
07emO@D0QHF5101oOgl40861P@D0OGem1023Ph<90861P@@0Ogmo2@22PX8508B4Q0@0OWin101kNg/5
08B4Q0@0Ph>31@1oOgl408>3P`@0Q8B41@1kNg/408:2PPD0OGem1023Ph<407alO0T0P8201@22PX88
0820P0D0Ogmo1020P80907moOaH0b>3H000E0<SPf0D0>3Ph100X:2P403@d=0D0>3Ph100n?Sh503Hf
=P@0IfMW101>CTh50451@@@0<C4a1@0V9RH402h^;P@0=cLg1@0T92@40451@@D0CTi>100T92@404=3
@`D0FEUI100k>c/402XZ:PD0FUYJ1015ADD502TY:@@09RHV100T92@504e=C@@0PX:21@1RHV8406EU
I@@0W9bL1@2][Jd409nOW`D0Xj>S102RXZ8409fMW@D0XJ6Q102_[jl50;jn_P@0_;bl102f][H50;Vi
^@T0[Zj^102c/k<40:VYZ@D0YZJV102LW9`509^KV`@0XZ:R2@2TY:@90:>SX`P0YjNW1@2][Jd40;6a
/@D0[Zj^102`/;040;6a/@D0/[:b102^[Zh50;Ng]`d0b>3H101jNWX408:2PPD0PH61101hN7P50861
P@@0O7al102@T90506MWI`@0RHV91@1kNg/408F5Q@@0Ph>32@20P80407moO`D0Ng]k1022PX8507em
O@@0NGUi101eMGD507]kN`@0QHF51@1hN7P407inOP@0Ph>31@22PX840820P0D0S8b<1025QHD408N7
Q`D0PX:2101mOGd508F5Q@@0Ogmo1021PH4507emO@@0Ph>32@21PH4407moO`T0PX:21@24Q8@407in
OP@0Ng]k1@24Q8@408>3P`D0Ogmo1023Ph<408B4Q0D0Ng]k1022PX8507emO@@0Ph>3101lO7`90820
P0D0PX:22020P80507moO`@0P8202@1oOglF0<SPf0005@38h=P503Ph>0@0:2PX100d=3@503Ph>0@0
?Shn1@0f=SH406MWI`@0CTi>1@11@D44034a<@D09RHV100^;Rh403Lg=`D092@T1011@D4504i>CP@0
92@T1013@d<505UIF@@0>c/k100Z:RX505YJFP@0ADE51@0Y:BT402HV9P@092@T1@1=CDd408:2PPD0
HV9R101UIFD409bLW0D0[Jf]102OWil50:>SX`@0XZ:R102MWId50:6QX@@0[jn_1@2n_[h40;bl_0@0
][Jf1@2i^KT90:j^[P@0/k>c102YZJT50:JVYP@0W9bL1@2KVi/40::RXPT0Y:BT2@2SXj<80:NWY`D0
[Jf]102a/K450:j^[P@0/;2`102a/K450;:b/P@0[Zj^1@2g]kL=0<SPf0@0NWYj1022PX850861P@@0
N7Qh1@21PH4407alO0@0T92@1@1WIfL408V9R@D0Ng]k1025QHD408>3P`T0P820101oOgl507]kN`@0
PX:21@1mOGd407UiN@@0MGEe1@1kNg/408F5Q@D0N7Qh101nOWh408>3P`D0PX:21020P80508b<S0@0
QHF51027QhL508:2PP@0OGem1@25QHD407moO`@0PH611@1mOGd408>3P`T0PH61101oOgl908:2PPD0
Q8B4101nOWh407]kN`D0Q8B41023Ph<507moO`@0Ph>31024Q8@507]kN`@0PX:21@1mOGd408>3P`@0
O7al2@20P80508:2PPP0P8201@1oOgl40820P0T0Ogmo5P38h=P001D0b>3H1@0h>3P402PX:0@0=3@d
1@0h>3P403hn?PD0=SHf101WIfL404i>CPD0@D51100a<C4502HV9P@0;Rh^100g=cL502@T90@0@D51
1@1>CTh402@T90@0@d=31@1IFET403/k>`@0:RXZ1@1JFUX404E5A@D0:BTY100V9RH402@T90D0CDe=
1022PX85069RHP@0IFEU102LW9`50:f][@@0WinO1@2SXj<40::RXP@0WIfM1@2QXJ440:n_[`D0_[jn
102l_;`40;Jf]PD0^KVi2@2^[Zh40;>c/`@0ZJVY1@2VYZH409bLW0D0Vi^K102RXZ890:BTY0T0Xj>S
202WYjL50:f][@@0/K6a1@2^[Zh40;2`/0@0/K6a1@2b/[840:j^[PD0]kNg3@38h=P407YjNP@0PX:2
1@21PH4407QhN0D0PH61101lO7`4092@T0D0IfMW1029RHT507]kN`@0QHF51023Ph<90820P0@0Ogmo
1@1kNg/408:2PPD0OGem101iNGT407EeM@D0Ng]k1025QHD507QhN0@0OWin1023Ph<508:2PP@0P820
1@2<S8`408F5Q@@0QhN71@22PX8407emO@D0QHF5101oOgl40861P@D0OGem1023Ph<90861P@@0Ogmo
2@22PX8508B4Q0@0OWin101kNg/508B4Q0@0Ph>31@1oOgl408>3P`@0Q8B41@1kNg/408:2PPD0OGem
1023Ph<407alO0T0P8201@22PX880820P0D0Ogmo1020P80907moOaH0b>3H000E0<SPf0D0BTY:100n
?Sh402d];@D0;bl_100V9RH502l_;`@0@410101PH60505YJFP@0=cLg1@0Y:BT402d];@@0>CTi1@0[
:b/4038b<PD0FUYJ100R8R8404A4A0D0?Cdm100_;bl903De=@@0OWin1@0/;2`4020P80@07alO1@0/
;2`406UYJ@D0T92@101hN7P4079bLPD0Y:BT102[Zj/509jNWPP0X:2P1@2TY:@40;6a/@D0_;bl102j
^[X90;Vi^@@0Z:RX1@2DU9@40;Ng]`@0];Bd1@2VYZH40:FUY@D0W9bL102KVi/40:2PX0D0Y:BT102O
Wil50:2PX0@0Y:BT102VYZH50:b/[0@0[Zj^1@2][Jd40:n_[`@0/[:b2@2d];@50;Zj^Pd0b>3H102<
S8`4071`L0D0MgMg101nOWh507emO@@0Q8B4101aLG4508Z:RP@0N7Qh1@21PH4408B4Q0@0QhN72@1n
OWh408B4Q0T0Ogmo1@1nOWh408>3P`@0QHF51@1jNWX407]kN`D0QHF51022PX8407alO0T0PH611@1i
NGT407AdM0@0PH611@20P80408J6QPD0OGem1020P80407moO`T0PX:22@1nOWh40820P0D0PX:2101l
O7`507YjNP@0Ng]k1023Ph<507alO0T0P8201021PH4407YjNPD0Ph>31020P80507inOP@0Ogmo1020
P80507inOP@0P8201@1mOGd80861P@D0PX:21021PH490820P1H0b>3H000E0<SPf0D0BTY:100n?Sh4
02d];@D0;bl_100V9RH502l_;`@0@410101PH60505YJFP@0=cLg1@0Y:BT402d];@@0>CTi1@0[:b/4
038b<PD0FUYJ100R8R8404A4A0D0?Cdm100_;bl903De=@@0OWin1@0/;2`4020P80@07alO1@0/;2`4
06UYJ@D0T92@101hN7P4079bLPD0Y:BT102[Zj/509jNWPP0X:2P1@2TY:@40;6a/@D0_;bl102j^[X9
0;Vi^@@0Z:RX1@2DU9@40;Ng]`@0];Bd1@2VYZH40:FUY@D0W9bL102KVi/40:2PX0D0Y:BT102OWil5
0:2PX0@0Y:BT102VYZH50:b/[0@0[Zj^1@2][Jd40:n_[`@0/[:b2@2d];@50;Zj^Pd0b>3H102<S8`4
071`L0D0MgMg101nOWh507emO@@0Q8B4101aLG4508Z:RP@0N7Qh1@21PH4408B4Q0@0QhN72@1nOWh4
08B4Q0T0Ogmo1@1nOWh408>3P`@0QHF51@1jNWX407]kN`D0QHF51022PX8407alO0T0PH611@1iNGT4
07AdM0@0PH611@20P80408J6QPD0OGem1020P80407moO`T0PX:22@1nOWh40820P0D0PX:2101lO7`5
07YjNP@0Ng]k1023Ph<507alO0T0P8201021PH4407YjNPD0Ph>31020P80507inOP@0Ogmo1020P805
07inOP@0P8201@1mOGd80861P@D0PX:21021PH490820P1H0b>3H000E0<SPf0D0BTY:100n?Sh402d]
;@D0;bl_100V9RH502l_;`@0@410101PH60505YJFP@0=cLg1@0Y:BT402d];@@0>CTi1@0[:b/4038b
<PD0FUYJ100R8R8404A4A0D0?Cdm100_;bl903De=@@0OWin1@0/;2`4020P80@07alO1@0/;2`406UY
J@D0T92@101hN7P4079bLPD0Y:BT102[Zj/509jNWPP0X:2P1@2TY:@40;6a/@D0_;bl102j^[X90;Vi
^@@0Z:RX1@2DU9@40;Ng]`@0];Bd1@2VYZH40:FUY@D0W9bL102KVi/40:2PX0D0Y:BT102OWil50:2P
X0@0Y:BT102VYZH50:b/[0@0[Zj^1@2][Jd40:n_[`@0/[:b2@2d];@50;Zj^Pd0b>3H102<S8`4071`
L0D0MgMg101nOWh507emO@@0Q8B4101aLG4508Z:RP@0N7Qh1@21PH4408B4Q0@0QhN72@1nOWh408B4
Q0T0Ogmo1@1nOWh408>3P`@0QHF51@1jNWX407]kN`D0QHF51022PX8407alO0T0PH611@1iNGT407Ad
M0@0PH611@20P80408J6QPD0OGem1020P80407moO`T0PX:22@1nOWh40820P0D0PX:2101lO7`507Yj
NP@0Ng]k1023Ph<507alO0T0P8201021PH4407YjNPD0Ph>31020P80507inOP@0Ogmo1020P80507in
OP@0P8201@1mOGd80861P@D0PX:21021PH490820P1H0b>3H000E0<SPf0D0BTY:100n?Sh402d];@D0
;bl_100V9RH502l_;`@0@410101PH60505YJFP@0=cLg1@0Y:BT402d];@@0>CTi1@0[:b/4038b<PD0
FUYJ100R8R8404A4A0D0?Cdm100_;bl903De=@@0OWin1@0/;2`4020P80@07alO1@0/;2`406UYJ@D0
T92@101hN7P4079bLPD0Y:BT102[Zj/509jNWPP0X:2P1@2TY:@40;6a/@D0_;bl102j^[X90;Vi^@@0
Z:RX1@2DU9@40;Ng]`@0];Bd1@2VYZH40:FUY@D0W9bL102KVi/40:2PX0D0Y:BT102OWil50:2PX0@0
Y:BT102VYZH50:b/[0@0[Zj^1@2][Jd40:n_[`@0/[:b2@2d];@50;Zj^Pd0b>3H102<S8`4071`L0D0
MgMg101nOWh507emO@@0Q8B4101aLG4508Z:RP@0N7Qh1@21PH4408B4Q0@0QhN72@1nOWh408B4Q0T0
Ogmo1@1nOWh408>3P`@0QHF51@1jNWX407]kN`D0QHF51022PX8407alO0T0PH611@1iNGT407AdM0@0
PH611@20P80408J6QPD0OGem1020P80407moO`T0PX:22@1nOWh40820P0D0PX:2101lO7`507YjNP@0
Ng]k1023Ph<507alO0T0P8201021PH4407YjNPD0Ph>31020P80507inOP@0Ogmo1020P80507inOP@0
P8201@1mOGd80861P@D0PX:21021PH490820P1H0b>3H000E0<SPf0D0BTY:100n?Sh402d];@D0;bl_
100V9RH502l_;`@0@410101PH60505YJFP@0=cLg1@0Y:BT402d];@@0>CTi1@0[:b/4038b<PD0FUYJ
100R8R8404A4A0D0?Cdm100_;bl903De=@@0OWin1@0/;2`4020P80@07alO1@0/;2`406UYJ@D0T92@
101hN7P4079bLPD0Y:BT102[Zj/509jNWPP0X:2P1@2TY:@40;6a/@D0_;bl102j^[X90;Vi^@@0Z:RX
1@2DU9@40;Ng]`@0];Bd1@2VYZH40:FUY@D0W9bL102KVi/40:2PX0D0Y:BT102OWil50:2PX0@0Y:BT
102VYZH50:b/[0@0[Zj^1@2][Jd40:n_[`@0/[:b2@2d];@50;Zj^Pd0b>3H102<S8`4071`L0D0MgMg
101nOWh507emO@@0Q8B4101aLG4508Z:RP@0N7Qh1@21PH4408B4Q0@0QhN72@1nOWh408B4Q0T0Ogmo
1@1nOWh408>3P`@0QHF51@1jNWX407]kN`D0QHF51022PX8407alO0T0PH611@1iNGT407AdM0@0PH61
1@20P80408J6QPD0OGem1020P80407moO`T0PX:22@1nOWh40820P0D0PX:2101lO7`507YjNP@0Ng]k
1023Ph<507alO0T0P8201021PH4407YjNPD0Ph>31020P80507inOP@0Ogmo1020P80507inOP@0P820
1@1mOGd80861P@D0PX:21021PH490820P1H0b>3H000E0<SPf0D09bLW1011@D4402`/;0D0;Bd]100X
:2P504a<C0@0@d=3100[:b/5059BDP@0AdM71@0/;2`4034a<@@0=CDe1@0_;bl402XZ:PD0EEEE100`
<304051@D0D0;Rh^100[:b/4038b<PD0>c/k101JFUX502DU9@@08b<S100P820505=CD`@0JVYZ1@1d
M7@409^KV`@0M7Ad1@1hN7P40:BTY0D0YJFU102QXJ440:>SX`D0ZZZZ102f][H50;^k^`@0^;Rh102k
^k/50;2`/0@0Ti>C1@24Q8@40;:b/P@0`<301@2f][H40:JVYPD0WinO102IVIT409ZJVPD0Vi^K102J
VYX50:2PX0@0XJ6Q102UYJD50:ZZZPT0Zj^[102`/;040;6a/@D0/k>c102d];@50;^k^`d0b>3H101o
Ogl408:2PPD0Ogmo1020P80508J6QP@0N7Qh1024Q8@507]kN`@0QHF51@26QXH408:2PP@0MGEe1@24
Q8@407inOP@0Ogmo1@1nOWh407alO0D0Ogmo101kNg/40820P0D0QhN7101oOgl508>3P`@0Ogmo1020
P80507inOP@0Ogmo1@22PX840820P0@0OWin1@25QHD907moO`@0P8204P1oOgl408:2PP@0Ogmo2@20
P80907moO`@0PX:21@1oOgl90820P0@0PH611022PX8507IfMP@0PH611@1oOgl40820P0@0PX:22@1o
Ogl507emO@@0P820101nOWh50820P0@0Ph>31022PX850861PAH0b>3H000E0<SPf0D09bLW1011@D44
02`/;0D0;Bd]100X:2P504a<C0@0@d=3100[:b/5059BDP@0AdM71@0/;2`4034a<@@0=CDe1@0_;bl4
02XZ:PD0EEEE100`<304051@D0D0;Rh^100[:b/4038b<PD0>c/k101JFUX502DU9@@08b<S100P8205
05=CD`@0JVYZ1@1dM7@409^KV`@0M7Ad1@1hN7P40:BTY0D0YJFU102QXJ440:>SX`D0ZZZZ102f][H5
0;^k^`@0^;Rh102k^k/50;2`/0@0Ti>C1@24Q8@40;:b/P@0`<301@2f][H40:JVYPD0WinO102IVIT4
09ZJVPD0Vi^K102JVYX50:2PX0@0XJ6Q102UYJD50:ZZZPT0Zj^[102`/;040;6a/@D0/k>c102d];@5
0;^k^`d0b>3H101oOgl408:2PPD0Ogmo1020P80508J6QP@0N7Qh1024Q8@507]kN`@0QHF51@26QXH4
08:2PP@0MGEe1@24Q8@407inOP@0Ogmo1@1nOWh407alO0D0Ogmo101kNg/40820P0D0QhN7101oOgl5
08>3P`@0Ogmo1020P80507inOP@0Ogmo1@22PX840820P0@0OWin1@25QHD907moO`@0P8204P1oOgl4
08:2PP@0Ogmo2@20P80907moO`@0PX:21@1oOgl90820P0@0PH611022PX8507IfMP@0PH611@1oOgl4
0820P0@0PX:22@1oOgl507emO@@0P820101nOWh50820P0@0Ph>31022PX850861PAH0b>3H000E0<SP
f0D09bLW1011@D4402`/;0D0;Bd]100X:2P504a<C0@0@d=3100[:b/5059BDP@0AdM71@0/;2`4034a
<@@0=CDe1@0_;bl402XZ:PD0EEEE100`<304051@D0D0;Rh^100[:b/4038b<PD0>c/k101JFUX502DU
9@@08b<S100P820505=CD`@0JVYZ1@1dM7@409^KV`@0M7Ad1@1hN7P40:BTY0D0YJFU102QXJ440:>S
X`D0ZZZZ102f][H50;^k^`@0^;Rh102k^k/50;2`/0@0Ti>C1@24Q8@40;:b/P@0`<301@2f][H40:JV
YPD0WinO102IVIT409ZJVPD0Vi^K102JVYX50:2PX0@0XJ6Q102UYJD50:ZZZPT0Zj^[102`/;040;6a
/@D0/k>c102d];@50;^k^`d0b>3H101oOgl408:2PPD0Ogmo1020P80508J6QP@0N7Qh1024Q8@507]k
N`@0QHF51@26QXH408:2PP@0MGEe1@24Q8@407inOP@0Ogmo1@1nOWh407alO0D0Ogmo101kNg/40820
P0D0QhN7101oOgl508>3P`@0Ogmo1020P80507inOP@0Ogmo1@22PX840820P0@0OWin1@25QHD907mo
O`@0P8204P1oOgl408:2PP@0Ogmo2@20P80907moO`@0PX:21@1oOgl90820P0@0PH611022PX8507If
MP@0PH611@1oOgl40820P0@0PX:22@1oOgl507emO@@0P820101nOWh50820P0@0Ph>31022PX850861
PAH0b>3H000E0<SPf0D09bLW1011@D4402`/;0D0;Bd]100X:2P504a<C0@0@d=3100[:b/5059BDP@0
AdM71@0/;2`4034a<@@0=CDe1@0_;bl402XZ:PD0EEEE100`<304051@D0D0;Rh^100[:b/4038b<PD0
>c/k101JFUX502DU9@@08b<S100P820505=CD`@0JVYZ1@1dM7@409^KV`@0M7Ad1@1hN7P40:BTY0D0
YJFU102QXJ440:>SX`D0ZZZZ102f][H50;^k^`@0^;Rh102k^k/50;2`/0@0Ti>C1@24Q8@40;:b/P@0
`<301@2f][H40:JVYPD0WinO102IVIT409ZJVPD0Vi^K102JVYX50:2PX0@0XJ6Q102UYJD50:ZZZPT0
Zj^[102`/;040;6a/@D0/k>c102d];@50;^k^`d0b>3H101oOgl408:2PPD0Ogmo1020P80508J6QP@0
N7Qh1024Q8@507]kN`@0QHF51@26QXH408:2PP@0MGEe1@24Q8@407inOP@0Ogmo1@1nOWh407alO0D0
Ogmo101kNg/40820P0D0QhN7101oOgl508>3P`@0Ogmo1020P80507inOP@0Ogmo1@22PX840820P0@0
OWin1@25QHD907moO`@0P8204P1oOgl408:2PP@0Ogmo2@20P80907moO`@0PX:21@1oOgl90820P0@0
PH611022PX8507IfMP@0PH611@1oOgl40820P0@0PX:22@1oOgl507emO@@0P820101nOWh50820P0@0
Ph>31022PX850861PAH0b>3H000E0<SPf0D09RHV200[:b/502XZ:P@0BDU91@1LG5`402l_;`@0<C4a
1@0i>CT405=CD`D0=3@d100_;bl403Ti>@D0<C4a100[:b/504U9B@@0>3Ph100g=cL502d];@@0>CTi
101<C4`5038b<P@0DU9B1@0/;2`402<S8`@09RHV1@22PX8404M7A`D0<S8b1027QhL408f=S@D0MgMg
1022PX850:VYZ@@0XZ:R102XZ:P50:n_[`@0/K6a1@30`<040;Rh^0@0^[Zj1@2WYjL408n?S`D0S8b<
102`/;040;Rh^0D0`l?3102f][H50:RXZ0P0WinO1@2QXJ4409VIV@D0WIfM102RXZ840:2PX0D0ZJVY
102[Zj/90:f][@T0/;2`102h^;P50;^k^`d0b>3H101jNWX407alO0D0Ogmo1023Ph<507moO`@0OGem
2@20P804071`L0D0PH61101nOWh408>3P`D0Ng]k101jNWX408>3P`D0PX:2101nOWh507emO@@0OWin
101lO7`507]kN`@0PH611@1gMgL408V9R@@0QhN71@2<S8`407emO@D0Q8B41021PH4408>3P`D0NWYj
1027QhL508>3P`@0P820101mOGd508>3P`T0P820201mOGd507inOP@0P8201@23Ph<408:2PP@0Ogmo
2@20P80507inOP@0P820101nOWh508>3P`@0NGUi1@23Ph<807moO`D0PH611020P80507moO`@0P820
1021PH4508:2PP@0PH61101lO7`507moOaH0b>3H000E0<SPf0D09RHV200[:b/502XZ:P@0BDU91@1L
G5`402l_;`@0<C4a1@0i>CT405=CD`D0=3@d100_;bl403Ti>@D0<C4a100[:b/504U9B@@0>3Ph100g
=cL502d];@@0>CTi101<C4`5038b<P@0DU9B1@0/;2`402<S8`@09RHV1@22PX8404M7A`D0<S8b1027
QhL408f=S@D0MgMg1022PX850:VYZ@@0XZ:R102XZ:P50:n_[`@0/K6a1@30`<040;Rh^0@0^[Zj1@2W
YjL408n?S`D0S8b<102`/;040;Rh^0D0`l?3102f][H50:RXZ0P0WinO1@2QXJ4409VIV@D0WIfM102R
XZ840:2PX0D0ZJVY102[Zj/90:f][@T0/;2`102h^;P50;^k^`d0b>3H101jNWX407alO0D0Ogmo1023
Ph<507moO`@0OGem2@20P804071`L0D0PH61101nOWh408>3P`D0Ng]k101jNWX408>3P`D0PX:2101n
OWh507emO@@0OWin101lO7`507]kN`@0PH611@1gMgL408V9R@@0QhN71@2<S8`407emO@D0Q8B41021
PH4408>3P`D0NWYj1027QhL508>3P`@0P820101mOGd508>3P`T0P820201mOGd507inOP@0P8201@23
Ph<408:2PP@0Ogmo2@20P80507inOP@0P820101nOWh508>3P`@0NGUi1@23Ph<807moO`D0PH611020
P80507moO`@0P8201021PH4508:2PP@0PH61101lO7`507moOaH0b>3H000E0<SPf0D09RHV200[:b/5
02XZ:P@0BDU91@1LG5`402l_;`@0<C4a1@0i>CT405=CD`D0=3@d100_;bl403Ti>@D0<C4a100[:b/5
04U9B@@0>3Ph100g=cL502d];@@0>CTi101<C4`5038b<P@0DU9B1@0/;2`402<S8`@09RHV1@22PX84
04M7A`D0<S8b1027QhL408f=S@D0MgMg1022PX850:VYZ@@0XZ:R102XZ:P50:n_[`@0/K6a1@30`<04
0;Rh^0@0^[Zj1@2WYjL408n?S`D0S8b<102`/;040;Rh^0D0`l?3102f][H50:RXZ0P0WinO1@2QXJ44
09VIV@D0WIfM102RXZ840:2PX0D0ZJVY102[Zj/90:f][@T0/;2`102h^;P50;^k^`d0b>3H101jNWX4
07alO0D0Ogmo1023Ph<507moO`@0OGem2@20P804071`L0D0PH61101nOWh408>3P`D0Ng]k101jNWX4
08>3P`D0PX:2101nOWh507emO@@0OWin101lO7`507]kN`@0PH611@1gMgL408V9R@@0QhN71@2<S8`4
07emO@D0Q8B41021PH4408>3P`D0NWYj1027QhL508>3P`@0P820101mOGd508>3P`T0P820201mOGd5
07inOP@0P8201@23Ph<408:2PP@0Ogmo2@20P80507inOP@0P820101nOWh508>3P`@0NGUi1@23Ph<8
07moO`D0PH611020P80507moO`@0P8201021PH4508:2PP@0PH61101lO7`507moOaH0b>3H000E0<SP
f0D09RHV200[:b/502XZ:P@0BDU91@1LG5`402l_;`@0<C4a1@0i>CT405=CD`D0=3@d100_;bl403Ti
>@D0<C4a100[:b/504U9B@@0>3Ph100g=cL502d];@@0>CTi101<C4`5038b<P@0DU9B1@0/;2`402<S
8`@09RHV1@22PX8404M7A`D0<S8b1027QhL408f=S@D0MgMg1022PX850:VYZ@@0XZ:R102XZ:P50:n_
[`@0/K6a1@30`<040;Rh^0@0^[Zj1@2WYjL408n?S`D0S8b<102`/;040;Rh^0D0`l?3102f][H50:RX
Z0P0WinO1@2QXJ4409VIV@D0WIfM102RXZ840:2PX0D0ZJVY102[Zj/90:f][@T0/;2`102h^;P50;^k
^`d0b>3H101jNWX407alO0D0Ogmo1023Ph<507moO`@0OGem2@20P804071`L0D0PH61101nOWh408>3
P`D0Ng]k101jNWX408>3P`D0PX:2101nOWh507emO@@0OWin101lO7`507]kN`@0PH611@1gMgL408V9
R@@0QhN71@2<S8`407emO@D0Q8B41021PH4408>3P`D0NWYj1027QhL508>3P`@0P820101mOGd508>3
P`T0P820201mOGd507inOP@0P8201@23Ph<408:2PP@0Ogmo2@20P80507inOP@0P820101nOWh508>3
P`@0NGUi1@23Ph<807moO`D0PH611020P80507moO`@0P8201021PH4508:2PP@0PH61101lO7`507mo
OaH0b>3H000E0<SPf0D09RHV200[:b/502XZ:P@0BDU91@1LG5`402l_;`@0<C4a1@0i>CT405=CD`D0
=3@d100_;bl403Ti>@D0<C4a100[:b/504U9B@@0>3Ph100g=cL502d];@@0>CTi101<C4`5038b<P@0
DU9B1@0/;2`402<S8`@09RHV1@22PX8404M7A`D0<S8b1027QhL408f=S@D0MgMg1022PX850:VYZ@@0
XZ:R102XZ:P50:n_[`@0/K6a1@30`<040;Rh^0@0^[Zj1@2WYjL408n?S`D0S8b<102`/;040;Rh^0D0
`l?3102f][H50:RXZ0P0WinO1@2QXJ4409VIV@D0WIfM102RXZ840:2PX0D0ZJVY102[Zj/90:f][@T0
/;2`102h^;P50;^k^`d0b>3H101jNWX407alO0D0Ogmo1023Ph<507moO`@0OGem2@20P804071`L0D0
PH61101nOWh408>3P`D0Ng]k101jNWX408>3P`D0PX:2101nOWh507emO@@0OWin101lO7`507]kN`@0
PH611@1gMgL408V9R@@0QhN71@2<S8`407emO@D0Q8B41021PH4408>3P`D0NWYj1027QhL508>3P`@0
P820101mOGd508>3P`T0P820201mOGd507inOP@0P8201@23Ph<408:2PP@0Ogmo2@20P80507inOP@0
P820101nOWh508>3P`@0NGUi1@23Ph<807moO`D0PH611020P80507moO`@0P8201021PH4508:2PP@0
PH61101lO7`507moOaH0b>3H000E0<SPf0D09bLW100X:2P402XZ:PD0;Rh^101PH60503`l?0@0B4Q8
100h>3P502h^;P@0>c/k1@0g=cL402h^;P@0>3Ph1@0g=cL4038b<PD0>SXj1016ATH403De=@D09BDU
1013@d<405YJFPD0DU9B1015ADD504U9B@@0=CDe101JFUX508N7Q`@0:RXZ1@0Q8B4404=3@`@0T92@
1@29RHT407=cL`D0QHF5102b/[840:ZZZPD0ZJVY102f][H50;^k^`@0^;Rh102`/;050:b/[0@0TY:B
1@2GUiL40:BTY0@0[Zj^1@32`/840<?3``D0[jn_202TY:@50:>SX`@0XZ:R1@2DU9@409bLW0@0WIfM
1@2SXj<40:JVYPD0Zj^[102/[:`40:f][@D0]KFe102h^;P50;jn_Pd0b>3H101oOgl407inOPD0P820
101lO7`90820P0@0RHV91@1lO7`408J6QPD0P820101iNGT40861P@D0Ogmo101nOWh907emO@@0PH61
1@1oOgl408R8R0@0OGem1@1gMgL407moO`D0RHV9101cLg<406QXJ0D0IVIV1023Ph<508J6QP@0OGem
1022PX850861P@T0OWin1021PH4407emO@D0PX:21020P80508:2PP@0PH61101kNg/508:2PP@0Ogmo
3@21PH4508>3P`@0P8201@1oOgl40861P@T0Ogmo1023Ph<50861P@@0Ph>3101oOgl507inOP@0PX:2
1@21PH4407inOP@0Q8B41@1lO7`407moO`@0PH611@22PX8F0<SPf0005@38h=P502LW9`@0:2PX100Z
:RX502h^;P@0H61P1@0l?3`404Q8B0@0>3Ph1@0^;Rh403/k>`D0=cLg100^;Rh403Ph>0D0=cLg100b
<S8503Xj>P@0ATI6100e=CD502DU9@@0@d=3101JFUX5059BDP@0ADE51@19BDT403De=@@0FUYJ1@27
QhL402XZ:PD08B4Q1013@d<4092@T0D0RHV9101cLg<508F5Q@@0/[:b102ZZZX50:VYZ@@0][Jf1@2k
^k/40;Rh^0@0/;2`1@2/[:`409:BTPD0UiNG102TY:@40:j^[PD0`/;21033`l<50:n_[`P0Y:BT1@2S
Xj<40::RXPD0U9BD102LW9`409fMW@D0Xj>S102VYZH50:^[Z`@0[:b/102][Jd50;Fe]@@0^;Rh1@2n
_[h=0<SPf0@0Ogmo101nOWh50820P0@0O7al2@20P80408V9R@D0O7al1026QXH50820P0@0NGUi1021
PH4507moO`@0OWin2@1mOGd40861P@D0Ogmo1028R8P407emO@D0MgMg101oOgl508V9R@@0Lg=c101X
J6P506IVIP@0Ph>31@26QXH407emO@@0PX:21@21PH4907inOP@0PH61101mOGd508:2PP@0P8201@22
PX840861P@@0Ng]k1@22PX8407moO`d0PH611@23Ph<40820P0D0Ogmo1021PH4907moO`@0Ph>31@21
PH4408>3P`@0Ogmo1@1nOWh408:2PPD0PH61101nOWh408B4Q0D0O7al101oOgl40861P@D0PX:25P38
h=P001D0b>3H1@0W9bL402PX:0@0:RXZ1@0^;Rh4061PH0D0?3`l1018B4P403Ph>0D0;Rh^100k>c/5
03Lg=`@0;Rh^100h>3P503Lg=`@0<S8b1@0j>SX404I6AP@0=CDe1@0U9BD404=3@`@0FUYJ1@1BDU84
04E5A@D0BDU9100e=CD405YJFPD0QhN7100Z:RX5024Q8@@0@d=3102@T90508V9R@@0Lg=c1@25QHD4
0;:b/P@0ZZZZ1@2YZJT40;Jf]PD0^k^k102h^;P40;2`/0D0[:b/102BTY8509NGU`@0Y:BT102^[Zh5
0<;2`P@0`l?31@2_[jl80:BTY0D0Xj>S102RXZ8509BDU0@0W9bL102MWId50:>SX`@0YZJV1@2[Zj/4
0:b/[0@0[Jf]1@2e]KD40;Rh^0D0_[jn3@38h=P407moO`@0OWin1@20P80407alO0T0P8201029RHT5
07alO0@0QXJ61@20P80407UiN@@0PH611@1oOgl407inOPT0OGem1021PH4507moO`@0R8R8101mOGd5
07MgM`@0Ogmo1@29RHT407=cL`@0J6QX1@1VIVH408>3P`D0QXJ6101mOGd408:2PPD0PH612@1nOWh4
0861P@@0OGem1@22PX840820P0D0PX:21021PH4407]kN`D0PX:2101oOgl=0861P@D0Ph>31020P805
07moO`@0PH612@1oOgl408>3P`D0PH611023Ph<407moO`D0OWin1022PX850861P@@0OWin1024Q8@5
07alO0@0Ogmo1021PH4508:2PQH0b>3H000E0<SPf0D09bLW100X:2P402XZ:PD0;Rh^101PH60503`l
?0@0B4Q8100h>3P502h^;P@0>c/k1@0g=cL402h^;P@0>3Ph1@0g=cL4038b<PD0>SXj1016ATH403De
=@D09BDU1013@d<405YJFPD0DU9B1015ADD504U9B@@0=CDe101JFUX508N7Q`@0:RXZ1@0Q8B4404=3
@`@0T92@1@29RHT407=cL`D0QHF5102b/[840:ZZZPD0ZJVY102f][H50;^k^`@0^;Rh102`/;050:b/
[0@0TY:B1@2GUiL40:BTY0@0[Zj^1@32`/840<?3``D0[jn_202TY:@50:>SX`@0XZ:R1@2DU9@409bL
W0@0WIfM1@2SXj<40:JVYPD0Zj^[102/[:`40:f][@D0]KFe102h^;P50;jn_Pd0b>3H101oOgl407in
OPD0P820101lO7`90820P0@0RHV91@1lO7`408J6QPD0P820101iNGT40861P@D0Ogmo101nOWh907em
O@@0PH611@1oOgl408R8R0@0OGem1@1gMgL407moO`D0RHV9101cLg<406QXJ0D0IVIV1023Ph<508J6
QP@0OGem1022PX850861P@T0OWin1021PH4407emO@D0PX:21020P80508:2PP@0PH61101kNg/508:2
PP@0Ogmo3@21PH4508>3P`@0P8201@1oOgl40861P@T0Ogmo1023Ph<50861P@@0Ph>3101oOgl507in
OP@0PX:21@21PH4407inOP@0Q8B41@1lO7`407moO`@0PH611@22PX8F0<SPf0005@38h=P502h^;P@0
9RHV100/;2`5038b<P@0Hf=S1@0X:2P402`/;0@0=cLg1@0m?Cd4038b<PD0@T92100/;2`4038b<PD0
>SXj100b<S8502l_;`@0?Shn100d=3@502l_;`@0BDU9101@D50505MGE`T0GEeM101;Bd/406e]K@D0
S8b<100e=CD501lO7`@08B4Q101ADE4509JFUP@0Q8B41@1fMWH408n?S`@0^k^k1@2WYjL40;Bd]0D0
][Jf102a/K490:n_[`@0SXj>1@2PX:040:BTY0@0/;2`1@2o_kl40<G5a@D0_Kfm102WYjL40:ZZZPD0
Z:RX102RXZ850:6QX@@0UIFE102IVIT509nOW`@0XJ6Q2@2YZJT40:ZZZPD0];Bd102j^[X50;no_`d0
b>3H101hN7P408:2PPD0OGem101lO7`508F5Q@@0Ogmo2@20P80407IfMPD0PH61101hN7P40820P0D0
QHF51024Q8@408:2PPD0Ph>3101mOGd507alO0@0OWin2@27QhL407MgM`D0Ng]k1026QXH408b<S0T0
RHV91@28R8P408:2PP@0OWin1@26QXH407]kN`D0PX:2101nOWh408N7Q`D0NWYj1025QHD507emO@@0
OWin1020P80508B4Q0@0Ogmo2@21PH4408F5Q@D0Ng]k101mOGd508F5Q@@0OWin101oOgl508>3P`@0
PH611@1nOWh408:2PP@0Ph>31@21PH4407]kN`D0P8201021PH4408:2PPT0OGem101oOgl507inOQH0
b>3H000E0<SPf0D0;Rh^100V9RH402`/;0D0<S8b101SHf<502PX:0@0;2`/100g=cL503dm?@@0<S8b
1@12@T8402`/;0@0<S8b1@0j>SX4038b<PD0;bl_100n?Sh403@d=0D0;bl_1019BDT4051@D0D0EeMG
2@1MGEd404];B`@0KFe]1@2<S8`403De=@D07alO100Q8B44055AD@D0UYJF1024Q8@507IfMP@0Shn?
102k^k/50:NWY`@0];Bd1@2f][H40;6a/@T0[jn_102>SXh50:2PX0@0Y:BT102`/;050;no_`@0aLG5
1@2m_Kd40:NWY`@0ZZZZ1@2XZ:P40::RXPD0XJ6Q102EUID409VIV@D0WinO102QXJ490:VYZ@@0ZZZZ
1@2d];@40;Zj^PD0_kno3@38h=P407QhN0@0PX:21@1mOGd407alO0D0QHF5101oOgl90820P0@0MWIf
1@21PH4407QhN0@0P8201@25QHD408B4Q0@0PX:21@23Ph<407emO@D0O7al101nOWh908N7Q`@0MgMg
1@1kNg/408J6QP@0S8b<2@29RHT508R8R0@0PX:2101nOWh508J6QP@0Ng]k1@22PX8407inOP@0QhN7
1@1jNWX408F5Q@D0OGem101nOWh40820P0D0Q8B4101oOgl90861P@@0QHF51@1kNg/407emO@D0QHF5
101nOWh407moO`D0Ph>31021PH4507inOP@0PX:21023Ph<50861P@@0Ng]k1@20P8040861P@@0PX:2
2@1mOGd407moO`D0OWin5P38h=P001D0b>3H1@0^;Rh402HV9P@0;2`/1@0b<S8406=SH`D0:2PX100/
;2`403Lg=`D0?Cdm100b<S850492@P@0;2`/100b<S8503Xj>P@0<S8b1@0_;bl403hn?P@0=3@d1@0_
;bl404U9B@@0D51@1@1GEeL905eMG@@0Bd];101]KFd508b<S0@0=CDe1@0O7al4024Q8@@0DE5A1@2F
UYH408B4Q0D0MWIf102?Shl40;^k^`D0YjNW102d];@50;Jf]P@0/K6a2@2_[jl408j>SPD0X:2P102T
Y:@40;2`/0D0_kno1035aLD50;fm_@@0YjNW102ZZZX50:RXZ0@0XZ:R1@2QXJ4409FEU@@0VIVI1@2O
Wil40:6QX@T0ZJVY102ZZZX50;Bd]0@0^[Zj1@2o_kl=0<SPf0@0N7Qh1022PX8507emO@@0O7al1@25
QHD407moO`T0P820101fMWH50861P@@0N7Qh1020P80508F5Q@@0Q8B41022PX8508>3P`@0OGem1@1l
O7`407inOPT0QhN7101gMgL507]kN`@0QXJ6102<S8`908V9R@D0R8R81022PX8407inOPD0QXJ6101k
Ng/508:2PP@0OWin1027QhL507YjNP@0QHF51@1mOGd407inOP@0P8201@24Q8@407moO`T0PH611025
QHD507]kN`@0OGem1@25QHD407inOP@0Ogmo1@23Ph<40861P@D0OWin1022PX8408>3P`D0PH61101k
Ng/50820P0@0PH611022PX8907emO@@0Ogmo1@1nOWhF0<SPf0005@38h=P502h^;P@09RHV100/;2`5
038b<P@0Hf=S1@0X:2P402`/;0@0=cLg1@0m?Cd4038b<PD0@T92100/;2`4038b<PD0>SXj100b<S85
02l_;`@0?Shn100d=3@502l_;`@0BDU9101@D50505MGE`T0GEeM101;Bd/406e]K@D0S8b<100e=CD5
01lO7`@08B4Q101ADE4509JFUP@0Q8B41@1fMWH408n?S`@0^k^k1@2WYjL40;Bd]0D0][Jf102a/K49
0:n_[`@0SXj>1@2PX:040:BTY0@0/;2`1@2o_kl40<G5a@D0_Kfm102WYjL40:ZZZPD0Z:RX102RXZ85
0:6QX@@0UIFE102IVIT509nOW`@0XJ6Q2@2YZJT40:ZZZPD0];Bd102j^[X50;no_`d0b>3H101hN7P4
08:2PPD0OGem101lO7`508F5Q@@0Ogmo2@20P80407IfMPD0PH61101hN7P40820P0D0QHF51024Q8@4
08:2PPD0Ph>3101mOGd507alO0@0OWin2@27QhL407MgM`D0Ng]k1026QXH408b<S0T0RHV91@28R8P4
08:2PP@0OWin1@26QXH407]kN`D0PX:2101nOWh408N7Q`D0NWYj1025QHD507emO@@0OWin1020P805
08B4Q0@0Ogmo2@21PH4408F5Q@D0Ng]k101mOGd508F5Q@@0OWin101oOgl508>3P`@0PH611@1nOWh4
08:2PP@0Ph>31@21PH4407]kN`D0P8201021PH4408:2PPT0OGem101oOgl507inOQH0b>3H000E0<SP
f0D0<30`100Z:RX402d];@D0@410101WIfL502XZ:P@0;Bd]100`<30504Y:BP@0=SHf1@0g=cL8038b
<PD0=SHf100j>SX502XZ:P@0>3Ph100m?Cd503Hf=P@0<S8b101LG5`506i^KP@0Lg=c1@0k>c/402d]
;@@0IfMW1@1JFUX401lO7`D08R8R100S8b<402HV9PD0G5aL102OWil508B4Q0@0MgMg102HV9P50;Jf
]P@0ZJVY1@2d];@40:VYZ@@0YJFU1@2VYZH408Z:RPD0YZJV102][Jd40:j^[PD0]kNg1030`<050;^k
^`@0[:b/102ZZZX50:RXZ0@0Zj^[1@2WYjL40:FUY@@0UiNG1@2EUID409jNWPD0YZJV102XZ:P40:^[
Z`D0/[:b102i^KT50;jn_Pd0b>3H1025QHD408j>SPD0PX:2101oOgl507inOP@0NWYj101mOGd508>3
P`@0QHF51@20P80408B4Q0@0OWin1@1jNWX407emO@@0Ng]k1@22PX840861P@D0Ogmo1022PX8907mo
O`@0MGEe1@23Ph<407emO@@0OWin2@1mOGd50820P0@0PX:2101mOGd507QhN0@0SHf=1@1kNg/40820
P0@0OWin1@20P80407EeM@D0QXJ63@20P80407]kN`T0Ogmo101lO7`507inOP@0PX:21@1nOWh407em
O@T0Ogmo101nOWh50861P@@0OWin101mOGd507inOP@0Ph>31@1lO7`407inOP@0PH611@20P8040861
P@@0OWin1@20P80F0<SPf0005@38h=P5030`<0@0:RXZ100];Bd50410@0@0IfMW1@0Z:RX402d];@@0
<30`1@1:BTX403Hf=PD0=cLg200b<S8503Hf=P@0>SXj1@0Z:RX403Ph>0@0?Cdm1@0f=SH4038b<P@0
G5aL1@1^KVh407=cL`D0>c/k100];Bd406MWI`D0FUYJ100O7al5028R8P@08b<S100V9RH505aLG0@0
WinO1@24Q8@407MgM`@0V9RH1@2f][H40:VYZ@D0];Bd102YZJT40:FUY@D0YZJV102:RXX50:JVYP@0
[Jf]102^[Zh50;Ng]`@0`<301@2k^k/40:b/[0@0ZZZZ1@2XZ:P40:^[Z`D0YjNW102UYJD409NGU`D0
UIFE102NWYh50:JVYP@0Z:RX102[Zj/50;:b/P@0^KVi1@2n_[h=0<SPf0@0QHF5102>SXh508:2PP@0
Ogmo1@1nOWh407YjNP@0OGem1@23Ph<408F5Q@D0P8201024Q8@407inOPD0NWYj101mOGd407]kN`D0
PX:21021PH4507moO`@0PX:22@1oOgl407EeM@D0Ph>3101mOGd407inOPT0OGem1@20P80408:2PP@0
OGem1@1hN7P408f=S@D0Ng]k1020P80407inOPD0P820101eMGD508J6QPd0P820101kNg/907moO`@0
O7al1@1nOWh408:2PPD0OWin101mOGd907moO`@0OWin1@21PH4407inOP@0OGem1@1nOWh408>3P`D0
O7al101nOWh40861P@D0P8201021PH4407inOPD0P8205P38h=P001D0b>3H1@0`<30402XZ:P@0;Bd]
1@10@40406MWI`D0:RXZ100];Bd4030`<0D0BTY:100f=SH503Lg=`P0<S8b1@0f=SH403Xj>PD0:RXZ
100h>3P403dm?@D0=SHf100b<S8405aLG0D0KVi^101cLg<503/k>`@0;Bd]101WIfL505YJFP@07alO
1@0R8R8402<S8`@09RHV1@1LG5`409nOW`D0Q8B4101gMgL409RHV0D0][Jf102YZJT50;Bd]0@0ZJVY
102UYJD50:JVYP@0RXZ:1@2VYZH40:f][@@0[Zj^1@2g]kL40<30`0D0^k^k102/[:`40:ZZZPD0Z:RX
102[Zj/50:NWY`@0YJFU102GUiL509FEU@@0WYjN1@2VYZH40:RXZ0@0Zj^[1@2b/[840;Vi^@D0_[jn
3@38h=P408F5Q@@0SXj>1@22PX8407moO`D0OWin101jNWX407emO@D0Ph>31025QHD50820P0@0Q8B4
101nOWh507YjNP@0OGem101kNg/508:2PP@0PH611@1oOgl408:2PPT0Ogmo101eMGD508>3P`@0OGem
101nOWh907emO@D0P8201022PX8407emO@D0N7Qh102=SHd507]kN`@0P820101nOWh50820P0@0MGEe
1@26QXH=0820P0@0Ng]k2@1oOgl407alO0D0OWin1022PX8507inOP@0OGem2@1oOgl407inOPD0PH61
101nOWh407emO@D0OWin1023Ph<507alO0@0OWin1021PH450820P0@0PH61101nOWh50820P1H0b>3H
000E0<SPf0D0<30`100Z:RX402d];@D0@410101WIfL502XZ:P@0;Bd]100`<30504Y:BP@0=SHf1@0g
=cL8038b<PD0=SHf100j>SX502XZ:P@0>3Ph100m?Cd503Hf=P@0<S8b101LG5`506i^KP@0Lg=c1@0k
>c/402d];@@0IfMW1@1JFUX401lO7`D08R8R100S8b<402HV9PD0G5aL102OWil508B4Q0@0MgMg102H
V9P50;Jf]P@0ZJVY1@2d];@40:VYZ@@0YJFU1@2VYZH408Z:RPD0YZJV102][Jd40:j^[PD0]kNg1030
`<050;^k^`@0[:b/102ZZZX50:RXZ0@0Zj^[1@2WYjL40:FUY@@0UiNG1@2EUID409jNWPD0YZJV102X
Z:P40:^[Z`D0/[:b102i^KT50;jn_Pd0b>3H1025QHD408j>SPD0PX:2101oOgl507inOP@0NWYj101m
OGd508>3P`@0QHF51@20P80408B4Q0@0OWin1@1jNWX407emO@@0Ng]k1@22PX840861P@D0Ogmo1022
PX8907moO`@0MGEe1@23Ph<407emO@@0OWin2@1mOGd50820P0@0PX:2101mOGd507QhN0@0SHf=1@1k
Ng/40820P0@0OWin1@20P80407EeM@D0QXJ63@20P80407]kN`T0Ogmo101lO7`507inOP@0PX:21@1n
OWh407emO@T0Ogmo101nOWh50861P@@0OWin101mOGd507inOP@0Ph>31@1lO7`407inOP@0PH611@20
P8040861P@@0OWin1@20P80F0<SPf0005@38h=P5030`<0@0:RXZ100];Bd50410@0@0IfMW1@0Z:RX4
02d];@@0<30`1@1:BTX403Hf=PD0=cLg200b<S8503Hf=P@0>SXj1@0Z:RX403Ph>0@0?Cdm1@0f=SH4
038b<P@0G5aL1@1^KVh407=cL`D0>c/k100];Bd406MWI`D0FUYJ100O7al5028R8P@08b<S100V9RH5
05aLG0@0WinO1@24Q8@407MgM`@0V9RH1@2f][H40:VYZ@D0];Bd102YZJT40:FUY@D0YZJV102:RXX5
0:JVYP@0[Jf]102^[Zh50;Ng]`@0`<301@2k^k/40:b/[0@0ZZZZ1@2XZ:P40:^[Z`D0YjNW102UYJD4
09NGU`D0UIFE102NWYh50:JVYP@0Z:RX102[Zj/50;:b/P@0^KVi1@2n_[h=0<SPf0@0QHF5102>SXh5
08:2PP@0Ogmo1@1nOWh407YjNP@0OGem1@23Ph<408F5Q@D0P8201024Q8@407inOPD0NWYj101mOGd4
07]kN`D0PX:21021PH4507moO`@0PX:22@1oOgl407EeM@D0Ph>3101mOGd407inOPT0OGem1@20P804
08:2PP@0OGem1@1hN7P408f=S@D0Ng]k1020P80407inOPD0P820101eMGD508J6QPd0P820101kNg/9
07moO`@0O7al1@1nOWh408:2PPD0OWin101mOGd907moO`@0OWin1@21PH4407inOP@0OGem1@1nOWh4
08>3P`D0O7al101nOWh40861P@D0P8201021PH4407inOPD0P8205P38h=P001D0b>3H1@1BDU8404I6
AP@0;Bd]1@0k>c/406QXJ0D0<c<c100/;2`402/[:`D0=CDe1013@d<903Lg=`@0;2`/1@0_;bl403Lg
=`D0<30`100o?cl403hn?PD0=3@d1012@T8406=SH`D0@d=3101JFUX502d];@@0=3@d1026QXH50451
@@@0:b/[1@0V9RH402<S8`T092@T101WIfL509fMW@@0NGUi101^KVh509fMW@@0/[:b1@2YZJT80:FU
Y@D0Xj>S1026QXH50:FUY@@0[:b/102QXJ450;Zj^P@0_[jn1@2h^;P40;2`/0T0Z:RX102ZZZX50:VY
Z@@0Zj^[102/[:`509fMW@@0UIFE1@2RXZ840:JVYP@0Zj^[1@2^[Zh40;Fe]@D0^k^k3@38h=P806YZ
JPD0MgMg1020P8050861P@@0Ph>32@1oOgl408>3P`D0O7al1021PH4407inOPD0P820101oOgl408B4
Q0D0Ph>3101nOWh508>3P`@0PH611022PX850861P@@0PX:21@1iNGT408:2PP@0Ph>31@1oOgl907em
O@@0PH61101nOWh50820P0@0Ng]k1@2;Rh/407IfMP@0Q8B41@1oOgl40861P@D0N7Qh1021PH4407mo
O`D0PH611023Ph<50820P0@0O7al1025QHD508J6QP@0OWin1@23Ph<408:2PP@0P8201@1kNg/40820
P0D0Ogmo1021PH4408:2PPD0OGem101kNg/508f=S@@0OWin1022PX8508>3P`@0P8201021PH4507mo
OaH0b>3H000E0<SPf0D0DU9B1016ATH402d];@D0>c/k101XJ6P503<c<`@0;2`/100[:b/503De=@@0
@d=32@0g=cL402`/;0D0;bl_100g=cL5030`<0@0?clo100n?Sh503@d=0@0@T92101SHf<504=3@`@0
FUYJ1@0];Bd403@d=0@0QXJ61@11@D4402/[:`D09RHV100S8b<902@T90@0IfMW1@2MWId407UiN@@0
KVi^1@2MWId40;:b/PD0ZJVY202UYJD50:>SX`@0QXJ61@2UYJD40:b/[0@0XJ6Q1@2j^[X40;jn_PD0
^;Rh102`/;090:RXZ0@0ZZZZ1@2YZJT40:^[Z`@0[:b/1@2MWId409FEU@D0XZ:R102VYZH40:^[Z`D0
[Zj^102e]KD50;^k^`d0b>3H201ZJVX507MgM`@0P8201@21PH4408>3P`T0Ogmo1023Ph<507alO0@0
PH61101nOWh50820P0@0Ogmo1024Q8@508>3P`@0OWin1@23Ph<40861P@@0PX:21@21PH4408:2PPD0
NGUi1022PX8408>3P`D0Ogmo2@1mOGd40861P@@0OWin1@20P80407]kN`D0Rh^;101fMWH408B4Q0D0
Ogmo1021PH4507QhN0@0PH61101oOgl50861P@@0Ph>31@20P80407alO0@0QHF51@26QXH407inOPD0
Ph>31022PX840820P0D0Ng]k1020P80507moO`@0PH611022PX8507emO@@0Ng]k1@2=SHd407inOP@0
PX:21@23Ph<40820P0@0PH611@1oOglF0<SPf0005@38h=P5059BDP@0ATI6100];Bd503/k>`@0J6QX
1@0c<c<402`/;0@0:b/[1@0e=CD404=3@`T0=cLg100/;2`502l_;`@0=cLg1@0`<30403lo?`@0?Shn
1@0d=3@40492@P@0Hf=S1@13@d<405YJFPD0;Bd]100d=3@408J6QPD0@D51100[:b/502HV9P@08b<S
2@0T92@406MWI`D0WIfM101iNGT406i^KPD0WIfM102b/[850:VYZ@P0YJFU1@2SXj<408J6QPD0YJFU
102/[:`40:6QX@D0^[Zj102n_[h50;Rh^0@0/;2`2@2XZ:P40:ZZZPD0ZJVY102[Zj/40:b/[0D0WIfM
102EUID50::RXP@0YZJV102[Zj/50:j^[P@0]KFe1@2k^k/=0<SPf0P0JVYZ1@1gMgL40820P0D0PH61
1023Ph<907moO`@0Ph>31@1lO7`40861P@@0OWin1@20P80407moO`@0Q8B41@23Ph<407inOPD0Ph>3
1021PH4408:2PPD0PH611022PX8507UiN@@0PX:21023Ph<507moO`T0OGem1021PH4407inOPD0P820
101kNg/508^;R`@0MWIf1024Q8@507moO`@0PH611@1hN7P40861P@@0Ogmo1@21PH4408>3P`D0P820
101lO7`408F5Q@D0QXJ6101nOWh508>3P`@0PX:21020P80507]kN`@0P8201@1oOgl40861P@@0PX:2
1@1mOGd407]kN`D0SHf=101nOWh408:2PPD0Ph>31020P8040861P@D0Ogmo5P38h=P001D0b>3H1@1B
DU8404I6AP@0;Bd]1@0k>c/406QXJ0D0<c<c100/;2`402/[:`D0=CDe1013@d<903Lg=`@0;2`/1@0_
;bl403Lg=`D0<30`100o?cl403hn?PD0=3@d1012@T8406=SH`D0@d=3101JFUX502d];@@0=3@d1026
QXH50451@@@0:b/[1@0V9RH402<S8`T092@T101WIfL509fMW@@0NGUi101^KVh509fMW@@0/[:b1@2Y
ZJT80:FUY@D0Xj>S1026QXH50:FUY@@0[:b/102QXJ450;Zj^P@0_[jn1@2h^;P40;2`/0T0Z:RX102Z
ZZX50:VYZ@@0Zj^[102/[:`509fMW@@0UIFE1@2RXZ840:JVYP@0Zj^[1@2^[Zh40;Fe]@D0^k^k3@38
h=P806YZJPD0MgMg1020P8050861P@@0Ph>32@1oOgl408>3P`D0O7al1021PH4407inOPD0P820101o
Ogl408B4Q0D0Ph>3101nOWh508>3P`@0PH611022PX850861P@@0PX:21@1iNGT408:2PP@0Ph>31@1o
Ogl907emO@@0PH61101nOWh50820P0@0Ng]k1@2;Rh/407IfMP@0Q8B41@1oOgl40861P@D0N7Qh1021
PH4407moO`D0PH611023Ph<50820P0@0O7al1025QHD508J6QP@0OWin1@23Ph<408:2PP@0P8201@1k
Ng/40820P0D0Ogmo1021PH4408:2PPD0OGem101kNg/508f=S@@0OWin1022PX8508>3P`@0P8201021
PH4507moOaH0b>3H000E0<SPf0D0B4Q81014A4@403@d=0D0=SHf101SHf<50410@0P0:RXZ1@0/;2`4
03Ti>@D0;Rh^100k>c/402l_;`T0<c<c1@1;Bd/404Q8B0@0?clo1@0m?Cd404A4A0@0EeMG1@0_;bl4
04E5A@D0<S8b101FEUH408V9R@D0;bl_2@0W9bL8028R8PD0820P100W9bL507=cL`@0Xj>S101aLG45
07AdM0@0WinO1@2j^[X40:BTY0@0YJFU1@2OWil408:2PPD0VIVI102XZ:P40:NWY`D0/;2`102n_[h5
0:f][@@0][Jf2@2YZJT40:NWY`D0Xj>S102TY:@40:b/[0D0]KFe102NWYh509NGU`@0Xj>S102ZZZX5
0:j^[P@0];Bd1@2g]kL=0<SPf0@0QhN71026QXH50820P0@0MgMg1@1nOWh407emO@@0Ng]k1@22PX84
07inOPD0Ogmo101mOGd407inOPD0Ng]k1022PX840820P0D0OWin101jNWX50820P0@0Ogmo1025QHD5
07emO@@0O7al1@22PX8407EeM@@0NWYj1@1iNGT408>3P`D0R8R8102?Shl408J6QPD0Ng]k1022PX85
07moO`@0Ph>3101hN7P50861P@@0QHF51@1oOgl407MgM`@0Ph>31@1nOWh407emO@D0P8201024Q8@4
07QhN0D0Ogmo101nOWh50820P0@0O7al2@20P80408J6QPD0P820101oOgl907emO@@0Ph>31@1fMWH4
08F5Q@@0P8202@1nOWh407emO@D0Ogmo5P38h=P001D0b>3H1@18B4P404A4A0@0=3@d1@0f=SH406=S
H`D0@410200Z:RX502`/;0@0>CTi1@0^;Rh403/k>`@0;bl_2@0c<c<504];B`@0B4Q8100o?cl503dm
?@@0A4A4101GEeL502l_;`@0ADE51@0b<S8405IFEP@0RHV91@0_;bl902LW9`P08R8R1@0P820402LW
9`D0Lg=c102SXj<4075aL@D0M7Ad102OWil50;Zj^P@0Y:BT102UYJD509nOW`@0PX:21@2IVIT40:RX
Z0@0YjNW1@2`/;040;jn_PD0[Jf]102f][H90:VYZ@@0YjNW1@2SXj<40:BTY0@0[:b/1@2e]KD409jN
WPD0UiNG102SXj<40:ZZZPD0[Zj^102d];@50;Ng]`d0b>3H1027QhL408J6QPD0P820101gMgL507in
OP@0OGem101kNg/508:2PP@0OWin1@1oOgl407emO@@0OWin1@1kNg/408:2PP@0P8201@1nOWh407Yj
NPD0P820101oOgl408F5Q@D0OGem101lO7`508:2PP@0MGEe101jNWX507UiN@@0Ph>31@28R8P408n?
S`@0QXJ61@1kNg/408:2PPD0Ogmo1023Ph<407QhN0D0PH611025QHD507moO`@0MgMg1023Ph<507in
OP@0OGem1@20P80408B4Q0@0N7Qh1@1oOgl407inOPD0P820101lO7`90820P0@0QXJ61@20P80407mo
O`T0OGem1023Ph<507IfMP@0QHF51020P80907inOP@0OGem1@1oOglF0<SPf0005@38h=P504Q8B0@0
A4A4100d=3@503Hf=P@0Hf=S1@10@40802XZ:PD0;2`/100i>CT502h^;P@0>c/k100_;bl903<c<`D0
Bd];1018B4P403lo?`D0?Cdm1014A4@405MGE`D0;bl_1015ADD5038b<P@0EUIF1029RHT502l_;`T0
9bLW200R8R85020P80@09bLW1@1cLg<40:>SX`@0LG5a1@1dM7@409nOW`D0^[Zj102TY:@40:FUY@D0
WinO1022PX8509VIV@@0Z:RX102WYjL50;2`/0@0_[jn1@2][Jd40;Jf]PT0ZJVY102WYjL50:>SX`@0
Y:BT102/[:`50;Fe]@@0WYjN1@2GUiL40:>SX`@0ZZZZ1@2^[Zh40;Bd]0D0]kNg3@38h=P408N7Q`@0
QXJ61@20P80407MgM`D0OWin101mOGd407]kN`D0PX:2101nOWh507moO`@0OGem101nOWh507]kN`@0
PX:21020P80507inOP@0NWYj1@20P80407moO`@0QHF51@1mOGd407alO0D0PX:2101eMGD407YjNPD0
NGUi1023Ph<508R8R0@0Shn?1026QXH507]kN`@0PX:21@1oOgl408>3P`@0N7Qh1@21PH4408F5Q@D0
Ogmo101gMgL408>3P`D0OWin101mOGd50820P0@0Q8B4101hN7P507moO`@0OWin1@20P80407alO0T0
P8201026QXH50820P0@0Ogmo2@1mOGd408>3P`D0MWIf1025QHD40820P0T0OWin101mOGd507moOaH0
b>3H000E0<SPf0D0B4Q81014A4@403@d=0D0=SHf101SHf<50410@0P0:RXZ1@0/;2`403Ti>@D0;Rh^
100k>c/402l_;`T0<c<c1@1;Bd/404Q8B0@0?clo1@0m?Cd404A4A0@0EeMG1@0_;bl404E5A@D0<S8b
101FEUH408V9R@D0;bl_2@0W9bL8028R8PD0820P100W9bL507=cL`@0Xj>S101aLG4507AdM0@0WinO
1@2j^[X40:BTY0@0YJFU1@2OWil408:2PPD0VIVI102XZ:P40:NWY`D0/;2`102n_[h50:f][@@0][Jf
2@2YZJT40:NWY`D0Xj>S102TY:@40:b/[0D0]KFe102NWYh509NGU`@0Xj>S102ZZZX50:j^[P@0];Bd
1@2g]kL=0<SPf0@0QhN71026QXH50820P0@0MgMg1@1nOWh407emO@@0Ng]k1@22PX8407inOPD0Ogmo
101mOGd407inOPD0Ng]k1022PX840820P0D0OWin101jNWX50820P0@0Ogmo1025QHD507emO@@0O7al
1@22PX8407EeM@@0NWYj1@1iNGT408>3P`D0R8R8102?Shl408J6QPD0Ng]k1022PX8507moO`@0Ph>3
101hN7P50861P@@0QHF51@1oOgl407MgM`@0Ph>31@1nOWh407emO@D0P8201024Q8@407QhN0D0Ogmo
101nOWh50820P0@0O7al2@20P80408J6QPD0P820101oOgl907emO@@0Ph>31@1fMWH408F5Q@@0P820
2@1nOWh407emO@D0Ogmo5P38h=P001D0b>3H1@1_Kfl404U9B@@0:BTY1@0`<30405=CD`D0D51@100Y
:BT402/[:`D0;2`/100b<S8502d];@@0<C4a100_;bl503De=@@0B4Q81@1@D50403`l?0@0BDU91@17
AdL4038b<P@0GemO1@0`<30403Xj>PD0<C4a101IFET408F5Q@D0>3Ph1015ADD504Q8B0@0<30`100V
9RH502<S8`@08B4Q1@0`<30407emO@@0VYZJ1@1cLg<406][J`D0WIfM102`/;040:6QX@D0UiNG101k
Ng/50:>SX`@0^KVi102^[Zh50;>c/`@0`<301@2k^k/40;Vi^@@0[:b/1@2WYjL40:>SX`D0X:2P102O
Wil40:NWY`D0/K6a102i^KT50:^[Z`@0VYZJ102TY:@50:RXZ0@0[Jf]1@2d];@=0<SPf0@0P820101[
Jf/507alO0@0Q8B41@23Ph<407UiN@@0QXJ61@21PH4407UiN@D0RHV91023Ph<40861P@D0P820101h
N7P407moO`D0OGem1024Q8@507UiN@@0NWYj1025QHD507moO`@0QHF51@23Ph<40861P@@0Ogmo1@20
P80407emO@D0L71`101OGel4079bLPD0Ph>3101mOGd50820P0@0OGem1027QhL507AdM0@0PX:21@20
P80408>3P`@0MGEe1@2<S8`407inOPD0RHV9101lO7`408>3P`D0PH61101oOgl507emO@@0PH61101o
Ogl508F5Q@@0Ph>31@20P80408:2PPT0PH611023Ph<907moO`@0OGem1@23Ph<407inOP@0P8201@21
PH4F0<SPf0005@38h=P506m_K`@0BDU9100Y:BT5030`<0@0De=C1@1@D50402TY:@@0:b/[1@0/;2`4
038b<PD0;Bd]100a<C4402l_;`D0=CDe1018B4P5051@D0@0?3`l1019BDT504M7A`@0<S8b101OGel5
030`<0@0>SXj1@0a<C4405UIF@@0QHF51@0h>3P404E5A@D0B4Q8100`<30402HV9PD08b<S100Q8B45
030`<0@0OGem102JVYX507=cL`@0Jf][1@2MWId40;2`/0@0XJ6Q1@2GUiL407]kN`D0Xj>S102i^KT4
0:j^[PD0/k>c1030`<050;^k^`@0^KVi102/[:`50:NWY`@0Xj>S1@2PX:0409nOW`@0YjNW1@2a/K44
0;Vi^@D0Zj^[102JVYX40:BTY0D0Z:RX102][Jd50;Bd]0d0b>3H1020P80406][J`D0O7al1024Q8@5
08>3P`@0NGUi1026QXH50861P@@0NGUi1@29RHT408>3P`@0PH611@20P80407QhN0@0Ogmo1@1mOGd4
08B4Q0D0NGUi101jNWX408F5Q@D0Ogmo1025QHD508>3P`@0PH61101oOgl50820P0@0OGem1@1`L704
05mOG`@0LW9b1@23Ph<407emO@D0P820101mOGd408N7Q`D0M7Ad1022PX850820P0@0Ph>3101eMGD5
08b<S0@0OWin1@29RHT407alO0@0Ph>31@21PH4407moO`D0OGem1021PH4407moO`D0QHF51023Ph<5
0820P0@0PX:22@21PH4408>3P`T0Ogmo101mOGd508>3P`@0OWin1020P8050861PAH0b>3H000E0<SP
f0D0Kfm_1019BDT402TY:@D0<30`101CDe<5051@D0@0:BTY100[:b/502`/;0@0<S8b1@0];Bd4034a
<@@0;bl_1@0e=CD404Q8B0D0D51@100l?3`404U9B@D0AdM7100b<S8405mOG`D0<30`100j>SX5034a
<@@0FEUI1025QHD503Ph>0@0ADE51@18B4P4030`<0@09RHV1@0S8b<4024Q8@D0<30`101mOGd409ZJ
VPD0Lg=c101[Jf/509fMW@@0/;2`102QXJ4509NGU`@0Ng]k1@2SXj<40;Vi^@@0[Zj^1@2c/k<40<30
`0D0^k^k102i^KT40:b/[0D0YjNW102SXj<50:2PX0@0WinO102WYjL50;6a/@@0^KVi1@2[Zj/409ZJ
VP@0Y:BT1@2XZ:P40:f][@D0];Bd3@38h=P40820P0@0Jf][1@1lO7`408B4Q0D0Ph>3101iNGT408J6
QPD0PH61101iNGT508V9R@@0Ph>31021PH450820P0@0N7Qh101oOgl507emO@@0Q8B41@1iNGT407Yj
NP@0QHF51@1oOgl408F5Q@D0Ph>31021PH4407moO`D0P820101mOGd5071`L0@0GemO101bLW8508>3
P`@0OGem1@20P80407emO@@0QhN71@1dM7@408:2PPD0P8201023Ph<407EeM@D0S8b<101nOWh508V9
R@@0O7al1023Ph<50861P@@0Ogmo1@1mOGd40861P@@0Ogmo1@25QHD408>3P`D0P8201022PX890861
P@@0Ph>32@1oOgl407emO@D0Ph>3101nOWh40820P0D0PH615P38h=P001D0b>3H1@1_Kfl404U9B@@0
:BTY1@0`<30405=CD`D0D51@100Y:BT402/[:`D0;2`/100b<S8502d];@@0<C4a100_;bl503De=@@0
B4Q81@1@D50403`l?0@0BDU91@17AdL4038b<P@0GemO1@0`<30403Xj>PD0<C4a101IFET408F5Q@D0
>3Ph1015ADD504Q8B0@0<30`100V9RH502<S8`@08B4Q1@0`<30407emO@@0VYZJ1@1cLg<406][J`D0
WIfM102`/;040:6QX@D0UiNG101kNg/50:>SX`@0^KVi102^[Zh50;>c/`@0`<301@2k^k/40;Vi^@@0
[:b/1@2WYjL40:>SX`D0X:2P102OWil40:NWY`D0/K6a102i^KT50:^[Z`@0VYZJ102TY:@50:RXZ0@0
[Jf]1@2d];@=0<SPf0@0P820101[Jf/507alO0@0Q8B41@23Ph<407UiN@@0QXJ61@21PH4407UiN@D0
RHV91023Ph<40861P@D0P820101hN7P407moO`D0OGem1024Q8@507UiN@@0NWYj1025QHD507moO`@0
QHF51@23Ph<40861P@@0Ogmo1@20P80407emO@D0L71`101OGel4079bLPD0Ph>3101mOGd50820P0@0
OGem1027QhL507AdM0@0PX:21@20P80408>3P`@0MGEe1@2<S8`407inOPD0RHV9101lO7`408>3P`D0
PH61101oOgl507emO@@0PH61101oOgl508F5Q@@0Ph>31@20P80408:2PPT0PH611023Ph<907moO`@0
OGem1@23Ph<407inOP@0P8201@21PH4F0<SPf0005@38h=P506m_K`@0BDU9100Y:BT5030`<0@0De=C
1@1@D50402TY:@@0:b/[1@0/;2`4038b<PD0;Bd]100a<C4402l_;`D0=CDe1018B4P5051@D0@0?3`l
1019BDT504M7A`@0<S8b101OGel5030`<0@0>SXj1@0a<C4405UIF@@0QHF51@0h>3P404E5A@D0B4Q8
100`<30402HV9PD08b<S100Q8B45030`<0@0OGem102JVYX507=cL`@0Jf][1@2MWId40;2`/0@0XJ6Q
1@2GUiL407]kN`D0Xj>S102i^KT40:j^[PD0/k>c1030`<050;^k^`@0^KVi102/[:`50:NWY`@0Xj>S
1@2PX:0409nOW`@0YjNW1@2a/K440;Vi^@D0Zj^[102JVYX40:BTY0D0Z:RX102][Jd50;Bd]0d0b>3H
1020P80406][J`D0O7al1024Q8@508>3P`@0NGUi1026QXH50861P@@0NGUi1@29RHT408>3P`@0PH61
1@20P80407QhN0@0Ogmo1@1mOGd408B4Q0D0NGUi101jNWX408F5Q@D0Ogmo1025QHD508>3P`@0PH61
101oOgl50820P0@0OGem1@1`L70405mOG`@0LW9b1@23Ph<407emO@D0P820101mOGd408N7Q`D0M7Ad
1022PX850820P0@0Ph>3101eMGD508b<S0@0OWin1@29RHT407alO0@0Ph>31@21PH4407moO`D0OGem
1021PH4407moO`D0QHF51023Ph<50820P0@0PX:22@21PH4408>3P`T0Ogmo101mOGd508>3P`@0OWin
1020P8050861PAH0b>3H000E0<SPf0D0KVi^100k>c/402TY:@D0<c<c100g=cL5059BDP@0>SXj100`
<30902d];@D0;bl_100b<S8402h^;PD0BDU9101FEUH503lo?`@0B4Q8101GEeL503`l?0@0:RXZ101K
Fe/502/[:`@0;Rh^1@0j>SX4075aL@@0Q8B41@1NGUh405YJFPD0Bd];100[:b/402HV9PD092@T100S
8b<502HV9P@0=3@d1021PH4508n?S`@0GEeM1@1WIfL409FEU@@0/[:b2@28R8P50:b/[0@0^[Zj102`
/;050;Rh^0@0_;bl1@30`<040;no_`@0][Jf1@2ZZZX40:FUY@D0WinO102QXJ440:FUY@D0[:b/102b
/[850;Fe]@@0[:b/102RXZ850:FUY@@0[Jf]1@2b/[8=0<SPf0@0PX:2102>SXh50861P@@0NGUi2@20
P80408F5Q@D0OWin1022PX850820P0@0Ng]k1026QXH508B4Q0@0Ogmo101iNGT508N7Q`@0NWYj1@1k
Ng/408B4Q0@0PX:21@21PH4407alO0D0OGem101jNWX407inOPD0LG5a1023Ph<909>CT`@0OWin1@21
PH4908:2PP@0Ng]k1022PX8508B4Q0T0Ng]k101jNWX408B4Q0D0M7Ad1023Ph<907UiN@@0PH611@1n
OWh408>3P`D0P820101oOgl40820P0T0OGem1@21PH4408F5Q@@0P8201@1oOgl407inOPD0Ogmo1022
PX8407moO`D0PX:21021PH4407YjNPD0Ng]k5P38h=P001D0b>3H1@1^KVh403/k>`@0:BTY1@0c<c<4
03Lg=`D0DU9B100j>SX4030`<0T0;Bd]1@0_;bl4038b<P@0;Rh^1@19BDT405IFEPD0?clo1018B4P4
05MGE`D0?3`l100Z:RX405]KF`D0:b/[100^;Rh503Xj>P@0LG5a1024Q8@505iNGP@0FUYJ1@1;Bd/4
02/[:`@09RHV1@0T92@402<S8`D09RHV100d=3@40861P@D0Shn?101MGEd506MWI`@0UIFE102b/[89
08R8R0D0[:b/102j^[X40;2`/0D0^;Rh102l_;`50<30`0@0_kno102f][H50:ZZZP@0YJFU1@2OWil4
0:6QX@@0YJFU1@2/[:`40;:b/PD0]KFe102/[:`40::RXPD0YJFU102][Jd50;:b/Pd0b>3H1022PX84
08j>SPD0PH61101iNGT90820P0@0QHF51@1nOWh408:2PPD0P820101kNg/408J6QPD0Q8B4101oOgl4
07UiN@D0QhN7101jNWX507]kN`@0Q8B41022PX850861P@@0O7al1@1mOGd407YjNP@0OWin1@1aLG44
08>3P`T0Ti>C101nOWh50861P@T0PX:2101kNg/408:2PPD0Q8B42@1kNg/407YjNP@0Q8B41@1dM7@4
08>3P`T0NGUi1021PH4507inOP@0Ph>31@20P80407moO`@0P8202@1mOGd50861P@@0QHF51020P805
07moO`@0OWin1@1oOgl408:2PP@0Ogmo1@22PX840861P@@0NWYj1@1kNg/F0<SPf0005@38h=P506i^
KP@0>c/k100Y:BT503<c<`@0=cLg1@1BDU8403Xj>P@0<30`2@0];Bd502l_;`@0<S8b100^;Rh504U9
B@@0EUIF1@0o?cl404Q8B0@0EeMG1@0l?3`402XZ:P@0Fe]K1@0[:b/402h^;PD0>SXj101aLG4408B4
Q0D0GUiN101JFUX504];B`@0:b/[100V9RH502@T90@08b<S1@0V9RH403@d=0@0PH611@2?Shl405eM
G@D0IfMW102EUID40;:b/PT0R8R81@2/[:`40;Zj^P@0/;2`1@2h^;P40;bl_0D0`<30102o_kl40;Jf
]PD0ZZZZ102UYJD509nOW`@0XJ6Q102UYJD50:b/[0@0/[:b1@2e]KD40:b/[0@0XZ:R1@2UYJD40:f]
[@D0/[:b3@38h=P408:2PP@0SXj>1@21PH4407UiN@T0P8201025QHD507inOP@0PX:21@20P80407]k
N`@0QXJ61@24Q8@407moO`@0NGUi1@27QhL407YjNPD0Ng]k1024Q8@408:2PPD0PH61101lO7`507em
O@@0NWYj101nOWh5075aL@@0Ph>32@2CTi<407inOPD0PH612@22PX8407]kN`@0PX:21@24Q8@907]k
N`@0NWYj1024Q8@507AdM0@0Ph>32@1iNGT40861P@D0OWin1023Ph<50820P0@0Ogmo1020P80907em
O@D0PH611025QHD40820P0D0Ogmo101nOWh507moO`@0PX:2101oOgl508:2PP@0PH61101jNWX507]k
NaH0b>3H000E0<SPf0D0KVi^100k>c/402TY:@D0<c<c100g=cL5059BDP@0>SXj100`<30902d];@D0
;bl_100b<S8402h^;PD0BDU9101FEUH503lo?`@0B4Q8101GEeL503`l?0@0:RXZ101KFe/502/[:`@0
;Rh^1@0j>SX4075aL@@0Q8B41@1NGUh405YJFPD0Bd];100[:b/402HV9PD092@T100S8b<502HV9P@0
=3@d1021PH4508n?S`@0GEeM1@1WIfL409FEU@@0/[:b2@28R8P50:b/[0@0^[Zj102`/;050;Rh^0@0
_;bl1@30`<040;no_`@0][Jf1@2ZZZX40:FUY@D0WinO102QXJ440:FUY@D0[:b/102b/[850;Fe]@@0
[:b/102RXZ850:FUY@@0[Jf]1@2b/[8=0<SPf0@0PX:2102>SXh50861P@@0NGUi2@20P80408F5Q@D0
OWin1022PX850820P0@0Ng]k1026QXH508B4Q0@0Ogmo101iNGT508N7Q`@0NWYj1@1kNg/408B4Q0@0
PX:21@21PH4407alO0D0OGem101jNWX407inOPD0LG5a1023Ph<909>CT`@0OWin1@21PH4908:2PP@0
Ng]k1022PX8508B4Q0T0Ng]k101jNWX408B4Q0D0M7Ad1023Ph<907UiN@@0PH611@1nOWh408>3P`D0
P820101oOgl40820P0T0OGem1@21PH4408F5Q@@0P8201@1oOgl407inOPD0Ogmo1022PX8407moO`D0
PX:21021PH4407YjNPD0Ng]k5P38h=P001D0b>3H1@1/K6`40410@0@0=SHf1@0j>SX402XZ:PD0Cdm?
101;Bd/4038b<PD0;Bd]100^;Rh502l_;`@0<30`100e=CD505aLG0@0B4Q81@12@T84055AD@@0FEUI
1@0/;2`403Hf=P@0D51@1@0[:b/4034a<@D0K6a/101mOGd406ATI0h0;2`/100a<C4902/[:`@09BDU
1@0T92@402HV9P@0>SXj1@1eMGD4075aL@D0HF5Q101KFe/409FEU@D0R8R8102PX:0509ZJVP@0^;Rh
102c/k<50;Fe]@@0]kNg1@2k^k/40;bl_0@0][Jf1@2a/K440:FUY@T0X:2P102TY:@50:JVYP@0[:b/
1@2f][H40:j^[P@0Y:BT1@2LW9`40::RXPD0[Zj^3@38h=P408J6QP@0NWYj1@23Ph<408J6QPD0RXZ:
101oOgl407IfMPD0O7al101nOWh508>3P`@0P8201021PH4508N7Q`@0Ogmo102=SHd507YjNPT0Ng]k
1021PH4407moO`T0Q8B41@23Ph<407inOP@0N7Qh1@22PX8407inOPD0O7al101hN7P40820P0D0QhN7
1024Q8@507moO`@0OWin1021PH4508R8R0@0P8202@21PH440820P0D0QXJ6101fMWH508:2PP@0Ph>3
2@1oOgl=0820P0@0Ogmo2@22PX850820P0@0PH61101mOGd507moO`T0Q8B4101oOgl90820P0@0PH61
1020P80508B4Q1H0b>3H000E0<SPf0D0K6a/1010@40403Hf=PD0>SXj100Z:RX504m?C`@0Bd];100b
<S8502d];@@0;Rh^1@0_;bl4030`<0@0=CDe1@1LG5`404Q8B0D0@T92101ADE4405UIF@D0;2`/100f
=SH4051@D0D0:b/[100a<C4506a/K0@0OGem101TI6@>02`/;0@0<C4a2@0[:b/402DU9@D092@T100V
9RH403Xj>PD0MGEe101aLG45065QH@@0Fe]K102EUID508R8R0@0X:2P1@2JVYX40;Rh^0@0/k>c1@2e
]KD40;Ng]`D0^k^k102l_;`40;Jf]PD0/K6a102UYJD90:2PX0@0Y:BT1@2VYZH40:b/[0D0][Jf102^
[Zh40:BTY0D0W9bL102RXZ850:j^[Pd0b>3H1026QXH407YjNPD0Ph>31026QXH508Z:RP@0Ogmo101f
MWH507alO0@0OWin1@23Ph<40820P0@0PH611@27QhL407moO`@0SHf=1@1jNWX907]kN`@0PH61101o
Ogl908B4Q0D0Ph>3101nOWh407QhN0D0PX:2101nOWh507alO0@0N7Qh1020P80508N7Q`@0Q8B41@1o
Ogl407inOP@0PH611@28R8P40820P0T0PH611020P80508J6QP@0MWIf1@22PX8408>3P`T0Ogmo3@20
P80407moO`T0PX:21@20P8040861P@@0OGem1@1oOgl908B4Q0@0Ogmo2@20P8040861P@@0P8201@24
Q8@F0<SPf0005@38h=P506a/K0@0@410100f=SH503Xj>P@0:RXZ1@1?Cdl404];B`@0<S8b1@0];Bd4
02h^;PD0;bl_100`<30403De=@D0G5aL1018B4P50492@P@0DE5A101IFET502`/;0@0=SHf101@D505
02/[:`@0<C4a1@1/K6`407emO@@0I6AT3P0/;2`4034a<@T0:b/[100U9BD502@T90@09RHV100j>SX5
07EeM@@0LG5a1@1QHF4405]KF`@0UIFE1@28R8P40:2PX0D0VYZJ102h^;P40;>c/`D0]KFe102g]kL5
0;^k^`@0_;bl102f][H50;6a/@@0YJFU2@2PX:040:BTY0D0YZJV102/[:`50;Jf]P@0[Zj^102TY:@5
09bLW0@0XZ:R1@2^[Zh=0<SPf0@0QXJ6101jNWX508>3P`@0QXJ61@2:RXX407moO`@0MWIf1@1lO7`4
07inOPD0Ph>31020P8040861P@D0QhN7101oOgl408f=S@D0NWYj2@1kNg/40861P@@0Ogmo2@24Q8@5
08>3P`@0OWin101hN7P508:2PP@0OWin1@1lO7`407QhN0@0P8201@27QhL408B4Q0D0Ogmo101nOWh4
0861P@D0R8R81020P8090861P@@0P8201@26QXH407IfMPD0PX:21023Ph<907moO`d0P820101oOgl9
08:2PPD0P8201021PH4407emO@D0Ogmo2@24Q8@407moO`T0P8201021PH440820P0D0Q8B45P38h=P0
01D0b>3H1@1/K6`40410@0@0=SHf1@0j>SX402XZ:PD0Cdm?101;Bd/4038b<PD0;Bd]100^;Rh502l_
;`@0<30`100e=CD505aLG0@0B4Q81@12@T84055AD@@0FEUI1@0/;2`403Hf=P@0D51@1@0[:b/4034a
<@D0K6a/101mOGd406ATI0h0;2`/100a<C4902/[:`@09BDU1@0T92@402HV9P@0>SXj1@1eMGD4075a
L@D0HF5Q101KFe/409FEU@D0R8R8102PX:0509ZJVP@0^;Rh102c/k<50;Fe]@@0]kNg1@2k^k/40;bl
_0@0][Jf1@2a/K440:FUY@T0X:2P102TY:@50:JVYP@0[:b/1@2f][H40:j^[P@0Y:BT1@2LW9`40::R
XPD0[Zj^3@38h=P408J6QP@0NWYj1@23Ph<408J6QPD0RXZ:101oOgl407IfMPD0O7al101nOWh508>3
P`@0P8201021PH4508N7Q`@0Ogmo102=SHd507YjNPT0Ng]k1021PH4407moO`T0Q8B41@23Ph<407in
OP@0N7Qh1@22PX8407inOPD0O7al101hN7P40820P0D0QhN71024Q8@507moO`@0OWin1021PH4508R8
R0@0P8202@21PH440820P0D0QXJ6101fMWH508:2PP@0Ph>32@1oOgl=0820P0@0Ogmo2@22PX850820
P0@0PH61101mOGd507moO`T0Q8B4101oOgl90820P0@0PH611020P80508B4Q1H0b>3H000E0<SPf0D0
KFe]101GEeL4065QH@D0FUYJ1014A4@504M7A`@0EeMG1012@T8503De=@@0;bl_1@0/;2`4034a<@@0
?Cdm1@1ADE4404I6APD0AdM7101EEED404i>CPD0<c<c100f=SH404i>CPD09bLW101ADE45079bLP@0
Kfm_100k>c/502`/;0@0<C4a1@0b<S84030`<0@0;Rh^1@0/;2`4034a<@D0:BTY100W9bL402XZ:PD0
?Shn101ZJVX507EeM@@0Cdm?101SHf<506MWI`@0Xj>S1@2<S8`40;Rh^0@0/K6a1@2b/[890;Fe]@P0
^k^k1@2f][H40:f][@D0YZJV102RXZ840:RXZ0D0Zj^[102_[jl50;>c/`@0/K6a102_[jl509nOW`T0
ZJVY3@38h=P4075aL@@0O7al1@1`L70407IfMPD0KVi^101hN7P408j>SPD0NGUi101dM7@507QhN0@0
Ph>3101jNWX507EeM@@0QhN71026QXH508N7Q`@0QXJ61@27QhL407alO0@0P8201@1nOWh40861P@D0
Lg=c1025QHD408^;R`D0OGem1022PX8907moO`@0QXJ61@1mOGd407QhN0D0O7al1021PH4407YjNPD0
P8201029RHT509RHV0@0O7al101^KVh507emO@@0T92@1@25QHD407moO`T0RHV91021PH4908B4Q0@0
QXJ61@20P80407moO`D0Q8B4101hN7P407moO`D0OWin101oOgl507inOP@0Ph>3101mOGd508:2PP@0
NGUi101lO7`507QhN1H0b>3H000E0<SPf0D0KFe]101GEeL4065QH@D0FUYJ1014A4@504M7A`@0EeMG
1012@T8503De=@@0;bl_1@0/;2`4034a<@@0?Cdm1@1ADE4404I6APD0AdM7101EEED404i>CPD0<c<c
100f=SH404i>CPD09bLW101ADE45079bLP@0Kfm_100k>c/502`/;0@0<C4a1@0b<S84030`<0@0;Rh^
1@0/;2`4034a<@D0:BTY100W9bL402XZ:PD0?Shn101ZJVX507EeM@@0Cdm?101SHf<506MWI`@0Xj>S
1@2<S8`40;Rh^0@0/K6a1@2b/[890;Fe]@P0^k^k1@2f][H40:f][@D0YZJV102RXZ840:RXZ0D0Zj^[
102_[jl50;>c/`@0/K6a102_[jl509nOW`T0ZJVY3@38h=P4075aL@@0O7al1@1`L70407IfMPD0KVi^
101hN7P408j>SPD0NGUi101dM7@507QhN0@0Ph>3101jNWX507EeM@@0QhN71026QXH508N7Q`@0QXJ6
1@27QhL407alO0@0P8201@1nOWh40861P@D0Lg=c1025QHD408^;R`D0OGem1022PX8907moO`@0QXJ6
1@1mOGd407QhN0D0O7al1021PH4407YjNPD0P8201029RHT509RHV0@0O7al101^KVh507emO@@0T92@
1@25QHD407moO`T0RHV91021PH4908B4Q0@0QXJ61@20P80407moO`D0Q8B4101hN7P407moO`D0OWin
101oOgl507inOP@0Ph>3101mOGd508:2PP@0NGUi101lO7`507QhN1H0b>3H000E0<SPf0D0KFe]101G
EeL4065QH@D0FUYJ1014A4@504M7A`@0EeMG1012@T8503De=@@0;bl_1@0/;2`4034a<@@0?Cdm1@1A
DE4404I6APD0AdM7101EEED404i>CPD0<c<c100f=SH404i>CPD09bLW101ADE45079bLP@0Kfm_100k
>c/502`/;0@0<C4a1@0b<S84030`<0@0;Rh^1@0/;2`4034a<@D0:BTY100W9bL402XZ:PD0?Shn101Z
JVX507EeM@@0Cdm?101SHf<506MWI`@0Xj>S1@2<S8`40;Rh^0@0/K6a1@2b/[890;Fe]@P0^k^k1@2f
][H40:f][@D0YZJV102RXZ840:RXZ0D0Zj^[102_[jl50;>c/`@0/K6a102_[jl509nOW`T0ZJVY3@38
h=P4075aL@@0O7al1@1`L70407IfMPD0KVi^101hN7P408j>SPD0NGUi101dM7@507QhN0@0Ph>3101j
NWX507EeM@@0QhN71026QXH508N7Q`@0QXJ61@27QhL407alO0@0P8201@1nOWh40861P@D0Lg=c1025
QHD408^;R`D0OGem1022PX8907moO`@0QXJ61@1mOGd407QhN0D0O7al1021PH4407YjNPD0P8201029
RHT509RHV0@0O7al101^KVh507emO@@0T92@1@25QHD407moO`T0RHV91021PH4908B4Q0@0QXJ61@20
P80407moO`D0Q8B4101hN7P407moO`D0OWin101oOgl507inOP@0Ph>3101mOGd508:2PP@0NGUi101l
O7`507QhN1H0b>3H000E0<SPf0D0KFe]101GEeL4065QH@D0FUYJ1014A4@504M7A`@0EeMG1012@T85
03De=@@0;bl_1@0/;2`4034a<@@0?Cdm1@1ADE4404I6APD0AdM7101EEED404i>CPD0<c<c100f=SH4
04i>CPD09bLW101ADE45079bLP@0Kfm_100k>c/502`/;0@0<C4a1@0b<S84030`<0@0;Rh^1@0/;2`4
034a<@D0:BTY100W9bL402XZ:PD0?Shn101ZJVX507EeM@@0Cdm?101SHf<506MWI`@0Xj>S1@2<S8`4
0;Rh^0@0/K6a1@2b/[890;Fe]@P0^k^k1@2f][H40:f][@D0YZJV102RXZ840:RXZ0D0Zj^[102_[jl5
0;>c/`@0/K6a102_[jl509nOW`T0ZJVY3@38h=P4075aL@@0O7al1@1`L70407IfMPD0KVi^101hN7P4
08j>SPD0NGUi101dM7@507QhN0@0Ph>3101jNWX507EeM@@0QhN71026QXH508N7Q`@0QXJ61@27QhL4
07alO0@0P8201@1nOWh40861P@D0Lg=c1025QHD408^;R`D0OGem1022PX8907moO`@0QXJ61@1mOGd4
07QhN0D0O7al1021PH4407YjNPD0P8201029RHT509RHV0@0O7al101^KVh507emO@@0T92@1@25QHD4
07moO`T0RHV91021PH4908B4Q0@0QXJ61@20P80407moO`D0Q8B4101hN7P407moO`D0OWin101oOgl5
07inOP@0Ph>3101mOGd508:2PP@0NGUi101lO7`507QhN1H0b>3H000E0<SPf0D0KFe]101GEeL4065Q
H@D0FUYJ1014A4@504M7A`@0EeMG1012@T8503De=@@0;bl_1@0/;2`4034a<@@0?Cdm1@1ADE4404I6
APD0AdM7101EEED404i>CPD0<c<c100f=SH404i>CPD09bLW101ADE45079bLP@0Kfm_100k>c/502`/
;0@0<C4a1@0b<S84030`<0@0;Rh^1@0/;2`4034a<@D0:BTY100W9bL402XZ:PD0?Shn101ZJVX507Ee
M@@0Cdm?101SHf<506MWI`@0Xj>S1@2<S8`40;Rh^0@0/K6a1@2b/[890;Fe]@P0^k^k1@2f][H40:f]
[@D0YZJV102RXZ840:RXZ0D0Zj^[102_[jl50;>c/`@0/K6a102_[jl509nOW`T0ZJVY3@38h=P4075a
L@@0O7al1@1`L70407IfMPD0KVi^101hN7P408j>SPD0NGUi101dM7@507QhN0@0Ph>3101jNWX507Ee
M@@0QhN71026QXH508N7Q`@0QXJ61@27QhL407alO0@0P8201@1nOWh40861P@D0Lg=c1025QHD408^;
R`D0OGem1022PX8907moO`@0QXJ61@1mOGd407QhN0D0O7al1021PH4407YjNPD0P8201029RHT509RH
V0@0O7al101^KVh507emO@@0T92@1@25QHD407moO`T0RHV91021PH4908B4Q0@0QXJ61@20P80407mo
O`D0Q8B4101hN7P407moO`D0OWin101oOgl507inOP@0Ph>3101mOGd508:2PP@0NGUi101lO7`507Qh
N1H0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o
0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3H
K@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0
b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]
0<SPf000o`38h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38
h=So0<SPf6d0b>3H003o0<SPf?l0b>3HK@38h=P00?l0b>3Ho`38h=Q]0<SPf000o`38h=So0<SPf6d0
b>3H003o0<SPf?l0b>3HK@38h=P00001\
\>"],
  ImageRangeCache->{{{0, 618.188}, {618.188, 0}} -> {-0.0500105, -0.0500105, \
0.00339706, 0.00339706}, {{14.6875, 309.063}, {603.438, 309.063}} -> \
{-4.95322, -4.96749, 0.228282, 0.228282}, {{309.063, 603.438}, {603.438, \
309.063}} -> {-72.1537, -4.96749, 0.228282, 0.228282}, {{14.6875, 309.063}, \
{309.063, 14.6875}} -> {-4.95322, -72.1679, 0.228282, 0.228282}, {{309.063, \
603.438}, {309.063, 14.6875}} -> {-72.1537, -72.1679, 0.228282, 0.228282}}]
}, Open  ]],

Cell["The transformation is reversible, as we now show.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Graphics[Raster[\((ImgIDWT[Interleave2[decomp]] + 128)\)/255]], 
        AspectRatio \[Rule] 1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5D6685BBB54029292428262D425238333932392F2F3835392F3A37434B513F3B382F2D26
2B283E6A66665A7165535C62676A736F76827D7C83837B837D81827E8385888989888887
8C8E928B8E8C908C88898A8B8E8A8A8D8E8A928E8F9292929293908D9195938F8E929295
9090999493969B979B9B9EA0ACB1C4CFCBD1CFBE
5A597093C19C3E282C29242A373630343837372B323B30322F4135444C4D4236372F2E30
2B2742696164607A644A5C62696D7575757C7C7E7A82847F7F7E807F8586868A8B88898B
8B9090888C8A8F8B8F87888B8D8B8F8E8D9191939595928F919292909698999195949492
9293979798969A9B9BA0A1A7AAAEC4CFD1CDCCC0
595A5F729AC2953A2A262A2D38342F364438322E3335332C343D384A413D422D2E34302C
292A416364675F7B59515E69766E6D7777787D7E818281818087837F8284838B8786898B
8F8C908C8B88898B928A8A8E908D8B8E8E9694939595949595979292979C9C9394979690
94919694959B9B999B9A9DA4ABB0C4D4D3CECDC5
60595D667CACC06E2F2A24282B2A2B3D4030333031312A2E363E2F4E443E3C312D362F27
262A466C65685C77585B63656F70717276797D7B7E818082847F82828088878B8889898E
8D888D8E8C888C90928D8C908E938D949196949499979593939998999899A09A99939392
96909797949699969A999DA5A5B0C2D2CFCECCC1
5F5A5B59708DBFB35B2C27242B2D32342E30292C32332B2D3133324B4339363031343228
27304C74606A676F565E636A6E7073787A7777817F7E7E858382827C7F85888B8787878E
8B8889908B8B918B8F8C8F8E8D8F8E95949796949598969794999898999F9B979593928F
94979A9A97909897979C96A3A5AABECED1CEC8BC
625A585F6176A0C8AA3F2824242934312D2C2C3135343032383C3D4C403D433A33322C30
302D4B77696E6169515E6169737273747D7A7C827D8080837F8182848288858B898D898D
8D8F8D8D8A8C8C8A8D8B8C918C9294989A97979997979A94979C9696979D999899949494
939598959294939797989A9EA4ABB8CACECDC7BB
5C6A595A62658AC3C791372C31262C322834312E31332E2D313731413D3C3B2E322F2C2B
28264A706F6E666654616C6C717170767F7A79827A7D7E7D7E797E83848582858C898991
898D8E8F8B888A8C8E8C8F918F949697999897979B9A9694989D999C9B9C9B979794929A
9895939294949491909497969CA9B6C6CDCAC1B7
4E6955515A6994B3C7C57E3927252C2B2A313238383B39403E43424C4142423C3A3A2F39
3A3A5C72746770625D636B6B6F72787B807F7F7D7F828584838386818588888A8F8A8F91
8A8B8A8C8C8B8E8D8C9090959099999A9A9A9C99999B98989B9F9E9C9F9D9B9B9897979A
98959795929493918E8E95989FA3B1BFC9C8C0B0
516063596276939CC1CBC374383537363641403E373733383A343D3F3836342C2E32272D
2C325A6F705D6E565660646A707476787B787D827A80807E7F8280848384888D8B898D8F
8A8E8D8A8C8F938F91919397969B979D979999999A9A9C9B9F9CA09D9D9C9D9A96949A98
999796949697929291918F959EA1ACBAC2C5BBA8
65586F6A63748789A4C2D0BA4B2F2E303030343431312D353433413638363632322F2C2C
30345C73735F695554646169717076777B7D7F807A7F807F7C817F8482848B8B898B898D
8F8D908F8F918E93948D8F919398999B979E999C9D9E9EA1A49F9D9D9D9C9E9B9A989A99
999693919691918F8F8D8D949499A5B3BABFB1A1
9E5B63705F6A777D8AABCFD4A13A322E2D34383635323A393E403E3A3833393435312F31
31386077815E6751545C656D6D7275787979797B7D7C7D7B787D828682828685868E8A8C
8A8D938E908E8F8E918F91958E94989A9B9A9A9C9A9F9E9D9EA29B9D9E9D9E9C9B9BA096
969896969690958F8A8D8A8B8D919DA4B2B6A59A
B48A60646A5E65757D8EC0D4CB7730292A292E2B2F2A3232332D4641343436313332292A
2D3164777957664E575B606E6D73737A79797F7C7D7C7E7A8181847E7D8381818A898588
908B919591908F92909095949495969F9A999C9C999B9B9EA09F9B9DA19C9E9A9C9E9A98
969396908F918F8A868785888D8F9798A6A49693
ADAC72647566636C7283A2D3D7C05225262A272426292D31383D41343031302F31272529
262E6776795E644B555B676A7374737576747B797D7E7D8081827C7F8386898689898789
8E8D938E8F918D91929394979893949B99999A9A9E9A96999E9E9FA29C989C999D9A979C
9592948F938D8C86838B828385878D8F968F8486
879794616A746B6C6F7384BBCFCF9D2D29252C23292A323A434E5A3435312A2730232A2B
2F35637D7563634F52596970716F717578787A7D7A7F81817F82847F828685878B8C868C
92918D918E949393909493959A94969E9D989A979DA09D9C9F9E9F9F9E9F9C9D98979195
94958F8D898E887F7D807F808280858788817679
606F7E6D6D7A7F84847A879BB5B4B7633127232324262A3B524B4B46452C2C2D2D27333B
342C577179685D53515C61696B70777674767E7E7F7E7B7E7F88818580868687868C878D
94928F9191989294909491959493989C9A9397989D9C9D9E9FA3989B9E9E9A9794969893
938D868686827D7A7A80828287848686827C7477
4C5E6470707B8B949694999FA8A4AE9E5F3727262023282E383C2C312F2B2A2B31262F2F
2A3163747368524A505E666C68746F717577807E817B7B7C807F82828188888A898A8B90
8E95939294939595939187969693969A97969C989B9E9CA19F9E9AA09E9A9C9594949592
9089827E7B7A7E7C8082848784868685847E7777
2C3B46698D899399A1ADADB1B6BEC0B9AE8129252627242A2F2B2C342E2C2E2F3228312C
3130606E6D644D4E506365666C75777175767D7D787E818083828385858A88868A8E9190
938C8F8F909597959795969D979A9C9D999A9C9A9B9F9EA09D9D9C9EA29B979891949490
90817B74787D7F7F837F807C7E837F817D776F6E
221F235192979EA2A2AFC2B9BEC0C7C6BCA23C2325232728292727272B2B2F2D2E2F2F29
24295F6B70664D4E535F66636A6C706F7875787A7A7D7D7E838283848389888A88909090
92909492919796989696939599979A9F9C9B9F9D9F9D9EA09D9F9F9E9C9B96949494938C
8B7C777A7E808278736C6560666D78746F696064
201C222F81A4A6AAB1B4C5B7BEBFC1BEBCAE6534232128282A2525262B2A3432342F2C27
272E5A6D7069474F555C626466696E7473797C79807D7D7F83828180858787888B8C8B93
93938E9493999796969598979494989D9C9FA09E9F9B9E9C9E9D9C9FA296969895948F8B
857B757A848384816957463B4751615D5C575559
25221F2158ADB1ADB3BAC4B4B7BDBCBEB7AEA27430292A232126262525262C382E2A2E2B
2B2D576A625F4B4951605E60626B70717579787A7A7B808182808282868A8988888B8A90
8F8D8E9A9696939999969B9C98959A9C9A9A9D9CA09F9E9F9F9EA09FA1989394918D8F8A
82777981848688836541323132404D59605A6371
201D1D1F37A2B4ACAFADBFB3B3B8BDB9B3AFA7A15B3C35272521222226292D2F2F252729
252E5E6E585B47504C565D62656A777379777D7C7A7D82807F7E8284878A8D8C8B8A9090
919090959B94929A94979A9C9598999D999F9C9E9C9E9C9E9D9D999F9D9C9692948A8A87
807478878485848A78563A38394959667273777E
2920211D258CAEA5A7A7B4B4A9B0B0B4B9B4B6B4997B4C2D292620222222302D2B262829
2534606F645C464D4C555C5D666D746F797A7D807C7D857F7D83838288868C8A918D8D8F
908D9295959697959A9895979597999C9C9F989D9E9E9EA09FA09D9B9E97968F948A8A84
716C71817F89878585837770757E7F8082847E7A
2A201B1B1D62A89DAAA8A6AFA9ACA7B1B5B5B8BDAD8C774F3729242626272C2931312F26
273258695B563E3A47555A60656E7473767D7C7F837D84807F83808586838B908E898D8D
978D8F988F96999397959797949B9C9CA09A979CA19F9F9E9E9C9B9A9B969192908B9480
746C747C7D878A8786878684868D89848B847E77
28261D1D1C3BA0A3A3A59F9FA6ACA19E9B9FA9BDBAAA8F5D412621201F2635282F282A29
28345B6A675A47443D53585F697072747676837B7F84817F7F8383868686878D8D8D908D
928D939091949C9796989B9C9C979C9D9E9B9E9D9EA59E9E9F9CA29D9A9794998F918F83
756B72787D858F8D8B89888A928D8F908C837E78
26312720212A78A9A1A6A49996928180757782A1ABBDB191653124242428263227232728
252C5D71635943454A4C5C5A696D6F74787B80787D7F8280818581838887898C8B928F90
908F8F9395979796999598A19B9D9F9C9F9F9F9F9FA29F9E9F9DA19E9A959292908B8C7E
786870767D86868D8D8E898C8D8C908E8A827C79
25302C212225478C989A968881766B6D6476838792A2AD9C6E372925262323272E242F46
252E57715B4E4643444E5957636B7672777A7B827E7C827F80828686868C888F8E91918D
8E8F939C9399969695979A9D9C9F9C9F9C9D9E9EA0A29E9F9D9F9F9D9A92938E8B8D8A7D
746B6D747D83878A8D8B888B908D8F888680807D
24243226221E224C7883787A7A67656C6C90B5ADA38D909A875A452D23222B252B282822
232E5A6D5A43404B4E51535F5F6A747176767D7F7D7C827D81838685878B8D8A8B8F9493
948F939B97979A98969A9A96999C9A9F99A29F9CA19FA2A4A3A1A19B999899928C8B8F7F
77726E737C8087868B888A898B8F8484817C7D7F
2323302F2B1E23285165677E856A6E727290B9C9C3A682977D3424231F1E232925222A25
292A5C6C5C413847484F565D67686C737575797D7F808482838287858886878C8B8D9091
9393959A9B99989897999A969A9D9E9DA2A39FA2A69EA2A4A4A3A19D9C98989691908E85
7C797572767C84858387868483827F84797B7B81
25312C372F1F1B212E4F4B6D877672807B7E9EC9CACAABA0A33C28221F25272B27262C25
252C596A5D3D42474D525958656A6D7574767B7E7D8080818585858C8782858A898D9492
979693999697979896949B9A9E9FA2A0A0A0A2A5A59EA3A5A29D9F9D9B9892958E8E908A
837C7772797D8286868B8783817E7B7C7A7C7B7E
2A24293A32212330212C285C898A7578787992BFCCCECABFC57F2F2222272B2922282727
283056645A4137484553575C6066717577777D8080808784848486868A878C8F86909092
96999397959894969A9D9B9C9C989EA3A2A0A5A4A4A0A4A4A3A4A19E9B9D9494928F8E88
857D7C7A7B7C7B82838C857D7F7B7D7E79757A7E
232532382F2C1F1F221E2244829A7B7176737FA8D0CFD0CCD0B94926232A26282C242425
22285360543C414A4B545D61676A71757779777F8080858181878386878B8C988A929090
969892999899989A9B9E9B9B9F9A9EA09FA3A7A7A4A3A09EA0A1A39F9E9D999591928988
87827E817F7E7C838387837E7C7B7F7F79757681
232E3D4E3523201B1E1C1F2F6B8F867370747690BFCDCBCECCCEA3382524262925262722
24254D664E3A4247454B5761676C7171797E807A7E80808382878889898A8E8E8F949390
91989B9796999A9EA29E9D9CA09F9F9FA2A6A8A2A6A4A5A2A0A4A5A2A69F9E9A93938C8E
85858484808181847D84827C7F7C7B797B797C7D
26324C734D2620211E1D1D25508395796F797678A5C7C8CECFCECE893125262527212329
2729495C48353C45494D5A62666C72747582837D7B8083867E8487898A8A8689909A9290
96969B9997A1A1A1A3A09E9FA0A2A3A2A5A8A5A3A8A9A8A4A5A8A2A6A69FA09B96919089
8A8883838382848481817B7C7D7978787A7B7C7D
333D5C857646241E1B1B1C233770A08B6D7E767591BEC3CACACCCFC3642821232526211F
272E4B5544353A444A515668696B706F7B7E7D7D81838185817F898B8B87888D92989196
97999A969BA19DA3A29A9E9EA2A4ABAAABAAA8A7A9A8AAA6A8A6A0A0A5A19E9B9598918C
8B8A86858083868785827D7E807C787A7B7C7B7D
345166887758241C1D1B1A1E2659929E716F6F7185A8C5C9CCCBCCCEB546272121232A25
232947563F3A383C45555569666C7076777D7D858182848082828487898D8B909093959D
979C9D98A09DA1A4A2A1A2A0AAA7AAA6A3ABACA8AAABA9A7A9A5A5A1A5A1999B9897928E
89868884838383878381817D827E7B787A7E7B7E
43627E937F60261D1F241D1E243B819C7F756E707EA0C6C7CACCCDCECCA53F2623232321
212B41573C37343C45505B64656C7074767C7981818083858687838689918F928E939397
959B9C9F9A9FA4A2A0A4A0A4AAACADA6A3ABADACA8A8ABAAA9AAA7A5A5A69E9D9D979488
878584868587868883828383817C77787D7B7E83
53749BAD9869261E2024231F20265B8C947C6E6B7490B6CEC6CDCFCDCDC98B3122272724
2B264455382F35394C565A65666F7173767E788385808385858586878B8B90938F959898
9898A09DA0A49C9DA0A3A8A4ADB1A9AAA7ACA8AEB0ABAAACACA5A7A0A5A69F9E98999491
8A85868686848886828580807F7B7A787B7C8282
5F80B6AD8A5129232328252028243B7A99836D6F6F81A0D1C7C9CBCCCDD1C15C27202623
2425404E3931383F4F545B62656C706F787C7D7E857F87848685848D8F8B8C9093989B99
999C9E9B9E9CA4A1A6A3AAACB2ADACACAFAEABACAEADA8A8ABA6A7A7A1A29F9995979591
8A88868984848787878A7E7B807F80797B7D8185
7993B2986E32212E22262B2B2827306090956D64707985C3CAC5C8CBCED1D4A72F222525
282F394837363C4751535E656E6D77747A807E83837E848286878A8D8D8D909794989697
989C9C9B9D9CA5A9A7ADABABB4AFADAFB1AFB2AFACA8A7ACACA7A9A7A4A1A29E9A999391
8A898588868587889186837F81817A7D7C7C8489
A49A9470492D2621222528242A2B2A4D80977964707B7DADCCBCC4C8CCD0D5C875352922
26273F43312F363D475164686C707779798080807F828084898C8D8B8D93929098919997
98999A9E9FA2A6A9A5ADA8ABB3AEAEAEB1B0B1B0B2AAA8ABADA8A8A8A4A39F9D9B979895
92908B8C8B89898B8B86847E817E7D817C838184
AC976C442C282B262126222320282833718F8E697074778FC7BCBDC4C7CBCFD1B3442A23
24282F3E2F343C434F5163686C707A7A7B7B7B7E8183888282868C8A8D8F909298959A99
9B96999D9DA0A5A5A5ADA7AEB1B0ACB1B5B1B2AFADABA9ABAAACAAA7A7A5A1A19D9A9293
938F8C888A8A90888F88858380827B7D79828283
907A452A222B2F29222122292622242A53859F787374777BB6C5B8BDC4C5C9D0CC973229
292935432C303C3D4B555F656E747F797678797F83828C84848589898F8F918E95969899
9C929B9B9AA2A7A3A7A9AAB2AFB3AFB1AFB1B8B1AEAEA9ABB0AEA5A6A5A49E9D9B9F9292
8C8E8F898B8C918B8A898984817C76847F808388
77582D252320232225242322221F212539729A8B737270749BC6B9BBBFC4C3C5CCC26A32
302A2D3A2D37343C4D59656C71757A7876787E83868487828585878C9094928E92919495
9C9D9BA2A2A2A8A6ACAFB0B1B0B8AEB2B4B5B7B0AFAFAFABB2ADA9A8A6A7A2A2A09A9695
8B8F918C8D94938E8A8B8586817F7E7D83808682
593E272524272C27232226322522221F295B8994766F6F7384C0C7BBBDC6BDBDC3CEAC3A
2F2B2D352E3236404F59656C727175757B7B82837E8289858886848B8F91909390909597
989DA2A7A9A5A8ABACB0B2B4B6B3B0AFB4B7B3ADAFAEA9AFB0AFABADA9A2A39E9B9B9796
918F93908D92948C91888886867E7F7C82848585
4331332C2827292A29252831252A201D223A769493707478759FCCBEB9C2C0BCBBCACA90
3523252C2B2E37454D596167757379757C7D7E83827A848186848589889296969593979A
9E9EA5A7A8AAADACB2ADB1B0B1B4B4B7BEB9B5AFADAEA8ABABA9ABA8AFA8A19FA09A9B9C
989393969095928C8D8C8A8486857B8081858489
542F2F383335242A2C2A29322B27282224335F90A48373777286BFCCB1BEC1BFBAC1D1C1
622827282C30344448555F6874747979787C80807F798083868A8C8E8D92989898979B98
9CA0A1A6ADADB0AEAEB3B5B3AEB6B3BABAB6B4ADB3ABABACB0ADACA8B0A6A4A59D9F9F98
96939495919495958C8E8C8A8587817E81838483
5F37302B23292B2F2C272632333026212A2C3C789794766D7D76A4CDB3B6BFBBBCBDCAD1
AF4229272D393637475761696D75787A787C7A7B7A7A8383868A8F918F91989899989D9C
9EA2A6A8AFAEAEADB1B1B4B3B4B4B2B4B2B0AFACB6ADAFB0B3AEB0AAACAEA7A6A29F9D9A
98929999929195948F8C8C8A848983817C818482
503A2E2E26322A30322A2D2E2F292726282A325C889B7F69797983B2B8ACBBBDC0BEC8D1
CD983524262F323B415461656E727A777B7C7C7F7D7C868187898B8F938E95969B9B9C9C
A5A4A7A8ACAAACACB1B3B4B4B3B3B0ADB0AEAEAEB3B0ADADB2B3B1ABAAA9A5A2A19E9B9B
9B9A909291908E928B8B8884848081847F7F8082
3738292E2F322E2D2B2C2D2F2A2F3329292A303A6C94977373787590BCA8B6C1C1C3C3CD
D2C97C2D21282D38475560626C6F777C7B7A7E80807F87818A888E9494919397979D9D9D
A5A5A7A7AAAEADACB0B1B3B0B5AFB0B4B2B7B4AEAEAFB4B3B0B3B2B2ADAAA8A6A1A19A9D
999A9092929490948A8D8A818587858382827B7F
3E352F2D2E2E2E2F2D2E302E2D2E2F31302B2C365389AA807372747DB5B5B3BCC0C3C3C6
CFCFBD5829242E34444D575F696F777577797C7D7E8682838D898D9493979897989A9EA1
A2A3A7A9ABAEADABAEB3B2B4B0ACAAB4B3B0B1B1B2B1B0ADAEB2AFB2AFADAAA9A7A49B9C
9493949498958E928A8D86828886847F84838285
4A302D3335342F3A2D2D2C30302D2B3029292926316F9E9470666F76A6C0ABB4BDBCC4C2
C9D0CCA83D2A2836414B545A66717574757A7D7E807E81868A8C8D9290949898959E9EA2
9FA4A7AEACADA9ADAFB6B5AEA8AAABB2B2B1AFB6B3B1B0B0ADAEAFB1B0B0A9AAA4A39F9A
93919595949193908C8C85858586877D81838285
532F272E32362D2C31302B3035302B2A2C2927282D5493A27D66677088BBB4AEB9BCC2BF
C2CBCEC8903430333F4C535F5F6F727579787A7B837F8384888A8B90929799959A9DA0A0
A2A7A8A8AEA7A7B1ACB4B0ADA8B1B6B6B1B1B0AFACABA5A9AEB2AEB2ABAEAAA8A3A09A98
9696908E8E90918F8C8B86817E87877C7F808084
4227252834333429262F2B2A292F2D2D2E2B29282D42779C986E616A76A4BEA7B1BCBFBB
BDC6CCCDC17A36343D474B56676D727075787C7B83818084878C908F94989C969B9D9FA0
A5A4A8A8ACA7ADADACB0ADAEADB0B2B2ADAFACAAACADA8A4ADB1B1B2AEB2ACA7A29B9B98
9593908A8E8D948F8B8884878182877C807A7F83
2F2C2D2D36332E2E2C2D2830312C3431372C2B322C29528BA57E6967708CC0B2ABB5BCBE
BDC2C6C9C9BB593637455152616B70716F797E7A8482828A8B8B8D8D92979D9AA19B9F9F
A2A9A9A4A5A5AAADA9B1ADADACABADABACADABAAACADA8A9A8A9A9B0B0ADA8ACA09C9A9A
95948D888E8E96898B8980838281817A867A7E87
3134313337362E2B302C282F322F35332D2E313127273A6F969B746C6982ACBEA0B3B8BF
C0BEC4C3C7CCB04C39434B575F647070767C7A797F7F7F8C8B8B8A93939698979E9D9F9F
A7AAA9A1A3A2AAACAEB4ACABA9A3A6A5A8A6A9ACAEAEADACA8A8AAA6A8ACA8AAA3A2A099
948E8A888D8D8D8A858387828183847F85807F89
333030333431262B2B2C282C31353136353234352A2E2C5082A37F67656E8EB9A3B1B6BC
BBBDC0C2C8CCCCA4403F47515C5F6C7074787B7C837D868D898C8E95969898989D9FA09E
A8A9A7A3A5A2AAACACB2ABA9A8A3A6AAA4A7A8AEB1B0AEACA5A9A6A6A6A7A7A6A1A69B9F
958D88898B8E92908A86878584867F8281818488
322B2F32302C302E27302E31323F30303030332B2A2A2C386B92956F626475A2B5AAB2B5
BABDBDC6C9CFCEC78A40404D59616A71717576777D858689858A8D979497969CA198A1A2
A4A7A4A6A0A4A7AAADACA6A6A0A5A7A5A8A3A7A9ABADA9A9B1AEA9A4A6ACB0A4A6AEA59E
938C8E8888908F8E8B8689868181838182807F8B
2C2C2D2F2D272C31282B293036372D33323130302627282D47829E8469656B87B4ADB1B4
B6BBBBC3C3CACFCDC1813F4554606671706F72787F878687838E8C9694979C9C9C9B9FA4
A1A1A2A49EA6A1A1A39F9A9F9BA2A29D9E9FA6A4ABAAA3A6B1ACAEA5A2ACACA0A2AAA4A4
958C8D8585888A8F8E888882827E847F7F807D8C
302D292C2E2E2D2C2B2F2934352F2F322A2F32292521252330668F9F7C64687BA4BBACB6
B1B3B7BAC0C6CBCCCEBB703C4E555E656E70767879828787868D8E989699979A97979A9B
A0A39EA39FA09C9A9A97949696989B96999E9B9C9CA5A0A2A4A5A7AAA5A7A5A29FA6A3A7
9C8E8B827F84868B8C8789807E8084828283878D
2B2F2C2F3231332C272E31383633302F2D2D2C2723242523243F799C8F736B6F96C1B2AB
A6AAB1B5BCBFC8CCCFCCB66047515C5F676E727B7A7C838B88909294999A9A989793969E
949B9B9F9A9D9A9597918E9291938F909093929298969C9DA0A1A8A8A7A3A4A49CA1A3A7
A0928683858484868A8B87847F817C837C81848E
272B342E2D2B2E2F302D2E362C2E2F2B2F2A3027282B262122286085A1826B677EA9C0A8
A1ABB2B6B7B5C1C7C9CACAA95F4A565D636D75757D7F838A888D939494959B999A9A9698
969497999594939095908B94928F908D8E908E8F8E969796979A9B9DA1A3A5A49A9DA1A3
A1988B81818188848A88868781837E827F82838C
342A2C343432312E282E3733332E3437342C3030271E212020233C76999B6E63708CB9AA
9FA7B0B3B3B0BBC2CAC9CBC8A25D4F535C63717679848386878B8C8F9392979A92969297
999193918B8F919495958C8A94908D8988898B8D8D94918C95959B999F9FA49E9A949699
9C9C8D837A7B81848689868285817F7F7D838590
2D2A2C312F3433292E33302E2F2C2F343532362D2627261C1E23265987A180636673A8B8
A3A3A8B3ADB2B5BDC5C8CBC6C49E595151606B6E7B807E8385878E92958D8D9090969497
92948B8F8C8F9396979084838C89827C7E847F88888585778C958E90A099999696969191
96958F83777A80818884857E8383807D80868991
2E31334429292B2F2F2E2D2E2A2C2C303236342D28252623222223326B8D956E626990BB
B7A2A1B0ADB6B8BCC4C4CBC9C5C59A59515F666E767C818289858C8D93858D8B91949392
8E928D9190909695948E837781817B716E867F888A8F7B6C868A8186A692929799979992
8E8E847F75797F838384847F81837E7F82888A91
282B2D262D292D2C2C3034342B2A2F39382F302C2327262323222126467C9980625C7FB3
C3AD9FA9AAB3B3B8C1C2C8CAC5C7C1965953696C747E7E8388858A8D8D8A8E8E908F8F91
8E8C91958F8C908D8E85816D77807A6E5C808089868B716E807B667DA698939CA5A2A399
978A837E7A777A7C8284847D838081807E8A9495
2C262A2D2E2B302F2B2D2E312F3030333239332E2B312426222320202A5E899C6F59679C
C0C2A2A4A8AFB0BBBDC2C8CEC6C5C6C2966060696E76787F8583868B848789898F8D9291
908F9292898684888A837A6D68777D6459768182847F696A8073657F9FA3A8A7B3AFAFA8
9E90887D777D787E7C81818283848782818A8F96
302A23292A2F2C362D2E2F30302B2A2B322C3A2D39282425242523222239779C875F6181
B7CAB9A6A7AAB1B6BABEC3CACBC9C2C2BF8A5E5F68757781827C828A81878285928E8F8F
8D8F8F8D8678767D7E7F7E6C6D6B7C6F607A858892969193A7A08D9FA2A4AFACACABAEAD
9F948C837E807C7F747B827B7E808383868D9295
2824252B252C2F343231303138322E3930312F2A382F27262D22211F232C52849F6D566C
9BC2CBAFA3A7ACB6B9BCBEC8C9CAC6C4C5BE94625C6C787B7C7B81867E817D8493939190
8F8D878881706D72696C78726F7485858F979B979EA9A7ACB2B2AAB1B4BBBDB1A09B9794
88888984837E79777973788083818079828D9497
2C2724272931342C312D303C403A362E2C3032443B2F342B232725222C293B6E91935F60
7CACCEBF9EA3A6AEB4BABBC5C8CAC8C6C4BFBC8F606277797B7B7F8181807E889093908D
8D8C827C746B6369534B717D878A92959D9D9FA8ADB0BBBBC1C4C1B9AFA7AA9B928E877C
75768280867E7D7877797B8082828580848E949A
322C27272429303938322E36433F2E2E36302C2E313727242825242120392A4D859B7C63
6688C2C59C959FADB1B9B5C0C7C7C6C7C5C1C1BC926669727F7C7B7A7C7E7B878E8B8D86
8685726A5F5B5D5F5E6E77828B8D83858A939EB6BBC1C5C7CBCED1CEC7B69E908991988B
73707C83827D797275797C8481828185848D8D99
2C2B362C2F2B363D3A362D283740312726292C2F303526252E2D2123212A363C58889663
5866A3C2AB969CACB5B2B4BDC3C3C7C9C5C7C1C4C19C6C6A73777A72767E7C838C838F88
7C766353434352637377777C84786C65667489A3BAC5C6CACDCFD1CFCAC6B09788908E94
716E79857E747179747C7B7C7F82828386869094
3C35282E2A2E34454F3D2A29313A322D2C282D2D36382827272421252A3032353F6E957C
53567EAFB99F98A9B0B3B4BCBEC3C7C9CAC4C5C5C5C4A06D68717576767F8284827C827C
756C56412F2F496371707578715F523F424B587F9EBCCACBCACACECCC6C3BCA3948A8478
6A747E7A7070737C7D78767B7A86848B8A8F949B
402E2C282C283A52744D2A2C3430352C2D2B2B3534302A302C27282B272E28252C407D8A
67516689A6A19097A3A8ABBBB9C1C6C5C8C7C5C4C2C7C3986C6370727A7E817D7475796D
64604A322B33445C69727D71593E39363D3A414D6BA0C6D0CED0CFD1CAC8C0B09E837261
667D7D74666F72777C75717B818286898A8E939B
38282627262D40657F4F352E3129352B29312D313D2D282D262C2B28232D2724262F5A78
73515C7D97B19E93979399A2AAB4BBC3C6C9CAC8C5C5C3C298676D6573787A756E64615F
564E372F3345535A6C7F73583B3C4F575A504D374171ADCFD3D2D3D3CDCECAB69E7B5D54
637E7666626B6F6F7572767A80808688899097A2
382E2B292B31457977463E2C292A2C2A2D2C2A303A2E2A2628292B2B25272325252E4A69
8472566C93BCBFA8A1999599A8ADB3BEC3CACACBC6C1C6C7C793696267746E695C54524E
423B2E2B2D454A5D757963433A546256565B534839427EC5D1CED0D2CDCEC8B6956C4C46
6C7E6A5C6070706D7076797A7D81858A888D959C
352A3026272E528854364430302324262F262E37382F2B29273439322B25282D35484A62
899D756074A9CDBFAAA4ADAAB2BBB6BDBCC8C9CBC6C6CDC9C8C28D5D616B656156534035
3330312D2F42475F736B47345C625A4842425A6C4A3557B1CFCCCCCECBC8BFAB80584658
7C785E5A6C7772707173787B818687888B8D9199
28352B2C2C34668D49313D35292729282E2E2F2C3A32322A2B2A343A342A292F494B393B
74988E675C8CC2C9B4A4AFB6B3B9B9B8B7C0CCCFCBC7C9C9C4C9BD7A505B5E5651443838
35332A2E3438465C675A32395E5D4C30292B45704D38429DCCCCC6C6C6C1AC906246445D
836E545B747A75747173888284898B89908C8F99
27382E272C3E7A7D3F2B352B2C282A2B2933302F312E2F2B2B2D404841383A2526272125
528DA17E606C9CC6BDA4ADAFB1B7B2B1B7B9C3CECBCAC7C1C8C5CBB76B515258554E4438
31352C2A2C3341525A51323C504F30262427385A413248A3CCCCC7C0C0B98B6B483C3E68
6C544B647B7C787A7779808782878B8B968D919A
2C302D2E304780652A2F2D31312E2B322F2B2D30323B3B2D333F505A55322A2722211F21
3272989C6B5F79B1C8B0A4A8ACB3B5AFB5B8B6CACEC9C7C1C5C5C5C4AF694C5057554C44
3C322A292A33353D4D432B2F3E3C2D2724285857415679AECACCBFB0A39A61452B2B3B4C
4A3F4F6D7B827C797679808A868C8B9290919499
31303840334F8D53282E2C2C2F2B282928252B344867604A5A536D5E2F292A2823252220
26538C9F85656592C3C6ABACA6AFB2AEB5B5B4C4C9CAC4C7C5C0BEC0C8AE614448504B4B
463A292F3130313035352F2B363132282E304C3E455E80A2C1C0AF9577623B2A2726272A
2C33516E8187817E7D807E8788858E8C93959899
2F3A5256355C8747252D34322C252B292B2A303E6E7A706D66523B2B27272D2922222621
21336A93A6715F7EACC9BDA7A9AAABAFB3B9B9C4C9CDCAC2C4BEBEC3C1C5A659434B493E
3B42333030342F30302F372F33302E2C2E2F2C3238465A8AA2968E684E382A29292B262A
2E436475848884817E8082888A8B8A8F92969499
2A3F553D2D5E82382C2C2A2826242429252A4169797972674828242926272D2F25292722
21234580A195646490B9C6AFA7A4ACB1B0B8B8C2C5CDCAC3C2C0BDBFBFBDC5A75E4A4141
43433935322F30353533353733352D2C2A2F2E2F304F4262776F5C46392E2A272E29262E
3C5673818B8787837D8282858D8D90979394999D
37563A2F3259732E26292724272525203035707971726040262624272B2F33342A20262A
1B1F265A90AD76677B9AC1C3A6A6ACB0ADB6B4B9C4C8CBC3C1C2BABCBEB9C2C6A2584640
3F4B3B36373935323534343A332F32342E302E2F2C33373F544737332E282E2727302837
586F8388898180837B7E83828C8F8B9294949C9D
4A472D303163672E2B262B242826272B305C7B7C6E4F322D2A2E282B292F2E2C25242C33
1D1F1F3978A098806D7DAACBB4A7ADB3AFB1B7BBC4C8CBC5C2BEB9B7BAB4BBC6C89D5041
47464744433F3A3533363433343431322F31302E323B30383936412C2E28262C292A385E
838A8D82827F847D7E83828F8C8E909197999C9E
582F2C2A2F5D652F282622232631303A497D7865412F28252B2B2C392F2F302826242427
1F2523284F91A0886E668DBCC0A6ACAAADB0B3BBC3C6CBC7C9C2BBB9BBB6B6BFC5C99F5A
484E564D5048473C343B4038363935323831323533353532312D2B2D2B29282C35444B6A
8A8C8880807A85837D7A8989899292979B9E9C9F
4027292D36595D2B27262624292E30435C76603A2A292C2F322D282F2D2E332930262423
283D2122276E8F9F77656FA2BFB9A8AAAAB0AEB6BFC4CBCCCBC7BCB9B5ACB1B7BFC6CDA6
5E4F514F5E574D454657544040433E393B3936322C32353C37382F2B2F303038537B6461
7888817C797A7B7C777A84898C8F969A9FA19A9D
31302D2D3C545E312F2D262429333E5F606C573425302B2B2C2E2D342A2E2B2B2A2E2727
443F1E1D223E81A28D6A697CB0C6B5A4AAA8ADB1BBC1C5C8C8CAC0B5B3A9AEADB7BDC6CA
AD6454555F6260646764604A4B49435249513B362F3851695E4B302E434540546F798057
6580777A75737474777A80868D93999C9DA2A09D
2C2C312A305B57342E29252324304D676C6234282B2528262B34322E2D262C2A25282D3B
55261C1E212C6194A173686B8CB9C1B0A4ACA7B2BBBDC2C4CBC8C3B9B1A8A8A6B2BABCC4
CCB275556460686C6B655E5F626666696D6B573E2F456F91847C5344657049676E7B7C6B
5F75746F6D7170666D79818A939B9F9A9EA3A3A2
302F292A3C5351322626282A30315565685B2D272828242A2A302F28282A28312D385262
3D2922262121357B9699716D779EBCC2A7A3ACAEAFB8C0C0C3C7C5BBACA3A1A2A6B7BAC2
C8C8B68264626C7171727875767D78757C816E58335A8195928B7460777D5B5971737C71
69646E635D6461686D7A85989C9D9C9DA1A6A4A5
28252C29344C40372B27263028385766664C352A23222C2D2C2A3128272A3335436C6E41
2B312F221E20214A7B9E8E7B7281A3BFB9A8A8A9ABB2B8BDC1C6C5BFB5A99AA19CB1B5BE
C4C7C7BD956C6F71787E7D7B7C8A8786848A83734F7B9B9D9B9D89718489765B6C656A64
5E575D5A515A5C626F778F9EA5A4A3A3A7AAA2A5
2429312634473B3E372E2A2C33395B5D613C3830242424292829272A3031595360855225
2B495C27201D1F32628EA796827182A8C3B7A1A8ACB1B3B8BBC7C6C4BBA7969A99A8ABBA
BFC1C5C7C09E6F6E7B828283858992938E928A757A90A5A3A09B8F7F818A7E5B685A5E55
544F4B4E484E4E60768796A6AAA9A6A8A7ABAAAD
26242F3345614C463C373D63463F5B5C4327353B2929282B272529232D334F5F66765426
2D5B592E2A1F1D2439759AA7886E688FB7C3ACA7AAADB4B4BEC2C6C7BFACA39696A1A9B3
BCBEC4C5C7C1AB7C74787A86898E97999A958E7B969D9FA3A09A8B857E7E736161565348
48443F3F414F5B798895A1A7ABA7ABA4A7ABABAD
25282727334D3F423A2B3D532A334A543429363E2A28232C29202829345066593D696125
335D3A2D3E2228272A5085A2907264739ABFBDA69EAAB0B2B8BBC1C6C4B3A69B949CA5A8
B2BBBDC0C5C3BDB1887679838B919198999998929DA29B96958F817A6D605D52464D4341
3F39464F59678196A0A9AFABAAADABA8ABAAABB0
212827262A3C4C424E4C3B35293B4F4835302B3C2D2727282A272A2E4A6D6033284E6328
4B5C2B364E28221D2F3A6E8D9E816562799BBFB1A1ABAFB0B7B9BAC3C7BDAF9B979A9CAB
ACBCBDBAC6C3C3C0B9927B7D84898F969C9696979794918C847D74685C4B433B463D3D44
4C585E71848D9BA7A9AFB0ADAFB5B1AEACAEAEB1
242B34232A34353C5642323B344746392F2A2C3A372F322B30302C4260684E46323C602E
5B53252D55311F2725233E75979F6E5B607BAAB9AEA6ADACB4B2B8C0C2C4B5A59A9C989F
A8B6BCBBBDC2C3C2C1BA9979767A8289908C8E8D897F79756E6B645B503F3F4447494B59
6A6F7A8D9EA5A8B0B3B0AFB1B3B4B3B4B0ACACAC
2828362E2730302F383738343F4A393329302F36392D2B272F48464F5A52323D3D345733
694E262F5C341D2727202A4C84A6836C5C6488B0BFAEA9AAACAFB5B8BEC2BBA9979A989E
9EB6BABEBEC2C4C2C1C2C19E7666686E76787977756C666067655B534D57555D656B727D
8592989FA7AEB0B9B5B5B0ADB1B3B2B1AFAFADAA
262B412C2C2E383433392A34353A302B2F2A2C353A372E323839352E4A462F2B2C386049
6C3E30325F422A25201D232B6D8B9982635D6C8FB5C1ACA5ACAEB3B2BFC0BBAD9A9D999C
9DADB8BDC0C3C4C6C5C0C0BFAA785555575861616066635B6068646456666E737A7C8690
9CA3A6ADAFB3B3B6B6B5B1B2B3B0B0AFB5ADAAAF
23263D3233393F39342F2F2F3340322831292A2B342C2E353335312C47372A2929306555
6C3929325B5B37322E291E233B798CA0785F647297C6BAA9ABA6A7B0B9B9B7ABA39A9B96
9BA4B3BDC3C1C0C2C5C0BEBBB9B0894F454755595D656A6E6874797D7E7D84878994989E
A6A6ACB1AFB5B4B4B7B5B5B4AEB3B3AFAFB2AFB4
262230373235484D463E3C323E432D282C28252A282D3132333A332F57472424262C5465
6C3C23234A6D4145503B27212A457D9D97745B657DAAC6B9A4A8A7ABB3B3B7ABA69A9C96
9DA6B2B8C0C0C0BEC6BFBEBFBBB6B8A36D4E4A5266756E797986898E93919498989EA4AB
AAAEAEAAB1B4B0B4B6B4B0B4AEAEB1B0B1B2AFB5
22292F33292A32405A615F5043463A3A312B272C292A2C3435382B315A582D2326263C69
633D25243A6A412C3440362E2F2B5883A689605D6187B4C2AFA3A6B0ACB3B2AEA5A69B9C
9EA7B3B7BFBEBEBABFBDB9B4B9B4B6B5A5896C64687C7B8A8A8E939499A0A3A3A5A5A8A9
A6AEB1AFB2AFB0B3B3B4B2B0B2B0B1AFB4B7B5B8
2621253725282F384853666E565056433E312C2C2D2D313E38332D2B476F2F2728263864
753D29252C5C662A2B30383226242E648E9A735F596994B4B9ACA0A9A6B0ABAEA9A59FA1
9EA7B0BDBFBEBABAB9BFBCB7B2B6B2B0B4ACA28C7C858B9397969E9FA2A1A3A4A7A4A6AF
A9A8AEB0AEB1B1B2B1B3B6B7AFB5B2AFB6B6B7B7
27292A34372334474B444E687857494F48353127282F28383D31252B4472332A282B3F5E
723E36292B417D3A29242D342E21223E768C906956597290B9B89FA0A7A7A5A8AAA59D9F
A1A9AFBEBEBEBDBAB5C0BAB7ADAFB2B8AFAEB2A89E959598A0A0A1A3A3A7A5A5A7A3A7A9
A7A9ABABAEAFB4B1B1AFB1B2B2B1B0B0B4B2B8B8
363424283D2C3A3F3B3B33476D71423946363425272E2C3C37292827376B4D272A2C3F5D
5D3A3B3B282A5D753E282C282520292B49788775635C66799ABBB0A1A0A4A3A5A29C9E9E
A3A6AFBCBEC2BCB7B4BCB7B8B2AAAEB9B5ACA9A6A6A79B989AA1A4A8A2A4A6A4A4A1A6A3
A9A7A7ACABB4B2ADB0B0B0B2B0B2B4AEAEB1B6BC
404F2B2433373D2F322D2E37426B686547363B2A25222B3B372E26293759642A252A4751
583940432F273C78714130231D1E2020325372767E6C636A839EB4AEA29DA1A1A09FA1A1
A0A6ADBCBBBEBEB5B7B9B7B4AC9CA2B6B9B6ACA3A7A6A49B9A9A9CA1A6A9A4A1A3A29EA4
A9A7A6A8ADB0ADAEADAEAFB1B2B4B4B1B2B4B8BE
3A6234292839282524272C363E4D6369623F3637282930393C2E2B2C2D52642D262D4A3C
3E392931322D2E638C61291F1F1D1F21283E6C8E97847C716E86A7BCAD9D9EA3A09FA2A1
A6ACAFBBBCBABBBCBBBBBBB2AE908FABB5BCB8A7A9A7A6A19E9A9B9CA0A5A6A39E9DA3A1
A6A1A8A8B0ABB0ADADB0B0AEB4B5B6B2B6B8B9BE
274A5432313C2A2525283452483E395A62533D322628293239372C292940663B273B5A31
343225263245344F7A532120231E1E203162678E8EA1887D6A7488A3B2A5A0A4A19CA2A2
A5AFB3C0BCBAB9BBB8BBB9AFA48A84ABB0B9C3B8AEA8A69F9C9E9C9B989EA09E9E9EA3A0
A2A6A5ACAAAEAFABACACB0AFAFB4B4B3B7B6BCBD
2931453327302C26293449613B2E293B55584A392E2B2F3831392A2C2A3C5F412B455D33
2D37272B2E3D364F653F241F2120202C4F7D675F729BA187746F7A84ABAFA3A4A29DA6A6
AAB4B5BDBBBAB6BFBBB8B1A098747DA9B0BCC3C0B6AFA6A2A199979B969B9A9B999BA0A4
A1A3A5A9AAADAAA9ACAFB1B1B4B0B7B5B7B5BDC1
2926363728292B2C3348684B3625322E3E574E35342D3C362F3B2A302A36594B323D4E2F
3137312E422D344E533F23231F20243373865A3156819F947D6F777A90B7A99DA2A5A5AB
AEB3B3BABEBAB9BBBBBAAE929A7681ACABB8C0C2BEB8AAABA19D999CA2A59A989B98A1A1
A0A3A2A8AAAEADACAEADB3AEB3B0B0B2B5B7BBBD
2328292E292A2A34476B5F3B312B2F30334D5C46362D2C35383A2D2C2E334A542F343B28
2F2E3451562A324D51412B2823202B45947B4B202C6687A0907A777F8095B1AA9DA7A7AE
B1AEB0BCC3BBB8BBB9B9AC8C9B7D88B0ADB1BAC0C5C1B6AFA9A4A09C9BA9A2939C9D9F9D
A99DA1A8A9A9ABAEAEADAEAEB3B0B0B9B8B8BAC3
2B282B2B292A2B335A6C4D3F3E3D342F3F41484B312F2A32394732312C303D523F38382F
282C3868612E4A514C482F2722242E6E91692E1D2336698AA28A787A727B96BAABA6A6AC
ADACB3BFC2BCBABAB4B9AF8998878BAAA6ADB4BCC5C9C0B2ACA7A2A19FA1AAA29C96999B
A1A09CA3A6A9AAABAEAAAEACB0ABB2BDBBB8BFC1
252729232D282F45685733474B4E352B2C2F3A423131313039383536333239484B3A3926
272C386A5B3C67434251473733344F9A88512A1F212041788BAA8579707781A2B6B3AAAA
AAADBBB8BBBEB4B4ADB6B2939A8F95A7A1A4B2B9C6C6C5BCAEAAA2A5A6A1A4A6A797939A
9A9E9BA5A2A9A5A8ABADAFABADB4B5B8B7BCBEC3
2B27252C2929314D6E492C3336383E332E2D353D47302D3337333A423131373B483D3526
242E4769594E643C4B59615D565677A68A5E271D1E202A46769A9B83787B7881AABEB6A5
AAACB9B3B8BBB6B5ACB5B399919298A7A0A3AEB6C3C9C7C3B6ADA5A7A8A9A49FA0A69493
989B9CA09FA3A2A6ADAAA9A8AEB3B7B4BABBBDBF
2D2926272E282B576E3E272B2E2A38403F2F353744342C2F34383D373132312E443C312E
313C4B5548595B4568655F52533E68A48C6F36231D1D20295285979B8079727B8EAFC0B7
A6ACB8B5BAB0B2B0B3B3B1A18D90A4A6A6AAB1B7C0C7C5CABEB0A8A6ADADABA4A2A3A49D
95929B9CA1A0A2A6AAABABAAA8ACB4B8BBBDC0C1
3A2729252E39345B693F2527272F3047513E303840422B292D383438362A2B2E3A483B2D
3938334649666C6F79594C3B3B2D5E986A41251F1C201D252E5983A196857C737B93B4BD
A9AAB0B8B9AEAEA9A8ABAE998A90A7A8A7A6B6BABDBFBFC4BFB3ABA5A9ACA7A7A9A7A2A5
9991969B9D9C9FA6A6A8A7A9ADAFB7B8BAC1C2BE
322B32262F3538696D41272A292F2E414C47382C363D302D333732423537292E36413C38
3734323F607269787E50402A35366889582920262024221E24365D91A994847B777D95B6
B9A9A8B6B3AEAAA6A3B0A3948B8FA9B5ADACAFAEB9BEC3BFBAB6ACA7ACABA7ABADA8A7AB
A5A0959394979DA5A6A9ABA8ADADB3B7B9BEBFBE
3F372E2A2C2C3C686D4D2E312C2B2B303E473F32333B353235313736442E2B2E3B3E4039
3232374E636E675C7A3F372D333B8089472524281F24232823292B6291A5958174727BA0
B5B9A5AEADA8A9A1A8A8AA96878EA9B6B1A9A8AFB9BCC0C6B9B8AFA7AAABA9AAACA9ABAE
AAAFA19693959CA3A6A5A9A7AEACB2B0BABDBFB9
4F5247332B2C35666D49342D2A2A2C2E3646463A3B3C392A2B2E2F2F3B353134433E4239
3634445A60633B436A372C2F3450908137292D2A27242123202124346B9BA08F786B6A7D
9BB5B5ACABA5A5A6A6A7A394848DA7B1ADA39FB1BAC1BEBDB8B7B1A7A7A7A8AAABABAAAB
ADAEACA79C9395A2A0A2A9AAADAFB0AEB6BABCBB
5C5C5A43392E3754685A322D292A2D262D4043372E413A322C2E342B303A3C414C3A3B41
353448545C4F3137613A2C2E406F8F712C2E292327262322211F2025367097A88E746772
83A0B3BFB1A9A4A5A4A5A08E8489A4A9A59E9FA9B6C1BBB5ADB6B4ABACACA9A9ACA6A8A4
AAA8B2B3AF9D8A939D9FA6A7A9ACAFAFB4B9BBB7
43424435342E2E5561623E2D2A272D292D343B2E2E383E33312F36313340514C4A413D44
39414D465950292B4B3B352D59888A5E272926242E282323211D1E1F264173A4AC887167
74879FB6BFADA6A4A6A5A38D86809BA7A4ACACA2B0C0BFB6ADACBDAEA7ADAAA9AAA1A7A0
A8A3AEB0B7B59E8F999FA6A5AAB2ADAFB4BBB4B9
50563F2F2E3233515E604D322B2A29272D3237332F313B3332352E333853544848454245
41433A4061562B2E3E40373C57928E5B28272C2D2B2A25242A211E1E21254A85A49C8970
6A7284A0BABDA7A4A5A4A386808399AFB5B6AEA4B2C1C0B8B9B3BBB3A9A7A6A0A8A0A4A1
A5A4AEAFB4BBB5A59B9C9BA4A7AEACADB5B6B3BD
7569472D272B2D3E575F562C2D292F262B2F36342D2B32302D3134384A564F453A3F494B
4540314562582B2D3C3C2C32518E8558313E404B433E2E29262423231F212956829AA088
716C68789FB8B5A0A7A298807B8EA0BBBAB1B4A6B7BCC3BCBCBEB8B5ADAAACA2A4A39FA1
9E9FA7B1B4B6BCB1B09F989CA4A8A8A7AFB0B4BA
786857302C262B363F5B5D362D2F2C2B352A2A2A2B2E30312B37434C54504E3B3F485655
45382838675324232D392B3B629187635651646F63593325212A22241F22282E50869FA2
81665D637C9EB5ABA1A48E7A7B86B0BEBAAEAFB4B5C0C1BFBFC1BFB5AEAAA6A2A5A29F9C
A19FA6AAADB5B9B6B2B0A29EA0A4A7ADADADB0BB
725D342D26292F3C33435847413330302B2D312D3132382F3134465C50533B3F4B4E594B
3D2C2E3A625325232A3731537288876B685E5F5D48352523262A242125242521325B839A
94755A53667696B4B6A589788D95ACBBBCB6B0B5BBBABCC0C2C1C1BDB6B3A7A9A5A5A1A1
A1A6A5AAAFACB4B7B6B2ADA7A4A1A6ABADACB1B8
76522E272B313B342B3C54503D39312C2B2D2F2F352F2E2B2F3E585F58423A415557604D
2B272F405750252A2C3A5C687D8D865C463F362F2E2A31292A26292322222428262F5F7E
937A6669605C7795B5AE8677A69EA7BCB6B4B4B5B6B5BABCC1BEBFBEB9B4B1A9A2A49B9C
A2A4A5A8ABACB0B5B6B3B1A6A29BA0A5ACAEB6B6
765D4335353D392E2B384E5F4A36342B2D333129312F3233394A62594A3E45475254613B
2B2F3648564127282E4776757E8162392A2A2D2F2E3031342B2F2C2E232222242629375F
767C6C755C4E5B7793A38B7AB19893B9B5B3B6B4B8B6B8BABCBBBDBBB6B5B3AAA5A5A1A0
A1A0A6A4A6ABACB3B9B4AFACA7999CA39EA5AEB5
6D5E56434A534433313249665949412E33342A2A302B2F343346614B3B454458555B5945
292D37485036222F3B5A76857C6F4B2A2B2C302E333A312B2929292C2D282A2324242736
5C696E7A6B4F4F5F6F89827DB19785B3B7B4B7B1B6B2B6BBB6BBBDBBB8B4B4AFA9A7A1A2
A3A5A7A6A6A5ABB1B6B6B0ACABA39A9DA5A7A9A7
6A66584F67625D4E463B44575A4F4233342E2F2D2E2B31353D4A55514655444855604C3D
3825384B4F3F282C5E597B806C5E35292D2F322D31323234302C2A31332B2F21272C2635
3C536F8A765649545D6C657CB19A86A7BDB7B7AFB3B7B6B6B7B9BDBFBCB9B6B6ADACA4A2
A0A9A8A9AEAEB0B3B1B8B0AEB1AB9D9DAAADA8A6
766F5C5B7C716A595553494A514D4C3D3E3B3230292A383A484D484E434145455551473E
3B27364C51382636715B79785F5832282C2B2F3A2F2C2D30303631303A2F292A2C292729
2C415F6C846B585559614F72A7A1839DB6B0AEA9B1B7B1B0B3B5B7BBBCBCB7B2ABADADA5
A3A6ABACAFACB3B3AFB2B4B3B0A9A7A0AFB3ACAD
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf0001P38h=P205eMG@80IVIV0P25QHD30;^k^`80]KFe
0P10@40402TY:@8092@T0P0X:2P302HV9P80;Bd]0P12@T82059BDP80>3Ph0P0c<c<203Ti>@<0<S8b
0P0i>CT402l_;`80>3Ph0P0e=CD203Ti>@<0;bl_0P0j>SX203Lg=`80@d=30P1;Bd/2055AD@80?clo
0P0k>c/303Ph>080;bl_0P0];Bd202HV9P80:b/[0P0X:2P203hn?P<0JVYZ101VIVH205YJFP80LG5a
0P1UIFD205=CD`<0G5aL0P1RHV8206MWI`80JVYZ0P1cLg<206m_K`80MWIf0`22PX8207emO@80O7al
1023Ph<207]kN`80Ph>30`1mOGd20861P@80PX:20P1nOWh208>3P`80QHF50P28R8P508V9R@@0R8R8
0P27QhL208b<S080SXj>0`2BTY8208^;R`80SXj>0P2<S8`2092@T080S8b<0P28R8P308V9R@80RXZ:
0P2;Rh/208j>SP@0RXZ:0P2=SHd308j>SP80RXZ:0P2BTY8208j>SP80Shn?2@2BTY8209>CT`80T92@
0P2=SHd2096AT@80UIFE0P2CTi<308n?S`80SXj>102BTY8209FEU@@0T92@0`2IVIT209BDU080Ti>C
0P2FUYH209^KV`80UiNG1@2KVi/209jNWP80X:2P0P2/[:`20;6a/@80a<C40P3?cll30<_;b`80dM7A
0P3?cll20;jn_PP0b>3H00060<SPf080GEeM0P1VIVH208F5Q@<0^k^k0P2e]KD20410@0@0:BTY0P0T
92@202PX:0<09RHV0P0];Bd20492@P80DU9B0P0h>3P203<c<`80>CTi0`0b<S8203Ti>@@0;bl_0P0h
>3P203De=@80>CTi0`0_;bl203Xj>P80=cLg0P13@d<204];B`80DE5A0P0o?cl203/k>`<0>3Ph0P0_
;bl202d];@809RHV0P0[:b/202PX:080?Shn0`1ZJVX406IVIP80FUYJ0P1aLG4206EUI@80De=C0`1L
G5`2069RHP80IfMW0P1ZJVX207=cL`80Kfm_0P1fMWH308:2PP80OGem0P1lO7`408>3P`80Ng]k0P23
Ph<307emO@80PH610P22PX8207inOP80Ph>30P25QHD208R8R0D0RHV91028R8P208N7Q`80S8b<0P2>
SXh309:BTP80Rh^;0P2>SXh208b<S080T92@0P2<S8`208R8R0<0RHV90P2:RXX208^;R`80SXj>102:
RXX208f=S@<0SXj>0P2:RXX209:BTP80SXj>0P2?Shl909:BTP80Ti>C0P2@T90208f=S@80TI6A0P2E
UID209>CT`<0Shn?0P2>SXh409:BTP80UIFE102@T90309VIV@80U9BD0P2CTi<209JFUP80Vi^K0P2G
UiL509^KV`80WYjN0P2PX:020:b/[080/K6a0P34a<@20<o?c`<0bl_;0P3AdM420<o?c`80_[jn2038
h=P000H0b>3H0P1JFUX205UIF@80L71`0`2CTi<20<71`@80W9bL0P0n?Sh202PX:080;2`/0P0Y:BT3
02@T9080:RXZ0P0g=cL203Hf=P80<30`0P0d=3@203Ph>0D0=cLg0P0[:b/2038b<P80>c/k0P0`<302
038b<P<0;bl_0P11@D4203De=@80A4A40P1<C4`204e=C@80@T920P0f=SH303Lg=`80;bl_0P0^;Rh2
030`<080:b/[0P0W9bL20492@P<0JFUY0P1QHF4206ATI080H61P0P1jNWX206ATI080BTY:0`1LG5`2
069RHP80JFUY0P1]KFd607EeM@D0O7al0P1nOWh207YjNP80PX:20P24Q8@507moO`80OWin0P20P802
07moO`80QHF51026QXH308Z:RP80Rh^;0P28R8P208V9R@@0Rh^;1@2@T90208R8R080S8b<0P2:RXX2
08n?S`80Rh^;0P2?Shl308N7Q`80R8R80P2;Rh/208f=S@80Rh^;0P2?Shl208j>SP<0SHf=102ATI42
09>CT`@0UIFE0P2BTY8208n?S`<0TI6A102BTY82092@T080UYJF0P2HV9P209VIV@<0TI6A0P2EUID4
09BDU0@0TY:B0P2CTi<509NGU`80V9RH0P2FUYH209ZJVP@0Vi^K0`2PX:020:6QX@80YjNW0P2ZZZX2
0:j^[P80a<C40P3?cll30=7Ad@80cLg=0P3<c<`20<30`0P0b>3H00060<SPf080FUYJ0P1IFET2071`
L0<0Ti>C0P31`L4209bLW080?Shn0P0X:2P202`/;080:BTY0`0T92@202XZ:P80=cLg0P0f=SH2030`
<080=3@d0P0h>3P503Lg=`80:b/[0P0b<S8203/k>`80<30`0P0b<S8302l_;`80@D510P0e=CD204A4
A080C4a<0P1=CDd20492@P80=SHf0`0g=cL202l_;`80;Rh^0P0`<30202/[:`809bLW0P12@T8306UY
J@80HF5Q0P1TI6@2061PH080NWYj0P1TI6@204Y:BP<0G5aL0P1RHV8206UYJ@80KFe]1P1eMGD507al
O080OWin0P1jNWX208:2PP80Q8B41@1oOgl207inOP80P8200P1oOgl208F5Q@@0QXJ60`2:RXX208^;
R`80R8R80P29RHT408^;R`D0T92@0P28R8P208b<S080RXZ:0P2?Shl208^;R`80Shn?0`27QhL208R8
R080Rh^;0P2=SHd208^;R`80Shn?0P2>SXh308f=S@@0TI6A0P2CTi<409FEU@80TY:B0P2?Shl3096A
T@@0TY:B0P2@T90209JFUP80V9RH0P2IVIT3096AT@80UIFE102DU9@409:BTP80Ti>C1@2GUiL209RH
V080UYJF0P2JVYX409^KV`<0X:2P0P2QXJ420:NWY`80ZZZZ0P2^[Zh20<C4a080clo?0`3AdM420<g=
c@80c<c<0P30`<080<SPf0001P38h=P205UIF@80FUYJ0P1OGel3079bLP80VYZJ0P32`/8209FEU@80
>SXj0P0Z:RX202HV9P<0:RXZ0P0];Bd203Ph>080=3@d0P0_;bl203Hf=P80A4A40`0h>3P2038b<P80
;Rh^0P0c<c<203De=@80<c<c0P0/;2`303@d=080?Cdm0P0h>3P204Y:BP80@D510P0m?Cd20492@P80
;Bd]0`0^;Rh203@d=080<30`0P0/;2`202TY:@80:RXZ0P11@D4306=SH`80I6AT0P1WIfL205mOG`80
Ng]k0P1IFET2055AD@<0GUiN0P1YJFT207IfMP80KVi^0P1]KFd407MgM`<0N7Qh0P1mOGd207inOP80
PH610P22PX840861P@<0P8200P27QhL208>3P`80Ogmo0P22PX8208B4Q080Ph>30`2;Rh/208N7Q`80
QXJ60P29RHT208^;R`80Shn?0P2<S8`3092@T080S8b<0P2;Rh/208R8R080RHV90P2;Rh/209:BTPD0
RXZ:0P2>SXh2092@T080SHf=0P2;Rh/508j>SP80UYJF0P2DU9@209>CT`@0UIFE0P2DU9@509FEU@80
UiNG102BTY8209NGU`@0W9bL0`2CTi<209BDU080UiNG0P2FUYH2092@T080U9BD0P2ATI4309JFUP80
U9BD0P2EUID409^KV`80VIVI0P2KVi/309ZJVP80WIfM0P2TY:@20:^[Z`80/;2`0P34a<@20=CDe0<0
dm?C0P3>c/h20<g=c@80aLG52038h=P000H0b>3H0P1IFET205YJFP80GemO0`1bLW8209ZJVP80`/;2
0P2EUID203Xj>P80:RXZ0P0V9RH302XZ:P80;Bd]0P0h>3P203@d=080;bl_0P0f=SH204A4A0<0>3Ph
0P0b<S8202h^;P80<c<c0P0e=CD203<c<`80;2`/0`0d=3@203dm?@80>3Ph0P1:BTX20451@@80?Cdm
0P12@T8202d];@<0;Rh^0P0d=3@2030`<080;2`/0P0Y:BT202XZ:P80@D510`1SHf<206ATI080IfMW
0P1OGel207]kN`80FEUI0P1ADE4305iNGP80JFUY0P1fMWH206i^KP80KFe]101gMgL307QhN080OGem
0P1nOWh20861P@80PX:21021PH430820P080QhN70P23Ph<207moO`80PX:20P24Q8@208>3P`<0Rh^;
0P27QhL208J6QP80RHV90P2;Rh/208n?S`80S8b<0`2@T90208b<S080Rh^;0P28R8P208V9R@80Rh^;
0P2BTY8508Z:RP80SXj>0P2@T90208f=S@80Rh^;1@2>SXh209JFUP80U9BD0P2CTi<409FEU@80U9BD
1@2EUID209NGU`@0TY:B0P2GUiL409bLW0<0Ti>C0P2DU9@209NGU`80UYJF0P2@T90209BDU080TI6A
0`2FUYH209BDU080UIFE102KVi/209VIV@80Vi^K0`2JVYX209fMW@80Y:BT0P2[Zj/20;2`/080a<C4
0P3De=@30=?Cd`80c/k>0P3=cLd20<G5a@P0b>3H00060<SPf080H61P0P1IFET205eMG@<0IVIV0P1l
O7`20:b/[080`<300P1^KVh202l_;`80:RXZ0`0T92@202PX:080:b/[0P0Z:RX202/[:`80?Cdm0P10
@403030`<080<c<c0P0`<304034a<@80:RXZ0P0^;Rh303Hf=P80?Shn0P0_;bl204i>CP80A4A40P0n
?Sh203`l?080<C4a0`0];Bd203Hf=P80;bl_0P0W9bL202HV9P80:RXZ0P16ATH306a/K080IFEU0P1X
J6P205aLG080MgMg0P1HF5P205]KF`<0Hf=S0P1UIFD206m_K`80L71`0P1aLG42079bLP80MWIf0`1i
NGT207emO@80Ng]k0P1nOWh20861P@80P8200P22PX8308B4Q080Ogmo1022PX820820P080R8R80P27
QhL308^;R`80R8R81029RHT208j>SP80SHf=0P28R8P308f=S@80SXj>0P2<S8`208R8R080S8b<0P2@
T90209:BTP<0SHf=0P2<S8`2092@T080SXj>0P2CTi<208f=S@80U9BD0`2ATI4209JFUP@0U9BD0P2I
VIT209NGU`80UIFE1@2CTi<209VIV@80V9RH0P2IVIT209RHV080VIVI0P2PX:0309ZJVP80VIVI102C
Ti<209:BTP80UYJF0P2@T90509NGU`80U9BD0P2FUYH209VIV@80UYJF0P2JVYX309VIV@80WIfM102U
YJD20;2`/080`/;20P3Bd]830<o?c`80c/k>0P3<c<`20<71`@P0b>3H00060<SPf080H61P0P1IFET2
05eMG@<0IVIV0P1lO7`20:b/[080`<300P1^KVh202l_;`80:RXZ0`0T92@202PX:080:b/[0P0Z:RX2
02/[:`80?Cdm0P10@403030`<080<c<c0P0`<304034a<@80:RXZ0P0^;Rh303Hf=P80?Shn0P0_;bl2
04i>CP80A4A40P0n?Sh203`l?080<C4a0`0];Bd203Hf=P80;bl_0P0W9bL202HV9P80:RXZ0P16ATH3
06a/K080IFEU0P1XJ6P205aLG080MgMg0P1HF5P205]KF`<0Hf=S0P1UIFD206m_K`80L71`0P1aLG42
079bLP80MWIf0`1iNGT207emO@80Ng]k0P1nOWh20861P@80P8200P22PX8308B4Q080Ogmo1022PX82
0820P080R8R80P27QhL308^;R`80R8R81029RHT208j>SP80SHf=0P28R8P308f=S@80SXj>0P2<S8`2
08R8R080S8b<0P2@T90209:BTP<0SHf=0P2<S8`2092@T080SXj>0P2CTi<208f=S@80U9BD0`2ATI42
09JFUP@0U9BD0P2IVIT209NGU`80UIFE1@2CTi<209VIV@80V9RH0P2IVIT209RHV080VIVI0P2PX:03
09ZJVP80VIVI102CTi<209:BTP80UYJF0P2@T90509NGU`80U9BD0P2FUYH209VIV@80UYJF0P2JVYX3
09VIV@80WIfM102UYJD20;2`/080`/;20P3Bd]830<o?c`80c/k>0P3<c<`20<71`@P0b>3H00060<SP
f080H61P0P1IFET205eMG@<0IVIV0P1lO7`20:b/[080`<300P1^KVh202l_;`80:RXZ0`0T92@202PX
:080:b/[0P0Z:RX202/[:`80?Cdm0P10@403030`<080<c<c0P0`<304034a<@80:RXZ0P0^;Rh303Hf
=P80?Shn0P0_;bl204i>CP80A4A40P0n?Sh203`l?080<C4a0`0];Bd203Hf=P80;bl_0P0W9bL202HV
9P80:RXZ0P16ATH306a/K080IFEU0P1XJ6P205aLG080MgMg0P1HF5P205]KF`<0Hf=S0P1UIFD206m_
K`80L71`0P1aLG42079bLP80MWIf0`1iNGT207emO@80Ng]k0P1nOWh20861P@80P8200P22PX8308B4
Q080Ogmo1022PX820820P080R8R80P27QhL308^;R`80R8R81029RHT208j>SP80SHf=0P28R8P308f=
S@80SXj>0P2<S8`208R8R080S8b<0P2@T90209:BTP<0SHf=0P2<S8`2092@T080SXj>0P2CTi<208f=
S@80U9BD0`2ATI4209JFUP@0U9BD0P2IVIT209NGU`80UIFE1@2CTi<209VIV@80V9RH0P2IVIT209RH
V080VIVI0P2PX:0309ZJVP80VIVI102CTi<209:BTP80UYJF0P2@T90509NGU`80U9BD0P2FUYH209VI
V@80UYJF0P2JVYX309VIV@80WIfM102UYJD20;2`/080`/;20P3Bd]830<o?c`80c/k>0P3<c<`20<71
`@P0b>3H00060<SPf080GemO0P1JFUX205]KF`<0FEUI0P1`L70208f=S@80_kno0P2c/k<205]KF`80
;2`/0`0W9bL202@T9080:b/[0P0];Bd2038b<P80=3@d0P0^;Rh3030`<080:BTY0P0/;2`2038b<P80
<c<c0P0[:b/202d];@<0<C4a0P0c<c<2038b<P80Bd];0P13@d<203Ti>@80=SHf0P0`<303034a<@80
=3@d0P0b<S8202PX:0809bLW0P0`<30204a<C0<0M7Ad0P1PH60206YZJP80IfMW0P1_Kfl205IFEP80
GUiN0`1SHf<206YZJP80KVi^0P1`L70207=cL`80N7Qh0P1jNWX507MgM`80PH610P1oOgl407inOP80
QHF50`23Ph<408:2PP80O7al0P1oOgl208F5Q@80R8R80`2;Rh/608N7Q`80SXj>0P2;Rh/208R8R0<0
RHV90P2@T90408^;R`80TI6A0P2;Rh/208n?S`<0S8b<0P2?Shl208j>SP80SHf=0P2?Shl208j>SP80
UIFE0`2DU9@209NGU`80UYJF0P2DU9@209FEU@80V9RH0P2FUYH209NGU`<0U9BD0P2IVIT409RHV080
VIVI0P2OWil209^KV`<0UiNG0P2EUID209>CT`80TY:B0P2?Shl209BDU080UiNG1@2JVYX209NGU`80
T92@0P2HV9P409NGU`<0W9bL0P2FUYH20:>SX`80YJFU0P2ZZZX20;jn_P80c/k>0`3AdM420<k>cP80
b<S80P2l_;`80<SPf0001P38h=P205mOG`80FUYJ0P1KFe/305UIF@80L71`0P2=SHd20;no_`80/k>c
0P1KFe/202`/;0<09bLW0P0T92@202/[:`80;Bd]0P0b<S8203@d=080;Rh^0`0`<30202TY:@80;2`/
0P0b<S8203<c<`80:b/[0P0];Bd3034a<@80<c<c0P0b<S8204];B`80@d=30P0i>CT203Hf=P80<30`
0`0a<C4203@d=080<S8b0P0X:2P202LW9`80<30`0P1<C4`307AdM080H61P0P1ZJVX206MWI`80Kfm_
0P1FEUH205iNGP<0Hf=S0P1ZJVX206i^KP80L71`0P1cLg<207QhN080NWYj1@1gMgL20861P@80Ogmo
101nOWh208F5Q@<0Ph>31022PX8207alO080Ogmo0P25QHD208R8R0<0Rh^;1P27QhL208j>SP80Rh^;
0P28R8P308V9R@80T92@102;Rh/2096AT@80Rh^;0P2?Shl308b<S080Shn?0P2>SXh208f=S@80Shn?
0P2>SXh209FEU@<0U9BD0P2GUiL209JFUP80U9BD0P2EUID209RHV080UYJF0P2GUiL309BDU080VIVI
102HV9P209VIV@80WinO0P2KVi/309NGU`80UIFE0P2CTi<209:BTP80Shn?0P2DU9@209NGU`D0VYZJ
0P2GUiL2092@T080V9RH102GUiL309bLW080UYJF0P2SXj<20:FUY@80ZZZZ0P2n_[h20<k>cP<0dM7A
0P3>c/h20<S8b080_;bl2038h=P000H0b>3H0P1RHV8205YJFP80F5QH0`1OGel2065QH@80MWIf0P2P
X:020<S8b080ZZZZ0P0o?cl302PX:0@092@T0P0Y:BT203@d=080<C4a0P0];Bd502`/;080<C4a0P0e
=CD203@d=080<30`0P0b<S8303Ph>080?3`l0P0m?Cd204a<C080@4100P0m?Cd204=3@`80>SXj0`0c
<c<2038b<P80;2`/100`<30202d];@80Bd];0`1gMgL206UYJ@80KVi^0P1QHF4206UYJ@80DE5A0P1N
GUh3065QH@80JFUY0P1cLg<2079bLP80Lg=c0P1dM7@207emO@<0NWYj0P1lO7`208:2PP80OGem1020
P80208>3P`<0Ogmo0P21PH4208:2PP80Q8B40P22PX8208R8R080QHF50`2;Rh/208V9R@80SHf=0P29
RHT408f=S@80Shn?1@2=SHd208Z:RP@0S8b<0P2:RXX208f=S@<0Rh^;0P2<S8`2096AT@80S8b<0P2B
TY8209BDU080V9RH0`2JVYX409NGU`80VIVI102GUiL209ZJVP80U9BD0`2GUiL209bLW0@0UYJF0P2G
UiL209fMW@80VIVI0`2HV9P209VIV@H0U9BD0P2CTi<209FEU@<0V9RH0P2EUID209:BTP80U9BD0P2C
Ti<409NGU`<0V9RH0P2JVYX209jNWP80Y:BT0P2[Zj/20;Rh^080b/[:0`3>c/h20<g=c@80alO70P2k
^k/80<SPf0001P38h=P2069RHP80FUYJ0P1HF5P305mOG`80HF5Q0P1fMWH20:2PX080b<S80P2ZZZX2
03lo?`<0:2PX100T92@202TY:@80=3@d0P0a<C4202d];@D0;2`/0P0a<C4203De=@80=3@d0P0`<302
038b<P<0>3Ph0P0l?3`203dm?@80C4a<0P10@40203dm?@80@d=30P0j>SX303<c<`80<S8b0P0/;2`4
030`<080;Bd]0P1;Bd/307MgM`80JFUY0P1^KVh2065QH@80JFUY0P1ADE4205iNGP<0HF5Q0P1YJFT2
07=cL`80LW9b0P1cLg<207AdM080OGem0`1jNWX207alO080PX:20P1mOGd40820P080Ph>30`1oOgl2
0861P@80PX:20P24Q8@208:2PP80R8R80P25QHD308^;R`80RHV90P2=SHd208V9R@@0SHf=0P2?Shl5
08f=S@80RXZ:102<S8`208Z:RP80SHf=0`2;Rh/208b<S080TI6A0P2<S8`209:BTP80U9BD0P2HV9P3
09ZJVP@0UiNG0P2IVIT409NGU`80VYZJ0P2DU9@309NGU`80W9bL102FUYH209NGU`80WIfM0P2IVIT3
09RHV080VIVI1P2DU9@209>CT`80UIFE0`2HV9P209FEU@80TY:B0P2DU9@209>CT`@0UiNG0`2HV9P2
09ZJVP80WYjN0P2TY:@20:^[Z`80^;Rh0P3:b/X30<k>cP80cLg=0P37alL20;^k^`P0b>3H00060<SP
f080G5aL0P1ZJVX205UIF@<0FUYJ0P1RHV8206EUI@80RXZ:0P33`l<20<O7a`80TI6A0`0g=cL202`/
;080<C4a0P0V9RH202`/;080<S8b0P0X:2P303@d=080<C4a0P0^;Rh2034a<@80<c<c0P0^;Rh202d]
;@<0<C4a0P0g=cL2034a<@80@D510P0m?Cd203`l?080>c/k0P0^;Rh3038b<P80;bl_0P0/;2`202/[
:`80:2PX0P0V9RH204Y:BP<0L71`0P1_Kfl206i^KP@0IVIV0P1DE5@2065QH@D0K6a/101aLG42071`
L080MWIf0P1oOgl307YjNP80NGUi0P22PX8207YjNP80OGem0P1nOWh207emO@<0OWin0P1iNGT207in
OP80Ph>30P24Q8@208F5Q@80PX:20`25QHD208b<S0@0RHV90P2ATI4208V9R@80SHf=0`2>SXh208n?
S`80Rh^;0P28R8P208Z:RP80S8b<0P2>SXh308b<S080Shn?0P2ATI4208n?S`80U9BD0P2FUYH209NG
U`<0VIVI0P2HV9P409NGU`80Vi^K0P2JVYX209JFUP80U9BD0`2HV9P209fMW@80VIVI0P2LW9`209^K
V`80W9bL0P2KVi/509NGU`80U9BD0P2BTY8209ZJVP80V9RH0P2EUID309>CT`80TY:B1P2DU9@2096A
T@80T92@0`2DU9@209NGU`80UYJF0P2LW9`20:VYZ@80][Jf0P36a/H30<g=c@80b/[:0P31`L420;Ng
]`P0b>3H00060<SPf080G5aL0P1ZJVX205UIF@<0FUYJ0P1RHV8206EUI@80RXZ:0P33`l<20<O7a`80
TI6A0`0g=cL202`/;080<C4a0P0V9RH202`/;080<S8b0P0X:2P303@d=080<C4a0P0^;Rh2034a<@80
<c<c0P0^;Rh202d];@<0<C4a0P0g=cL2034a<@80@D510P0m?Cd203`l?080>c/k0P0^;Rh3038b<P80
;bl_0P0/;2`202/[:`80:2PX0P0V9RH204Y:BP<0L71`0P1_Kfl206i^KP@0IVIV0P1DE5@2065QH@D0
K6a/101aLG42071`L080MWIf0P1oOgl307YjNP80NGUi0P22PX8207YjNP80OGem0P1nOWh207emO@<0
OWin0P1iNGT207inOP80Ph>30P24Q8@208F5Q@80PX:20`25QHD208b<S0@0RHV90P2ATI4208V9R@80
SHf=0`2>SXh208n?S`80Rh^;0P28R8P208Z:RP80S8b<0P2>SXh308b<S080Shn?0P2ATI4208n?S`80
U9BD0P2FUYH209NGU`<0VIVI0P2HV9P409NGU`80Vi^K0P2JVYX209JFUP80U9BD0`2HV9P209fMW@80
VIVI0P2LW9`209^KV`80W9bL0P2KVi/509NGU`80U9BD0P2BTY8209ZJVP80V9RH0P2EUID309>CT`80
TY:B1P2DU9@2096AT@80T92@0`2DU9@209NGU`80UYJF0P2LW9`20:VYZ@80][Jf0P36a/H30<g=c@80
b/[:0P31`L420;Ng]`P0b>3H00060<SPf080CTi>0P1YJFT205EEE@<0DE5A0P1JFUX206UYJ@80U9BD
0P2c/k<20<O7a`80aLG50`1nOWh203Ti>@809bLW0P0U9BD202`/;080:b/[0P0Z:RX3034a<@80<S8b
100h>3P203/k>`80>CTi0P10@40303hn?P80@d=30P12@T8204a<C080@D511012@T8203`l?0D0>SXj
0P0_;bl203Ti>@@0>SXj0P1LG5`3079bLP80M7Ad0P1WIfL2071`L080HV9R0P1MGEd206=SH`D0Jf][
0P1_Kfl2079bLP80N7Qh0P1kNg/20820P0D0Ogmo0P1mOGd207moO`80PX:20P25QHD208B4Q0D0Ph>3
0P26QXH20861P@80QHF51028R8P308Z:RP80Shn?0P2:RXX208n?S`80TI6A0P2:RXX208^;R`<0RXZ:
102<S8`208^;R`80SXj>0P2=SHd208b<S0D0T92@0P2EUID2092@T0@0VIVI1`2JVYX209bLW0@0VIVI
0P2KVi/409RHV0<0Vi^K0P2OWil209jNWP80W9bL0P2OWil209fMW@D0Vi^K0P2HV9P409NGU`80VYZJ
0P2HV9P209FEU@<0UiNG0P2EUID209:BTP80U9BD0P2CTi<2096AT@D0SXj>0P2EUID209RHV080WinO
0P2SXj<20;6a/@80_kno0`39bLT20<S8b080`<300P2`/;080<SPf0001P38h=P204i>CP80JFUY0P1E
EED3055AD@80FUYJ0P1YJFT209BDU080/k>c0P37alL20<G5a@<0OWin0P0i>CT202LW9`809BDU0P0/
;2`202/[:`80:RXZ0`0a<C42038b<P@0>3Ph0P0k>c/203Ti>@80@4100`0n?Sh204=3@`80@T920P1<
C4`20451@@@0@T920P0l?3`503Xj>P80;bl_0P0i>CT403Xj>P80G5aL0`1bLW8207AdM080IfMW0P1`
L702069RHP80GEeM0P1SHf<506][J`80Kfm_0P1bLW8207QhN080Ng]k0P20P80507moO`80OGem0P1o
Ogl208:2PP80QHF50P24Q8@508>3P`80QXJ60P21PH4208F5Q@@0R8R80`2:RXX208n?S`80RXZ:0P2?
Shl2096AT@80RXZ:0P2;Rh/308Z:RP@0S8b<0P2;Rh/208j>SP80SHf=0P2<S8`5092@T080UIFE0P2@
T90409VIV@L0VYZJ0P2LW9`409VIV@80Vi^K102HV9P309^KV`80WinO0P2NWYh209bLW080WinO0P2M
WId509^KV`80V9RH102GUiL209ZJVP80V9RH0P2EUID309NGU`80UIFE0P2BTY8209BDU080Ti>C0P2A
TI4508j>SP80UIFE0P2HV9P209nOW`80Xj>S0P2a/K420;no_`<0bLW90P38b<P20<30`080/;2`2038
h=P000H0b>3H0P1ADE42061PH080Hf=S0`1IFET2069RHP80MWIf0P2CTi<209bLW080`L710P3;bl/3
0<?3``80M7Ad0P0h>3P203De=@80=cLg100f=SH30451@@80@4100P0n?Sh403Lg=`80<c<c0P0h>3P3
03Xj>P80=3@d0P0m?Cd203lo?`80>3Ph0P0f=SH203@d=080;2`/0`0^;Rh2038b<P809bLW0P0];Bd2
02`/;080<S8b0P1JFUX306m_K`80L71`0P1MGEd206i^KP@0EUIF0P1PH60306ATI080JVYZ0P1`L702
07AdM080MWIf0P1hN7P207]kN`<0N7Qh0P1mOGd208:2PP80NWYj1020P80207inOP<0Ogmo0P22PX82
0820P080Q8B40P23Ph<208B4Q080R8R80`2=SHd208^;R`80RHV90P2=SHd208n?S`80RXZ:0P2>SXh3
08f=S@80RXZ:0P2<S8`208n?S`80Ti>C0P2?Shl5096AT@80Ti>C0P2GUiL209JFUP80Vi^K0P2GUiL2
09fMW@<0UiNG1P2IVIT409ZJVP80W9bL0P2KVi/309nOW`80W9bL0P2PX:0409fMW@80W9bL0P2MWId3
09ZJVP80UYJF0P2DU9@209ZJVP80V9RH0P2IVIT209NGU`<0UYJF0P2DU9@209JFUP80UiNG102BTY85
096AT@80Shn?0P2EUID209jNWP80XJ6Q0P2/[:`20;Zj^P<0`/;20P35aLD20;^k^`80Z:RX2038h=P0
00H0b>3H0P1ADE42061PH080Hf=S0`1IFET2069RHP80MWIf0P2CTi<209bLW080`L710P3;bl/30<?3
``80M7Ad0P0h>3P203De=@80=cLg100f=SH30451@@80@4100P0n?Sh403Lg=`80<c<c0P0h>3P303Xj
>P80=3@d0P0m?Cd203lo?`80>3Ph0P0f=SH203@d=080;2`/0`0^;Rh2038b<P809bLW0P0];Bd202`/
;080<S8b0P1JFUX306m_K`80L71`0P1MGEd206i^KP@0EUIF0P1PH60306ATI080JVYZ0P1`L70207Ad
M080MWIf0P1hN7P207]kN`<0N7Qh0P1mOGd208:2PP80NWYj1020P80207inOP<0Ogmo0P22PX820820
P080Q8B40P23Ph<208B4Q080R8R80`2=SHd208^;R`80RHV90P2=SHd208n?S`80RXZ:0P2>SXh308f=
S@80RXZ:0P2<S8`208n?S`80Ti>C0P2?Shl5096AT@80Ti>C0P2GUiL209JFUP80Vi^K0P2GUiL209fM
W@<0UiNG1P2IVIT409ZJVP80W9bL0P2KVi/309nOW`80W9bL0P2PX:0409fMW@80W9bL0P2MWId309ZJ
VP80UYJF0P2DU9@209ZJVP80V9RH0P2IVIT209NGU`<0UYJF0P2DU9@209JFUP80UiNG102BTY85096A
T@80Shn?0P2EUID209jNWP80XJ6Q0P2/[:`20;Zj^P<0`/;20P35aLD20;^k^`80Z:RX2038h=P000H0
b>3H0P1UIFD205QHF080Kfm_0`1ZJVX206=SH`80M7Ad0P27QhL208V9R@80Y:BT0P32`/830=3@d080
^[Zj0P1;Bd/202l_;`80;Rh^1`0`<30403@d=0@0<C4a0P0];Bd203De=@<0=3@d0P0c<c<20451@@80
=SHf0P0h>3P403Hf=PD0<S8b0P0_;bl402`/;080<30`0P0d=3@205aLG0D0Lg=c0P1OGel206UYJ@80
EEEE0P1DE5@206ATI0<0HF5Q0P1YJFT2075aL@80L71`0P1fMWH207MgM`80Ng]k0`1mOGd207moO`80
P8200P1jNWX207moO`80P8200P1oOgl307alO080PH610P1oOgl208B4Q080PX:20P24Q8@508^;R`80
RHV90P2;Rh/208V9R@80SHf=0P2?Shl208f=S@<0T92@102?Shl2096AT@80SXj>0P2CTi<209BDU0<0
SHf=0P2?Shl2096AT@80Ti>C0P2HV9P209VIV@80Vi^K0`2GUiL209jNWP80VIVI0P2LW9`209fMW@@0
WYjN0P2QXJ430:BTY080WinO1P2MWId209bLW080WYjN0`2KVi/209ZJVP80V9RH0P2JVYX409VIV@80
UYJF0`2CTi<2096AT@80UYJF102ATI4408n?S`D0SHf=102DU9@209VIV@80YJFU0P2c/k<30;Zj^P80
_kno0P2a/K420:6QX@P0b>3H00060<SPf080IFEU0P1HF5P206m_K`<0JVYZ0P1SHf<207AdM080QhN7
0P29RHT20:BTY080`/;20`3@d=020;Zj^P80Bd];0P0_;bl202h^;PL0<30`100d=3@4034a<@80;Bd]
0P0e=CD303@d=080<c<c0P11@D4203Hf=P80>3Ph100f=SH5038b<P80;bl_100/;2`2030`<080=3@d
0P1LG5`507=cL`80GemO0P1YJFT205EEE@80E5AD0P1TI6@3065QH@80JFUY0P1aLG42071`L080MWIf
0P1gMgL207]kN`<0OGem0P1oOgl20820P080NWYj0P1oOgl20820P080Ogmo0`1lO7`20861P@80Ogmo
0P24Q8@208:2PP80Q8B41@2;Rh/208V9R@80Rh^;0P29RHT208f=S@80Shn?0P2=SHd3092@T0@0Shn?
0P2ATI4208j>SP80Ti>C0P2DU9@308f=S@80Shn?0P2ATI4209>CT`80V9RH0P2IVIT209^KV`<0UiNG
0P2NWYh209VIV@80W9bL0P2MWId409jNWP80XJ6Q0`2TY:@209nOW`H0WIfM0P2LW9`209jNWP<0Vi^K
0P2JVYX209RHV080VYZJ102IVIT209JFUP<0Ti>C0P2ATI4209JFUP@0TI6A102?Shl508f=S@@0U9BD
0P2IVIT20:FUY@80/k>c0`2j^[X20;no_`80/K6a0P2QXJ480<SPf0001P38h=P209jNWP80Fe]K0P1S
Hf<3071`L080GemO0P1ZJVX207MgM`80OGem0P2:RXX20:^[Z`<0clo?0P3De=@20:6QX@80>SXj0P0b
<S8202h^;P80;Bd]0`0d=3@203Ph>080=SHf0P0e=CD2038b<P80>SXj0P0i>CT303hn?P80@4100P0n
?Sh203Xj>P80>3Ph0P0c<c<203Ti>@80=3@d0`0e=CD2034a<@80;bl_100a<C4203Ph>080H61P0`1g
MgL20861P@80GUiN0P1WIfL2055AD@80E5AD0P1LG5`306EUI@@0KFe]0P1bLW8207EeM@80N7Qh1`1i
NGT207]kN`80OGem0P1lO7`207emO@80Ng]k0`1hN7P207emO@80PX:20P26QXH408:2PP80QXJ60`25
QHD208J6QP80SXj>0P2:RXX208b<S080RXZ:0P2=SHd309>CT`80SXj>0P2@T90208j>SP80Shn?0P2>
SXh2096AT@<0Shn?0P2ATI4209FEU@80SXj>0P2DU9@209RHV080VYZJ0`2KVi/409ZJVP80W9bL0P2J
VYX209nOW`80WYjN0P2MWId309jNWP80XZ:R0P2KVi/209fMW@80WYjN0P2MWId209jNWP<0W9bL102K
Vi/20:2PX0@0UYJF0P2HV9P709JFUP80T92@0P2EUID208n?S`80RXZ:0`2=SHd208Z:RP80Rh^;0P2=
SHd2096AT@80WIfM0P2TY:@30;:b/P80][Jf0P2UYJD209ZJVPP0b>3H00060<SPf080WYjN0P1KFe/2
06=SH`<0L71`0P1OGel206YZJP80MgMg0P1mOGd208Z:RP80Zj^[0`3?cll20=CDe080XJ6Q0P0j>SX2
038b<P80;Rh^0P0];Bd303@d=080>3Ph0P0f=SH203De=@80<S8b0P0j>SX203Ti>@<0?Shn0P10@402
03hn?P80>SXj0P0h>3P203<c<`80>CTi0P0d=3@303De=@80<C4a0P0_;bl4034a<@80>3Ph0P1PH603
07MgM`80PH610P1NGUh206MWI`80DE5A0P1DE5@205aLG0<0IFEU101]KFd2079bLP80MGEe0P1hN7P7
07UiN@80Ng]k0P1mOGd207alO080OGem0P1kNg/307QhN080OGem0P22PX8208J6QP@0PX:20P26QXH3
08F5Q@80QXJ60P2>SXh208Z:RP80S8b<0P2:RXX208f=S@<0Ti>C0P2>SXh2092@T080SXj>0P2?Shl2
08j>SP80TI6A0`2?Shl2096AT@80UIFE0P2>SXh209BDU080V9RH0P2JVYX309^KV`@0VYZJ0P2LW9`2
09ZJVP80WinO0P2NWYh209fMW@<0WYjN0P2RXZ8209^KV`80WIfM0P2NWYh209fMW@80WYjN0`2LW9`4
09^KV`80X:2P102FUYH209RHV0L0UYJF0P2@T90209FEU@80Shn?0P2:RXX308f=S@80RXZ:0P2;Rh/2
08f=S@80TI6A0P2MWId20:BTY0<0/[:b0P2f][H20:FUY@80VYZJ2038h=P000H0b>3H0P2NWYh205]K
F`80Hf=S0`1`L70205mOG`80JVYZ0P1gMgL207emO@80RXZ:0P2[Zj/30<o?c`80e=CD0P2QXJ4203Xj
>P80<S8b0P0^;Rh202d];@<0=3@d0P0h>3P203Hf=P80=CDe0P0b<S8203Xj>P80>CTi0`0n?Sh20410
@080?Shn0P0j>SX203Ph>080<c<c0P0i>CT203@d=0<0=CDe0P0a<C4202l_;`@0<C4a0P0h>3P2061P
H0<0MgMg0P21PH4205iNGP80IfMW0P1ADE4205ADE080G5aL0`1UIFD406e]K@80LW9b0P1eMGD207Qh
N0L0NGUi0P1kNg/207emO@80O7al0P1mOGd207]kN`<0N7Qh0P1mOGd208:2PP80QXJ61022PX8208J6
QP<0QHF50P26QXH208j>SP80RXZ:0P2<S8`208Z:RP80SHf=0`2CTi<208j>SP80T92@0P2>SXh208n?
S`80SXj>0P2ATI4308n?S`80TI6A0P2EUID208j>SP80U9BD0P2HV9P209ZJVP<0Vi^K102JVYX209bL
W080VYZJ0P2OWil209jNWP80WIfM0`2NWYh20::RXP80Vi^K0P2MWId209jNWP80WIfM0P2NWYh309bL
W0@0Vi^K0P2PX:0409JFUP80V9RH1`2FUYH2092@T080UIFE0P2?Shl208Z:RP<0SHf=0P2:RXX208^;
R`80SHf=0P2ATI4209fMW@80Y:BT0`2b/[820;Jf]P80YJFU0P2JVYX80<SPf0001P38h=P20;Bd]080
RXZ:0P1PH60306ATI080JVYZ0P1NGUh206EUI@80MGEe0P1mOGd208j>SP<0`<300P3De=@20<_;b`80
MgMg0P0`<30202TY:@80:RXZ0`0Y:BT202h^;P80:b/[0P0_;bl202XZ:P@0<S8b0`0c<c<202d];@80
ATI60P11@D4403@d=080=SHf0P0a<C4303<c<`80<S8b0P0Y:BT202XZ:P80;Bd]0P0a<C4206ATI0<0
MgMg0P1iNGT205MGE`80IVIV0P1>CTh205MGE`80Fe]K0`1PH60206i^KP80KFe]101cLg<207YjNPD0
NGUi0P1oOgl207alO080OGem0P1lO7`207inOP80NWYj1@21PH4208B4Q080OWin0P1mOGd208>3P`D0
PH610P2:RXX208V9R@80QHF50P28R8P2092@T080Rh^;0`2ATI4209FEU@80TI6A0P2@T90208n?S`80
TY:B1@2@T90209FEU@@0U9BD0P2EUID209JFUP80WinO0`2JVYX209VIV@@0W9bL0P2IVIT409^KV`80
WYjN0`2PX:0209nOW`80Vi^K0P2MWId20:6QX@80W9bL0P2NWYh309ZJVP80W9bL0P2NWYh209ZJVP80
V9RH0P2FUYH209>CT`<0UYJF0P2@T90208n?S`80TI6A0P2?Shl208Z:RP80QXJ60`27QhL208F5Q@80
R8R80P2=SHd208n?S`80UiNG0P2HV9P30:JVYP80Y:BT0P2FUYH209>CT`P0b>3H00060<SPf080];Bd
0P2:RXX2061PH0<0I6AT0P1ZJVX205iNGP80IFEU0P1eMGD207emO@80SXj>0`30`<020=CDe080bl_;
0P1gMgL2030`<080:BTY0P0Z:RX302TY:@80;Rh^0P0[:b/202l_;`80:RXZ100b<S8303<c<`80;Bd]
0P16ATH20451@@@0=3@d0P0f=SH2034a<@<0<c<c0P0b<S8202TY:@80:RXZ0P0];Bd2034a<@80I6AT
0`1gMgL207UiN@80EeMG0P1VIVH204i>CP80EeMG0P1KFe/3061PH080KVi^0P1]KFd407=cL`80NWYj
1@1iNGT207moO`80O7al0P1mOGd207alO080OWin0P1jNWX50861P@80Q8B40P1nOWh207emO@80Ph>3
1@21PH4208Z:RP80RHV90P25QHD208R8R080T92@0P2;Rh/3096AT@80UIFE0P2ATI42092@T080Shn?
0P2BTY85092@T080UIFE102DU9@209FEU@80UYJF0P2OWil309ZJVP80VIVI102LW9`209VIV@@0Vi^K
0P2NWYh30:2PX080WinO0P2KVi/209fMW@80XJ6Q0P2LW9`209jNWP<0VYZJ0P2LW9`209jNWP80VYZJ
0P2HV9P209JFUP80Ti>C0`2FUYH2092@T080Shn?0P2ATI4208n?S`80RXZ:0P26QXH308N7Q`80QHF5
0P28R8P208f=S@80Shn?0P2GUiL209RHV0<0YZJV0P2TY:@209JFUP80Ti>C2038h=P000H0b>3H0P2]
[Jd20:b/[080LW9b0`1TI6@207EeM@80IVIV0P1SHf<206a/K080LW9b0P23Ph<30::RXP80dm?C0P3G
emL20<30`080DU9B0P0U9BD202HV9P<0:RXZ0P0W9bL202@T90809RHV0P0Y:BT202d];@80<C4a0`0h
>3P203dm?@80@D510P0d=3@2030`<080<C4a0P0`<30202l_;`<0<C4a0P0W9bL202DU9@80:BTY0P0V
9RH202h^;P80IfMW0`1fMWH207UiN@80GUiN0P1TI6@204];B`80EEEE0P1KFe/306MWI`80JVYZ0P1c
Lg<207AdM080Lg=c0P1eMGD207IfMP<0M7Ad0P1kNg/207UiN@80OGem0P1nOWh207emO@80P8200`21
PH4208:2PP80O7al0P1oOgl208>3P`80QXJ60P29RHT308J6QP@0RHV90P27QhL208V9R@80SXj>0P2=
SHd309>CT`80SXj>0P2?Shl2096AT@80SHf=0P2ATI4209:BTP<0Ti>C0P2DU9@209NGU`80V9RH0P2C
Ti<209BDU080Vi^K1@2IVIT409ZJVP80WYjN0P2JVYX209JFUP80VIVI1@2NWYh209nOW`80XZ:R0P2L
W9`209RHV080W9bL0`2IVIT209fMW@80VYZJ0P2GUiL209bLW080UIFE0P2BTY8309BDU080Shn?0P2C
Ti<208f=S@80S8b<0P26QXH208>3P`<0Rh^;0P22PX8208>3P`80QHF50P27QhL208f=S@80Shn?0`2F
UYH208n?S`80Q8B40P26QXH80<SPf0001P38h=P20:f][@80[:b/0P1bLW8306ATI080MGEe0P1VIVH2
06=SH`80K6a/0P1bLW8208>3P`<0XZ:R0P3Cdm<20=OGe`80`<300P1BDU8202DU9@809RHV0`0Z:RX2
02LW9`8092@T0P0V9RH202TY:@80;Bd]0P0a<C4303Ph>080?Cdm0P11@D4203@d=080<30`0P0a<C42
030`<080;bl_0`0a<C4202LW9`809BDU0P0Y:BT202HV9P80;Rh^0P1WIfL307IfMP80NGUi0P1NGUh2
06ATI080Bd];0P1EEED205]KF`<0IfMW0P1ZJVX207=cL`80M7Ad0P1cLg<207EeM@80MWIf0`1dM7@2
07]kN`80NGUi0P1mOGd207inOP80OGem0P20P8030861P@80PX:20P1lO7`207moO`80Ph>30P26QXH2
08V9R@<0QXJ61029RHT208N7Q`80RHV90P2>SXh208f=S@<0Ti>C0P2>SXh208n?S`80TI6A0P2=SHd2
096AT@80TY:B0`2CTi<209BDU080UiNG0P2HV9P209>CT`80U9BD0P2KVi/509VIV@@0VYZJ0P2NWYh2
09ZJVP80UYJF0P2IVIT509jNWP80WinO0P2RXZ8209bLW080V9RH0P2LW9`309VIV@80WIfM0P2JVYX2
09NGU`80W9bL0P2EUID209:BTP<0U9BD0P2?Shl209>CT`80SHf=0P2<S8`208J6QP80Ph>30`2;Rh/2
08:2PP80Ph>30P25QHD208N7Q`80SHf=0P2?Shl309JFUP80Shn?0P24Q8@208J6QPP0b>3H00060<SP
f080QhN70P2GUiL209BDU0<0HF5Q0P1ZJVX207AdM080Jf][0P1/K6`206m_K`80Lg=c0`24Q8@20;^k
^`@0clo?0P2MWId202d];@80:BTY0`0U9BD202`/;0808b<S0P0Y:BT202XZ:P80<S8b0P0j>SX304=3
@`80CTi>0P1JFUX203@d=080=CDe0P0a<C4202XZ:P809bLW0`0`<30202<S8`80:RXZ0P0[:b/202l_
;`80=CDe0P1SHf<307emO@80MGEe101SHf<204m?C`80DU9B0P1IFET306UYJ@80L71`0P1aLG4206m_
K`80LG5a0P1eMGD507QhN080NWYj0P1mOGd207YjNP80Ogmo1021PH4307moO`80PX:20P24Q8@207mo
O`80PX:20P26QXH208F5Q@<0QhN70P2;Rh/208b<S080QXJ60P2<S8`209:BTP80TI6A0`2=SHd2096A
T@80SXj>0P2DU9@409>CT`80T92@0`2DU9@209>CT`80UIFE0P2JVYX209BDU080UYJF0P2NWYh309fM
W@80V9RH0P2JVYX209NGU`80WIfM0P2PX:0209fMW@80W9bL0`2OWil209jNWP@0WinO0P2NWYh209nO
W`80W9bL0`2MWId209RHV080UiNG0P2ATI4209FEU@80U9BD0P2EUID308n?S`80SHf=0P29RHT208j>
SP80R8R80P1oOgl207emO@<0P8200P1oOgl20820P080PX:20P20P80208F5Q@80QhN70`28R8P20861
P@80MWIf0P1iNGT80<SPf0001P38h=P208N7Q`80UiNG0P2DU9@3065QH@80JVYZ0P1dM7@206][J`80
K6a/0P1_Kfl207=cL`<0Q8B40P2k^k/40<o?c`80WIfM0P0];Bd202TY:@<09BDU0P0/;2`202<S8`80
:BTY0P0Z:RX2038b<P80>SXj0`13@d<204i>CP80FUYJ0P0d=3@203De=@80<C4a0P0Z:RX202LW9`<0
<30`0P0S8b<202XZ:P80:b/[0P0_;bl203De=@80Hf=S0`1mOGd207EeM@@0Hf=S0P1?Cdl2059BDP80
FEUI0`1YJFT2071`L080LG5a0P1_Kfl2075aL@80MGEe1@1hN7P207YjNP80OGem0P1jNWX207moO`@0
PH610`1oOgl208:2PP80Q8B40P1oOgl208:2PP80QXJ60P25QHD308N7Q`80Rh^;0P2<S8`208J6QP80
S8b<0P2BTY82096AT@<0SHf=0P2ATI4208j>SP80U9BD102CTi<2092@T0<0U9BD0P2CTi<209FEU@80
VYZJ0P2DU9@209JFUP80WYjN0`2MWId209RHV080VYZJ0P2GUiL209fMW@80X:2P0P2MWId209bLW0<0
WinO0P2NWYh409nOW`80WYjN0P2OWil209bLW0<0WIfM0P2HV9P209NGU`80TI6A0P2EUID209BDU080
UIFE0`2?Shl208f=S@80RHV90P2>SXh208R8R080Ogmo0P1mOGd30820P080Ogmo0P20P80208:2PP80
P8200P25QHD208N7Q`<0R8R80P21PH4207IfMP80NGUi2038h=P000H0b>3H0P1PH60206m_K`80OWin
1@1]KFd207YjNP80Ogmo1024Q8@207YjNP<0QhN70P2KVi/20;Fe]@80];Bd0P2g]kL206=SH`80<C4a
0`0W9bL402<S8`8092@T0P0V9RH202XZ:P80>c/k0`1BDU8404];B`80ATI60P15ADD402`/;0D0;Bd]
0P0W9bL203<c<`80>c/k0P0d=3@202`/;080EeMG0`1aLG4207UiN@80J6QX0P1MGEd205=CD`80DE5A
0P1LG5`3065QH@80JFUY0P1[Jf/2071`L080MgMg0P1fMWH207AdM0<0MWIf101nOWh207moO`80OWin
0P1kNg/207inOP<0Ogmo0P28R8P20861P@80QHF50P20P80408J6QP<0QhN70P26QXH208b<S080QhN7
0P2=SHd209BDU080TY:B0`2?Shl4096AT@80V9RH0P2BTY8209BDU080T92@0`2DU9@2096AT@80UIFE
0P2DU9@209>CT`80V9RH0P2LW9`309ZJVP80Ti>C0P2GUiL209RHV080WIfM0P2LW9`209fMW@80WYjN
0`2OWil20:>SX`80V9RH0P2KVi/409jNWP80VYZJ0`2GUiL209BDU080UYJF0P2HV9P409>CT`80SHf=
1`26QXH208:2PP80OGem101jNWX30820P0@0PX:20P27QhL208B4Q0@0QXJ60`22PX8207alO080M7Ad
0P1gMgL80<SPf0001P38h=P2061PH080Kfm_0P1nOWh506e]K@80NWYj0P1oOgl408B4Q080NWYj0`27
QhL209^KV`80]KFe0P2d];@20;Ng]`80Hf=S0P0a<C4302LW9`@08b<S0P0T92@202HV9P80:RXZ0P0k
>c/3059BDP@0Bd];0P16ATH204E5A@@0;2`/1@0];Bd202LW9`80<c<c0P0k>c/203@d=080;2`/0P1G
EeL3075aL@80NGUi0P1XJ6P205eMG@80De=C0P1ADE4205aLG0<0HF5Q0P1YJFT206][J`80L71`0P1g
MgL207IfMP80M7Ad0`1fMWH407inOP80Ogmo0P1nOWh207]kN`80OWin0`1oOgl208R8R080PH610P25
QHD20820P0@0QXJ60`27QhL208J6QP80S8b<0P27QhL208f=S@80U9BD0P2BTY8308n?S`@0TI6A0P2H
V9P209:BTP80U9BD0P2@T90309BDU080TI6A0P2EUID209BDU080Ti>C0P2HV9P209bLW0<0VYZJ0P2C
Ti<209NGU`80V9RH0P2MWId209bLW080WIfM0P2NWYh309nOW`80Xj>S0P2HV9P209^KV`@0WYjN0P2J
VYX309NGU`80U9BD0P2FUYH209RHV0@0Ti>C0P2=SHd708J6QP80PX:20P1mOGd407YjNP<0P8201022
PX8208N7Q`80Q8B41026QXH308:2PP80O7al0P1dM7@207MgM`P0b>3H00060<SPf080C4a<0P1NGUh2
06ATI0D0L71`0P1kNg/208^;R`80U9BD0P2FUYH209BDU0<0VIVI0P2OWil20:RXZ080Y:BT0P2^[Zh2
09jNWP80GemO0`0g=cL202LW9`809RHV0P0P820202<S8`80:2PX0P0^;Rh303Ph>080?3`l0P0/;2`2
034a<@80;bl_0P0[:b/202XZ:P80:b/[0`0a<C4202HV9P@0;bl_0P0Z:RX2034a<@80Hf=S0`1dM7@2
07=cL`80J6QX0P1BDU8204Y:BP80D51@0P1NGUh306IVIP80K6a/0P1XJ6P207AdM080Kfm_0P1aLG42
07EeM@<0MgMg0P20P80207inOP80PH61101kNg/207alO0<0P8200P1oOgl408:2PP80PH611028R8P3
08Z:RP80RHV90P2:RXX208^;R`80T92@0P2>SXh209FEU@<0Ti>C0P2BTY8209BDU080Ti>C102EUID2
09>CT`<0TI6A0P27QhL409JFUP80Ti>C0P2FUYH209ZJVP<0UiNG0P2FUYH209bLW080V9RH0P2KVi/2
09jNWP80W9bL0P2QXJ4309nOW`80WYjN0P2JVYX20:2PX080WYjN0P2JVYX209bLW0<0UIFE102DU9@2
09FEU@80TY:B0P2@T90208V9R@<0PX:20P1nOWh207]kN`80NWYj0P1nOWh207alO080P8200`22PX82
08B4Q080QhN70P24Q8@408J6QP80QHF50`24Q8@207inOP@0MgMg2038h=P000H0b>3H0P1<C4`205iN
GP80I6AT1@1`L70207]kN`80Rh^;0P2DU9@209JFUP80U9BD0`2IVIT209nOW`80Z:RX0P2TY:@20:j^
[P80WYjN0P1OGel303Lg=`809bLW0P0V9RH2020P80808b<S0P0X:2P202h^;P<0>3Ph0P0l?3`202`/
;080<C4a0P0_;bl202/[:`80:RXZ0P0[:b/3034a<@809RHV100_;bl202XZ:P80<C4a0P1SHf<307Ad
M080Lg=c0P1XJ6P2059BDP80BTY:0P1@D50205iNGP<0IVIV0P1/K6`206QXJ080M7Ad0P1_Kfl2075a
L@80MGEe0`1gMgL20820P080OWin0P21PH4407]kN`80O7al0`20P80207moO`@0PX:20P21PH4408R8
R0<0RXZ:0P29RHT208Z:RP80Rh^;0P2@T90208j>SP80UIFE0`2CTi<209:BTP80U9BD0P2CTi<409FE
U@80Ti>C0`2ATI4208N7Q`@0UYJF0P2CTi<209JFUP80VYZJ0`2GUiL209JFUP80W9bL0P2HV9P209^K
V`80WYjN0P2LW9`20:6QX@<0WinO0P2NWYh209ZJVP80X:2P0P2NWYh209ZJVP80W9bL0`2EUID409BD
U080UIFE0P2BTY82092@T080RHV90`22PX8207inOP80Ng]k0P1jNWX207inOP80O7al0P20P80308:2
PP80Q8B40P27QhL208B4Q0@0QXJ60P25QHD308B4Q080OWin101gMgL80<SPf0001P38h=P202`/;080
>c/k0P16ATH306UYJ@80SHf=0P29RHT209>CT`80VIVI0P2QXJ450:f][@80/K6a0P2f][H20;jn_P80
`<300P2i^KT20:j^[P<0PH610P0Y:BT202DU9@809RHV0P0W9bL202@T9080:RXZ0`0_;bl202/[:`80
;2`/0P0d=3@202h^;P80;2`/0P0^;Rh202l_;`<0<S8b0P0X:2P2034a<@80;2`/0P0a<C42030`<080
H61P0`1^KVh206e]K@80I6AT0P1=CDd204i>CP80D51@0P1SHf<306EUI@80IVIV0P1/K6`207EeM@80
MgMg0P1aLG4207EeM@<0MWIf101mOGd207QhN080OWin0P21PH420820P0<0Ph>30P22PX8208>3P`@0
QHF50P2:RXX208R8R0<0QXJ60P2:RXX208j>SP80TI6A0P2@T90209>CT`80S8b<1@2?Shl2092@T080
UIFE0P2GUiL209FEU@80UiNG0`2EUID209JFUP80WIfM0P2GUiL209ZJVP80W9bL0P2MWId309VIV@80
VYZJ0P2LW9`209ZJVP80Vi^K0P2OWil209jNWP80X:2P1@2MWId209bLW080WYjN0P2RXZ8209^KV`80
UiNG0`2HV9P2096AT@@0U9BD102@T9020861P@<0Ng]k0P1dM7@207QhN080OGem101oOgl208>3P`<0
Ogmo0P20P80207alO080OWin0P23Ph<207moO`80PH610`1mOGd207MgM`80Kfm_0P1^KVh80<SPf000
1P38h=P202`/;080>c/k0P16ATH306UYJ@80SHf=0P29RHT209>CT`80VIVI0P2QXJ450:f][@80/K6a
0P2f][H20;jn_P80`<300P2i^KT20:j^[P<0PH610P0Y:BT202DU9@809RHV0P0W9bL202@T9080:RXZ
0`0_;bl202/[:`80;2`/0P0d=3@202h^;P80;2`/0P0^;Rh202l_;`<0<S8b0P0X:2P2034a<@80;2`/
0P0a<C42030`<080H61P0`1^KVh206e]K@80I6AT0P1=CDd204i>CP80D51@0P1SHf<306EUI@80IVIV
0P1/K6`207EeM@80MgMg0P1aLG4207EeM@<0MWIf101mOGd207QhN080OWin0P21PH420820P0<0Ph>3
0P22PX8208>3P`@0QHF50P2:RXX208R8R0<0QXJ60P2:RXX208j>SP80TI6A0P2@T90209>CT`80S8b<
1@2?Shl2092@T080UIFE0P2GUiL209FEU@80UiNG0`2EUID209JFUP80WIfM0P2GUiL209ZJVP80W9bL
0P2MWId309VIV@80VYZJ0P2LW9`209ZJVP80Vi^K0P2OWil209jNWP80X:2P1@2MWId209bLW080WYjN
0P2RXZ8209^KV`80UiNG0`2HV9P2096AT@@0U9BD102@T9020861P@<0Ng]k0P1dM7@207QhN080OGem
101oOgl208>3P`<0Ogmo0P20P80207alO080OWin0P23Ph<207moO`80PH610`1mOGd207MgM`80Kfm_
0P1^KVh80<SPf0001P38h=P2028R8P807alO0P0S8b<3055AD@80TY:B0P2GUiL209jNWP@0XZ:R0P2_
[jl30<;2`P80^KVi0P2n_[h20<30`080alO70P36a/H20;bl_0<0XZ:R0P0l?3`202<S8`809BDU0P0S
8b<202LW9`80:2PX0`0Y:BT602LW9`@0:b/[0P0_;bl202d];@<0;Rh^100_;bl202TY:@8092@T0P0Y
:BT205mOG`<0Jf][0P1`L70206IVIP80CDe=0P1>CTh205=CD`80GemO0`1VIVH206=SH`80JVYZ0P1/
K6`2071`L080Kfm_0P1hN7P307EeM@80N7Qh101jNWX407emO@80OWin0`23Ph<208:2PP80Ph>30P24
Q8@208>3P`80RHV90P28R8P308Z:RP80R8R81P2@T90209:BTP80T92@0`2DU9@209:BTP80TI6A0P2G
UiL209JFUP80V9RH1@2FUYH209>CT`80UIFE0P2IVIT209NGU`80VYZJ0P2OWil309bLW080Vi^K0P2O
Wil209fMW@80WinO0P2MWId209jNWP80X:2P0`2MWId409nOW`80WYjN0P2LW9`209^KV`80UYJF1`2D
U9@209>CT`80S8b<0P2;Rh/207alO0<0MgMg0P1jNWX207inOP80P8200P22PX8207QhN080Lg=c0`1/
K6`206EUI@80H61P0P1VIVH206e]K@80N7Qh0P1dM7@306m_K`80JFUY0P1PH60206ATI0P0b>3H0006
0<SPf0808R8R0P0O7al202<S8`<0DE5A0P2BTY8209NGU`80WYjN102RXZ820:n_[`<0`/;20P2i^KT2
0;jn_P80`<300P37alL20<K6aP80_;bl0`2RXZ8203`l?0808b<S0P0U9BD202<S8`809bLW0P0X:2P3
02TY:@H09bLW100[:b/202l_;`80;Bd]0`0^;Rh402l_;`80:BTY0P0T92@202TY:@80GemO0`1[Jf/2
071`L080IVIV0P1=CDd204i>CP80De=C0P1OGel306IVIP80Hf=S0P1ZJVX206a/K080L71`0P1_Kfl2
07QhN0<0MGEe0P1hN7P407YjNP@0OGem0P1nOWh308>3P`80PX:20P23Ph<208B4Q080Ph>30P29RHT2
08R8R0<0RXZ:0P28R8P6092@T080TY:B0P2@T90309BDU080TY:B0P2ATI4209NGU`80UYJF0P2HV9P5
09JFUP80Ti>C0P2EUID209VIV@80UiNG0P2JVYX209nOW`<0W9bL0P2KVi/209nOW`80WIfM0P2OWil2
09fMW@80WYjN0P2PX:0309fMW@@0WinO0P2NWYh209bLW080Vi^K0P2FUYH709BDU080Ti>C0P2<S8`2
08^;R`80O7al0`1gMgL207YjNP80OWin0P20P80208:2PP80N7Qh0P1cLg<306a/K080IFEU0P1PH602
06IVIP80KFe]0P1hN7P207AdM0<0Kfm_0P1YJFT2061PH080I6AT2038h=P000H0b>3H0P0R8R8201lO
7`808b<S0`1ADE4209:BTP80UiNG0P2NWYh40::RXP80[jn_0`32`/820;Vi^@80_[jn0P30`<020<O7
a`80a/K60P2l_;`30::RXP80?3`l0P0S8b<202DU9@808b<S0P0W9bL202PX:0<0:BTY1P0W9bL402/[
:`80;bl_0P0];Bd302h^;P@0;bl_0P0Y:BT202@T9080:BTY0P1OGel306][J`80L71`0P1VIVH204e=
C@80CTi>0P1CDe<205mOG`<0IVIV0P1SHf<206YZJP80K6a/0P1`L70206m_K`80N7Qh0`1eMGD207Qh
N0@0NWYj101mOGd207inOP<0Ph>30P22PX8208>3P`80Q8B40P23Ph<208V9R@80R8R80`2:RXX208R8
R0H0T92@0P2BTY82092@T0<0U9BD0P2BTY82096AT@80UiNG0P2FUYH209RHV0D0UYJF0P2CTi<209FE
U@80VIVI0P2GUiL209ZJVP80WinO0`2LW9`209^KV`80WinO0P2MWId209nOW`80WIfM0P2NWYh20:2P
X0<0WIfM102OWil209jNWP80W9bL0P2KVi/209JFUPL0U9BD0P2CTi<208b<S080Rh^;0P1lO7`307Mg
M`80NWYj0P1nOWh20820P080PX:20P1hN7P207=cL`<0K6a/0P1UIFD2061PH080IVIV0P1]KFd207Qh
N080M7Ad0`1_Kfl206UYJ@80H61P0P1TI6@80<SPf0001P38h=P2020P808071`L0P0R8R8302l_;`80
PH610P2TY:@20:JVYP80ZZZZ0P2a/K420;Bd]0<0aLG50P2g]kL20;jn_P80_kno0P31`L420;jn_P80
_;bl0`2^[Zh206EUI@80=3@d0P0S8b<2024Q8@@0:2PX0`0Z:RX402DU9@809RHV0P0[:b/202XZ:P80
=3@d0P0b<S8303@d=080;bl_0P0/;2`402LW9`80;Rh^0P1JFUX306e]K@80L71`0P1YJFT204M7A`80
Cdm?0P1EEED205aLG0<0HV9R0P1TI6@206IVIP80JFUY0P1^KVh207AdM080Lg=c0`1iNGT207alO080
NGUi0P20P80407emO@80Ogmo0`23Ph<208:2PP80PH610P20P80208F5Q@@0QhN70`28R8P208^;R`80
S8b<0P2;Rh/609>CT`<0SXj>0P2DU9@209>CT`80VIVI0P2GUiL409JFUP<0UIFE0P2HV9P209NGU`@0
U9BD0P2HV9P209fMW@<0W9bL0P2OWil20:2PX080WYjN0P2OWil209^KV`80WYjN0P2LW9`309jNWP80
WIfM0P2LW9`209nOW`80XZ:R102FUYH309RHV080UIFE0P2DU9@208n?S`80Rh^;0P25QHD207]kN`<0
MGEe0P1jNWX208B4Q080Ph>30P24Q8@20861P@80JFUY0`1GEeL204I6AP80>c/k0P17AdL2055AD@80
HF5Q0P1MGEd305aLG080EeMG0P1EEED205UIF@P0b>3H00060<SPf080820P0P0L71`2028R8P<0;bl_
0P21PH420:BTY080YZJV0P2ZZZX20;6a/@80];Bd0`35aLD20;Ng]`80_[jn0P2o_kl20<71`@80_[jn
0P2l_;`30:j^[P80IFEU0P0d=3@202<S8`808B4Q100X:2P302XZ:P@09BDU0P0V9RH202/[:`80:RXZ
0P0d=3@2038b<P<0=3@d0P0_;bl202`/;0@09bLW0P0^;Rh205YJFP<0KFe]0P1`L70206UYJ@80AdM7
0P1?Cdl205EEE@80G5aL0`1RHV8206ATI080IVIV0P1YJFT206i^KP80M7Ad0P1cLg<307UiN@80O7al
0P1iNGT20820P0@0OGem0P1oOgl308>3P`80PX:20P21PH420820P080QHF51027QhL308R8R080Rh^;
0P2<S8`208^;R`H0Ti>C0`2>SXh209BDU080Ti>C0P2IVIT209NGU`@0UYJF0`2EUID209RHV080UiNG
102DU9@209RHV080WIfM0`2LW9`209nOW`80X:2P0P2NWYh209nOW`80Vi^K0P2NWYh209bLW0<0WYjN
0P2MWId209bLW080WinO0P2RXZ8409JFUP<0V9RH0P2EUID209BDU080Shn?0P2;Rh/208F5Q@80Ng]k
0`1eMGD207YjNP80Q8B40P23Ph<208B4Q080PH610P1YJFT305MGE`80ATI60P0k>c/204M7A`80DE5A
0P1QHF4205eMG@<0G5aL0P1GEeL205EEE@80FEUI2038h=P000H0b>3H0P0U9BD2028R8P807alO0`0Q
8B4205QHF080[Jf]0P2a/K420:f][@80/k>c0P2j^[X30<C4a080];Bd0P2g]kL20;fm_@80_;bl0P2n
_[h20;Ng]`<0[Zj^0P2RXZ8207AdM080<30`0P0Y:BT202XZ:P808b<S0`0Q8B4402HV9P@09BDU0P0V
9RH202`/;080>3Ph0`0^;Rh202XZ:P80;Rh^100[:b/202d];@80EeMG0`1ZJVX2069RHP80GemO0P1;
Bd/204U9B@80DE5A0P1PH60305iNGP80H61P0P1RHV8206][J`80L71`0P1aLG4207EeM@<0NGUi0P1h
N7P407YjNP80Ng]k0P20P8020861P@<0PX:20P20P80408:2PP80QXJ60P2:RXX208V9R@D0R8R80P2;
Rh/208Z:RP80T92@0P2?Shl208f=S@<0SXj>0P2JVYX409JFUP80Ti>C102IVIT309JFUP80Vi^K0P2L
W9`209RHV080UIFE0P2JVYX209bLW0D0VYZJ0P2MWId209bLW080X:2P0P2OWil209jNWPD0WinO0P2N
WYh20:2PX080WinO0P2QXJ4209RHV080Ti>C0`2DU9@2096AT@80SHf=0P2?Shl208Z:RP80PX:20P1g
MgL307UiN@80PH610P24Q8@208J6QP80R8R80P23Ph<206EUI@<0@D510P0b<S82034a<@80<S8b0P10
@40204e=C@80FEUI0`1PH60205YJFP80Hf=S0P1aLG480<SPf0001P38h=P202DU9@808R8R0P0O7al3
024Q8@80F5QH0P2][Jd20;6a/@80[Jf]0P2c/k<20;Zj^P<0a<C40P2d];@20;Ng]`80_Kfm0P2l_;`2
0;jn_P80]kNg0`2^[Zh20::RXP80M7Ad0P0`<30202TY:@80:RXZ0P0S8b<3024Q8@@09RHV100U9BD2
02HV9P80;2`/0P0h>3P302h^;P80:RXZ0P0^;Rh402/[:`80;Bd]0P1GEeL306YZJP80HV9R0P1OGel2
04];B`80BDU90P1ADE42061PH0<0GUiN0P1PH602069RHP80Jf][0P1`L702075aL@80MGEe0`1iNGT2
07QhN0@0NWYj0P1kNg/20820P080PH610`22PX820820P0@0PX:20P26QXH208Z:RP80RHV91@28R8P2
08^;R`80RXZ:0P2@T90208n?S`80SHf=0`2>SXh209ZJVP@0UYJF0P2CTi<409VIV@<0UYJF0P2KVi/2
09bLW080V9RH0P2EUID209ZJVP80W9bL1@2JVYX209fMW@80W9bL0P2PX:0209nOW`80WYjN1@2OWil2
09jNWP80X:2P0P2OWil20:6QX@80V9RH0P2CTi<309BDU080TI6A0P2=SHd208n?S`80RXZ:0P22PX82
07MgM`<0NGUi0P21PH4208B4Q080QXJ60P28R8P208>3P`80IFEU0`11@D42038b<P80<C4a0P0b<S82
0410@080CDe=0P1IFET3061PH080FUYJ0P1SHf<2075aL@P0b>3H00060<SPf080820P100M7Ad301lO
7`80=cLg0P2RXZ820;Bd]080[:b/0P2_[jl20:f][@<0_kno102c/k<20;Rh^080_Kfm0P2i^KT20;>c
/`<0[jn_0P2WYjL20:6QX@80Fe]K0P0l?3`203De=@809bLW0`0U9BD2024Q8@@08R8R0P0V9RH202TY
:@80;Bd]1@0_;bl202DU9@809bLW0P0Y:BT202DU9@80;Rh^0P1NGUh306i^KP80F5QH0P1KFe/204M7
A`80D51@0P1<C4`205IFEP<0GEeM0P1RHV8206EUI@80JVYZ0P1gMgL207=cL`80NGUi0`1gMgL207em
O@80O7al0P1jNWX207emO@80PX:20P20P80307moO`80OWin0P22PX8208B4Q080QhN70P2:RXX208f=
S@<0S8b<0P2;Rh/208Z:RP@0T92@0P2ATI45092@T080UIFE0P2KVi/209BDU080TY:B0P2JVYX209BD
U0<0UiNG0P2JVYX209bLW080UIFE0P2HV9P209VIV@80WIfM0`2IVIT209nOW`80W9bL0P2NWYh209bL
W080WYjN0P2LW9`209jNWPD0WIfM0P2IVIT209nOW`80WIfM0P2LW9`209JFUP<0TY:B0P2DU9@408Z:
RP80QhN70P20P80207AdM0<0N7Qh0P27QhL208B4Q080QHF50P24Q8@208Z:RP80N7Qh0`1FEUH203Xj
>P80>3Ph0P0i>CT204U9B@80FEUI0P1VIVH3079bLP80Lg=c0P1gMgL207inOPP0b>3H00060<SPf080
820P100M7Ad301lO7`80=cLg0P2RXZ820;Bd]080[:b/0P2_[jl20:f][@<0_kno102c/k<20;Rh^080
_Kfm0P2i^KT20;>c/`<0[jn_0P2WYjL20:6QX@80Fe]K0P0l?3`203De=@809bLW0`0U9BD2024Q8@@0
8R8R0P0V9RH202TY:@80;Bd]1@0_;bl202DU9@809bLW0P0Y:BT202DU9@80;Rh^0P1NGUh306i^KP80
F5QH0P1KFe/204M7A`80D51@0P1<C4`205IFEP<0GEeM0P1RHV8206EUI@80JVYZ0P1gMgL207=cL`80
NGUi0`1gMgL207emO@80O7al0P1jNWX207emO@80PX:20P20P80307moO`80OWin0P22PX8208B4Q080
QhN70P2:RXX208f=S@<0S8b<0P2;Rh/208Z:RP@0T92@0P2ATI45092@T080UIFE0P2KVi/209BDU080
TY:B0P2JVYX209BDU0<0UiNG0P2JVYX209bLW080UIFE0P2HV9P209VIV@80WIfM0`2IVIT209nOW`80
W9bL0P2NWYh209bLW080WYjN0P2LW9`209jNWPD0WIfM0P2IVIT209nOW`80WIfM0P2LW9`209JFUP<0
TY:B0P2DU9@408Z:RP80QhN70P20P80207AdM0<0N7Qh0P27QhL208B4Q080QHF50P24Q8@208Z:RP80
N7Qh0`1FEUH203Xj>P80>3Ph0P0i>CT204U9B@80FEUI0P1VIVH3079bLP80Lg=c0P1gMgL207inOPP0
b>3H00060<SPf080:BTY0P0P8202024Q8@<07AdM0P0U9BD208b<S080[Zj^0P2UYJD40:NWY`D0];Bd
0P2YZJT40;2`/080];Bd0P2i^KT30;Bd]080][Jf0P2d];@209VIV@80Ng]k0P1<C4`202d];@<0:BTY
0P0V9RH2020P80H08R8R0P0`<30202d];@<0:b/[0P0V9RH202PX:080:BTY0P0U9BD203@d=080H61P
0`1_Kfl206ATI080G5aL0P16ATH204e=C@80C4a<0P1EEED305aLG080GEeM0P1VIVH206e]K@80M7Ad
0P1_Kfl207UiN@<0NWYj0P1mOGd20820P080O7al0P1mOGd208F5Q@80Ogmo0`1mOGd408>3P`80PX:2
0P28R8P208J6QP80S8b<0`2:RXX2096AT@@0SHf=0P2?Shl2092@T080SHf=0`2BTY8409FEU@80UYJF
0P2GUiL209FEU@80VYZJ0`2HV9P209FEU@80UiNG0P2EUID209NGU`80VIVI1@2LW9`209nOW`80V9RH
0P2MWId609jNWP80X:2P0`2OWil20:2PX080WIfM0P2KVi/209jNWP80UiNG0P2FUYH308n?S`80U9BD
102:RXX208B4Q080LG5a0P1/K6`3075aL@80PH610P1oOgl208V9R@80QhN71025QHD308>3P`80MgMg
0P1`L70207EeM@80OWin0P1oOgl20820P0<0PX:20P24Q8@207inOP80NWYj2038h=P000H0b>3H0P0Y
:BT2020P80808B4Q0`0M7Ad202DU9@80S8b<0P2^[Zh20:FUY@@0YjNW1@2d];@20:VYZ@@0/;2`0P2d
];@20;Vi^@<0];Bd0P2f][H20;Bd]080VIVI0P1kNg/204a<C080;Bd]0`0Y:BT202HV9P80820P1P0R
8R82030`<080;Bd]0`0[:b/202HV9P80:2PX0P0Y:BT202DU9@80=3@d0P1PH60306m_K`80I6AT0P1L
G5`204I6AP80CDe=0P1<C4`205EEE@<0G5aL0P1MGEd206IVIP80KFe]0P1dM7@206m_K`80NGUi0`1j
NWX207emO@80P8200P1lO7`207emO@80QHF50P1oOgl307emO@@0Ph>30P22PX8208R8R080QXJ60P2<
S8`308Z:RP80TI6A102=SHd208n?S`80T92@0P2=SHd309:BTP@0UIFE0P2FUYH209NGU`80UIFE0P2J
VYX309RHV080UIFE0P2GUiL209FEU@80UiNG0P2IVIT509bLW080WinO0P2HV9P209fMW@H0WYjN0P2P
X:0309nOW`80X:2P0P2MWId209^KV`80WYjN0P2GUiL209JFUP<0Shn?0P2DU9@408Z:RP80Q8B40P1a
LG4206a/K0<0LG5a0P21PH4207moO`80RHV90P27QhL408F5Q@<0Ph>30P1gMgL2071`L080MGEe0P1n
OWh207moO`80P8200`22PX8208B4Q080OWin0P1jNWX80<SPf0001P38h=P202XZ:P80820P1@0K6a/2
01dM7@80HV9R0P2XZ:P209fMW@80ZZZZ0P2XZ:P30:JVYP80[jn_0P2YZJT20:b/[080YjNW0P2a/K45
0;Fe]@80^;Rh0P2m_Kd20:f][@80S8b<0P1gMgL204m?C`<0=cLg0P0Y:BT202@T90@09RHV0P0W9bL2
02`/;080:BTY1@0a<C4202l_;`809RHV0P0W9bL2038b<P80F5QH0`1YJFT205]KF`80EUIF0P0n?Sh2
03Xj>P80AdM70P1EEED305YJFP80H61P0P1UIFD206i^KP80M7Ad0P1cLg<207IfMP<0OGem0P1lO7`2
07moO`80Ph>30P1mOGd208B4Q080P8200`1oOgl208>3P`80P8200P25QHD208J6QP80Ph>30P2;Rh/3
092@T080SXj>0P29RHT408f=S@80UiNG0P2=SHd308n?S`80V9RH0P2?Shl209JFUP80VIVI0P2CTi<2
09NGU`<0UIFE102GUiL209BDU080Vi^K102LW9`30:2PX080VYZJ0P2GUiL209bLW080XJ6Q102OWil5
09jNWP80W9bL0P2KVi/209ZJVP80Vi^K0P2FUYH2096AT@<0TY:B0P2@T90208^;R`80U9BD0P20P802
07AdM080K6a/0`1dM7@207alO080OGem0P27QhL208Z:RP80QhN70P26QXH308N7Q`80QXJ60P24Q8@2
08J6QP80SHf=0P29RHT208B4Q0<0Rh^;0P24Q8@207inOP80MgMg2038h=P000H0b>3H0P0Z:RX2020P
80D06a/K0P0M7Ad2069RHP80Z:RX0P2MWId20:ZZZP80Z:RX0`2VYZH20:n_[`80ZJVY0P2/[:`20:NW
Y`80/K6a1@2e]KD20;Rh^080_Kfm0P2][Jd208b<S080MgMg0P1?Cdl303Lg=`80:BTY0P0T92@402HV
9P809bLW0P0/;2`202TY:@D0<C4a0P0_;bl202HV9P809bLW0P0b<S8205QHF0<0JFUY0P1KFe/205IF
EP80?Shn0P0j>SX204M7A`80EEEE0`1JFUX2061PH080IFEU0P1^KVh207AdM080Lg=c0P1fMWH307em
O@80O7al0P1oOgl208>3P`80OGem0P24Q8@20820P0<0Ogmo0P23Ph<20820P080QHF50P26QXH208>3
P`80Rh^;0`2@T90208j>SP80RHV9102=SHd209NGU`80SHf=0`2?Shl209RHV080Shn?0P2FUYH209VI
V@80Ti>C0P2GUiL309FEU@@0UiNG0P2DU9@209^KV`@0W9bL0`2PX:0209ZJVP80UiNG0P2LW9`20:6Q
X@@0WinO1@2NWYh209bLW080Vi^K0P2JVYX209^KV`80UYJF0P2ATI4309:BTP80T92@0P2;Rh/209BD
U080P8200P1dM7@206a/K0<0M7Ad0P1lO7`207emO@80QhN70P2:RXX208N7Q`80QXJ60`27QhL208J6
QP80Q8B40P26QXH208f=S@80RHV90P24Q8@308^;R`80Q8B40P1nOWh207MgM`P0b>3H00060<SPf080
:2PX0P0V9RH501dM7@8071`L0P0k>c/20:2PX0@0Xj>S0P2UYJD509nOW`80YZJV0P2/[:`20:6QX@80
WYjN0P2KVi/309nOW`80ZJVY0P2m_Kd20;Zj^P80ZZZZ0P2?Shl205eMG@<0@D510P0V9RH2024Q8@80
820P0P0O7al202HV9P80=CDe0P0X:2P302l_;`80:2PX0P0Z:RX202TY:@80:2PX0P0d=3@205]KF`<0
JVYZ0P1WIfL205YJFP80AdM70P14A4@203dm?@80De=C0`1HF5P205mOG`80JFUY0P1`L702079bLP80
M7Ad1@1fMWH208>3P`80Ng]k0P1oOgl208B4Q080PH611@1oOgl408>3P`H0QXJ60P27QhL708f=S@80
T92@0P2=SHd209:BTP80SHf=0`2CTi<2092@T080TI6A0P2DU9@209bLW080UiNG0P2FUYH309RHV080
Vi^K102LW9`209NGU`80W9bL0P2MWId309jNWP80Vi^K0P2NWYh209fMW@80WYjN0P2UYJD409jNWP<0
WinO0P2LW9`20::RXP80WIfM0P2JVYX209NGU`80U9BD0`2IVIT208n?S`80TI6A0P2?Shl208>3P`80
MGEe0P1[Jf/3079bLP80N7Qh0P1mOGd208F5Q@80Shn?0P2=SHd208^;R`<0RHV90P28R8P208Z:RP80
TY:B0P2=SHd208n?S`80T92@0`2<S8`208>3P`80OWin0P1hN7P80<SPf0001P38h=P202PX:0809RHV
1@0M7Ad201`L7080>c/k0P2PX:040:>SX`80YJFU1@2OWil20:JVYP80[:b/0P2QXJ4209jNWP80Vi^K
0`2OWil20:VYZ@80_Kfm0P2j^[X20:ZZZP80Shn?0P1MGEd30451@@809RHV0P0Q8B42020P80807alO
0P0V9RH203De=@80:2PX0`0_;bl202PX:080:RXZ0P0Y:BT202PX:080=3@d0P1KFe/306YZJP80IfMW
0P1JFUX204M7A`80A4A40P0m?Cd205=CD`<0F5QH0P1OGel206UYJ@80L71`0P1bLW8207AdM0D0MWIf
0P23Ph<207]kN`80Ogmo0P24Q8@20861P@D0Ogmo1023Ph<608J6QP80QhN71`2=SHd2092@T080SHf=
0P2BTY8208f=S@<0Ti>C0P2@T902096AT@80U9BD0P2LW9`209NGU`80UYJF0`2HV9P209^KV`@0W9bL
0P2GUiL209bLW080WIfM0`2NWYh209^KV`80WYjN0P2MWId209jNWP80YJFU102NWYh309nOW`80W9bL
0P2RXZ8209fMW@80VYZJ0P2GUiL209BDU0<0VIVI0P2?Shl2096AT@80Shn?0P23Ph<207EeM@80Jf][
0`1bLW8207QhN080OGem0P25QHD208n?S`80SHf=0P2;Rh/308V9R@80R8R80P2:RXX209:BTP80SHf=
0P2?Shl2092@T0<0S8b<0P23Ph<207inOP80N7Qh2038h=P000H0b>3H0P0V9RH2034a<@809bLW0`0P
8202024Q8@80:RXZ0P1hN7P20:VYZ@80XJ6Q0P2VYZH30:BTY080VIVI0P2FUYH209:BTP80PH610P20
P80207EeM@<0MgMg0P22PX820:6QX@80Zj^[0P2m_Kd20;6a/@80TI6A0`1UIFD2034a<@H092@T0P0X
:2P202HV9P80<S8b0`0W9bL202<S8`809bLW0P0X:2P202DU9@80;2`/0P1MGEd3075aL@80Hf=S0P1I
FET204=3@`80ADE50P1:BTX204a<C0<0G5aL0P1JFUX206UYJ@80KFe]0P1_Kfl207AdM080N7Qh0`1k
Ng/20820P080N7Qh0P1mOGd207moO`80PX:20P20P8030861P@80QHF50P21PH4208>3P`80R8R80P27
QhL208V9R@<0S8b<0P2;Rh/209:BTP80Shn?102@T90508n?S`80Ti>C0P2EUID409NGU`80UYJF0P2I
VIT309FEU@80V9RH0P2QXJ4209^KV`80WIfM0P2OWil209bLW0/0WinO0P2RXZ8209nOW`80WYjN0`2O
Wil209fMW@80XJ6Q0P2NWYh209ZJVP80UIFE1@2BTY82092@T080Rh^;0P2<S8`207inOP80N7Qh0P1X
J6P3071`L080MWIf0P1mOGd408J6QP@0SHf=0`2>SXh208V9R@80S8b<0P2=SHd208b<S080T92@0P2>
SXh308Z:RP80PX:20P1lO7`207UiN@P0b>3H00060<SPf0809RHV0P0a<C4202LW9`<0820P0P0Q8B42
02XZ:P80N7Qh0P2YZJT20:6QX@80YZJV0`2TY:@209VIV@80UYJF0P2BTY820861P@80P8200P1eMGD3
07MgM`80PX:20P2QXJ420:^[Z`80_Kfm0P2a/K42096AT@<0IFEU0P0a<C4602@T9080:2PX0P0V9RH2
038b<P<09bLW0P0S8b<202LW9`80:2PX0P0U9BD202`/;080GEeM0`1aLG4206=SH`80FEUI0P13@d<2
04E5A@80BTY:0P1<C4`305aLG080FUYJ0P1YJFT206e]K@80Kfm_0P1dM7@207QhN0<0Ng]k0P20P802
07QhN080OGem0P1oOgl208:2PP80P8200`21PH4208F5Q@80PH610P23Ph<208R8R080QhN70P29RHT3
08b<S080Rh^;0P2BTY8208n?S`@0T92@1@2?Shl209>CT`80UIFE102GUiL209JFUP80VIVI0`2EUID2
09RHV080XJ6Q0P2KVi/209fMW@80WinO0P2LW9`;09nOW`80XZ:R0P2OWil209jNWP<0WinO0P2MWId2
0:6QX@80WYjN0P2JVYX209FEU@D0TY:B0P2@T90208^;R`80S8b<0P1nOWh207QhN080J6QX0`1`L702
07IfMP80OGem1026QXH408f=S@<0SXj>0P29RHT208b<S080SHf=0P2<S8`2092@T080SXj>0`2:RXX2
08:2PP80O7al0P1iNGT80<SPf0001P38h=P202HV9P80<C4a0P0W9bL3020P80808B4Q0P0Z:RX207Qh
N080ZJVY0P2QXJ420:JVYP<0Y:BT0P2IVIT209JFUP80TY:B0P21PH420820P080MGEe0`1gMgL208:2
PP80XJ6Q0P2[Zj/20;fm_@80/K6a0P2ATI4306EUI@80<C4a1P0T92@202PX:0809RHV0P0b<S8302LW
9`808b<S0P0W9bL202PX:0809BDU0P0/;2`205eMG@<0LG5a0P1SHf<205UIF@80@d=30P15ADD204Y:
BP80C4a<0`1LG5`205YJFP80JFUY0P1]KFd206m_K`80M7Ad0P1hN7P307]kN`80P8200P1hN7P207em
O@80Ogmo0P22PX820820P0<0PH610P25QHD20861P@80Ph>30P28R8P208N7Q`80RHV90`2<S8`208^;
R`80TY:B0P2?Shl4092@T0D0Shn?0P2CTi<209FEU@@0UiNG0P2FUYH209VIV@<0UIFE0P2HV9P20:6Q
X@80Vi^K0P2MWId209nOW`80W9bL2`2OWil20::RXP80WinO0P2NWYh309nOW`80WIfM0P2QXJ4209jN
WP80VYZJ0P2EUID509:BTP80T92@0P2;Rh/208b<S080OWin0P1hN7P206QXJ0<0L71`0P1fMWH207em
O@@0QXJ6102=SHd308j>SP80RHV90P2<S8`208f=S@80S8b<0P2@T90208j>SP<0RXZ:0P22PX8207al
O080NGUi2038h=P000H0b>3H0P0U9BD2030`<080;2`/0`0Q8B42028R8P809BDU0P17AdL208b<S080
V9RH0P2JVYX309JFUP80R8R80P21PH4207IfMP80Jf][0P1]KFd206ATI0<0MWIf0P23Ph<208N7Q`80
TY:B0P2RXZ820:f][@80W9bL0`1^KVh203Lg=`80:BTY0P0U9BD202HV9P@08b<S0P0W9bL302h^;P80
92@T0P0_;bl204I6AP809BDU0P0^;Rh205MGE`<0LG5a0P1KFe/204i>CP80ATI60P13@d<204A4A080
CTi>0`1IFET205MGE`80Hf=S0P1[Jf/207IfMP80LW9b0P1gMgL307YjNP80Ng]k0P22PX8207inOP80
O7al0P22PX8207moO`<0P8200P22PX8608J6QP80S8b<0P28R8P308n?S`80SXj>102ATI4208f=S@80
SXj>0P2?Shl309>CT`80W9bL0P2CTi<209VIV@@0UYJF0P2EUID309NGU`80VYZJ0P2MWId209bLW080
WinO0P2LW9`209nOW`<0W9bL0P2MWId409jNWP80X:2P0P2RXZ8209jNWP80WinO0`2MWId409nOW`80
WIfM0P2JVYX209:BTP80Ti>C0`2>SXh208^;R`80SHf=0P2:RXX207emO@80M7Ad0P1[Jf/306e]K@80
M7Ad0P1mOGd208>3P`80QhN70P2:RXX208f=S@<0Rh^;0P28R8P208^;R`80T92@0P2=SHd208n?S`80
R8R80`26QXH40820P080OGem2038h=P000H0b>3H0P0U9BD2030`<080;2`/0`0Q8B42028R8P809BDU
0P17AdL208b<S080V9RH0P2JVYX309JFUP80R8R80P21PH4207IfMP80Jf][0P1]KFd206ATI0<0MWIf
0P23Ph<208N7Q`80TY:B0P2RXZ820:f][@80W9bL0`1^KVh203Lg=`80:BTY0P0U9BD202HV9P@08b<S
0P0W9bL302h^;P8092@T0P0_;bl204I6AP809BDU0P0^;Rh205MGE`<0LG5a0P1KFe/204i>CP80ATI6
0P13@d<204A4A080CTi>0`1IFET205MGE`80Hf=S0P1[Jf/207IfMP80LW9b0P1gMgL307YjNP80Ng]k
0P22PX8207inOP80O7al0P22PX8207moO`<0P8200P22PX8608J6QP80S8b<0P28R8P308n?S`80SXj>
102ATI4208f=S@80SXj>0P2?Shl309>CT`80W9bL0P2CTi<209VIV@@0UYJF0P2EUID309NGU`80VYZJ
0P2MWId209bLW080WinO0P2LW9`209nOW`<0W9bL0P2MWId409jNWP80X:2P0P2RXZ8209jNWP80WinO
0`2MWId409nOW`80WIfM0P2JVYX209:BTP80Ti>C0`2>SXh208^;R`80SHf=0P2:RXX207emO@80M7Ad
0P1[Jf/306e]K@80M7Ad0P1mOGd208>3P`80QhN70P2:RXX208f=S@<0Rh^;0P28R8P208^;R`80T92@
0P2=SHd208n?S`80R8R80`26QXH40820P080OGem2038h=P000H0b>3H100T92@2038b<P<09RHV0P0R
8R8201hN7P808R8R0P1<C4`207QhN080Ph>30`1hN7P407YjNP80IfMW0P1UIFD406a/K0<0T92@0P2e
]KD20:f][@80Xj>S0P2=SHd2092@T080VYZJ0`27QhL205YJFP80ADE50P0];Bd202<S8`808R8R0P0[
:b/202DU9@<0:b/[100X:2P2028R8P808b<S0P0^;Rh205YJFP<0KFe]0P1JFUX204=3@`80@4100P1;
Bd/204i>CP80DE5A0`1CDe<405mOG`80JVYZ0P1dM7@2075aL@D0MWIf0P1mOGd207moO`80OGem0P1l
O7`208:2PP80OGem0`21PH4208>3P`80QXJ60P25QHD208N7Q`80Rh^;0P2=SHd308Z:RP80Rh^;0P2?
Shl209BDU080Ti>C0P2DU9@208n?S`<0Ti>C0P2KVi/409NGU`80VYZJ0P2HV9P209JFUPD0VYZJ0P2F
UYH209VIV@80W9bL0P2JVYX209nOW`<0VIVI0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`80XZ:R0P2T
Y:@30:>SX`@0XJ6Q0P2KVi/209VIV@80V9RH0P2IVIT309:BTP80S8b<0P2;Rh/208n?S`80Ogmo0P1g
MgL2079bLP<0KVi^0P1cLg<207alO080P8200P27QhL208J6QP80Rh^;0`28R8P208Z:RP80RHV90P2;
Rh/208n?S`@0Q8B40`21PH4207alO080OGem0P1oOgl80<SPf0001P38h=P402@T9080<S8b0`0V9RH2
028R8P807QhN0P0R8R8204a<C080N7Qh0P23Ph<307QhN0@0NWYj0P1WIfL206EUI@@0K6a/0`2@T902
0;Fe]@80[Jf]0P2SXj<208f=S@80T92@0P2JVYX308N7Q`80FUYJ0P15ADD202d];@808b<S0P0R8R82
02/[:`809BDU0`0[:b/402PX:0808R8R0P0S8b<202h^;P80FUYJ0`1]KFd205YJFP80@d=30P10@402
04];B`80CTi>0P1ADE4305=CD`@0GemO0P1ZJVX207AdM080LG5a1@1fMWH207emO@80Ogmo0P1mOGd2
07alO080PX:20P1mOGd30861P@80Ph>30P26QXH208F5Q@80QhN70P2;Rh/208f=S@<0RXZ:0P2;Rh/2
08n?S`80U9BD0P2CTi<209BDU080Shn?0`2CTi<209^KV`@0UiNG0P2JVYX209RHV080UYJF1@2JVYX2
09JFUP80VIVI0P2LW9`209ZJVP80WinO0`2IVIT20::RXP80WinO0P2LW9`20:6QX@80WinO0P2RXZ82
0:BTY0<0Xj>S102QXJ4209^KV`80VIVI0P2HV9P209VIV@<0TY:B0P2<S8`208^;R`80Shn?0P1oOgl2
07MgM`80LW9b0`1^KVh207=cL`80O7al0P20P80208N7Q`80QXJ60P2;Rh/308R8R080RXZ:0P29RHT2
08^;R`80Shn?1024Q8@30861P@80O7al0P1mOGd207moO`P0b>3H00060<SPf0@08b<S0P0`<30302l_
;`80:b/[0P0N7Qh202<S8`80:2PX0P1ADE4206EUI@<0IfMW0P1nOWh208F5Q@80JVYZ0P1^KVh4079b
LP<0T92@0P2i^KT20<W9b@80`l?30P2VYZH208:2PP80UiNG0`1mOGd203@d=08092@T0P0S8b<201lO
7`807QhN0P0S8b<202TY:@<09BDU0P0R8R8202XZ:P809BDU0P0Y:BT202XZ:P80G5aL0`1/K6`205aL
G080@D510P0h>3P204M7A`80B4Q80P1?Cdl305IFEP80GEeM0P1WIfL206QXJ080K6a/0P1cLg<507Ee
M@80NGUi0P1mOGd207moO`80P8200P24Q8@208:2PP<0Ph>30P22PX8208N7Q`80QHF50P28R8P208J6
QP80QhN70`2<S8`208^;R`80SHf=0P2@T902096AT@@0Ti>C0`2EUID209ZJVP80Vi^K0P2IVIT409RH
V080UiNG0`2IVIT209ZJVP80UYJF0P2JVYX209fMW@80WYjN0P2MWId30::RXP80Xj>S0P2OWil20::R
XP80YZJV0P2NWYh20::RXPD0Y:BT0P2SXj<20:6QX@80WIfM0P2LW9`409RHV0<0UYJF0P2ATI42092@
T080SXj>0P25QHD207alO080NGUi0`1eMGD2079bLP80MWIf0P1lO7`208B4Q080QHF50P23Ph<308N7
Q`80QXJ60P24Q8@208>3P`80PX:20P1oOgl208B4Q0<0NGUi101kNg/20861P@P0b>3H00060<SPf0@0
8b<S0P0`<30302l_;`80:b/[0P0N7Qh202<S8`80:2PX0P1ADE4206EUI@<0IfMW0P1nOWh208F5Q@80
JVYZ0P1^KVh4079bLP<0T92@0P2i^KT20<W9b@80`l?30P2VYZH208:2PP80UiNG0`1mOGd203@d=080
92@T0P0S8b<201lO7`807QhN0P0S8b<202TY:@<09BDU0P0R8R8202XZ:P809BDU0P0Y:BT202XZ:P80
G5aL0`1/K6`205aLG080@D510P0h>3P204M7A`80B4Q80P1?Cdl305IFEP80GEeM0P1WIfL206QXJ080
K6a/0P1cLg<507EeM@80NGUi0P1mOGd207moO`80P8200P24Q8@208:2PP<0Ph>30P22PX8208N7Q`80
QHF50P28R8P208J6QP80QhN70`2<S8`208^;R`80SHf=0P2@T902096AT@@0Ti>C0`2EUID209ZJVP80
Vi^K0P2IVIT409RHV080UiNG0`2IVIT209ZJVP80UYJF0P2JVYX209fMW@80WYjN0P2MWId30::RXP80
Xj>S0P2OWil20::RXP80YZJV0P2NWYh20::RXPD0Y:BT0P2SXj<20:6QX@80WIfM0P2LW9`409RHV0<0
UYJF0P2ATI42092@T080SXj>0P25QHD207alO080NGUi0`1eMGD2079bLP80MWIf0P1lO7`208B4Q080
QHF50P23Ph<308N7Q`80QXJ60P24Q8@208>3P`80PX:20P1oOgl208B4Q0<0NGUi101kNg/20861P@P0
b>3H00060<SPf0809BDU0P0a<C4202`/;0<0=cLg0P0_;bl201lO7`806a/K0P0Q8B4202h^;P80Cdm?
0`1;Bd/206e]K@80QhN70P1fMWH2079bLP80P8200P1kNg/307inOP80WYjN0P39bLT40<[:bP80Zj^[
0P2PX:030:>SX`80?3`l0P0X:2P2028R8P807alO0P0U9BD202LW9`80:b/[0`0W9bL202HV9P80;2`/
100U9BD202`/;080FEUI0`1ZJVX205eMG@80?Cdm0P12@T8204M7A`80CDe=0P1BDU8305UIF@80F5QH
0P1UIFD206YZJP80KFe]0P1eMGD207AdM0<0MWIf0P1kNg/207inOP80OGem1020P8020861P@L0QHF5
0P2<S8`208N7Q`80PX:20P25QHD308Z:RP80RHV90P2=SHd209BDU080TY:B0P2GUiL209JFUP<0Ti>C
0P2IVIT209JFUP@0UiNG0P2HV9P209JFUP<0U9BD0P2KVi/209ZJVP80WYjN0P2OWil20::RXPL0X:2P
0P2RXZ840:FUY@80WYjN0P2SXj<20:FUY@<0XZ:R0P2MWId209nOW`80WIfM0P2KVi/209RHV080TY:B
0`2EUID408j>SP80T92@0P2:RXX208>3P`80O7al0`1gMgL2079bLP80NGUi0P1mOGd208:2PP@0QXJ6
0`2;Rh/208N7Q`80Ph>30P21PH4207inOP80Ng]k0P1lO7`307YjNP80O7al0P1kNg/207inOPP0b>3H
00060<SPf0809BDU0P0a<C4202`/;0<0=cLg0P0_;bl201lO7`806a/K0P0Q8B4202h^;P80Cdm?0`1;
Bd/206e]K@80QhN70P1fMWH2079bLP80P8200P1kNg/307inOP80WYjN0P39bLT40<[:bP80Zj^[0P2P
X:030:>SX`80?3`l0P0X:2P2028R8P807alO0P0U9BD202LW9`80:b/[0`0W9bL202HV9P80;2`/100U
9BD202`/;080FEUI0`1ZJVX205eMG@80?Cdm0P12@T8204M7A`80CDe=0P1BDU8305UIF@80F5QH0P1U
IFD206YZJP80KFe]0P1eMGD207AdM0<0MWIf0P1kNg/207inOP80OGem1020P8020861P@L0QHF50P2<
S8`208N7Q`80PX:20P25QHD308Z:RP80RHV90P2=SHd209BDU080TY:B0P2GUiL209JFUP<0Ti>C0P2I
VIT209JFUP@0UiNG0P2HV9P209JFUP<0U9BD0P2KVi/209ZJVP80WYjN0P2OWil20::RXPL0X:2P0P2R
XZ840:FUY@80WYjN0P2SXj<20:FUY@<0XZ:R0P2MWId209nOW`80WIfM0P2KVi/209RHV080TY:B0`2E
UID408j>SP80T92@0P2:RXX208>3P`80O7al0`1gMgL2079bLP80NGUi0P1mOGd208:2PP@0QXJ60`2;
Rh/208N7Q`80Ph>30P21PH4207inOP80Ng]k0P1lO7`307YjNP80O7al0P1kNg/207inOPP0b>3H0006
0<SPf080:RXZ0P0T92@202TY:@<0>SXj0P0b<S82024Q8@808b<S0P0`<302024Q8@80;2`/0`0X:2P2
05aLG080RHV90P2:RXX207EeM@@0N7Qh0`1iNGT209:BTP80_kno0P3<c<`20<k>cP80b/[:0P2o_kl3
0<G5a@80Ogmo0P0_;bl4028R8P809bLW0P0[:b/202TY:@<08R8R0P0X:2P402LW9`80:2PX0P0`<302
05IFEP<0I6AT0P1JFUX20451@@80=cLg0P18B4P204E5A@80De=C0`1GEeL205aLG080H61P0P1VIVH2
075aL@80MGEe1@1gMgL207emO@H0P8200P27QhL708B4Q0@0QXJ60P2:RXX208N7Q`80S8b<0`2?Shl2
08J6QP@0T92@0P2BTY8209JFUP80VIVI0`2CTi<209NGU`80UIFE0P2HV9P209BDU080UYJF0P2JVYX3
09fMW@80Vi^K102LW9`209RHV080WYjN0P2SXj<30::RXP80X:2P0P2UYJD40:BTY080X:2P102TY:@3
0:>SX`80Y:BT0P2QXJ4209jNWP80Vi^K0P2MWId509BDU080TY:B0P2?Shl208j>SP80R8R80P25QHD2
07emO@<0O7al0P1jNWX207]kN`80O7al0P1kNg/208:2PP80Ph>30`2<S8`208F5Q@80OGem0P1oOgl2
07]kN`80OGem0P1nOWh307UiN@80MGEe0P1jNWX207inOPP0b>3H00060<SPf080:RXZ0P0T92@202TY
:@<0>SXj0P0b<S82024Q8@808b<S0P0`<302024Q8@80;2`/0`0X:2P205aLG080RHV90P2:RXX207Ee
M@@0N7Qh0`1iNGT209:BTP80_kno0P3<c<`20<k>cP80b/[:0P2o_kl30<G5a@80Ogmo0P0_;bl4028R
8P809bLW0P0[:b/202TY:@<08R8R0P0X:2P402LW9`80:2PX0P0`<30205IFEP<0I6AT0P1JFUX20451
@@80=cLg0P18B4P204E5A@80De=C0`1GEeL205aLG080H61P0P1VIVH2075aL@80MGEe1@1gMgL207em
O@H0P8200P27QhL708B4Q0@0QXJ60P2:RXX208N7Q`80S8b<0`2?Shl208J6QP@0T92@0P2BTY8209JF
UP80VIVI0`2CTi<209NGU`80UIFE0P2HV9P209BDU080UYJF0P2JVYX309fMW@80Vi^K102LW9`209RH
V080WYjN0P2SXj<30::RXP80X:2P0P2UYJD40:BTY080X:2P102TY:@30:>SX`80Y:BT0P2QXJ4209jN
WP80Vi^K0P2MWId509BDU080TY:B0P2?Shl208j>SP80R8R80P25QHD207emO@<0O7al0P1jNWX207]k
N`80O7al0P1kNg/208:2PP80Ph>30`2<S8`208F5Q@80OGem0P1oOgl207]kN`80OGem0P1nOWh307Ui
N@80MGEe0P1jNWX207inOPP0b>3H00060<SPf0808b<S0P0U9BD2038b<P<0>3Ph0P0_;bl202`/;0@0
7alO0P0R8R8201hN7P<08R8R0P14A4@208:2PP80VYZJ0P1kNg/2075aL@80MWIf0`1cLg<207moO`80
Z:RX0P3@d=020<o?c`80d=3@0P3<c<`30=3@d080^KVi0P19BDT202HV9P808b<S0P0Z:RX202HV9P80
:2PX0`0/;2`402@T90809BDU0P0R8R8202PX:080De=C0`1PH60205ADE080?3`l0P11@D4204Y:BP80
Bd];0P1DE5@305eMG@80HF5Q0P1WIfL206YZJP80LG5a0P1eMGD207MgM`<0NGUi0P1gMgL207moO`@0
P8200P25QHD50861P@80QhN70P23Ph<208J6QP80QhN70P2;Rh/208b<S0<0V9RH0P2:RXX209:BTP@0
T92@0P2FUYH209RHV0<0TY:B0P2IVIT209RHV080VIVI0P2HV9P209ZJVP80Vi^K0`2NWYh409^KV`80
WinO0P2JVYX209jNWP80X:2P0`2OWil20:>SX`@0YjNW0P2TY:@20:>SX`80X:2P0P2NWYh30:2PX080
XJ6Q0P2SXj<209nOW`80WYjN0P2MWId209VIV@<0UIFE0P2ATI4209:BTP80RHV90P28R8P208N7Q`80
PX:20`1nOWh20861P@80Ogmo0P1nOWh207alO0@0Ph>30`27QhL208>3P`80OWin0P1lO7`207]kN`@0
Ogmo0`1iNGT207EeM@80MWIf0P21PH480<SPf0001P38h=P202<S8`809BDU0P0b<S8303Ph>080;bl_
0P0/;2`401lO7`808R8R0P0N7Qh3028R8P80A4A40P22PX8209ZJVP80Ng]k0P1aLG4207IfMP<0Lg=c
0P1oOgl20:RXZ080d=3@0P3?cll20=3@d080c<c<0`3@d=020;Vi^@80BDU90P0V9RH202<S8`80:RXZ
0P0V9RH202PX:0<0;2`/100T92@202DU9@808R8R0P0X:2P205=CD`<0H61P0P1DE5@203`l?080@D51
0P1:BTX204];B`80E5AD0`1MGEd2065QH@80IfMW0P1ZJVX2075aL@80MGEe0P1gMgL307UiN@80MgMg
0P1oOgl40820P080QHF51@21PH4208N7Q`80Ph>30P26QXH208N7Q`80Rh^;0P2<S8`309RHV080RXZ:
0P2BTY84092@T080UYJF0P2HV9P309:BTP80VIVI0P2HV9P209VIV@80V9RH0P2JVYX209^KV`<0WYjN
102KVi/209nOW`80VYZJ0P2NWYh20:2PX0<0WinO0P2SXj<40:NWY`80Y:BT0P2SXj<20:2PX080WYjN
0`2PX:020:6QX@80Xj>S0P2OWil209jNWP80WIfM0P2IVIT309FEU@80TI6A0P2BTY8208V9R@80R8R8
0P27QhL208:2PP<0OWin0P21PH4207moO`80OWin0P1lO7`408>3P`<0QhN70P23Ph<207inOP80O7al
0P1kNg/407moO`<0NGUi0P1eMGD207IfMP80PH612038h=P000H0b>3H0P0S8b<202h^;P80?Cdm0`1>
CTh203De=@808b<S0P0P820201/K6`807QhN0P0L71`301lO7`80;bl_0P1[Jf/208n?S`80QXJ60P1c
Lg<2071`L0<0M7Ad0P1fMWH2092@T080_kno0P3=cLd20<_;b`80c/k>0`3<c<`20<k>cP80Xj>S0P0h
>3P202DU9@8092@T0P0V9RH202TY:@<09BDU0P0V9RH202LW9`808R8R0P0T92@202DU9@80CDe=0`1V
IVH204i>CP80>SXj0P12@T8204M7A`80ADE50P1;Bd/305MGE`80HF5Q0P1WIfL206a/K0@0LG5a0P1i
NGT307inOP80P8200P1jNWX207inOP@0P8200P23Ph<308:2PP80QhN70P28R8P408V9R@80RXZ:1@2>
SXh208n?S`80U9BD0P2CTi<2092@T080TI6A0P2HV9P309^KV`80UiNG0P2FUYH209VIV@80VYZJ0P2N
WYh20::RXP<0WYjN0P2MWId209bLW080X:2P1P2OWil30::RXP80YZJV0P2XZ:P20::RXP80YZJV0P2T
Y:@20:FUY@80XZ:R0`2PX:020:BTY080YJFU0P2RXZ820:JVYP80WinO0P2NWYh309ZJVP@0Ti>C0P2<
S8`208j>SP@0QHF51@24Q8@20820P0@0PH610P24Q8@207emO@<0Q8B40P22PX8207alO080Ogmo0P1l
O7`207]kN`80NGUi0`1kNg/207UiN@80O7al0P1mOGd80<SPf0001P38h=P202<S8`80;Rh^0P0m?Cd3
04i>CP80=CDe0P0S8b<2020P80806a/K0P0N7Qh201`L70<07alO0P0_;bl206][J`80Shn?0P26QXH2
07=cL`80L71`0`1dM7@207IfMP80T92@0P2o_kl20<g=c@80bl_;0P3>c/h30<c<c080c/k>0P2SXj<2
03Ph>0809BDU0P0T92@202HV9P80:BTY0`0U9BD202HV9P809bLW0P0R8R8202@T90809BDU0P1=CDd3
06IVIP80CTi>0P0j>SX20492@P80AdM70P15ADD204];B`<0EeMG0P1QHF4206MWI`80K6a/101aLG42
07UiN@<0OWin0P20P80207YjNP80OWin1020P80208>3P`<0PX:20P27QhL208R8R0@0RHV90P2:RXX5
08j>SP80Shn?0P2DU9@209>CT`80T92@0P2ATI4209RHV0<0Vi^K0P2GUiL209JFUP80VIVI0P2JVYX2
09jNWP80XZ:R0`2NWYh209fMW@80W9bL0P2PX:0609nOW`<0XZ:R0P2VYZH20:RXZ080XZ:R0P2VYZH2
0:BTY080YJFU0P2RXZ830:2PX080Y:BT0P2UYJD20::RXP80YZJV0P2OWil209jNWP<0VYZJ102CTi<2
08b<S080SXj>1025QHD508B4Q080P8201021PH4208B4Q080OGem0`24Q8@208:2PP80O7al0P1oOgl2
07alO080Ng]k0P1iNGT307]kN`80NGUi0P1lO7`207emO@P0b>3H00060<SPf0808b<S0P0^;Rh203dm
?@<0CTi>0P0e=CD202<S8`80820P0P0K6a/201hN7P8071`L0`0O7al202l_;`80Jf][0P2?Shl208J6
QP80Lg=c0P1`L70307AdM080MWIf0P2@T9020;no_`80cLg=0P3;bl/20<k>cP<0c<c<0P3>c/h20:>S
X`80>3Ph0P0U9BD202@T90809RHV0P0Y:BT302DU9@809RHV0P0W9bL2028R8P8092@T0P0U9BD204e=
C@<0IVIV0P1>CTh203Xj>P80@T920P17AdL204E5A@80Bd];0`1GEeL2065QH@80IfMW0P1/K6`4075a
L@80NGUi0`1nOWh20820P080NWYj0P1nOWh40820P080Ph>30`22PX8208N7Q`80R8R81029RHT208Z:
RPD0SXj>0P2?Shl209BDU080Ti>C0P2@T902096AT@80V9RH0`2KVi/209NGU`80UYJF0P2IVIT209ZJ
VP80WYjN0P2RXZ8309jNWP80WIfM0P2LW9`20:2PX0H0WinO0`2RXZ820:JVYP80Z:RX0P2RXZ820:JV
YP80Y:BT0P2UYJD20::RXP<0X:2P0P2TY:@20:FUY@80XZ:R0P2VYZH209nOW`80WYjN0`2JVYX409>C
T`80S8b<0P2>SXh408F5Q@D0Q8B40P20P8040861P@80Q8B40P1mOGd308B4Q080PX:20P1lO7`207mo
O`80O7al0P1kNg/207UiN@<0Ng]k0P1iNGT207alO080OGem2038h=P000H0b>3H0P0V9RH2038b<P80
C4a<0`1cLg<204e=C@809RHV0P0P8202024Q8@807QhN1@0M7Ad202DU9@80D51@0P23Ph<209FEU@80
NGUi0P1_Kfl307UiN@80MWIf0P1hN7P20:FUY@80alO70P38b<P20<k>cP<0clo?103>c/h208V9R@80
<C4a0P0U9BD202HV9P809BDU0`0W9bL2024Q8@808b<S0P0Y:BT202LW9`80:BTY0P19BDT305aLG080
B4Q80P0e=CD203`l?080ADE50P19BDT204e=C@<0FUYJ0P1RHV8206IVIP80K6a/0P1bLW8207AdM080
MGEe0`22PX8208>3P`80OGem0P1kNg/20820P080Ph>30P26QXH307inOP80Q8B40P27QhL208V9R@@0
RXZ:0P26QXH308V9R@80T92@0P2JVYX209:BTP80T92@102FUYH309^KV`80VIVI0P2GUiL60:6QX@80
Xj>S0`2PX:0209jNWP80WinO0P2PX:020::RXP80Xj>S0P2RXZ830:FUY@80Z:RX0P2UYJD20:>SX`80
Z:RX0P2YZJT20:RXZ080Y:BT0`2UYJD20:RXZ080XZ:R102VYZH209nOW`80X:2P0`2KVi/209JFUP80
TI6A0P2@T90208V9R@80RXZ:0P28R8P708>3P`80PX:21024Q8@50861P@80Ng]k0P1lO7`207emO@80
NGUi101hN7P307YjNP80Ng]k0P1lO7`207emO@P0b>3H00060<SPf0809RHV0P0b<S8204a<C0<0Lg=c
0P1=CDd202HV9P80820P0P0Q8B4201hN7PD07AdM0P0U9BD2051@D080Ph>30P2EUID207UiN@80Kfm_
0`1iNGT207IfMP80N7Qh0P2UYJD20<O7a`80b<S80P3>c/h30<o?c`@0c/k>0P29RHT2034a<@809BDU
0P0V9RH202DU9@<09bLW0P0Q8B4202<S8`80:BTY0P0W9bL202TY:@80BDU90`1LG5`204Q8B080=CDe
0P0l?3`204E5A@80BDU90P1=CDd305YJFP80HV9R0P1VIVH206a/K080LW9b0P1dM7@207EeM@<0PX:2
0P23Ph<207emO@80Ng]k0P20P80208>3P`80QXJ60`1nOWh208B4Q080QhN70P29RHT408Z:RP80QXJ6
0`29RHT2092@T080VYZJ0P2BTY82092@T0@0UYJF0`2KVi/209VIV@80UiNG1P2QXJ420:>SX`<0X:2P
0P2NWYh209nOW`80X:2P0P2RXZ820:>SX`80XZ:R0`2UYJD20:RXZ080YJFU0P2SXj<20:RXZ080ZJVY
0P2XZ:P20:BTY0<0YJFU0P2XZ:P20::RXP@0YZJV0P2OWil20:2PX0<0Vi^K0P2FUYH2096AT@80T92@
0P29RHT208Z:RP80R8R81`23Ph<208:2PP@0Q8B41@21PH4207]kN`80O7al0P1mOGd207UiN@@0N7Qh
0`1jNWX207]kN`80O7al0P1mOGd80<SPf0001P38h=P203<c<`80?Cdm0P1LG5`308F5Q@80MWIf0P16
ATH202@T90807QhN100K6a/301`L70808b<S0P0g=cL2071`L080X:2P0P2;Rh/206e]K@<0OWin0P1f
MWH207EeM@80TI6A0P2n_[h20<?3``D0b/[:0P3<c<`20<o?c`80`l?30P1TI6@202PX:0808B4Q0P0S
8b<302DU9@809RHV0P0Q8B4201lO7`809bLW0P0^;Rh204];B`<0EEEE0P14A4@203De=@80>SXj0P14
A4@204Y:BP80DE5A0`1FEUH206QXJ080JFUY0P1[Jf/2071`L080Kfm_0P1kNg/307inOP@0OGem0P21
PH4208>3P`80PH610P25QHD30861P@80Ogmo0P29RHT408^;R`80QhN70P28R8P308f=S@80TY:B0P2H
V9P2096AT@80UYJF0P2GUiL209VIV@<0VYZJ0P2FUYH209^KV`80XJ6Q0P2MWId20:>SX`80XZ:R0`2J
VYX409jNWP80XZ:R0P2TY:@20:^[Z`80ZZZZ0`2[Zj/20:ZZZP80Z:RX0P2WYjL20:VYZ@80Z:RX0P2Z
ZZX20:JVYP<0Z:RX0P2VYZH40:2PX080YJFU0P2QXJ4209jNWP<0Vi^K0P2EUID209RHV080TI6A0P2<
S8`208^;R`80RXZ:0`26QXH208F5Q@80P8200P23Ph<208J6QP80QhN70P25QHD308:2PP80OGem0P1n
OWh20820P080O7al0P1hN7P207YjNP<0Ng]k0P1lO7`207]kN`80OGem2038h=P000H0b>3H0P0c<c<2
03dm?@80G5aL0`25QHD207IfMP80ATI60P0T92@201hN7P@06a/K0`0L71`202<S8`80=cLg0P1`L702
0:2PX080Rh^;0P1]KFd307inOP80MWIf0P1eMGD2096AT@80_[jn0P33`l<50<[:bP80c<c<0P3?cll2
0<?3``80I6AT0P0X:2P2024Q8@808b<S0`0U9BD202HV9P808B4Q0P0O7al202LW9`80;Rh^0P1;Bd/3
05EEE@80A4A40P0e=CD203Xj>P80A4A40P1:BTX2055AD@<0EUIF0P1XJ6P206UYJ@80Jf][0P1`L702
06m_K`80Ng]k0`1nOWh407emO@80PH610P23Ph<20861P@80QHF50`21PH4207moO`80RHV9102;Rh/2
08N7Q`80R8R80`2=SHd209:BTP80V9RH0P2ATI4209JFUP80UiNG0P2IVIT309ZJVP80UYJF0P2KVi/2
0:6QX@80WIfM0P2SXj<20::RXP<0VYZJ102NWYh20::RXP80Y:BT0P2[Zj/20:ZZZP<0Zj^[0P2ZZZX2
0:RXZ080YjNW0P2YZJT20:RXZ080ZZZZ0P2VYZH30:RXZ080YZJV102PX:020:FUY@80XJ6Q0P2NWYh3
09^KV`80UIFE0P2HV9P2096AT@80S8b<0P2;Rh/208Z:RP<0QXJ60P25QHD20820P080Ph>30P26QXH2
08N7Q`80QHF50`22PX8207emO@80OWin0P20P80207alO080N7Qh0P1jNWX307]kN`80O7al0P1kNg/2
07emO@P0b>3H00060<SPf080=3@d0P1ADE4206IVIP<0R8R80P1gMgL205QHF08092@T0P0L71`201dM
7@806a/K0`0J6QX201hN7P809RHV0P1IFET209:BTP80WYjN0P1aLG4506m_K`80LG5a0P25QHD20:RX
Z080aLG50P39bLT30<c<c080bl_;0P3<c<`20<k>cP80]KFe0P16ATH202LW9`D08B4Q0P0S8b<202XZ
:P809BDU0P0S8b<202TY:@80AdM70`1FEUH203lo?`80>SXj0P0h>3P203`l?080ADE51@1EEED206UY
J@80IVIV0P1/K6`2071`L080MWIf0P1gMgL507emO@80QHF50P21PH4208:2PP80Q8B40P20P80508:2
PP80Q8B40P27QhL208V9R@80SHf=0P2;Rh/5092@T080Ti>C0P2EUID209fMW@80UiNG0P2LW9`309fM
W@80V9RH0P2PX:0209fMW@80XJ6Q0P2TY:@20::RXP<0XJ6Q0P2RXZ820:2PX080ZZZZ0P2WYjL20:ZZ
ZP80YZJV0`2SXj<20:^[Z`80[:b/0P2XZ:P20:ZZZP80Zj^[0P2YZJT20:NWY`<0ZJVY102UYJD20:6Q
X@80YJFU0P2QXJ4209VIV@<0Vi^K0P2HV9P209NGU`80TY:B0P2>SXh208V9R@80QXJ60`28R8P208B4
Q0H0Ph>30P27QhL208>3P`D0PH610P1mOGd208:2PP80OWin0P1kNg/207QhN0<0NWYj0P1nOWh207]k
N`80OWin2038h=P000H0b>3H0P0d=3@2055AD@80IVIV0`28R8P207MgM`80F5QH0P0T92@201`L7080
7AdM0P0K6a/301XJ6P807QhN0P0V9RH205UIF@80TY:B0P2NWYh2075aL@D0Kfm_0P1aLG4208F5Q@80
Z:RX0P35aLD20<W9b@<0c<c<0P3;bl/20<c<c080c/k>0P2e]KD204I6AP809bLW1@0Q8B4202<S8`80
:RXZ0P0U9BD202<S8`80:BTY0P17AdL305IFEP80?clo0P0j>SX203Ph>080?3`l0P15ADD505EEE@80
JFUY0P1VIVH206a/K080L71`0P1fMWH207MgM`D0OGem0P25QHD20861P@80PX:20P24Q8@20820P0D0
PX:20P24Q8@208N7Q`80RHV90P2=SHd208^;R`D0T92@0P2CTi<209FEU@80WIfM0P2GUiL209bLW0<0
WIfM0P2HV9P20:2PX080WIfM0P2QXJ420:BTY080XZ:R0`2QXJ420::RXP80X:2P0P2ZZZX20:NWY`80
ZZZZ0P2VYZH30:>SX`80Zj^[0P2/[:`20:RXZ080ZZZZ0P2[Zj/20:VYZ@80YjNW0`2YZJT40:FUY@80
XJ6Q0P2UYJD20:6QX@80VIVI0`2KVi/209RHV080UiNG0P2BTY8208j>SP80RHV90P26QXH308R8R080
Q8B41P23Ph<208N7Q`80Ph>31@21PH4207emO@80PX:20P1nOWh207]kN`80N7Qh0`1jNWX207inOP80
Ng]k0P1nOWh80<SPf0001P38h=P204=3@`80HV9R0P1nOWh309>CT`80Ogmo0P1PH60202HV9P807AdM
0P0O7al202@T90<07AdM0P0N7Qh202@T9080>c/k0P21PH4209bLW080Ogmo0`1eMGD206i^KP80L71`
0P1nOWh20:2PX080a/K60P37alL30<[:bP80c<c<0P3=cLd20<k>cP80c<c<0P2UYJD203lo?`809RHV
1`0S8b<4024Q8@80:b/[0P11@D4305MGE`80?3`l0P0g=cL203@d=080?3`l0P15ADD2051@D0<0Fe]K
0P1TI6@206EUI@80K6a/0P1`L70207AdM080MWIf0`1lO7`207UiN@@0PH610P20P80208>3P`80QHF5
0`26QXH208N7Q`80Ph>30P26QXH208V9R@80TI6A0P2?Shl309:BTP80SXj>102CTi<209NGU`80UIFE
0P2KVi/309bLW080WinO0P2JVYX209nOW`80Y:BT0P2RXZ820:2PX0<0Y:BT0P2PX:020:BTY080ZZZZ
0P2/[:`20:f][@80YZJV0`2SXj<20:^[Z`80[Jf]0P2/[:`40:RXZ080Zj^[0P2ZZZX30:VYZ@80ZZZZ
0P2WYjL40:FUY@80YZJV0P2NWYh509fMW@80UiNG0P2DU9@208R8R080QhN70P25QHD308B4Q080QXJ6
0P25QHD208N7Q`80QXJ60P28R8P208>3P`<0PX:21023Ph<20861P@80O7al0P1gMgL207QhN0<0OGem
0P1kNg/207inOP80Ph>32038h=P000H0b>3H0P13@d<2069RHP80OWin0`2CTi<207moO`80H61P0P0V
9RH201dM7@807alO0P0T92@301dM7@807QhN0P0T92@203/k>`80PH610P2LW9`207moO`<0MGEe0P1^
KVh2071`L080OWin0P2PX:020<K6aP80alO70`3:b/X20<c<c080cLg=0P3>c/h20<c<c080YJFU0P0o
?cl202HV9PL08b<S100Q8B4202/[:`80@D510`1GEeL203`l?080=cLg0P0d=3@203`l?080ADE50P1@
D50305]KF`80I6AT0P1UIFD206a/K080L71`0P1dM7@207IfMP<0O7al0P1iNGT40861P@80P8200P23
Ph<208F5Q@<0QXJ60P27QhL208>3P`80QXJ60P29RHT2096AT@80Shn?0`2BTY8208j>SP@0Ti>C0P2G
UiL209FEU@80Vi^K0`2LW9`209nOW`80VYZJ0P2OWil20:BTY080XZ:R0P2PX:030:BTY080X:2P0P2T
Y:@20:ZZZP80[:b/0P2][Jd20:JVYP<0Xj>S0P2[Zj/20:f][@80[:b/102XZ:P20:^[Z`80ZZZZ0`2Y
ZJT20:ZZZP80YjNW102UYJD20:JVYP80WYjN1@2MWId209NGU`80U9BD0P28R8P208N7Q`80QHF50`24
Q8@208J6QP80QHF50P27QhL208J6QP80R8R80P23Ph<308:2PP@0Ph>30P21PH4207alO080MgMg0P1h
N7P307emO@80Ng]k0P1nOWh208>3P`P0b>3H00060<SPf080De=C0P1dM7@209^KV`<0[Jf]0P2HV9P2
06UYJ@809RHV0P0N7Qh2020P808092@T0`0S8b<201lO7`80820P0P0V9RH205]KF`80S8b<0P2DU9@3
07alO080KVi^0P1[Jf/207AdM080T92@0P2f][H20<k>cP<0a/K60P3=cLd20<o?c`@0cLg=0P39bLT2
08^;R`80<C4a0`0R8R8402LW9`8092@T0P0[:b/202HV9P80A4A40`1EEED203Ph>080;bl_0P0e=CD2
03Ti>@80C4a<0P1FEUH305YJFP80IFEU0P1VIVH206m_K`80LG5a0P1cLg<207IfMP<0OWin0P1hN7P2
08>3P`80QHF50P20P80208>3P`L0QHF50P26QXH208N7Q`@0Rh^;0P2@T90309>CT`80Shn?0P2EUID8
09RHV0<0X:2P0P2MWId20:2PX080Y:BT0P2LW9`209fMW@80X:2P0`2SXj<20:RXZ080Y:BT0P2][Jd2
0;6a/@80ZJVY0P2ZZZX30:NWY`80[:b/0P2XZ:P20:j^[P80/;2`0P2[Zj/20:ZZZPD0[:b/0P2UYJD2
0:NWY`80X:2P0P2UYJD20:JVYP80WinO0`2NWYh209RHV080VIVI0P2DU9@2096AT@80RXZ:0P25QHD7
08J6QP80Q8B40P28R8P208J6QP80PX:20`25QHD40820P080Ogmo0P1kNg/207YjNP80N7Qh0`1kNg/2
07alO0@0PX:22038h=P000H0b>3H0P1CDe<207AdM080Vi^K0`2][Jd209RHV080JFUY0P0V9RH201hN
7P80820P0P0T92@302<S8`807alO0P0P820202HV9P80Fe]K0P2<S8`209BDU0<0O7al0P1^KVh206][
J`80M7Ad0P2@T9020;Jf]P80c/k>0`36a/H20<g=c@80clo?103=cLd20<W9b@80Rh^;0P0a<C43028R
8P@09bLW0P0T92@202/[:`809RHV0P14A4@305EEE@80>3Ph0P0_;bl203De=@80>CTi0P1<C4`205IF
EP<0FUYJ0P1UIFD206IVIP80Kfm_0P1aLG4207=cL`80MWIf0`1nOWh207QhN080Ph>30P25QHD20820
P080Ph>31`25QHD208J6QP80QhN7102;Rh/2092@T0<0Ti>C0P2?Shl209FEU@P0V9RH0`2PX:0209fM
W@80X:2P0P2TY:@209bLW080WIfM0P2PX:030:>SX`80Z:RX0P2TY:@20:f][@80/K6a0P2YZJT20:ZZ
ZP<0YjNW0P2/[:`20:RXZ080[Zj^0P2`/;020:^[Z`80ZZZZ1@2/[:`20:FUY@80YjNW0P2PX:020:FU
Y@80YZJV0P2OWil309jNWP80V9RH0P2IVIT209BDU080TI6A0P2:RXX208F5Q@L0QXJ60P24Q8@208R8
R080QXJ60P22PX8308F5Q@@0P8200P1oOgl207]kN`80NWYj0P1hN7P307]kN`80O7al1022PX880<SP
f0001P38h=P205mOG`80P8200P2f][H30:f][@80RXZ:0P1ADE4202TY:@@08b<S0P0X:2P302DU9@80
820P0P0X:2P202@T9080>c/k0P1jNWX209VIV@<0Ph>30P1]KFd406m_K`80PH610P2PX:020=7Ad@<0
alO70P39bLT20<_;b`80c<c<0P3=cLd20=7Ad@80`L710P1LG5`302LW9`80820P0P0V9RH202<S8`80
92@T0P0U9BD20410@0<0CTi>0P0i>CT2034a<@80>3Ph0P0o?cl204m?C`80E5AD0`1KFe/2069RHP80
IFEU0P1/K6`2071`L080Kfm_0P1hN7P307alO080OGem0P1nOWh208F5Q@80Ogmo0P27QhL208B4Q0<0
QXJ60P25QHD208B4Q080SHf=0P2?Shl208^;R`80S8b<0`2@T90209>CT`80V9RH0P2KVi/409VIV@80
W9bL0`2NWYh209^KV`80WYjN0P2LW9`20:BTY080XJ6Q0P2VYZH30:>SX`80ZZZZ0P2/[:`20;:b/P80
[Jf]102/[:`30:n_[`80[Zj^0P2[Zj/20:b/[080[Zj^0P2][Jd40:RXZ0<0Zj^[0P2VYZH40:NWY`80
XJ6Q0P2RXZ8209nOW`<0VIVI0P2EUID209NGU`80UIFE0P2ATI4208Z:RP80R8R80`26QXH208V9R@@0
Q8B41P27QhL308Z:RP80OWin0P1kNg/20820P080Ogmo0P20P80207UiN@<0Ng]k0P1mOGd20861P@80
QHF52038h=P000H0b>3H0P1OGel20820P080][Jf0`2][Jd208Z:RP80DE5A0P0Y:BT402<S8`80:2PX
0`0U9BD2020P8080:2PX0P0T92@203/k>`80NWYj0P2IVIT308>3P`80KFe]101_Kfl20861P@80X:2P
0P3AdM430<O7a`80bLW90P3;bl/20<c<c080cLg=0P3AdM420<71`@80G5aL0`0W9bL2020P80809RHV
0P0S8b<202@T90809BDU0P10@40304i>CP80>CTi0P0a<C4203Ph>080?clo0P1?Cdl205ADE0<0Fe]K
0P1RHV8206EUI@80K6a/0P1`L70206m_K`80N7Qh0`1lO7`207emO@80OWin0P25QHD207moO`80QhN7
0P24Q8@308J6QP80QHF50P24Q8@208f=S@80Shn?0P2;Rh/208b<S0<0T92@0P2CTi<209RHV080Vi^K
102IVIT209bLW0<0WYjN0P2KVi/209jNWP80W9bL0P2TY:@20:6QX@80YZJV0`2SXj<20:ZZZP80[:b/
0P2b/[820:f][@@0[:b/0`2_[jl20:j^[P80Zj^[0P2/[:`20:j^[P80[Jf]102XZ:P30:^[Z`80YZJV
102WYjL20:6QX@80XZ:R0P2OWil309VIV@80UIFE0P2GUiL209FEU@80TI6A0P2:RXX208R8R0<0QXJ6
0P29RHT408B4Q0H0QhN70`2:RXX207inOP80Ng]k0P20P80207moO`80P8200P1iNGT307]kN`80OGem
0P21PH4208F5Q@P0b>3H00060<SPf080NGUi0P2CTi<20;:b/P<0V9RH0P1^KVh2038b<P808B4Q0P0^
;Rh2028R8P809RHV1@0[:b/202PX:0809bLW0P0`<302061PH080T92@0`2EUID206e]K@80I6AT0P1`
L70207UiN@80QHF50P33`l<30<[:bP80aLG50P38b<P20<_;b`80c/k>0P3AdM420=CDe080YjNW0`0_
;bl2028R8P@09BDU0P0X:2P202l_;`80>CTi0`18B4P203Lg=`80=SHf0P0l?3`204M7A`80DE5A0P1C
De<305iNGP80IFEU0P1^KVh206e]K@80MgMg0P1dM7@207YjNP<0P8200P1nOWh408>3P`80OWin0P24
Q8@208:2PP<0QXJ60P27QhL208Z:RPH0SHf=0P2@T90309NGU`80U9BD0P2HV9P209JFUP80UiNG0P2H
V9P509bLW080Vi^K0P2MWId209bLW080YJFU0P2YZJT20:NWY`<0[Jf]102[Zj/20;Bd]080[jn_0P2]
[Jd20:n_[`<0/K6a0P2_[jl20;:b/P80[jn_0P2/[:`20:RXZ080YjNW1@2/[:`20:NWY`80ZJVY0P2W
YjL20:BTY080XJ6Q0P2RXZ8309jNWP80VYZJ0P2IVIT209>CT`80TI6A0P2:RXX208V9R@<0QHF50P28
R8P208J6QP80QHF50P27QhL208R8R080TI6A0`26QXH208>3P`80Ogmo1021PH4207YjNP80OGem1@1l
O7`208B4Q080RHV92038h=P000H0b>3H0P1iNGT209>CT`80/[:b0`2HV9P206i^KP80<S8b0P0Q8B42
02h^;P808R8R0P0V9RH502/[:`80:2PX0P0W9bL2030`<080H61P0P2@T90309FEU@80KFe]0P1TI6@2
071`L080NGUi0P25QHD20<?3``<0b/[:0P35aLD20<S8b080bl_;0P3>c/h20=7Ad@80e=CD0P2WYjL3
02l_;`808R8R100U9BD202PX:080;bl_0P0i>CT304Q8B080=cLg0P0f=SH203`l?080AdM70P1ADE42
05=CD`<0GUiN0P1UIFD206i^KP80KFe]0P1gMgL207AdM080NWYj0`20P80207inOP@0Ph>30P1nOWh2
08B4Q080PX:20`26QXH208N7Q`80RXZ:1P2=SHd2092@T0<0UiNG0P2DU9@209RHV080UYJF0P2GUiL2
09RHV0D0W9bL0P2KVi/209fMW@80W9bL0P2UYJD20:VYZ@80YjNW0`2][Jd40:^[Z`80];Bd0P2_[jl2
0:f][@80[jn_0`2a/K420:n_[`80/[:b0P2_[jl20:b/[080Z:RX0P2WYjL50:b/[080YjNW0P2YZJT2
0:NWY`80Y:BT0P2QXJ420::RXP<0WYjN0P2JVYX209VIV@80Ti>C0P2ATI4208Z:RP80RHV90`25QHD2
08R8R080QXJ60P25QHD208N7Q`80R8R80P2ATI4308J6QP80Ph>30P1oOgl40861P@80NWYj0P1mOGd5
07alO080Q8B40P29RHT80<SPf0001P38h=P20:BTY080VYZJ0P2DU9@3071`L080BDU90P0];Bd202HV
9P808B4Q0P0R8R8202DU9@<0:2PX0P0T92@202XZ:P80:b/[0P0Z:RX204e=C@80P8200`2GUiL207Ui
N@80I6AT0P1`L70207]kN`80OGem0P2][Jd30<c<c080_;bl0P34a<@20<S8b080c<c<0P3@d=020=GE
e@80b<S80`1eMGD203De=@80:BTY0P0R8R8202HV9P809bLW0P0o?cl304=3@`80<C4a0P0_;bl203Hf
=P80?Cdm0P17AdL2055AD@<0I6AT0P1XJ6P206a/K080L71`0P1gMgL407UiN@L0P8200P1oOgl208:2
PP80P8200P24Q8@308V9R@80S8b<0P2=SHd208^;R`80SHf=0P2CTi<209:BTP<0T92@0P2HV9P2096A
T@80VIVI0P2GUiL209RHV080VIVI0`2JVYX209jNWP80WinO0P2RXZ820:JVYP80ZJVY0P2UYJD30:f]
[@80Z:RX0P2[Zj/20;>c/`H0[Zj^0`2a/K420;2`/080/K6a0P2`/;020;:b/P80ZZZZ0P2XZ:P20:^[
Z`<0[Jf]1P2XZ:P20:BTY080Xj>S0P2OWil309fMW@80Vi^K0P2GUiL209RHV080UIFE0P2BTY82092@
T0<0Rh^;0P2<S8`208^;R`@0RHV9102;Rh/308J6QP80Q8B40P1nOWh20861P@80OWin0P1mOGd20861
P@<0O7al0P23Ph<20861P@80Q8B42038h=P000H0b>3H0P2TY:@209ZJVP80U9BD0`1`L70204U9B@80
;Bd]0P0V9RH2024Q8@808R8R0P0U9BD302PX:08092@T0P0Z:RX202/[:`80:RXZ0P1=CDd20820P0<0
UiNG0P1iNGT206ATI080L71`0P1kNg/207emO@80[Jf]0`3<c<`20;bl_080a<C40P38b<P20<c<c080
d=3@0P3EeMD20<S8b0<0MGEe0P0e=CD202TY:@808R8R0P0V9RH202LW9`80?clo0`13@d<2034a<@80
;bl_0P0f=SH203dm?@80AdM70P1ADE4306ATI080J6QX0P1/K6`2071`L080MgMg101iNGT70820P080
Ogmo0P22PX820820P080Q8B40`29RHT208b<S080SHf=0P2;Rh/208f=S@80Ti>C0P2BTY83092@T080
V9RH0P2ATI4209VIV@80UiNG0P2HV9P209VIV@<0VYZJ0P2NWYh209nOW`80XZ:R0P2VYZH20:VYZ@80
YJFU0`2][Jd20:RXZ080Zj^[0P2c/k<60:j^[P<0/K6a0P2`/;020;6a/@80/;2`0P2b/[820:ZZZP80
Z:RX0P2[Zj/30:f][@H0Z:RX0P2TY:@20:>SX`80WinO0`2MWId209^KV`80UiNG0P2HV9P209FEU@80
TY:B0P2@T90308^;R`80S8b<0P2;Rh/408V9R@@0Rh^;0`26QXH208B4Q080OWin0P21PH4207inOP80
OGem0P21PH4307alO080Ph>30P21PH4208B4Q0P0b>3H00060<SPf080Y:BT0P2JVYX209BDU0<0L71`
0P19BDT202d];@809RHV0P0Q8B42028R8P809BDU0`0X:2P202@T9080:RXZ0P0[:b/202XZ:P80CDe=
0P20P80309NGU`80NGUi0P1TI6@2071`L080Ng]k0P1mOGd20:f][@<0c<c<0P2l_;`20<C4a080b<S8
0P3<c<`20=3@d080eMGE0P38b<P307EeM@80=CDe0P0Y:BT2028R8P809RHV0P0W9bL203lo?`<0@d=3
0P0a<C4202l_;`80=SHf0P0m?Cd204M7A`80DE5A0`1TI6@206QXJ080K6a/0P1`L70207MgM`@0NGUi
1`20P80207moO`80PX:20P20P80208B4Q0<0RHV90P2<S8`208f=S@80Rh^;0P2=SHd209>CT`80TY:B
0`2@T90209RHV080TI6A0P2IVIT209NGU`80V9RH0P2IVIT309ZJVP80WYjN0P2OWil20::RXP80YZJV
0P2YZJT20:FUY@<0[Jf]0P2XZ:P20:^[Z`80/k>c1P2^[Zh30;6a/@80/;2`0P2a/K420;2`/080/[:b
0P2ZZZX20:RXZ080Zj^[0`2][Jd60:RXZ080Y:BT0P2SXj<209nOW`<0WIfM0P2KVi/209NGU`80V9RH
0P2EUID209:BTP80T92@0`2;Rh/208b<S080Rh^;1029RHT408^;R`<0QXJ60P24Q8@207inOP80PH61
0P1nOWh207emO@80PH610`1lO7`208>3P`80PH610P24Q8@80<SPf0001P38h=P20:b/[080UiNG0P1/
K6`304A4A080;2`/0P0X:2P202/[:`809RHV0P0Q8B4202HV9P<08R8R0P0S8b<2020P80@0:2PX0P0c
<c<2075aL@<0Shn?0P2>SXh206UYJ@80L71`0P1dM7@207MgM`80Shn?0`37alL20;bl_080_Kfm0P34
a<@20<O7a`80bl_;0P3?cll20=7Ad@<0/k>c0P14A4@202XZ:P808b<S0P0T92@202PX:080;bl_0`0n
?Sh202l_;`80=3@d0P0l?3`204=3@`80Cdm?0P1ADE4306=SH`80J6QX0P1/K6`2071`L0@0NWYj1`1k
Ng/207inOP80PH610P23Ph<208R8R0D0PX:20P26QXH208b<S080RXZ:0P2=SHd208n?S`80T92@0`2B
TY8209RHV080UIFE0P2JVYX209VIV@80Vi^K0P2FUYH309VIV@@0WIfM0P2PX:060:FUY@<0[Jf]0P2W
YjL20:j^[P80/K6a0P2`/;020:b/[080/K6a0`2e]KD20;6a/@80/[:b0P2_[jl20:f][@80Zj^[0P2Y
ZJT20:^[Z`<0ZZZZ0P2/[:`20:ZZZP@0YjNW0P2UYJD50:6QX@80WIfM0P2JVYX209:BTP@0Ti>C0P2?
Shl308b<S080R8R8102:RXX2092@T080R8R80P2?Shl308R8R080QHF50P23Ph<20820P080PX:20P1k
Ng/207emO@<0NGUi1022PX8208>3P`P0b>3H00060<SPf080[:b/0P2GUiL206a/K0<0A4A40P0/;2`2
02PX:080:b/[0P0V9RH2024Q8@809RHV0`0R8R8202<S8`80820P100X:2P203<c<`80LG5a0`2?Shl2
08j>SP80JFUY0P1`L70207AdM080MgMg0P2?Shl30<O7a`80_;bl0P2m_Kd20<C4a080alO70P3;bl/2
0<o?c`80dM7A0`2c/k<204A4A080:RXZ0P0S8b<202@T9080:2PX0P0_;bl303hn?P80;bl_0P0d=3@2
03`l?080@d=30P1?Cdl2055AD@<0Hf=S0P1XJ6P206a/K080L71`101jNWX707]kN`80OWin0P21PH42
08>3P`80R8R81@22PX8208J6QP80S8b<0P2:RXX208f=S@80Shn?0P2@T90309:BTP80V9RH0P2EUID2
09ZJVP80VIVI0P2KVi/209JFUP<0VIVI102MWId20:2PX0H0YJFU0`2][Jd20:NWY`80[Zj^0P2a/K42
0;2`/080[:b/0P2a/K430;Fe]@80/K6a0P2b/[820:n_[`80[Jf]0P2[Zj/20:VYZ@80Zj^[0`2ZZZX2
0:b/[080ZZZZ102WYjL20:FUY@D0XJ6Q0P2MWId209ZJVP80TY:B102CTi<208n?S`<0S8b<0P28R8P4
08Z:RP80T92@0P28R8P208n?S`<0R8R80P25QHD208>3P`80P8200P22PX8207]kN`80OGem0`1iNGT4
08:2PP80Ph>32038h=P000H0b>3H0P2@T90207YjNP80ADE50`0Z:RX2028R8P80:b/[0P0_;bl202TY
:@808R8R0P0Q8B43028R8P80:BTY0P0V9RH2028R8P8092@T0P0Z:RX205=CD`<0QHF50P2OWil207Qh
N080Lg=c0P1dM7@207MgM`80Ng]k0`2f][H20<G5a@80^;Rh0P2m_Kd20<C4a080aLG50P39bLT20=3@
d0<0c<c<0P2GUiL2038b<PH0:BTY0P0e=CD304=3@`80;2`/0P0`<30203`l?080?Cdm0P1;Bd/205EE
E@<0GemO0P1UIFD206i^KP80M7Ad0P1oOgl207UiN@80MWIf0`1hN7P207UiN@80Ogmo0P23Ph<208:2
PP80S8b<1@24Q8@208F5Q@@0RHV9102?Shl2096AT@<0SXj>0P2EUID209JFUP80V9RH0P2IVIT209bL
W080TY:B1@2KVi/209ZJVP80XZ:R0P2WYjL20:>SX`80YjNW0`2YZJT20:ZZZP80/[:b0P2_[jl20;>c
/`80[jn_0P2a/K430:n_[`80/K6a0P2h^;P20;6a/@@0[Zj^0P2YZJT20:^[Z`<0/;2`0P2^[Zh20:FU
Y@80YZJV0P2UYJD20:BTY080WYjN0`2MWId209^KV`80WinO102BTY8208b<S080SXj>0`2?Shl208V9
R@80Rh^;0P2<S8`2096AT@80Rh^;0P2:RXX508V9R@80Q8B40P21PH4207alO080MWIf0P24Q8@307mo
O`80P8200P23Ph<208R8R0P0b>3H00060<SPf080T92@0P1jNWX204E5A@<0:RXZ0P0R8R8202/[:`80
;bl_0P0Y:BT2028R8P808B4Q0`0R8R8202TY:@809RHV0P0R8R8202@T9080:RXZ0P1CDe<308F5Q@80
WinO0P1hN7P207=cL`80M7Ad0P1gMgL207]kN`<0][Jf0P35aLD20;Rh^080_Kfm0P34a<@20<G5a@80
bLW90P3@d=030<c<c080UiNG0P0b<S8602TY:@80=CDe0`13@d<202`/;080<30`0P0l?3`203dm?@80
Bd];0P1EEED305mOG`80IFEU0P1^KVh207AdM080Ogmo0P1iNGT207IfMP<0N7Qh0P1iNGT207moO`80
Ph>30P22PX8208b<S0D0Q8B40P25QHD408V9R@@0Shn?0P2ATI4308j>SP80UIFE0P2FUYH209RHV080
VIVI0P2LW9`209:BTPD0Vi^K0P2JVYX20::RXP80YjNW0P2SXj<20:NWY`<0ZJVY0P2ZZZX20;:b/P80
[jn_0P2c/k<20:n_[`80/K6a0`2_[jl20;6a/@80^;Rh0P2a/K440:j^[P80ZJVY0P2[Zj/30;2`/080
[Zj^0P2UYJD20:JVYP80YJFU0P2TY:@209jNWP<0WIfM0P2KVi/209nOW`@0TY:B0P2<S8`208j>SP<0
Shn?0P29RHT208^;R`80S8b<0P2ATI4208^;R`80RXZ:1@29RHT208B4Q080PH610P1lO7`207IfMP80
Q8B40`1oOgl20820P080Ph>30P28R8P80<SPf0001P38h=P207MgM`80F5QH0P0];Bd302DU9@808b<S
0P0P820202<S8`808R8R0P0U9BD202@T90<08b<S100R8R8201lO7`808B4Q0P0U9BD203Ti>@<0LW9b
0P2JVYX208^;R`80Lg=c0P1bLW82071`L080M7Ad0`2KVi/20<K6aP80^KVi0P2k^k/20;no_`80a<C4
0P33`l<20<G5a@<0c<c<0P32`/8206YZJP80<S8b0P0`<30202XZ:P80;Bd]0`0j>SX202d];@80=cLg
0P0d=3@203`l?080CDe=0P1IFET306EUI@80K6a/0P1aLG4207EeM@80NWYj0P1hN7P207IfMP<0N7Qh
0P1nOWh208>3P`80QXJ60P24Q8@208N7Q`80PX:21@25QHD208N7Q`80S8b<0P2@T90209BDU080TY:B
0`2>SXh209:BTP80TI6A0P2DU9@209FEU@80W9bL0P2MWId309^KV`H0XZ:R0P2XZ:P20:JVYP80[:b/
0`2_[jl20;2`/080/K6a0P2`/;020;Rh^080[Zj^0P2b/[830;Bd]080]KFe0P2g]kL20;2`/0H0[jn_
0P2[Zj/30;:b/P80[Jf]0P2YZJT20:RXZ080YZJV0P2WYjL50::RXP80X:2P0P2JVYX209JFUP80UIFE
0P2;Rh/208n?S`<0TI6A0P2<S8`208f=S@80U9BD0P2CTi<208j>SP80RXZ:0`2;Rh/208F5Q@80QXJ6
0P21PH4207moO`80OWin0P1mOGd308>3P`80P8200P26QXH208:2PPP0b>3H00060<SPf080MgMg0P1H
F5P202d];@<09BDU0P0S8b<2020P80808b<S0P0R8R8202DU9@8092@T0`0S8b<4028R8P807alO0P0Q
8B4202DU9@80>CTi0`1bLW8209ZJVP80Rh^;0P1cLg<2079bLP80L71`0P1dM7@309^KV`80a/K60P2i
^KT20;^k^`80_kno0P34a<@20<?3``80aLG50`3<c<`20<;2`P80JVYZ0P0b<S82030`<080:RXZ0P0]
;Bd303Xj>P80;Bd]0P0g=cL203@d=080?3`l0P1=CDd205UIF@<0IFEU0P1/K6`2075aL@80MGEe0P1j
NWX207QhN080MWIf0`1hN7P207inOP80Ph>30P26QXH208B4Q080QhN70P22PX8508F5Q@80QhN70P2<
S8`2092@T080U9BD0P2BTY8308j>SP80TY:B0P2ATI4209BDU080UIFE0P2LW9`209fMW@<0Vi^K1P2R
XZ820:RXZ080YZJV0P2/[:`30:n_[`80/;2`0P2a/K420;2`/080^;Rh0P2^[Zh20;:b/P<0];Bd0P2e
]KD20;Ng]`80/;2`1P2_[jl20:^[Z`<0/[:b0P2][Jd20:VYZ@80Z:RX0P2VYZH20:NWY`D0XZ:R0P2P
X:0209ZJVP80UYJF0P2EUID208^;R`80Shn?0`2ATI4208b<S080SHf=0P2DU9@209>CT`80SXj>0P2:
RXX308^;R`80QHF50P26QXH20861P@80Ogmo0P1nOWh207emO@<0Ph>30P20P80208J6QP80PX:22038
h=P000H0b>3H0P1IFET203hn?P809bLW0`0U9BD202@T90809bLW0P0/;2`202LW9`808b<S0P0R8R83
02HV9P80<S8b0P0U9BD4028R8P807alO0P0Y:BT305]KF`80RHV90P2DU9@207IfMP@0Kfm_0P1cLg<3
08B4Q080`<300P37alL20;^k^`80_Kfm0P36a/H40;fm_@<0`l?30P3>c/h20:b/[080>SXj0P0_;bl2
02/[:`80;Bd]0`0e=CD202h^;P80<S8b0P0f=SH20410@080Cdm?0P1IFET306EUI@80K6a/0P1bLW82
075aL@@0MGEe1@1kNg/208:2PP80Ph>30P1nOWh208:2PP80RHV90P25QHD308R8R080QXJ60P24Q8@2
08^;R`80Shn?0P2ATI42092@T0<0Ti>C102@T90209FEU@80UiNG0P2HV9P209fMW@<0XZ:R0P2WYjL2
0:VYZ@80YJFU0P2XZ:P20:^[Z`80[:b/0`2`/;020;:b/P80];Bd0P2f][H20;>c/`80/;2`0P2_[jl3
0;Bd]080]kNg0P2c/k<20:f][@80[jn_0P2^[Zh20:VYZ@80[jn_0`2`/;020:n_[`80Zj^[0P2][Jd2
0:VYZ@80XZ:R0P2SXj<309jNWP@0Vi^K0P2GUiL209JFUP80TI6A0P2?Shl309>CT`80T92@0P2=SHd2
09:BTP80U9BD0P2<S8`2096AT@D0R8R81026QXH207inOP80Ogmo0P1lO7`308:2PP80Q8B41025QHD8
0<SPf0001P38h=P205UIF@80?Shn0P0W9bL302DU9@8092@T0P0W9bL202`/;0809bLW0P0S8b<2028R
8P<09RHV0P0b<S8202DU9@@08R8R0P0O7al202TY:@<0Fe]K0P29RHT209BDU080MWIf101_Kfl207=c
L`<0Q8B40P30`<020<O7a`80^k^k0P2m_Kd20<K6aP@0_Kfm0`33`l<20<k>cP80[:b/0P0j>SX202l_
;`80:b/[0P0];Bd303De=@80;Rh^0P0b<S8203Hf=P80@4100P1?Cdl205UIF@<0IFEU0P1/K6`2079b
LP80LG5a101eMGD507]kN`80PX:20P23Ph<207inOP80PX:20P29RHT208F5Q@<0R8R80P26QXH208B4
Q080Rh^;0P2?Shl2096AT@80T92@0`2CTi<4092@T080UIFE0P2GUiL209RHV080WIfM0`2RXZ820:NW
Y`80ZJVY0P2UYJD20:RXZ080Zj^[0P2/[:`30;2`/080/[:b0P2d];@20;Jf]P80/k>c0P2`/;020:n_
[`<0];Bd0P2g]kL20;>c/`80[Jf]0P2_[jl20:j^[P80ZJVY0P2_[jl30;2`/080[jn_0P2[Zj/20:f]
[@80ZJVY0P2RXZ820:>SX`<0WYjN102KVi/209NGU`80UYJF0P2ATI4208n?S`<0Ti>C0P2@T90208f=
S@80TY:B0P2DU9@208b<S080TI6A1@28R8P408J6QP80OWin0P1oOgl207alO0<0PX:20P24Q8@408F5
Q@P0b>3H00060<SPf080@d=30P0a<C4203<c<`<0;2`/0P0X:2P202LW9`80:BTY0P0Z:RX202TY:@80
9BDU0`0X:2P2034a<@809BDU0P0Z:RX2020P80807AdM0P0R8R8303Xj>P80MWIf0P2DU9@209>CT`80
L71`0P1dM7@207QhN0<0MGEe0P2OWil20<c<c080_[jn0P2i^KT20<;2`P80`<300P2l_;`30;^k^`@0
b/[:0P2@T90203De=@808b<S0P0U9BD302`/;080:b/[0P0^;Rh203Lg=`80ADE50P1=CDd205UIF@<0
HF5Q0P1WIfL207EeM@80Lg=c0P1iNGT207EeM@80O7al0`1mOGd207inOP80Ph>30P22PX8207YjNP80
Q8B40P21PH4308J6QP80Q8B40P25QHD208V9R@80R8R80P2BTY8509JFUP80UIFE0P2CTi<209NGU`80
VYZJ102NWYh30:FUY@80YjNW0P2XZ:P20:ZZZP80[Jf]0P2/[:`20;:b/P<0[Jf]0P2a/K420;2`/080
/K6a102d];@20;Ng]`<0_[jn0P2i^KT20;Fe]@80[jn_0P2][Jd20:j^[P80Z:RX1@2[Zj/20:VYZ@80
Zj^[0P2XZ:P20:n_[`80Z:RX0P2QXJ4309nOW`80X:2P0P2JVYX209^KV`80W9bL0P2HV9P509>CT`80
UYJF0P2@T90209FEU@80TY:B0P2<S8`208f=S@<0S8b<0P2:RXX208B4Q080QXJ60P25QHD207]kN`80
P8200`21PH4208F5Q@80Q8B40P29RHT80<SPf0001P38h=P204=3@`80<C4a0P0c<c<302`/;080:2PX
0P0W9bL202TY:@80:RXZ0P0Y:BT202DU9@<0:2PX0P0a<C4202DU9@80:RXZ0P0P820201dM7@808R8R
0`0j>SX207IfMP80U9BD0P2CTi<2071`L080M7Ad0P1hN7P307EeM@80WinO0P3<c<`20;jn_P80^KVi
0P32`/820<30`080_;bl0`2k^k/40<[:bP80T92@0P0e=CD202<S8`809BDU0`0/;2`202/[:`80;Rh^
0P0g=cL204E5A@80CDe=0P1IFET3065QH@80IfMW0P1eMGD207=cL`80NGUi0P1eMGD207alO0<0OGem
0P1nOWh208>3P`80PX:20P1jNWX208B4Q080PH610`26QXH208B4Q080QHF50P29RHT208R8R080TY:B
1@2FUYH209FEU@80Ti>C0P2GUiL209ZJVP@0WYjN0`2UYJD20:NWY`80Z:RX0P2ZZZX20:f][@80[:b/
0P2b/[830:f][@80/K6a0P2`/;020;6a/@@0];Bd0P2g]kL30;jn_P80^KVi0P2e]KD20:n_[`80[Jf]
0P2^[Zh20:RXZ0D0Zj^[0P2YZJT20:^[Z`80Z:RX0P2_[jl20:RXZ080XJ6Q0`2OWil20:2PX080VYZJ
0P2KVi/209bLW080V9RH1@2CTi<209JFUP80T92@0P2EUID209:BTP80S8b<0P2=SHd308b<S080RXZ:
0P24Q8@208J6QP80QHF50P1kNg/20820P0<0PH610P25QHD208B4Q080RHV92038h=P000H0b>3H0P1D
E5@402l_;`<0>3Ph0P0c<c<203De=@8092@T0P0Z:RX202`/;080:RXZ0`0Y:BT2038b<P80:b/[0P0W
9bL202PX:0808R8R0P0T92@303<c<`80GemO0P2@T9020:BTY080Ph>30P1cLg<207MgM`<0LW9b0P26
QXH20;no_`80c<c<0P2a/K420;jn_P80`L710P2o_kl30;Zj^P80`L710P3AdM420<71`@80HV9R0P0X
:2P202LW9`<0:2PX0P0/;2`2030`<080=3@d0P14A4@204Q8B080EEEE0`1OGel206QXJ0@0M7Ad101i
NGT207QhN0<0O7al1020P80207moO`80NGUi0P20P80208>3P`<0QXJ60P2:RXX208b<S080SXj>0P2=
SHd209:BTPL0V9RH0P2GUiL209^KV`80V9RH0P2LW9`20:2PX0<0XJ6Q0P2VYZH40:f][@80/;2`102^
[Zh30;>c/`80]KFe0P2c/k<20:j^[P80][Jf0P2c/k<50;Zj^P80][Jf0P2d];@20:f][@80/k>c102[
Zj/20:b/[0<0/;2`0P2][Jd20:b/[080Z:RX0P2`/;020:JVYP80Y:BT0`2UYJD209fMW@@0WinO0P2H
V9P209JFUP80Ti>C0`2DU9@209FEU@80TI6A0P2DU9@409FEU@80S8b<0`2>SXh208b<S080RXZ:0P25
QHD208N7Q`80PH610P1nOWh30861P@80Ph>30P24Q8@208>3P`P0b>3H00060<SPf080E5AD100_;bl3
03Ph>080<c<c0P0e=CD202@T9080:RXZ0P0/;2`202XZ:P<0:BTY0P0b<S8202/[:`809bLW0P0X:2P2
028R8P8092@T0`0c<c<205mOG`80T92@0P2TY:@208>3P`80Lg=c0P1gMgL3079bLP80QXJ60P2o_kl2
0<c<c080/K6a0P2n_[h20<71`@80_kno0`2j^[X20<71`@80dM7A0P31`L42069RHP80:2PX0P0W9bL3
02PX:080;2`/0P0`<30203@d=080A4A40P18B4P205EEE@<0GemO0P1XJ6P407AdM0@0NGUi0P1hN7P3
07alO0@0P8200P1oOgl207UiN@80P8200P23Ph<308J6QP80RXZ:0P2<S8`208j>SP80SHf=0P2BTY87
09RHV080UiNG0P2KVi/209RHV080W9bL0P2PX:030:6QX@80YZJV102][Jd20;2`/0@0[Zj^0`2c/k<2
0;Fe]@80/k>c0P2^[Zh20;Jf]P80/k>c1@2j^[X20;Jf]P80];Bd0P2][Jd20;>c/`@0Zj^[0P2/[:`3
0;2`/080[Jf]0P2/[:`20:RXZ080/;2`0P2VYZH20:BTY0<0YJFU0P2MWId409nOW`80V9RH0P2FUYH2
09>CT`<0U9BD0P2EUID2096AT@80U9BD102EUID208b<S0<0SXj>0P2<S8`208Z:RP80QHF50P27QhL2
0861P@80OWin0`21PH4208>3P`80Q8B40P23Ph<80<SPf0001P38h=P205mOG`80=cLg0P0`<30302/[
:`808b<S0P0Y:BT202/[:`80;bl_0P0/;2`202LW9`<09RHV0P0b<S8203<c<`80<30`0P0V9RH2024Q
8@80:RXZ0`0/;2`203`l?080N7Qh0P2GUiL209BDU080MWIf0P1]KFd307emO@80MWIf0P2TY:@20<g=
c@80/k>c0P2f][H20;no_`80^k^k0`2l_;`20;fm_@80b/[:0P3AdM420:n_[`80@T920P0Y:BT302LW
9`80;Bd]0P0i>CT203Hf=P80=cLg0P17AdL205MGE`<0HF5Q0P1YJFT206e]K@80MGEe0P1hN7P207Yj
NP80N7Qh0`1lO7`207YjNP80Ng]k101jNWX408>3P`<0QXJ60P2:RXX208n?S`80TI6A0P2?Shl2096A
T@D0V9RH0P2IVIT209RHV080WIfM0P2LW9`209jNWP80XZ:R0`2VYZH20:RXZ080[jn_102^[Zh20:f]
[@D0/K6a0P2d];@20;>c/`@0];Bd0P2b/[820;Bd]0<0/[:b0P2`/;020:n_[`80[:b/0P2f][H20:f]
[@80[jn_0P2`/;030;>c/`80[Zj^0P2`/;020:ZZZP80[:b/0P2^[Zh20:NWY`<0YZJV0P2RXZ8209nO
W`80WIfM0P2JVYX209RHV080TY:B1@2IVIT209:BTP80TI6A0P2EUID209BDU080Shn?1@2<S8`208Z:
RP80Q8B40P29RHT208>3P`80PH610`1lO7`20861P@80Q8B40P22PX880<SPf0001P38h=P205mOG`80
=cLg0P0`<30302/[:`808b<S0P0Y:BT202/[:`80;bl_0P0/;2`202LW9`<09RHV0P0b<S8203<c<`80
<30`0P0V9RH2024Q8@80:RXZ0`0/;2`203`l?080N7Qh0P2GUiL209BDU080MWIf0P1]KFd307emO@80
MWIf0P2TY:@20<g=c@80/k>c0P2f][H20;no_`80^k^k0`2l_;`20;fm_@80b/[:0P3AdM420:n_[`80
@T920P0Y:BT302LW9`80;Bd]0P0i>CT203Hf=P80=cLg0P17AdL205MGE`<0HF5Q0P1YJFT206e]K@80
MGEe0P1hN7P207YjNP80N7Qh0`1lO7`207YjNP80Ng]k101jNWX408>3P`<0QXJ60P2:RXX208n?S`80
TI6A0P2?Shl2096AT@D0V9RH0P2IVIT209RHV080WIfM0P2LW9`209jNWP80XZ:R0`2VYZH20:RXZ080
[jn_102^[Zh20:f][@D0/K6a0P2d];@20;>c/`@0];Bd0P2b/[820;Bd]0<0/[:b0P2`/;020:n_[`80
[:b/0P2f][H20:f][@80[jn_0P2`/;030;>c/`80[Zj^0P2`/;020:ZZZP80[:b/0P2^[Zh20:NWY`<0
YZJV0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080TY:B1@2IVIT209:BTP80TI6A0P2EUID209BDU080
Shn?1@2<S8`208Z:RP80Q8B40P29RHT208>3P`80PH610`1lO7`20861P@80Q8B40P22PX880<SPf000
1P38h=P205mOG`80=cLg0P0`<30302/[:`808b<S0P0Y:BT202/[:`80;bl_0P0/;2`202LW9`<09RHV
0P0b<S8203<c<`80<30`0P0V9RH2024Q8@80:RXZ0`0/;2`203`l?080N7Qh0P2GUiL209BDU080MWIf
0P1]KFd307emO@80MWIf0P2TY:@20<g=c@80/k>c0P2f][H20;no_`80^k^k0`2l_;`20;fm_@80b/[:
0P3AdM420:n_[`80@T920P0Y:BT302LW9`80;Bd]0P0i>CT203Hf=P80=cLg0P17AdL205MGE`<0HF5Q
0P1YJFT206e]K@80MGEe0P1hN7P207YjNP80N7Qh0`1lO7`207YjNP80Ng]k101jNWX408>3P`<0QXJ6
0P2:RXX208n?S`80TI6A0P2?Shl2096AT@D0V9RH0P2IVIT209RHV080WIfM0P2LW9`209jNWP80XZ:R
0`2VYZH20:RXZ080[jn_102^[Zh20:f][@D0/K6a0P2d];@20;>c/`@0];Bd0P2b/[820;Bd]0<0/[:b
0P2`/;020:n_[`80[:b/0P2f][H20:f][@80[jn_0P2`/;030;>c/`80[Zj^0P2`/;020:ZZZP80[:b/
0P2^[Zh20:NWY`<0YZJV0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080TY:B1@2IVIT209:BTP80TI6A
0P2EUID209BDU080Shn?1@2<S8`208Z:RP80Q8B40P29RHT208>3P`80PH610`1lO7`20861P@80Q8B4
0P22PX880<SPf0001P38h=P2051@D080>SXj1@0^;Rh202HV9P80<S8b0P0Z:RX2030`<080<S8b0P0Z
:RX302d];@80;Rh^0P0_;bl202TY:@809bLW0P0V9RH202PX:0<0:RXZ0P0b<S8205aLG080R8R80P2K
Vi/207moO`80JFUY1@1iNGT208>3P`80/[:b0P2h^;P20:b/[080^k^k0P2m_Kd30<30`080_[jn0P38
b<P20=7Ad@80cLg=0P2HV9P203De=@<092@T0P0V9RH202l_;`80<S8b0P0k>c/20451@@80E5AD0`1Q
HF4206EUI@80KVi^0P1bLW8207YjNP80MgMg0P1kNg/507alO080Ogmo0P1mOGd207alO080QXJ60P21
PH4308N7Q`80RHV90P2;Rh/208n?S`80Ti>C0P2>SXh209FEU@<0UYJF102KVi/409bLW080YJFU0P2T
Y:@30:NWY`80Z:RX0P2/[:`20:ZZZP@0[:b/0P2a/K430;>c/`@0];Bd102c/k<20;2`/080[Jf]0`2`
/;060:j^[P80/k>c0P2`/;040:f][@<0/[:b0P2c/k<20;6a/@80Zj^[0P2ZZZX20:VYZ@80YJFU0`2R
XZ820:6QX@80WYjN1P2KVi/209ZJVP<0T92@0P2BTY82096AT@80T92@0P2>SXh209:BTPD0Rh^;0P28
R8P408B4Q080P8200P21PH4208B4Q0D0Ogmo0P20P80208:2PPP0b>3H00060<SPf080D51@0P0j>SX5
02h^;P809RHV0P0b<S8202XZ:P80<30`0P0b<S8202XZ:P<0;Bd]0P0^;Rh202l_;`80:BTY0P0W9bL2
02HV9P80:2PX0`0Z:RX2038b<P80G5aL0P28R8P209^KV`80Ogmo0P1YJFT507UiN@80Ph>30P2b/[82
0;Rh^080[:b/0P2k^k/20;fm_@<0`<300P2n_[h20<S8b080dM7A0P3=cLd209RHV080=CDe0`0T92@2
02HV9P80;bl_0P0b<S8203/k>`80@D510P1DE5@3065QH@80IFEU0P1^KVh2079bLP80NWYj0P1gMgL2
07]kN`D0O7al0P1oOgl207emO@80O7al0P26QXH20861P@<0QhN70P29RHT208^;R`80Shn?0P2CTi<2
08j>SP80UIFE0`2FUYH409^KV`@0W9bL0P2UYJD20:BTY0<0YjNW0P2XZ:P20:b/[080ZZZZ102/[:`2
0;6a/@<0/k>c102d];@40;>c/`80/;2`0P2][Jd30;2`/0H0[Zj^0P2c/k<20;2`/0@0[Jf]0`2b/[82
0;>c/`80/K6a0P2[Zj/20:ZZZP80ZJVY0P2UYJD30::RXP80XJ6Q0P2NWYh609^KV`80VYZJ0`2@T902
09:BTP80TI6A0P2@T90208j>SP80TY:B1@2;Rh/208R8R0@0Q8B40P20P8020861P@80Q8B41@1oOgl2
0820P080PX:22038h=P000H0b>3H0P0g=cL203Ph>080:BTY0`0^;Rh202l_;`80<S8b0P0^;Rh202d]
;@80:b/[0P0/;2`302d];@80;bl_0P0Z:RX202l_;`80<c<c100Y:BT302XZ:P80<30`0P0j>SX206a/
K080U9BD0P2GUiL507=cL`80N7Qh0P1eMGD2092@T080_;bl0P2XZ:P20;Jf]PD0`L711033`l<20<g=
c@80d];B0P39bLT207alO0<0;Bd]0P0Q8B4202PX:080;Bd]0P0h>3P204M7A`80EEEE0`1PH602069R
HP80K6a/0P1_Kfl207MgM`80O7al0P1kNg/307YjNP80OWin1020P80207moO`80QhN70P21PH4308Z:
RP80R8R80P2>SXh409BDU080TI6A0P2CTi<509NGU`H0WIfM102UYJD50:NWY`80ZZZZ0P2^[Zh20:f]
[@80[:b/0P2`/;030;6a/@80/k>c0P2`/;020;Fe]@80[jn_0P2`/;020;Bd]0<0/[:b0P2g]kL20;Bd
]0@0[Zj^0P2_[jl20;Bd]080/k>c0`2`/;020;>c/`@0/[:b0P2][Jd20:ZZZP80Z:RX0`2VYZH40:6Q
X@80VYZJ0P2MWId209VIV@80VYZJ0`2@T90409:BTP80U9BD0P2@T90209BDU080RXZ:0`2=SHd208Z:
RP80PH610P25QHD208N7Q`80QHF50P23Ph<508:2PP80Ng]k0P1oOgl80<SPf0001P38h=P203Lg=`80
>3Ph0P0Y:BT302h^;P80;bl_0P0b<S8202h^;P80;Bd]0P0[:b/202`/;0<0;Bd]0P0_;bl202XZ:P80
;bl_0P0c<c<402TY:@<0:RXZ0P0`<30203Xj>P80K6a/0P2DU9@209NGU`D0Lg=c0P1hN7P207EeM@80
T92@0P2l_;`20:RXZ080][Jf1@31`L440<?3``80cLg=0P3Bd]820<W9b@80O7al0`0];Bd2024Q8@80
:2PX0P0];Bd203Ph>080AdM70P1EEED3061PH080HV9R0P1/K6`206m_K`80MgMg0P1lO7`207]kN`<0
NWYj0P1nOWh40820P080Ogmo0P27QhL20861P@<0RXZ:0P28R8P208j>SP@0U9BD0P2ATI4209>CT`D0
UiNG1P2MWId40:FUY@D0YjNW0P2ZZZX20:j^[P80[Jf]0P2/[:`20;2`/0<0/K6a0P2c/k<20;2`/080
]KFe0P2_[jl20;2`/080];Bd0`2b/[820;Ng]`80];Bd102^[Zh20:n_[`80];Bd0P2c/k<30;2`/080
/k>c102b/[820:f][@80ZZZZ0P2XZ:P30:JVYP@0XJ6Q0P2JVYX209fMW@80VIVI0P2JVYX3092@T0@0
TY:B0P2DU9@2092@T080U9BD0P2:RXX308f=S@80RXZ:0P21PH4208F5Q@80QhN70P25QHD208>3P`D0
PX:20P1kNg/207moO`P0b>3H00060<SPf080?Shn0P0e=CD202l_;`<0;Bd]1P0^;Rh202l_;`80;Bd]
0P0^;Rh3030`<080;Rh^0P0];Bd202h^;P80;bl_0P0a<C42030`<0<0:b/[0P0/;2`203Hf=P80De=C
0P29RHT20:ZZZP80P8200`1cLg<2079bLP80M7Ad0P1mOGd40;Fe]@80/k>c0P2l_;`30<30`0@0`l?3
0P36a/H40<o?c`80_Kfm0`1HF5P202TY:@8092@T0P0^;Rh203@d=080A4A40P1=CDd305MGE`80GemO
0P1YJFT206m_K`80MgMg0P1eMGD207MgM`<0NGUi0P1lO7`207emO@80OWin0P26QXH208:2PP80Ph>3
0`2=SHd208V9R@80SHf=0P2DU9@209>CT`80UiNG0P2HV9P309NGU`80V9RH0P2JVYX209jNWP80XJ6Q
0P2RXZ820:>SX`<0YjNW0P2YZJT20:^[Z`80[Zj^0P2][Jd20:^[Z`80[Zj^0`2c/k<20;:b/P80];Bd
0P2`/;020:b/[080ZZZZ0P2d];@30;>c/`80/;2`102a/K420;:b/P80/K6a0P2`/;020:f][@<0[Zj^
0P2b/[820:n_[`80/[:b0P2_[jl20:f][@80ZZZZ0`2YZJT20:NWY`80Y:BT0P2KVi/209bLW080U9BD
0P2CTi<509BDU080V9RH0P2EUID208j>SP80TY:B0P2:RXX308f=S@80QXJ60P22PX8208R8R080QXJ6
0P24Q8@207moO`<0Q8B40P23Ph<208:2PP80QHF52038h=P000H0b>3H0P0n?Sh203De=@80;bl_0`0]
;Bd602h^;P80;bl_0P0];Bd202h^;P<0<30`0P0^;Rh202d];@80;Rh^0P0_;bl2034a<@80<30`0`0[
:b/202`/;080=SHf0P1CDe<208V9R@80ZZZZ0P20P80307=cL`80LW9b0P1dM7@207emO@@0]KFe0P2c
/k<20;bl_0<0`<301033`l<20<K6aP@0clo?0P2m_Kd305QHF080:BTY0P0T92@202h^;P80=3@d0P14
A4@204e=C@<0EeMG0P1OGel206UYJ@80Kfm_0P1gMgL207EeM@80MgMg0`1iNGT207alO080OGem0P1n
OWh208J6QP80PX:20P23Ph<308f=S@80RHV90P2=SHd209BDU080Ti>C0P2GUiL209RHV0<0UiNG0P2H
V9P209ZJVP80WYjN0P2QXJ420::RXP80Xj>S0`2WYjL20:VYZ@80Zj^[0P2^[Zh20:f][@80Zj^[0P2^
[Zh30;>c/`80/[:b0P2d];@20;2`/080[:b/0P2ZZZX20;Bd]0<0/k>c0P2`/;040;6a/@80/[:b0P2a
/K420;2`/080[Jf]0`2^[Zh20;:b/P80[jn_0P2b/[820:n_[`80[Jf]0P2ZZZX30:VYZ@80YjNW0P2T
Y:@209^KV`80W9bL0P2DU9@209>CT`D0U9BD0P2HV9P209FEU@80SXj>0P2BTY8208Z:RP<0SHf=0P26
QXH208:2PP80R8R80P26QXH208B4Q080Ogmo0`24Q8@208>3P`80PX:20P25QHD80<SPf0001P38h=P2
04Y:BP80<30`0P0];Bd303<c<`80=CDe0P0d=3@202l_;`80>SXj100];Bd302`/;0@0<30`0P0];Bd2
02/[:`80<30`1`0Y:BT202HV9P80<C4a0P1_Kfl209jNWP80U9BD0`1`L70206IVIP80Kfm_0P1fMWH2
0:JVYP80`<300P2[Zj/20;Bd]0<0_Kfm0P2l_;`20<C4a080`/;20P39bLT20=3@d080c<c<0`2XZ:P2
03dm?@80:RXZ0P0X:2P203Hf=P80@D510P1;Bd/305ADE080FUYJ0P1VIVH2075aL@80MGEe0P1dM7@2
07EeM@<0NWYj0P1mOGd207inOP80P8200P1nOWh20861P@80QXJ60`2:RXX208b<S080SHf=0P2BTY82
092@T080U9BD1@2HV9P209FEU@@0WYjN0P2RXZ8209nOW`80Y:BT0`2WYjL20:j^[P80[:b/0P2][Jd2
0:VYZ@80[Jf]0P2_[jl30;Jf]P80]KFe0P2^[Zh20:RXZ080ZZZZ0P2[Zj/50;:b/P80/K6a0P2_[jl2
0;Jf]P80/k>c0P2a/K440;2`/0<0[Jf]0P2^[Zh20:n_[`80/K6a102`/;020:VYZ@<0ZZZZ0P2TY:@2
0:>SX`80WinO0P2JVYX209>CT`80TI6A1@2EUID209BDU080TI6A0P2CTi<2092@T0D0S8b<1P25QHD2
08J6QP80QhN70P1mOGd30861P@80Ph>30P22PX8208F5Q@P0b>3H00060<SPf080BTY:0P0`<30202d]
;@<0<c<c0P0e=CD203@d=080;bl_0P0j>SX402d];@<0;2`/100`<30202d];@80:b/[0P0`<30702TY
:@809RHV0P0a<C4206m_K`80WYjN0P2DU9@3071`L080IVIV0P1_Kfl207IfMP80YZJV0P30`<020:^[
Z`80];Bd0`2m_Kd20;bl_080a<C40P32`/820<W9b@80d=3@0P3<c<`30:RXZ080?Cdm0P0Z:RX202PX
:080=SHf0P11@D4204];B`<0E5AD0P1JFUX206IVIP80LG5a0P1eMGD207AdM080MGEe0`1jNWX207em
O@80OWin0P20P80207inOP80PH610P26QXH308Z:RP80S8b<0P2=SHd209:BTP80T92@0P2DU9@509RH
V080UIFE102NWYh20::RXP80WinO0P2TY:@30:NWY`80[Zj^0P2/[:`20:f][@80ZJVY0P2][Jd20:n_
[`<0][Jf0P2e]KD20:j^[P80Z:RX0P2ZZZX20:^[Z`D0/[:b0P2a/K420:n_[`80][Jf0P2c/k<20;6a
/@@0/;2`0`2][Jd20:j^[P80[jn_0P2a/K440;2`/080ZJVY0`2ZZZX20:BTY080Xj>S0P2OWil209ZJ
VP80Ti>C0P2ATI4509FEU@80U9BD0P2ATI4209>CT`80T92@1@2<S8`608F5Q@80QXJ60P27QhL207em
O@<0PH610P23Ph<208:2PP80QHF52038h=P000H0b>3H0P1CDe<202l_;`809bLW0`0^;Rh2038b<P80
=SHf0P0];Bd202`/;080<C4a0P0`<30302/[:`80<30`0P0e=CD2030`<080:b/[0P0Z:RX202`/;0<0
:BTY0P0W9bL202PX:080;Bd]0P1DE5@209>CT`80XZ:R0`1mOGd206IVIP80IfMW0P1`L70208R8R080
^k^k0P2d];@20:j^[P<0^KVi0P2l_;`20<;2`P80_kno0P32`/820<_;b`80c/k>0`38b<P2092@T080
=3@d0P0`<30203<c<`80?clo0P1<C4`305=CD`@0GemO0P1_Kfl2079bLP80MGEe0P1iNGT307QhN080
NWYj0P1kNg/208>3P`80Ogmo0P23Ph<208B4Q0<0R8R80P2:RXX208^;R`80T92@0P2BTY8209NGU`80
VIVI0`2EUID209ZJVP80WIfM102PX:020::RXP80YjNW1@2XZ:P20:j^[P@0YjNW0P2a/K420:b/[0<0
];Bd0P2`/;020:f][@80Z:RX0P2a/K440;Jf]PD0/K6a0P2`/;020:n_[`80[:b/0P2[Zj/20:FUY@80
ZJVY0`2^[Zh20;:b/P80[Zj^0P2b/[820:^[Z`80[Zj^0P2ZZZX30:RXZ080Xj>S0P2PX:0209ZJVP80
V9RH102FUYH3092@T0@0SXj>0P2@T902096AT@80Shn?0P2<S8`308^;R`80QXJ60P21PH4207inOP@0
QhN70P1lO7`307moO`@0P8200P24Q8@80<SPf0001P38h=P205=CD`80;bl_0P0W9bL302h^;P80<S8b
0P0f=SH202d];@80;2`/0P0a<C42030`<0<0:b/[0P0`<30203De=@80<30`0P0[:b/202XZ:P80;2`/
0`0Y:BT202LW9`80:2PX0P0];Bd205ADE080Ti>C0P2RXZ8307emO@80IVIV0P1WIfL2071`L080R8R8
0P2k^k/20;Bd]080[Zj^0`2i^KT20;bl_080`/;20P2o_kl20<;2`P80bl_;0P3>c/h30<S8b080T92@
0P0d=3@2030`<080<c<c0P0o?cl204a<C0<0De=C101OGel206m_K`80LW9b0P1eMGD207UiN@<0N7Qh
0P1jNWX207]kN`80Ph>30P1oOgl208>3P`80Q8B40`28R8P208Z:RP80Rh^;0P2@T90209:BTP80UiNG
0P2IVIT309FEU@80VYZJ0P2MWId40:2PX080XZ:R0P2WYjL50:RXZ080[Zj^102WYjL20;6a/@80[:b/
0`2d];@20;2`/080[Jf]0P2XZ:P20;6a/@@0][Jf1@2a/K420;2`/080[jn_0P2/[:`20:^[Z`80YJFU
0P2YZJT30:j^[P80/[:b0P2^[Zh20;:b/P80Zj^[0P2^[Zh20:ZZZP<0Z:RX0P2SXj<20:2PX080VYZJ
0P2HV9P409JFUP<0T92@102>SXh2092@T080TI6A0P2?Shl208b<S0<0Rh^;0P26QXH20861P@80OWin
1027QhL207alO0<0Ogmo1020P80208B4Q0P0b>3H00060<SPf080@T920P0W9bL202DU9@<0:2PX0P0d
=3@203<c<`80=3@d0P0Y:BT202HV9P80;bl_0`0[:b/202XZ:P80:BTY0P0_;bl402d];@80;Rh^0`0[
:b/202TY:@80:2PX0P0];Bd20492@P80MgMg0P2LW9`309RHV080KVi^0P1QHF4206YZJP80MWIf0P2T
Y:@20;jn_P80YjNW0`2a/K420;bl_080_kno0P2k^k/20;fm_@80a/K60P3<c<`30<g=c@80`L710P1j
NWX203Hf=P80=3@d0P0m?Cd204M7A`<0Bd];0P1FEUH206MWI`80KFe]0P1bLW82071`L080MGEe0`1h
N7P207alO080Ng]k0P23Ph<20861P@80P8200P24Q8@308N7Q`80S8b<0P2@T90208n?S`80U9BD0P2H
V9P209bLW0<0UYJF0P2KVi/209fMW@80WinO0P2PX:020:FUY@80Y:BT1@2XZ:P20:b/[080YjNW102]
[Jd20:b/[0<0/;2`0P2][Jd20:j^[P80[Jf]0P2`/;040;:b/P<0[Jf]0P2_[jl20:b/[080ZZZZ0P2/
[:`20:f][@80Z:RX0P2TY:@30:f][@@0/K6a0P2b/[820:j^[P80/[:b0P2/[:`30:NWY`80XZ:R102K
Vi/209RHV080UIFE0P2CTi<3092@T080RXZ:0P2>SXh208f=S@80U9BD0P2?Shl208^;R`<0R8R80P24
Q8@208N7Q`80PH610P22PX8208N7Q`80O7al0`20P80207YjNP80Ogmo0P23Ph<80<SPf0001P38h=P2
0492@P809bLW0P0U9BD302PX:080=3@d0P0c<c<203@d=080:BTY0P0V9RH202l_;`<0:b/[0P0Z:RX2
02TY:@80;bl_100];Bd202h^;P<0:b/[0P0Y:BT202PX:080;Bd]0P12@T8207MgM`80W9bL0`2HV9P2
06i^KP80HF5Q0P1ZJVX207IfMP80Y:BT0P2n_[h20:NWY`<0/K6a0P2l_;`20;no_`80^k^k0P2m_Kd2
0<K6aP80c<c<0`3=cLd20<71`@80NWYj0P0f=SH203@d=080?Cdm0P17AdL304];B`80EUIF0P1WIfL2
06e]K@80LW9b0P1`L70207EeM@<0N7Qh0P1lO7`207]kN`80Ph>30P21PH420820P080Q8B40`27QhL2
08b<S080T92@0P2?Shl209BDU080V9RH0P2LW9`309JFUP80Vi^K0P2MWId209nOW`80X:2P0P2UYJD2
0:BTY0D0Z:RX0P2/[:`20:NWY`@0[Jf]0P2/[:`30;2`/080[Jf]0P2^[Zh20:f][@80/;2`102b/[83
0:f][@80[jn_0P2/[:`20:ZZZP80[:b/0P2][Jd20:RXZ080Y:BT0`2][Jd40;6a/@80/[:b0P2^[Zh2
0;:b/P80[:b/0`2WYjL20::RXP@0Vi^K0P2HV9P209FEU@80Ti>C0`2@T90208Z:RP80SXj>0P2=SHd2
09BDU080Shn?0P2;Rh/308R8R080Q8B40P27QhL20861P@80PX:20P27QhL207alO0<0P8200P1jNWX2
07moO`80Ph>32038h=P000H0b>3H0P0_;bl202`/;0D0;Bd]0P0f=SH203<c<`@0;Rh^0P0/;2`202d]
;@<0:2PX0P0`<302034a<@80;2`/0P0d=3@2034a<@80=cLg0`0/;2`202/[:`80<S8b0P0/;2`202TY
:@80DU9B0P2;Rh/30:FUY@80OWin0P1YJFT206MWI`80L71`0P2<S8`20<30`080/[:b0`2[Zj/20;Fe
]@80_;bl0P2n_[h20;fm_@80`/;20P36a/H50<W9b@80^k^k0P1IFET203Hf=P80=cLg0P15ADD3055A
D@80DU9B0P1QHF4206][J`80L71`0P1aLG4206m_K`<0NGUi0P1nOWh207YjNP80Q8B41022PX8208Z:
RPD0Rh^;102=SHd209:BTP80UiNG0P2MWId309ZJVP80XJ6Q0P2KVi/409nOW`80XZ:R1@2YZJT20:BT
Y0@0YJFU0P2ZZZX20:f][@80ZJVY0`2a/K440:f][@80[:b/0P2[Zj/20:f][@80Zj^[0`2/[:`20:f]
[@80Zj^[0P2ZZZX20:b/[080[Jf]0P2XZ:P20:VYZ@<0Z:RX102YZJT40;2`/080[Jf]0P2XZ:P30:b/
[080X:2P0P2LW9`409ZJVP80UIFE0P2DU9@308f=S@80R8R8102>SXh209JFUP80RHV90P2;Rh/308V9
R@80P8200P23Ph<208:2PP@0PH610P1jNWX308J6QP80NWYj0P1nOWh208N7Q`P0b>3H00060<SPf080
;bl_0P0/;2`502d];@80=SHf0P0c<c<402h^;P80;2`/0P0];Bd302PX:080<30`0P0a<C4202`/;080
=3@d0P0a<C4203Lg=`<0;2`/0P0[:b/2038b<P80;2`/0P0Y:BT2059BDP80Rh^;0`2UYJD207inOP80
JFUY0P1WIfL2071`L080S8b<0P30`<020;:b/P<0Zj^[0P2e]KD20;bl_080_[jn0P2m_Kd20<;2`P80
a/K61@39bLT20;^k^`80FEUI0P0f=SH203Lg=`80ADE50`1ADE42059BDP80HF5Q0P1[Jf/2071`L080
LG5a0P1_Kfl307UiN@80OWin0P1jNWX208B4Q0@0PX:20P2:RXX508^;R`@0SHf=0P2BTY8209NGU`80
WIfM0`2JVYX20:6QX@80Vi^K102OWil20::RXPD0ZJVY0P2TY:@40:FUY@80ZZZZ0P2][Jd20:VYZ@<0
/K6a102][Jd20:b/[080Zj^[0P2][Jd20:^[Z`<0[:b/0P2][Jd20:^[Z`80ZZZZ0P2/[:`20:f][@80
Z:RX0P2YZJT30:RXZ0@0ZJVY102`/;020:f][@80Z:RX0`2/[:`20:2PX080W9bL102JVYX209FEU@80
U9BD0`2=SHd208R8R0@0SXj>0P2FUYH208V9R@80Rh^;0`29RHT20820P080Ph>30P22PX840861P@80
NWYj0`26QXH207YjNP80OWin0P27QhL80<SPf0001P38h=P202l_;`80;2`/1@0];Bd203Hf=P80<c<c
100^;Rh202`/;080;Bd]0`0X:2P2030`<080<C4a0P0/;2`203@d=080<C4a0P0g=cL302`/;080:b/[
0P0b<S8202`/;080:BTY0P1BDU8208^;R`<0YJFU0P1nOWh206UYJ@80IfMW0P1`L70208b<S080`<30
0P2b/[830:^[Z`80]KFe0P2l_;`20;jn_P80_Kfm0P32`/820<K6aPD0bLW90P2k^k/205UIF@80=SHf
0P0g=cL204E5A@<0DE5A0P1BDU82065QH@80Jf][0P1`L702075aL@80Kfm_0`1iNGT207inOP80NWYj
0P24Q8@408:2PP80RXZ:1@2;Rh/408f=S@80TY:B0P2GUiL209fMW@<0VYZJ0P2QXJ4209^KV`@0WinO
0P2RXZ850:VYZ@80Y:BT102UYJD20:ZZZP80[Jf]0P2YZJT30;6a/@@0[Jf]0P2/[:`20:^[Z`80[Jf]
0P2[Zj/30:b/[080[Jf]0P2[Zj/20:ZZZP80[:b/0P2][Jd20:RXZ080ZJVY0`2XZ:P40:VYZ@@0/;2`
0P2][Jd20:RXZ0<0[:b/0P2PX:0209bLW0@0VYZJ0P2EUID209BDU0<0SHf=0P28R8P408j>SP80UYJF
0P29RHT208^;R`<0RHV90P20P80208>3P`80PX:21021PH4207YjNP<0QXJ60P1jNWX207inOP80QhN7
2038h=P000H0b>3H0P0a<C4203@d=080<C4a0`0c<c<203Lg=`80=SHf0P0^;Rh202/[:`80<30`0P0/
;2`302PX:080;bl_0P0b<S8202l_;`80=CDe0P0c<c<202d];@<0;Rh^100a<C4402LW9`80>SXj0P1_
Kfl309JFUP80Vi^K0P1dM7@206a/K080JFUY0P22PX820:b/[080_[jn0`2PX:020;>c/`80^;Rh0P2o
_kl20<30`080_[jn0P34a<@30<?3``80alO70P3<c<`20;2`/080C4a<0P0i>CT204=3@`<0Bd];0P1G
EeL205mOG`80I6AT101`L70207IfMP<0O7al0P1jNWX207UiN@H0Ogmo0P2<S8`508^;R`80RXZ:102C
Ti<209JFUP80V9RH0`2GUiL209jNWP80WIfM102OWil20:NWY`80ZZZZ0`2YZJT20:6QX@80Xj>S0P2R
XZ820:ZZZP80[:b/0P2^[Zh30;Bd]080[:b/0P2[Zj/20:VYZ@80Xj>S0P2VYZH20:FUY@<0Z:RX0P2V
YZH20:VYZ@80[:b/102^[Zh20:f][@80[:b/1@2XZ:P20:ZZZP80YZJV0P2XZ:P20:b/[080Z:RX0`2Z
ZZX20:>SX`80XZ:R0P2PX:0209VIV@80U9BD0P2>SXh308Z:RP80R8R81P2=SHd208Z:RP80QHF50`23
Ph<208N7Q`80PX:20P21PH4208>3P`80Q8B40P1oOgl308F5Q@80P8200P1oOgl208V9R@P0b>3H0006
0<SPf080<C4a0P0d=3@2034a<@<0<c<c0P0g=cL203Hf=P80;Rh^0P0[:b/2030`<080;2`/0`0X:2P2
02l_;`80<S8b0P0_;bl203De=@80<c<c0P0];Bd302h^;P@0<C4a100W9bL203Xj>P80Kfm_0`2FUYH2
09^KV`80M7Ad0P1/K6`206UYJ@80PX:20P2/[:`20;jn_P<0X:2P0P2c/k<20;Rh^080_kno0P30`<02
0;jn_P80a<C40`33`l<20<O7a`80c<c<0P2`/;0204a<C080>CTi0P13@d<304];B`80EeMG0P1OGel2
06ATI0@0L71`0P1fMWH307alO080NWYj0P1iNGT607moO`80S8b<1@2;Rh/208Z:RP@0Ti>C0P2FUYH2
09RHV0<0UiNG0P2NWYh209fMW@@0WinO0P2WYjL20:ZZZP<0ZJVY0P2QXJ420:>SX`80XZ:R0P2ZZZX2
0:b/[080[Zj^0`2d];@20:b/[080Zj^[0P2YZJT20:>SX`80YZJV0P2UYJD30:RXZ080YZJV0P2YZJT2
0:b/[0@0[Zj^0P2][Jd20:b/[0D0Z:RX0P2ZZZX20:JVYP80Z:RX0P2/[:`20:RXZ0<0ZZZZ0P2SXj<2
0::RXP80X:2P0P2IVIT209BDU080SXj>0`2:RXX208R8R0H0SHf=0P2:RXX208F5Q@<0Ph>30P27QhL2
08:2PP80PH610P23Ph<208B4Q080Ogmo0`25QHD20820P080Ogmo0P29RHT80<SPf0001P38h=P203<c
<`@0<30`0`0c<c<203@d=080<C4a0P0V9RH402/[:`80;2`/0`0X:2P202`/;080<C4a0P0e=CD2034a
<@80=SHf0P0e=CD3038b<P80=3@d0P0e=CD202XZ:P80;Rh^0P0/;2`2051@D0<0PX:20P2SXj<207mo
O`80IfMW0P1UIFD206i^KP80SXj>0P2i^KT30:>SX`80/K6a0P2f][H20;bl_080^k^k0P2m_Kd20<30
`0<0`/;20P38b<P40<c<c080Y:BT0P10@40203lo?`<0AdM70P1ADE4205aLG080GemO0P1/K6`2071`
L080M7Ad0`1hN7P207]kN`80O7al0P23Ph<207emO@80QXJ60P2=SHd308V9R@80S8b<0P2>SXh209FE
U@80UYJF1`2HV9P209fMW@80WinO0P2PX:0209jNWP80Z:RX0P2YZJT30:NWY`80Xj>S0P2UYJD20::R
XP80ZZZZ102/[:`30;:b/P80Zj^[0P2YZJT20:RXZ080Xj>S0P2VYZH20:ZZZP<0Y:BT0P2WYjL20:RX
Z080[Zj^0P2a/K420;2`/080[Zj^0P2/[:`30:FUY@80ZJVY1P2VYZH40:NWY`<0YZJV0P2QXJ420:JV
YP80Vi^K0P2OWil209FEU@80SHf=0`28R8P208V9R@80Rh^;0P2>SXh209:BTP80T92@0P2:RXX308J6
QP80QhN70P25QHD208B4Q080QXJ60P1oOgl208:2PPD0PH610P24Q8@208R8R0P0b>3H00060<SPf080
<c<c100`<30303<c<`80=3@d0P0a<C4202HV9P@0:b/[0P0/;2`302PX:080;2`/0P0a<C4203De=@80
<C4a0P0f=SH203De=@<0<S8b0P0d=3@203De=@80:RXZ0P0^;Rh202`/;080D51@0`22PX820:>SX`80
Ogmo0P1WIfL206EUI@80KVi^0P2>SXh20;Vi^@<0Xj>S0P2a/K420;Jf]P80_;bl0P2k^k/20;fm_@80
`<300`32`/820<S8b0@0c<c<0P2TY:@20410@080?clo0`17AdL2055AD@80G5aL0P1OGel206a/K080
L71`0P1dM7@307QhN080Ng]k0P1lO7`208>3P`80OGem0P26QXH208f=S@<0RHV90P2<S8`208j>SP80
UIFE0P2FUYH709RHV080WIfM0P2OWil20:2PX080WYjN0P2XZ:P20:VYZ@<0YjNW0P2SXj<20:FUY@80
XZ:R0P2ZZZX40:b/[0<0/[:b0P2[Zj/20:VYZ@80Z:RX0P2SXj<20:JVYP80ZZZZ0`2TY:@20:NWY`80
Z:RX0P2^[Zh20;6a/@80/;2`0P2^[Zh20:b/[0<0YJFU0P2YZJT60:JVYP@0YjNW0`2VYZH20:6QX@80
YZJV0P2KVi/209nOW`80UIFE0P2=SHd308R8R080RHV90P2;Rh/208j>SP80TY:B0P2@T90208Z:RP<0
QXJ60P27QhL208F5Q@80Q8B40P26QXH207moO`80PX:21@21PH4208B4Q080R8R82038h=P000H0b>3H
0P0b<S8202/[:`80;bl_0`0b<S82030`<080;2`/0P0`<30202h^;P809bLW0P0`<30302h^;P80<C4a
0P0b<S8203lo?`T0<30`0P0c<c<202/[:`@0:RXZ0P0/;2`203Ph>0<0Jf][0P2BTY8209FEU@80Kfm_
0P1RHV8206ATI080MGEe0P2RXZ830;Fe]@80ZZZZ0P2b/[820;Fe]@80^[Zj102m_Kd30<K6aP80bLW9
0P3?cll20<k>cP80alO70P2:RXX50410@080CDe=0P1IFET2065QH@80JVYZ101aLG4307EeM@80MWIf
0P1gMgL207emO@80QHF50P26QXH208V9R@<0QHF50P2:RXX208f=S@80UiNG0P2DU9@209NGU`80UYJF
0`2LW9`20:6QX@80V9RH0P2QXJ420::RXP80Y:BT0P2WYjL30:BTY080YZJV0P2PX:020:BTY080YjNW
0P2ZZZX20:f][@<0[:b/102VYZH20:2PX080YJFU0P2WYjL20:FUY@<0Z:RX0P2SXj<20:NWY`80ZJVY
0P2[Zj/20:f][@@0ZJVY0`2a/K420:j^[P80ZJVY0P2TY:@20:JVYP80[:b/0P2`/;030:BTY080YZJV
0P2^[Zh20:FUY@80WYjN0P2CTi<208b<S0<0SXj>1028R8P2092@T080Shn?0P2>SXh208^;R`<0QXJ6
0P29RHT208J6QP@0PH610P23Ph<20861P@<0PX:20P20P80207moO`80Rh^;2038h=P000H0b>3H0P0b
<S8202/[:`80;bl_0`0b<S82030`<080;2`/0P0`<30202h^;P809bLW0P0`<30302h^;P80<C4a0P0b
<S8203lo?`T0<30`0P0c<c<202/[:`@0:RXZ0P0/;2`203Ph>0<0Jf][0P2BTY8209FEU@80Kfm_0P1R
HV8206ATI080MGEe0P2RXZ830;Fe]@80ZZZZ0P2b/[820;Fe]@80^[Zj102m_Kd30<K6aP80bLW90P3?
cll20<k>cP80alO70P2:RXX50410@080CDe=0P1IFET2065QH@80JVYZ101aLG4307EeM@80MWIf0P1g
MgL207emO@80QHF50P26QXH208V9R@<0QHF50P2:RXX208f=S@80UiNG0P2DU9@209NGU`80UYJF0`2L
W9`20:6QX@80V9RH0P2QXJ420::RXP80Y:BT0P2WYjL30:BTY080YZJV0P2PX:020:BTY080YjNW0P2Z
ZZX20:f][@<0[:b/102VYZH20:2PX080YJFU0P2WYjL20:FUY@<0Z:RX0P2SXj<20:NWY`80ZJVY0P2[
Zj/20:f][@@0ZJVY0`2a/K420:j^[P80ZJVY0P2TY:@20:JVYP80[:b/0P2`/;030:BTY080YZJV0P2^
[Zh20:FUY@80WYjN0P2CTi<208b<S0<0SXj>1028R8P2092@T080Shn?0P2>SXh208^;R`<0QXJ60P29
RHT208J6QP@0PH610P23Ph<20861P@<0PX:20P20P80207moO`80Rh^;2038h=P000H0b>3H100/;2`2
02d];@<0;bl_0P0];Bd202LW9`80;2`/0P0a<C4202PX:080:b/[0`0Y:BT2030`<080=SHf0P0g=cL2
02d];@80<c<c0P0b<S83034a<@@0<30`0P0V9RH202LW9`80:2PX0P0];Bd304M7A`80PX:20P2NWYh2
08B4Q080JFUY0P1UIFD206][J`80QhN70`2d];@20:f][@80/K6a0P2d];@20;Jf]P@0^k^k1@33`l<2
0<[:bP80clo?0P3=cLd20<71`@80PH610`0o?cl204E5A@80E5AD0P1PH60206IVIP80LG5a0P1`L703
06m_K`80LW9b0P1hN7P207moO`80QhN70P26QXH208N7Q`<0Ph>30P2>SXh208b<S080UYJF0P2DU9@2
09NGU`L0W9bL0P2KVi/209nOW`80Y:BT102QXJ430::RXP80Y:BT0P2NWYh20:JVYP@0XJ6Q0P2SXj<3
09nOW`80VYZJ0P2OWil209^KV`@0XZ:R0P2MWId309jNWP80WinO0P2VYZH20:BTY080Zj^[0P2ZZZX2
0:>SX`80YZJV0`2a/K420:b/[080[Zj^0P2UYJD20::RXP@0[:b/0`2PX:020::RXP80ZZZZ102TY:@2
09FEU@80S8b<0`2=SHd408F5Q@80R8R80P2:RXX208n?S`80SXj>1@28R8P408:2PP80OWin0P24Q8@5
07moO`80P8200P1mOGd208b<S0P0b>3H00060<SPf0@0;2`/0P0];Bd302l_;`80;Bd]0P0W9bL202`/
;080<C4a0P0X:2P202/[:`<0:BTY0P0`<30203Hf=P80=cLg0P0];Bd203<c<`80<S8b0`0a<C44030`
<0809RHV0P0W9bL202PX:080;Bd]0`17AdL208:2PP80WYjN0P24Q8@206UYJ@80IFEU0P1[Jf/208N7
Q`<0];Bd0P2][Jd20;6a/@80];Bd0P2f][H40;^k^`D0`l?30P3:b/X20<o?c`80cLg=0P31`L420861
P@<0?clo0P15ADD205ADE080H61P0P1VIVH2075aL@80L71`0`1_Kfl2079bLP80N7Qh0P1oOgl208N7
Q`80QXJ60P27QhL308>3P`80SXj>0P2<S8`209JFUP80U9BD0P2GUiL709bLW080Vi^K0P2OWil20:BT
Y0@0XJ6Q0`2RXZ820:BTY080WYjN0P2VYZH40:6QX@80Xj>S0`2OWil209ZJVP80WinO0P2KVi/40::R
XP80WIfM0`2NWYh209nOW`80YZJV0P2TY:@20:^[Z`80ZZZZ0P2SXj<20:JVYP<0/K6a0P2/[:`20:j^
[P80YJFU0P2RXZ840:b/[0<0X:2P0P2RXZ820:ZZZP@0Y:BT0P2EUID208b<S0<0SHf=1025QHD208R8
R080RXZ:0P2?Shl208j>SPD0R8R81022PX8207inOP80Q8B41@1oOgl20820P080OGem0P2<S8`80<SP
f0001P38h=P2030`<080;Bd]0P0Y:BT302`/;0@0;Rh^0P0];Bd202`/;080:b/[0P0_;bl302TY:@80
=3@d0P0e=CD402l_;`80<S8b0P0Z:RX302l_;`80<S8b0P0Y:BT202DU9@808B4Q0P0U9BD202<S8`<0
<30`0P1VIVH208n?S`80WinO0P1lO7`206ATI080J6QX0P1kNg/30:BTY080^k^k0P2/[:`20;Jf]P80
/K6a0P2c/k<20;Ng]`<0^[Zj0P30`<020<K6aP80bl_;0P3<c<`20<k>cP80^k^k0`1`L70203`l?080
CTi>0P1EEED205iNGP80IFEU0P1^KVh3071`L080MWIf0P1hN7P207UiN@80PX:21027QhL308J6QP80
SHf=0P2>SXh209RHV080UYJF0P2IVIT209NGU`<0VYZJ102GUiL209ZJVP80Vi^K0P2PX:020:>SX`<0
WYjN0P2SXj<209nOW`80X:2P0P2LW9`409ZJVP<0UiNG0P2DU9@409JFUP80V9RH0P2KVi/209JFUP<0
VIVI0P2NWYh209^KV`@0W9bL0P2UYJD20:2PX080XZ:R0`2TY:@20:FUY@80YjNW0P2ZZZX20:FUY@80
YjNW0P2UYJD30::RXP80WinO0P2VYZH20:>SX`80YjNW0P2LW9`208j>SP<0Rh^;0P22PX8207moO`80
Q8B40P26QXH208^;R`80S8b<0`27QhL208V9R@80P8200P1nOWh20820P080Q8B41@22PX8208>3P`80
QhN70P2=SHd80<SPf0001P38h=P2030`<080;Bd]0P0Y:BT302`/;0@0;Rh^0P0];Bd202`/;080:b/[
0P0_;bl302TY:@80=3@d0P0e=CD402l_;`80<S8b0P0Z:RX302l_;`80<S8b0P0Y:BT202DU9@808B4Q
0P0U9BD202<S8`<0<30`0P1VIVH208n?S`80WinO0P1lO7`206ATI080J6QX0P1kNg/30:BTY080^k^k
0P2/[:`20;Jf]P80/K6a0P2c/k<20;Ng]`<0^[Zj0P30`<020<K6aP80bl_;0P3<c<`20<k>cP80^k^k
0`1`L70203`l?080CTi>0P1EEED205iNGP80IFEU0P1^KVh3071`L080MWIf0P1hN7P207UiN@80PX:2
1027QhL308J6QP80SHf=0P2>SXh209RHV080UYJF0P2IVIT209NGU`<0VYZJ102GUiL209ZJVP80Vi^K
0P2PX:020:>SX`<0WYjN0P2SXj<209nOW`80X:2P0P2LW9`409ZJVP<0UiNG0P2DU9@409JFUP80V9RH
0P2KVi/209JFUP<0VIVI0P2NWYh209^KV`@0W9bL0P2UYJD20:2PX080XZ:R0`2TY:@20:FUY@80YjNW
0P2ZZZX20:FUY@80YjNW0P2UYJD30::RXP80WinO0P2VYZH20:>SX`80YjNW0P2LW9`208j>SP<0Rh^;
0P22PX8207moO`80Q8B40P26QXH208^;R`80S8b<0`27QhL208V9R@80P8200P1nOWh20820P080Q8B4
1@22PX8208>3P`80QhN70P2=SHd80<SPf0001P38h=P202/[:`80;bl_0P0/;2`302l_;`80<S8b0P0a
<C4203<c<`80;2`/0P0W9bL202h^;P<0<C4a0P0h>3P203Hf=P80<c<c0P0`<30202l_;`D0;Bd]0P0/
;2`202LW9`808b<S0P0T92@202DU9@808b<S0`0T92@203lo?`80NGUi0P2LW9`208n?S`80Lg=c0P1[
Jf/206m_K`<0UYJF0P31`L420;:b/P80Zj^[0P2VYZH20:ZZZP80/K6a0`2e]KD20;bl_080_kno0P38
b<P20<c<c080clo?0P3<c<`30;Jf]P80H61P0P17AdL2055AD@80G5aL0P1OGel206MWI`<0KVi^0P1b
LW8207]kN`80NWYj0P1lO7`208>3P`80Rh^;0`28R8P2092@T080TY:B0P2DU9@209VIV@@0VYZJ0`2H
V9P209NGU`80Ti>C0P2FUYH209jNWP80U9BD1@2KVi/209nOW`80VYZJ0P2MWId209ZJVP80UIFE0P2G
UiL3096AT@80SXj>0P2BTY82096AT@80Ti>C0P2?Shl5092@T080Ti>C102BTY8209RHV080UYJF0P2L
W9`209fMW@<0X:2P0P2QXJ440:RXZ080YjNW0P2SXj<50:BTY080W9bL0P2QXJ420:>SX`80YjNW0P2P
X:0209:BTP<0QXJ60P23Ph<208F5Q@@0Q8B40P26QXH208Z:RP<0Rh^;0P27QhL208B4Q080Ogmo0P21
PH4207alO080Ph>30`1lO7`20861P@80Q8B40P2>SXh80<SPf0001P38h=P202/[:`80;bl_0P0/;2`3
02l_;`80<S8b0P0a<C4203<c<`80;2`/0P0W9bL202h^;P<0<C4a0P0h>3P203Hf=P80<c<c0P0`<302
02l_;`D0;Bd]0P0/;2`202LW9`808b<S0P0T92@202DU9@808b<S0`0T92@203lo?`80NGUi0P2LW9`2
08n?S`80Lg=c0P1[Jf/206m_K`<0UYJF0P31`L420;:b/P80Zj^[0P2VYZH20:ZZZP80/K6a0`2e]KD2
0;bl_080_kno0P38b<P20<c<c080clo?0P3<c<`30;Jf]P80H61P0P17AdL2055AD@80G5aL0P1OGel2
06MWI`<0KVi^0P1bLW8207]kN`80NWYj0P1lO7`208>3P`80Rh^;0`28R8P2092@T080TY:B0P2DU9@2
09VIV@@0VYZJ0`2HV9P209NGU`80Ti>C0P2FUYH209jNWP80U9BD1@2KVi/209nOW`80VYZJ0P2MWId2
09ZJVP80UIFE0P2GUiL3096AT@80SXj>0P2BTY82096AT@80Ti>C0P2?Shl5092@T080Ti>C102BTY82
09RHV080UYJF0P2LW9`209fMW@<0X:2P0P2QXJ440:RXZ080YjNW0P2SXj<50:BTY080W9bL0P2QXJ42
0:>SX`80YjNW0P2PX:0209:BTP<0QXJ60P23Ph<208F5Q@@0Q8B40P26QXH208Z:RP<0Rh^;0P27QhL2
08B4Q080Ogmo0P21PH4207alO080Ph>30`1lO7`20861P@80Q8B40P2>SXh80<SPf0001P38h=P202LW
9`80:b/[0P0d=3@302h^;P80;Bd]0P0[:b/202h^;P80;bl_0P0`<30202d];@<0;Rh^0P0f=SH202`/
;080;Rh^0P0_;bl202/[:`80;bl_0`0Z:RX2030`<0809bLW0P0X:2P202/[:`809RHV0P0Q8B43028R
8P80:2PX0P1PH60208F5Q@80XJ6Q0P22PX8206][J`80IfMW0`1nOWh20:VYZ@80`<300P2XZ:P20:6Q
X@80Zj^[0P2b/[830;Jf]P80]kNg0P2e]KD20<71`@80alO70P39bLT50<[:bP80ZJVY0P1OGel204Y:
BP80EUIF0P1MGEd206=SH`<0KFe]101eMGD207emO@80Ogmo0P23Ph<208Z:RP<0R8R80P2=SHd209>C
T`@0U9BD0P2EUID209^KV`<0VIVI102JVYX209JFUP80V9RH0P2FUYH209BDU0<0UiNG0P2IVIT209FE
U@80U9BD0P2CTi<2092@T080UIFE0`2@T90208^;R`80U9BD0P2BTY8208n?S`80T92@0P2=SHd308j>
SP80T92@0P2>SXh208n?S`80SXj>0P2FUYH209NGU`80UYJF0`2GUiL209ZJVP80Vi^K0P2MWId20:6Q
X@80Xj>S0P2UYJD30:BTY080VYZJ0P2MWId20:6QX@80Xj>S0P2QXJ4209RHV0<0Rh^;1P21PH4208R8
R080Q8B40P2:RXX308R8R080QXJ60P27QhL20861P@80Ph>30P1nOWh208:2PP<0Ogmo0P22PX8208>3
P`80S8b<2038h=P000H0b>3H0P0W9bL202/[:`80=3@d0`0^;Rh202d];@80:b/[0P0^;Rh202l_;`80
<30`0P0];Bd302h^;P80=SHf0P0/;2`202h^;P80;bl_0P0[:b/202l_;`<0:RXZ0P0`<30202LW9`80
:2PX0P0[:b/202HV9P808B4Q0`0R8R8202PX:080H61P0P25QHD20:6QX@80PX:20P1[Jf/206MWI`<0
OWin0P2YZJT20<30`080Z:RX0P2QXJ420:^[Z`80/[:b0`2f][H20;Ng]`80]KFe0P31`L420<O7a`80
bLW91@3:b/X20:VYZ@80GemO0P1:BTX205IFEP80GEeM0P1SHf<306e]K@@0MGEe0P1mOGd207moO`80
Ph>30P2:RXX308R8R080SHf=0P2CTi<409BDU080UIFE0P2KVi/309VIV@@0VYZJ0P2FUYH209RHV080
UYJF0P2DU9@309NGU`80VIVI0P2EUID209BDU080Ti>C0P2@T90209FEU@<0T92@0P2;Rh/209BDU080
TY:B0P2?Shl2092@T080SHf=0`2>SXh2092@T080SXj>0P2?Shl208j>SP80UYJF0P2GUiL209JFUP<0
UiNG0P2JVYX209^KV`80WIfM0P2QXJ420:>SX`80YJFU0`2TY:@209ZJVP80WIfM0P2QXJ420:>SX`80
XJ6Q0P2HV9P308^;R`H0PH610P28R8P208B4Q080RXZ:0`28R8P208J6QP80QhN70P21PH4208>3P`80
OWin0P22PX8307moO`80PX:20P23Ph<208b<S0P0b>3H00060<SPf0809bLW0P0[:b/203@d=0<0;Rh^
0P0];Bd202/[:`80;Rh^0P0_;bl2030`<080;Bd]0`0^;Rh203Hf=P80;2`/0P0^;Rh202l_;`80:b/[
0P0_;bl302XZ:P80<30`0P0W9bL202PX:080:b/[0P0V9RH2024Q8@<08R8R0P0X:2P2061PH080QHF5
0P2QXJ4208:2PP80Jf][0P1WIfL307inOP80ZJVY0P30`<020:RXZ080XJ6Q0P2[Zj/20;:b/P<0][Jf
0P2g]kL20;Fe]@80`L710P37alL20<W9b@D0b/[:0P2YZJT205mOG`80BTY:0P1FEUH205eMG@80Hf=S
0`1]KFd407EeM@80OGem0P1oOgl208>3P`80RXZ:0`28R8P208f=S@80Ti>C102DU9@209FEU@80Vi^K
0`2IVIT409ZJVP80UYJF0P2HV9P209JFUP80U9BD0`2GUiL209VIV@80UIFE0P2DU9@209>CT`80T92@
0P2EUID3092@T080Rh^;0P2DU9@209:BTP80Shn?0P2@T90208f=S@<0SXj>0P2@T90208j>SP80Shn?
0P2>SXh209JFUP80UiNG0P2FUYH309NGU`80VYZJ0P2KVi/209fMW@80XJ6Q0P2SXj<20:FUY@<0Y:BT
0P2JVYX209fMW@80XJ6Q0P2SXj<20:6QX@80V9RH0`2;Rh/60861P@80R8R80P24Q8@208Z:RP<0R8R8
0P26QXH208N7Q`80PH610P23Ph<207inOP80PX:20`1oOgl208:2PP80Ph>30P2<S8`80<SPf0001P38
h=P203@d=080:RXZ0P0/;2`503@d=080<S8b0P0a<C4202h^;P80:2PX0P0^;Rh303Lg=`@0<c<c0P0^
;Rh203@d=080=cLg0P0d=3@302`/;0@0<30`0P0W9bL201hN7P808B4Q1@0P820202<S8`80?3`l0P1f
MWH209VIV@80Vi^K0P1^KVh206=SH`<0L71`0P2<S8`20;Vi^@80ZZZZ0P2OWil20:NWY`80/;2`1@2c
/k<20;2`/080^k^k0P32`/820<[:bP80bLW90`3;bl/20<S8b080XZ:R0P1MGEd204m?C`80De=C0P1L
G5`306=SH`80LG5a0P1fMWH207UiN@80Q8B40P23Ph<208J6QP<0QhN70P2;Rh/208b<S080Shn?0P2C
Ti<209:BTP80UiNG0`2JVYX209:BTP80UYJF0P2BTY8209NGU`80VIVI0P2ATI4309>CT`80TI6A0P2;
Rh/208n?S`80TI6A0P2DU9@509FEU@80S8b<0P2:RXX209BDU080T92@0P2=SHd208V9R@<0R8R80P29
RHT208^;R`@0SHf=0P2DU9@2096AT@80S8b<1@2EUID209^KV`80VIVI102OWil20:BTY0<0WYjN0P2J
VYX209BDU080UYJF0P2IVIT409bLW0<0SHf=0P23Ph<207YjNP80Ng]k0P21PH4208B4Q080QXJ60`29
RHT208J6QP80PX:20P25QHD20861P@@0Ogmo0`1mOGd208>3P`80QHF50P2@T9080<SPf0001P38h=P2
03@d=080:RXZ0P0/;2`503@d=080<S8b0P0a<C4202h^;P80:2PX0P0^;Rh303Lg=`@0<c<c0P0^;Rh2
03@d=080=cLg0P0d=3@302`/;0@0<30`0P0W9bL201hN7P808B4Q1@0P820202<S8`80?3`l0P1fMWH2
09VIV@80Vi^K0P1^KVh206=SH`<0L71`0P2<S8`20;Vi^@80ZZZZ0P2OWil20:NWY`80/;2`1@2c/k<2
0;2`/080^k^k0P32`/820<[:bP80bLW90`3;bl/20<S8b080XZ:R0P1MGEd204m?C`80De=C0P1LG5`3
06=SH`80LG5a0P1fMWH207UiN@80Q8B40P23Ph<208J6QP<0QhN70P2;Rh/208b<S080Shn?0P2CTi<2
09:BTP80UiNG0`2JVYX209:BTP80UYJF0P2BTY8209NGU`80VIVI0P2ATI4309>CT`80TI6A0P2;Rh/2
08n?S`80TI6A0P2DU9@509FEU@80S8b<0P2:RXX209BDU080T92@0P2=SHd208V9R@<0R8R80P29RHT2
08^;R`@0SHf=0P2DU9@2096AT@80S8b<1@2EUID209^KV`80VIVI102OWil20:BTY0<0WYjN0P2JVYX2
09BDU080UYJF0P2IVIT409bLW0<0SHf=0P23Ph<207YjNP80Ng]k0P21PH4208B4Q080QXJ60`29RHT2
08J6QP80PX:20P25QHD20861P@@0Ogmo0`1mOGd208>3P`80QHF50P2@T9080<SPf0001P38h=P202d]
;@80:RXZ0P0/;2`3034a<@80;bl_0P0d=3@203<c<`80:BTY0P0^;Rh203<c<`<0<30`0P0^;Rh202l_
;`80;2`/0P0_;bl203@d=080=CDe0`0b<S8203Hf=P80;Bd]0P0V9RH202LW9`809RHV0P0L71`301hN
7P808b<S0P0V9RH205UIF@80QhN70P2QXJ420820P080Hf=S0`1VIVH207=cL`80Z:RX0P2h^;P40:>S
X`80Z:RX0`2c/k<20:f][@80/[:b0P2e]KD20;fm_@80aLG50P38b<P30<_;b`80a/K60P34a<@209jN
WP80FEUI101ADE43061PH080Jf][0P1^KVh207]kN`80P8200P1nOWh208>3P`<0QHF50P27QhL208j>
SP80TY:B0P2EUID408f=S@D0T92@0P2FUYH209BDU080UiNG0P2BTY8209BDU0<0Rh^;0P2?Shl208b<
S080Shn?0P2CTi<209JFUP80UiNG0`2@T90208B4Q080Ph>30P2<S8`208V9R@80PX:20P1lO7`307in
OP80Q8B40P1oOgl408R8R0@0QHF50P1gMgL308b<S080UIFE0P2>SXh2092@T080X:2P102IVIT709JF
UP@0TI6A0P2FUYH209FEU@<0Shn?0P23Ph<207MgM`80NWYj0P20P8020861P@80R8R80`24Q8@208F5
Q@80OWin1023Ph<20820P080OGem0`20P80208J6QP80RHV90P2ATI480<SPf0001P38h=P202d];@80
:RXZ0P0/;2`3034a<@80;bl_0P0d=3@203<c<`80:BTY0P0^;Rh203<c<`<0<30`0P0^;Rh202l_;`80
;2`/0P0_;bl203@d=080=CDe0`0b<S8203Hf=P80;Bd]0P0V9RH202LW9`809RHV0P0L71`301hN7P80
8b<S0P0V9RH205UIF@80QhN70P2QXJ420820P080Hf=S0`1VIVH207=cL`80Z:RX0P2h^;P40:>SX`80
Z:RX0`2c/k<20:f][@80/[:b0P2e]KD20;fm_@80aLG50P38b<P30<_;b`80a/K60P34a<@209jNWP80
FEUI101ADE43061PH080Jf][0P1^KVh207]kN`80P8200P1nOWh208>3P`<0QHF50P27QhL208j>SP80
TY:B0P2EUID408f=S@D0T92@0P2FUYH209BDU080UiNG0P2BTY8209BDU0<0Rh^;0P2?Shl208b<S080
Shn?0P2CTi<209JFUP80UiNG0`2@T90208B4Q080Ph>30P2<S8`208V9R@80PX:20P1lO7`307inOP80
Q8B40P1oOgl408R8R0@0QHF50P1gMgL308b<S080UIFE0P2>SXh2092@T080X:2P102IVIT709JFUP@0
TI6A0P2FUYH209FEU@<0Shn?0P23Ph<207MgM`80NWYj0P20P8020861P@80R8R80`24Q8@208F5Q@80
OWin1023Ph<20820P080OGem0`20P80208J6QP80RHV90P2ATI480<SPf0001P38h=P202h^;P80<C4a
0P0c<c<304A4A0@0:BTY0P0[:b/402l_;`80;Rh^0`0];Bd202h^;P80:RXZ100/;2`2030`<080<S8b
0`0f=SH203@d=080;Bd]0P0X:2P202DU9@809RHV0P0S8b<5028R8P808b<S0P0b<S8206][J`80SHf=
0P2EUID206i^KP<0HV9R0P1YJFT2092@T080^k^k0P2g]kL20::RXP80XJ6Q0`2`/;020:f][@80][Jf
0P2h^;P20;bl_0@0a<C40`3;bl/20<W9b@@0aLG50P2JVYX205UIF@80DE5A0`1OGel206IVIP80KVi^
0P1fMWH207alO080PH610P22PX8308V9R@80QHF50P2<S8`208f=S@80Ti>C0P25QHD208f=S@<0Rh^;
0P2ATI4209BDU080Ti>C0P2BTY8208j>SP80TY:B0`2=SHd2096AT@@0T92@0P2FUYH209FEU@80U9BD
0`2>SXh208>3P`80MgMg1021PH4207]kN`80LG5a0`1^KVh208J6QP80Ogmo0P28R8P208Z:RP80Shn?
0P1kNg/206a/K0<0QXJ60P2:RXX20861P@80QXJ60P2VYZH409:BTP<0UiNG0P2IVIT209NGU`80VIVI
0P2BTY8408j>SP<0Q8B40P1oOgl207EeM@80NGUi0P1oOgl408>3P`D0Q8B40P1oOgl20861P@80Ph>3
0P1nOWh207moO`<0PX:20P28R8P208Z:RP80TI6A2038h=P000H0b>3H0P0^;Rh2034a<@80<c<c0`14
A4@402TY:@80:b/[100_;bl202h^;P<0;Bd]0P0^;Rh202XZ:P@0;2`/0P0`<302038b<P<0=SHf0P0d
=3@202d];@80:2PX0P0U9BD202HV9P808b<S1@0R8R8202<S8`80<S8b0P1[Jf/208f=S@80UIFE0P1^
KVh3069RHP80JFUY0P2@T9020;^k^`80]kNg0P2RXZ820:6QX@<0/;2`0P2][Jd20;Jf]P80^;Rh0P2l
_;`40<C4a0<0bl_;0P39bLT40<G5a@80VYZJ0P1IFET2055AD@<0GemO0P1VIVH206i^KP80MWIf0P1l
O7`20861P@80PX:20`29RHT208F5Q@80S8b<0P2=SHd209>CT`80QHF50P2=SHd308^;R`80TI6A0P2D
U9@209>CT`80TY:B0P2>SXh209:BTP<0SHf=0P2ATI44092@T080UYJF0P2EUID209BDU0<0SXj>0P23
Ph<207MgM`@0PH610P1kNg/2075aL@<0KVi^0P26QXH207moO`80R8R80P2:RXX208n?S`80Ng]k0P1/
K6`308J6QP80RXZ:0P21PH4208J6QP80YZJV102BTY8309NGU`80VIVI0P2GUiL209VIV@80TY:B102>
SXh308B4Q080Ogmo0P1eMGD207UiN@80Ogmo1023Ph<508B4Q080Ogmo0P21PH4208>3P`80OWin0P1o
Ogl308:2PP80R8R80P2:RXX2096AT@P0b>3H00060<SPf080:2PX0P0[:b/202d];@<09RHV0P0];Bd2
02TY:@80;Bd]100/;2`2030`<0D0=3@d0P0[:b/202XZ:P80;bl_0P0i>CT203Ph>0<0;bl_0P0`<302
02`/;0808b<S0P0W9bL202HV9PD08b<S0P0R8R82024Q8@809RHV0P16ATH207alO080VIVI0P20P803
069RHP80G5aL0P1oOgl20;>c/`80`l?30P2][Jd209nOW`<0ZJVY0P2ZZZX40;>c/`80^;Rh0P31`L42
0<;2`P<0b<S80P3:b/X20<G5a@80alO70P31`L4209JFUP80FEUI0`1CDe<206UYJ@80K6a/0P1dM7@4
07inOP80Ph>30`28R8P208F5Q@80RXZ:102=SHd208Z:RPD0SXj>0P2@T90408n?S`80TI6A0P2>SXh2
08b<S0<0TI6A0P2EUID208n?S`80S8b<0P2@T90208f=S@80SXj>0`25QHD20861P@80KFe]0P1gMgL2
0820P080NWYj0P1^KVh305aLG0@0P8200P29RHT208J6QP80Rh^;0P1aLG4206i^KP<0P8200P1kNg/2
06IVIP80OGem0P2VYZH209RHV080Ti>C0`2LW9`20:FUY@80XZ:R0P2SXj<209VIV@80UiNG0P2:RXX3
08>3P`80OWin0P1jNWX207MgM`80NWYj0P1lO7`208:2PPD0Q8B40P1mOGd208>3P`80P8200P21PH42
0820P0<0OWin0P2:RXX209BDU080UIFE2038h=P000H0b>3H0P0X:2P202/[:`80;Bd]0`0V9RH202d]
;@80:BTY0P0];Bd402`/;080<30`1@0d=3@202/[:`80:RXZ0P0_;bl203Ti>@80>3Ph0`0_;bl2030`
<080;2`/0P0S8b<202LW9`809RHV1@0S8b<2028R8P808B4Q0P0V9RH204I6AP80O7al0P2IVIT20820
P0<0HV9R0P1LG5`207moO`80/k>c0P33`l<20:f][@80WinO0`2YZJT20:ZZZP@0/k>c0P2h^;P20<71
`@80`/;20`38b<P20<[:bP80aLG50P37alL20<71`@80UYJF0P1IFET305=CD`80JFUY0P1/K6`207Ad
M0@0OWin0P23Ph<308R8R080QHF50P2:RXX408f=S@80RXZ:1@2>SXh2092@T0@0Shn?0P2ATI4208j>
SP80S8b<0`2ATI4209FEU@80Shn?0P2<S8`2092@T080SHf=0P2>SXh308F5Q@80PH610P1]KFd207Mg
M`80P8200P1jNWX206i^KP<0G5aL1020P80208V9R@80QXJ60P2;Rh/2075aL@80KVi^0`20P80207]k
N`80IVIV0P1mOGd20:JVYP80V9RH0P2CTi<309bLW080YJFU0P2RXZ820:>SX`80VIVI0P2GUiL208Z:
RP<0Ph>30P1nOWh207YjNP80MgMg0P1jNWX207alO080PX:21@24Q8@207emO@80Ph>30P20P8020861
P@80P8200`1nOWh208Z:RP80U9BD0P2EUID80<SPf0001P38h=P202`/;0809RHV0P0Z:RX302d];@80
;Rh^0P0[:b/2030`<080;bl_0P0[:b/202d];@<0;Rh^0P0a<C4202l_;`@0<30`0P0c<c<2038b<P<0
>CTi0P0c<c<202h^;P80:b/[0P0a<C4202@T90809RHV0`0R8R8202<S8`@0820P0P0Z:RX205iNGP80
RHV90P2LW9`306m_K`80FEUI0P1WIfL209bLW080`<300P32`/820::RXP<0Y:BT0P2XZ:P20:n_[`80
/;2`0P2k^k/20;fm_@80`/;20`38b<P20<k>cP80a/K60P35aLD20<K6aP80`/;20P2FUYH5061PH080
JFUY0P1^KVh207IfMP80N7Qh0P1oOgl308F5Q@80Ph>30P26QXH208^;R`80Q8B40P27QhL508V9R@80
Shn?0P2=SHd209:BTP80TI6A0P2@T90208n?S`D0TY:B0P29RHT208J6QP80Q8B40P28R8P208Z:RP<0
Ph>30P1jNWX206e]K@80J6QX0P1gMgL207emO@80I6AT0`1IFET207IfMP80PH610P22PX8208B4Q080
Ogmo0P1YJFT206YZJP<0P8200P1cLg<206EUI@80Ogmo0P2OWil20:>SX`80Z:RX0`2WYjL20;>c/`@0
[jn_0P2XZ:P209jNWP80T92@0`28R8P207emO@80MgMg0P1mOGd207QhN080OWin0P1lO7`50861P@80
PX:20P23Ph<208B4Q080QhN70P22PX830861P@80RXZ:0P2?Shl209JFUPP0b>3H00060<SPf080;2`/
0P0V9RH202XZ:P<0;Bd]0P0^;Rh202/[:`80<30`0P0_;bl202/[:`80;Bd]0`0^;Rh2034a<@80;bl_
100`<30203<c<`80<S8b0`0i>CT203<c<`80;Rh^0P0[:b/2034a<@8092@T0P0V9RH3028R8P808b<S
100P820202XZ:P80GUiN0P29RHT209bLW0<0Kfm_0P1IFET206MWI`80W9bL0P30`<020<;2`P80XZ:R
0`2TY:@20:RXZ080[jn_0P2`/;020;^k^`80_Kfm0P32`/830<S8b080c/k>0P36a/H20<G5a@80a/K6
0P32`/8209JFUPD0H61P0P1YJFT206i^KP80MWIf0P1hN7P207moO`<0QHF50P23Ph<208J6QP80Rh^;
0P24Q8@208N7Q`D0RHV90P2?Shl208f=S@80TY:B0P2ATI42092@T080Shn?1@2BTY8208V9R@80QXJ6
0P24Q8@208R8R080RXZ:0`23Ph<207YjNP80KFe]0P1XJ6P207MgM`80OGem0P1TI6@305UIF@80MWIf
0P21PH4208:2PP80Q8B40P1oOgl206UYJ@80JVYZ0`20P80207=cL`80IFEU0P1oOgl209nOW`80Xj>S
0P2XZ:P30:NWY`80/k>c102_[jl20:RXZ080WYjN0P2@T90308R8R080OGem0P1gMgL207emO@80N7Qh
0P1nOWh207alO0D0PH610P22PX8208>3P`80Q8B40P27QhL208:2PP<0PH610P2:RXX208n?S`80UYJF
2038h=P000H0b>3H0P0`<30202XZ:P808b<S0`0Y:BT202XZ:P80;bl_0P0/;2`203Hf=P80;Bd]0P0^
;Rh302l_;`@0<30`0P0[:b/202XZ:P80:b/[0P0b<S8302`/;080>SXj0P0];Bd203Ti>@80:2PX0P0T
92@202DU9@<092@T0P0U9BD202<S8`@08R8R0P0i>CT207MgM`80W9bL0`27QhL205mOG`80HF5Q0P21
PH420;Ng]`80b/[:0P2i^KT30:JVYP80YjNW0P2ZZZX20;6a/@80][Jf0P2j^[X20;jn_P<0`l?30P3:
b/X20<_;b`80bLW91032`/820;no_`<0RXZ:0P1NGUh205mOG`80J6QX0P1eMGD207MgM`80PH610`22
PX8207alO080PX:20P2:RXX20861P@80QhN70P22PX8308F5Q@80TY:B0P2>SXh408n?S`80SHf=1@2?
Shl208f=S@80QXJ60P1hN7P207IfMP80OGem0P1nOWh307moO`80OWin0P1/K6`206e]K@80Jf][0P1l
O7`206m_K`<0H61P0P1jNWX208F5Q@80R8R80P2BTY8209JFUP80TI6A0P2CTi<30:NWY`80X:2P0P2=
SHd209nOW`80XZ:R0P2TY:@20:n_[`D0[:b/0P2[Zj/20:j^[P80[Jf]0P2OWil209BDU0<0S8b<0P23
Ph<207inOP80P8200P1lO7`207moO`80M7Ad0`1kNg/208:2PP80Ng]k0P1nOWh20820P0@0Ph>30`26
QXH208f=S@80TY:B0P2EUID80<SPf0001P38h=P2030`<080:RXZ0P0S8b<302TY:@80:RXZ0P0_;bl2
02`/;080=SHf0P0];Bd202h^;P<0;bl_100`<30202/[:`80:RXZ0P0[:b/2038b<P<0;2`/0P0j>SX2
02d];@80>CTi0P0X:2P202@T90809BDU0`0T92@202DU9@808b<S100R8R8203Ti>@80MgMg0P2LW9`3
08N7Q`80GemO0P1QHF420861P@80]kNg0P3:b/X20;Vi^@<0YZJV0P2WYjL20:ZZZP80/K6a0P2f][H2
0;Zj^P80_[jn0`33`l<20<[:bP80bl_;0P39bLT40<;2`P80_kno0`2:RXX205iNGP80GemO0P1XJ6P2
07EeM@80MgMg0P21PH4308:2PP80O7al0P22PX8208Z:RP80PH610P27QhL208:2PP<0QHF50P2BTY82
08j>SP@0Shn?0P2=SHd508n?S`80SHf=0P26QXH207QhN080MWIf0P1mOGd207inOP<0Ogmo0P1nOWh2
06a/K080KFe]0P1[Jf/207alO080Kfm_0`1PH60207YjNP80QHF50P28R8P209:BTP80UYJF0P2ATI42
09>CT`<0YjNW0P2PX:0208f=S@80WinO0P2RXZ820:BTY080[jn_1@2/[:`20:^[Z`80[Zj^0P2][Jd2
09nOW`80U9BD0`2<S8`208>3P`80OWin0P20P80207alO080Ogmo0P1dM7@307]kN`80PX:20P1kNg/2
07inOP80P8201023Ph<308J6QP80SHf=0P2BTY8209FEU@P0b>3H00060<SPf080:2PX0P0T92@202DU
9@<0:b/[0P0U9BD202`/;080;bl_0P0d=3@2038b<P80<C4a0`0`<302034a<@80>3Ph0P0b<S8202h^
;P80>CTi0P0`<303034a<@80;bl_0P0Z:RX203Ph>080;bl_0P0W9bL202HV9P<0;Bd]0P0R8R82024Q
8@807alO0P0S8b<202`/;080DU9B0P24Q8@309nOW`80KFe]0P1FEUH206a/K080Vi^K0P32`/820<_;
b`<0[jn_0P2SXj<20:NWY`80[:b/0P2f][H20;Vi^@80_;bl0`2n_[h20<S8b080bLW90P3:b/X20<K6
aP80a<C40P35aLD30;jn_P80U9BD0P1RHV8205aLG080K6a/0P1hN7P207]kN`<0O7al0P1kNg/20861
P@80QXJ60P1nOWh20861P@80OGem0`24Q8@409>CT`80TI6A0P2@T90208n?S`80SHf=0`27QhL208R8
R080PH610P1`L70206e]K@80LW9b0P1YJFT306a/K080N7Qh0P1bLW8206m_K`80M7Ad1025QHD308n?
S`80UiNG0P2KVi/209NGU`80WYjN0P2YZJT20:NWY`80[:b/1@2b/[820:ZZZP80/K6a0P2d];@20;^k
^`80_Kfm0`2a/K420:2PX080Vi^K0P2GUiL209BDU0@0R8R80`29RHT208B4Q080Ph>30P1nOWh207Ui
N@80MgMg0P1iNGT307=cL`80N7Qh0P20P80208>3P`80PH610P20P80207UiN@<0PX:20P2=SHd209BD
U080UiNG2038h=P000H0b>3H0P0X:2P202@T90809BDU0`0[:b/202DU9@80;2`/0P0_;bl203@d=080
<S8b0P0a<C43030`<080<C4a0P0h>3P2038b<P80;Rh^0P0i>CT2030`<0<0<C4a0P0_;bl202XZ:P80
>3Ph0P0_;bl202LW9`809RHV0`0];Bd2028R8P808B4Q0P0O7al202<S8`80;2`/0P1BDU8208B4Q0<0
WinO0P1]KFd205IFEP80K6a/0P2KVi/20<;2`P80bl_;0`2_[jl20:>SX`80YjNW0P2/[:`20;Jf]P80
^KVi0P2l_;`30;jn_P80b<S80P39bLT20<[:bP80a/K60P34a<@20<G5a@<0_[jn0P2DU9@2069RHP80
G5aL0P1/K6`207QhN080Ng]k0`1lO7`207]kN`80PH610P26QXH207inOP80PH610P1mOGd308B4Q0@0
Ti>C0P2ATI42092@T080Shn?0P2=SHd308N7Q`80R8R80P21PH42071`L080KFe]0P1bLW8206UYJ@<0
K6a/0P1hN7P2079bLP80Kfm_0P1dM7@408F5Q@<0Shn?0P2GUiL209^KV`80UiNG0P2NWYh20:VYZ@80
YjNW0P2/[:`50;:b/P80ZZZZ0P2a/K420;Bd]080^k^k0P2m_Kd30;6a/@80X:2P0P2KVi/209NGU`80
U9BD1028R8P308V9R@80Q8B40P23Ph<207inOP80NGUi0P1gMgL207UiN@<0Lg=c0P1hN7P20820P080
Ph>30P21PH420820P080NGUi0`22PX8208f=S@80U9BD0P2GUiL80<SPf0001P38h=P202PX:08092@T
0P0U9BD302/[:`809BDU0P0/;2`202l_;`80=3@d0P0b<S82034a<@<0<30`0P0a<C4203Ph>080<S8b
0P0^;Rh203Ti>@80<30`0`0a<C4202l_;`80:RXZ0P0h>3P202l_;`809bLW0P0V9RH302d];@808R8R
0P0Q8B4201lO7`808b<S0P0/;2`2059BDP80Q8B40`2OWil206e]K@80EUIF0P1/K6`209^KV`80`/;2
0P3;bl/30:n_[`80Xj>S0P2WYjL20:b/[080][Jf0P2i^KT20;bl_0<0_[jn0P38b<P20<W9b@80b/[:
0P36a/H20<C4a080aLG50`2n_[h209BDU080HV9R0P1LG5`206a/K080N7Qh0P1kNg/307alO080Ng]k
0P21PH4208J6QP80OWin0P21PH4207emO@<0Q8B4102CTi<2096AT@80T92@0P2?Shl208f=S@<0QhN7
0P28R8P20861P@80L71`0P1]KFd2079bLP80JFUY0`1/K6`207QhN080LW9b0P1_Kfl207AdM0@0QHF5
0`2?Shl209NGU`80Vi^K0P2GUiL209jNWP80ZJVY0P2WYjL20:b/[0D0/[:b0P2ZZZX20;6a/@80];Bd
0P2k^k/20;fm_@<0/K6a0P2PX:0209^KV`80UiNG0P2DU9@408R8R0<0RHV90P24Q8@208>3P`80OWin
0P1iNGT207MgM`80NGUi0`1cLg<207QhN080P8200P23Ph<20861P@80P8200P1iNGT308:2PP80SHf=
0P2DU9@209NGU`P0b>3H00060<SPf080;2`/0P0W9bL202@T90<09bLW0P0Y:BT2034a<@80=3@d0P0/
;2`2034a<@80;Bd]0`0`<30203`l?080@4100P0j>SX203Hf=P80;Rh^0P0/;2`3030`<080<S8b0P14
A4@203/k>`80;bl_0P0d=3@202/[:`<08b<S0P0W9bL202DU9@808R8R0P0/;2`202TY:@80>c/k0P1^
KVh3096AT@80Ti>C0P1OGel2061PH080O7al0P2/[:`20<k>cP<0_kno0P2NWYh20:>SX`80YZJV0P2^
[Zh20;Bd]080^[Zj0`2k^k/20<G5a@80b<S80P3:b/X20<S8b080a/K60P34a<@30;no_`80_;bl0P2?
Shl2061PH080HV9R0P1gMgL207UiN@D0Ng]k0P1oOgl40861P@80P8200P1nOWh308R8R080T92@0P2C
Ti<2092@T0@0SHf=0P2<S8`308:2PP80O7al0P1dM7@206][J`80Hf=S0P1YJFT205=CD`<0Bd];0P1a
LG4207emO@80QhN70P2:RXX209:BTP80UIFE1@2MWId209nOW`80Z:RX0P2][Jd20;2`/0@0^k^k0`31
`L420<C4a080`L710P2i^KT20:n_[`80YjNW0P2ZZZX309^KV`80TY:B0P2>SXh208N7Q`80O7al0P1e
MGD207IfMP<0PX:20P20P80208J6QP80OWin0P1mOGd207QhN080MgMg0`1iNGT207]kN`80P8201022
PX8208F5Q@80P8200`24Q8@208j>SP80U9BD0P2JVYX80<SPf0001P38h=P202`/;0809bLW0P0T92@3
02LW9`80:BTY0P0a<C4203@d=080;2`/0P0a<C4202d];@<0<30`0P0l?3`20410@080>SXj0P0f=SH2
02h^;P80;2`/0`0`<302038b<P80A4A40P0k>c/202l_;`80=3@d0P0[:b/302<S8`809bLW0P0U9BD2
028R8P80;2`/0P0Y:BT203/k>`80KVi^0`2ATI4209>CT`80GemO0P1PH60207alO080[:b/0P3>c/h3
0;no_`80WYjN0P2SXj<20:JVYP80[Zj^0P2d];@20;Zj^P<0^k^k0P35aLD20<S8b080b/[:0P38b<P2
0<K6aP80a<C40`2o_kl20;bl_080Shn?0P1PH602069RHP80MgMg0P1iNGT507]kN`80Ogmo1021PH42
0820P080OWin0`28R8P2092@T080Ti>C0P2@T90408f=S@80S8b<0`22PX8207alO080M7Ad0P1[Jf/2
06=SH`80JFUY0P1CDe<304];B`80LG5a0P1mOGd208N7Q`80RXZ:0P2BTY8209FEU@D0WIfM0P2OWil2
0:RXZ080[Jf]0P2`/;040;^k^`<0`L710P34a<@20<71`@80^KVi0P2_[jl20:NWY`80ZZZZ0`2KVi/2
09:BTP80SXj>0P27QhL207alO080MGEe0P1fMWH308:2PP80P8200P26QXH207inOP80OGem0P1hN7P2
07MgM`<0NGUi0P1kNg/20820P0@0PX:20P25QHD20820P0<0Q8B40P2>SXh209BDU080VYZJ2038h=P0
00H0b>3H0P0b<S8202`/;0D09bLW0P0T92@202TY:@80<30`0P0i>CT203Ph>080<S8b0`0^;Rh203Hf
=P80@d=30P0o?cl402h^;P80=SHf0`0`<30202`/;080;Rh^0P0a<C4203Lg=`809bLW0P0T92@302PX
:0809BDU0P0T92@2024Q8@80820P0P0i>CT202XZ:P80CDe=0`25QHD209^KV`80O7al0P1SHf<206IV
IP80R8R80P32`/830<G5a@80W9bL0P2EUID209nOW`80[Jf]0P2a/K420;Vi^@<0]KFe0P30`<040<O7
a`80a/K60P37alL20<G5a@D0`L710P2l_;`209:BTP80IVIV0P1YJFT2079bLP<0Ogmo0P1lO7`207]k
N`80NWYj0P1lO7`207inOP80Ng]k0`27QhL208j>SP80Rh^;0P2=SHd408J6QP80QHF50`1bLW8206YZ
JP80GemO0P1KFe/205eMG@80GemO0P1NGUh306i^KP80MgMg0P22PX8208^;R`80SHf=0P23Ph<208F5
Q@<0RXZ:0P2CTi<209jNWP80][Jf0P2k^k/20<71`@80aLG50P37alL30<_;b`80c/k>0P3AdM420<k>
cP80alO70P2f][H209jNWP<0T92@0P29RHT2096AT@80V9RH0P2;Rh/207=cL`80L71`0`1lO7`208>3
P`80PX:20P1mOGd207UiN@80LW9b0P1eMGD307UiN@80O7al0P24Q8@20861P@80PX:20P21PH4208F5
Q@<0Q8B4102=SHd209VIV@P0b>3H00060<SPf080<S8b0P0/;2`502LW9`8092@T0P0Y:BT2030`<080
>CTi0P0h>3P2038b<P<0;Rh^0P0f=SH204=3@`80?clo100^;Rh203Hf=P<0<30`0P0/;2`202h^;P80
<C4a0P0g=cL202LW9`8092@T0`0X:2P202DU9@8092@T0P0Q8B42020P8080>CTi0P0Z:RX204e=C@<0
QHF50P2KVi/207alO080Hf=S0P1VIVH208R8R080`/;20`35aLD209bLW080UIFE0P2OWil20:f][@80
/K6a0P2i^KT30;Fe]@80`<301037alL20<K6aP80alO70P35aLD50<71`@80_;bl0P2BTY8206IVIP80
JFUY0P1bLW8307moO`80O7al0P1kNg/207YjNP80O7al0P1nOWh207]kN`<0QhN70P2>SXh208^;R`80
SHf=1026QXH208F5Q@<0LW9b0P1ZJVX205mOG`80Fe]K0P1MGEd205mOG`80GUiN0`1^KVh207MgM`80
PX:20P2;Rh/208f=S@80Ph>30P25QHD308Z:RP80Ti>C0P2NWYh20;Jf]P80^k^k0P31`L420<G5a@80
alO70`3;bl/20<k>cP80dM7A0P3>c/h20<O7a`80][Jf0P2NWYh3092@T080RHV90P2ATI4209RHV080
Rh^;0P1cLg<2071`L0<0O7al0P23Ph<208:2PP80OGem0P1iNGT2079bLP80MGEe0`1iNGT207alO080
Q8B40P21PH4208:2PP80PH610P25QHD308B4Q0@0SHf=0P2IVIT80<SPf0001P38h=P202`/;080:b/[
0P0f=SH302`/;080;bl_0P0[:b/203Hf=P80?Cdm0P0j>SX203Hf=P<0;Bd]0P0X:2P203Lg=`80@410
0P0a<C4202LW9`809RHV0`0Y:BT202`/;080;bl_0P0`<30203De=@809RHV0P0U9BD302h^;P80;Bd]
0P0Q8B4202<S8`808B4Q0P0Z:RX203Hf=P80?3`l0`1HF5P208R8R080UYJF0P1SHf<205QHF080IVIV
0P2SXj<30<;2`P80Zj^[0P2FUYH209bLW080[:b/0P2e]KD20;:b/P<0];Bd0P2m_Kd40<?3``80alO7
0P39bLT20<G5a@<0alO70P31`L420<C4a080`L710P2LW9`206a/K080JVYZ0`1cLg<207MgM`80NWYj
0P1bLW8207IfMP80OWin0P1lO7`308>3P`80S8b<0P23Ph<208n?S`80R8R80P1lO7`207IfMP<0Hf=S
0P1CDe<404=3@`80DU9B0P1SHf<207=cL`D0MgMg0P1lO7`208B4Q080N7Qh0P1/K6`206EUI@<0IVIV
0P1dM7@208V9R@80Xj>S0P2j^[X20<G5a@80a/K60P3:b/X30<g=c@80clo?0P3AdM420<o?c`80b/[:
0P36a/H20;2`/0<0UiNG0P28R8P2092@T080SXj>0P2DU9@2075aL@80KVi^0`1iNGT208F5Q@80OWin
0P1dM7@2075aL@80NGUi0P1dM7@307alO080Ng]k0P1lO7`207moO`@0PX:20P23Ph<508J6QP80T92@
0P2DU9@80<SPf0001P38h=P202`/;080:b/[0P0f=SH302`/;080;bl_0P0[:b/203Hf=P80?Cdm0P0j
>SX203Hf=P<0;Bd]0P0X:2P203Lg=`80@4100P0a<C4202LW9`809RHV0`0Y:BT202`/;080;bl_0P0`
<30203De=@809RHV0P0U9BD302h^;P80;Bd]0P0Q8B4202<S8`808B4Q0P0Z:RX203Hf=P80?3`l0`1H
F5P208R8R080UYJF0P1SHf<205QHF080IVIV0P2SXj<30<;2`P80Zj^[0P2FUYH209bLW080[:b/0P2e
]KD20;:b/P<0];Bd0P2m_Kd40<?3``80alO70P39bLT20<G5a@<0alO70P31`L420<C4a080`L710P2L
W9`206a/K080JVYZ0`1cLg<207MgM`80NWYj0P1bLW8207IfMP80OWin0P1lO7`308>3P`80S8b<0P23
Ph<208n?S`80R8R80P1lO7`207IfMP<0Hf=S0P1CDe<404=3@`80DU9B0P1SHf<207=cL`D0MgMg0P1l
O7`208B4Q080N7Qh0P1/K6`206EUI@<0IVIV0P1dM7@208V9R@80Xj>S0P2j^[X20<G5a@80a/K60P3:
b/X30<g=c@80clo?0P3AdM420<o?c`80b/[:0P36a/H20;2`/0<0UiNG0P28R8P2092@T080SXj>0P2D
U9@2075aL@80KVi^0`1iNGT208F5Q@80OWin0P1dM7@2075aL@80NGUi0P1dM7@307alO080Ng]k0P1l
O7`207moO`@0PX:20P23Ph<508J6QP80T92@0P2DU9@80<SPf0001P38h=P203`l?080=CDe0P0X:2P3
02h^;P80:RXZ0P0^;Rh203@d=080ADE50P1?Cdl203dm?@<0:RXZ0P0Y:BT2034a<@80>SXj0P0b<S82
02d];@80;2`/0`0X:2P402d];@80=SHf0P0h>3P202PX:0D09bLW0P0T92@2024Q8@809BDU0P0Z:RX2
030`<080<S8b0P0e=CD303lo?`80KVi^0P2EUID207alO080De=C0P1FEUH207inOP<0[jn_0P2i^KT2
09nOW`80V9RH0P2YZJT20;2`/080/k>c0`2d];@20;bl_080_[jn0P33`l<20<O7a`80bLW90P3:b/X3
0<C4a0H0aLG50P34a<@20:2PX080KFe]0`1XJ6P2075aL@80MGEe101fMWH207moO`80PX:20`24Q8@2
08:2PP80O7al0P22PX8207alO080MGEe0P1/K6`305IFEP80@D51100_;bl204U9B@80Hf=S0P1aLG43
071`L080MGEe0P1hN7P2075aL@80GemO0P1BDU8203lo?`<0@T920P1;Bd/205QHF080Ogmo0P2NWYh2
0;bl_080b/[:0P3;bl/50<[:bP80c/k>0P3<c<`20<K6aP80`l?30P2l_;`30:>SX`80U9BD0P2:RXX2
08B4Q080N7Qh0P1ZJVX207AdM0<0OWin0P1jNWX4071`L080Lg=c0P1lO7`207emO@<0N7Qh0P1fMWH2
07]kN`80NWYj0P26QXH208B4Q080Rh^;0`2:RXX208n?S`80U9BD0P2KVi/80<SPf0001P38h=P203`l
?080=CDe0P0X:2P302h^;P80:RXZ0P0^;Rh203@d=080ADE50P1?Cdl203dm?@<0:RXZ0P0Y:BT2034a
<@80>SXj0P0b<S8202d];@80;2`/0`0X:2P402d];@80=SHf0P0h>3P202PX:0D09bLW0P0T92@2024Q
8@809BDU0P0Z:RX2030`<080<S8b0P0e=CD303lo?`80KVi^0P2EUID207alO080De=C0P1FEUH207in
OP<0[jn_0P2i^KT209nOW`80V9RH0P2YZJT20;2`/080/k>c0`2d];@20;bl_080_[jn0P33`l<20<O7
a`80bLW90P3:b/X30<C4a0H0aLG50P34a<@20:2PX080KFe]0`1XJ6P2075aL@80MGEe101fMWH207mo
O`80PX:20`24Q8@208:2PP80O7al0P22PX8207alO080MGEe0P1/K6`305IFEP80@D51100_;bl204U9
B@80Hf=S0P1aLG43071`L080MGEe0P1hN7P2075aL@80GemO0P1BDU8203lo?`<0@T920P1;Bd/205QH
F080Ogmo0P2NWYh20;bl_080b/[:0P3;bl/50<[:bP80c/k>0P3<c<`20<K6aP80`l?30P2l_;`30:>S
X`80U9BD0P2:RXX208B4Q080N7Qh0P1ZJVX207AdM0<0OWin0P1jNWX4071`L080Lg=c0P1lO7`207em
O@<0N7Qh0P1fMWH207]kN`80NWYj0P26QXH208B4Q080Rh^;0`2:RXX208n?S`80U9BD0P2KVi/80<SP
f0001P38h=P20410@080;Rh^0P0/;2`302PX:080;2`/0P0X:2P203Xj>P80DU9B0P1dM7@204e=C@<0
:RXZ0P0/;2`203@d=080<30`0P0e=CD202`/;080;Bd]1@0[:b/203De=@80=3@d0P0`<30202XZ:P80
<30`0`0/;2`202LW9`80:2PX0P0[:b/202LW9`80;Rh^0P0X:2P202DU9@<0;2`/0P10@40207emO@80
RXZ:0P1WIfL2055AD@80IVIV0`29RHT20:JVYP80XJ6Q0P2@T90209NGU`80Xj>S0P2XZ:P30:^[Z`80
^k^k0P2i^KT20<71`@80a/K60P35aLD20<S8b0<0alO70P35aLD20<C4a080`/;20P37alL20<?3``80
V9RH0`1/K6`206=SH`80L71`0P1bLW8207YjNP80OWin0P21PH4307emO@80M7Ad0P1eMGD207UiN@80
KFe]0P1TI6@2061PH0<0BTY:0P0b<S8202/[:`80<c<c0P14A4@205aLG080JFUY0`1bLW8207emO@80
LG5a0P1IFET203hn?P80>CTi0P0f=SH303dm?@80>SXj0P11@D4204e=C@80Jf][0P2PX:020<K6aP80
d=3@0`3>c/h20=3@d080clo?0P3AdM420<[:bP80b<S80P30`<030;2`/080WYjN0P23Ph<2079bLP80
HF5Q0P1VIVH507emO@80M7Ad0P1VIVH206m_K`80LW9b0P1gMgL207alO0<0MGEe0P1aLG4207]kN`80
PH610P22PX8208J6QP80RHV90`2:RXX208j>SP80Ti>C0P2KVi/80<SPf0001P38h=P20410@080;Rh^
0P0/;2`302PX:080;2`/0P0X:2P203Xj>P80DU9B0P1dM7@204e=C@<0:RXZ0P0/;2`203@d=080<30`
0P0e=CD202`/;080;Bd]1@0[:b/203De=@80=3@d0P0`<30202XZ:P80<30`0`0/;2`202LW9`80:2PX
0P0[:b/202LW9`80;Rh^0P0X:2P202DU9@<0;2`/0P10@40207emO@80RXZ:0P1WIfL2055AD@80IVIV
0`29RHT20:JVYP80XJ6Q0P2@T90209NGU`80Xj>S0P2XZ:P30:^[Z`80^k^k0P2i^KT20<71`@80a/K6
0P35aLD20<S8b0<0alO70P35aLD20<C4a080`/;20P37alL20<?3``80V9RH0`1/K6`206=SH`80L71`
0P1bLW8207YjNP80OWin0P21PH4307emO@80M7Ad0P1eMGD207UiN@80KFe]0P1TI6@2061PH0<0BTY:
0P0b<S8202/[:`80<c<c0P14A4@205aLG080JFUY0`1bLW8207emO@80LG5a0P1IFET203hn?P80>CTi
0P0f=SH303dm?@80>SXj0P11@D4204e=C@80Jf][0P2PX:020<K6aP80d=3@0`3>c/h20=3@d080clo?
0P3AdM420<[:bP80b<S80P30`<030;2`/080WYjN0P23Ph<2079bLP80HF5Q0P1VIVH507emO@80M7Ad
0P1VIVH206m_K`80LW9b0P1gMgL207alO0<0MGEe0P1aLG4207]kN`80PH610P22PX8208J6QP80RHV9
0`2:RXX208j>SP80Ti>C0P2KVi/80<SPf0001P38h=P203Ph>080:2PX0P0V9RH302LW9`809RHV0P0]
;Bd20410@080IFEU0P1oOgl204m?C`<0=CDe0P0^;Rh2034a<@80:BTY0P0e=CD202/[:`80:BTY0`0a
<C4202d];@80<C4a0P0m?Cd202d];@80:2PX0P0];Bd302HV9P80;2`/0P0[:b/202PX:0808b<S0P0]
;Bd202LW9`8092@T0`0V9RH202l_;`80FUYJ0P1hN7P207=cL`80DE5A0P1LG5`307emO@80UiNG0P2a
/K4209jNWP80Ti>C0P2GUiL209>CT`<0VIVI0P2RXZ820:ZZZP80];Bd0P2k^k/20<?3``80a/K60`39
bLT20<[:bP80b<S81035aLD20<?3``80`/;20`2HV9P206MWI`80KFe]0P1UIFD207=cL`80N7Qh0P1j
NWX307EeM@80KVi^0P1TI6@2065QH@80GemO0P1FEUH204i>CP<0=cLg0P0_;bl203<c<`80ADE50P1C
De<205YJFP80K6a/0`1oOgl207=cL`80F5QH0P0k>c/203`l?080Cdm?0P1GEeL305YJFP80D51@0P1=
CDd203Lg=`80@D510P1aLG420:f][@80clo?0`3Cdm<20=;BdP@0dm?C0P3=cLd20<k>cP80b/[:0`2f
][H209jNWP80Ng]k0P1MGEd205ADE080Hf=S0P1nOWh307IfMP80IVIV0P1RHV8206][J`@0Kfm_0P1e
MGD3079bLP80MWIf0P1jNWX40820P080QXJ60P28R8P308V9R@80T92@0P2GUiL20::RXPP0b>3H0006
0<SPf080>3Ph0P0X:2P202HV9P<09bLW0P0V9RH202d];@80@4100P1UIFD207moO`80Cdm?0`0e=CD2
02h^;P80<C4a0P0Y:BT203De=@80:b/[0P0Y:BT3034a<@80;Bd]0P0a<C4203dm?@80;Bd]0P0X:2P2
02d];@<09RHV0P0/;2`202/[:`80:2PX0P0S8b<202d];@809bLW0P0T92@302HV9P80;bl_0P1JFUX2
07QhN080Lg=c0P1ADE4205aLG0<0OGem0P2GUiL20;6a/@80WYjN0P2CTi<209NGU`80Ti>C0`2IVIT2
0::RXP80ZZZZ0P2d];@20;^k^`80`l?30P36a/H30<W9b@80b/[:0P38b<P40<G5a@80`l?30P32`/83
09RHV080IfMW0P1]KFd206EUI@80Lg=c0P1hN7P207YjNP<0MGEe0P1^KVh206ATI080HF5Q0P1OGel2
05IFEP80CTi>0`0g=cL202l_;`80<c<c0P15ADD205=CD`80FUYJ0P1/K6`307moO`80Lg=c0P1HF5P2
03/k>`80?3`l0P1?Cdl205MGE`<0FUYJ0P1@D50204e=C@80=cLg0P11@D42075aL@80[Jf]0P3?cll3
0=?Cd`80d];B103Cdm<20<g=c@80c/k>0P3:b/X30;Jf]P80WYjN0P1kNg/205eMG@80E5AD0P1SHf<2
07inOP<0MWIf0P1VIVH2069RHP80Jf][101_Kfl207EeM@<0LW9b0P1fMWH207YjNP@0P8200P26QXH2
08R8R0<0RHV90P2@T90209NGU`80XZ:R2038h=P000H0b>3H0P0h>3P202h^;P80:b/[0`0Y:BT202/[
:`80<C4a0P15ADD207UiN@80MgMg0P16ATH303hn?P80;2`/0P0Y:BT202XZ:P80;2`/0P0Z:RX202d]
;@<0;2`/0P0Z:RX2030`<080>SXj0P0^;Rh202XZ:P809RHV0`0X:2P202TY:@@0:b/[0P0U9BD202LW
9`808b<S1@0U9BD202h^;P80BTY:0P1YJFT208B4Q080LW9b0P1FEUH306a/K080Ti>C0P2l_;`20;no
_`80Z:RX0P2QXJ4209VIV@<0UIFE0P2IVIT20:RXZ080[Jf]0P2c/k<20;jn_P80`l?31@3:b/X20<_;
b`80a/K60P31`L420<K6aPD0alO70P2CTi<206UYJ@80HV9R0P1WIfL207AdM080KVi^0`1YJFT205aL
G080E5AD0P1BDU8204i>CP80@T920P0k>c/302h^;P80:b/[0P0];Bd204E5A@80BTY:0P1MGEd207Ee
M@<0NGUi0P1SHf<204=3@`80>SXj0P1DE5@2069RHPD0EUIF0P1KFe/205=CD`80B4Q80P0i>CT20492
@P80OWin0P35aLD30=7Ad@80c/k>0P3@d=020=;BdP80cLg=0P3>c/h20<S8b0<0][Jf0P2EUID206a/
K080C4a<0P16ATH206a/K080OWin0`1ZJVX205aLG080H61P101`L70206e]K@80L71`0`1fMWH207Ui
N@80NWYj0P1mOGd20861P@80QHF50P2:RXX308R8R080SHf=0P2EUID209bLW0P0b>3H00060<SPf080
>3Ph0P0^;Rh202/[:`<0:BTY0P0[:b/2034a<@80ADE50P1iNGT207MgM`80ATI60`0n?Sh202`/;080
:BTY0P0Z:RX202`/;080:RXZ0P0];Bd302`/;080:RXZ0P0`<30203Xj>P80;Rh^0P0Z:RX202HV9P<0
:2PX0P0Y:BT402/[:`809BDU0P0W9bL202<S8`D09BDU0P0^;Rh204Y:BP80JFUY0P24Q8@2079bLP80
EUIF0`1/K6`209>CT`80_;bl0P2o_kl20:RXZ080XJ6Q0P2IVIT309FEU@80VIVI0P2XZ:P20:f][@80
/k>c0P2n_[h20<?3``D0b/[:0P3;bl/20<K6aP80`L710P36a/H50<O7a`80Ti>C0P1YJFT2069RHP80
IfMW0P1dM7@206i^KP<0JFUY0P1LG5`205ADE080DU9B0P1>CTh20492@P80>c/k0`0^;Rh202/[:`80
;Bd]0P15ADD204Y:BP80GEeM0P1eMGD307UiN@80Hf=S0P13@d<203Xj>P80E5AD0P1RHV8505IFEP80
Fe]K0P1CDe<204Q8B080>CTi0P12@T8207inOP80aLG50`3AdM420<k>cP80d=3@0P3Bd]820<g=c@80
c/k>0P38b<P30;Jf]P80UIFE0P1/K6`204a<C080ATI60P1/K6`207inOP<0JVYZ0P1LG5`2061PH0@0
L71`0P1]KFd2071`L0<0MWIf0P1iNGT207YjNP80OGem0P21PH4208F5Q@80RXZ:0`28R8P208f=S@80
UIFE0P2LW9`80<SPf0001P38h=P203Ph>080;Rh^0P0[:b/302TY:@80:b/[0P0a<C4204E5A@80NGUi
0P1gMgL204I6AP<0?Shn0P0/;2`202TY:@80:RXZ0P0/;2`202XZ:P80;Bd]0`0/;2`202XZ:P80<30`
0P0j>SX202h^;P80:RXZ0P0V9RH302PX:080:BTY100[:b/202DU9@809bLW0P0S8b<502DU9@80;Rh^
0P1:BTX206UYJ@80Q8B40P1bLW8205IFEP<0K6a/0P2CTi<20;bl_080_kno0P2XZ:P20:6QX@80VIVI
0`2EUID209VIV@80Z:RX0P2][Jd20;>c/`80_[jn0P33`l<50<[:bP80bl_;0P36a/H20<71`@80a/K6
1@37alL209>CT`80JFUY0P1RHV8206MWI`80M7Ad0P1^KVh306UYJ@80G5aL0P1DE5@2059BDP80CTi>
0P12@T8203/k>`<0;Rh^0P0[:b/202d];@80ADE50P1:BTX205eMG@80MGEe0`1iNGT206=SH`80@d=3
0P0j>SX205ADE080HV9R1@1FEUH205]KF`80De=C0P18B4P203Ti>@80@T920P1nOWh20<G5a@<0dM7A
0P3>c/h20=3@d080d];B0P3=cLd20<k>cP80b<S80`2f][H209FEU@80K6a/0P1<C4`204I6AP80K6a/
0P1nOWh306YZJP80G5aL0P1PH604071`L080KFe]0P1`L70307IfMP80NGUi0P1jNWX207emO@80PH61
0P25QHD208Z:RP<0R8R80P2=SHd209FEU@80W9bL2038h=P000H0b>3H0P0e=CD202XZ:P80<30`0`0V
9RH202LW9`80;Rh^0P1BDU8208R8R080E5AD0P0f=SH304A4A0@0<30`0P0S8b<202@T90809RHV0P0_
;bl302HV9P80;Rh^0P0g=cL203Ph>080;bl_0P0[:b/202TY:@<09bLW0P0d=3@203Ti>@80<S8b0P0[
:b/202DU9@80:2PX0P0];Bd303De=@80B4Q80P1:BTX2069RHP80RHV90P2MWId207EeM@<0H61P0P1d
M7@20:VYZ@80cLg=0P2o_kl20:ZZZP80Y:BT0`2][Jd20:ZZZP80/[:b0P2k^k/20;Jf]P80_Kfm0P2l
_;`30<S8b080bLW90P3;bl/40<K6aP80cLg=0P39bLT30<S8b080`/;20P2=SHd205eMG@80HF5Q0P1[
Jf/206EUI@<0HF5Q0P1FEUH205=CD`80@4100P0e=CD203<c<`80<30`0`0a<C4202d];@80;bl_0P12
@T8204M7A`80GemO0P1cLg<306][J`80AdM70P0d=3@205aLG080HV9R0P1JFUX204Q8B0D0@T920P1J
FUX206a/K080BTY:0P0e=CD205MGE`80/K6a0`3?cll40<c<c080c/k>0P3;bl/20<S8b080_kno0`2[
Zj/20820P080F5QH0P16ATH205QHF080O7al0P1hN7P305iNGP80FUYJ0P1/K6`207MgM`80LW9b0P1`
L702075aL@<0Lg=c0P1hN7P207]kN`80PH610P26QXH208N7Q`80R8R80`2;Rh/208f=S@80TI6A0P2I
VIT80<SPf0001P38h=P203De=@80:RXZ0P0`<30302HV9P809bLW0P0^;Rh2059BDP80R8R80P1DE5@2
03Hf=P<0A4A4100`<30202<S8`8092@T0P0V9RH202l_;`<09RHV0P0^;Rh203Lg=`80>3Ph0P0_;bl2
02/[:`80:BTY0`0W9bL203@d=080>CTi0P0b<S8202/[:`809BDU0P0X:2P202d];@<0=CDe0P18B4P2
04Y:BP80HV9R0P29RHT209fMW@80MGEe0`1PH60207AdM080ZJVY0P3=cLd20;no_`80ZZZZ0P2TY:@3
0:f][@80ZZZZ0P2b/[820;^k^`80][Jf0P2m_Kd20;bl_0<0b<S80P39bLT20<_;b`@0a/K60P3=cLd2
0<W9b@<0b<S80P32`/8208f=S@80GEeM0P1QHF4206][J`80IFEU0`1QHF4205IFEP80De=C0P10@402
03De=@80<c<c0P0`<303034a<@80;Bd]0P0_;bl20492@P80AdM70P1OGel207=cL`<0Jf][0P17AdL2
03@d=080G5aL0P1RHV8205YJFP80B4Q81@12@T8205YJFP80K6a/0P1:BTX203De=@80EeMG0P2a/K43
0<o?c`@0c<c<0P3>c/h20<_;b`80b<S80P2o_kl30:^[Z`80P8200P1HF5P204I6AP80F5QH0P1lO7`2
07QhN0<0GUiN0P1JFUX206a/K080MgMg0P1bLW82071`L080LG5a0`1cLg<207QhN080Ng]k0P21PH42
08J6QP80QhN70P28R8P308^;R`80SHf=0P2ATI4209VIV@P0b>3H00060<SPf080:2PX0P0e=CD202/[
:`D0;2`/0P0d=3@206IVIP80SHf=0P19BDT2034a<@<0?Cdm0P0e=CD202TY:@809bLW0P0Y:BT202PX
:0D0;Rh^0P0_;bl202`/;080>SXj100b<S8202XZ:P<0:b/[0P0Z:RX203@d=080>SXj0P0d=3@202XZ
:P80:BTY0P0_;bl304U9B@80Bd];0P0i>CT203/k>`80M7Ad0P2HV9P208j>SP<0IfMW0P1LG5`208b<
S080`/;20P39bLT20;Bd]080Y:BT0`2_[jl20;Jf]P80/k>c102i^KT20;Rh^080]kNg0`30`<020<c<
c080clo?0P3;bl/20<O7a`@0bLW90`34a<@20<W9b@80_Kfm0P1jNWX2051@D080Fe]K0P1NGUh305IF
EP80DE5A0P14A4@403Ph>080=CDe0P0c<c<302XZ:P80;Rh^0P0d=3@203Ph>080ATI60P1LG5`206MW
I`<0FUYJ0P0b<S8203Ti>@80GUiN0P1MGEd204a<C080<30`0`0Y:BT202/[:`80ADE50P1`L70204e=
C@80>3Ph0P12@T8209fMW@D0c<c<1P36a/H20<71`@80[:b/0`2@T902069RHP80ATI60P14A4@205eM
G@80Ph>30P1^KVh305ADE080Fe]K0P1dM7@207YjNP80MGEe0P1dM7@2075aL@<0Lg=c0P28R8P208:2
PP80Q8B40P29RHT208^;R`80RHV90`2@T90208b<S080Shn?0P2IVIT80<SPf0001P38h=P202PX:080
=CDe0P0[:b/502`/;080=3@d0P1VIVH208f=S@80BDU90P0a<C4303dm?@80=CDe0P0Y:BT202LW9`80
:BTY0P0X:2P502h^;P80;bl_0P0/;2`203Xj>P@0<S8b0P0Z:RX302/[:`80:RXZ0P0d=3@203Xj>P80
=3@d0P0Z:RX202TY:@80;bl_0`19BDT204];B`80>CTi0P0k>c/207AdM080V9RH0P2>SXh306MWI`80
G5aL0P2<S8`20<;2`P80bLW90P2d];@20:BTY0<0[jn_0P2f][H20;>c/`@0^KVi0P2h^;P20;Ng]`<0
`<300P3<c<`20<o?c`80bl_;0P37alL40<W9b@<0a<C40P39bLT20;fm_@80NWYj0P1@D50205]KF`80
GUiN0`1FEUH2055AD@80A4A4100h>3P203De=@80<c<c0`0Z:RX202h^;P80=3@d0P0h>3P204I6AP80
G5aL0P1WIfL305YJFP80<S8b0P0i>CT205iNGP80GEeM0P1<C4`2030`<0<0:BTY0P0[:b/204E5A@80
L71`0P1=CDd203Ph>080@T920P2MWId50<c<c0H0a/K60P31`L420:b/[0<0T92@0P1RHV8204I6AP80
A4A40P1MGEd208>3P`80KVi^0`1DE5@205]KF`80M7Ad0P1jNWX207EeM@80M7Ad0P1aLG4307=cL`80
R8R80P22PX8208B4Q080RHV90P2;Rh/208V9R@<0T92@0P2<S8`208n?S`80VIVI2038h=P000H0b>3H
0P0W9bL203Ph>080;Rh^0`0W9bL202`/;080?Shn0P1jNWX207emO@80?clo0P0[:b/303De=@80:b/[
0P0/;2`202PX:080:RXZ0P0[:b/202TY:@<0<c<c0P0`<30202l_;`80<C4a0P0^;Rh202l_;`D0:b/[
0P0];Bd20410@080B4Q80P11@D4203Ph>080>SXj0P0U9BD302HV9P809bLW0P0Q8B4202DU9@80DU9B
0P2=SHd20:6QX@<0OWin0P1PH60206a/K080W9bL0P36a/H20;fm_@80Y:BT0`2][Jd20:n_[`80/K6a
0P2g]kL20;:b/P80/K6a0P2g]kL30;Vi^@80`l?30P3>c/h20<_;b`80b/[:0P37alL20<71`@<0b<S8
0P35aLD20<_;b`80]kNg0P1[Jf/2055AD@80DU9B0`1HF5P205EEE@80CTi>0P14A4@203Ph>080<C4a
0P0e=CD302`/;080:RXZ0P0/;2`203<c<`80@D510P1BDU8205YJFP<0DE5A0P0b<S8203`l?080D51@
0P1?Cdl2030`<0809RHV0`0T92@202LW9`80>3Ph0P1JFUX20451@@80<S8b0P18B4P20:>SX`D0c<c<
0P37alL40<30`080^KVi0P2;Rh/306][J`80B4Q80P0l?3`203hn?P80J6QX0P1/K6`205ADE0<0Bd];
0P1TI6@207]kN`80O7al0P1hN7P207YjNP80MgMg0`1iNGT20820P080QhN70P22PX8208N7Q`@0Rh^;
0`2FUYH208f=S@80TI6A0P2JVYX80<SPf0001P38h=P202LW9`80>3Ph0P0^;Rh302LW9`80;2`/0P0n
?Sh207YjNP80OGem0P0o?cl202/[:`<0=CDe0P0[:b/202`/;080:2PX0P0Z:RX202/[:`80:BTY0`0c
<c<2030`<080;bl_0P0a<C4202h^;P80;bl_1@0[:b/202d];@80@4100P18B4P20451@@80>3Ph0P0j
>SX202DU9@<09RHV0P0W9bL2024Q8@809BDU0P1BDU8208f=S@80XJ6Q0`1nOWh2061PH080K6a/0P2L
W9`20<K6aP80_Kfm0P2TY:@30:f][@80[jn_0P2a/K420;Ng]`80/[:b0P2a/K420;Ng]`<0^KVi0P33
`l<20<k>cP80bl_;0P3:b/X20<O7a`80`L710`38b<P20<G5a@80bl_;0P2g]kL206][J`80DE5A0P1B
DU8305QHF080EEEE0P1>CTh204A4A080>3Ph0P0a<C4203De=@<0;2`/0P0Z:RX202`/;080<c<c0P11
@D42059BDP80FUYJ0`1ADE42038b<P80?3`l0P1@D50204m?C`80<30`0P0V9RH302@T90809bLW0P0h
>3P205YJFP80@D510P0b<S8204Q8B080Xj>S1@3<c<`20<O7a`@0`<300P2i^KT208^;R`<0Jf][0P18
B4P203`l?080?Shn0P1XJ6P206a/K080E5AD0`1;Bd/206ATI080Ng]k0P1lO7`207QhN080NWYj0P1g
MgL307UiN@80P8200P27QhL208:2PP80QhN7102;Rh/309JFUP80SHf=0P2ATI4209ZJVPP0b>3H0006
0<SPf080;2`/0P0`<30202d];@<0;Rh^0P0`<30204M7A`80P8200P1UIFD202XZ:P80;bl_0`0];Bd4
034a<@80;Rh^0P0[:b/2038b<P80;bl_0`0[:b/202d];@80<30`0P0b<S8403/k>`80;Bd]0`0c<c<2
03lo?`80D51@0P1JFUX205EEE@80<S8b0P0Z:RX202LW9`<08R8R0P0Q8B4201lO7`808B4Q0P0b<S82
079bLP80V9RH0`2LW9`206][J`80GemO0P1iNGT20;6a/@80b<S80P2`/;030:BTY080Z:RX0P2/[:`2
0;>c/`80]KFe0P2_[jl20;Fe]@<0^;Rh0P2f][H20<[:bP80c/k>0P39bLT20<O7a`80`L711`35aLD2
0<C4a080[jn_0P1YJFT204a<C0<0D51@0P1GEeL205EEE@80C4a<0P14A4@203`l?080<S8b0`0Z:RX2
02TY:@80:RXZ0P0c<c<203De=@80?Cdm0P1=CDd304=3@`80:b/[0P0_;bl203hn?P80?3`l0P0];Bd2
02LW9`<092@T0P0X:2P205QHF080EeMG0P11@D4205IFEP80NGUi0P2^[Zh30<[:bP80c<c<0P2o_kl2
0;2`/080Xj>S0P2JVYX2065QH@<0ADE5100[:b/203/k>`80C4a<0P1:BTX203lo?`<0Cdm?0P1]KFd2
07]kN`80PX:20P1lO7`207UiN@80MWIf0`1iNGT20820P080RXZ:0P26QXH208b<S080Rh^;0P2BTY83
092@T080TI6A0P2DU9@209VIV@P0b>3H00060<SPf080;2`/0P0`<30202d];@<0;Rh^0P0`<30204M7
A`80P8200P1UIFD202XZ:P80;bl_0`0];Bd4034a<@80;Rh^0P0[:b/2038b<P80;bl_0`0[:b/202d]
;@80<30`0P0b<S8403/k>`80;Bd]0`0c<c<203lo?`80D51@0P1JFUX205EEE@80<S8b0P0Z:RX202LW
9`<08R8R0P0Q8B4201lO7`808B4Q0P0b<S82079bLP80V9RH0`2LW9`206][J`80GemO0P1iNGT20;6a
/@80b<S80P2`/;030:BTY080Z:RX0P2/[:`20;>c/`80]KFe0P2_[jl20;Fe]@<0^;Rh0P2f][H20<[:
bP80c/k>0P39bLT20<O7a`80`L711`35aLD20<C4a080[jn_0P1YJFT204a<C0<0D51@0P1GEeL205EE
E@80C4a<0P14A4@203`l?080<S8b0`0Z:RX202TY:@80:RXZ0P0c<c<203De=@80?Cdm0P1=CDd304=3
@`80:b/[0P0_;bl203hn?P80?3`l0P0];Bd202LW9`<092@T0P0X:2P205QHF080EeMG0P11@D4205IF
EP80NGUi0P2^[Zh30<[:bP80c<c<0P2o_kl20;2`/080Xj>S0P2JVYX2065QH@<0ADE5100[:b/203/k
>`80C4a<0P1:BTX203lo?`<0Cdm?0P1]KFd207]kN`80PX:20P1lO7`207UiN@80MWIf0`1iNGT20820
P080RXZ:0P26QXH208b<S080Rh^;0P2BTY83092@T080TI6A0P2DU9@209VIV@P0b>3H00060<SPf080
<C4a0P0`<30203Ph>0<0@4100P0c<c<204m?C`80SHf=0P1CDe<202PX:080;Rh^1@0/;2`202l_;`80
:b/[0P0X:2P202TY:@80:2PX0`0U9BD202/[:`80=3@d0P18B4P206MWI`80H61P0P1:BTX305YJFP80
De=C0P1]KFd205iNGP80;bl_0P0Y:BT202XZ:P80:2PX0`0S8b<202DU9@808R8R0P0P820202HV9P80
De=C0P2<S8`309nOW`80QHF5101UIFD209:BTP80`l?30P36a/H30:^[Z`80[:b/0P2VYZH20:n_[`80
/[:b0P2^[Zh50;Fe]@80];Bd0P34a<@20<W9b@80b/[:0P34a<@20<O7a`<0aLG50P30`<020;jn_P80
`<300P38b<P20:j^[P80HF5Q0`14A4@204Q8B080D51@101;Bd/204I6AP80>SXj0`0Y:BT202l_;`80
<C4a0P0`<302034a<@80<30`1@0e=CD202l_;`80:b/[0P0f=SH2034a<@80<S8b0P0X:2P302h^;P80
<30`0P1<C4`203hn?P80ADE50P1NGUh20820P080XZ:R0`31`L420<30`080[jn_0P2EUID207MgM`80
HV9R0P0k>c/302XZ:P809bLW0P0V9RH202LW9`80:RXZ0P0/;2`203<c<`<0DE5A0P1^KVh20861P@80
QhN70P21PH4207inOP80OGem0`20P80207inOP80QhN70P28R8P208F5Q@80SXj>0P2<S8`309>CT`80
UIFE0P2HV9P209VIV@P0b>3H00060<SPf080<C4a0P0`<30203Ph>0<0@4100P0c<c<204m?C`80SHf=
0P1CDe<202PX:080;Rh^1@0/;2`202l_;`80:b/[0P0X:2P202TY:@80:2PX0`0U9BD202/[:`80=3@d
0P18B4P206MWI`80H61P0P1:BTX305YJFP80De=C0P1]KFd205iNGP80;bl_0P0Y:BT202XZ:P80:2PX
0`0S8b<202DU9@808R8R0P0P820202HV9P80De=C0P2<S8`309nOW`80QHF5101UIFD209:BTP80`l?3
0P36a/H30:^[Z`80[:b/0P2VYZH20:n_[`80/[:b0P2^[Zh50;Fe]@80];Bd0P34a<@20<W9b@80b/[:
0P34a<@20<O7a`<0aLG50P30`<020;jn_P80`<300P38b<P20:j^[P80HF5Q0`14A4@204Q8B080D51@
101;Bd/204I6AP80>SXj0`0Y:BT202l_;`80<C4a0P0`<302034a<@80<30`1@0e=CD202l_;`80:b/[
0P0f=SH2034a<@80<S8b0P0X:2P302h^;P80<30`0P1<C4`203hn?P80ADE50P1NGUh20820P080XZ:R
0`31`L420<30`080[jn_0P2EUID207MgM`80HV9R0P0k>c/302XZ:P809bLW0P0V9RH202LW9`80:RXZ
0P0/;2`203<c<`<0DE5A0P1^KVh20861P@80QhN70P21PH4207inOP80OGem0`20P80207inOP80QhN7
0P28R8P208F5Q@80SXj>0P2<S8`309>CT`80UIFE0P2HV9P209VIV@P0b>3H00060<SPf080;bl_0P0j
>SX2059BDP<0EUIF0P0e=CD205aLG080QhN70P17AdL202DU9@80;Bd]0`0d=3@2038b<P80;2`/0P0U
9BD202/[:`80:BTY0P0[:b/302XZ:P80<30`0P0n?Sh206i^KP80NWYj0P1`L70206e]K@<0IVIV0P1B
DU8203/k>`80:b/[100W9bL202d];@80:BTY1@0R8R8202HV9P@08B4Q0P0c<c<206YZJP<0Ti>C0P2V
YZH2075aL@80GemO0P1nOWh20:b/[080bLW90`2m_Kd20:NWY`80ZJVY0P2ZZZX20:^[Z`80[jn_0P2c
/k<50;Vi^@80a<C40P39bLT20<g=c@80b/[:0P32`/830<C4a0@0_[jn0P33`l<20<71`@80aLG50P2V
YZH305UIF@80@d=30P1;Bd/204U9B@80?Shn0P0k>c/20492@P<0<c<c100`<30203@d=080;bl_100`
<30302l_;`80=cLg0P0_;bl203<c<`80<30`0P0^;Rh202`/;0<0;Rh^0P0_;bl202`/;080<S8b0P0h
>3P204I6AP80FUYJ0P2:RXX30::RXP80UYJF0P2>SXh206QXJ080CTi>0P0h>3P202XZ:PD0:BTY0P0[
:b/202HV9P80:RXZ0P0^;Rh204=3@`<0I6AT0P1eMGD208B4Q080R8R80P24Q8@20861P@80OWin0`20
P80208:2PP80R8R80P2:RXX208^;R`80RXZ:0P2?Shl309:BTP80UYJF0P2DU9@209VIV@P0b>3H0006
0<SPf080;bl_0P0j>SX2059BDP<0EUIF0P0e=CD205aLG080QhN70P17AdL202DU9@80;Bd]0`0d=3@2
038b<P80;2`/0P0U9BD202/[:`80:BTY0P0[:b/302XZ:P80<30`0P0n?Sh206i^KP80NWYj0P1`L702
06e]K@<0IVIV0P1BDU8203/k>`80:b/[100W9bL202d];@80:BTY1@0R8R8202HV9P@08B4Q0P0c<c<2
06YZJP<0Ti>C0P2VYZH2075aL@80GemO0P1nOWh20:b/[080bLW90`2m_Kd20:NWY`80ZJVY0P2ZZZX2
0:^[Z`80[jn_0P2c/k<50;Vi^@80a<C40P39bLT20<g=c@80b/[:0P32`/830<C4a0@0_[jn0P33`l<2
0<71`@80aLG50P2VYZH305UIF@80@d=30P1;Bd/204U9B@80?Shn0P0k>c/20492@P<0<c<c100`<302
03@d=080;bl_100`<30302l_;`80=cLg0P0_;bl203<c<`80<30`0P0^;Rh202`/;0<0;Rh^0P0_;bl2
02`/;080<S8b0P0h>3P204I6AP80FUYJ0P2:RXX30::RXP80UYJF0P2>SXh206QXJ080CTi>0P0h>3P2
02XZ:PD0:BTY0P0[:b/202HV9P80:RXZ0P0^;Rh204=3@`<0I6AT0P1eMGD208B4Q080R8R80P24Q8@2
0861P@80OWin0`20P80208:2PP80R8R80P2:RXX208^;R`80RXZ:0P2?Shl309:BTP80UYJF0P2DU9@2
09VIV@P0b>3H00060<SPf080:RXZ0P0o?cl205EEE@<0?Cdm0P0];Bd205iNGP80PX:20P0h>3P402`/
;0<0:RXZ0P0X:2P202HV9P@092@T0P0Y:BT202DU9@<0:RXZ0P11@D4206UYJ@@0NGUi0P1bLW8206MW
I`<0B4Q80P0X:2P202@T9080:BTY0P0V9RH202LW9`80;Bd]0P0_;bl302DU9@80:BTY0P0W9bL2028R
8P808B4Q0P0S8b<204E5A@<0P8200P2QXJ4209FEU@@0I6AT0P2@T9020;Vi^@<0a/K60P2_[jl20:NW
Y`80Y:BT0P2/[:`20;6a/@80/;2`1@2h^;P20<;2`P80aLG50P3=cLd20<[:bP80`l?30`32`/820<30
`080_Kfm102o_kl20;fm_@80aLG50`2WYjL205iNGP80BTY:1011@D4404=3@`<0>CTi0P0e=CD2038b
<P80;bl_0P0`<30403De=@<0<c<c0P0e=CD203Lg=`80<c<c0P0e=CD202d];@80;2`/0`0Z:RX202l_
;`80;Rh^0P0_;bl2030`<080Cdm?0P12@T82069RHP<0MgMg0P1_Kfl205aLG080ATI60P0i>CT202h^
;P80:RXZ0`0W9bL202h^;P80:BTY0P0V9RH202h^;P80?3`l0P1FEUH307=cL`80PH610P2;Rh/408N7
Q`80Ph>30P1mOGd508:2PP80QHF5102=SHd2092@T080UiNG0`2CTi<209BDU080VIVI0P2MWId80<SP
f0001P38h=P202XZ:P80?clo0P1EEED303dm?@80;Bd]0P1NGUh208:2PP80>3Ph100/;2`302XZ:P80
:2PX0P0V9RH402@T9080:BTY0P0U9BD302XZ:P80@D510P1YJFT407UiN@80LW9b0P1WIfL304Q8B080
:2PX0P0T92@202TY:@809RHV0P0W9bL202d];@80;bl_0`0U9BD202TY:@809bLW0P0R8R82024Q8@80
8b<S0P15ADD30820P080XJ6Q0P2EUID406ATI080T92@0P2i^KT30<K6aP80[jn_0P2WYjL20:BTY080
[:b/0P2a/K420;2`/0D0^;Rh0P32`/820<G5a@80cLg=0P3:b/X20<?3``<0`/;20P30`<020;fm_@@0
_kno0P2m_Kd20<G5a@<0YjNW0P1NGUh204Y:BP@0@D511013@d<303Ti>@80=CDe0P0b<S8202l_;`80
<30`100e=CD303<c<`80=CDe0P0g=cL203<c<`80=CDe0P0];Bd202`/;0<0:RXZ0P0_;bl202h^;P80
;bl_0P0`<30204m?C`80@T920P1RHV8307MgM`80Kfm_0P1LG5`204I6AP80>CTi0P0^;Rh202XZ:P<0
9bLW0P0^;Rh202TY:@809RHV0P0^;Rh203`l?080EUIF0`1cLg<20861P@80Rh^;1027QhL208>3P`80
OGem1@22PX8208F5Q@@0SHf=0P2@T90209NGU`<0Ti>C0P2DU9@209VIV@80WIfM2038h=P000H0b>3H
0P0Z:RX203lo?`80EEEE0`0m?Cd202d];@80GUiN0P22PX8203Ph>0@0;2`/0`0Z:RX202PX:0809RHV
100T92@202TY:@809BDU0`0Z:RX20451@@80JFUY101iNGT2079bLP80IfMW0`18B4P202PX:08092@T
0P0Y:BT202HV9P809bLW0P0];Bd202l_;`<09BDU0P0Y:BT202LW9`808R8R0P0Q8B4202<S8`80ADE5
0`20P8020:6QX@80UIFE101TI6@2092@T080^KVi0`36a/H20:n_[`80YjNW0P2TY:@20:b/[080/K6a
0P2`/;050;Rh^080`/;20P35aLD20<g=c@80b/[:0P33`l<30<;2`P80`<300P2m_Kd40;no_`80_Kfm
0P35aLD30:NWY`80GUiN0P1:BTX40451@@@0@d=30`0i>CT203De=@80<S8b0P0_;bl2030`<0@0=CDe
0`0c<c<203De=@80=cLg0P0c<c<203De=@80;Bd]0P0/;2`302XZ:P80;bl_0P0^;Rh202l_;`80<30`
0P1?Cdl20492@P80HV9R0`1gMgL206m_K`80G5aL0P16ATH203Ti>@80;Rh^0P0Z:RX302LW9`80;Rh^
0P0Y:BT202HV9P80;Rh^0P0l?3`205IFEP<0Lg=c0P21PH4208^;R`@0QhN70P23Ph<207emO@D0PX:2
0P25QHD408f=S@80T92@0P2GUiL309>CT`80U9BD0P2IVIT209fMW@P0b>3H00060<SPf080=cLg0P1F
EUH203Xj>P<0;bl_0P0b<S8205UIF@80Lg=c0P0^;Rh202HV9P80:BTY0`0W9bL202@T90809bLW100U
9BD2020P8080<30`0`0e=CD2071`L080NGUi0P1aLG42079bLP80H61P0P10@40502HV9P8092@T0P0W
9bL202/[:`80;bl_0P0c<c<203@d=0<0:RXZ0P0P820202HV9P80:RXZ0P0K6a/201lO7`809RHV0`1J
FUX2092@T080[Jf]0P1fMWH206MWI`80Ng]k0P2JVYX30<71`@80`l?3102VYZH20:b/[080/;2`0P2]
[Jd30;Jf]P80];Bd0P2i^KT20<C4a080b<S80P3;bl/20<?3``<0`L710P32`/820;Zj^P80_;bl0P2n
_[h20;Vi^@80`/;20`36a/H20::RXP80F5QH0P16ATH20410@080?clo0P1;Bd/303/k>`80=SHf0P0g
=cL203Ti>@80=CDe0P0b<S8203De=@D0=3@d0P0j>SX203<c<`80;bl_0P0b<S8203@d=0<0;Rh^0P0`
<30202h^;P80;bl_0P0/;2`203<c<`80=cLg0P0o?cl305ADE080AdM70P0g=cL203<c<`80;Rh^0P0X
:2P202h^;PD09bLW0P0`<30202PX:080=cLg0P1HF5P206m_K`<0Ph>30P28R8P208V9R@80PH610P20
P80208>3P`80Ng]k0`1nOWh208>3P`80PX:20P2<S8`208n?S`80Rh^;0P2BTY8509BDU080W9bL0P2M
WId80<SPf0001P38h=P203Lg=`80EUIF0P0j>SX302l_;`80<S8b0P1IFET207=cL`80;Rh^0P0V9RH2
02TY:@<09bLW0P0T92@202LW9`@09BDU0P0P8202030`<0<0=CDe0P1`L70207UiN@80LG5a0P1bLW82
061PH080@4101@0V9RH202@T90809bLW0P0[:b/202l_;`80<c<c0P0d=3@302XZ:P80820P0P0V9RH2
02XZ:P806a/K0P0O7al202HV9P<0FUYJ0P2@T9020:f][@80MWIf0P1WIfL207]kN`80VYZJ0`31`L42
0<?3``@0YZJV0P2/[:`20;2`/080[Jf]0`2f][H20;Bd]080^KVi0P34a<@20<S8b080bl_;0P33`l<3
0<71`@80`/;20P2j^[X20;bl_080_[jn0P2i^KT20<;2`P<0a/K60P2RXZ8205QHF080ATI60P10@402
03lo?`80Bd];0`0k>c/203Hf=P80=cLg0P0i>CT203De=@80<S8b0P0e=CD503@d=080>SXj0P0c<c<2
02l_;`80<S8b0P0d=3@302h^;P80<30`0P0^;Rh202l_;`80;2`/0P0c<c<203Lg=`80?clo0`1DE5@2
04M7A`80=cLg0P0c<c<202h^;P80:2PX0P0^;Rh502LW9`80<30`0P0X:2P203Lg=`80F5QH0P1_Kfl3
08>3P`80R8R80P29RHT20861P@80P8200P23Ph<207]kN`<0OWin0P23Ph<208:2PP80S8b<0P2?Shl2
08^;R`80TY:B1@2DU9@209bLW080WIfM2038h=P000H0b>3H0P1:BTX204M7A`80;Bd]0`0`<302034a
<@80Hf=S0P1WIfL202h^;P80:b/[0P0V9RH302/[:`8092@T0P0X:2P202HV9P809bLW0P0[:b/2030`
<0<0G5aL0P1kNg/207alO080KVi^0P1?Cdl2038b<P80;Bd]0`0Z:RX202h^;P80:2PX0P0[:b/202TY
:@80;bl_0P0^;Rh202`/;0<09BDU0P0T92@202`/;080<c<c0P0M7Ad401lO7`<0>CTi0P1hN7P20:2P
X080V9RH0P20P80206e]K@80OGem0`2ZZZX20<_;b`80];Bd0P2WYjL20:f][@80/k>c0P2_[jl30;6a
/@80]kNg0P2k^k/20<C4a080b<S80P3;bl/20<G5a@<0`/;20P2n_[h20;Vi^@80]kNg0P2j^[X20;Bd
]080^k^k0`36a/H20<S8b080WIfM0P1@D5020451@@80AdM70P16ATH304M7A`80A4A40P13@d<203lo
?`80>SXj0P0e=CD203<c<`<0=SHf0P0d=3@203<c<`@0=3@d0P0a<C42038b<P<0;bl_0P0a<C42030`
<080;Rh^0P0b<S8203/k>`80<30`0P0h>3P303Ti>@80=SHf0P11@D4202`/;080;Rh^0P0X:2P202HV
9P<0;2`/0P0Y:BT202XZ:P80>3Ph0P1NGUh208>3P`80RXZ:0`2=SHd408:2PP80Ogmo0P24Q8@207em
O@80OWin0`23Ph<208:2PP80Shn?0P2<S8`208j>SP80T92@0P2ATI4309NGU`80VIVI0P2LW9`209jN
WPP0b>3H00060<SPf080BTY:0P17AdL202d];@<0<30`0P0a<C4206=SH`80IfMW0P0^;Rh202/[:`80
9RHV0`0[:b/202@T9080:2PX0P0V9RH202LW9`80:b/[0P0`<30305aLG080Ng]k0P1lO7`206i^KP80
Cdm?0P0b<S8202d];@<0:RXZ0P0^;Rh202PX:080:b/[0P0Y:BT202l_;`80;Rh^0P0/;2`302DU9@80
92@T0P0/;2`203<c<`807AdM100O7al303Ti>@80N7Qh0P2PX:0209RHV080P8200P1]KFd207emO@<0
ZZZZ0P3;bl/20;Bd]080YjNW0P2][Jd20;>c/`80[jn_0`2a/K420;Ng]`80^k^k0P34a<@20<S8b080
bl_;0P35aLD30<;2`P80_[jn0P2i^KT20;Ng]`80^[Zj0P2d];@20;^k^`<0a/K60P38b<P209fMW@80
D51@0P11@D4204M7A`80ATI60`17AdL204A4A080@d=30P0o?cl203Xj>P80=CDe0P0c<c<303Hf=P80
=3@d0P0c<c<403@d=080<C4a0P0b<S8302l_;`80<C4a0P0`<30202h^;P80<S8b0P0k>c/2030`<080
>3Ph0`0i>CT203Hf=P80@D510P0/;2`202h^;P80:2PX0P0V9RH302`/;080:BTY0P0Z:RX203Ph>080
GUiN0P23Ph<208Z:RP<0SHf=1022PX8207moO`80Q8B40P1mOGd207inOP<0Ph>30P22PX8208n?S`80
S8b<0P2>SXh2092@T080TI6A0`2GUiL209VIV@80W9bL0P2NWYh80<SPf0001P38h=P205QHF080;bl_
0P0/;2`302XZ:P80;bl_0P1MGEd206EUI@80;bl_0P0X:2P202HV9P<08R8R0P0S8b<202HV9P80<C4a
0P0`<30203Xj>P80BDU90`1mOGd207QhN080IFEU0P11@D4202l_;`80:2PX0P0U9BD502/[:`80;2`/
0P0i>CT402l_;`80<30`0P0X:2P302HV9P@092@T0P0W9bL201lO7`809BDU0P0S8b<302PX:080Cdm?
0P2ATI420:2PX080R8R80P1^KVh206IVIP<0SHf=0P2l_;`20<30`080YZJV0P2/[:`20:ZZZP80[Jf]
0`2`/;020;>c/`80^k^k0P33`l<20<K6aP80bl_;0P37alL30<W9b@80`/;20P2k^k/20;Vi^@80^k^k
102f][H30;no_`80aLG50P39bLT209nOW`80FUYJ0P18B4P204i>CP<0EUIF0P1=CDd2051@D080B4Q8
0P17AdL203`l?080=3@d0`0k>c/20410@080>3Ph0P0f=SH203Ti>@80=CDe0P0b<S8303Ph>080<C4a
0P0b<S8203De=@80<c<c100e=CD2038b<P<0<C4a0P0];Bd202/[:`80;Bd]0P0[:b/202TY:@80:2PX
0`0/;2`203De=@80A4A40P1;Bd/206YZJP80RXZ:0P2<S8`308R8R0@0P8200P1jNWX208F5Q@80Ph>3
0P1mOGd307YjNPH0RHV9102BTY8209NGU`<0Vi^K0P2NWYh209bLW080WinO2038h=P000H0b>3H0P1H
F5P202l_;`80;2`/0`0Z:RX202l_;`80GEeM0P1UIFD202l_;`80:2PX0P0V9RH3028R8P808b<S0P0V
9RH2034a<@80<30`0P0j>SX204U9B@<0OGem0P1hN7P206EUI@80@D510P0_;bl202PX:0809BDU1@0[
:b/202`/;080>CTi100_;bl2030`<080:2PX0`0V9RH402@T90809bLW0P0O7al202DU9@808b<S0`0X
:2P204m?C`80TI6A0P2PX:0208R8R080KVi^0P1VIVH308f=S@80_;bl0P30`<020:JVYP80[:b/0P2Z
ZZX20:f][@<0/;2`0P2c/k<20;^k^`80`l?30P36a/H20<_;b`80alO70`39bLT20<;2`P80^k^k0P2i
^KT20;^k^`@0][Jf0`2o_kl20<G5a@80bLW90P2OWil205YJFP80B4Q80P1>CTh305IFEP80CDe=0P1@
D50204Q8B080AdM70P0l?3`203@d=0<0>c/k0P10@40203Ph>080=SHf0P0i>CT203De=@80<S8b0`0h
>3P2034a<@80<S8b0P0e=CD203<c<`@0=CDe0P0b<S83034a<@80;Bd]0P0[:b/202d];@80:b/[0P0Y
:BT202PX:0<0;2`/0P0e=CD204A4A080Bd];0P1ZJVX208Z:RP80S8b<0`28R8P40820P080NWYj0P25
QHD208>3P`80OGem0`1jNWX608V9R@@0TY:B0P2GUiL309^KV`80WYjN0P2LW9`209nOW`P0b>3H0006
0<SPf080@4100P0W9bL202TY:@<0;Bd]0P0f=SH205UIF@80GEeM0P0[:b/202LW9`D09RHV0P0T92@2
02TY:@80;Rh^0P0`<30204=3@`80G5aL0`1fMWH2061PH080>SXj0P0Z:RX202TY:@80;2`/0P0_;bl3
038b<P80;Bd]0P0X:2P202l_;`80;Bd]0P0^;Rh203<c<`80:BTY0`0`<30202HV9P8092@T0P0S8b<2
02PX:080?Cdm0P0Q8B43028R8P809bLW0P1^KVh208n?S`80WinO0P1gMgL206EUI@<0Kfm_0P2RXZ82
0;no_`80^KVi0P2XZ:P40:ZZZP<0/;2`0P2^[Zh20;Jf]P80_kno0P34a<@20<_;b`80c<c<0`3;bl/2
0<O7a`80_;bl0P2i^KT20;Fe]@80[:b/0P2a/K430;Ng]`80_kno0P36a/H20<g=c@80YZJV0P1NGUh2
04m?C`<0DE5A0P1?Cdl205iNGP80EeMG0P1=CDd204E5A@80ATI60`1GEeL205ADE0@0@4100P13@d<2
03hn?P80>CTi0`0k>c/203Ti>@80=SHf0P0b<S8202`/;080<S8b0P0e=CD203`l?0<0=cLg0P0h>3P2
02l_;`80:b/[0P0_;bl4030`<0<0>3Ph0P1CDe<207]kN`80I6AT0P1QHF4207QhN080R8R80`21PH42
07alO080NGUi0P1jNWX207]kN`80O7al0P1gMgL307YjNP80Q8B40P29RHT208b<S080Shn?0P2FUYH2
09ZJVP<0WinO0P2QXJ4209ZJVP80WIfM2038h=P000H0b>3H0P10@40202LW9`80:BTY0`0];Bd203Hf
=P80FEUI0P1MGEd202/[:`809bLW1@0V9RH202@T9080:BTY0P0^;Rh2030`<080@d=30P1LG5`307If
MP80H61P0P0j>SX202XZ:P80:BTY0P0/;2`202l_;`<0<S8b0P0];Bd202PX:080;bl_0P0];Bd202h^
;P80<c<c0P0Y:BT3030`<0809RHV0P0T92@202<S8`80:2PX0P0m?Cd2024Q8@<08R8R0P0W9bL206i^
KP80Shn?0P2OWil207MgM`80IFEU0`1_Kfl20::RXP80_kno0P2i^KT20:RXZ0@0ZZZZ0`2`/;020:j^
[P80][Jf0P2o_kl20<C4a080bl_;0P3<c<`30<_;b`80alO70P2l_;`20;Vi^@80]KFe0P2/[:`20;6a
/@<0]kNg0P2o_kl20<K6aP80cLg=0P2VYZH205iNGP80Cdm?0`1ADE4204m?C`80GUiN0P1GEeL204e=
C@80ADE50P16ATH305MGE`80E5AD1010@40204=3@`80?Shn0P0i>CT303/k>`80>CTi0P0f=SH2038b
<P80;2`/0P0b<S8203De=@80?3`l0`0g=cL203Ph>080;bl_0P0[:b/202l_;`@0<30`0`0h>3P205=C
D`80Ng]k0P1TI6@2065QH@80N7Qh0P28R8P30861P@80O7al0P1iNGT207YjNP80Ng]k0P1lO7`207Mg
M`<0NWYj0P24Q8@208V9R@80S8b<0P2?Shl209JFUP80VYZJ0`2OWil20:6QX@80VYZJ0P2MWId80<SP
f0001P38h=P2034a<@80<30`1@0];Bd203`l?080E5AD0P1NGUh2034a<@80;bl_0P0];Bd302HV9P80
92@T0P0Y:BT203<c<`80?Shn0P1OGel2061PH0<0K6a/0P1GEeL203@d=0809BDU0P0`<30402/[:`<0
;2`/0P0^;Rh202d];@80=3@d0P0Z:RX202h^;P@0:b/[0`0Z:RX202h^;P@09bLW0P14A4@203lo?`80
7QhN0`0M7Ad2028R8P80?Shn0P21PH420::RXP80SHf=0P1ZJVX306UYJ@80O7al0P2`/;020<K6aP80
]KFe0P2TY:@20:ZZZP<0Z:RX0P2][Jd20;6a/@80^k^k0P31`L420<G5a@D0b<S80P3:b/X20<30`080
]KFe0P2c/k<20:VYZ@80[Zj^0`2][Jd20;Ng]`80_Kfm0P36a/H20<[:bP80[Jf]0P1TI6@305ADE080
EEEE0P1OGel2069RHP80H61P0P1TI6@206MWI`<0I6AT0P1PH60204Y:BP80Bd];0P19BDT204=3@`80
DU9B0`19BDT2055AD@80>c/k0P0f=SH202l_;`80>3Ph0P1ADE4206UYJ@<0GUiN0P1;Bd/2030`<080
;Rh^0P13@d<204E5A@80@4100`1DE5@206m_K`80NGUi0P20P80205MGE`80IFEU0P20P80307MgM`80
NWYj0P1eMGD207=cL`@0M7Ad0P1gMgL307YjNP80P8200P26QXH208f=S@80Ti>C0P2IVIT209bLW0<0
WIfM0P2RXZ820:2PX080WIfM2038h=P000H0b>3H0P0a<C42030`<0D0;Bd]0P0l?3`205ADE080GUiN
0P0a<C4202l_;`80;Bd]0`0V9RH202@T9080:BTY0P0c<c<203hn?P80GemO0P1PH60306a/K080EeMG
0P0d=3@202DU9@80<30`100[:b/302`/;080;Rh^0P0];Bd203@d=080:RXZ0P0^;Rh402/[:`<0:RXZ
0P0^;Rh402LW9`80A4A40P0o?cl201hN7P<07AdM0P0R8R8203hn?P80PH610P2RXZ8208f=S@80JVYZ
0`1YJFT207alO080/;2`0P36a/H20;Fe]@80Y:BT0P2ZZZX30:RXZ080[Jf]0P2a/K420;^k^`80`L71
0P35aLD50<S8b080b/[:0P30`<020;Fe]@80/k>c0P2YZJT20:j^[P<0[Jf]0P2g]kL20;fm_@80a/K6
0P3:b/X20:f][@80I6AT0`1DE5@205EEE@80GemO0P1RHV82061PH080I6AT0P1WIfL306ATI080H61P
0P1:BTX204];B`80BDU90P13@d<2059BDP<0BDU90P1ADE4203/k>`80=SHf0P0_;bl203Ph>080DE5A
0P1YJFT305iNGP80Bd];0P0`<30202h^;P80@d=30P15ADD20410@0<0E5AD0P1_Kfl207UiN@80P820
0P1GEeL206EUI@80P8200`1gMgL207YjNP80MGEe0P1cLg<407AdM080MgMg0`1jNWX20820P080QXJ6
0P2=SHd209>CT`80VIVI0P2LW9`309fMW@80XZ:R0P2PX:0209fMW@P0b>3H00060<SPf0@0;2`/0P0a
<C4302XZ:P80<30`0P1KFe/205MGE`80=3@d0P0^;Rh202TY:@<09BDU0P0S8b<202@T9080<30`0P1=
CDd206MWI`80K6a/0`1RHV8203@d=080:2PX0P0[:b/202DU9@80:2PX0P0V9RH302/[:`80=3@d0P0b
<S8202h^;P80;Bd]0P0V9RH202`/;080:RXZ0`0U9BD202PX:080;Bd]0P0k>c/205EEE@809RHV0P0L
71`301hN7P808B4Q0P0/;2`2065QH@80U9BD0P2QXJ4207=cL`<0J6QX0P1[Jf/208b<S080^KVi0P31
`L420;2`/080Y:BT0`2/[:`20:NWY`80/[:b0P2k^k/20;fm_@80`/;20P34a<@30<_;b`80b<S80P33
`l<20;Vi^@80/K6a102XZ:P30:JVYP80/[:b0P2j^[X20;bl_080a<C40P3<c<`20;:b/P<0MGEe0P1E
EED206ATI080H61P0P1XJ6P206a/K080Jf][0`1UIFD205iNGP80GemO0P1RHV8406IVIP80JFUY0`1]
KFd206][J`80EeMG0P0n?Sh202l_;`80ADE50P1_Kfl2096AT@<0Q8B40P1lO7`205=CD`80A4A40P1U
IFD2071`L080BDU90`1WIfL206i^KP80Ng]k0P1lO7`206][J`80GemO0P1eMGD307AdM080Kfm_0P1]
KFd2075aL@80L71`0P1VIVH206e]K@<0NGUi0P21PH4208Z:RP80Ti>C0P2KVi/209nOW`80VYZJ0`2N
WYh40:>SX`80XZ:R2038h=P000H0b>3H100/;2`2034a<@<0:RXZ0P0`<30205]KF`80EeMG0P0d=3@2
02h^;P80:BTY0`0U9BD202<S8`8092@T0P0`<30204e=C@80IfMW0P1/K6`3069RHP80=3@d0P0X:2P2
02/[:`809BDU0P0X:2P202HV9P<0:b/[0P0d=3@2038b<P80;Rh^0P0];Bd202HV9P80;2`/0P0Z:RX3
02DU9@80:2PX0P0];Bd203/k>`80EEEE0P0V9RH201`L70<07QhN0P0Q8B4202`/;080HF5Q0P2DU9@2
0:6QX@80Lg=c0`1XJ6P206][J`80S8b<0P2i^KT20<71`@80/;2`0P2TY:@30:b/[080YjNW0P2b/[82
0;^k^`80_Kfm0P32`/820<C4a0<0bl_;0P38b<P20<?3``80^KVi0P2a/K440:RXZ0<0YZJV0P2b/[82
0;Zj^P80_;bl0P34a<@20<c<c080/[:b0`1eMGD205EEE@80I6AT0P1PH60206QXJ080K6a/0P1[Jf/3
06EUI@80GUiN0P1OGel2069RHP@0IVIV0P1YJFT306e]K@80Jf][0P1GEeL203hn?P80;bl_0P15ADD2
06m_K`80TI6A0`24Q8@207alO080De=C0P14A4@206EUI@80L71`0P19BDT306MWI`80KVi^0P1kNg/2
07alO080Jf][0P1OGel207EeM@<0M7Ad0P1_Kfl206e]K@80LG5a0P1`L70206IVIP80KFe]0`1iNGT2
0861P@80RXZ:0P2CTi<209^KV`80WinO0P2JVYX309jNWP@0Xj>S0P2RXZ880<SPf0001P38h=P2030`
<080;bl_0P0Y:BT302XZ:P80?3`l0P1CDe<2055AD@80<S8b100V9RH302PX:080:RXZ0P0`<302034a
<@80EEEE0P1UIFD206QXJ0<0Fe]K0P0];Bd202LW9`@0:2PX0P0T92@502XZ:P80<30`0P0_;bl402PX
:080:RXZ0P0X:2P2034a<@<0;Bd]0P0h>3P2059BDP80HV9R0P0m?Cd202TY:@808R8R0`0V9RH4024Q
8@80=CDe0P1kNg/209JFUP80VIVI0`1aLG4206e]K@80MgMg0P2NWYh20;bl_080`/;20P2WYjL30:>S
X`80[:b/0P2^[Zh20:n_[`80^;Rh1030`<030<?3``80alO70P35aLD20;^k^`80[:b/0P2SXj<20:6Q
X@<0XZ:R0P2VYZH20;Ng]`80^[Zj0P32`/840<S8b0<0][Jf0P22PX8206ATI080HV9R0P1/K6`4075a
L@<0LW9b0P1hN7P207EeM@80MWIf0P1mOGd207QhN080MGEe0`1lO7`20861P@80KVi^0P1HF5P203<c
<`80FUYJ0P21PH4209FEU@<0TY:B0P2;Rh/207AdM080H61P0P1gMgL207emO@80Fe]K0`1IFET2075a
L@80Lg=c0P1lO7`2075aL@80JFUY0P1TI6@306i^KP80Hf=S0P1MGEd206ATI080HF5Q0P1XJ6P206e]
K@<0NWYj0P25QHD209RHV080W9bL0P2MWId209bLW080WIfM0`2QXJ420:JVYP80Y:BT0P2UYJD80<SP
f0001P38h=P2030`<080;bl_0P0Y:BT302XZ:P80?3`l0P1CDe<2055AD@80<S8b100V9RH302PX:080
:RXZ0P0`<302034a<@80EEEE0P1UIFD206QXJ0<0Fe]K0P0];Bd202LW9`@0:2PX0P0T92@502XZ:P80
<30`0P0_;bl402PX:080:RXZ0P0X:2P2034a<@<0;Bd]0P0h>3P2059BDP80HV9R0P0m?Cd202TY:@80
8R8R0`0V9RH4024Q8@80=CDe0P1kNg/209JFUP80VIVI0`1aLG4206e]K@80MgMg0P2NWYh20;bl_080
`/;20P2WYjL30:>SX`80[:b/0P2^[Zh20:n_[`80^;Rh1030`<030<?3``80alO70P35aLD20;^k^`80
[:b/0P2SXj<20:6QX@<0XZ:R0P2VYZH20;Ng]`80^[Zj0P32`/840<S8b0<0][Jf0P22PX8206ATI080
HV9R0P1/K6`4075aL@<0LW9b0P1hN7P207EeM@80MWIf0P1mOGd207QhN080MGEe0`1lO7`20861P@80
KVi^0P1HF5P203<c<`80FUYJ0P21PH4209FEU@<0TY:B0P2;Rh/207AdM080H61P0P1gMgL207emO@80
Fe]K0`1IFET2075aL@80Lg=c0P1lO7`2075aL@80JFUY0P1TI6@306i^KP80Hf=S0P1MGEd206ATI080
HF5Q0P1XJ6P206e]K@<0NWYj0P25QHD209RHV080W9bL0P2MWId209bLW080WIfM0`2QXJ420:JVYP80
Y:BT0P2UYJD80<SPf0001P38h=P2030`<080;bl_0P0Y:BT302XZ:P80?3`l0P1CDe<2055AD@80<S8b
100V9RH302PX:080:RXZ0P0`<302034a<@80EEEE0P1UIFD206QXJ0<0Fe]K0P0];Bd202LW9`@0:2PX
0P0T92@502XZ:P80<30`0P0_;bl402PX:080:RXZ0P0X:2P2034a<@<0;Bd]0P0h>3P2059BDP80HV9R
0P0m?Cd202TY:@808R8R0`0V9RH4024Q8@80=CDe0P1kNg/209JFUP80VIVI0`1aLG4206e]K@80MgMg
0P2NWYh20;bl_080`/;20P2WYjL30:>SX`80[:b/0P2^[Zh20:n_[`80^;Rh1030`<030<?3``80alO7
0P35aLD20;^k^`80[:b/0P2SXj<20:6QX@<0XZ:R0P2VYZH20;Ng]`80^[Zj0P32`/840<S8b0<0][Jf
0P22PX8206ATI080HV9R0P1/K6`4075aL@<0LW9b0P1hN7P207EeM@80MWIf0P1mOGd207QhN080MGEe
0`1lO7`20861P@80KVi^0P1HF5P203<c<`80FUYJ0P21PH4209FEU@<0TY:B0P2;Rh/207AdM080H61P
0P1gMgL207emO@80Fe]K0`1IFET2075aL@80Lg=c0P1lO7`2075aL@80JFUY0P1TI6@306i^KP80Hf=S
0P1MGEd206ATI080HF5Q0P1XJ6P206e]K@<0NWYj0P25QHD209RHV080W9bL0P2MWId209bLW080WIfM
0`2QXJ420:JVYP80Y:BT0P2UYJD80<SPf0001P38h=P202PX:0809BDU0P0/;2`302TY:@80=3@d0P1<
C4`20410@080=cLg0P0[:b/202LW9`<09RHV0P0`<30202PX:080>3Ph0P1GEeL406IVIP<0C4a<0P0e
=CD202XZ:P808b<S0P0R8R8202`/;080;Bd]0`0/;2`202XZ:P80<C4a0P0X:2P202LW9`80:RXZ0P0c
<c<203De=@<0@d=30P1/K6`206i^KP80@D510P0[:b/2034a<@80;bl_0`0R8R8201hN7P80820P0P0Q
8B4204Y:BP80Ng]k0P2NWYh308j>SP80Ng]k0P1bLW820861P@80Xj>S0P2o_kl20;Vi^@D0Z:RX0P2Y
ZJT20:^[Z`80/[:b0P2h^;P20;fm_@<0`L710P36a/H20<G5a@80_kno0P2e]KD20:VYZ@80VYZJ0`2Q
XJ4209bLW080/K6a0P2e]KD20;jn_P80a<C41@37alL20;fm_@80UIFE0P1/K6`206m_K`80LG5a0P1h
N7P307inOP80OGem0P1kNg/207alO080RXZ:0P27QhL208J6QP<0Q8B40P2:RXX208>3P`80Lg=c0P1?
Cdl207]kN`80Vi^K0P2MWId309^KV`80WIfM0P29RHT2075aL@80Q8B40P29RHT207IfMP<0Fe]K0P1/
K6`206EUI@80JVYZ0P1TI6@205iNGP80EeMG0`1MGEd205YJFP80DE5A0P1JFUX205aLG080HV9R0P1_
Kfl307MgM`80Shn?0P2NWYh20:FUY@80Y:BT102SXj<30:NWY`80ZZZZ0P2RXZ820:FUY@P0b>3H0006
0<SPf080:2PX0P0U9BD202`/;0<0:BTY0P0d=3@204a<C080@4100P0g=cL202/[:`809bLW0`0V9RH2
030`<080:2PX0P0h>3P205MGE`@0IVIV0`1<C4`203De=@80:RXZ0P0S8b<2028R8P80;2`/0P0];Bd3
02`/;080:RXZ0P0a<C4202PX:0809bLW0P0Z:RX203<c<`80=CDe0`13@d<206a/K080KVi^0P11@D42
02/[:`80<C4a0P0_;bl3028R8P807QhN0P0P8202024Q8@80BTY:0P1kNg/209jNWP<0SXj>0P1kNg/2
079bLP80PH610P2SXj<20;no_`80^KVi1@2XZ:P20:VYZ@80Zj^[0P2b/[820;Rh^080_Kfm0`31`L42
0<K6aP80aLG50P2o_kl20;Fe]@80ZJVY0P2JVYX30:6QX@80W9bL0P2a/K420;Fe]@80_[jn0P34a<@5
0<O7a`80_Kfm0P2EUID206a/K080Kfm_0P1aLG4207QhN0<0OWin0P1mOGd207]kN`80O7al0P2:RXX2
08N7Q`80QXJ60`24Q8@208Z:RP80Ph>30P1cLg<204m?C`80Ng]k0P2KVi/209fMW@<0Vi^K0P2MWId2
08V9R@80LG5a0P24Q8@208V9R@80MWIf0`1KFe/206a/K080IFEU0P1ZJVX206ATI080GUiN0P1GEeL3
05eMG@80FUYJ0P1ADE4205YJFP80G5aL0P1RHV8206m_K`<0MgMg0P2?Shl209jNWP80YJFU0P2TY:@4
0:>SX`<0YjNW0P2ZZZX20::RXP80YJFU2038h=P000H0b>3H0P0T92@202TY:@80<C4a0`0V9RH203@d
=080AdM70P0k>c/203hn?P80=cLg0P0^;Rh302XZ:P80;2`/0P0c<c<203Ti>@80Fe]K0P1MGEd2065Q
H@<0?3`l0P0h>3P2030`<0H092@T0P0Y:BT302PX:080:BTY0P0W9bL202XZ:P80<30`0P0a<C4205UI
F@80De=C0`1PH60208F5Q@80DU9B0P0U9BD202/[:`80BDU90P1LG5`302LW9`80820P0P0M7Ad201lO
7`80<S8b0P1RHV8208j>SP<0YjNW0P2FUYH208:2PP80LG5a0P22PX820:RXZ080`l?30`2g]kL20:6Q
X@80Z:RX0P2/[:`20;6a/@80/k>c0P2h^;P30;^k^`80alO70P36a/H20<C4a080^k^k0P2WYjL209JF
UP<0VYZJ0P2IVIT20:RXZ080Zj^[0P2j^[X20;no_`80`L710`35aLD20<O7a`80`<300P2NWYh206m_
K`80KVi^0P1kNg/508:2PP80Ph>30P25QHD208V9R@80TY:B0P2CTi<308j>SP80TY:B0P2:RXX207Ee
M@80NWYj0P2@T9020:FUY@80Xj>S0`2PX:0209^KV`80Shn?0P1oOgl20861P@80RXZ:0P1nOWh305]K
F`80J6QX0P1JFUX205iNGP80EEEE0P1DE5@204m?C`<0Bd];0P1>CTh204Q8B0@0CTi>0P1PH60207If
MP<0QhN70P2FUYH20:JVYP80ZZZZ0P2YZJT20:JVYP80Z:RX0`2WYjL20:^[Z`80ZZZZ0P2][Jd80<SP
f0001P38h=P202@T9080:BTY0P0a<C4302HV9P80=3@d0P17AdL203/k>`80?Shn0P0g=cL202h^;P<0
:RXZ0P0/;2`203<c<`80>CTi0P1KFe/205eMG@80HF5Q0`0l?3`203Ph>080<30`1P0T92@202TY:@<0
:2PX0P0Y:BT202LW9`80:RXZ0P0`<302034a<@80FEUI0P1CDe<3061PH080QHF50P1BDU8202DU9@80
:b/[0P19BDT205aLG0<09bLW0P0P820201dM7@807alO0P0b<S82069RHP80SXj>0`2WYjL209JFUP80
PX:20P1aLG4208:2PP80Z:RX0P33`l<30;Ng]`80XJ6Q0P2XZ:P20:b/[080/K6a0P2c/k<20;Rh^0<0
^k^k0P37alL20<K6aP80a<C40P2k^k/20:NWY`80UYJF0`2JVYX209VIV@80Z:RX0P2[Zj/20;Zj^P80
_kno0P31`L430<G5a@80alO70P30`<0209jNWP80Kfm_0P1^KVh207]kN`D0PX:20P23Ph<208F5Q@80
RHV90P2BTY8209>CT`<0SXj>0P2BTY8208Z:RP80MGEe0P1jNWX2092@T080YJFU0P2SXj<30:2PX080
Vi^K0P2?Shl207moO`80PH610P2:RXX207inOP<0Fe]K0P1XJ6P205YJFP80GUiN0P1EEED205ADE080
Cdm?0`1;Bd/204i>CP80B4Q8101>CTh2061PH080MWIf0`27QhL209JFUP80YZJV0P2ZZZX20:VYZ@80
YZJV0P2XZ:P30:NWY`80Zj^[0P2ZZZX20:f][@P0b>3H00060<SPf0809RHV0P0T92@202l_;`<0<c<c
0P15ADD2065QH@80C4a<0P16ATH203`l?080=cLg0`0m?Cd206=SH`80ATI60P0o?cl205]KF`80G5aL
0P13@d<302LW9`80=CDe0P0k>c/402TY:@80:2PX0P0[:b/302LW9`809BDU0P0Y:BT202<S8`80;Bd]
0P0c<c<204m?C`80GemO0`1VIVH207IfMP80E5AD0P0V9RH202d];@80Fe]K0P1IFET302h^;P80:RXZ
0P0O7al201dM7@8092@T0P0i>CT207EeM@<0VYZJ0P2WYjL208R8R080KVi^0P1XJ6P208n?S`80]kNg
0`33`l<20:b/[080YjNW0P2ZZZX20:f][@@0];Bd0`2n_[h20<;2`P80a/K60P37alL20;no_`80[:b/
0P2SXj<509JFUP80XJ6Q0P2YZJT20;>c/`80_;bl0P2n_[h30<C4a080aLG50P37alL20<71`@80Zj^[
0P1lO7`207AdM0<0N7Qh0P1jNWX208J6QP80RHV90P2>SXh209NGU`80VIVI0`2JVYX209FEU@80SXj>
0P1kNg/209JFUP80WIfM0P2OWil20:>SX`<0X:2P0P2JVYX208^;R`80QHF5101nOWh207=cL`D0HF5Q
0P1FEUH205=CD`@0B4Q80P14A4@503lo?`80@D510P1?Cdl205]KF`80NGUi0P28R8P309FEU@80XJ6Q
0P2WYjL20:^[Z`80YjNW0P2[Zj/20:BTY0<0YjNW102[Zj/20:f][@P0b>3H00060<SPf0809RHV0P0T
92@202l_;`<0<c<c0P15ADD2065QH@80C4a<0P16ATH203`l?080=cLg0`0m?Cd206=SH`80ATI60P0o
?cl205]KF`80G5aL0P13@d<302LW9`80=CDe0P0k>c/402TY:@80:2PX0P0[:b/302LW9`809BDU0P0Y
:BT202<S8`80;Bd]0P0c<c<204m?C`80GemO0`1VIVH207IfMP80E5AD0P0V9RH202d];@80Fe]K0P1I
FET302h^;P80:RXZ0P0O7al201dM7@8092@T0P0i>CT207EeM@<0VYZJ0P2WYjL208R8R080KVi^0P1X
J6P208n?S`80]kNg0`33`l<20:b/[080YjNW0P2ZZZX20:f][@@0];Bd0`2n_[h20<;2`P80a/K60P37
alL20;no_`80[:b/0P2SXj<509JFUP80XJ6Q0P2YZJT20;>c/`80_;bl0P2n_[h30<C4a080aLG50P37
alL20<71`@80Zj^[0P1lO7`207AdM0<0N7Qh0P1jNWX208J6QP80RHV90P2>SXh209NGU`80VIVI0`2J
VYX209FEU@80SXj>0P1kNg/209JFUP80WIfM0P2OWil20:>SX`<0X:2P0P2JVYX208^;R`80QHF5101n
OWh207=cL`D0HF5Q0P1FEUH205=CD`@0B4Q80P14A4@503lo?`80@D510P1?Cdl205]KF`80NGUi0P28
R8P309FEU@80XJ6Q0P2WYjL20:^[Z`80YjNW0P2[Zj/20:BTY0<0YjNW102[Zj/20:f][@P0b>3H0006
0<SPf0809BDU0P0X:2P502LW9`80<c<c0P1=CDd203lo?`80@T920P0j>SX202/[:`<0?Cdm0P1CDe<2
02XZ:P80<c<c0P1:BTX205ADE080=3@d0`0Y:BT203Hf=P80?Shn0P0Z:RX202PX:0808b<S0P0/;2`3
02TY:@80820P0P0X:2P202TY:@80=3@d0P1@D50206IVIP80FEUI0`0m?Cd206UYJ@80HF5Q0P0U9BD2
03<c<`80GEeM0P0j>SX302d];@80?Shn0P0R8R8202PX:0809bLW0P0Z:RX2051@D0<0QHF50P2RXZ82
092@T080LW9b0P1TI6@207=cL`80VYZJ0`2o_kl20;fm_@80YZJV0P2NWYh20:ZZZP80/;2`0P2b/[83
0;Rh^080^k^k0P31`L420<K6aP80a<C40P2c/k<20:JVYP<0Vi^K0P2DU9@209bLW080YJFU0P2XZ:P2
0;:b/P80^k^k0`2m_Kd20<30`080aLG50P33`l<20;fm_@80/K6a0P28R8P307IfMP80NGUi0P23Ph<2
08^;R`@0TI6A0P2HV9P509VIV@80V9RH0P2BTY8209fMW@80XZ:R0P2KVi/209JFUP<0UIFE0P2?Shl2
0861P@80NWYj0P1]KFd2061PH080GEeM0`1BDU8204I6AP80CDe=0P13@d<20451@@80?clo0P0i>CT3
04I6AP80Cdm?0P1IFET206MWI`80PH610P2FUYH20:2PX0<0ZJVY0P2_[jl20:^[Z`80ZZZZ0P2][Jd2
0:^[Z`80Z:RX0`2[Zj/20:ZZZP80Zj^[0P2`/;080<SPf0001P38h=P202DU9@80:2PX1@0W9bL203<c
<`80CDe=0P0o?cl20492@P80>SXj0P0[:b/303dm?@80De=C0P0Z:RX203<c<`80BTY:0P1DE5@203@d
=0<0:BTY0P0f=SH203hn?P80:RXZ0P0X:2P202<S8`80;2`/0`0Y:BT2020P8080:2PX0P0Y:BT203@d
=080D51@0P1VIVH205UIF@<0?Cdm0P1YJFT2065QH@809BDU0P0c<c<205eMG@80>SXj0`0];Bd203hn
?P808R8R0P0X:2P202LW9`80:RXZ0P1@D50308F5Q@80XZ:R0P2@T902079bLP80I6AT0P1cLg<209ZJ
VP<0_kno0P2m_Kd20:JVYP80WYjN0P2ZZZX20;2`/080/[:b0`2h^;P20;^k^`80`L710P36a/H20<C4
a080/k>c0P2VYZH309^KV`80U9BD0P2LW9`20:FUY@80Z:RX0P2b/[820;^k^`<0_Kfm0P30`<020<G5
a@80`l?30P2m_Kd20;6a/@80R8R80`1fMWH207UiN@80Ph>30P2;Rh/4096AT@80V9RH1@2IVIT209RH
V080TY:B0P2MWId20::RXP80Vi^K0P2FUYH309FEU@80Shn?0P21PH4207YjNP80KFe]0P1PH60205eM
G@<0DU9B0P16ATH204e=C@80@d=30P11@D4203lo?`80>CTi0`16ATH204m?C`80FEUI0P1WIfL20861
P@80UYJF0P2PX:030:VYZ@80[jn_0P2[Zj/20:ZZZP80[Jf]0P2[Zj/20:RXZ0<0Zj^[0P2ZZZX20:^[
Z`80/;2`2038h=P000H0b>3H0P0Q8B4202PX:0809bLW0`0V9RH202XZ:P80?3`l0P1<C4`20492@P80
CTi>0P1<C4`303/k>`80=CDe0P0Y:BT203/k>`80Cdm?0P18B4P203De=@<0<30`0P0[:b/203`l?080
;Bd]100W9bL202PX:0<0:RXZ0P0W9bL202XZ:P80;Rh^0P1:BTX206e]K@80H61P0P0c<c<302PX:080
CTi>0P1SHf<202PX:080Bd];0P1LG5`202/[:`<0=SHf0P1>CTh202PX:0808R8R0P0M7Ad202l_;`80
>SXj0`1^KVh208f=S@80WYjN0P21PH4206EUI@80HV9R0P1iNGT309^KV`80_kno0P2a/K420:6QX@80
Zj^[0P2_[jl20;2`/0<0]kNg0P2i^KT20;Zj^P80`l?30P37alL20;fm_@80[jn_0`2KVi/209NGU`80
VYZJ0P2LW9`20:^[Z`80[:b/0P2l_;`30;fm_@80^[Zj0P36a/H40<?3``80`<300P2i^KT309:BTP80
Ng]k0P1mOGd208B4Q080RHV90P2?Shl209JFUP<0W9bL102FUYH409NGU`80U9BD0P2ATI4208b<S0<0
Q8B40P1mOGd207AdM080J6QX0P1LG5`204];B`80@d=30`0k>c/204I6AP@0?Cdm0P14A4@204a<C080
F5QH0`1NGUh2075aL@80Q8B40P2=SHd209^KV`80YjNW0P2YZJT30:n_[`80/;2`0P2][Jd20:n_[`80
]KFe0P2a/K420:j^[P<0[:b/102^[Zh20;6a/@P0b>3H00060<SPf0808B4Q0P0X:2P202LW9`<09RHV
0P0Z:RX203`l?080C4a<0P12@T8204i>CP80C4a<0`0k>c/203De=@80:BTY0P0k>c/204m?C`80B4Q8
0P0e=CD3030`<080:b/[0P0l?3`202d];@@09bLW0P0X:2P302XZ:P809bLW0P0Z:RX202h^;P80BTY:
0P1]KFd2061PH080<c<c0`0X:2P204i>CP80Hf=S0P0X:2P204];B`80G5aL0P0[:b/303Hf=P80CTi>
0P0X:2P2028R8P807AdM0P0_;bl203Xj>P<0KVi^0P2=SHd209jNWP80PH610P1UIFD2069RHP80NGUi
0`2KVi/20;no_`80/K6a0P2QXJ420:^[Z`80[jn_0P2`/;030;Ng]`80^KVi0P2j^[X20<?3``80alO7
0P2m_Kd20:n_[`<0Vi^K0P2GUiL209ZJVP80W9bL0P2[Zj/20:b/[080_;bl0`2m_Kd20;Zj^P80a/K6
1033`l<20<30`080^KVi0`2BTY8207]kN`80OGem0P24Q8@208V9R@80Shn?0P2FUYH309bLW0@0UYJF
102GUiL209BDU080TI6A0P2<S8`308B4Q080OGem0P1dM7@206QXJ080G5aL0P1;Bd/204=3@`<0>c/k
0P16ATH403dm?@80A4A40P1<C4`205QHF0<0GUiN0P1aLG4208B4Q080SHf=0P2KVi/20:NWY`80ZJVY
0`2_[jl20;2`/080[Jf]0P2_[jl20;Fe]@80/K6a0P2^[Zh30:b/[0@0[Zj^0P2a/K480<SPf0001P38
h=P202@T9080:b/[0P0d=3@302<S8`80:RXZ0P0d=3@203De=@80?3`l0P1FEUH20492@P<0<S8b0P0k
>c/203@d=080AdM70P16ATH203Ti>@80;bl_0`0Z:RX202`/;080>SXj0P0g=cL202l_;`80<S8b0P0[
:b/5030`<080;2`/0P12@T82061PH080J6QX0P1>CTh204I6AP<0<S8b0P0l?3`2061PH080;Rh^0P1K
Fe/205=CD`809BDU0`0];Bd205EEE@80<C4a0P0O7al202LW9`809BDU0P0S8b<303hn?P80MGEe0P2G
UiL209nOW`80KVi^0P1KFe/2061PH0<0Ng]k0P2ZZZX20;Vi^@80[Zj^0P2VYZH20:f][@80[:b/0`2d
];@20;:b/P80^;Rh0P30`<020<;2`P80a<C40P2e]KD30:FUY@80VYZJ0P2LW9`209RHV080WinO0P2X
Z:P20;Jf]P<0_;bl0P2k^k/20;fm_@80`/;20P33`l<20<;2`P80`L710`2j^[X209VIV@80NGUi0P1f
MWH207YjNP80PX:20P29RHT3092@T080S8b<0P2>SXh208f=S@80RHV90P1oOgl207UiN@80MGEe0`1^
KVh206][J`80I6AT0P1KFe/2051@D0@0?clo0`14A4@204M7A`80BDU90P1;Bd/205UIF@80JVYZ0P1_
Kfl307YjNP80SHf=0P2NWYh20:FUY@80Z:RX0P2`/;020;>c/`<0/;2`0P2_[jl20;6a/@80/k>c0P2d
];@20;>c/`80];Bd0`2`/;060:b/[0P0b>3H00060<SPf08092@T0P0[:b/203@d=0<08b<S0P0Z:RX2
03@d=080=CDe0P0l?3`205IFEP80@T920`0b<S8203/k>`80=3@d0P17AdL204I6AP80>CTi0P0_;bl3
02XZ:P80;2`/0P0j>SX203Lg=`80;bl_0P0b<S8202/[:`D0<30`0P0/;2`20492@P80H61P0P1XJ6P2
04i>CP80ATI60`0b<S8203`l?080H61P0P0^;Rh205]KF`80De=C0P0U9BD302d];@80EEEE0P0a<C42
01lO7`809bLW0P0U9BD202<S8`<0?Shn0P1eMGD209NGU`80WinO0P1^KVh205]KF`80H61P0`1kNg/2
0:ZZZP80^KVi0P2^[Zh20:JVYP80[Jf]0P2/[:`30;Bd]080/[:b0P2h^;P20<30`080`/;20P34a<@2
0;Fe]@<0YJFU0P2JVYX209bLW080V9RH0P2OWil20:RXZ080][Jf0`2l_;`20;^k^`80_Kfm0P32`/82
0<?3``80`/;20P31`L430;Zj^P80VIVI0P1iNGT207IfMP80NWYj0P22PX8208V9R@<0T92@0P2<S8`2
08j>SP80SHf=0P29RHT207moO`80NGUi0P1eMGD306i^KP80Jf][0P1TI6@205]KF`80D51@100o?cl3
04A4A080AdM70P19BDT204];B`80FEUI0P1ZJVX206m_K`<0NWYj0P2=SHd209jNWP80YJFU0P2XZ:P2
0;2`/080/k>c0`2`/;020:n_[`80/K6a0P2c/k<20;Bd]080/k>c0P2d];@30;2`/0H0[:b/2038h=P0
00H0b>3H100X:2P203Hf=P<0;Rh^0P0W9bL4030`<080;bl_0P0h>3P203Lg=`<0>3Ph0P0d=3@203lo
?`80BTY:0P0i>CT203<c<`80:BTY0`0`<30202l_;`80=SHf0P0i>CT202d];@80:b/[0P0W9bL302l_
;`80B4Q80P16ATH204m?C`80FUYJ0P1BDU82038b<PD0?Cdm0P0d=3@205MGE`80<c<c0P1YJFT204i>
CP809RHV0`0_;bl205aLG080=3@d0P0M7Ad402LW9`80820P0`0Z:RX204a<C080Q8B40P2VYZH208>3
P`80K6a/0P1LG5`306ATI080R8R80P2`/;020;no_`80[Zj^0P2YZJT20:ZZZP<0[:b/0P2_[jl20;Fe
]@80^;Rh0P2n_[h20<;2`P80^k^k0`2YZJT209NGU`80VYZJ0P2HV9P409jNWP80][Jf0`2j^[X40;jn
_P80`/;20P34a<@20<;2`P80`L710`32`/820<71`@80WYjN0P1fMWH206IVIP80J6QX0P1^KVh307If
MP80N7Qh0P1iNGT207MgM`80MGEe0P1/K6`206IVIP80H61P0`1WIfL206EUI@80Fe]K0P1CDe<204e=
C@80EeMG0P1EEED305eMG@80IFEU0P1[Jf/2079bLP80OGem0P25QHD209:BTP<0V9RH0P2OWil20:NW
Y`80[Zj^0P2`/;020;Vi^@D0]KFe0P2`/;020:f][@80/K6a0P2c/k<20;:b/P80/K6a1@2_[jl20:f]
[@80ZZZZ2038h=P000H0b>3H100X:2P203Hf=P<0;Rh^0P0W9bL4030`<080;bl_0P0h>3P203Lg=`<0
>3Ph0P0d=3@203lo?`80BTY:0P0i>CT203<c<`80:BTY0`0`<30202l_;`80=SHf0P0i>CT202d];@80
:b/[0P0W9bL302l_;`80B4Q80P16ATH204m?C`80FUYJ0P1BDU82038b<PD0?Cdm0P0d=3@205MGE`80
<c<c0P1YJFT204i>CP809RHV0`0_;bl205aLG080=3@d0P0M7Ad402LW9`80820P0`0Z:RX204a<C080
Q8B40P2VYZH208>3P`80K6a/0P1LG5`306ATI080R8R80P2`/;020;no_`80[Zj^0P2YZJT20:ZZZP<0
[:b/0P2_[jl20;Fe]@80^;Rh0P2n_[h20<;2`P80^k^k0`2YZJT209NGU`80VYZJ0P2HV9P409jNWP80
][Jf0`2j^[X40;jn_P80`/;20P34a<@20<;2`P80`L710`32`/820<71`@80WYjN0P1fMWH206IVIP80
J6QX0P1^KVh307IfMP80N7Qh0P1iNGT207MgM`80MGEe0P1/K6`206IVIP80H61P0`1WIfL206EUI@80
Fe]K0P1CDe<204e=C@80EeMG0P1EEED305eMG@80IFEU0P1[Jf/2079bLP80OGem0P25QHD209:BTP<0
V9RH0P2OWil20:NWY`80[Zj^0P2`/;020;Vi^@D0]KFe0P2`/;020:f][@80/K6a0P2c/k<20;:b/P80
/K6a1@2_[jl20:f][@80ZZZZ2038h=P000H0b>3H100X:2P203Hf=P<0;Rh^0P0W9bL4030`<080;bl_
0P0h>3P203Lg=`<0>3Ph0P0d=3@203lo?`80BTY:0P0i>CT203<c<`80:BTY0`0`<30202l_;`80=SHf
0P0i>CT202d];@80:b/[0P0W9bL302l_;`80B4Q80P16ATH204m?C`80FUYJ0P1BDU82038b<PD0?Cdm
0P0d=3@205MGE`80<c<c0P1YJFT204i>CP809RHV0`0_;bl205aLG080=3@d0P0M7Ad402LW9`80820P
0`0Z:RX204a<C080Q8B40P2VYZH208>3P`80K6a/0P1LG5`306ATI080R8R80P2`/;020;no_`80[Zj^
0P2YZJT20:ZZZP<0[:b/0P2_[jl20;Fe]@80^;Rh0P2n_[h20<;2`P80^k^k0`2YZJT209NGU`80VYZJ
0P2HV9P409jNWP80][Jf0`2j^[X40;jn_P80`/;20P34a<@20<;2`P80`L710`32`/820<71`@80WYjN
0P1fMWH206IVIP80J6QX0P1^KVh307IfMP80N7Qh0P1iNGT207MgM`80MGEe0P1/K6`206IVIP80H61P
0`1WIfL206EUI@80Fe]K0P1CDe<204e=C@80EeMG0P1EEED305eMG@80IFEU0P1[Jf/2079bLP80OGem
0P25QHD209:BTP<0V9RH0P2OWil20:NWY`80[Zj^0P2`/;020;Vi^@D0]KFe0P2`/;020:f][@80/K6a
0P2c/k<20;:b/P80/K6a1@2_[jl20:f][@80ZZZZ2038h=P000H0b>3H0P0V9RH202/[:`80@D511@0/
;2`202h^;P80>3Ph0P0d=3@203<c<`80>CTi0`0Z:RX203@d=080=CDe0P0j>SX2030`<080:b/[0P0_
;bl302XZ:P80;2`/0P0e=CD203Xj>P80=cLg0P0^;Rh2038b<P<0>3Ph0P0i>CT203De=@80;Rh^0P1:
BTX204I6AP80;bl_0P0[:b/302`/;080>3Ph0P1PH60204U9B@80K6a/0P0n?Sh2030`<0<0<S8b0P1O
Gel20492@P80:RXZ0P0U9BD2020P80807AdM0`0S8b<202/[:`80KFe]0P2;Rh/209VIV@80PX:20P1S
Hf<305eMG@80K6a/0P2?Shl20;Fe]@80`L710P2/[:`20:FUY@<0[:b/0P2^[Zh20;>c/`80/[:b0P2o
_kl20<30`080^k^k0`2][Jd209ZJVP80WIfM0P2IVIT209bLW080WIfM0P2][Jd30;Rh^080_Kfm0P30
`<020<?3``80a<C40P36a/H20<G5a@D0`<300P2o_kl20:ZZZP80N7Qh101EEED305MGE`80F5QH101Q
HF42061PH080IVIV0P1SHf<205]KF`<0H61P0P1XJ6P406ATI080EUIF0P1VIVH206i^KP<0Lg=c0P1j
NWX207alO080QXJ60P2@T90209bLW080Xj>S0`2VYZH20:f][@80[jn_102c/k<40;Jf]P<0]KFe0P2a
/K420;:b/P80/k>c102`/;020:n_[`<0]KFe0P2][Jd20:ZZZP80[jn_2038h=P000H0b>3H0P0V9RH2
02/[:`80@D511@0/;2`202h^;P80>3Ph0P0d=3@203<c<`80>CTi0`0Z:RX203@d=080=CDe0P0j>SX2
030`<080:b/[0P0_;bl302XZ:P80;2`/0P0e=CD203Xj>P80=cLg0P0^;Rh2038b<P<0>3Ph0P0i>CT2
03De=@80;Rh^0P1:BTX204I6AP80;bl_0P0[:b/302`/;080>3Ph0P1PH60204U9B@80K6a/0P0n?Sh2
030`<0<0<S8b0P1OGel20492@P80:RXZ0P0U9BD2020P80807AdM0`0S8b<202/[:`80KFe]0P2;Rh/2
09VIV@80PX:20P1SHf<305eMG@80K6a/0P2?Shl20;Fe]@80`L710P2/[:`20:FUY@<0[:b/0P2^[Zh2
0;>c/`80/[:b0P2o_kl20<30`080^k^k0`2][Jd209ZJVP80WIfM0P2IVIT209bLW080WIfM0P2][Jd3
0;Rh^080_Kfm0P30`<020<?3``80a<C40P36a/H20<G5a@D0`<300P2o_kl20:ZZZP80N7Qh101EEED3
05MGE`80F5QH101QHF42061PH080IVIV0P1SHf<205]KF`<0H61P0P1XJ6P406ATI080EUIF0P1VIVH2
06i^KP<0Lg=c0P1jNWX207alO080QXJ60P2@T90209bLW080Xj>S0`2VYZH20:f][@80[jn_102c/k<4
0;Jf]P<0]KFe0P2a/K420;:b/P80/k>c102`/;020:n_[`<0]KFe0P2][Jd20:ZZZP80[jn_2038h=P0
00H0b>3H0P0S8b<202HV9P80?Cdm0`0b<S8203<c<`80>CTi0P0o?cl203Ti>@80=3@d1`0_;bl203<c
<`80@4100P0b<S8202PX:080<C4a0`0Y:BT202XZ:P80:b/[0P0d=3@202`/;080;Rh^0P0e=CD303<c
<`80=CDe0P0a<C4202`/;080AdM70P0g=cL202XZ:PD0:BTY0P0`<30206EUI@80EEEE0P1/K6`203Ti
>@80:BTY0`0b<S8405]KF`80=cLg0P0b<S8202h^;P80:BTY0`0N7Qh202<S8`80>c/k0P1iNGT208b<
S080X:2P0P1hN7P305mOG`80I6AT0P1bLW8209NGU`80a/K60P2j^[X20:VYZ@<0Zj^[0P2VYZH20:NW
Y`80/;2`102i^KT20;Ng]`<0Zj^[0P2SXj<209ZJVP80Vi^K0P2FUYH209^KV`80Y:BT0`2c/k<20;fm
_@80`l?30P31`L420<30`080`/;20P35aLD30<30`080_[jn0P2k^k/20;Vi^@80/;2`0P29RHT204m?
C`<0ADE50P17AdL205EEE@80FEUI0P1MGEd206EUI@80JVYZ0P1^KVh306QXJ080M7Ad0P1iNGT207em
O@80OWin0P1mOGd208B4Q0<0QhN70P29RHT209BDU080V9RH0P2NWYh40:JVYP<0[:b/0P2a/K420:n_
[`80]KFe102d];@20;Ng]`D0]KFe0P2d];@20:j^[P@0/k>c1@2_[jl20;:b/P80[jn_0P2d];@80<SP
f0001P38h=P202<S8`809RHV0P0m?Cd3038b<P80<c<c0P0i>CT203lo?`80>CTi0P0d=3@702l_;`80
<c<c0P10@402038b<P80:2PX0P0a<C4302TY:@80:RXZ0P0[:b/203@d=080;2`/0P0^;Rh203De=@<0
<c<c0P0e=CD2034a<@80;2`/0P17AdL203Lg=`80:RXZ1@0Y:BT2030`<080IFEU0P1EEED206a/K080
>CTi0P0Y:BT3038b<P@0Fe]K0P0g=cL2038b<P80;Rh^0P0Y:BT301hN7P808b<S0P0k>c/207UiN@80
S8b<0P2PX:0207QhN0<0GemO0P1TI6@2079bLP80UiNG0P36a/H20;Zj^P80ZJVY0`2[Zj/20:JVYP80
YjNW0P2`/;040;Vi^@80]kNg0`2[Zj/20:>SX`80VYZJ0P2KVi/209JFUP80Vi^K0P2TY:@30;>c/`80
_Kfm0P33`l<20<71`@80`<300P32`/820<G5a@<0`<300P2n_[h20;^k^`80^KVi0P2`/;0208V9R@80
Cdm?0`15ADD204M7A`80EEEE0P1IFET205eMG@80IFEU0P1ZJVX206i^KP<0J6QX0P1dM7@207UiN@80
OGem0P1nOWh207emO@80Q8B40`27QhL208V9R@80U9BD0P2HV9P209jNWP@0YZJV0`2/[:`20;6a/@80
[jn_0P2e]KD40;Bd]080]kNg1@2e]KD20;Bd]080[Zj^102c/k<50:n_[`80/[:b0P2_[jl20;Bd]0P0
b>3H00060<SPf0809RHV0P0R8R82030`<0<0=cLg0P0b<S8203De=@80B4Q80P1=CDd204I6AP80?Shn
0`0l?3`2038b<P80?Shn0P13@d<202d];@80:2PX0P0/;2`302PX:0809BDU0P0Z:RX202PX:080;Bd]
0P0a<C42038b<P<0<c<c0P0j>SX203<c<`80;bl_0P1GEeL204M7A`@092@T0`0V9RH202`/;080E5AD
0P1UIFD206a/K080?3`l1@0S8b<204Y:BP80KFe]0P11@D4204E5A@80D51@0P0k>c/302LW9`808B4Q
0P0Z:RX204E5A@80OGem0P2MWId209NGU`<0M7Ad0P1KFe/206EUI@80OGem0P2ZZZX20<K6aP80^KVi
0`2TY:@20:RXZ080YjNW0P2[Zj/40;>c/`80]kNg0`2[Zj/20:JVYP80VYZJ0P2LW9`209JFUP80WIfM
0P2VYZH30;:b/P80^;Rh1P30`<020;jn_P80a/K60`2o_kl20;jn_P80_kno0P2k^k/20;Jf]P80^;Rh
0P2SXj<306e]K@80CTi>0P1:BTX2059BDP80IVIV0P1eMGD206i^KPD0NGUi0P26QXH208V9R@80SXj>
0P2CTi<2096AT@80U9BD1@2HV9P209jNWP80Y:BT0P2[Zj/20:ZZZPD0[Zj^0P2ZZZX20;6a/@80];Bd
0P2`/;020;Bd]080][Jf0`2d];@20;2`/080];Bd102^[Zh20;6a/@80/;2`0`2a/K420;:b/P80[jn_
0P2e]KD80<SPf0001P38h=P202HV9P808R8R0P0`<30303Lg=`80<S8b0P0e=CD204Q8B080CDe=0P16
ATH203hn?P<0?3`l0P0b<S8203hn?P80@d=30P0];Bd202PX:080;2`/0`0X:2P202DU9@80:RXZ0P0X
:2P202d];@80<C4a0P0b<S8303<c<`80>SXj0P0c<c<202l_;`80EeMG0P17AdL402@T90<09RHV0P0/
;2`205ADE080IFEU0P1/K6`203`l?0D08b<S0P1:BTX206e]K@80@D510P15ADD2051@D080>c/k0`0W
9bL2024Q8@80:RXZ0P15ADD207emO@80WIfM0P2GUiL307AdM080Fe]K0P1UIFD207emO@80ZZZZ0P36
a/H20;Vi^@<0Y:BT0P2XZ:P20:NWY`80Zj^[102c/k<20;Ng]`<0Zj^[0P2VYZH209ZJVP80W9bL0P2F
UYH209fMW@80YZJV0`2b/[820;Rh^0H0`<300P2n_[h20<K6aP<0_kno0P2n_[h20;no_`80^k^k0P2f
][H20;Rh^080Xj>S0`1]KFd204i>CP80BTY:0P1BDU8206IVIP80MGEe0P1^KVh507UiN@80QXJ60P29
RHT208j>SP80Ti>C0P2ATI4209BDU0D0V9RH0P2NWYh20:BTY080Zj^[0P2ZZZX50:j^[P80ZZZZ0P2a
/K420;Bd]080/;2`0P2d];@20;Jf]P<0];Bd0P2`/;020;Bd]0@0[Zj^0P2a/K420;2`/0<0/K6a0P2b
/[820:n_[`80]KFe2038h=P000H0b>3H0P0R8R8202TY:@80;bl_0`0c<c<202TY:@80:RXZ0P0b<S82
0410@080FUYJ0P1QHF4305mOG`80D51@0P13@d<204I6AP@0>SXj0P0a<C4302/[:`809bLW0P0/;2`2
02TY:@80:RXZ0P0/;2`203@d=0<0=CDe0P0h>3P202/[:`80<C4a0P1JFUX205QHF080;Bd]0P0S8b<5
02HV9P80?3`l0P1YJFT206=SH`80?Cdm0P0U9BD302@T9080>SXj0P1ZJVX20451@@80;2`/0P0d=3@2
0410@0<0=SHf0P0^;Rh202l_;`80:b/[0P1HF5P208>3P`80YZJV0`29RHT2061PH080GEeM0P1QHF42
08N7Q`80];Bd0P32`/830:n_[`80Xj>S0P2VYZH20;2`/080[:b/0P2c/k<20;:b/P<0[Zj^0P2UYJD2
0:JVYP80Vi^K0P2LW9`209jNWP80YjNW0`2c/k<20;Ng]`80_kno102n_[h20;Zj^P80_kno0`2m_Kd2
0;Vi^@80];Bd0P2i^KT20;Bd]080][Jf0P2e]KD30:FUY@80RHV90P1/K6`206ATI080J6QX0P1lO7`2
07]kN`D0RXZ:0P2>SXh209>CT`80U9BD0P2IVIT20:2PX0D0Xj>S102UYJD20:RXZ080ZJVY0P2VYZH2
0:j^[P<0/K6a0P2_[jl20;:b/P80[jn_0P2`/;040;>c/`<0];Bd0P2b/[820;2`/080/[:b0P2`/;02
0;6a/@80[jn_0`2d];@20;Ng]`80]KFe0P2h^;P80<SPf0001P38h=P2028R8P80:BTY0P0_;bl303<c
<`80:BTY0P0Z:RX2038b<P80@4100P1JFUX2065QH@<0GemO0P1@D50204=3@`80ATI6100j>SX2034a
<@<0:b/[0P0W9bL202`/;080:BTY0P0Z:RX202`/;080=3@d0`0e=CD203Ph>080:b/[0P0a<C4205YJ
FP80F5QH0P0];Bd202<S8`D09RHV0P0l?3`206UYJ@80Hf=S0P0m?Cd202DU9@<092@T0P0j>SX206YZ
JP80@D510P0/;2`203@d=080@4100`0f=SH202h^;P80;bl_0P0[:b/205QHF080Ph>30P2VYZH308V9
R@80H61P0P1MGEd2065QH@80QhN70P2d];@20<;2`P<0[jn_0P2SXj<20:JVYP80/;2`0P2/[:`20;>c
/`80/[:b0`2^[Zh20:FUY@80YZJV0P2KVi/209bLW080WYjN0P2WYjL30;>c/`80]kNg0P2o_kl40;jn
_P80^[Zj0P2o_kl30;fm_@80^KVi0P2d];@20;Vi^@80];Bd0P2f][H20;Fe]@<0YJFU0P29RHT206a/
K080I6AT0P1XJ6P207alO080Ng]k1@2:RXX208j>SP80Ti>C0P2DU9@209VIV@80X:2P1@2SXj<40:FU
Y@80Z:RX0P2YZJT20:JVYP80[Zj^0`2a/K420:n_[`80/[:b0P2_[jl20;2`/0@0/k>c0`2d];@20;:b
/P80/;2`0P2b/[820;2`/080/K6a0P2_[jl30;Bd]080]kNg0P2e]KD20;Rh^0P0b>3H00060<SPf080
9RHV0P0Q8B4202DU9@<0=cLg0P0U9BD202PX:080;bl_0P0h>3P204Q8B080De=C0`1VIVH206i^KP80
EUIF0P1@D50205IFEP80@d=30P0n?Sh3034a<@@0;2`/100];Bd2034a<@80?Shn0`0h>3P203<c<`80
;Bd]0P0[:b/204M7A`80Kfm_0P0_;bl202LW9`<0:2PX0P0V9RH203Ph>080I6AT0P1eMGD203dm?@80
:BTY0`0U9BD202`/;080G5aL0P1VIVH202XZ:P80:b/[0P0`<30303Ph>080<S8b0P0V9RH202@T9080
;Rh^0P1TI6@208j>SP<0VYZJ0P1cLg<205mOG`80FEUI0P1YJFT209BDU080];Bd0`2i^KT20:b/[080
X:2P0P2YZJT20:JVYP80/;2`0P2[Zj/30:j^[P80ZJVY0P2UYJD209nOW`80XJ6Q0P2NWYh20:NWY`<0
/;2`0P2m_Kd20;no_`80_[jn102j^[X20;Vi^@<0_kno0P2l_;`20;Ng]`80/[:b0P2f][H20;:b/P80
/;2`0`2d];@20:b/[080XZ:R0P2<S8`207alO080QHF50P2;Rh/209>CT`<0UiNG0P2FUYH209jNWP80
WinO0P2RXZ820:6QX@80Xj>S0`2TY:@20:NWY`80Y:BT0P2VYZH20:n_[`80ZJVY0P2XZ:P30:j^[P80
/;2`0P2^[Zh40;6a/@80/[:b0P2a/K430;>c/`80][Jf0P2g]kL20:n_[`80]KFe0P2b/[820:n_[`D0
][Jf102g]kL80<SPf0001P38h=P202HV9P808B4Q0P0U9BD303Lg=`809BDU0P0X:2P202l_;`80>3Ph
0P18B4P205=CD`<0IVIV0P1^KVh205IFEP80D51@0P1FEUH204=3@`80?Shn0`0a<C4402`/;0@0;Bd]
0P0a<C4203hn?P<0>3Ph0P0c<c<202d];@80:b/[0P17AdL206m_K`80;bl_0P0W9bL302PX:0809RHV
0P0h>3P206ATI080MGEe0P0m?Cd202TY:@<09BDU0P0/;2`205aLG080IVIV0P0Z:RX202/[:`80<30`
0`0h>3P2038b<P809RHV0P0T92@202h^;P80I6AT0P2>SXh309ZJVP80Lg=c0P1OGel205UIF@80JFUY
0P2DU9@20;Bd]0<0^KVi0P2/[:`20:2PX080ZJVY0P2VYZH20;2`/080Zj^[0`2^[Zh20:VYZ@80YJFU
0P2OWil20:6QX@80WYjN0P2WYjL30;2`/080_Kfm0P2o_kl20;jn_P@0^[Zj0P2i^KT30;no_`80_;bl
0P2g]kL20;:b/P80][Jf0P2b/[820;2`/0<0];Bd0P2/[:`20::RXP80S8b<0P1lO7`208F5Q@80Rh^;
0P2CTi<309NGU`80UYJF0P2NWYh209nOW`80XZ:R0P2QXJ420:>SX`<0Y:BT0P2WYjL20:BTY080YZJV
0P2_[jl20:VYZ@80Z:RX0`2^[Zh20;2`/080[Zj^102a/K420;:b/P80/K6a0`2c/k<20;Jf]P80]kNg
0P2_[jl20;Fe]@80/[:b0P2_[jl50;Jf]P@0]kNg2038h=P000H0b>3H0P0W9bL202TY:@80:RXZ0`0d
=3@203Lg=`808b<S0P0d=3@204M7A`80Bd];0P14A4@304i>CP80J6QX0P1hN7P205MGE`80BDU90P1?
Cdl204Q8B0<0=CDe0P0a<C4202LW9`80:2PX0P0_;bl202PX:080>3Ph0`0m?Cd2034a<@809BDU0P0[
:b/204A4A080LW9b0P0c<c<202XZ:P<0:2PX0P0[:b/203lo?`80GUiN0P1bLW8203hn?P80=SHf0`0Y
:BT202/[:`80@D510P1mOGd203Xj>P80:BTY0P0T92@302d];@80=3@d0P0^;Rh2024Q8@808R8R0P0n
?Sh207IfMP<0S8b<0P2@T90206UYJ@80EUIF0P1IFET2079bLP80T92@0`2i^KT20;Rh^080WinO0P2P
X:040:NWY`80YJFU0`2XZ:P20:ZZZP80YJFU0P2MWId209nOW`80XJ6Q0P2YZJT30:n_[`H0_[jn0P2m
_Kd20;Zj^P80]KFe0`30`<020;Zj^P80]kNg0P2][Jd20:n_[`80/[:b0P2h^;P30:n_[`80[Zj^0P2b
/[820:RXZ080WYjN102EUID209RHV0D0X:2P0P2QXJ440:>SX`80YjNW1@2UYJD20:NWY`80Xj>S0P2W
YjL20:VYZ@80YjNW0P2YZJT50:^[Z`80[Zj^0P2_[jl20;Bd]0@0/K6a0`2_[jl20;6a/@@0/[:b0P2a
/K440;2`/0<0];Bd0P2b/[840;Rh^0P0b>3H00060<SPf0809bLW0P0Y:BT202XZ:P<0=3@d0P0g=cL2
02<S8`80=3@d0P17AdL204];B`80A4A40`1>CTh206QXJ080N7Qh0P1GEeL204U9B@80Cdm?0P18B4P3
03De=@80<C4a0P0W9bL202PX:080;bl_0P0X:2P203Ph>0<0?Cdm0P0a<C4202DU9@80:b/[0P14A4@2
079bLP80<c<c0P0Z:RX302PX:080:b/[0P0o?cl205iNGP80LW9b0P0n?Sh203Hf=P<0:BTY0P0[:b/2
0451@@80OGem0P0j>SX202TY:@8092@T0`0];Bd203@d=080;Rh^0P0Q8B42028R8P80?Shn0P1fMWH3
08b<S080T92@0P1YJFT205IFEP80FEUI0P1bLW82092@T0<0^KVi0P2h^;P209nOW`80X:2P102WYjL2
0:FUY@<0Z:RX0P2ZZZX20:FUY@80WIfM0P2OWil20:6QX@80ZJVY0`2_[jl60;jn_P80_Kfm0P2j^[X2
0;Fe]@<0`<300P2j^[X20;Ng]`80[Jf]0P2_[jl20;:b/P80^;Rh0`2_[jl20:j^[P80/[:b0P2XZ:P2
09jNWP@0UIFE0P2HV9P50:2PX080XJ6Q102SXj<20:NWY`D0YJFU0P2WYjL20:>SX`80YjNW0P2YZJT2
0:NWY`80ZJVY1@2[Zj/20:j^[P80[jn_0P2d];@40;6a/@<0[jn_0P2a/K440;:b/P80/K6a102`/;03
0;Bd]080/[:b102h^;P80<SPf0001P38h=P203Hf=P80=3@d0P0T92@302PX:080?Cdm0P0/;2`203Xj
>P80?clo100k>c/303<c<`80AdM70P1]KFd2075aL@80@T920P0i>CT204I6AP<0=SHf0P0d=3@202DU
9@809bLW0P0^;Rh202`/;080?3`l0`0g=cL202TY:@80:2PX0P0W9bL203Lg=`80Jf][0P1=CDd202LW
9`<0:RXZ0P0/;2`203lo?`@0GEeM0P0j>SX503/k>`80:2PX0P0Z:RX205eMG@80MGEe0P0n?Sh202PX
:0<0;2`/0P0X:2P202DU9@80820P0P0Y:BT202/[:`80BDU90`1hN7P208N7Q`80MGEe0P1SHf<205aL
G080IVIV0P1iNGT309ZJVP80^k^k0P2`/;020:6QX@80X:2P0P2TY:@20:>SX`<0YJFU0P2RXZ8209bL
W0@0WYjN0P2SXj<20:JVYP<0[jn_0P2l_;`20;jn_P80`/;20P2l_;`20;Ng]`80];Bd0`2l_;`20;Ng
]`80^;Rh0P2b/[820:ZZZP80[Zj^0P2i^KT30;Fe]@80[:b/0P2YZJT40:JVYP80YjNW0P2KVi/209RH
V0<0VYZJ0P2QXJ420:BTY080Z:RX0P2RXZ820:BTY080YZJV1@2TY:@20:6QX@80YZJV0P2SXj<20:VY
Z@D0YjNW0P2/[:`20:^[Z`80];Bd0P2b/[820:f][@L0/;2`0P2b/[820;2`/080/[:b0P2d];@50:j^
[P80/K6a0P2f][H20;bl_0P0b>3H00060<SPf080=SHf0P0d=3@202@T90<0:2PX0P0m?Cd202`/;080
>SXj0P0o?cl403/k>`<0<c<c0P17AdL206e]K@80LG5a0P12@T8203Ti>@80ATI60`0f=SH203@d=080
9BDU0P0W9bL202h^;P80;2`/0P0l?3`303Lg=`80:BTY0P0X:2P202LW9`80=cLg0P1[Jf/204e=C@80
9bLW0`0Z:RX202`/;080?clo101MGEd203Xj>PD0>c/k0P0X:2P202XZ:P80GEeM0P1eMGD203hn?P80
:2PX0`0/;2`202PX:0809BDU0P0P820202TY:@80:b/[0P19BDT307QhN080QhN70P1eMGD206=SH`80
G5aL0P1VIVH207UiN@<0VYZJ0P2k^k/20;2`/080XJ6Q0P2PX:020:BTY080Xj>S0`2UYJD20::RXP80
W9bL102NWYh20:>SX`80YZJV0`2_[jl20;bl_080_[jn0P32`/820;bl_080]kNg0P2d];@30;bl_080
]kNg0P2h^;P20;:b/P80ZZZZ0P2^[Zh20;Vi^@<0]KFe0P2/[:`20:VYZ@@0YZJV0P2WYjL209^KV`80
V9RH0`2JVYX20:6QX@80Y:BT0P2XZ:P20::RXP80Y:BT0P2VYZH50:BTY080XJ6Q0P2VYZH20:>SX`80
ZJVY1@2WYjL20:b/[080Zj^[0P2d];@20;:b/P80[Jf]1`2`/;020;:b/P80/;2`0P2b/[820;Bd]0D0
[Zj^0P2a/K420;Jf]P80_;bl2038h=P000H0b>3H0P10@40204m?C`80:b/[0`0T92@203<c<`80=cLg
0P0m?Cd202l_;`80<S8b0P0];Bd302h^;P80=cLg0P12@T8206][J`80J6QX0P1UIFD204M7A`<0=SHf
0P0k>c/202XZ:P809BDU0P0R8R8202/[:`80>c/k0`0g=cL202h^;P809RHV0P0Y:BT203Lg=`80FEUI
0P1TI6@202XZ:P<09BDU0P0Z:RX204M7A`80DE5A0P1HF5P203Ti>@80@4100`13@d<202l_;`809bLW
0P0l?3`207QhN080LG5a0P11@D43030`<0808b<S0P0M7Ad201hN7P@0820P0P0b<S8305=CD`80LW9b
0P1fMWH207inOP80K6a/0P1SHf<206YZJP<0Ph>30P2NWYh20;Bd]080[Zj^0P2RXZ8209fMW@D0XJ6Q
0P2PX:0209nOW`@0XJ6Q0P2PX:020:JVYP<0[Jf]0P2l_;`20;^k^`@0_[jn0P2e]KD20;Ng]`<0^KVi
0P2g]kL20;Bd]080[:b/0P2LW9`20::RXP80][Jf0`2i^KT20;Jf]P80[:b/0P2SXj<20:NWY`80YZJV
0P2TY:@209^KV`D0VYZJ0P2LW9`20:6QX@80YZJV0P2YZJT20:BTY0<0XJ6Q0P2SXj<20::RXP80WYjN
0P2TY:@20:VYZ@80YjNW0`2VYZH20:RXZ080[Jf]0P2`/;020:f][@80[Zj^0P2][Jd30:j^[P80[jn_
0P2a/K420;:b/P@0];Bd0P2a/K430;:b/P80];Bd0P2h^;P20;jn_PP0b>3H00060<SPf080@4100P1?
Cdl202/[:`<092@T0P0c<c<203Lg=`80?Cdm0P0_;bl2038b<P80;Bd]0`0^;Rh203Lg=`80@T920P1[
Jf/206QXJ080IFEU0P17AdL303Hf=P80>c/k0P0Z:RX202DU9@808R8R0P0[:b/203/k>`<0=cLg0P0^
;Rh202HV9P80:BTY0P0g=cL205UIF@80I6AT0P0Z:RX302DU9@80:RXZ0P17AdL2055AD@80F5QH0P0i
>CT20410@0<0@d=30P0_;bl202LW9`80?3`l0P1hN7P2075aL@80@D510`0`<30202<S8`807AdM0P0N
7Qh4020P8080<S8b0`1CDe<2079bLP80MWIf0P1nOWh206a/K080Hf=S0P1ZJVX308>3P`80WYjN0P2d
];@20:j^[P80XZ:R0P2MWId50:6QX@80X:2P0P2OWil40:6QX@80X:2P0P2VYZH30:f][@80_;bl0P2k
^k/40;jn_P80]KFe0P2g]kL30;Vi^@80]kNg0P2d];@20:b/[080W9bL0P2RXZ820;Jf]P<0^KVi0P2f
][H20:b/[080Xj>S0P2WYjL20:JVYP80Y:BT0P2KVi/509ZJVP80W9bL0P2QXJ420:JVYP80ZJVY0P2T
Y:@30:6QX@80Xj>S0P2RXZ8209jNWP80Y:BT0P2YZJT20:NWY`<0YZJV0P2XZ:P20:f][@80/;2`0P2]
[Jd20:j^[P80[Jf]0`2^[Zh20:n_[`80/K6a0P2b/[840;Bd]080/K6a0`2b/[820;Bd]080^;Rh0P2n
_[h80<SPf0001P38h=P20410@080Cdm?0P0[:b/302@T9080<c<c0P0g=cL203dm?@80;bl_0P0b<S82
02d];@<0;Rh^0P0g=cL20492@P80Jf][0P1XJ6P206EUI@80AdM70`0f=SH203/k>`80:RXZ0P0U9BD2
028R8P80:b/[0P0k>c/303Lg=`80;Rh^0P0V9RH202TY:@80=cLg0P1IFET206ATI080:RXZ0`0U9BD2
02XZ:P80AdM70P1ADE4205QHF080>CTi0P10@40304=3@`80;bl_0P0W9bL203`l?080N7Qh0P1aLG42
0451@@<0<30`0P0S8b<201dM7@807QhN100P8202038b<P<0De=C0P1bLW8207IfMP80OWin0P1/K6`2
06=SH`80JVYZ0`23Ph<209jNWP80];Bd0P2^[Zh20::RXP80WIfM1@2QXJ420:2PX080WinO102QXJ42
0:2PX080YZJV0`2][Jd20;bl_080^k^k102n_[h20;Fe]@80]kNg0`2i^KT20;Ng]`80];Bd0P2/[:`2
09bLW080XZ:R0P2f][H30;Vi^@80][Jf0P2/[:`20:>SX`80YjNW0P2VYZH20:BTY080Vi^K1@2JVYX2
09bLW080XJ6Q0P2VYZH20:VYZ@80Y:BT0`2QXJ420:>SX`80XZ:R0P2NWYh20:BTY080ZJVY0P2WYjL3
0:JVYP80Z:RX0P2][Jd20;2`/080[Jf]0P2^[Zh20:f][@<0[Zj^0P2_[jl20;6a/@80/[:b102d];@2
0;6a/@<0/[:b0P2d];@20;Rh^080_[jn2038h=P000H0b>3H0P0j>SX2069RHP80=3@d0`0Y:BT202PX
:080>CTi0P0X:2P202DU9@8092@T0P0W9bL302`/;080=SHf0P0n?Sh204e=C@80Hf=S0P1YJFT2069R
HP<0?clo0P0f=SH203Lg=`80:2PX0P0Y:BT2030`<080>CTi0`0l?3`202h^;P80:b/[0P0/;2`202d]
;@80DU9B0P1TI6@202d];@<09RHV0P0];Bd204Y:BP80?3`l0P0n?Sh203Ti>@80:BTY0`0a<C42038b
<P80;Bd]0P0^;Rh206=SH`80S8b<0P1QHF4302TY:@@07alO0P0M7Ad201lO7`808B4Q0P0X:2P303hn
?P80K6a/0P2>SXh209NGU`80Q8B40P1lO7`2075aL@<0KVi^0P26QXH20:NWY`80_;bl0P2][Jd209fM
W@80WYjN0`2SXj<20:2PX080WinO0P2RXZ820:6QX@80YZJV0P2/[:`30:n_[`80^k^k0P2l_;`20;Zj
^P80^k^k0P2l_;`70;^k^`80/[:b0P2^[Zh2092@T080Shn?0P2[Zj/30;Fe]@80_;bl0P2h^;P20:NW
Y`80ZJVY0P2WYjL20:JVYP80XJ6Q0`2NWYh209ZJVP80Vi^K0P2LW9`20:2PX080YJFU0P2VYZH30:>S
X`80WYjN0P2MWId20:>SX`80XJ6Q0P2VYZH20:6QX@D0Z:RX0P2`/;020:^[Z`80/;2`102][Jd50;2`
/080[Zj^0P2d];@20;Fe]@80][Jf0P2b/[830;Jf]P80^;Rh0P2i^KT20;jn_PP0b>3H00060<SPf080
>SXj0P1RHV8203@d=0<0:BTY0P0X:2P203Ti>@80:2PX0P0U9BD202@T90809bLW0`0/;2`203Hf=P80
?Shn0P1=CDd206=SH`80JFUY0P1RHV8303lo?`80=SHf0P0g=cL202PX:080:BTY0P0`<30203Ti>@<0
?3`l0P0^;Rh202/[:`80;2`/0P0];Bd2059BDP80I6AT0P0];Bd302HV9P80;Bd]0P1:BTX203`l?080
?Shn0P0i>CT202TY:@<0<C4a0P0b<S8202d];@80;Rh^0P1SHf<208b<S080HF5Q0`0Y:BT401lO7`80
7AdM0P0O7al2024Q8@80:2PX0`0n?Sh206a/K080SXj>0P2GUiL208B4Q080O7al0P1aLG4306i^KP80
QXJ60P2WYjL20;bl_080[Jf]0P2MWId209jNWP<0Xj>S0P2PX:0209nOW`80XZ:R0P2QXJ420:JVYP80
[:b/0`2_[jl20;^k^`80_;bl0P2j^[X20;^k^`80_;bl1`2k^k/20;:b/P80[Zj^0P2@T90208n?S`80
Zj^[0`2e]KD20;bl_080^;Rh0P2WYjL20:VYZ@80YjNW0P2VYZH20:6QX@<0WYjN0P2JVYX209^KV`80
W9bL0P2PX:020:FUY@80YZJV0`2SXj<209jNWP80WIfM0P2SXj<20:6QX@80YZJV0P2QXJ450:RXZ080
/;2`0P2[Zj/20;2`/0@0[Jf]1@2`/;020:j^[P80];Bd0P2e]KD20;Jf]P80/[:b0`2f][H20;Rh^080
^KVi0P2n_[h80<SPf0001P38h=P202LW9`80BTY:0P1DE5@3038b<P80<C4a0P0l?3`202XZ:P@09BDU
0P0X:2P303@d=080DU9B0P18B4P203hn?P80>CTi0P1JFUX2069RHP<0De=C0P0m?Cd2038b<P809RHV
0P0X:2P202TY:@80<S8b0`0i>CT203Lg=`80;2`/100Y:BT20410@080IVIV0P0k>c/302LW9`80>c/k
0P1JFUX2034a<@80=3@d0P0b<S8202DU9@<09RHV0P0b<S8204E5A@80=3@d0P1?Cdl207YjNP80De=C
0`0Q8B42020P80808b<S100N7Qh2020P8080<C4a0`1RHV8206MWI`@0SXj>0P2QXJ4208R8R080OGem
0`1ZJVX207AdM080R8R80P2SXj<20;:b/P80YJFU0P2PX:030:BTY080XJ6Q0P2LW9`40::RXP80YJFU
0P2_[jl30;>c/`80`<300P2l_;`20;Zj^P80^KVi0P2k^k/20;Rh^0<0^k^k0P2i^KT20:n_[`80Y:BT
0P2:RXX208B4Q080Zj^[0`2`/;020;Vi^@80`l?30P2h^;P20:j^[P80Z:RX0P2VYZH209nOW`<0W9bL
0P2NWYh209bLW080Vi^K0P2HV9P209jNWP80X:2P1`2NWYh20:>SX`80X:2P0P2RXZ820:JVYP<0YJFU
0P2/[:`20:ZZZP80[Zj^0P2_[jl20:^[Z`D0[:b/0P2`/;040:n_[`@0];Bd0P2c/k<30;Ng]`80][Jf
0P2l_;`20;fm_@P0b>3H00060<SPf0809bLW0P1:BTX205ADE0<0<S8b0P0a<C4203`l?080:RXZ100U
9BD202PX:0<0=3@d0P1BDU8204Q8B080?Shn0P0i>CT205YJFP80HV9R0`1CDe<203dm?@80<S8b0P0V
9RH202PX:080:BTY0P0b<S8303Ti>@80=cLg0P0/;2`402TY:@80@4100P1VIVH203/k>`<09bLW0P0k
>c/205YJFP80<C4a0P0d=3@2038b<P809BDU0`0V9RH2038b<P80ADE50P0d=3@204m?C`80NWYj0P1C
De<3024Q8@80820P0P0S8b<401hN7P80820P0P0a<C43069RHP80IfMW102>SXh20:6QX@80R8R80P1m
OGd306YZJP80M7Ad0P28R8P20:>SX`80/[:b0P2UYJD20:2PX0<0Y:BT0P2QXJ4209bLW0@0XZ:R0P2U
YJD20:n_[`<0/k>c0P30`<020;bl_080^[Zj0P2i^KT20;^k^`80^;Rh0`2k^k/20;Vi^@80[jn_0P2T
Y:@208Z:RP80Q8B40P2[Zj/30;2`/080^KVi0P33`l<20;Rh^080[Zj^0P2XZ:P20:JVYP80WinO0`2L
W9`209jNWP80W9bL0P2KVi/209RHV080WYjN0P2PX:0709jNWP80Xj>S0P2PX:020::RXP80YZJV0`2U
YJD20:b/[080ZZZZ0P2^[Zh20:n_[`80Zj^[1@2/[:`20;2`/0@0[jn_102d];@20;>c/`<0]kNg0P2f
][H20;bl_080_Kfm2038h=P000H0b>3H0P0Y:BT2034a<@80ADE50`0c<c<202LW9`80<30`0P0/;2`2
02HV9P80:BTY0P0d=3@304U9B@80HF5Q0P0k>c/202h^;P80:BTY0P0k>c/205EEE@<0F5QH0P1:BTX2
03Ti>@80;Rh^0P0[:b/202l_;`80>3Ph0`0a<C4203Ti>@80:RXZ0P0/;2`202XZ:P80?3`l0P1OGel2
0451@@<0:b/[0P15ADD205eMG@80<c<c0P0];Bd203Lg=`809bLW0`0[:b/202h^;P80?Cdm0P0f=SH2
04m?C`80IFEU0P0o?cl302@T90807alO0P0Q8B44020P8080;2`/0P1?Cdl307emO@80IfMW0P1OGel2
079bLP80Vi^K0P2QXJ4208N7Q`<0M7Ad0P1_Kfl207YjNP80Q8B40P2[Zj/20:n_[`80Xj>S0`2TY:@2
0::RXP80WIfM102VYZH20:ZZZP80];Bd0`2e]KD20;fm_@80^k^k0P2j^[X20;Jf]P80_kno0P2k^k/3
0;Rh^080/K6a0P2PX:0209RHV080M7Ad0P1mOGd20:VYZ@<0/;2`0P2l_;`20<?3``80`<300P2f][H2
0:n_[`80YZJV0P2RXZ830:6QX@80VIVI0P2GUiL209^KV`80UYJF0P2KVi/209ZJVP<0Vi^K0P2IVIT2
09^KV`80X:2P0P2TY:@20:6QX@80Xj>S0`2UYJD20:VYZ@80ZZZZ0P2][Jd20:ZZZP80ZJVY0P2/[:`3
0:n_[`@0/K6a0P2d];@20;2`/080]kNg0P2e]KD30;Ng]`80]KFe0P2m_Kd20<71`@P0b>3H00060<SP
f080:BTY0P0a<C4204E5A@<0<c<c0P0W9bL2030`<080;2`/0P0V9RH202TY:@80=3@d0`19BDT2065Q
H@80>c/k0P0^;Rh202TY:@80>c/k0P1EEED305QHF080BTY:0P0i>CT202h^;P80:b/[0P0_;bl203Ph
>0<0<C4a0P0i>CT202XZ:P80;2`/0P0Z:RX203`l?080GemO0P11@D4302/[:`80ADE50P1MGEd203<c
<`80;Bd]0P0g=cL202LW9`<0:b/[0P0^;Rh203dm?@80=SHf0P1?Cdl206EUI@80?clo0`0T92@201lO
7`808B4Q100P820202`/;080Cdm?0`1mOGd206MWI`80GemO0P1bLW8209^KV`80XJ6Q0P27QhL307Ad
M080Kfm_0P1jNWX208B4Q080Zj^[0P2_[jl20:>SX`<0Y:BT0P2RXZ8209fMW@@0YZJV0P2ZZZX20;Bd
]0<0]KFe0P2m_Kd20;^k^`80^[Zj0P2f][H20;no_`80^k^k0`2h^;P20;6a/@80X:2P0P2HV9P207Ad
M080OGem0P2YZJT30;2`/080_;bl0P33`l<20<30`080][Jf0P2_[jl20:JVYP80XZ:R0`2QXJ4209VI
V@80UiNG0P2KVi/209JFUP80Vi^K0P2JVYX309^KV`80VIVI0P2KVi/20:2PX080Y:BT0P2QXJ420:>S
X`<0YJFU0P2YZJT20:ZZZP80[Jf]0P2ZZZX20:VYZ@80[:b/0`2_[jl40;6a/@80];Bd0P2`/;020;Ng
]`80]KFe0`2g]kL20;Fe]@80_Kfm0P31`L480<SPf0001P38h=P202TY:@809RHV0P0f=SH303Lg=`80
:2PX0P0Y:BT202/[:`80;2`/0P0c<c<204Q8B0<0J6QX0P1;Bd/203Hf=P809BDU0P0b<S8202h^;P80
?Shn0`1GEeL204i>CP80=CDe0P0d=3@202d];@80?3`l0P0f=SH302l_;`80>c/k0P0Z:RX2030`<080
:RXZ0P0f=SH205UIF@80Bd];0`0b<S8203dm?@80CTi>0P0_;bl2034a<@80=cLg0P0a<C4302h^;P80
@T920P0];Bd203@d=080CTi>0P1CDe<203lo?`D08b<S0P0O7al2020P808092@T0P0c<c<207=cL`<0
QXJ60P1JFUX2034a<@80EUIF0P21PH4209nOW`80U9BD0`1mOGd206m_K`80MgMg0P1jNWX2092@T080
]kNg0P2YZJT309fMW@80XZ:R102UYJD20:^[Z`80[Zj^1@2c/k<20;Zj^P80_[jn0P2j^[X20;Vi^@@0
^k^k0`2j^[X20:j^[P80TY:B0P2JVYX207IfMP80PH610P2/[:`30:^[Z`80^;Rh0P30`<020<;2`P80
_[jn0P2h^;P20:ZZZP80Zj^[0`2QXJ4209fMW@80VIVI0P2LW9`20::RXP80YJFU0P2JVYX309RHV080
Vi^K0P2HV9P40:6QX@80X:2P0P2SXj<30::RXP80Z:RX0P2ZZZX20:j^[P80[Jf]0P2/[:`20:j^[P<0
[Jf]0P2c/k<20:j^[P80/k>c102`/;020;:b/P<0]KFe0P2g]kL20;^k^`80_Kfm2038h=P000H0b>3H
0P0Y:BT202HV9P80=SHf0`0g=cL202PX:080:BTY0P0[:b/202`/;080<c<c0P18B4P306QXJ080Bd];
0P0f=SH202DU9@80<S8b0P0^;Rh203hn?P<0EeMG0P1>CTh203De=@80=3@d0P0];Bd203`l?080=SHf
0`0_;bl203/k>`80:RXZ0P0`<30202XZ:P80=SHf0P1IFET204];B`<0<S8b0P0m?Cd204i>CP80;bl_
0P0a<C4203Lg=`80<C4a0`0^;Rh20492@P80;Bd]0P0d=3@204i>CP80De=C0P0o?cl502<S8`807alO
0P0P820202@T9080<c<c0P1cLg<308J6QP80FUYJ0P0a<C4205IFEP80PH610P2OWil209BDU0<0OGem
0P1_Kfl207MgM`80NWYj0P2@T9020;Ng]`80ZJVY0`2MWId20::RXP@0YJFU0P2[Zj/20:j^[PD0/k>c
0P2j^[X20;jn_P80^[Zj0P2i^KT40;^k^`<0^[Zj0P2^[Zh209:BTP80VYZJ0P1fMWH20861P@80[:b/
0`2[Zj/20;Rh^080`<300P32`/820;jn_P80^;Rh0P2ZZZX20:^[Z`<0XJ6Q0P2MWId209VIV@80W9bL
0P2RXZ820:FUY@80VYZJ0`2HV9P209^KV`80V9RH102QXJ420:2PX080Xj>S0`2RXZ820:RXZ080ZZZZ
0P2^[Zh20:f][@80[:b/0P2^[Zh30:f][@80/k>c0P2^[Zh20;>c/`@0/;2`0P2b/[830;Fe]@80]kNg
0P2k^k/20;fm_@P0b>3H00060<SPf0808b<S0P0X:2P202TY:@<0;Rh^0P0Y:BT402XZ:P80=3@d0P17
AdL206][J`<0GemO0P0k>c/2034a<@80:b/[0P0_;bl2030`<080<c<c0`1=CDd205aLG080ATI60P0f
=SH202d];@80;2`/0P0e=CD303Ph>080>SXj0P0];Bd202`/;080;Rh^0P0c<c<204Y:BP80E5AD0`0_
;bl203@d=080>c/k0P0X:2P202l_;`80;Rh^0P0d=3@3055AD@80EUIF0P0Z:RX2038b<P80CDe=0P1A
DE420451@@<0:b/[0P0X:2P202<S8`80820P0P0[:b/204E5A@80U9BD0`1kNg/204];B`80820P0P0/
;2`206IVIP80QhN70P2PX:03092@T080NWYj0P1gMgL207moO`80P8200P2EUID20;6a/@<0ZZZZ0P2M
WId40:NWY`80[Zj^0P2a/K420:j^[P<0/;2`0P2l_;`20<?3``80^k^k0P2h^;P20;^k^`D0^KVi0P2/
[:`208b<S080Vi^K0P1mOGd208R8R080/;2`0`2][Jd20;6a/@80^[Zj0P30`<020<G5a@80`L710P2f
][H20:n_[`<0ZJVY0P2TY:@20:2PX080W9bL0P2KVi/20:VYZ@80XZ:R0`2CTi<209bLW080WIfM0P2O
Wil209fMW@80ZJVY0P2MWId30:6QX@80Z:RX102YZJT20:^[Z`@0[Zj^0`2][Jd40:j^[P80/k>c102`
/;020;Vi^@D0^;Rh0P2j^[X20<?3``P0b>3H00060<SPf0808b<S0P0X:2P202TY:@<0;Rh^0P0Y:BT4
02XZ:P80=3@d0P17AdL206][J`<0GemO0P0k>c/2034a<@80:b/[0P0_;bl2030`<080<c<c0`1=CDd2
05aLG080ATI60P0f=SH202d];@80;2`/0P0e=CD303Ph>080>SXj0P0];Bd202`/;080;Rh^0P0c<c<2
04Y:BP80E5AD0`0_;bl203@d=080>c/k0P0X:2P202l_;`80;Rh^0P0d=3@3055AD@80EUIF0P0Z:RX2
038b<P80CDe=0P1ADE420451@@<0:b/[0P0X:2P202<S8`80820P0P0[:b/204E5A@80U9BD0`1kNg/2
04];B`80820P0P0/;2`206IVIP80QhN70P2PX:03092@T080NWYj0P1gMgL207moO`80P8200P2EUID2
0;6a/@<0ZZZZ0P2MWId40:NWY`80[Zj^0P2a/K420:j^[P<0/;2`0P2l_;`20<?3``80^k^k0P2h^;P2
0;^k^`D0^KVi0P2/[:`208b<S080Vi^K0P1mOGd208R8R080/;2`0`2][Jd20;6a/@80^[Zj0P30`<02
0<G5a@80`L710P2f][H20:n_[`<0ZJVY0P2TY:@20:2PX080W9bL0P2KVi/20:VYZ@80XZ:R0`2CTi<2
09bLW080WIfM0P2OWil209fMW@80ZJVY0P2MWId30:6QX@80Z:RX102YZJT20:^[Z`@0[Zj^0`2][Jd4
0:j^[P80/k>c102`/;020;Vi^@D0^;Rh0P2j^[X20<?3``P0b>3H00060<SPf080:b/[0P0X:2P502/[
:`80:BTY0P0Z:RX202/[:`80<c<c0P1JFUX206a/K0<0CDe=0P0o?cl203hn?P80?Cdm0P0d=3@202l_
;`80?clo0`11@D4204Q8B080Bd];0P0a<C4202l_;`80:RXZ0P0b<S8303Ti>@80AdM70P0b<S82034a
<@80;2`/0P0`<30203dm?@80DU9B0`0o?cl403Ph>080;bl_0P0X:2P202`/;080>3Ph0`1XJ6P2065Q
H@80;Rh^0P1:BTX2055AD@80C4a<0P18B4P302l_;`809bLW0P0R8R8202@T9080;Rh^0P1^KVh2096A
T@<0JFUY0P0^;Rh201dM7@808b<S0P0f=SH206UYJ@80RXZ:0`2RXZ8208Z:RP80N7Qh0P1jNWX2079b
LP80Ng]k0P2FUYH30;Zj^P80Zj^[102VYZH20:b/[080[Jf]0P2/[:`30;>c/`80_kno0P32`/820;bl
_0@0^[Zj0P2d];@30;Vi^@80[jn_0P29RHT209RHV080QhN70P2;Rh/20:ZZZP<0YZJV0P2][Jd20;Bd
]080_;bl0P35aLD20<W9b@80`<300P2b/[830:b/[080YjNW0P2RXZ820:6QX@80WinO0P2QXJ420:ZZ
ZP<0XZ:R0P2LW9`209JFUP80VIVI0P2KVi/20:6QX@80X:2P0`2LW9`20:>SX`80YZJV0P2YZJT20:ZZ
ZP80Zj^[0P2^[Zh30:ZZZP80[Zj^0P2/[:`20;2`/080Zj^[0P2b/[820;fm_@<0^k^k0P2h^;P20;no
_`80`L712038h=P000H0b>3H0P0[:b/202PX:0D0:b/[0P0Y:BT202XZ:P80:b/[0P0c<c<205YJFP80
K6a/0`1=CDd203lo?`80?Shn0P0m?Cd203@d=080;bl_0P0o?cl30451@@80B4Q80P1;Bd/2034a<@80
;bl_0P0Z:RX2038b<P<0>CTi0P17AdL2038b<P80<C4a0P0/;2`2030`<080?Cdm0P1BDU8303lo?`@0
>3Ph0P0_;bl202PX:080;2`/0P0h>3P306QXJ080HF5Q0P0^;Rh204Y:BP80DE5A0P1<C4`204Q8B0<0
;bl_0P0W9bL2028R8P8092@T0P0^;Rh206i^KP80TI6A0`1YJFT202h^;P807AdM0P0S8b<203Hf=P80
JFUY0P2:RXX30::RXP80RXZ:0P1hN7P207YjNP80LW9b0P1kNg/209JFUP<0^[Zj0P2[Zj/40:JVYP80
[:b/0P2][Jd20:b/[0<0/k>c0P2o_kl20<;2`P80_;bl102j^[X20;Bd]0<0^KVi0P2_[jl208V9R@80
V9RH0P27QhL208^;R`80ZZZZ0`2VYZH20:f][@80];Bd0P2l_;`20<G5a@80bLW90P30`<020;:b/P<0
[:b/0P2WYjL20::RXP80XJ6Q0P2OWil20:6QX@80ZZZZ0`2RXZ8209bLW080UYJF0P2IVIT209^KV`80
XJ6Q0P2PX:0309bLW080Xj>S0P2VYZH20:VYZ@80ZZZZ0P2[Zj/20:j^[P<0ZZZZ0P2^[Zh20:b/[080
/;2`0P2[Zj/20;:b/P80_Kfm0`2k^k/20;Rh^080_kno0P31`L480<SPf0001P38h=P202DU9@809bLW
0P0Y:BT302<S8`80;Bd]0P0X:2P202l_;`80ADE50P1XJ6P205MGE`<0<c<c0P17AdL204];B`80CTi>
0P0e=CD202/[:`80;2`/0`0_;bl203Xj>P80@T921P0a<C42030`<0<0>CTi0P0h>3P203De=@80=SHf
0P0c<c<2038b<P80>CTi0P18B4P304];B`80>SXj0P0i>CT202HV9P809bLW0P0/;2`203Ph>0<0JVYZ
0P1KFe/203`l?080IfMW0P13@d<20492@P80DE5A0`17AdL203Lg=`80<c<c0P0d=3@204m?C`80VYZJ
0P28R8P3055AD@80:RXZ0P0O7al2024Q8@80820P0P11@D4207QhN0<0Rh^;0P2ZZZX208F5Q@80NGUi
0P1`L70207MgM`80PH610`2RXZ820;Jf]P80/k>c1P2ZZZX20:f][@<0^k^k0P2h^;P20;^k^`80_[jn
102d];@20:f][@<0][Jf0P2b/[8209>CT`80VYZJ0P2?Shl209FEU@80YjNW0`2QXJ420:BTY080/[:b
0P2i^KT40<K6aP80aLG50P2l_;`30:j^[P80ZZZZ0P2RXZ820:FUY@80YZJV0P2QXJ420:BTY0<0YZJV
0P2WYjL209NGU`80Ti>C102JVYX209jNWP<0Vi^K0P2UYJD20::RXP80ZJVY0P2UYJD20:RXZ080Zj^[
0`2][Jd20:n_[`80Zj^[0P2][Jd20;Bd]080]KFe0P2h^;P30;Ng]`80_;bl0P2n_[h20<?3``P0b>3H
00060<SPf0809BDU0P0W9bL202TY:@<08b<S0P0];Bd202PX:080;bl_0P15ADD206QXJ080EeMG0`0c
<c<204M7A`80Bd];0P1>CTh203De=@80:b/[0P0/;2`302l_;`80>SXj0P12@T86034a<@80<30`0`0i
>CT203Ph>080=CDe0P0f=SH203<c<`80<S8b0P0i>CT204Q8B0<0Bd];0P0j>SX203Ti>@809RHV0P0W
9bL202`/;080>3Ph0`1ZJVX205]KF`80?3`l0P1WIfL204=3@`80@T920P1ADE4304M7A`80=cLg0P0c
<c<203@d=080Cdm?0P2JVYX208R8R0<0DE5A0P0Z:RX201lO7`808B4Q0P0P82020451@@80N7Qh0`2;
Rh/20:ZZZP80QHF50P1iNGT2071`L080MgMg0P21PH430::RXP80][Jf0P2c/k<60:ZZZP80[Jf]0`2k
^k/20;Rh^080^k^k0P2n_[h40;Bd]080[Jf]0`2f][H20;:b/P80Ti>C0P2JVYX208n?S`80UIFE0P2W
YjL30:6QX@80Y:BT0P2b/[820;Vi^@@0a/K60P35aLD20;bl_0<0[Zj^0P2ZZZX20::RXP80YJFU0P2V
YZH20:6QX@80Y:BT0`2VYZH20:NWY`80UiNG0P2CTi<409ZJVP80WYjN0`2KVi/20:FUY@80XZ:R0P2Y
ZJT20:FUY@80Z:RX0P2[Zj/30:f][@80[jn_0P2[Zj/20:f][@80];Bd0P2e]KD20;Rh^0<0]kNg0P2l
_;`20;jn_P80`l?32038h=P000H0b>3H0P0U9BD202LW9`80:BTY0`0S8b<202d];@80:2PX0P0_;bl2
04E5A@80J6QX0P1GEeL303<c<`80AdM70P1;Bd/204i>CP80=CDe0P0[:b/202`/;0<0;bl_0P0j>SX2
0492@PH0<C4a0P0`<30303Ti>@80>3Ph0P0e=CD203Hf=P80<c<c0P0b<S8203Ti>@80B4Q80`1;Bd/2
03Xj>P80>CTi0P0V9RH202LW9`80;2`/0P0h>3P306YZJP80Fe]K0P0l?3`206MWI`80@d=30P12@T82
055AD@<0AdM70P0g=cL203<c<`80=3@d0P1?Cdl209ZJVP80R8R80`1ADE4202XZ:P807alO0P0Q8B42
020P8080@D510P1hN7P308^;R`80ZZZZ0P25QHD207UiN@80L71`0P1gMgL20861P@<0XZ:R0P2f][H2
0;>c/`H0ZZZZ0P2][Jd30;^k^`80^;Rh0P2k^k/20;jn_P@0];Bd0P2][Jd30;Jf]P80/[:b0P2CTi<2
09ZJVP80Shn?0P2EUID20:NWY`<0XJ6Q0P2TY:@20;:b/P80^KVi1036a/H20<G5a@80_;bl0`2^[Zh2
0:ZZZP80XZ:R0P2UYJD20:JVYP80XJ6Q0P2TY:@30:JVYP80YjNW0P2GUiL209>CT`@0VYZJ0P2NWYh3
09^KV`80YJFU0P2RXZ820:VYZ@80YJFU0P2XZ:P20:^[Z`<0[Jf]0P2_[jl20:^[Z`80[Jf]0P2d];@2
0;Fe]@80^;Rh0`2g]kL20;bl_080_[jn0P33`l<80<SPf0001P38h=P202/[:`809bLW0P0U9BD302`/
;0@0:BTY0P0a<C4204e=C@80KVi^0P19BDT302`/;080<c<c0P0f=SH203Ph>080?Shn0P0c<c<202h^
;P<0;Bd]0P0e=CD203dm?@80AdM70P0`<30202d];@80<c<c0`0g=cL203<c<`80>SXj0P12@T84034a
<@80=cLg0P0k>c/304Q8B080?Cdm0P0e=CD202HV9P8092@T0P0^;Rh204M7A`<0JFUY0P1IFET204i>
CP80I6AT0P0l?3`204];B`80FEUI0`1QHF4205eMG@@0EUIF0P1gMgL20:JVYP80RXZ:0`1NGUh202LW
9`807AdM0P0N7Qh2020P8080:RXZ0P16ATH307IfMP80VYZJ0P2KVi/208>3P`80N7Qh0P1kNg/207Qh
N0<0PH610P2ZZZX20;jn_P80][Jf0P2UYJD20:ZZZP80[:b/0`2i^KT20;>c/`80^;Rh0P2k^k/20;Jf
]P80]KFe0P2/[:`30;Fe]@80/k>c0P2IVIT2096AT@80TY:B0P2HV9P20:NWY`<0X:2P0P2SXj<20:j^
[P80][Jf0P33`l<20<W9b@80alO70P33`l<30;Jf]P80[Jf]0P2UYJD20:NWY`80Z:RX0P2YZJT20:BT
Y0<0WinO0P2PX:020:JVYP80U9BD0P2CTi<209RHV080Vi^K0`2LW9`20:2PX080WinO0P2SXj<20::R
XP80YZJV0P2][Jd30:ZZZP80ZJVY0P2XZ:P20:j^[P80/k>c0P2g]kL20;Bd]0<0^[Zj0P2k^k/20;fm
_@80_kno2038h=P000H0b>3H0P0[:b/202LW9`809BDU0`0/;2`402TY:@80<C4a0P1=CDd206i^KP80
BDU90`0/;2`203<c<`80=SHf0P0h>3P203hn?P80<c<c0P0^;Rh302d];@80=CDe0P0m?Cd204M7A`80
<30`0P0];Bd203<c<`<0=cLg0P0c<c<203Xj>P80@T92100a<C4203Lg=`80>c/k0`18B4P203dm?@80
=CDe0P0V9RH202@T9080;Rh^0P17AdL306UYJ@80FEUI0P1>CTh206ATI080?3`l0P1;Bd/205UIF@<0
HF5Q0P1MGEd405IFEP80MgMg0P2VYZH208Z:RP<0GUiN0P0W9bL201dM7@807QhN0P0P820202XZ:P80
ATI60`1fMWH209ZJVP80Vi^K0P23Ph<207QhN080Ng]k0P1hN7P30861P@80ZZZZ0P2n_[h20;Jf]P80
YJFU0P2ZZZX20:b/[0<0^KVi0P2c/k<20;Rh^080^k^k0P2f][H20;Fe]@80[:b/0`2e]KD20;>c/`80
VIVI0P2ATI4209:BTP80V9RH0P2WYjL30:2PX080Xj>S0P2^[Zh20;Jf]P80`l?30P39bLT20<O7a`80
`l?30`2f][H20:f][@80YJFU0P2WYjL20:RXZ080ZJVY0P2TY:@309nOW`80X:2P0P2VYZH209BDU080
Ti>C0P2HV9P209^KV`<0W9bL0P2PX:0209nOW`80Xj>S0P2RXZ820:JVYP80[Jf]0`2ZZZX20:VYZ@80
Z:RX0P2^[Zh20;>c/`80]kNg0P2d];@30;Zj^P80^k^k0P2m_Kd20;no_`P0b>3H00060<SPf080;Bd]
0P0Y:BT202HV9P<09bLW0P0^;Rh202PX:080:b/[0P1GEeL206i^KP80?Shn0`0W9bL202/[:`80;Rh^
0P0Z:RX203Ph>080@4100P0o?cl302l_;`80=CDe0P0g=cL204A4A080=3@d0P0/;2`202l_;`<0=3@d
0P0h>3P203dm?@80=cLg0P0a<C42038b<P80<C4a0P0^;Rh304A4A080?3`l0P0a<C4202h^;P80<C4a
0P0l?3`204];B`<0EEEE0P18B4P205UIF@80Fe]K0P15ADD206QXJ080IFEU0`1OGel2059BDP80De=C
0P0n?Sh206QXJ080Y:BT0P2<S8`306m_K`80=SHf0P0S8b<401dM7@80820P0P0Y:BT3059BDP80QHF5
0P2GUiL209^KV`80P8200P1iNGT2079bLP<0Ng]k0P2>SXh20:n_[`80`<300P2g]kL20:JVYP80[:b/
0`2h^;P20;Fe]@80^[Zj0P2`/;020;:b/P80/;2`1@2c/k<20;6a/@80XJ6Q0P2=SHd2092@T080Y:BT
1@2VYZH20:ZZZP80/K6a0P2g]kL20<30`080alO70P35aLD20<[:bP<0_[jn0P2`/;020:RXZ080YZJV
102][Jd20:^[Z`<0Y:BT0P2RXZ820:>SX`80Y:BT0P2MWId209FEU@80TY:B0`2KVi/209bLW080XJ6Q
0P2PX:020::RXP80YZJV0P2ZZZX50:^[Z`80ZZZZ0P2XZ:P20:b/[080];Bd0P2h^;P30;^k^`80_Kfm
0P30`<020<71`@P0b>3H00060<SPf080;Bd]0P0Y:BT202HV9P<09bLW0P0^;Rh202PX:080:b/[0P1G
EeL206i^KP80?Shn0`0W9bL202/[:`80;Rh^0P0Z:RX203Ph>080@4100P0o?cl302l_;`80=CDe0P0g
=cL204A4A080=3@d0P0/;2`202l_;`<0=3@d0P0h>3P203dm?@80=cLg0P0a<C42038b<P80<C4a0P0^
;Rh304A4A080?3`l0P0a<C4202h^;P80<C4a0P0l?3`204];B`<0EEEE0P18B4P205UIF@80Fe]K0P15
ADD206QXJ080IFEU0`1OGel2059BDP80De=C0P0n?Sh206QXJ080Y:BT0P2<S8`306m_K`80=SHf0P0S
8b<401dM7@80820P0P0Y:BT3059BDP80QHF50P2GUiL209^KV`80P8200P1iNGT2079bLP<0Ng]k0P2>
SXh20:n_[`80`<300P2g]kL20:JVYP80[:b/0`2h^;P20;Fe]@80^[Zj0P2`/;020;:b/P80/;2`1@2c
/k<20;6a/@80XJ6Q0P2=SHd2092@T080Y:BT1@2VYZH20:ZZZP80/K6a0P2g]kL20<30`080alO70P35
aLD20<[:bP<0_[jn0P2`/;020:RXZ080YZJV102][Jd20:^[Z`<0Y:BT0P2RXZ820:>SX`80Y:BT0P2M
WId209FEU@80TY:B0`2KVi/209bLW080XJ6Q0P2PX:020::RXP80YZJV0P2ZZZX50:^[Z`80ZZZZ0P2X
Z:P20:b/[080];Bd0P2h^;P30;^k^`80_Kfm0P30`<020<71`@P0b>3H00060<SPf080>SXj0P0W9bL2
02TY:@<09BDU0P0^;Rh203Ti>@80=3@d0P1KFe/206UYJ@80?clo0`0U9BD402LW9`80;bl_0P0`<302
04M7A`80DE5A0`0n?Sh2030`<080>3Ph0P10@4020492@P80:b/[0P0Y:BT302d];@80>3Ph0P0d=3@2
03Ph>080=SHf0P0Z:RX202/[:`80;Rh^0`0j>SX204Q8B080>c/k0P0];Bd203Ti>@80>3Ph0P0c<c<3
04I6AP80BDU90P1VIVH206a/K080Kfm_0P1iNGT205UIF@<0C4a<100k>c/202d];@80GUiN0P2HV9P2
06YZJP<0@D510P0U9BD201lO7`8071`L0P0P820201dM7@809BDU0`0^;Rh205UIF@80Ph>30P2QXJ42
09JFUP80QHF50P1lO7`307=cL`80Ng]k0P2CTi<20;Bd]080_Kfm0P2YZJT20:ZZZP<0/;2`0P2h^;P2
0;Vi^@@0[Zj^0P2YZJT20:RXZ0<0Zj^[0P2^[Zh209VIV@80RXZ:0P2@T9020:NWY`80Z:RX0`2WYjL2
0:JVYP80][Jf0P2j^[X20;fm_@@0_kno0P34a<@30;no_`80/k>c0P2[Zj/20:FUY@80ZJVY0P2/[:`5
0:NWY`80ZJVY0P2WYjL20::RXP80YJFU0P2IVIT2096AT@<0UYJF0P2KVi/209fMW@80W9bL0P2OWil4
0:JVYP<0Z:RX0P2WYjL20:VYZ@80[Jf]0P2_[jl20;Ng]`80^;Rh0`2j^[X20<71`@80`/;20P2n_[h8
0<SPf0001P38h=P203Xj>P809bLW0P0Y:BT302DU9@80;Rh^0P0i>CT203@d=080Fe]K0P1YJFT203lo
?`<09BDU100W9bL202l_;`80<30`0P17AdL2055AD@<0?Shn0P0`<30203Ph>080@4100P12@T8202/[
:`80:BTY0`0];Bd203Ph>080=3@d0P0h>3P203Hf=P80:RXZ0P0[:b/202h^;P<0>SXj0P18B4P203/k
>`80;Bd]0P0i>CT203Ph>080<c<c0`16ATH204U9B@80IVIV0P1/K6`206m_K`80NGUi0P1IFET304a<
C0@0>c/k0P0];Bd205iNGP80V9RH0P1ZJVX30451@@809BDU0P0O7al201`L7080820P0P0M7Ad202DU
9@<0;Rh^0P1IFET208>3P`80XJ6Q0P2FUYH208F5Q@80O7al0`1cLg<207]kN`80Ti>C0P2d];@20;fm
_@80ZJVY0P2ZZZX30;2`/080^;Rh0P2i^KT40:j^[P80ZJVY0P2XZ:P30:^[Z`80[Zj^0P2IVIT208Z:
RP80T92@0P2WYjL20:RXZ0<0YjNW0P2VYZH20;Jf]P80^[Zj0P2m_Kd40;no_`80a<C40`2o_kl20;>c
/`80Zj^[0P2UYJD20:VYZ@80[:b/1@2WYjL20:VYZ@80YjNW0P2RXZ820:FUY@80VIVI0P2ATI4309JF
UP80Vi^K0P2MWId209bLW080WinO102VYZH30:RXZ080YjNW0P2YZJT20:f][@80[jn_0P2g]kL20;Rh
^0<0^[Zj0P31`L420<;2`P80_[jn2038h=P000H0b>3H0P0b<S8202/[:`80<S8b0`0V9RH202l_;`80
=CDe0P0h>3P206UYJ@80KFe]0P11@D4302LW9`80:RXZ0P0Y:BT202l_;`80;Rh^0P11@D4204a<C0<0
AdM70P0h>3P202`/;080=SHf0P0m?Cd2030`<080;Bd]0`0c<c<203Lg=`80<S8b0P12@T8203De=@80
=cLg0P0Y:BT202h^;P<0=SHf0P11@D4203`l?080>3Ph0P0g=cL203@d=080<S8b0`0o?cl2061PH080
LW9b0P1YJFT207QhN080OWin0P1@D5030410@080:RXZ0P0e=CD203Hf=P80J6QX0P29RHT205QHF0<0
:BTY0P0P820202HV9P80820P0P0T92@2028R8P807QhN0`0T92@203Hf=P80GEeM0P2ATI420:VYZ@80
U9BD0P24Q8@307]kN`80MgMg0P1mOGd209FEU@80][Jf0P2i^KT20:VYZ@<0Z:RX0P2f][H20;>c/`80
[Zj^0P2ZZZX20:JVYP80Xj>S0`2`/;020:>SX`80U9BD0P2;Rh/208n?S`80ZJVY0P2e]KD30:f][@80
[:b/0P2_[jl20:j^[P80^KVi0P2n_[h20<?3``80_kno0`2j^[X20;Jf]P80[:b/0P2WYjL20:b/[080
Zj^[0P2WYjL30:^[Z`80[Jf]0P2XZ:P20:NWY`80Zj^[0P2UYJD20:2PX0<0UIFE0P2CTi<209BDU080
UiNG0P2MWId20:FUY@80YZJV0`2YZJT20:^[Z`80Z:RX102][Jd20;>c/`80]kNg0`2i^KT20;jn_P80
_kno0P2n_[h80<SPf0001P38h=P2038b<P80:b/[0P0b<S8302HV9P80;bl_0P0e=CD203Ph>080JFUY
0P1]KFd20451@@<09bLW0P0Z:RX202TY:@80;bl_0P0^;Rh20451@@80C4a<0`17AdL203Ph>080;2`/
0P0f=SH203dm?@80<30`0P0];Bd303<c<`80=cLg0P0b<S820492@P80=CDe0P0g=cL202TY:@80;Rh^
0`0f=SH20451@@80?3`l0P0h>3P203Lg=`80=3@d0P0b<S8303lo?`80H61P0P1bLW8206UYJ@80N7Qh
0P1nOWh2051@D0<0@4100P0Z:RX203De=@80=SHf0P1XJ6P208V9R@80F5QH0`0Y:BT2020P80809RHV
0P0P820202@T90808R8R0P0N7Qh302@T9080=SHf0P1MGEd2096AT@80ZJVY0P2DU9@208B4Q0<0Ng]k
0P1gMgL207emO@80UIFE0P2f][H20;Vi^@80ZJVY0`2XZ:P20;Jf]P80/k>c0P2^[Zh20:ZZZP80YZJV
0P2SXj<30;2`/080Xj>S0P2DU9@208^;R`80Shn?0P2YZJT20;Fe]@<0[Jf]0P2/[:`20:n_[`80[Zj^
0P2i^KT20;jn_P80`l?30P2o_kl30;Zj^P80][Jf0P2/[:`20:NWY`80[:b/0P2[Zj/20:NWY`<0Zj^[
0P2][Jd20:RXZ080YjNW0P2[Zj/20:FUY@80X:2P0`2EUID209>CT`80U9BD0P2GUiL209fMW@80YJFU
0P2VYZH30:VYZ@80Zj^[0P2XZ:P40:f][@80/k>c0P2g]kL30;Vi^@80_[jn0P2o_kl20;jn_PP0b>3H
00060<SPf080?clo0P0g=cL202h^;P<0:RXZ100/;2`203`l?080J6QX0P1]KFd204e=C@<0;Rh^0P0a
<C4202`/;0@0:b/[0P0`<30203hn?P<0AdM70P0o?cl2038b<P80<c<c0P0k>c/203De=@80<S8b0`0e
=CD2034a<@80=cLg0P0f=SH204A4A080;Rh^0P0[:b/202h^;P<0>c/k0P0n?Sh20410@080>CTi100b
<S8203Lg=`<0CTi>0P1SHf<206i^KP80IfMW0P1LG5`207YjNP80?clo0`0g=cL202d];@80<c<c0P0k
>c/20820P080RHV90P17AdL302DU9@8092@T0P0X:2P201lO7`8092@T0P0S8b<202PX:0<08b<S0P0Y
:BT202/[:`80HV9R0P2ATI420:FUY@80UIFE0`21PH4207AdM080LW9b0P1kNg/20:2PX080]KFe0P2i
^KT30:FUY@80[Zj^0P2][Jd20:RXZ080ZJVY0P2QXJ450:RXZ080ZZZZ0P2FUYH208N7Q`80SXj>0P2Y
ZJT20;Jf]P<0/K6a0P2YZJT20:RXZ080[jn_0P2i^KT20;bl_080`<300P36a/H30;Vi^@80^;Rh0P2_
[jl20:NWY`80ZZZZ0P2[Zj/20:VYZ@<0ZZZZ0P2/[:`20:VYZ@80Zj^[0P2^[Zh20:ZZZP80[jn_0`2Q
XJ4209JFUP80Ti>C0P2EUID209bLW080Xj>S0P2VYZH30:FUY@80ZJVY0P2WYjL20:j^[P80[:b/0P2b
/[820;2`/0<0^[Zj0P2m_Kd20;no_`80^KVi2038h=P000H0b>3H0P0o?cl203Lg=`80;Rh^0`0Z:RX4
02`/;080?3`l0P1XJ6P206e]K@80CDe=0`0^;Rh2034a<@80;2`/100[:b/2030`<080?Shn0`17AdL2
03lo?`80<S8b0P0c<c<203/k>`80=CDe0P0b<S8303De=@80<C4a0P0g=cL203Hf=P80A4A40P0^;Rh2
02/[:`80;Rh^0`0k>c/203hn?P80@4100P0i>CT4038b<P80=cLg0`1>CTh206=SH`80KVi^0P1WIfL2
05aLG080NWYj0P0o?cl303Lg=`80;Bd]0P0c<c<203/k>`80P8200P29RHT204M7A`<09BDU0P0T92@2
02PX:0807alO0P0T92@202<S8`80:2PX0`0S8b<202TY:@80:b/[0P1RHV82096AT@80YJFU0P2EUID3
0861P@80M7Ad0P1bLW8207]kN`80X:2P0P2e]KD20;Vi^@<0YJFU0P2^[Zh20:f][@80Z:RX0P2YZJT2
0:6QX@D0Z:RX0P2ZZZX209JFUP80QhN70P2>SXh20:VYZ@80][Jf0`2a/K420:VYZ@80Z:RX0P2_[jl2
0;Vi^@80_;bl0P30`<020<K6aP<0^KVi0P2h^;P20:n_[`80YjNW0P2ZZZX20:^[Z`80ZJVY0`2ZZZX2
0:b/[080ZJVY0P2[Zj/20:j^[P80ZZZZ0P2_[jl30:6QX@80UYJF0P2CTi<209FEU@80W9bL0P2SXj<2
0:JVYP<0YJFU0P2YZJT20:NWY`80[Zj^0P2/[:`20;:b/P80/;2`0`2j^[X20;fm_@80_kno0P2i^KT8
0<SPf0001P38h=P204m?C`80DU9B0P17AdL303<c<`80:b/[0P0/;2`203De=@80IVIV0P1]KFd204U9
B@<0=3@d0P0];Bd402XZ:P80;2`/0P0^;Rh203Hf=PD0ATI60P0j>SX203/k>`80?3`l0P0i>CT202XZ
:P<0:b/[0P0^;Rh402l_;`80>c/k0P0e=CD2034a<@80=3@d0`13@d<203hn?P80@T920P0i>CT203Hf
=P80=3@d0P14A4@305YJFP80H61P0P1SHf<203/k>`80@d=30P1ZJVX203Lg=`<0;2`/0P0_;bl203@d
=080D51@0P2@T9020861P@80=cLg0`0Y:BT202d];@80:RXZ0P0W9bL202@T90808B4Q0P0S8b<3020P
80808B4Q0P0T92@203@d=080Jf][0P2KVi/20:2PX0<0Shn?0P1hN7P206][J`80JVYZ0P1mOGd209^K
V`D0]KFe0P2/[:`20:^[Z`@0YJFU102VYZH30:NWY`80Xj>S0P2DU9@208B4Q080SHf=0P2WYjL20;6a
/@<0[Jf]0P2SXj<209nOW`80/K6a0P2j^[X20<71`@80_[jn0P2m_Kd30;Rh^080]kNg0P2a/K460:NW
Y`80Z:RX0`2ZZZX40:^[Z`80ZZZZ0P2[Zj/20:f][@80[Zj^0`2/[:`20:NWY`80W9bL0P2CTi<209FE
U@80XZ:R0P2PX:030::RXP80ZJVY0P2ZZZX20:f][@80[jn_0P2`/;020:j^[P<0][Jf0P2j^[X20;bl
_080^k^k2038h=P000H0b>3H0P1?Cdl2059BDP80AdM70`0c<c<202/[:`80;2`/0P0e=CD206IVIP80
KFe]0P19BDT303@d=080;Bd]100Z:RX202`/;080;Rh^0P0f=SH504I6AP80>SXj0P0k>c/203`l?080
>CTi0P0Z:RX302/[:`80;Rh^100_;bl203/k>`80=CDe0P0a<C4203@d=0<0@d=30P0n?Sh20492@P80
>CTi0P0f=SH203@d=080A4A40`1JFUX2061PH080Hf=S0P0k>c/204=3@`80JVYZ0P0g=cL302`/;080
;bl_0P0d=3@2051@D080T92@0P21PH4203Lg=`<0:BTY0P0];Bd202XZ:P809bLW0P0T92@2024Q8@80
8b<S0`0P8202024Q8@8092@T0P0d=3@206][J`80Vi^K0P2PX:0308n?S`80N7Qh0P1[Jf/206YZJP80
OGem0P2KVi/50;Fe]@80[:b/0P2[Zj/40:FUY@@0YZJV0`2WYjL20:>SX`80U9BD0P24Q8@208f=S@80
YjNW0P2a/K430:f][@80Xj>S0P2OWil20;6a/@80^[Zj0P31`L420;jn_P80_Kfm0`2h^;P20;Ng]`80
/K6a1P2WYjL20:RXZ0<0ZZZZ102[Zj/20:ZZZP80Zj^[0P2][Jd20:j^[P<0[:b/0P2WYjL209bLW080
Ti>C0P2EUID20::RXP80X:2P0`2RXZ820:VYZ@80ZZZZ0P2][Jd20:n_[`80/;2`0P2^[Zh30;Jf]P80
^[Zj0P2l_;`20;^k^`P0b>3H00060<SPf0@0G5aL0P1JFUX304=3@`80>CTi0P0^;Rh203Lg=`80E5AD
0P1XJ6P205YJFP<0<S8b0P0];Bd202TY:@80:RXZ0P0];Bd202HV9P80;Bd]0`10@40204=3@`80=cLg
0P0^;Rh20451@@80>SXj0P0b<S8302`/;080;Rh^0P0d=3@202/[:`80<30`0P0j>SX203`l?080@D51
0`1<C4`203Xj>P80>c/k0P11@D4203De=@80=3@d0P18B4P305ADE080G5aL0P1?Cdl2034a<@80=cLg
0P1QHF4203Xj>P<0;2`/0P0^;Rh20410@080Kfm_0P2?Shl2075aL@80;2`/0`0^;Rh202TY:@808b<S
0P0W9bL202HV9P808b<S0P0R8R83024Q8@807alO0P0P820202DU9@80=SHf0P1`L70209NGU`<0Z:RX
0P2>SXh207AdM080IfMW0P1bLW8208>3P`80X:2P0`2c/k<20;no_`80/K6a0P2YZJT20:BTY080YJFU
0P2TY:@30:FUY@80X:2P0P2>SXh208B4Q080RHV90P2TY:@20:VYZ@<0YJFU0P2NWYh209nOW`80ZJVY
0P2f][H20<71`@80^k^k0P2e]KD30:f][@80][Jf0P2d];@20:^[Z`@0[:b/1@2YZJT20:b/[080YZJV
0P2XZ:P20:BTY080ZZZZ0P2XZ:P30;:b/P80/k>c0P2_[jl209fMW@80RXZ:0P2CTi<209fMW@<0WinO
0P2VYZH20:NWY`80ZJVY0P2/[:`40:n_[`<0];Bd0P2i^KT20;^k^`80]kNg2038h=P000H0b>3H101L
G5`205YJFP<0@d=30P0i>CT202h^;P80=cLg0P1DE5@206QXJ080FUYJ0`0b<S8202d];@80:BTY0P0Z
:RX202d];@809RHV0P0];Bd30410@080@d=30P0g=cL202h^;P80@D510P0j>SX2038b<P<0;2`/0P0^
;Rh203@d=080:b/[0P0`<30203Xj>P80?3`l0P11@D4304a<C080>SXj0P0k>c/20451@@80=CDe0P0d
=3@204Q8B0<0E5AD0P1LG5`204m?C`80<C4a0P0g=cL2065QH@80>SXj0`0/;2`202h^;P80@4100P1_
Kfl208n?S`80LG5a0P0/;2`302h^;P80:BTY0P0S8b<202LW9`809RHV0P0S8b<2028R8P<08B4Q0P0O
7al2020P80809BDU0P0f=SH2071`L080UiNG0`2XZ:P208j>SP80M7Ad0P1WIfL2079bLP80Ph>30P2P
X:030;>c/`80_kno0P2a/K420:VYZ@80Y:BT0P2UYJD20:BTY0<0YJFU0P2PX:0208j>SP80Q8B40P29
RHT20:BTY080ZJVY0`2UYJD209jNWP80WinO0P2YZJT20;Jf]P80`L710P2k^k/20;Fe]@<0[Jf]0P2f
][H20;Bd]080Zj^[102/[:`50:VYZ@80[:b/0P2VYZH20:RXZ080Y:BT0P2ZZZX20:RXZ0<0/[:b0P2c
/k<20:n_[`80WIfM0P2:RXX209>CT`80WIfM0`2OWil20:JVYP80YjNW0P2YZJT20:b/[0@0[jn_0`2d
];@20;Vi^@80^k^k0P2g]kL80<SPf0001P38h=P405aLG080FUYJ0`13@d<203Ti>@80;Rh^0P0g=cL2
05ADE080J6QX0P1JFUX3038b<P80;Bd]0P0Y:BT202XZ:P80;Bd]0P0V9RH202d];@<0@4100P13@d<2
03Lg=`80;Rh^0P11@D4203Xj>P80<S8b0`0/;2`202h^;P80=3@d0P0[:b/2030`<080>SXj0P0l?3`2
0451@@<0C4a<0P0j>SX203/k>`80@D510P0e=CD203@d=080B4Q80`1DE5@205aLG080Cdm?0P0a<C42
03Lg=`80HF5Q0P0j>SX302`/;080;Rh^0P10@40206m_K`80Shn?0P1aLG4202`/;0<0;Rh^0P0Y:BT2
02<S8`809bLW0P0V9RH202<S8`808R8R0`0Q8B4201lO7`80820P0P0U9BD203Hf=P80L71`0P2GUiL3
0:RXZ080SXj>0P1dM7@206MWI`80LW9b0P23Ph<20:2PX0<0/k>c0P2o_kl20;6a/@80ZJVY0P2TY:@2
0:FUY@80Y:BT0`2UYJD20:2PX080SXj>0P24Q8@208V9R@80Y:BT0P2YZJT30:FUY@80WYjN0P2OWil2
0:VYZ@80][Jf0P31`L420;^k^`80]KFe0`2][Jd20;Jf]P80];Bd0P2[Zj/40:b/[0D0ZJVY0P2/[:`2
0:JVYP80Z:RX0P2TY:@20:ZZZP80Z:RX0`2b/[820;>c/`80[jn_0P2MWId208Z:RP80Ti>C0P2MWId3
09nOW`80YZJV0P2WYjL20:VYZ@80[:b/102_[jl30;Bd]080^KVi0P2k^k/20;Ng]`P0b>3H00060<SP
f080@d=30P12@T8204A4A0<0=CDe0P0d=3@402h^;P80EEEE0P1QHF42069RHP<0?Shn0P0];Bd202XZ
:P809bLW0P0];Bd202TY:@80;Bd]0`0d=3@203/k>`@0;Rh^0P0h>3P203hn?P80<c<c0`0a<C4202l_
;`80=SHf0P0a<C4203<c<`80@4100P1ADE4204a<C0<0BTY:0P11@D4203dm?@80A4A40P0i>CT20451
@@80CDe=0`16ATH205UIF@80D51@0P0Y:BT202/[:`80Bd];0P0k>c/303De=@80;Bd]0P1IFET208R8
R080RXZ:0P1NGUh202LW9`<0:BTY0P0V9RH202@T9080;Rh^0P0X:2P402<S8`<08B4Q0P0M7Ad201hN
7P807alO0P0V9RH20451@@80Lg=c0`2TY:@20:b/[080R8R80P1aLG4206MWI`80M7Ad0P27QhL309nO
W`80][Jf0P2o_kl20:f][@80YZJV0P2TY:@20:JVYP<0YJFU0P2SXj<208f=S@80QXJ60P20P80209^K
V`80YjNW0`2TY:@40:b/[080XZ:R0P2`/;020<30`080_kno0P2f][H30:f][@80[:b/0P2m_Kd20:j^
[P80YjNW0P2][Jd20:ZZZP<0ZJVY0P2ZZZX20:6QX@80YjNW0P2PX:020:RXZ080Xj>S0`2^[Zh20;2`
/080]kNg0P2e]KD209jNWP80Shn?0P2IVIT309nOW`80YZJV0P2UYJD20:ZZZP80/[:b0P2][Jd20:n_
[`<0];Bd0P2k^k/20;Bd]080^KVi2038h=P000H0b>3H0P13@d<20492@P80A4A40`0e=CD203@d=0@0
;Rh^0P1EEED2065QH@80HV9R0`0n?Sh202d];@80:RXZ0P0W9bL202d];@80:BTY0P0];Bd303@d=080
>c/k100^;Rh203Ph>080?Shn0P0c<c<3034a<@80;bl_0P0f=SH2034a<@80<c<c0P10@402055AD@80
C4a<0`1:BTX20451@@80?Cdm0P14A4@203Ti>@80@D510P1=CDd304I6AP80FEUI0P1@D50202TY:@80
:b/[0P1;Bd/203/k>`<0=CDe0P0];Bd205UIF@80R8R80P2:RXX205iNGP809bLW0`0Y:BT202HV9P80
92@T0P0^;Rh202PX:0@08b<S0`0Q8B4201dM7@807QhN0P0O7al202HV9P80@D510P1cLg<30:BTY080
[:b/0P28R8P2075aL@80IfMW0P1dM7@208N7Q`<0WinO0P2f][H20;no_`80[Jf]0P2VYZH20:BTY080
YZJV0`2UYJD20:>SX`80SHf=0P26QXH20820P080Vi^K0P2WYjL30:BTY0@0[:b/0P2RXZ820;2`/080
`<300P2o_kl20;Jf]P<0[Jf]0P2/[:`20;fm_@80[Zj^0P2WYjL20:f][@80ZZZZ0`2YZJT20:ZZZP80
XJ6Q0P2WYjL20:2PX080Z:RX0P2SXj<30:j^[P80/;2`0P2g]kL20;Fe]@80WYjN0P2?Shl209VIV@<0
WinO0P2VYZH20:FUY@80ZZZZ0P2b/[820:f][@80[jn_0`2d];@20;^k^`80];Bd0P2i^KT80<SPf000
1P38h=P2051@D080EUIF0P0o?cl302l_;`80;Rh^0P0b<S8203<c<`80DE5A0P1NGUh2061PH0<0CDe=
0P0b<S8202/[:`80:RXZ0P0Y:BT202LW9`80;Bd]0`0b<S8203Lg=`80<c<c0P0_;bl2034a<@80>c/k
0P0c<c<3038b<P80=CDe0P0^;Rh203<c<`80>3Ph0P1CDe<205ADE0D0B4Q80P15ADD20492@P80ADE5
0P11@D4204=3@`80>SXj0`10@402065QH@80EUIF0P0[:b/202h^;P80?Shn0P10@40303Lg=`80?3`l
0P1GEeL209:BTP80SXj>0P1KFe/202PX:0<09bLW0P0/;2`202d];@80:b/[0P0Z:RX202DU9@8092@T
0`0Z:RX2024Q8@@07QhN0P0Q8B4202DU9@80BTY:0`25QHD20:BTY080W9bL0P29RHT2071`L080JVYZ
0P1bLW8308B4Q080X:2P0P2j^[X20;fm_@80YjNW0P2TY:@20:FUY@<0Y:BT0P2SXj<208J6QP80P820
0P23Ph<209VIV@80[jn_0`2e]KD20;Jf]P80[Zj^0P2TY:@20;:b/P80`L710P30`<020;Rh^0<0^KVi
0P2c/k<20;^k^`80/k>c0P2YZJT20:NWY`80YZJV0`2PX:020:RXZ080X:2P0P2TY:@20:6QX@80YJFU
0P2TY:@30:j^[P80[jn_0P2d];@20;^k^`80]KFe0P2UYJD209^KV`<0W9bL0P2KVi/20:BTY080YjNW
0P2^[Zh20:b/[080[Jf]0`2e]KD20;Jf]P80/k>c0P2m_Kd80<SPf0001P38h=P2051@D080EUIF0P0o
?cl302l_;`80;Rh^0P0b<S8203<c<`80DE5A0P1NGUh2061PH0<0CDe=0P0b<S8202/[:`80:RXZ0P0Y
:BT202LW9`80;Bd]0`0b<S8203Lg=`80<c<c0P0_;bl2034a<@80>c/k0P0c<c<3038b<P80=CDe0P0^
;Rh203<c<`80>3Ph0P1CDe<205ADE0D0B4Q80P15ADD20492@P80ADE50P11@D4204=3@`80>SXj0`10
@402065QH@80EUIF0P0[:b/202h^;P80?Shn0P10@40303Lg=`80?3`l0P1GEeL209:BTP80SXj>0P1K
Fe/202PX:0<09bLW0P0/;2`202d];@80:b/[0P0Z:RX202DU9@8092@T0`0Z:RX2024Q8@@07QhN0P0Q
8B4202DU9@80BTY:0`25QHD20:BTY080W9bL0P29RHT2071`L080JVYZ0P1bLW8308B4Q080X:2P0P2j
^[X20;fm_@80YjNW0P2TY:@20:FUY@<0Y:BT0P2SXj<208J6QP80P8200P23Ph<209VIV@80[jn_0`2e
]KD20;Jf]P80[Zj^0P2TY:@20;:b/P80`L710P30`<020;Rh^0<0^KVi0P2c/k<20;^k^`80/k>c0P2Y
ZJT20:NWY`80YZJV0`2PX:020:RXZ080X:2P0P2TY:@20:6QX@80YJFU0P2TY:@30:j^[P80[jn_0P2d
];@20;^k^`80]KFe0P2UYJD209^KV`<0W9bL0P2KVi/20:BTY080YjNW0P2^[Zh20:b/[080[Jf]0`2e
]KD20;Jf]P80/k>c0P2m_Kd80<SPf0001P38h=P207EeM@80JFUY0P17AdL302d];@809bLW0P0[:b/2
02d];@80?Shn0P1GEeL205mOG`<0EUIF0P0/;2`202d];@80:BTY0P0_;bl202HV9P80:b/[0`0_;bl2
03Hf=P80=3@d0P0];Bd202/[:`80<S8b0P0`<30302d];@80<C4a0P0d=3@203Ph>080BTY:0P1FEUH2
04m?C`80ADE50`0j>SX203lo?`80BDU90P1;Bd/204E5A@80@4100P0a<C4304E5A@80HV9R0P1HF5P2
02/[:`80;Bd]100l?3`302`/;080<S8b0P1ADE4208j>SP80QHF50P1HF5P2034a<@<0?Shn0P10@402
04];B`80@d=30P0n?Sh202h^;P80:BTY0`0V9RH202@T90@08b<S0P0O7al2024Q8@80:BTY0`1FEUH2
08:2PP80VYZJ0P2PX:0208R8R080LG5a0P1/K6`306QXJ080N7Qh0P2OWil20;Rh^080]KFe0P2PX:02
0:NWY`<0XZ:R0P2HV9P20820P080Ng]k0P2>SXh20:2PX080^k^k0`2j^[X20;6a/@80];Bd0P2VYZH2
0;Ng]`80_;bl0P33`l<50;bl_080_[jn0P2h^;P20;Fe]@80[Jf]0P2ZZZX20:b/[0<0XZ:R0P2TY:@2
0:>SX`80WinO0P2QXJ4209jNWP80WinO0`2WYjL20;6a/@80];Bd0P2f][H20;bl_080/K6a0P2`/;03
09nOW`80V9RH0P2LW9`20:BTY0@0Z:RX0P2WYjL30:n_[`80/;2`0P2d];@20;Zj^PP0b>3H00060<SP
f080MGEe0P1YJFT204M7A`<0;Bd]0P0W9bL202/[:`80;Bd]0P0n?Sh205MGE`80GemO0`1FEUH202`/
;080;Bd]0P0Y:BT202l_;`809RHV0P0[:b/302l_;`80=SHf0P0d=3@202d];@80:b/[0P0b<S82030`
<0<0;Bd]0P0a<C4203@d=080>3Ph0P1:BTX205IFEP80Cdm?0P15ADD303Xj>P80?clo0P19BDT204];
B`80ADE50P10@402034a<@<0ADE50P1RHV8205QHF080:b/[0P0];Bd403`l?0<0;2`/0P0b<S82055A
D@80SXj>0P25QHD205QHF080<C4a0`0n?Sh20410@080Bd];0P13@d<203hn?P80;Rh^0P0Y:BT302HV
9P8092@T100S8b<201lO7`808B4Q0P0Y:BT305IFEP80PX:20P2JVYX20:2PX080R8R80P1aLG4206a/
K0<0J6QX0P1hN7P209nOW`80^;Rh0P2e]KD20:2PX080YjNW0`2RXZ8209RHV080P8200P1kNg/208j>
SP80X:2P0P2k^k/30;Zj^P80/K6a0P2d];@20:JVYP80]kNg0P2l_;`20<?3``D0_;bl0P2n_[h20;Rh
^080]KFe0P2][Jd20:ZZZP80[:b/0`2RXZ820:BTY080Xj>S0P2OWil20:6QX@80WYjN0P2OWil30:NW
Y`80/K6a0P2d];@20;Jf]P80_;bl0P2a/K420;2`/0<0WinO0P2HV9P209bLW080Y:BT102XZ:P20:NW
Y`<0[jn_0P2`/;020;Bd]080^[Zj2038h=P000H0b>3H0P1hN7P206QXJ080EeMG0`0`<30202`/;080
9RHV0P0[:b/203Hf=P80?clo0P1KFe/305eMG@80=SHf0P0];Bd202l_;`80;2`/0P0[:b/203De=@L0
:RXZ0P0[:b/202h^;P80<30`0P0a<C4302/[:`80=cLg0P13@d<204a<C080E5AD0P1@D50204i>CP80
>c/k0`0o?cl204Q8B080EUIF0P1EEED204E5A@80>3Ph0P0X:2P303Ph>080IfMW0P1CDe<202@T9080
8b<S0P0];Bd203Ti>@<0:b/[0P0k>c/2069RHP80TI6A0P27QhL206=SH`80EUIF0`1ADE4206ATI080
Kfm_0P1SHf<205UIF@80<c<c0P0U9BD3024Q8@80:RXZ0P0R8R8202@T90807alO0P0R8R8202PX:0<0
;Rh^0P1@D50208J6QP80WinO0P2RXZ820861P@80IVIV0`1MGEd206=SH`80O7al0P2NWYh20;Fe]@80
Zj^[0P2QXJ430:BTY080SXj>0P1jNWX207]kN`80QXJ60P2`/;020;jn_P<0^[Zj0P2^[Zh20:n_[`80
];Bd0P2e]KD20<30`080`L711@2o_kl20<71`@80_kno0P2e]KD20:j^[P80ZZZZ0P2VYZH30::RXP80
YJFU0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`<0YZJV0P2ZZZX20:f][@80]KFe0P2i^KT20;Jf]P80
/[:b0`2`/;020::RXP80WYjN0P2PX:020:BTY080YjNW1`2][Jd20;2`/080^k^k2038h=P000H0b>3H
0P1hN7P206QXJ080EeMG0`0`<30202`/;0809RHV0P0[:b/203Hf=P80?clo0P1KFe/305eMG@80=SHf
0P0];Bd202l_;`80;2`/0P0[:b/203De=@L0:RXZ0P0[:b/202h^;P80<30`0P0a<C4302/[:`80=cLg
0P13@d<204a<C080E5AD0P1@D50204i>CP80>c/k0`0o?cl204Q8B080EUIF0P1EEED204E5A@80>3Ph
0P0X:2P303Ph>080IfMW0P1CDe<202@T90808b<S0P0];Bd203Ti>@<0:b/[0P0k>c/2069RHP80TI6A
0P27QhL206=SH`80EUIF0`1ADE4206ATI080Kfm_0P1SHf<205UIF@80<c<c0P0U9BD3024Q8@80:RXZ
0P0R8R8202@T90807alO0P0R8R8202PX:0<0;Rh^0P1@D50208J6QP80WinO0P2RXZ820861P@80IVIV
0`1MGEd206=SH`80O7al0P2NWYh20;Fe]@80Zj^[0P2QXJ430:BTY080SXj>0P1jNWX207]kN`80QXJ6
0P2`/;020;jn_P<0^[Zj0P2^[Zh20:n_[`80];Bd0P2e]KD20<30`080`L711@2o_kl20<71`@80_kno
0P2e]KD20:j^[P80ZZZZ0P2VYZH30::RXP80YJFU0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`<0YZJV
0P2ZZZX20:f][@80]KFe0P2i^KT20;Jf]P80/[:b0`2`/;020::RXP80WYjN0P2PX:020:BTY080YjNW
1`2][Jd20;2`/080^k^k2038h=P000H0b>3H0P1bLW8205eMG@80=3@d0`0];Bd202HV9P80:BTY0P0_
;bl203`l?080<c<c0P13@d<305QHF080AdM70P11@D4203<c<`@0<30`0P0[:b/302d];@80<C4a0P0]
;Bd2034a<@80<S8b0P0h>3P202l_;`<0<C4a0P0d=3@204I6AP80G5aL0P1@D50205=CD`80>c/k0P0o
?cl304];B`80CTi>0P1IFET204];B`80?Cdm0P0/;2`202h^;P<0>SXj0P1RHV8205=CD`809BDU0P0S
8b<202XZ:P80=cLg0`0a<C4205=CD`80LW9b0P28R8P208N7Q`80Jf][0P1XJ6P305iNGP80GemO0P1M
GEd204Q8B080=CDe0P0U9BD202<S8`<09RHV0P0Z:RX202@T90808B4Q0P0U9BD202@T90809BDU0`0Q
8B42038b<P80Fe]K0P23Ph<209ZJVP80U9BD0P1eMGD305YJFP80De=C0P1VIVH207IfMP80UYJF0P2d
];@20;Jf]P<0YJFU0P29RHT207QhN080SHf=0P2EUID20:b/[080^k^k0`2l_;`20;Jf]P80/;2`0P2e
]KD20;^k^`80^[Zj0P2l_;`20<30`0<0`/;21031`L420;fm_@80][Jf0P2c/k<20:NWY`<0ZJVY102U
YJD60:6QX@80YZJV0`2UYJD20:ZZZP80[jn_0P2/[:`20;Bd]080]kNg0P2f][H30;:b/P80[Jf]0P2W
YjL20:BTY080XJ6Q0P2VYZH20:^[Z`<0[Jf]0P2/[:`20;6a/@80^;Rh2038h=P000H0b>3H0P1bLW82
05eMG@80=3@d0`0];Bd202HV9P80:BTY0P0_;bl203`l?080<c<c0P13@d<305QHF080AdM70P11@D42
03<c<`@0<30`0P0[:b/302d];@80<C4a0P0];Bd2034a<@80<S8b0P0h>3P202l_;`<0<C4a0P0d=3@2
04I6AP80G5aL0P1@D50205=CD`80>c/k0P0o?cl304];B`80CTi>0P1IFET204];B`80?Cdm0P0/;2`2
02h^;P<0>SXj0P1RHV8205=CD`809BDU0P0S8b<202XZ:P80=cLg0`0a<C4205=CD`80LW9b0P28R8P2
08N7Q`80Jf][0P1XJ6P305iNGP80GemO0P1MGEd204Q8B080=CDe0P0U9BD202<S8`<09RHV0P0Z:RX2
02@T90808B4Q0P0U9BD202@T90809BDU0`0Q8B42038b<P80Fe]K0P23Ph<209ZJVP80U9BD0P1eMGD3
05YJFP80De=C0P1VIVH207IfMP80UYJF0P2d];@20;Jf]P<0YJFU0P29RHT207QhN080SHf=0P2EUID2
0:b/[080^k^k0`2l_;`20;Jf]P80/;2`0P2e]KD20;^k^`80^[Zj0P2l_;`20<30`0<0`/;21031`L42
0;fm_@80][Jf0P2c/k<20:NWY`<0ZJVY102UYJD60:6QX@80YZJV0`2UYJD20:ZZZP80[jn_0P2/[:`2
0;Bd]080]kNg0P2f][H30;:b/P80[Jf]0P2WYjL20:BTY080XJ6Q0P2VYZH20:^[Z`<0[Jf]0P2/[:`2
0;6a/@80^;Rh2038h=P000H0b>3H0P1fMWH2059BDP80;Rh^0`0W9bL202/[:`80<C4a0P0k>c/203@d
=080:b/[0P0l?3`305ADE080D51@0P0m?Cd203Ti>@80<C4a0P0/;2`202/[:`<0;Bd]100_;bl203De
=@80;bl_0P0^;Rh202/[:`<0;bl_0P0n?Sh205QHF080GemO0P1HF5P20492@P80>SXj0P11@D4305EE
E@80EeMG0P1PH60204e=C@80:b/[0P0W9bL202l_;`<0@4100P1GEeL2051@D0809BDU0P0Z:RX202`/
;080>SXj0`1LG5`206QXJ080OGem0P2=SHd208J6QP80G5aL0P16ATH303lo?`80=SHf0P0_;bl202h^
;P80:RXZ0P0a<C4202TY:@<0:RXZ0P0V9RH202TY:@808b<S100R8R8202@T90<0:2PX0P0V9RH202l_
;`80GemO0P1nOWh209>CT`80NWYj0`1VIVH206UYJ@80H61P0P1LG5`207MgM`80UIFE0P2e]KD30:j^
[P80QXJ60P1gMgL20:JVYP80WYjN0P2WYjL20;bl_0<0][Jf102d];@20;Fe]@80][Jf0P2e]KD20;Zj
^P80_;bl0`31`L420;jn_P80_kno0P2n_[h20;Vi^@80];Bd0P2a/K430:VYZ@80XZ:R0P2TY:@209^K
V`80W9bL0P2RXZ820:BTY0<0YJFU0P2XZ:P20:^[Z`80[:b/0P2`/;020;Fe]@80][Jf0`2c/k<20;6a
/@80YZJV0P2RXZ8209^KV`80X:2P0P2UYJD30:b/[080[Zj^102f][H80<SPf0001P38h=P207IfMP80
DU9B0P0^;Rh302LW9`80:b/[0P0a<C4203/k>`80=3@d0P0[:b/203`l?0<0E5AD0P1@D50203dm?@80
>CTi0P0a<C4202`/;080:b/[0`0];Bd402l_;`80=CDe0P0_;bl202h^;P80:b/[0`0_;bl203hn?P80
F5QH0P1OGel205QHF080@T920P0j>SX20451@@<0EEEE0P1GEeL2061PH080CDe=0P0[:b/202LW9`80
;bl_0`10@40205MGE`80D51@0P0U9BD202XZ:P80;2`/0P0j>SX305aLG080J6QX0P1mOGd208f=S@80
QXJ60P1LG5`204I6AP<0?clo0P0f=SH202l_;`80;Rh^0P0Z:RX2034a<@80:BTY0`0Z:RX202HV9P80
:BTY0P0S8b<4028R8P8092@T0`0X:2P202HV9P80;bl_0P1OGel207inOP80Ti>C0P1jNWX306IVIP80
JFUY0P1PH60205aLG080MgMg0P2EUID20;Fe]@<0[Zj^0P26QXH207MgM`80YZJV0P2NWYh20:NWY`80
_;bl0`2f][H40;Bd]080]KFe0P2f][H20;Fe]@80^[Zj0P2l_;`30<71`@80_[jn0P2o_kl20;jn_P80
^KVi0P2d];@20;6a/@<0ZJVY0P2RXZ820:BTY080Vi^K0P2LW9`20::RXP80Y:BT0`2UYJD20:RXZ080
Zj^[0P2/[:`20;2`/080]KFe0P2f][H30;>c/`80/K6a0P2VYZH20::RXP80Vi^K0P2PX:020:FUY@<0
[:b/0P2^[Zh40;Jf]PP0b>3H00060<SPf080MWIf0P1MGEd204=3@`D0=CDe0P0m?Cd203Ti>@80;Rh^
0P0[:b/203Ph>0<0CTi>0P1OGel204Y:BP80=SHf0P0d=3@202/[:`80;Bd]0`0c<c<2034a<@80:BTY
0P0a<C4202l_;`80<S8b0P0c<c<303Ti>@80BTY:0P1RHV8205UIF@80BTY:0P0n?Sh204E5A@80AdM7
0`1BDU8205ADE080HF5Q0P0k>c/202/[:`80;bl_0P0f=SH304Q8B080EUIF0P11@D4202LW9`80:2PX
0P0^;Rh204M7A`<0MWIf0P1eMGD207inOP80PH610P1RHV8203Ti>@D0:RXZ0P0];Bd202l_;`80;Rh^
0P0`<302034a<@80=3@d0`0[:b/202l_;`80;2`/0P0^;Rh202<S8`@08R8R0`0T92@202HV9P80:BTY
0P0g=cL205mOG`80MWIf0P1lO7`306a/K080MGEe0P1LG5`204i>CP80Fe]K0P1gMgL209>CT`<0Xj>S
0P2;Rh/207YjNP80/K6a0P2HV9P209>CT`80^KVi0`2e]KD20;>c/`80][Jf0P2d];@20;Rh^080][Jf
0P2h^;P20;Zj^P<0_;bl0P2k^k/20;fm_@80^k^k0P2f][H20;Fe]@80/k>c0`2ZZZX40:FUY@80XJ6Q
0P2PX:020:6QX@80X:2P0`2VYZH20:BTY080YZJV0P2[Zj/20:b/[080/k>c0P2i^KT30;Bd]080[jn_
0P2/[:`20:NWY`80VIVI0P2LW9`20:>SX`<0WYjN0P2UYJD20:j^[P80]KFe2038h=P000H0b>3H0P1f
MWH205eMG@80@d=31@0e=CD203dm?@80>CTi0P0^;Rh202/[:`80>3Ph0`1>CTh205mOG`80BTY:0P0f
=SH203@d=080:b/[0P0];Bd303<c<`80<C4a0P0Y:BT2034a<@80;bl_0P0b<S8203<c<`<0>CTi0P1:
BTX2069RHP80FEUI0P1:BTX203hn?P80ADE50P17AdL3059BDP80E5AD0P1QHF4203/k>`80:b/[0P0_
;bl203Hf=P<0B4Q80P1FEUH20451@@809bLW0P0X:2P202h^;P80AdM70`1fMWH207EeM@80OWin0P21
PH42069RHP80>CTi1@0Z:RX202d];@80;bl_0P0^;Rh2030`<080<C4a0P0d=3@302/[:`80;bl_0P0/
;2`202h^;P808b<S100R8R8302@T90809RHV0P0Y:BT203Lg=`80GemO0P1fMWH207alO0<0K6a/0P1e
MGD205aLG080CTi>0P1KFe/207MgM`80Ti>C0`2SXj<208^;R`80NWYj0P2a/K4209RHV080Ti>C0P2i
^KT30;Fe]@80/k>c0P2f][H20;Bd]080^;Rh0P2f][H20;Rh^080^[Zj0`2l_;`20;^k^`80_Kfm0P2k
^k/20;Jf]P80]KFe0P2c/k<30:ZZZP@0YJFU0P2QXJ420:2PX080XJ6Q0P2PX:030:JVYP80Y:BT0P2V
YZH20:^[Z`80[:b/0P2c/k<20;Vi^@<0];Bd0P2_[jl20:b/[080YjNW0P2IVIT209bLW080Xj>S0`2N
WYh20:FUY@80[Zj^0P2e]KD80<SPf0001P38h=P207IfMP80GEeM0P13@d<503De=@80?Cdm0P0i>CT2
02h^;P80:b/[0P0h>3P304i>CP80GemO0P1:BTX203Hf=P80=3@d0P0[:b/202d];@<0<c<c0P0a<C42
02TY:@80<C4a0P0_;bl2038b<P80<c<c0`0i>CT204Y:BP80HV9R0P1IFET204Y:BP80?Shn0P15ADD2
04M7A`<0DU9B0P1DE5@2065QH@80>c/k0P0[:b/202l_;`80=SHf0`18B4P205IFEP80@D510P0W9bL2
02PX:080;Rh^0P17AdL307IfMP80MGEe0P1nOWh20861P@80HV9R0P0i>CT502XZ:P80;Bd]0P0_;bl2
02h^;P80<30`0P0a<C4203@d=0<0:b/[0P0_;bl202`/;080;Rh^0P0S8b<4028R8P<092@T0P0V9RH2
02TY:@80=cLg0P1OGel207IfMP80O7al0`1/K6`207EeM@80G5aL0P1>CTh205]KF`80MgMg0P2CTi<3
0:>SX`80Rh^;0P1jNWX20;6a/@80V9RH0P2CTi<20;Vi^@<0]KFe0P2c/k<20;Jf]P80];Bd0P2h^;P2
0;Jf]P80^;Rh0P2j^[X30;bl_080^k^k0P2m_Kd20;^k^`80][Jf0P2e]KD20;>c/`<0ZZZZ102UYJD2
0:6QX@80X:2P0P2QXJ420:2PX0<0YZJV0P2TY:@20:JVYP80Zj^[0P2/[:`20;>c/`80^KVi0`2d];@2
0:n_[`80[:b/0P2WYjL209VIV@80W9bL0P2SXj<309jNWP80YJFU0P2^[Zh20;Fe]@P0b>3H00060<SP
f080KFe]0P1NGUh205IFEP<0@d=30P1:BTX205=CD`80A4A40P0c<c<2034a<@80<S8b0`19BDT206IV
IP80FEUI0P19BDT20451@@80;Rh^0P0c<c<303@d=0@0:RXZ0P0`<30202/[:`80;bl_0P0d=3@303<c
<`80ATI60P1QHF4204];B`80>c/k0P15ADD204A4A080F5QH0`1EEED205]KF`80FEUI0P15ADD202TY
:@80;Bd]0P0g=cL304Q8B080D51@0P0f=SH2028R8P80;bl_0P0k>c/205YJFP<0MWIf0P25QHD207al
O080Kfm_0P1;Bd/202XZ:P80:b/[0`0/;2`2030`<080;Rh^0P0c<c<203Xj>P80<C4a0P0[:b/702TY
:@80;2`/0P0];Bd202PX:080:RXZ0`0S8b<402@T90809bLW0P0f=SH205aLG080JFUY0`1^KVh207Yj
NP80Jf][101?Cdl205mOG`80Kfm_0`29RHT208:2PP80OGem0P2a/K4209NGU`80QHF50P2c/k<30;Ng
]`80];Bd0P2g]kL20;6a/@80][Jf0P2b/[820;Jf]P80^k^k0`2f][H20;^k^`80_Kfm0P2k^k/20;Rh
^0@0];Bd0`2_[jl20:VYZ@80YjNW0P2QXJ420::RXP80Xj>S0P2UYJD30:NWY`@0YZJV0P2UYJD20:^[
Z`80/K6a1@2f][H20;2`/080[:b/0P2[Zj/20:>SX`80VYZJ0P2MWId30:FUY@80YjNW0P2YZJT20:NW
Y`P0b>3H00060<SPf080KFe]0P1NGUh205IFEP<0@d=30P1:BTX205=CD`80A4A40P0c<c<2034a<@80
<S8b0`19BDT206IVIP80FEUI0P19BDT20451@@80;Rh^0P0c<c<303@d=0@0:RXZ0P0`<30202/[:`80
;bl_0P0d=3@303<c<`80ATI60P1QHF4204];B`80>c/k0P15ADD204A4A080F5QH0`1EEED205]KF`80
FEUI0P15ADD202TY:@80;Bd]0P0g=cL304Q8B080D51@0P0f=SH2028R8P80;bl_0P0k>c/205YJFP<0
MWIf0P25QHD207alO080Kfm_0P1;Bd/202XZ:P80:b/[0`0/;2`2030`<080;Rh^0P0c<c<203Xj>P80
<C4a0P0[:b/702TY:@80;2`/0P0];Bd202PX:080:RXZ0`0S8b<402@T90809bLW0P0f=SH205aLG080
JFUY0`1^KVh207YjNP80Jf][101?Cdl205mOG`80Kfm_0`29RHT208:2PP80OGem0P2a/K4209NGU`80
QHF50P2c/k<30;Ng]`80];Bd0P2g]kL20;6a/@80][Jf0P2b/[820;Jf]P80^k^k0`2f][H20;^k^`80
_Kfm0P2k^k/20;Rh^0@0];Bd0`2_[jl20:VYZ@80YjNW0P2QXJ420::RXP80Xj>S0P2UYJD30:NWY`@0
YZJV0P2UYJD20:^[Z`80/K6a1@2f][H20;2`/080[:b/0P2[Zj/20:>SX`80VYZJ0P2MWId30:FUY@80
YjNW0P2YZJT20:NWY`P0b>3H00060<SPf080JVYZ0P1VIVH205QHF0<0Cdm?0P1WIfL2069RHP80GEeM
0P1>CTh204I6AP80>c/k0`14A4@205MGE`80FUYJ0P1?Cdl20492@P80<c<c0P0d=3@302h^;P80;bl_
0P0];Bd202h^;P80:b/[0P0a<C4203De=@<0?Cdm0P1:BTX205EEE@80DE5A0P16ATH205EEE@80A4A4
0P18B4P305EEE@80H61P0P1<C4`203dm?@80>3Ph0P0U9BD203Ph>0<0Bd];0P1?Cdl203lo?`80:2PX
0P0/;2`205iNGP80FEUI0`1kNg/20820P080K6a/0P1NGUh203De=@80:BTY0P0];Bd302l_;`80<S8b
0P0];Bd2034a<@@0<S8b0P0d=3@3030`<080;2`/0P0Z:RX2034a<@80<c<c0P0[:b/202l_;`<08B4Q
0P0W9bL202`/;0809RHV0P0e=CD203`l?080De=C0`1_Kfl208Z:RP80MWIf0P1FEUH204U9B@80E5AD
0P1MGEd306a/K080IFEU0P1lO7`20;6a/@80VYZJ0P26QXH20:NWY`<0_Kfm102g]kL20:n_[`80/k>c
0P2g]kL40;Jf]P<0]kNg0P2i^KT20;fm_@80_kno0P2l_;`20;Vi^@D0][Jf0P2][Jd20:b/[080Y:BT
0P2RXZ820:2PX080ZJVY0`2XZ:P20:VYZ@@0[Zj^0P2`/;020;>c/`80/K6a0`2h^;P20;2`/080[Zj^
0P2a/K420:^[Z`@0WIfM0`2ZZZX20:f][@80Z:RX0P2VYZH80<SPf0001P38h=P206YZJP80IVIV0P1H
F5P304m?C`80IfMW0P1RHV8205eMG@80CTi>0P16ATH203/k>`<0A4A40P1GEeL205YJFP80Cdm?0P12
@T8203<c<`80=3@d0`0^;Rh202l_;`80;Bd]0P0^;Rh202/[:`80<C4a0P0e=CD303dm?@80BTY:0P1E
EED2055AD@80ATI60P1EEED204A4A080B4Q80`1EEED2061PH080C4a<0P0m?Cd203Ph>0809BDU0P0h
>3P304];B`80Cdm?0P0o?cl202PX:080;2`/0P1NGUh205UIF@<0Ng]k0P20P80206a/K080GUiN0P0e
=CD202TY:@80;Bd]0`0_;bl2038b<P80;Bd]0P0a<C44038b<P80=3@d0`0`<30202`/;080:RXZ0P0a
<C4203<c<`80:b/[0P0_;bl3024Q8@809bLW0P0/;2`202HV9P80=CDe0P0l?3`205=CD`<0Kfm_0P2:
RXX207IfMP80EUIF0P19BDT205ADE080GEeM0`1/K6`206EUI@80O7al0P2a/K4209ZJVP80QXJ60P2W
YjL30;fm_@@0]kNg0P2_[jl20;>c/`80]kNg102f][H30;Ng]`80^KVi0P2m_Kd20;no_`80_;bl0P2i
^KT50;Jf]P80[Jf]0P2/[:`20:BTY080XZ:R0P2PX:020:VYZ@<0Z:RX0P2YZJT40:j^[P80/;2`0P2c
/k<20;6a/@<0^;Rh0P2`/;020:j^[P80/K6a0P2[Zj/409fMW@<0ZZZZ0P2][Jd20:RXZ080YZJV2038
h=P000H0b>3H0P1fMWH206m_K`80G5aL0`1KFe/207alO080LG5a0P1ZJVX205UIF@80EEEE0P1CDe<3
04U9B@80BTY:0P1ADE4204e=C@80C4a<0P0m?Cd203hn?P<0>c/k0P0b<S82030`<080:BTY0P0Z:RX2
03Ph>080>SXj0`18B4P204e=C@80B4Q80P1>CTh204=3@`80@D511015ADD305EEE@80DE5A0P17AdL2
03hn?P80>c/k0P0W9bL203Hf=P<0C4a<0P1ADE4203Ph>0809RHV0P0f=SH2075aL@80Fe]K0`1iNGT2
07QhN080GemO0P1HF5P2038b<P80:2PX0P0/;2`302/[:`80;bl_0P0j>SX202l_;`80;2`/0P0];Bd5
030`<080=SHf0P0a<C42030`<080>SXj0P0_;bl202TY:@<0:RXZ0P0/;2`202TY:@809bLW0P0Y:BT2
02`/;080@D510`1OGel206a/K080Q8B40P1[Jf/205QHF080EEEE0P1IFET3065QH@80Cdm?0P1bLW82
0:NWY`80XJ6Q0P23Ph<209fMW@<0][Jf0P2`/;020:j^[P80ZJVY0P2a/K420;Ng]`80/K6a0P2`/;03
0;>c/`80]KFe0P2g]kL20;^k^`@0_;bl0P2g]kL30;:b/P80Zj^[102][Jd20:FUY@80Xj>S0P2VYZH3
0:^[Z`80[:b/0P2_[jl20:b/[0@0/k>c0P2_[jl30;:b/P80];Bd0P2c/k<20;2`/080ZJVY0P2WYjL2
0:2PX0<0[jn_0P2c/k<20:b/[080[Jf]2038h=P000H0b>3H0P1fMWH206m_K`80G5aL0`1KFe/207al
O080LG5a0P1ZJVX205UIF@80EEEE0P1CDe<304U9B@80BTY:0P1ADE4204e=C@80C4a<0P0m?Cd203hn
?P<0>c/k0P0b<S82030`<080:BTY0P0Z:RX203Ph>080>SXj0`18B4P204e=C@80B4Q80P1>CTh204=3
@`80@D511015ADD305EEE@80DE5A0P17AdL203hn?P80>c/k0P0W9bL203Hf=P<0C4a<0P1ADE4203Ph
>0809RHV0P0f=SH2075aL@80Fe]K0`1iNGT207QhN080GemO0P1HF5P2038b<P80:2PX0P0/;2`302/[
:`80;bl_0P0j>SX202l_;`80;2`/0P0];Bd5030`<080=SHf0P0a<C42030`<080>SXj0P0_;bl202TY
:@<0:RXZ0P0/;2`202TY:@809bLW0P0Y:BT202`/;080@D510`1OGel206a/K080Q8B40P1[Jf/205QH
F080EEEE0P1IFET3065QH@80Cdm?0P1bLW820:NWY`80XJ6Q0P23Ph<209fMW@<0][Jf0P2`/;020:j^
[P80ZJVY0P2a/K420;Ng]`80/K6a0P2`/;030;>c/`80]KFe0P2g]kL20;^k^`@0_;bl0P2g]kL30;:b
/P80Zj^[102][Jd20:FUY@80Xj>S0P2VYZH30:^[Z`80[:b/0P2_[jl20:b/[0@0/k>c0P2_[jl30;:b
/P80];Bd0P2c/k<20;2`/080ZJVY0P2WYjL20:2PX0<0[jn_0P2c/k<20:b/[080[Jf]2038h=P00?l0
b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0
b>3H8@38h=P00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.20067, -3.20067, 0.468297, \
0.468297}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Denoising", "Section"],

Cell["\<\
Now, let's try to denoise the image, by chopping near-zero values in the LH, \
HL and HH components (or low-power white noise), and subsequently \
reconstructing the image. Note that we chop away more in the HH subband than \
in the LH and HL - but we didn't have to. This technique is called hard  \
thresholding.\
\>", "Text"],

Cell[BoxData[{
    \(\(thdecomp\  = \ decomp;\)\), "\[IndentingNewLine]", 
    \(\(thdecomp[\([2, 2]\)]\  = \ 
        Chop[decomp[\([2, 2]\)], 32];\)\), "\[IndentingNewLine]", 
    \(\(thdecomp[\([1, 2]\)]\  = \ 
        Chop[decomp[\([1, 2]\)], 8];\)\), "\[IndentingNewLine]", 
    \(\(thdecomp[\([2, 1]\)]\  = \ Chop[decomp[\([2, 1]\)], 8];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Graphics[Raster[\((ImgIDWT[Interleave2[thdecomp]] + 128)\)/255]], 
        AspectRatio \[Rule] 1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5B6589B3B940272C24212333414C35333235382C2F3B34332F3D35424E533F3D37312B29
2C27406C63645D73674F5C5E656C737474807C7E7F80817F7E7E7F818386888A8A898889
8B8E908D8B8E908D8988898A8C8C8C8C8D8E8F909192929191909091929394918F919492
909498969496999A9B9DA0A4ABAFC6CBCFCECEBD
5C5A6C9BBE9B40252C2B242C343A31363A38352E31373332303F3545484C403634302E2A
2B27406764655D78624F5D626B6E7173757D7C7E7F8082817F808081838587898A89888A
8C8E8F8D8A8B8C8D8D8A898B8E8D8C8D8E90929393939292939291929496979592939493
9193969695989A9A9B9DA0A3AAB3C5CDD1D0CEC1
5A5962719CC2993A2828272F36302C37423A303133313031323F354A4142402E3030322B
2928416464665E7C5A505E6872716F73777A7C7E7F81828281818282828486888989898B
8D8E8E8C8A89888D918D898C908F8D8E909294969695949495949495979A9C9995959594
9293949596999B9A9A9C9FA3A8B6C4CED4D1CCC4
5C595B607CAEB670322026282D2D2F363B342D30332F2D303339344C413F3A2F3031322A
272C476D63666177575660687071717478797B7D7F80818283838281818488898889898B
8D8D8C8C8B8B8B8E908E8B8D8F8F8F91939495969696969595969797989B9D9A96949392
92959797969798999A9B9DA1A7B4C1CCD4D0CBC1
5F5A595F6E8DC1B25D322622282D3333322E2A2F332F2C303533314B423C333232323128
252D4B766268646F565C62696E71737678797A7D80808082848381807F858A8A8889898B
8C8C8B8B8C8D8E8E8D8E8E8E8E8F9194969696969697989695979999999B9C9A96939191
93979A9895949597999A9B9FA5B1BECAD2CECABC
5E61575B6474A7C8A43D2A20272B2F2E2D2C2C3033302D3034383D4D3E41403A312F2F2D
302E4B74696D646B555E676C6F7172777C7B7B7D7F7F808081808081838587888A8A8B8B
8C8C8C8C8C8C8C8C8C8D8F8E8E919497989897979897979797989A9A9A9B9B9997949394
95979795939495949597999CA1ADBAC7D1CCC6BB
5C68565A61668AC4C993362B2D2B2B2A2B2D2F3233312F31333332423C3B3834302E2D28
29264A7070706567565F6A6E717171787E7E7C7D7E7F807F7E7E8083868483878B8C8C8C
8C8E8E8D8B8A898B8C8E8F8F909397999A9998999A989697999A9A9B9C9B9A9998969596
9896949393939492909397999DA9B6C4CEC9C3B8
50665C53596A8EB4CFB67F452026312F2F34383735383B3E404244484242413E3B363334
3C395B736F676B5F585F686D707274797D7E7E7D7D8082817F808183858687898C8D8D8D
8D8D8D8C8B8C8D8E8E8F91929497999A9999999A9A99999A9C9D9D9D9C9C9B9997969798
9997949494949391909194979DA6B1C0CBC6C1B1
4F6160576379959BC0CCC6743A313533343A403D37353436383A3B3A393532302E2C2B28
2D31596F705E6F585A5E666B6F7377797B7D7F7E7D8082828182828283878B8B8C8C8D8D
8D8C8C8C8C8F92919091929597999A9A999A9A9A9A9B9B9D9F9F9F9E9D9D9D9A97979899
9997959596949291919090959DA3ABB9C5C1BDA9
65586D6B5F71868CA7BECEB8512432353131323436322E3033393E3B38363533322F2E2C
31365E70785D6B54585C656A6E7376797A7C7E7D7D7E807E7D808383828588898A8B8C8C
8C8D8F8F8E8F90919191929294979A9A9A9A9B9B9B9C9E9FA19F9D9D9E9E9E9B999A9B9A
97969595959492908E8D8E91969CA4B1BCBEB3A3
9D5C636F606A757D8AAAD3D2A23C2F2F2C3237353133373A3D3F3E3B373637353431302D
32376172805D6652555B656A6E7275787A7B7C7C7C7D7D7B797E83838182848688898A8B
8C8F9191908F8F8F919191909094999A9B9B9B9B9C9D9FA0A19E9C9D9E9E9E9C9B9C9D9A
969595949393928E8B8A8B8C8E949CA8B1B6A69B
B68862626A67686F7B94BCDCC57A3122292B2F2D2B2F33302E38403A31323433312E2A26
2D3466727D5C664D555B656B7072747678797A7B7C7D7E7D7D7F8181818385878988888A
8C8F9191908F8F9091929393949597999B9B9B9B9C9C9B9D9F9F9E9E9E9D9C9C9C9C9B98
969595939291908C88878787888D939CA3A29590
ACAB745F726761677581A0D1D9BF51282725292726292E33373D40372E2E30302E2A2521
29306772795D654B555B666D7273737477787A7B7C7D7F8182807F80828486888A88868A
8E8F90909090909192939597989795999C9B9A9B9D9A989A9E9FA09F9E9C9B9C9C9A9797
96959391908E8C888483838385878B91958D8584
899B8E6C6C706E6D70738DB8D2CE9C302D1F262424272C37424D5346352F2B2C2E272B2C
2D3267777764604F525A666B6F72737475787B7D7E7D7D7F81828181818486888988878C
919190919192929292929495969696989B99979A9C9B9A9D9F9F9D9E9E9D9B9A99979696
95928E8C8B8885817E808283848587898A827C7B
5F6D816B6A7C7F83867B849BB5B3B8633122262324252B3D4D4D49453E3228292E253138
322D5573776C5A53505A65696C70747475797D7F7F7D7C7D80828483818487888988888E
939290919394959392929394949697999A9896999C9D9EA0A19E9B9D9E9E9C9895959594
928D888685827E7B7A7D818384848484837C7674
4E5A6669737C8A909492989FA7A8AE9B5A452523252527343E382F2E2E2C2A2B2F263131
2F32637473665451505B676A6C70747474787D7D7D7D7D7F8082848484868889898B8D90
9291909192949696948F8A90979999999999999A9C9D9FA0A09E9C9D9F9D9A9693949593
9088817E7D7D7D7D7E81848585868585827B7472
2A3B456D8F88949BA4ABB0B4B7BFC3B9B17F2821272525282B2C2D2E2F2D2C2D30283029
2C2E616C70604F4D525C676A6C70747473787C7B7A7C7F808182838486888989898D9191
909091909194969696969698999A9B9A999B9C9C9B9D9F9F9E9D9D9E9F9C989593939492
8D837A77787B7E8081818080808283838079716F
2422254A8E999EA1A3B2BEB7BBC0C2C5BC9A432521202527282727282A2C2E30312D3027
292D5E6A71644B4D545D6567686C707274777A7B7C7C7D8082828283858788898A8C8F91
91919191939597979696969797999A9B9B9D9E9E9D9E9E9E9E9E9E9F9F9B96959494928F
897F77777C80827D756B6260616A72716C666063
2019223181A4A6ADAFBBC5B7BFC0C0C4BAAC64332120282828262526282C303231302E26
272C5A697068494D555C626465696E727577797B7D7D7C8083828182848687898A8B8C90
9392919395979897969797969597999B9D9E9F9F9F9E9D9E9E9E9E9F9F9A94959594918B
857C757B8387867B6B564540435262605A57535B
281E1E245CABAEAFAFB6C4B8B8BBBFBEB5BB9C73372B282523232323252A2F302E2D2928
262D5C6B64624A4D535A6062646A707376787A7A7B7D7F808181818386888A8A8A8B8D90
9191909498979596979899979697999B9C9D9E9E9E9E9D9E9E9E9D9F9F9A959493908C87
817A75818489877A6648303038424E5962656469
201E1F1E35A6B3ADAEAEBEB7B0B6BCB8B1B0A69C574130272221222223282D2E2C282529
262F5E6D575A4A4C50565D60646C737576797C7A797E82817E808284878A8C8B8A8C8E8F
8F8F90959A979395989A9A9997989A9B9B9C9D9D9D9D9E9E9F9D9C9E9F9A9593918D8983
7D787586838787857C5A3A343847596670767879
251F1C1B2487B3A3ABAAB2B1AFB1B4B6B7B8B7BB99744E322924222122282E2A2E2C2928
27315C6F645A46464B535C61646C7475767A7D7D7D8082807E80828486898B8C8D8D8D8F
91919093969696969798999796989A9C9D9B9A9C9F9F9E9F9F9D9C9D9D999492908F8D81
7674747F81878986817B7774747A80807E7D7D7C
28211A1B1C62AA9BA7A6A7AAADAAA8AFB7B9B8B5AE93754A372A232122282F27302F2D26
27345A686051424146505B61666D7375767A7E80808182807F8183848587898D8F8D8B8F
92929191929699989696979696989B9D9F9B989CA0A09F9F9F9D9C9C9A9794918F919080
706F73787F868B8A888684858888888A8B847D7B
282A1F1B1D4297A8A6A7A4A3A2A4A39B979FAAB9BCAB8D5F4025232024282D292E282B29
26315A6D64554541444F5B5D686D7274767B7E7F7E808281808183848687898C8F8E8E8F
90909191929698979697999A9A9B9C9E9E9D9B9EA0A09F9E9D9E9E9D9A96939190908E80
736B71767F858B8C8C8C8B8E9090908F8D847D7B
2631261D21297AAB9FA4A19D968D837C787A81A0AEB9B4906631252024272A2B2B212728
252D5B7164584743454E5B59696D7174777B7E7D7C7F8181818283858788898B8E90908F
8E8F91939496979796989B9D9E9E9E9D9E9E9FA0A0A0A09E9D9FA19E9A9692918F8E8A80
776870757E84898D8E8B888A8D8F8F8D8A837C7B
222D2B2221204C849A9A918C8678726D6674818C919FAE9D6D3929212425272929282C45
252E5A705E4E4444484F5859656C727475797D7D7D7F81808082848687898B8C8D909290
8F9193959798989797989A9B9C9C9D9D9D9E9FA0A0A0A0A0A0A1A19D999795918D8D8B80
766B6F747C82888B8C8A888B8E8E8C8985817D7C
20272F28211F234C787E7D7D7A65646B6B92B4AEA28D8E9E8559452E2221252728282722
242C596D584440444C51555B616A727474787C7D7E7F80807F838686878A8C8C8C8F9291
91939597999A999897989A99999A9C9D9E9E9F9FA0A1A1A2A3A2A09C999898928C8D8C81
75716F747A8085888888888A8C8A8783807E7E7D
24282E31291C1B3251676576816A6A73728FB9CDC1A58690813425222023262626282925
262D5A6B5B403F424D51555C6169707274787B7D7E80818182848687878889898B8E9293
93949597999998979698999A9A9C9F9FA0A0A0A1A2A2A2A3A4A29F9D9A9896928E8F8E85
7C767274787E8386878888878683817E7C7C7D7D
282A2C39311C1D222C4E4D708A76737F7B7F9FC9C9C8A9A7A03C27241E23282724272A25
272D5A695D3F3E414C51565C63696E7275787B7D7E80828384858687888685868A8D9194
969695979898979697989A9B9C9EA1A1A1A2A2A3A4A3A2A3A4A19F9D9C98959291918F8A
837C7775767C8185868787837F7D7C7B7A7B7C7C
25282B352F272523232C2B568A8A757B78788FBDD0D4C6C4C37D2F1E2124292826272823
262B56665A3F3E464A51595E63696F7376787A7D7F8183838485868787898A8F8A8D9194
96969597989796989A9A9B9C9C9D9E9FA1A3A5A5A4A3A1A1A2A1A19F9D9A979492908D89
857F7B7A7B7C7E82858686817C7C7D7B7979797E
21272F3830291F1F231C22458298787572747FA7CED1CFCACFBA4B2A25252A2928262621
24295262543D3F4A48525B60646B717578797A7D8082838383848686878C8E978B8E9193
959696979897979A9D9D9C9C9D9D9D9EA0A4A7A6A4A2A1A0A0A2A3A19F9C9996938F8B88
8682807F807E7D80848584807B7D7F7C7978767F
202E3C4F3522211F20181E336A9187747078798EBCD0CDCDD1D09E332721272627252422
26294E5F4E393F4648515960666C7074787C7E7E7D80848382848788898A8A928E949193
94969898989A9C9EA09E9C9D9E9F9FA1A4A5A6A6A5A5A4A3A2A3A3A3A2A09D9994908D8A
88858382818181828382807E7C7B7B7A7979797E
23374B714E26211D1F1B1F254F8296786E7B7679A5C9C6CCCDCFD3863024262526242323
28294A5D48353F4149505860686D7074787E827F7B7F84828184888A8B88868B90999192
93979B99989CA1A2A2A09D9EA0A2A3A6A7A6A5A6A7A8A8A7A5A4A3A5A5A39F9B9692908C
8A87858382838584827F7D7D7D7A77787A7C7D7C
2C3F57867545231B1D1A1D1E396F9C8D6E74727694B8C7CDCCCDCFC2692B1E2423232422
252B485843383B3F484F5765676C7074787D80807E818382818387898A8A898C91979395
96999B9A9A9EA2A3A3A09EA0A3A6A7A7A6A8A9A8A7A8A9A8A7A5A3A4A5A29E9B9895918D
898786848284858583807E7F807C78797B7C7D7C
394D67877A53261D1D1B1C1C2859979F716E707885A6C6CBC9CDCCCCB544242421232622
222C46553F3B373D47505769666C6F74797B7D8082838282828384878A8C8D8F91939598
9A9A9B9B9C9FA2A3A3A09FA2A6A9ABA8A5A9ADABA8A9A9A9A8A6A3A4A4A09C9B9A97928D
888787848384858585828081817D797A7B7C7D7D
44618396805D281E1F1E1F1C223C7B9B83726F717B9DC1CDC8CECDD4C9A7471E22252523
242845553A37333C48515A66666B7074787A7C8083838383848484878A8D8F8F91939798
989B9D9D9E9FA0A1A1A1A2A6AAABACA9A7A9ACACABABAAAAAAA7A4A5A5A29E9C9A97948E
888786858485868584828181807D79797A7D7F7F
53749CAD996A271E2222231E22255B8D947B6F6B7395B7CEC7CDCFCBCEC78C2F24242524
272542553733313C4A545C61666C707477797B7F83838385868585878B8E8F9091959998
979A9E9F9F9F9F9FA0A2A5AAADADABAAA9A9AAADAEACAAAAABA8A5A5A5A3A19D9997958F
8986858585878886848381807F7C79797A7D8182
5B83AFAA89502424222527242623417996886A6A6F859FCDC9C9CCCCD0D5B86723232523
262B3E4E363535404D555D62696D7175787B7E81838282848787878A8D8E909193969898
989B9E9E9EA0A2A3A5A6A8ADB0AEACACADADADAEAEABA9AAABA9A7A5A4A3A19D99979690
8A88868686868688898581807F7E7C7B7B7F8283
7796B4976F33222A222629292A272E6290936A6B6E7887C6CAC4C9CBCED0D8A431262623
24313A463636394450575D646B6F7376797D81828181818487888A8C8E8F909396979798
999B9D9C9CA0A5A8A9AAABAFB2B0ADAFB1B1B0AFADAAA8A9ABAAA8A6A3A2A09C99979691
8C8A88878786858A8E878080807F7E7C7C808384
9F9F946F4A2B2628222427272728294983957C676F767DACCCBFC3C6CBD1D8C372302322
222E364231353A3F45525F666B7177797A7C7E7F8082848485888B8C8D8E909396989899
99999A9B9CA1A5A7A8A9AAAEB2B0ADAFB2B2B1B0AEABA8AAACAAA8A7A5A3A09E9B989593
908D8A898888898B8D888381817F7D7C7C808384
AD936B472A272A2521222423232828346F908F687176798FC8BCBEC2C7CECDD2B5452825
222B323F2D3239424B5660666B737A7B7A7B7B7D8083868483878B8C8C8E909396989999
9998989A9DA2A5A6A6A7A9ADB1B0AEB0B2B3B2B0AFABA9AAACABA8A8A7A4A09F9D999494
93908C8A8A8B8D8C8B888583817E7C7C7D808384
9877462F21283028212123222324232B54829A7A7172757DB4C4B9BFC4C7C8D2CC9B3A22
292C303F2D3237404A5763696D757A7977797C7F828587858486898C8F90909193949698
999A9A9C9FA2A5A7A8AAADB0B3B1AFB0B1B3B4B2AFACABADAFADA9A8A6A4A1A09E9A9592
8F8F8E8C8B8E908E8A898784817E7C7D7F828384
76562B222222232323232424241F1F27396F9C8F746F73739CC9B8BFC0C1C4C5CCBF6734
2F2C2F3D2E31353F4B58646B7076797775797E81848687868585868C9191909090929497
9A9C9D9FA2A4A6A8AAAEB1B3B4B2B1B1B1B4B6B3AFADADB0B2AEA9A8A7A4A2A09E9B9791
8C8E908E8C9093908B898785827E7C7E81838484
583F2A25252527262425252C242121212A558E927B69737585B8C4C1BBC2C1BFC4D3AB3A
2F272B312D3036414D58626B72757777787C8081828384858585868A8E91939392939597
9B9EA1A3A6A7A9ABADAFB1B2B3B3B2B5B7B7B5B2AEACABADAFACA9AAAAA6A19F9E9C9995
919192908F9293908C8A888784807C7F82848585
4430312A27282A28272827332625241D223C77969270737973A1CCC4B6C3C0BDB9CBCC8F
312729282C3036424F58606A737575787A7E81817F808183868686888B91969694959799
9CA0A4A7AAABACAEAFB0B1B2B2B2B4B9BDB9B4B1AEABAAABACABAAACADA7A19F9D9C9B99
97959392929393908D8B898886827E7F82848586
5230313338312A2A2B2927312D29241F23325890A28670757489BBCDB2C0BEBCB9C4D2B5
6D2D22272E3137404A55616A717577787A7D7F7D7C7E808386888B8B8C9297979798999B
9DA0A4A9ACADADAEB0B2B3B3B2B3B4B7B8B4B0B0B1ADAAADAFADABACADA9A4A29F9E9D9A
97969594929394918E8C8B89868381807F828585
6137322725272B2D2E2A282D332C2423272E3D79999372717A76A3CEB0BABDBDBCBCCBD3
AC40292B2F31363C445361696E757979797B7C7B7A7D8183868B8F8F8F939798999A9B9D
9EA1A5AAAEAEADAEB0B3B5B4B3B3B3B3B3AFADB0B3B0ACAFB2B0ADACABAAA8A5A19F9D9A
96969794929394928F8D8C89858584807D808384
4E372F2A2A2B2D2D2D2C2B2C2F2D2A28292A335B8899846F787688B3B6AFBCBDC0BFC7DA
C9963A1C262E323B445360676C73787A7A7B7D7C7C7F8284868A8E91929395979A9B9C9F
A2A4A5A9ACADADAEB0B2B4B4B4B2B1B2B2B1AFB0B1B0AFB1B2B2B1AEACAAA8A5A29F9C9B
9A979493939393908E8C8A878584848280808080
3A362C2C2E2E2E2D2C2D2F2C2A2D2F2C2A28303E6E96987175797294BAA7B9BEC4C3C2CF
D1C67F311E272E3945525E656A7177797A7C7D7E80828485878A8D9194949396999B9CA0
A4A6A6A8AAACADAEAFB1B2B3B4B1AFB1B3B3B2B0AEB0B2B1B1B2B3B1ADAAA7A5A39F9B9C
9C9691929493918F8D8A87858483848483817E7E
41332D2E32312F2F2F2E2E2E2E2E2E2C2B282B304F86A38070716E82B3B5B1BBC1C2C2C9
CED8B2572E242A35444F5961676F7678787A7D7E80818386898B8D9093959596989B9EA1
A2A5A7AAACACABADB0B3B4B1AEADAEB1B3B3B2B1B1B1B1B0AFB0B1B0AFACA9A7A5A19D9A
979593939593918F8D8A87858484848481818181
49302E2F34323031312E2C2F322F2C2C2C2A29283370A59170697075A5C2ABB6BCC0C2C4
C5D3CDA93C2A2933424B545D656E757676797C7E7F8081868A8C8D8F92969897979BA0A0
A0A4A8ABAEACAAADB0B4B5AFA9AAAEB1B3B2B0B2B4B1AEAEAEAFAFB0B0AEABA9A7A39F98
93939494949391908D8A8685858585827F828485
5130282B3433312F2D2C2C2E302E2C2D2D2A28252E56929C8467686C8DB7B6ADB9BCC1C0
C0CCD1C58D3532344046505B656D737474777B7E81818185898B8E9092969A99999CA0A1
A2A5A8AAACABAAACAFB1B2AEAAAEB2B3B2B0AFAFB0ACA9ABADAFB1B1B1AFACA8A4A09C98
95939291909192908D8986848384867D7F808281
412724293332302C292A2C2D2D2D2D2E2E2B29262F3E769E986C636677A4C0A7B4B8C0BE
BDC4CBCFC47C34333F454E59646C717374777A7E82828184888B8E9093979B9B9B9D9FA1
A3A6A8A9A9AAABACADAEAEADADB1B5B3AFAEADACABA8A6A8ACAFB1B1B0AFADA7A19D9998
97938F8C8B8F93908C8885828183867A7F7E7F7E
32282B3035322E2D2C2A2A2C2F2F3130302E2C2D2A3154899E8468676E91BBB5A9B4BEBE
BEC3C7CBC4B85B3236474E5760696F7274787B7E808182868B8C8D909497999B9C9D9EA1
A5A7A8A6A5A7AAACAEAFAFADABACADACABABABACADABAAA9A9AAACADADACABA7A29E9B99
97918C8A8B8F918D888685838282837E81807F83
3332313537322C2D2F2B282C3132333231313033262A366C9A9B726A6B7FADC0A1AFBBBF
BFC0C0C6C8C9B14E37474D555D656D7175787C7D7F8082888E8D8C909596989B9D9D9DA2
A6A8A9A4A1A4A9ACAFAFAFACA8A6A5A6A7A8A9ACAFAFAEAAA6A6A7A9AAAAA9A7A4A19E9A
958E898A8C8E8F8B868584848382818283827F89
2F31313333302C2C2D2B2A2E313931323232313229282E51859E8568647090B5AAABB7BB
BDBEC0C5C8D7C8A4443543555B646C717476797C7F8285888A8C8D919597989B9E9E9FA2
A6A7A8A4A1A4A9ACAFAEACA9A6A6A6A6A7A7A8ACB0AFADACABA9A8A7A7A9ABA8A3A8A19B
948E8A8A8B8E918D888786858382818282817F8A
2E2E2E2F2F2E2C2B2A2B2D30313D2F313232322E2C282D386995956C616574A2B4A9B3B6
BABDC0C4C7D0CEC28A463E5059636A6F7374757A7F848887868A90939697989B9E9F9FA2
A5A6A6A4A2A4A7AAADAAA7A4A3A5A8A6A5A5A7ABAFACA9ACAFADA9A6A5A9ADA9A2ADA49D
938F8B89898D918F8B8988858382828180807F8A
2E2D2C2D2E2E2D2B2A2A2C3134392F2F3031312C2724282C497F98886B626B8CB1B4AFB4
B7B9BBBFC4CBCFD6BE804539545D666C707274787D838887868B90949798999A9B9C9DA0
A2A3A3A3A2A2A3A3A3A09D9C9C9FA1A09FA0A2A5A8A6A5A8ACACABA8A6A8AAA6A1A9A6A0
97908A8685888C8D8C8A8783808182818081828C
2F2C2A2C2E2E2E2C2B2B2C3236332F2E2D2F3029232224252E63929F7A656979A7BDADB1
B2B4B6BAC0C6CCC9CFBA713C515561676C7074777B818687878C91959899999897989A9D
9FA0A0A1A19F9D9B999693949698989897999C9E9FA0A0A3A5A8AAA9A7A6A5A2A0A3A7A3
9C9188838183868A8C8A87817D8083818083858D
2C2C2D2D2E2F2F2C2B2D303234312F2E2D2D2D292424252125437C979174676E94B9B7AB
A9ADB5B7BBC0C6C8D1D0AE6D47445C61696F74787B808687898D929496999B9A98989899
9A9B9C9C9B999796959290929494949392949596979A9D9F9EA2A4A5A4A6A7A29EA0A5A4
A1958883818285888A898783808081807F82848D
292C312F2F2F2F2D2B2F33323130302F2D2C2B292726261F22275F84A18669677FACBFA6
A1A8B3B4B5BAC0C6CAC9CCA45F4E575B646C74787B8084878A8E929394989B9A99979696
969797969593929394918E9093918F8E8D8E8F8F90949899989A9D9FA1A5A7A29C9DA0A3
A3978A84818284868888878683817F7F7F81838D
2C2C2D342F30302E2C2F32312F2F2F303031302B2725241F201F40719A9873627190B7AE
9FA5AEB4B1B6BBC2C8C9CFC6A2604F5059656F767A7F8385888B8F929394949596969696
95949290909192959690898D908C88888887898B8D8D908994959A999FA0A09C9897979A
9C968E837B7D82858787858483817F7F7F83858F
2F2C27363031302E2C2E312F2D2E2F313435342E272422201F1F265A87A080626673A8B7
A3A6A8B3AEB2B6BEC6C9C8CBC1A057574F5C6B73797E818385888C9093908D8F92949596
95918E8C8C8F9397988F85888B878280808084888C888879918F92909F9C989796939092
94948F82767980838685838282817F7F80858891
2B3137382D2D2D2C2C2F312F2C2D30333635322D25252523211E213C68909270606592B8
B3AA9FAEADB2B5BCC2C7C9CBC8BB985D58556970787C808386888B8D908E8C8E90929392
91908F8E8E909395948B827A82817F756D7F81878889796D85868287A19A93979D9B9895
938E887E76787C81848483828281817F80878D93
292A2B2B2B2B2B2B2C2F322F2C2D30333634302B26262725231F222347769D81615E7CB3
C2B19AA9ACB1B5BAC0C5C9C8C5C9C4975850696E757A7E838788898A8C8C8C8D8F90918F
8E90929190908F8F8E867F6E777B7D6C5C7F7F88888D726E817B677BA39C929BA5A6A29C
948A827C78787A7E828383828182828080899294
2A2929292B2C2D2D2E2F302E2C2C2D303434342A2E2925242522221C30578E9474586A9E
C0C1A7A5AAAEB4B9BDC3C7C9C9CAC9B595705E626F767C808485858A8687878B8F90908F
8E90928F8B87848589857D6D6C737969597B8086837E6A6A7F75657EA3A5A1A7ACADACA5
9C91877F7B7A7C7C7D7F818080818381828A9394
2C2825272B2E3030302F2E2F2F2D2B2D3034382B372C23232624231D213B749D895C5F86
B5CBB8A5A7AAB1B6BBC0C4C9CBC8C3C5BE8E5F5E6971797E8081808A818282888F90908F
8E8F8F8B857C767A81817B706770796C6078848D92919496A89C9298A1A9AEAFADAFAFA9
A0968C847E7D7D7A777A7E7F7F818383848B9294
2C272325292D3031302F2F3539342F2F302E2E2D3A31292626242321232D54899672516F
9AC1CAB0A3A6ACB2B8BCC0C7CBC9C5C8C6AD8E715E64797C7D7E7F8582807F8890928F8F
8F8D8B867F766C70676776726D79868B8D94969B9FA2A7ABB5AFABB0B4BCBEB0A09D9C92
8B888784827F7C7976787C7F82828282838C9496
2B272424272C31323130303A413B332F2D30353839342E29262323252B25396B96905F67
7BABD2BDA1A1A7AEB5B9BCC3CACAC8C6C3C5BE8D605F7979797C7E80827F7D8791928F8F
8D89837C756D63675351707D888C8F969DA0A4A8AEB4BBBFC1C5C4BAAEABA79D928C877B
7479808384807A7776777A7F84838181838C9698
2B2B2A29282D323434312F323E3E303235312E3234362928282623211F392C54849A7B61
6489C0C19E96A3ADB7B8B8BFC7C8C8C7C5C8C5AD9273656F7E7F7C7B7C7C7D86908B8F8C
887F75685C59596361657A838A87828388909CADBCC1C3C7C8CBCDCDC8B49F918A92968C
70737C81837D767677797C7F81828282848C9394
2C2E302D2A2E343A3E352D2937402E2925272A2E2F3623272B272221242A363C588A9664
5667A3C4AB969FAAB7B6B5BBC3C6C7C7C7C5C2C7C39A6F6B7175797876797E858C828D87
7F736651414551627476737E857A6D66677489A4BCC4C7CACCCFD1CFCAC0B29B878C9191
70737A7D7E797374787A7C7D7E818384868B9091
3C362B292A2E354350402A29353A312D28292B30323427292B272424272C302E3F6B977D
595382AEB99F959FADB0B1BCBEC3C7C8C8C6C4C9C9B5997E69677577777C8282827D837D
736B564131384A5D6F777A79715C5044404C607FA0BCCDCECDD0D1D0CCC5B9A6928A837E
68777D7A727173777A79777B7F828587898E9298
38312726292C36577151292A3233332F2B2B2D3337312C2A2A2827282A2B2C272C417C8A
664F6786A79F929BA5A9ADBAB8BFC5C8C8C7C6C4C3C9C5986B607174787E827D7676756F
656047342731455869757B6E5B3F3A383B393D4F6B9ECAD0CED0D0CECAC8C2B19D856F65
627B7E74676B73787B767278808486898B90949E
3A2D282628303A68794E332D2E2D2F2D2C2B2C3338312A2829292A292728282424315976
70575A7A9EAEA195969697A6AEB6BDC3C7C9C9C6C4C9CAB498776766737C7A736A67635D
544B39323045505D6F7A73523D3C4C545952483A4269A9CED1D0D2CFCDCDC9B69E7A5C53
657E7667616C7074757474797E8386878990979C
38292B262634437A78473E2F2A282A2B2C2A2B3338312726282A2C29252526232432476A
856F58708EBDC1AAA299949BA7AEB5BDC5C9CCC9C5C5C5CAC597685C6B766E685E57504B
46392F2B2C454A5B757B62413D4F635D545758423B4480C6D2CFD2D0CECFCAB4976C4C48
6B7E6A5C61706E6F6F73777A7D82868788909798
302F2D272834548358354132292627292C2C2C3337312A27263139322A27272836464B61
8E91736473A9C8BCA8A1ACACAEB2B7BABEC6CDCBC8C7C7CDCBB2916958636761564C4239
312E2E2D2F414A5E716B483F5A5C5A4B3F485A674B3858B1CFCDCDCECECAC1A87F5B4556
7C785D5C6A7372706F757C7F808487898B8F9298
29352E292B33668F4A303E322A2625282C2D2E3236332E2B282D3233332C282E494C383A
719D91645C8DC2CCB3A3B1B3B8B9BAB7B7C2CCCDCACAC9C9C6C6BC7D5455605B51443936
35312E2E3139465C69593136615A4B36262A44724D3441A0CBCAC6C9C9BFAE92624A4164
856C5160747777737178818384878A8C8E8E8D99
2B322D272E3B777D392C35302D2A282A2D2D2E30303133282C34444A4339382825252028
538C9E805D719FC3C1A9ACAFB4B6B7B5B5BBC3C9CDCBC7C6C5CDC7B76C515154554C423B
362F2B2B2E343D4F5950313A52453328241F3C593F37479ECFD0C5C3BBB28A6A433B3D5D
6A544D637B7C7A76747A818486888B8E90919197
2F2F302A314683652E2A2D2E2F2E2C2C2D2D2D3032363C2B36394E5A4F312A2625201F24
326D9E9C6A5E78B1C9B0A5A7AEB1B3B3B4B5B9C5CFCBC4C3C4C6C6C1B1694E4F59544D44
3A302A292C2F3541484028333D383026252C5956435978AECCCCBDB5A39C63432B2F3A4F
4B3E4E667F817C7A787B8184878A8C8F91949696
302E3C3C325588542A29302F2D2C2A2A2B2929354E5E605251576C5938292B26211F211F
274F8A9F89626397BEC1B0A5ABACAFB1B4B6B9C4CDCBC6C5C4BFBBC8C4AC6244484F4B4A
453D2D2C2E2F313639372E3335322D29292D44413E5B7FA4BBBDAF9777633A2D2826262C
2A37556E8385827E7C7E8285898A8C8F92959796
32395553306088462929342F2A28282829272C416C7B7070684B3D2D23272B282425271F
22336B96A4735B7EABCBBDA8A9A8ACB0B4B7BAC3CACBC9C6C3C0BFC2C1C1A858404B4743
3B3F32323130302F2E31333331302E2D2D2E2F333C485D83A39D886A4C372B292B292827
2D455F75858886827F8082868A8B8C8F93969798
26424B462F5F7E392A262F2B27252523282A4C5F787D6F5F4A312420252B2F2B26262624
1F23457DA292666E90B9C3B5A5A8ACAFB2B5B8C0C7CACAC6C1BEBDBFC1C6C1A7644A4040
40443534333231303132343332302F2E2E2E2D2E3341476379705E4A382C28272925252C
3C597280878784817F8082878B8C8D909396999A
39563A322F5B732F2B242826252323222A366F77766F6243272326272A2F322E2826232A
1E1C245E91AB7967789EC1C2A5A9ADAFB1B3B6BDC4C8CAC6C1BEBCBBBDB4C3C19F5E4440
44483B3836353435363534343433312F2E2F2F2E2C3A3344514636312E2C2B2A2A27293C
556F84898785817F7E7F82878C8E8F9193989B9C
4943312B305D6A2D292226262626282B375A787C6D50332A2827262D2C2F312C26292B2E
1A1F1F4070A691766E80A8C6B4A7ACADB0B2B5BCC3C8CBC8C4BFBBBABBB4BDD2C891573D
42494846423E3A3632353837343332302F2E30302F363033383A3B33282527292C31375F
828888858282837F7D8085898C8E9094989A9C9D
562E2A29315F622E28222525282B313A467E7A63413128292E2D2B352D2F2F2A25242328
1C2822274D91A28A6D678BC0C1A7ABABAFB0B4BBC3C7CACAC8C1BBB9B9B6B3BEC3C89C62
484A54524E49433A3339403C363535343332323234353633302E2D2C2B27262D36424C6D
888B88817B7F837F7B80878A8C8F92979C9D9D9D
432C2A2C345A5F2F2C252525272A2E4957755E3F2925282A2E2E2D322E2E2D2B29252324
3135211C3269989C7D61759FBDBAAFA6ACADB0B7C0C5C8CBCBC5BDB9B5B2AFB6BFD6CC9B
674950535856514D4B4D4F423F3D3D3E3D3E34313032353F36342C2B3334303E4B746062
798A817E797A7C7A787D83878B91969A9D9E9E9E
2E2D2C3037555D31302827242632405D636D57342A292E2D2D2E2F2D2D2D2D2D2C282A26
453D2019204080A48F66677CAFC7B4A4AAA9ACB3BCC1C6CACCC7C1B8B1ADABAFB5BEC5CB
AB66545561605E616464624C4C494A4B4B4F3D312C3D506A5C4F322C41463E57707B8059
6280777976757473747980868D949A9D9E9FA0A0
2D2C2A30365557312B26282529324B646A60352527272A2B2C2F302C292A292A29262D3B
48321D1B1E2F5A93997E666E90B5BEB5A6A7ABB0B6BDC2C6C8C7C3B9AEA9A6A9AEB7B8CF
C7B07160615E686C6D67605B636261686C6A56442B476A888978514765684A5E717D8065
637573706B6C6E6D6F77828C94999B9EA0A1A2A2
2F2B282E34544F33262428262B3255656A5C2D29272626282B2F302B26292B29293D525C
43282220222634779996706D739BC0C2A5A7ABADB1B8BFC2C4C6C5BBAEA6A1A2A7B9BAC3
C7C5B684665D6F707174767777797A7B7B7A725B325A8892918F755E787F59626B747871
65676C66606267686B7887949E9E9D9FA2A3A4A5
282A2D2A344E44372E2A272B2F365B63674B3228262526282A2C2D2A29253536466E6949
2B29331D1F2123517E998E807583A4B8B9AFA5A9AFB4B9BDC1C6C7BFB4A69C9CA1AFB5BD
C5D0CBAE94786E6B787B7D7F7F84898A8887826A55759AA09E998873828B71606A6A6A66
5E5A5B56535357606D7D8E9BA5A5A2A3A5A7A7A8
2228312632473A3B382F26312F385C5F5E393B2C25252829292929282D3157545F805425
2B4C5A271E1D1C2E5D91A696807182A6C7B7A2A6AEB1B3B9BEC4C8C4BBA999979CA5B0B8
BFC3C4C9C39A726B7F818382838B9292908F8E787B8EA4A6A1999181838C815B655E5B57
534F4B4B4C4B4F60758696A3ABAAA6A7A9A9AAAA
23252A32455E4D453735415B47425559482E383627262627282626272E35505A6380531D
2C5C57302C1E20233F779DA1886E6C8EB5C0B1A5A6ACB2B7BBC1C5C5C0AF9E98979FAAB2
BABFC2C8C8BCA88672737C838A90959898928D82939CA4A49F968E817B7A715D61564E48
44434340425164788A98A2A8ABABA9A9A9AAACAD
2625262B2F4A41403A313B522B334E553428333F2A28252628252428324F655B3D676228
345D392F3E222721285786A290745E7799BFBEA7A0A7B2B5B8BDC1C5C4B6A69A949BA5AD
B4B9BDC2C4C6C0A68A7D78808C9093989C9A9991A09E9C9A978E83796E655C5247474741
3D3E444C586B8092A1A9ADADAAABACAAA9ABADAE
2527282A2B41474751423B3E25384B492F292F3D2E2C2829292B2638496563352A48622A
485B2C2F4B28231F273B648F998A6066799DBAB4A7A4AFB2B5B9BCC3C5BCAFA196989FA6
AFB7BDC0C1C4C5C2B6967A7B85898E949A99969399938B88847C72685C4C404345403C44
4F555D6F838E97A3ACAFAFAFAFB0B1AEACACADAE
24292E2A272B373A554736333749463B2F2D2C3933302B2C2C3028465F6C4D44323D612D
5D55232E55301F1F2A2442729A9E6C5F5E78ABBCB0A5ACAEB2B4B7BFC5C0B6A79A979AA1
AAB4BDBEBEC0C2C4C2B099837378848B91918E8D89817874706A63584D443F4349494B59
69737C8D9DA5ABB0B3B1AFB0B3B4B5B2B0AEADAD
2529382C292C3530383532363E473A332D2D2C3738322C2D3140494C564F35383D385631
684A28315D3822222B1F2C4C85A0856C59668BAAB7B5A9AAAEB0B3BBC1C0BAAA9B989A9D
A3AFBBBEBFC2C4C5C5C7C09C7669666D71757878746E6A6764636158505053585F69737B
848C95A0AAAFB2B5B6B4B1B1B3B3B3B2B1AFACAC
2629402E2C2F343635322E32343B302F2D2C2D343A332C31383334324D40332A2D366448
6D3E2F335E442922211C212B67949980625F6A91B6C2A9A9AAACAFB6BDBFBCAC9C9A9B9B
9DABB9BEC1C3C4C4C2C2BFBAAA7D5258565C606161616160606467605C6570767A7F8591
9DA3A8ACAFB2B4B6B7B5B3B2B2B1B0B1B2AFADAC
23293A2F30373E3A3231332F363E2A2B2B29292D32302D313538352B4A352C252A305D58
6B3C292C575D32322E262222456F92957C685C789BBDBAB2A6A7ABB2B7BAB9ADA09B9A99
9BA7B5BCC1C2C1C3C4C2C0C0BCA78C4F454754595D6766696B727877777E85888C9299A0
A6AAADB0B1B2B4B6B7B5B3B1B0B0B0B1B1B0B0AF
20283231313C464847403A2F3A432B2B2B282627292C2F31323830315B412922272A5466
6A3C23254B6F3E4A4B3B282329477D9F967759627AADC7BAA5A4A8ADB2B5B5ADA49D9998
9BA5B1BAC0C0BEC1C4C0BBBAB9BCB69D6D534450627471777C838A8F93949597999FA5A8
AAACADAFB1B1B1B4B6B5B2B1AFB0B1B1B1B2B3B3
1F262C352B2C2F44595F5D5547454039322D27282A2C303437352E2F54582825252A4363
683925243B63452E3B37322A263253869C8B645D648AB2BCB1A8A3A9AFB1B1AEA8A29D9B
9EA7B1BAC0BFBCBEBFBEBCB9B7B9B9B5A68A706A6D7A7F868B9094999C9E9FA0A2A5A9AA
AAACAFB0B0B1B1B3B4B4B4B2B1B1B1B2B3B5B6B6
2225283625292D394758636C564A53473A322B2B2C2D30373D322B2D4B6F2C29242A3464
753F29232C5B662A292E3A3228242B639497725F566996B4B8AEA2A6ACADADADABA6A09F
A0A8B2BAC0BEBBBABBBCBCB7B2B1B2B2B3ABA08B7B818D93989A9B9EA0A3A5A6A7A7A8A8
A9ACAEAFAFB0B2B2B1B3B5B4B3B1B1B3B5B7B8B8
2C2924323128353D46494E6673644948493930262A2B2D3A3A2F272A42713B28262C3862
6E3D342E2748783A2B2134322F25244171918B6C57567095B6B8A19DA5A8A8A8A7A39F9E
A1A8B1BAC0BFBCB9B7BABBB6B0B1B1B4B0B1B0A79D9795979B9EA1A3A4A5A6A6A6A6A6A7
A9AAABADAEB0B2B1B0B1B3B3B2B2B1B1B1B4B8B8
3633232D3C2B3E3F4036344A6D6C3F3F4335362427282B3B362D24273A6A4C27272F405D
62393C3B29265B7840272D25232025284B778A70615D63759BBAB2A1A1A1A4A4A3A09D9E
A1A8B0B9C0C0BDB9B5B8BAB5AEAEADBBB5AFA6A7A7A29D9B9B9FA4A5A5A5A5A4A3A3A3A6
A8A8A7AAADB0B2B0AFAFB0B1B1B2B2B0AEB2B8B9
3B4E2C2834333533312D2D3047676B634A33372C26272C39392F2728345D5D29242F444B
513C3F3C302645716A452A21211F21203252707D7E71686C83A3AEB1A69DA1A1A1A09FA0
A2A9B0B8BFBFBCB9B7B9BBB5AEA19FB4B6B5B0A8A9A6A29E9B9DA0A2A4A5A6A4A1A1A2A4
A7A6A6AAADAFB0AFAEAEAFB1B2B3B4B2B1B5B9BA
3D613524283B2A2723272C333E4F606E6242373425282D353B322A292F4D682E22314A3B
41342A2E362F2E618D62291E1F1D1E1E25446B8F9387776E6D88A5BBAD9CA09FA1A1A1A2
A4AAB1B8BDBDBBBABABBBAB5AD9290ADB6BAB8A7A8A6A6A19C9A9B9DA1A4A6A39F9FA1A3
A5A5A6AAADAEAEAEADAEAFB1B2B4B5B5B5B8BBBB
244D4D3A2D39292522273A5148403B535E503D3527292F3336362B282C436639263B5735
35362629303830577B55241D201D1E22335E6883949E8D796A788EA1AFAAA0A0A1A1A2A4
A7AEB5BABCBBB9BBBBBAB6AEA28284AAB2BDC0B4AFAAA6A19D9A999A9C9EA09F9C9EA1A2
A3A4A6A9ACADADACACAEB0B1B2B3B5B5B5B8BCBD
27324236262F2C2828314C5E3A2F293E535945372B2B2E31323A2C282B3A5F452B445F32
2E3625292D3F374F5F42211E231F212A4D80675F729C9F8A706F7883AAB4A2A2A1A2A3A6
ABB2B8BBBCBAB8BBBCB8B1A597767DA9ADBDC4C0B7AEA6A29F9C999898999B9A9A9DA1A1
A1A3A6A9ABACACABABAEB1B1B1B3B4B4B4B9BCBD
242B3832292B292E344F5C4E342A28344454523F2F323837333C2C292B35554E2D3D4E2E
2E332D3A4132324E563E2420221D23347384593C51819C98816E747E95A9ABA79FA2A6AA
AFB1B4BBC0BCB8BBBDB7AF96987781ACACBAC0C2BFB7AEA8A49E9B9EA1A49E96999CA0A2
A3A3A3A7ABACACACADAEB0B1B1B1B2B4B7BABCBD
25282B2B2B272836446A6439302B302F33485948332D2B32373F2D2B2D324A5330353A2B
2F2F364F5727324E4F402C24211F2B46937D481D315C8C9E9376767E7D98B0AAA0A3A9AD
B1B0B0BAC3BEB8BBBCB5AE8A9B7D88AFABB4B9C1C6C0B7B0A9A39F9C9BA7A4969B9B9EA1
A4A2A0A5AAABACADAEAEADAFB1B0B0B5B9BBBCBC
252728292A272B3C58664F3D3F3C323439434946332E2D33383C33302F33414E3F37372A
292D37615E2E4C4E4E462F292824306A92673418253B698B99917C7973849BA8AFACA8AA
AEB0B3BAC0BDB9B8B6B4B18C9A888CABA5ADB3BEC6C5BFB6ABA6A2A0A0A6A49D9F9A979B
A1A09FA3A7A9A9ABADADADAEAFB1B3B6B9BCBDBE
2727282829292F42695935424E4E352D2730384333302D3339393834323539444D3B372B
242D396D5D3C6644425046392E354F988752251C2120436F94A68579707583A0B9B4A9A7
A9B0B7BBBCBBB9B4B0B2B492979292A79FA7AEBAC5C8C6BBAFA8A4A4A5A4A4A5A49A9296
9D9D9EA1A4A5A6A9ABACACADAEB2B7B8B9BCBFC0
2B2825282B292F496E4C2D2F353C3835322E33403D342C2F36383B36313235384B3C3428
21304269594C643D4A5B605A575374AF8B5C2C1F1E192D49749B96877773788BA8B4B9AE
A6AEB8B9B9B8B6B2B0B3B49991959AA3A1A7AFBAC3C8C8C1B8AEA5A6A9A7A6A6A39E9997
96989C9FA3A3A3A7ABABABABABB1B6B8BABDC0C0
2F2A24282D2B2F516E3E28252D31373B3E2F323C46382B2C32373B37322F312F443C322F
303D485547525D4869635C53523E68A48D6836241D1A20294F839E958378747690ACC4B5
A5ACB7B8B7B4B1B0B0B3B29E8B95A2A2A5AAB0B9C1C5C7C5C0B2A6A8ACABA9A5A2A3A39B
9395999DA1A1A1A6AAAAA9A9AAAFB5B8BBBEC0C1
2E2A27262F2F355E6D3F27242A2C3344513E33333E3C2B2E3236393A37302C2D3B403635
34363A4950676E6A765A503E3A2E60926D4023211E1E1F20345E809B9A8979737F98B0BA
AEADADB6B5B2ADABABAEAD9C8A91A7ACA9ACB1B6BCC1C5C4BFB4A9A9ACAAA9A8A7A7A6A1
9C9896979A9CA0A5A9A9A9A9ABAFB4B8BBBEC0C1
2F2E2F2630333B676B4429272D2C2E3E4C43372E353E2E303234363B3B32282E35423C3A
372F2E435C6E697B7E4D3D2F3433688D582720251F212320213A5B93A79A8378748294B6
B4AEA4B5B3B0A9A6A5A8A8978A8EA9B4ACAEAFB3B7BDC2C1BCB4ACAAAAA9A8ABADAAA8A8
A79E969394999FA3A7A8A9AAACAFB3B7BBBEC0C0
433A2E272D313A676B4A2C292C2B2C3741463E36363B33312E3034343D3228313A3F3F39
3432364C606F60677840322D2F3D7D88442724262223232220222F608EA4958370727BA1
B5BAABB1ACAAA6A5A5A7A6948692A9B2AEA9A6B0BABEC0BFBBB5AEABA9A8A9ABADABAAAB
ACA8A29B95969AA0A6A7A8AAACAEB1B4B8BBBEBF
504E4736282B37626B52312B2B2A2A2D3245443F373739312B2C322D3C332D37423B4138
3238425762603D3F6D372C2F334F9182362E2C2826242323242025386A9D9F8F766B697F
9AB5B4B0A8A6A5A6A6A7A5918294A7ADAEA59EADBDBFBFBDB9B5B0ABA8A8A9AAABABAAAC
ADAFAEA59C97989DA3A5A7A9ACADAEB1B5B9BCBD
5B5B57473530335B675B352F2A292A2B2D3C403A32363D352C2E322E34393E44483F3D3D
343C494F5E5632335C392F2F456E916F2C2A262627242222231E1E1E396F99A79477676F
84A1AFB6B5ABA3A5A6A6A391838AA2A6AAA6A3A7B6C1BEB8B1B3B5AEA8A8AAAAAAA8A7A8
A9ADAFAFAB9E8A919BA1A6A9ACADAFB2B5B8BABA
40403F39322D2F5462613B3128282A2A2C333A332D363E372F30333130404F4F4A433A43
38404A455A4E292D4B3D312F578A8D5D272824282B272121221F1E1E273F71A6AC886F69
7087A3B5BEB1A3A4A6A5A19084809DA3A8AAABA3B0C1BEB5ABB2B9B2A9A9AAA9A8A5A3A3
A4A8ADB4B7B49B96959CA5A8ABADAFB2B6B7B8B8
5C5346332F2E354E5D604B2F29272A2A2B3137312C3138342F3032363B49544C41414148
41423D435F52282D3F423834549089592A2A2B2C2C2A29262422201D1F2A4C82A0978A77
6B73859EBBBDADA2A6A29E8C7D849DAEB1B0AFA4B3BFC0BAB3B6BAB2AAA8A8A7A5A3A2A0
A1A5AAB1B6BCB4A99F9C9DA2A8AAACAFB2B4B5BA
7763482B2B262C40575C5A2E2B272B2A2B3136312C2E31302F30333E4951534639414B4B
47412E426457292F373B2B325290865934374548463A2D28262423212020295483999F89
706669799DB7B3A2A8A09886798CA1BBB9B6B1A8B7BCC3C0BDBCBBB3ACA9A7A5A3A1A09F
9FA2A8ADB3B7BAB4ACA0989DA4A7A8ABAEB1B2BC
7769533426262D3C43515C38332D2D2D2D2A282B2E30312F2D333C4E524F48423F4A534D
43372A3B645726292F372B41618E89635055636A6950352A25232422201F23375682A39E
836C5C627EA3B3AAA59E907B788CACBBBCB7B0AFB9BCC0C1C0C0BEB8B1ACA7A5A4A2A09F
A0A3A7ABB0B5B9B7B2AAA2A1A2A4A7ABAEB1B3B8
745A362B262B303A314759443C34302D2D2E2F2F2F32332E2C39475D574B3C4048545A4D
3C2D2B38615423232A3533547289876A666260574A36252326252423232325242D57829B
94775857627B95ADB8A886789096B2B7BCB6B0B5BABBBDBFC2C2C1BDB7B0AAA7A6A29FA0
A2A4A6A9ADB1B3B6B6B3AEA7A1A2A6AAAEB1B3B3
75552C2A2B303432293F53534038302E2D2D2E2F3031312E2F43565D51453D444F565F48
302B30405B492426273E55667B8E865C4B3D37302C2C2D2A2828282522232420233D5C7E
8D7C62635B5F779AB3AE8977A298A4BAB7B6B2B6B8B9BABDBFC0C0BCB7B3AEA9A5A29FA0
A1A3A5A7A9ACAFB5B8B5B0A8A2A0A0A3A7ADB2B2
725D423934373A2F293B4C5E453C312E2D2D2E2F2F2F2F2F334C61584B43414955566143
262A3649543E262B2B487779818062372A282F2F3032332F2A2B2C28242324232429375A
7B7A6E765E4C5A7691A28A79B39A93BAB3B6B4B5B6B6B8BABCBDBDBAB7B5B3ACA5A2A0A0
A1A3A5A5A6A8ACB3B8B5AFAAA49E9B9DA2A9AFB1
6F604F454E4E4C392C38495F5A4C3B30312F2F2E2D2E3032384C5C4C3A42434D55595641
2D283849523A262D44527B7F776F4A2D28282D2D2F3132302D2C2C2C2C2926252521243D
5A686E7F6B504F60748C807FB29A8AB0B6B8B4B4B4B5B6B7B8BBBCBBB9B8B5B0AAA6A4A2
A2A4A7A8A8ABADB2B6B4B1AEABA29C9FA5A9ACAD
6B635C5066615A4D434247525C52453334302F2C2B2D31353A48534F464F434D545B4B40
36273947523A262D5B5978816E5F35282D2E3232323131302F2D2B30332F292827272A30
3C566D8877584A505D6D657BAE9A84A7BCBBB4B2B2B4B6B5B5B9BCBDBCBAB7B3AEAAA7A4
A3A6AAABACAEB0B2B3B3B2B2B1A79EA3AAABA9A9
796A5D597B72655D554C4648514D473A40372E2B2B2C313B464D514C4450434D545B493F
38273947513826356D63797C605531262D2F313232313030302D2B3035302A2828272827
2B425E6983675956565D5173AE9C83A0B4B2ABAEB2B4B6B5B5B8BCBDBCBAB7B3AFABA8A4
A3A6AAABACAEB0B2B3B3B2B3B2A89FA4ABABA9A9
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf0001P38h=P205]KF`80IFEU0P29RHT30;>c/`80^KVi
0P10@40202LW9`80;2`/0P0T92@2024Q8@<08b<S0P0c<c<20451@@80C4a<0P0e=CD203<c<`80<S8b
0`0e=CD203Ph>080;2`/0P0_;bl203/k>`80=3@d0P0c<c<302l_;`80?Cdm0P0e=CD20492@P80CTi>
0P1CDe<203lo?`80?Cdm0`0g=cL2034a<@80:b/[0P0Y:BT202`/;0809bLW0P10@40306a/K080Hf=S
0P1TI6@205eMG@80Lg=c0P1WIfL204m?C`<0G5aL0P1NGUh206EUI@80K6a/0P1cLg<407AdM0<0P820
0P1lO7`207inOP80Ogmo0P20P8020861P@80Ogmo1@1nOWh207moO`80PH610P23Ph<208J6QP80R8R8
1@2:RXX208V9R@80R8R80P29RHT208^;R`80SXj>0`2@T90208f=S@80Rh^;0P2>SXh2092@T080SHf=
0P29RHT308R8R080RHV90P2:RXX808b<S0<0SHf=0P2>SXh208n?S`80T92@0P2ATI4409:BTPD0TI6A
102@T902096AT@80TY:B0P2CTi<209BDU0<0TI6A0P2?Shl2096AT@80U9BD0P2BTY82092@T080U9BD
0`2HV9P209JFUP80U9BD0P2FUYH209VIV@80VYZJ0P2KVi/309fMW@80X:2P0P2TY:@20:^[Z`80[jn_
0P36a/H20<_;b`<0clo?103>c/h20;fm_@P0b>3H00060<SPf080Fe]K0P1UIFD208V9R@<0/k>c0P2i
^KT20410@0809bLW0P0/;2`202@T90808B4Q0`0S8b<203<c<`80@D510P1<C4`203De=@80<c<c0P0b
<S8303De=@80>3Ph0P0/;2`202l_;`80>c/k0P0d=3@203<c<`<0;bl_0P0m?Cd203De=@80@T920P1>
CTh205=CD`80?clo0P0m?Cd303Lg=`80<C4a0P0[:b/202TY:@80;2`/0P0W9bL20410@0<0K6a/0P1S
Hf<206ATI080GEeM0P1cLg<206MWI`80Cdm?0`1LG5`205iNGP80IFEU0P1/K6`207=cL`@0M7Ad0`20
P80207alO080OWin0P1oOgl20820P080PH610P1oOgl507inOP80Ogmo0P21PH4208>3P`80QXJ60P28
R8P508Z:RP80RHV90P28R8P208V9R@80Rh^;0P2>SXh3092@T080SHf=0P2;Rh/208j>SP80T92@0P2=
SHd208V9R@<0R8R80P29RHT208Z:RPP0S8b<0`2=SHd208j>SP80Shn?0P2@T902096AT@@0TY:B1@2A
TI44092@T080TI6A0P2BTY8209>CT`80U9BD0`2ATI4208n?S`80TI6A0P2DU9@209:BTP80T92@0P2D
U9@309RHV080UYJF0P2DU9@209JFUP80VIVI0P2JVYX209^KV`<0WIfM0P2PX:020:BTY080Zj^[0P2_
[jl20<K6aP80bl_;0`3?cll40<k>cP80_Kfm2038h=P000H0b>3H0P1LG5`205YJFP80K6a/0`2KVi/2
0;jn_P80Vi^K0P10@40202DU9@80;2`/0P0[:b/302@T9080;2`/0P0d=3@203Xj>P80<C4a0P0f=SH2
03Xj>P<0>3Ph0P0e=CD202h^;P80<C4a0P0g=cL203<c<`80<S8b0`0`<30203lo?`80=CDe0P15ADD2
04Q8B080C4a<0P10@40203Hf=P<0=3@d0P0`<30202h^;P80:RXZ0P0[:b/202LW9`80@4100`1WIfL2
06ATI080IFEU0P1MGEd207QhN080HV9R0P1?Cdl305eMG@80HV9R0P1[Jf/206i^KP80LG5a0P1cLg<2
07EeM@<0OGem0P1lO7`207inOP80Ogmo0P20P80208:2PP80PH610`1oOgl40820P080PH610P23Ph<2
08F5Q@80QhN70`29RHT208Z:RP80RHV90P28R8P208Z:RP80S8b<0P2>SXh308n?S`80SHf=0P2:RXX2
08^;R`80S8b<102=SHd308Z:RP80RHV90P2;Rh/208j>SP80SHf=0P2<S8`208f=S@<0SXj>0P2@T902
09:BTPH0Ti>C102BTY8309>CT`80TY:B0P2ATI4209:BTP80U9BD0P2FUYH209NGU`<0UIFE0P2BTY82
09>CT`80U9BD0P2CTi<2096AT@80Ti>C1@2FUYH209FEU@80V9RH102JVYX209^KV`<0WIfM0P2PX:02
0:>SX`80ZZZZ0P2c/k<20<G5a@80cLg=0`3AdM420=3@d080c/k>0P31`L480<SPf0001P38h=P205aL
G080FUYJ0P1/K6`309^KV`80_[jn0P2KVi/20410@0809BDU0P0/;2`202/[:`<092@T0P0/;2`203@d
=080>SXj0P0a<C4203Hf=P80>SXj0`0h>3P203De=@80;Rh^0P0a<C4203Lg=`80<c<c0P0b<S83030`
<080?clo0P0e=CD204E5A@80B4Q80P1<C4`20410@080=SHf0`0d=3@2030`<080;Rh^0P0Z:RX202/[
:`809bLW0P10@40306MWI`80I6AT0P1UIFD205eMG@80N7Qh0P1RHV8204m?C`<0GEeM0P1RHV8206][
J`80KVi^0P1aLG4207=cL`80MGEe0`1mOGd207alO080OWin0P1oOgl20820P080PX:20P21PH4307mo
O`@0P8200P21PH4208>3P`80QHF50P27QhL308V9R@80RXZ:0P29RHT208R8R080RXZ:0P2<S8`208j>
SP<0Shn?0P2=SHd208Z:RP80Rh^;0P2<S8`408f=S@<0RXZ:0P29RHT208^;R`80SXj>0P2=SHd208b<
S080SHf=0`2>SXh2092@T080TY:B1P2CTi<409:BTP<0Ti>C0P2BTY82096AT@80TY:B0P2DU9@209JF
UP80UiNG0`2EUID209:BTP80Ti>C0P2DU9@209>CT`80TI6A0P2CTi<509JFUP80UIFE0P2HV9P409ZJ
VP80Vi^K0`2MWId20:2PX080Xj>S0P2ZZZX20;>c/`80aLG50P3=cLd30=7Ad@80d=3@0P3>c/h20<71
`@P0b>3H00060<SPf080FUYJ0P1IFET2069RHP<0LG5a0P2LW9`20<;2`P80VIVI0P0j>SX402PX:0<0
9bLW0P0_;bl203Hf=P80<30`0P0/;2`203Lg=`80@T920`0j>SX2030`<080<C4a0P0c<c<2034a<@80
<30`0P0a<C43038b<P80?clo0P0e=CD204Y:BP80@D510P12@T820410@080;Rh^1@0`<302038b<P80
:b/[0P0Y:BT202PX:080@D511@1TI6@206IVIP80GUiN0P1lO7`205YJFP80D51@0`1NGUh206QXJ080
LW9b0P1aLG4206m_K`80Lg=c0P1gMgL307YjNP80O7al0P1nOWh207moO`80PH611022PX850861P@H0
PX:20P24Q8@208J6QP<0R8R81P29RHT208^;R`80SHf=1@2>SXh208b<S080RXZ:0P29RHT208R8R080
SHf=0P2ATI4308f=S@80RHV90P2<S8`2092@T080Shn?0P2=SHd208j>SP<0T92@0P2BTY8209BDU0@0
UYJF0P2EUID409BDU0<0UIFE102DU9@209FEU@80UiNG0P2JVYX209bLW0<0VIVI1P2EUID209BDU080
TY:B0P2CTi<309BDU080UIFE0P2FUYH209VIV@80Vi^K102JVYX309bLW080WinO0P2SXj<20:RXZ080
][Jf0P34a<@20<k>cP<0e=CD0P3AdM420<c<c080a<C42038h=P000H0b>3H0P1JFUX205UIF@80HV9R
0`1aLG4209bLW080`/;20P2IVIT203Xj>P@0:2PX0`0W9bL202l_;`80=SHf0P0`<30202`/;080=cLg
0P12@T8303Xj>P80<30`0P0a<C4203<c<`80<C4a0P0`<302034a<@<0<S8b0P0o?cl203De=@80BTY:
0P11@D420492@P80@4100P0^;Rh5030`<080<S8b0P0[:b/202TY:@80:2PX0P11@D4506ATI080IVIV
0P1NGUh207alO080FUYJ0P1@D50305iNGP80J6QX0P1bLW82075aL@80Kfm_0P1cLg<207MgM`<0NWYj
0P1lO7`207inOP80Ogmo0P21PH4408:2PPD0PH611P22PX8208B4Q080QXJ60`28R8P608V9R@80Rh^;
0P2=SHd508j>SP80S8b<0P2:RXX208V9R@80R8R80P2=SHd2096AT@<0SHf=0P29RHT208b<S080T92@
0P2?Shl208f=S@80SXj>0`2@T90209:BTP80U9BD102FUYH209FEU@@0U9BD0`2EUID409BDU080UIFE
0P2GUiL209ZJVP80W9bL0`2IVIT609FEU@80U9BD0P2BTY8209>CT`<0U9BD0P2EUID209JFUP80VIVI
0P2KVi/409ZJVP<0W9bL0P2OWil20:>SX`80Z:RX0P2f][H20<C4a080c/k>0`3De=@20=7Ad@80c<c<
0P34a<@80<SPf0001P38h=P205aLG080FEUI0P1KFe/3061PH080O7al0P2^[Zh20;Jf]P80L71`0P0b
<S82020P80<09RHV0P0X:2P402d];@80;bl_0P0f=SH203/k>`<0=3@d0P0];Bd2030`<080<c<c0P0_
;bl202d];@80<30`0`0c<c<203Ti>@80=3@d0P1<C4`20451@@80?clo0P0j>SX202l_;`<0<30`0P0a
<C42038b<P80:RXZ0P0W9bL202`/;080AdM70`1]KFd206=SH`80IVIV0P1QHF4207MgM`80EeMG0P1F
EUH3061PH080J6QX0P1`L704075aL@80M7Ad0P1hN7P307UiN@80Ng]k0P1mOGd207moO`80P8200P21
PH4208:2PPD0Ph>30P22PX840861P@80Q8B40P28R8P308V9R@80R8R81029RHT208^;R`@0SHf=1@2<
S8`608^;R`80SXj>0P2@T90308j>SP80Rh^;0P2=SHd608n?S`80TI6A0`2CTi<209BDU080UIFE202F
UYH509FEU@80UYJF102GUiL209RHV080Vi^K0P2MWId309ZJVP80UYJF0P2DU9@209>CT`@0TY:B0P2E
UID509NGU`80UYJF0P2GUiL209RHV080VIVI0P2JVYX309^KV`80WIfM0P2QXJ420:NWY`80];Bd0P31
`L420<c<c0<0e=CD0P3@d=020<_;b`80`L712038h=P000H0b>3H0P1LG5`205UIF@80Fe]K0`1PH602
07alO080[Zj^0P2f][H2071`L080<S8b0P0P820302HV9P80:2PX100];Bd202l_;`80=SHf0P0k>c/3
03@d=080;Bd]0P0`<30203<c<`80;bl_0P0];Bd2030`<0<0<c<c0P0i>CT203@d=080C4a<0P11@D42
03lo?`80>SXj0P0_;bl3030`<080<C4a0P0b<S8202XZ:P809bLW0P0/;2`204M7A`<0KFe]0P1SHf<2
06IVIP80HF5Q0P1gMgL205MGE`80EUIF0`1PH60206QXJ080L71`101aLG4207AdM080N7Qh0`1iNGT2
07]kN`80OGem0P1oOgl20820P080PH610P22PX8508>3P`80PX:21021PH4208B4Q080R8R80`29RHT2
08R8R0@0RHV90P2;Rh/408f=S@D0S8b<1P2;Rh/208j>SP80T92@0`2>SXh208^;R`80SHf=1P2?Shl2
096AT@<0Ti>C0P2DU9@209FEU@P0UYJF1@2EUID209JFUP@0UiNG0P2HV9P209^KV`80WIfM0`2JVYX2
09JFUP80U9BD0P2CTi<409:BTP80UIFE1@2GUiL209JFUP80UiNG0P2HV9P209VIV@80VYZJ0`2KVi/2
09fMW@80XJ6Q0P2WYjL20;Bd]080`L710P3<c<`30=CDe080d=3@0P3;bl/20<71`@P0b>3H00060<SP
f080G5aL0P1IFET205]KF`<0H61P0P1lO7`20:j^[P80][Jf0P1`L702038b<P80820P0`0V9RH202PX
:0@0;Bd]0P0_;bl203Hf=P80>c/k0`0d=3@202d];@80<30`0P0c<c<202l_;`80;Bd]0P0`<30303<c
<`80>CTi0P0d=3@204a<C080@D510P0o?cl203Xj>P80;bl_0`0`<302034a<@80<S8b0P0Z:RX202LW
9`80;2`/0P17AdL306e]K@80Hf=S0P1VIVH2065QH@80MgMg0P1GEeL205IFEP<0H61P0P1XJ6P2071`
L0@0LG5a0P1dM7@207QhN0<0NGUi0P1kNg/207emO@80Ogmo0P20P8020861P@80PX:21@23Ph<208:2
PP@0PH610P24Q8@208R8R0<0RHV90P28R8P408V9R@80Rh^;102=SHd508b<S0H0Rh^;0P2>SXh2092@
T0<0SXj>0P2;Rh/208f=S@H0Shn?0P2ATI4309>CT`80U9BD0P2EUID809JFUPD0UIFE0P2FUYH409NG
U`80V9RH0P2KVi/209fMW@<0VYZJ0P2FUYH209BDU080Ti>C102BTY8209FEU@D0UiNG0P2FUYH209NG
U`80V9RH0P2IVIT209ZJVP<0Vi^K0P2MWId20:6QX@80YjNW0P2d];@20<71`@80c<c<0`3De=@20=3@
d080bl_;0P31`L480<SPf0001P38h=P205mOG`80FUYJ0P1IFET305mOG`80KVi^0P2=SHd20<71`@80
/[:b0P1MGEd2038b<P<09RHV0P0R8R8202PX:080;Bd]100c<c<2038b<P<0;Rh^0P0Z:RX202l_;`80
<c<c0P0_;bl202`/;080<30`0`0e=CD203<c<`80<C4a0P1;Bd/20492@P80?3`l0P0c<c<7038b<P80
<C4a0P0X:2P202DU9@80;Bd]0P1;Bd/307IfMP80HV9R0P1XJ6P206ATI080Kfm_0P1FEUH205aLG0<0
HV9R0P1YJFT206i^KP80LG5a0P1cLg<207IfMP80N7Qh0`1iNGT207YjNP80OGem1P20P80208:2PP<0
Q8B40P23Ph<20861P@80P8200P1oOgl208F5Q@D0RXZ:0P28R8P408V9R@80Rh^;102<S8`508^;R`80
S8b<0P2=SHd408j>SP80SHf=2@2>SXh208n?S`80TI6A0P2DU9@;09JFUP80UiNG0P2HV9P209JFUP<0
UIFE0P2GUiL609VIV@80Vi^K0P2LW9`309ZJVP80UYJF0P2CTi<4096AT@80Ti>C0P2GUiL309ZJVP80
V9RH0P2EUID209BDU080UIFE0P2GUiL209VIV@<0VYZJ0P2KVi/209nOW`80YJFU0P2a/K420;jn_P80
b/[:0`3Bd]820<k>cP80b/[:0P2l_;`80<SPf0001P38h=P205mOG`80FUYJ0P1IFET305mOG`80KVi^
0P2=SHd20<71`@80/[:b0P1MGEd2038b<P<09RHV0P0R8R8202PX:080;Bd]100c<c<2038b<P<0;Rh^
0P0Z:RX202l_;`80<c<c0P0_;bl202`/;080<30`0`0e=CD203<c<`80<C4a0P1;Bd/20492@P80?3`l
0P0c<c<7038b<P80<C4a0P0X:2P202DU9@80;Bd]0P1;Bd/307IfMP80HV9R0P1XJ6P206ATI080Kfm_
0P1FEUH205aLG0<0HV9R0P1YJFT206i^KP80LG5a0P1cLg<207IfMP80N7Qh0`1iNGT207YjNP80OGem
1P20P80208:2PP<0Q8B40P23Ph<20861P@80P8200P1oOgl208F5Q@D0RXZ:0P28R8P408V9R@80Rh^;
102<S8`508^;R`80S8b<0P2=SHd408j>SP80SHf=2@2>SXh208n?S`80TI6A0P2DU9@;09JFUP80UiNG
0P2HV9P209JFUP<0UIFE0P2GUiL609VIV@80Vi^K0P2LW9`309ZJVP80UYJF0P2CTi<4096AT@80Ti>C
0P2GUiL309ZJVP80V9RH0P2EUID209BDU080UIFE0P2GUiL209VIV@<0VYZJ0P2KVi/209nOW`80YJFU
0P2a/K420;jn_P80b/[:0`3Bd]820<k>cP80b/[:0P2l_;`80<SPf0001P38h=P205iNGP80HF5Q0P1G
EeL305]KF`80I6AT0P1dM7@20:NWY`80b<S80P2TY:@203dm?@<0:RXZ0P0P820202LW9`80:b/[0P0_
;bl202h^;P80;Bd]1@0/;2`2030`<080<c<c0P0`<30202d];@80<30`0`0d=3@203Ph>080?Cdm0P1=
CDd203hn?P80@D510P10@40203Xj>P<0<C4a100_;bl202d];@80<30`0P0^;Rh204];B`<0M7Ad0P1Y
JFT206e]K@80I6AT0P1[Jf/205EEE@80GUiN0`1WIfL206a/K080Kfm_0P1aLG42079bLP80MgMg0P1l
O7`507]kN`80OGem101oOgl40820P0<0PH611020P8020861P@80Ph>30P25QHD208N7Q`<0R8R8102:
RXX408^;Ra<0S8b<0`2=SHd208n?S`@0SXj>0P2ATI4209BDU080UiNG1@2HV9P409NGU`80V9RH2@2G
UiL209RHV0H0VYZJ102KVi/309VIV@80UiNG0P2DU9@209>CT`80U9BD0P2EUID509NGU`80UIFE0P2C
Ti<209BDU080UIFE0P2DU9@209FEU@<0UiNG0P2IVIT209bLW080XJ6Q0P2][Jd20;Zj^P80alO70`3A
dM420<c<c080a/K60P2k^k/80<SPf0001P38h=P205iNGP80HF5Q0P1GEeL305]KF`80I6AT0P1dM7@2
0:NWY`80b<S80P2TY:@203dm?@<0:RXZ0P0P820202LW9`80:b/[0P0_;bl202h^;P80;Bd]1@0/;2`2
030`<080<c<c0P0`<30202d];@80<30`0`0d=3@203Ph>080?Cdm0P1=CDd203hn?P80@D510P10@402
03Xj>P<0<C4a100_;bl202d];@80<30`0P0^;Rh204];B`<0M7Ad0P1YJFT206e]K@80I6AT0P1[Jf/2
05EEE@80GUiN0`1WIfL206a/K080Kfm_0P1aLG42079bLP80MgMg0P1lO7`507]kN`80OGem101oOgl4
0820P0<0PH611020P8020861P@80Ph>30P25QHD208N7Q`<0R8R8102:RXX408^;Ra<0S8b<0`2=SHd2
08n?S`@0SXj>0P2ATI4209BDU080UiNG1@2HV9P409NGU`80V9RH2@2GUiL209RHV0H0VYZJ102KVi/3
09VIV@80UiNG0P2DU9@209>CT`80U9BD0P2EUID509NGU`80UIFE0P2CTi<209BDU080UIFE0P2DU9@2
09FEU@<0UiNG0P2IVIT209bLW080XJ6Q0P2][Jd20;Zj^P80alO70`3AdM420<c<c080a/K60P2k^k/8
0<SPf0001P38h=P205aLG080J6QX0P1FEUH305YJFP80HF5Q0P1VIVH208Z:RP80a<C40P39bLT209>C
T`<0=SHf0P0[:b/202d];@@0:b/[0P0Z:RX202/[:`<0;Bd]0P0_;bl2038b<P80<c<c0P0a<C4202l_
;`80<C4a1@0c<c<2038b<P80@T920P0l?3`203/k>`80>3Ph0P0d=3@3030`<080;Rh^0P0];Bd202PX
:080:BTY0P0V9RH204Y:BPL0L71`0P1UIFD206MWI`80EUIF0P1OGel306YZJP80KVi^1P1aLG4207Qh
N0D0OWin0P1lO7`207emO@80OWin0P1oOgl20820P080Ogmo1@1nOWh20820P080Ph>30P26QXH208B4
Q080Ph>30`27QhL208^;R`P0S8b<1@2>SXh208f=S@80Rh^;0P2:RXX208V9R@80Rh^;0P2<S8`308j>
SP@0Shn?0P2@T90209>CT`80UiNG0P2IVIT309ZJVP80VIVI0P2HV9P209VIV@80VYZJ0P2HV9P209JF
UP80UiNG0`2IVIT409ZJVP80Vi^K0P2LW9`209^KV`80VYZJ0`2IVIT209RHV080UYJF0P2EUID209JF
UP80V9RH0P2FUYH309BDU0H0Ti>C0P2DU9@209:BTP80T92@0`2CTi<209NGU`80VIVI0P2MWId20:VY
Z@80][Jf0P34a<@30<k>cP80bLW90P33`l<20;Rh^0P0b>3H00060<SPf080G5aL0P1XJ6P205IFEP<0
FUYJ0P1QHF4206IVIP80RXZ:0P34a<@20<W9b@80Ti>C0`0f=SH202/[:`80;Bd]100[:b/202XZ:P80
:b/[0`0];Bd202l_;`80<S8b0P0c<c<2034a<@80;bl_0P0a<C4503<c<`80<S8b0P12@T8203`l?080
>c/k0P0h>3P203@d=0<0<30`0P0^;Rh202d];@80:2PX0P0Y:BT202HV9P80BTY:1`1`L70206EUI@80
IfMW0P1FEUH205mOG`<0JVYZ0P1^KVh6075aL@80N7Qh1@1nOWh207alO080OGem0P1nOWh207moO`80
P8200P1oOgl507inOP80P8200P23Ph<208J6QP80Q8B40P23Ph<308N7Q`80Rh^;202<S8`508j>SP80
SHf=0P2;Rh/208Z:RP80RHV90P2;Rh/208b<S0<0SXj>102?Shl2092@T080Ti>C0P2GUiL209VIV@<0
VYZJ0P2IVIT209RHV080VIVI0P2JVYX209RHV080UYJF0P2GUiL309VIV@@0VYZJ0P2KVi/209bLW080
Vi^K0P2JVYX309VIV@80V9RH0P2FUYH209FEU@80UYJF0P2HV9P209JFUP<0U9BD1P2CTi<209BDU080
TY:B0P2@T90309>CT`80UiNG0P2IVIT209fMW@80ZJVY0P2f][H20<C4a0<0c/k>0P39bLT20<?3``80
^;Rh2038h=P000H0b>3H0P1@D50206IVIP80G5aL0`1CDe<205UIF@80JVYZ0P2>SXh20;Bd]080clo?
0P2f][H307moO`80ADE50P0P820202HV9P80<C4a100_;bl303@d=080>3Ph0P0g=cL203De=@80>3Ph
0P0k>c/203hn?P<0@4100P12@T8204A4A080B4Q81012@T820451@@80?Shn0`0k>c/203Hf=P80<c<c
0P0d=3@203`l?080>CTi0P1KFe/307=cL`80Kfm_0P1WIfL206][J`80GemO0P1HF5P205mOG`<0J6QX
0P1]KFd2071`L080LW9b0P1dM7@207UiN@80OGem1@1nOWh407emO@80P8200P22PX820861P@<0Ogmo
0P20P8020861P@80Ph>30P25QHD208J6QP80QhN70`29RHT208b<S0d0SHf=0P2<S8`208^;R`80S8b<
0P2=SHd408j>SP<0Shn?0P2ATI4209:BTP80U9BD0P2GUiL209VIV@80VYZJ1`2IVIT409ZJVP@0VIVI
0P2JVYX309bLW0H0WIfM102LW9`209^KV`<0VIVI0P2GUiL209JFUP80UiNG0P2HV9P209VIV@80UiNG
2@2DU9@209>CT`80TI6A0P2@T903096AT@80U9BD0P2GUiL209fMW@80YZJV0P2a/K420<30`0<0bl_;
0P36a/H20<71`@80/K6a2038h=P000H0b>3H0P1@D50206IVIP80G5aL0`1CDe<205UIF@80JVYZ0P2>
SXh20;Bd]080clo?0P2f][H307moO`80ADE50P0P820202HV9P80<C4a100_;bl303@d=080>3Ph0P0g
=cL203De=@80>3Ph0P0k>c/203hn?P<0@4100P12@T8204A4A080B4Q81012@T820451@@80?Shn0`0k
>c/203Hf=P80<c<c0P0d=3@203`l?080>CTi0P1KFe/307=cL`80Kfm_0P1WIfL206][J`80GemO0P1H
F5P205mOG`<0J6QX0P1]KFd2071`L080LW9b0P1dM7@207UiN@80OGem1@1nOWh407emO@80P8200P22
PX820861P@<0Ogmo0P20P8020861P@80Ph>30P25QHD208J6QP80QhN70`29RHT208b<S0d0SHf=0P2<
S8`208^;R`80S8b<0P2=SHd408j>SP<0Shn?0P2ATI4209:BTP80U9BD0P2GUiL209VIV@80VYZJ1`2I
VIT409ZJVP@0VIVI0P2JVYX309bLW0H0WIfM102LW9`209^KV`<0VIVI0P2GUiL209JFUP80UiNG0P2H
V9P209VIV@80UiNG2@2DU9@209>CT`80TI6A0P2@T903096AT@80U9BD0P2GUiL209fMW@80YZJV0P2a
/K420<30`0<0bl_;0P36a/H20<71`@80/K6a2038h=P000H0b>3H0P1?Cdl2065QH@80H61P0`1GEeL2
06=SH`80NGUi0P2EUID209^KV`80`<300P3<c<`30<K6aP80M7Ad0P0j>SX2034a<@80=CDe0P0c<c<2
03@d=0<0>SXj0P10@40203dm?@80=cLg0P0e=CD203@d=080=SHf0`0h>3P203Xj>P80>c/k0P0j>SX2
03Ti>@80=CDe0P0b<S82030`<0<0;Rh^0P0/;2`202/[:`80:2PX0P0];Bd2034a<@80FEUI0`1_Kfl2
071`L080GUiN0P1_Kfl205QHF080FUYJ0P1NGUh306IVIP80Jf][0P1_Kfl207=cL`80MgMg0P1iNGT2
07]kN`<0OGem0P1oOgl207inOP80OGem0P20P80408:2PP<0PH611P22PX8208>3P`80QhN71@2;Rh/4
08b<S0H0SHf=2@2<S8`208n?S`80TY:B0P2ATI42092@T0<0TI6A0P2BTY8209FEU@80UiNG0P2IVIT4
09ZJVP<0VIVI202JVYX409^KV`80WIfM1`2OWil209jNWPH0WIfM0`2JVYX409NGU`80V9RH102IVIT2
09NGU`D0UIFE0P2FUYH209BDU080TY:B102ATI45092@T080UIFE0P2MWId20:>SX`80Zj^[0P2i^KT3
0<G5a@80`L710P2m_Kd20:VYZ@P0b>3H00060<SPf080Cdm?0P1QHF42061PH0<0EeMG0P1SHf<207Ui
N@80UIFE0P2KVi/20<30`080c<c<0`36a/H207AdM080>SXj0P0a<C4203De=@80<c<c0P0d=3@303Xj
>P80@4100P0m?Cd203Lg=`80=CDe0P0d=3@203Hf=P<0>3Ph0P0j>SX203/k>`80>SXj0P0i>CT203De
=@80<S8b0P0`<30302h^;P80;2`/0P0[:b/202PX:080;Bd]0P0a<C4205UIF@<0Kfm_0P1`L70205iN
GP80Kfm_0P1HF5P205YJFP80GUiN0`1VIVH206][J`80Kfm_0P1cLg<207MgM`80NGUi0P1kNg/307em
O@80Ogmo0P1nOWh207emO@80P8201022PX830861P@H0PX:20P23Ph<208N7Q`D0Rh^;102<S8`608f=
S@T0S8b<0P2?Shl209:BTP80TI6A0P2@T903096AT@80TY:B0P2EUID209NGU`80VIVI102JVYX309VI
V@P0VYZJ102KVi/209fMW@L0WinO0P2NWYh609fMW@<0VYZJ102GUiL209RHV0@0VIVI0P2GUiL509FE
U@80UYJF0P2DU9@209:BTP@0TI6A1@2@T90209FEU@80WIfM0P2SXj<20:^[Z`80^KVi0`35aLD20<71
`@80_Kfm0P2YZJT80<SPf0001P38h=P206EUI@80F5QH0P1]KFd306][J`80GemO0P1aLG4208J6QP80
S8b<0P2WYjL20;jn_P<0c/k>0P2h^;P2055AD@8092@T0P0b<S8203De=@D0<C4a0P0b<S8203@d=080
=SHf0P0b<S8202h^;P80<30`0`0c<c<203Ti>@80?Shn0P0k>c/203Ph>080=SHf0P0e=CD203<c<`<0
<S8b0P0_;bl202h^;P80;2`/0P0a<C4203Hf=P80GUiN0`1`L70207QhN080GEeM0P1[Jf/205ADE080
F5QH0P1LG5`306EUI@80JVYZ0P1^KVh207=cL`80MWIf0P1iNGT207YjNP<0O7al0P1nOWh407emO@80
OWin0P20P80207inOP<0OGem0P20P80408>3P`80PX:20P25QHD208R8R0<0RHV90P2:RXX208^;R`H0
S8b<0P2=SHd508n?S`80SXj>0P2?Shl2092@T0L0TI6A102BTY8209BDU080UiNG2@2JVYX609^KV`80
W9bL0P2NWYh209nOW`<0XJ6Q0P2OWil409fMW@H0WYjN0`2KVi/209VIV@80VYZJ0P2KVi/209ZJVP80
UiNG0P2FUYH709FEU@80U9BD0P2BTY82092@T080SXj>0`2=SHd208j>SP80TI6A0P2FUYH209bLW080
Y:BT0P2a/K430;bl_080_[jn0P2c/k<20:>SX`P0b>3H00060<SPf080IFEU0P1HF5P206e]K@<0Jf][
0P1OGel2075aL@80QXJ60P2<S8`20:NWY`80_[jn0`3>c/h20;Rh^080DE5A0P0T92@2038b<P80=CDe
1@0a<C42038b<P80=3@d0P0f=SH2038b<P80;Rh^0P0`<30303<c<`80>CTi0P0n?Sh203/k>`80>3Ph
0P0f=SH203De=@80<c<c0`0b<S8202l_;`80;Rh^0P0/;2`2034a<@80=SHf0P1NGUh3071`L080N7Qh
0P1MGEd206][J`80E5AD0P1HF5P205aLG0<0IFEU0P1ZJVX206i^KP80Lg=c0P1fMWH207UiN@80NWYj
0`1lO7`207inOP@0OGem0P1nOWh20820P080OWin0`1mOGd20820P0@0Ph>30P22PX8208F5Q@80R8R8
0`29RHT208Z:RP80Rh^;1P2<S8`208f=S@D0Shn?0P2>SXh208n?S`80T92@1`2ATI4409:BTP80U9BD
0P2GUiL909ZJVPH0Vi^K0P2LW9`209jNWP80WinO0`2QXJ4209nOW`@0WIfM1P2NWYh309^KV`80VIVI
0P2JVYX209^KV`80VYZJ0P2GUiL209JFUPL0UIFE0P2DU9@209:BTP80T92@0P2>SXh308f=S@80SXj>
0P2ATI4209JFUP80W9bL0P2TY:@20;6a/@<0_;bl0P2n_[h20;>c/`80Xj>S2038h=P000H0b>3H0P2M
WId205aLG080Hf=S0`1_Kfl2061PH080JVYZ0P1eMGD207emO@80RXZ:0P2ZZZX30=?Cd`80d];B0P2R
XZ8203`l?0@0;bl_0P0/;2`3038b<P80=cLg0P0e=CD2034a<@80<c<c0P0g=cL203Xj>P<0?Cdm0P0o
?cl203hn?P80>c/k0P0g=cL203Hf=P80=cLg0P0e=CD303@d=080<C4a0P0`<30202d];@80<S8b0P0g
=cL2065QH@<0LW9b0P20P80205eMG@80IVIV0P1BDU8205EEE@80Fe]K0`1UIFD206YZJP80KVi^0P1b
LW8207EeM@80N7Qh0P1jNWX307]kN`H0O7al101mOGd207]kN`<0NGUi0P1nOWh408>3P`80PH610P22
PX8208B4Q0<0QXJ60P28R8P208V9R@80RXZ:0P2;Rh/208b<S080Shn?1@2ATI42092@T0H0Shn?1`2A
TI44092@T080U9BD0P2IVIT209ZJVPT0Vi^K0P2LW9`209fMW@80WinO0P2PX:030:6QX@80WYjN0P2L
W9`209fMW@H0WYjN0`2LW9`209^KV`80W9bL0P2MWId209ZJVP80UYJF1@2EUID209BDU0@0Ti>C0P2B
TY8208j>SP80Rh^;0`2:RXX208^;R`80S8b<0P2>SXh209BDU080W9bL0P2XZ:P30;6a/@80][Jf0P2V
YZH209^KV`P0b>3H00060<SPf080WIfM0P1LG5`206=SH`<0Kfm_0P1PH60206YZJP80MGEe0P1mOGd2
08Z:RP80ZZZZ0`3Cdm<20=;BdP80XZ:R0P0l?3`402l_;`80;2`/0`0b<S8203Lg=`80=CDe0P0a<C42
03<c<`80=cLg0P0j>SX303dm?@80?clo0P0n?Sh203/k>`80=cLg0P0f=SH203Lg=`80=CDe0`0d=3@2
034a<@80<30`0P0];Bd2038b<P80=cLg0P1QHF43079bLP80P8200P1MGEd206IVIP80DU9B0P1EEED2
05]KF`<0IFEU0P1ZJVX206i^KP80LW9b0P1eMGD207QhN080NWYj0`1kNg/607alO0@0OGem0P1kNg/3
07UiN@80OWin1023Ph<20861P@80PX:20P24Q8@308J6QP80R8R80P29RHT208Z:RP80Rh^;0P2<S8`2
08n?S`D0TI6A0P2@T90608n?S`L0TI6A102@T90209BDU080VIVI0P2JVYX909^KV`80W9bL0P2MWId2
09nOW`80X:2P0`2QXJ4209jNWP80W9bL0P2MWId609jNWP<0W9bL0P2KVi/209bLW080WIfM0P2JVYX2
09JFUPD0UIFE0P2DU9@409>CT`80TY:B0P2>SXh208^;R`<0RXZ:0P2;Rh/208b<S080SXj>0P2DU9@2
09bLW080Z:RX0`2a/K420;Jf]P80YZJV0P2KVi/80<SPf0001P38h=P209fMW@80G5aL0P1SHf<306m_
K`80H61P0P1ZJVX207EeM@80OGem0P2:RXX20:ZZZP<0dm?C0P3Bd]820::RXP80?3`l100_;bl202`/
;0<0<S8b0P0g=cL203De=@80<C4a0P0c<c<203Lg=`80>SXj0`0m?Cd203lo?`80?Shn0P0k>c/203Lg
=`80=SHf0P0g=cL203De=@<0=3@d0P0a<C42030`<080;Bd]0P0b<S8203Lg=`80HF5Q0`1bLW820820
P080GEeM0P1VIVH2059BDP80EEEE0P1KFe/306EUI@80JVYZ0P1^KVh2079bLP80MGEe0P1hN7P207Yj
NP<0Ng]k1P1lO7`407emO@80Ng]k0`1iNGT207inOP@0Ph>30P21PH4208:2PP80Q8B40`26QXH208R8
R080RHV90P2:RXX208^;R`80S8b<0P2?Shl5096AT@80T92@1P2?Shl7096AT@@0T92@0P2DU9@209VI
V@80VYZJ2@2KVi/209bLW080WIfM0P2OWil20:2PX0<0XJ6Q0P2NWYh209bLW080WIfM1P2NWYh309bL
W080Vi^K0P2LW9`209fMW@80VYZJ0P2FUYH509FEU@80U9BD102CTi<209:BTP80SXj>0P2;Rh/308Z:
RP80Rh^;0P2<S8`208j>SP80U9BD0P2LW9`20:RXZ0<0/K6a0P2f][H20:JVYP80Vi^K2038h=P000H0
b>3H0P2f][H208R8R0D0HV9R0P1ZJVX206MWI`80J6QX0P1_Kfl207]kN`80U9BD0`2l_;`20=cLg080
aLG50P1jNWX2034a<@808R8R0P0Y:BT302/[:`80;bl_0P0];Bd202/[:`80;bl_0P0c<c<2030`<0<0
;Rh^0P0h>3P20410@080>SXj0P0a<C42038b<P80=3@d0P0c<c<3034a<@80;Rh^0P0Z:RX202HV9P80
;Bd]0P0d=3@206IVIP<0LW9b0P1mOGd205aLG080IVIV0P1=CDd205EEE@80Fe]K0`1UIFD206][J`80
L71`0P1bLW8207AdM080MWIf0P1hN7P307UiN@80NWYj0P1kNg/207alO080OGem0P1nOWh507emO@80
Ogmo1P21PH4208>3P`80QHF50`27QhL208V9R@@0R8R80P2:RXX208b<S080Shn?1@2ATI42092@T0@0
Shn?0P2@T902096AT@<0TY:B102CTi<209BDU080UIFE0P2GUiL209VIV@T0Vi^K102LW9`209^KV`80
WIfM1@2OWil609jNWP80WIfM2@2LW9`209^KV`80V9RH0P2FUYH509FEU@80Ti>C0P2BTY82096AT@80
T92@0P2<S8`208R8R0L0QhN70P28R8P208f=S@80Ti>C0P2LW9`30:>SX`80XZ:R0P2EUID2092@T0P0
b>3H00060<SPf080][Jf0P28R8P5069RHP80JVYZ0P1WIfL206QXJ080Kfm_0P1kNg/209BDU0<0_;bl
0P3Lg=`20<G5a@80NWYj0P0a<C42028R8P80:BTY0`0[:b/202l_;`80;Bd]0P0[:b/202l_;`80<c<c
0P0`<30302h^;P80>3Ph0P10@40203Xj>P80<C4a0P0b<S8203@d=080<c<c0`0a<C4202h^;P80:RXZ
0P0V9RH202d];@80=3@d0P1VIVH3079bLP80OGem0P1LG5`206IVIP80CDe=0P1EEED205]KF`<0IFEU
0P1[Jf/2071`L080LW9b0P1dM7@207IfMP80N7Qh0`1iNGT207YjNP80Ng]k0P1lO7`207emO@80OWin
1@1mOGd207moO`H0PH610P23Ph<208F5Q@<0QhN70P29RHT408R8R080RXZ:0P2<S8`208n?S`D0TI6A
0P2@T90408n?S`80T92@0P2ATI4309:BTP@0Ti>C0P2DU9@209FEU@80UiNG0P2IVIT909^KV`@0W9bL
0P2KVi/209fMW@D0WinO1P2NWYh209fMW@T0W9bL0P2KVi/209RHV080UYJF1@2EUID209>CT`80TY:B
0P2ATI42092@T080S8b<0P28R8P708N7Q`80R8R80P2=SHd209>CT`80W9bL0`2SXj<20::RXP80UIFE
0P2@T9080<SPf0001P38h=P20:b/[080Zj^[0P1dM7@305mOG`80LW9b0P1WIfL2065QH@80IfMW0P1e
MGD20861P@<0X:2P0P3AdM420=WIf@80_kno0P1ADE4202PX:0809bLW0`0U9BD202TY:@809bLW0P0V
9RH202TY:@80;Rh^0P0c<c<303Lg=`80?Cdm0P10@40203Lg=`@0;Rh^100`<30302h^;P80:RXZ0P0U
9BD2024Q8@80:BTY0P0`<30206MWI`<0LW9b0P1iNGT205eMG@80IFEU0P1;Bd/205EEE@80Fe]K0`1V
IVH206e]K@80LW9b101cLg<207AdM080MgMg0`1hN7P207YjNP80Ng]k0P1lO7`207emO@80Ogmo0P21
PH4308:2PP80P8200P1oOgl20820P080PX:20P24Q8@208J6QP<0R8R80P2:RXX208R8R080QXJ60P2:
RXX208j>SP80Shn?2`2@T902096AT@80TY:B0`2CTi<209FEU@80UiNG0P2HV9P209NGU`80UIFE0P2I
VIT309bLW080Vi^K0P2JVYX209^KV`80WIfM0P2JVYX209RHV080VYZJ0`2NWYh209nOW`80X:2P0P2O
Wil209jNWP80W9bL0P2KVi/509bLW080VYZJ102GUiL209JFUP80UIFE0`2CTi<2096AT@80T92@0P2>
SXh208b<S080R8R80P24Q8@708>3P`80QHF50P27QhL208^;R`80TI6A0`2EUID208f=S@80QHF50P24
Q8@80<SPf0001P38h=P20:b/[080Zj^[0P1dM7@305mOG`80LW9b0P1WIfL2065QH@80IfMW0P1eMGD2
0861P@<0X:2P0P3AdM420=WIf@80_kno0P1ADE4202PX:0809bLW0`0U9BD202TY:@809bLW0P0V9RH2
02TY:@80;Rh^0P0c<c<303Lg=`80?Cdm0P10@40203Lg=`@0;Rh^100`<30302h^;P80:RXZ0P0U9BD2
024Q8@80:BTY0P0`<30206MWI`<0LW9b0P1iNGT205eMG@80IFEU0P1;Bd/205EEE@80Fe]K0`1VIVH2
06e]K@80LW9b101cLg<207AdM080MgMg0`1hN7P207YjNP80Ng]k0P1lO7`207emO@80Ogmo0P21PH43
08:2PP80P8200P1oOgl20820P080PX:20P24Q8@208J6QP<0R8R80P2:RXX208R8R080QXJ60P2:RXX2
08j>SP80Shn?2`2@T902096AT@80TY:B0`2CTi<209FEU@80UiNG0P2HV9P209NGU`80UIFE0P2IVIT3
09bLW080Vi^K0P2JVYX209^KV`80WIfM0P2JVYX209RHV080VYZJ0`2NWYh209nOW`80X:2P0P2OWil2
09jNWP80W9bL0P2KVi/509bLW080VYZJ102GUiL209JFUP80UIFE0`2CTi<2096AT@80T92@0P2>SXh2
08b<S080R8R80P24Q8@708>3P`80QHF50P27QhL208^;R`80TI6A0`2EUID208f=S@80QHF50P24Q8@8
0<SPf0001P38h=P208V9R@80Vi^K0P2>SXh506a/K080L71`0P1^KVh206e]K@80L71`0P1cLg<308f=
S@80^;Rh0P3Bd]820<k>cP80W9bL0P0`<30202d];@<07alO0P0V9RH402@T90809bLW0P0/;2`203Lg
=`<0@T920P1=CDd205=CD`80ATI60P0e=CD202l_;`80:b/[0P0/;2`302h^;P809bLW0P0[:b/202`/
;080;Bd]0P0b<S8206MWI`D0MgMg0P1TI6@2061PH080Cdm?0P1BDU8205YJFP<0IVIV0P1[Jf/206m_
K`80LW9b0P1cLg<207AdM080MGEe0`1hN7P207]kN`80OGem0P1nOWh407emO@80Ogmo0`21PH4208:2
PPH0PH610P24Q8@208J6QP<0R8R80P29RHT208R8R080QhN70P2<S8`4096AT@<0T92@102ATI4;09:B
TP80U9BD0P2EUID609JFUP80V9RH0`2KVi/209VIV@80UiNG0P2JVYX209bLW080Vi^K0P2JVYX209fM
W@D0WinO0P2MWId409jNWP80WIfM0P2KVi/309ZJVP80VIVI0P2GUiL409JFUP80UIFE0P2BTY8308j>
SP80S8b<0P2;Rh/208R8R080QHF50P21PH4207inOP<0P8200P22PX8208>3P`80Q8B40P25QHD208N7
Q`80RHV90`2:RXX208:2PP80O7al0P1kNg/80<SPf0001P38h=P208V9R@80Vi^K0P2>SXh506a/K080
L71`0P1^KVh206e]K@80L71`0P1cLg<308f=S@80^;Rh0P3Bd]820<k>cP80W9bL0P0`<30202d];@<0
7alO0P0V9RH402@T90809bLW0P0/;2`203Lg=`<0@T920P1=CDd205=CD`80ATI60P0e=CD202l_;`80
:b/[0P0/;2`302h^;P809bLW0P0[:b/202`/;080;Bd]0P0b<S8206MWI`D0MgMg0P1TI6@2061PH080
Cdm?0P1BDU8205YJFP<0IVIV0P1[Jf/206m_K`80LW9b0P1cLg<207AdM080MGEe0`1hN7P207]kN`80
OGem0P1nOWh407emO@80Ogmo0`21PH4208:2PPH0PH610P24Q8@208J6QP<0R8R80P29RHT208R8R080
QhN70P2<S8`4096AT@<0T92@102ATI4;09:BTP80U9BD0P2EUID609JFUP80V9RH0`2KVi/209VIV@80
UiNG0P2JVYX209bLW080Vi^K0P2JVYX209fMW@D0WinO0P2MWId409jNWP80WIfM0P2KVi/309ZJVP80
VIVI0P2GUiL409JFUP80UIFE0P2BTY8308j>SP80S8b<0P2;Rh/208R8R080QHF50P21PH4207inOP<0
P8200P22PX8208>3P`80Q8B40P25QHD208N7Q`80RHV90`2:RXX208:2PP80O7al0P1kNg/80<SPf000
1P38h=P205mOG`80KFe]0P21PH4306][J`80JVYZ0P1lO7`207moO`80Ph>30P26QXH207]kN`<0Q8B4
0P2KVi/20;Fe]@80/k>c0P2h^;P206=SH`80<C4a0`0R8R8202HV9P808b<S0P0T92@202DU9@80:b/[
0P0m?Cd504e=C@80BDU90P15ADD203hn?P80<S8b0P0X:2P202TY:@<0;Rh^0P0U9BD2034a<@80>3Ph
0P0b<S8202d];@80EEEE0`1cLg<207MgM`80K6a/0P1JFUX205=CD`80D51@0P1JFUX306EUI@80JFUY
0P1/K6`2071`L0@0M7Ad0P1eMGD307UiN@80OGem101oOgl207emO@80O7al0P1mOGd30820P080PX:2
0P24Q8@208>3P`80PH610P24Q8@208N7Q`<0R8R80P29RHT408R8R080SXj>0P2CTi<209:BTP<0T92@
0P2ATI4209>CT`80U9BD0P2EUID209>CT`D0TY:B0P2CTi<409BDU080UYJF0P2GUiL209VIV@<0VYZJ
0P2HV9P209JFUP80VIVI0P2LW9`209fMW@80WYjN0P2PX:030:6QX@80WYjN0P2KVi/209fMW@@0WYjN
0P2LW9`309RHV0H0UIFE0P2DU9@209:BTP80SHf=0`28R8P208J6QP80QHF50P22PX8207inOP80Ng]k
0P1jNWX307emO@80PH610P23Ph<808B4Q0<0Ph>30P1lO7`207IfMP80M7Ad2038h=P000H0b>3H0P1O
Gel206e]K@80PH610`1[Jf/206YZJP80O7al0P1oOgl208>3P`80QXJ60P1kNg/308B4Q080Vi^K0P2e
]KD20;>c/`80^;Rh0P1SHf<2034a<@<08R8R0P0V9RH202<S8`8092@T0P0U9BD202/[:`80?Cdm1@1=
CDd204U9B@80ADE50P0n?Sh2038b<P80:2PX0P0Y:BT302h^;P809BDU0P0a<C4203Ph>080<S8b0P0]
;Bd205EEE@<0Lg=c0P1gMgL206a/K080FUYJ0P1CDe<2051@D080FUYJ0`1UIFD206UYJ@80K6a/0P1`
L70407AdM080MGEe0`1iNGT207emO@@0Ogmo0P1mOGd207alO080OGem0`20P80208:2PP80Q8B40P23
Ph<20861P@80Q8B40P27QhL308R8R080RHV91028R8P208j>SP80Ti>C0P2BTY83092@T080TI6A0P2C
Ti<209BDU080UIFE0P2CTi<509:BTP80Ti>C102DU9@209JFUP80UiNG0P2IVIT309ZJVP80V9RH0P2F
UYH209VIV@80W9bL0P2MWId209jNWP80X:2P0`2QXJ4209jNWP80Vi^K0P2MWId409jNWP80W9bL0`2H
V9P609FEU@80U9BD0P2BTY8208f=S@<0R8R80P26QXH208F5Q@80PX:20P1nOWh207]kN`80NWYj0`1m
OGd20861P@80Ph>32024Q8@308>3P`80O7al0P1fMWH207AdM0P0b>3H00060<SPf080CTi>0P1JFUX2
06IVIP<0JFUY0P1cLg<207alO080RXZ:0P2@T90209BDU080TY:B0`2HV9P209nOW`80YjNW0P2XZ:P2
0:j^[P80Vi^K0P1JFUX304E5A@809BDU0P0S8b<402DU9@809bLW0P0d=3@303hn?P80>3Ph0P0_;bl4
02h^;P80;2`/0P0Z:RX202/[:`<0;bl_0P0V9RH4034a<@80;bl_0P0b<S8206=SH`<0M7Ad0P1cLg<2
06IVIP80E5AD0P1ADE42051@D080Fe]K0`1WIfL206YZJP80K6a/0P1`L70607AdM0<0N7Qh2P1mOGd2
07moO`<0P8200P22PX8608B4Q080QXJ60P28R8P508V9R@80Rh^;0P2=SHd2092@T080TY:B0P2ATI43
092@T080TI6A0P2BTY8209BDU0@0UYJF0P2DU9@308n?S`80RXZ:0P2@T90209NGU`d0VIVI0P2JVYX2
09bLW080WIfM0P2OWil50:2PX080WYjN0P2LW9`209fMW@80WinO0P2MWId209ZJVP<0UYJF0P2CTi<2
09BDU080UIFE0P2CTi<2092@T080R8R80`21PH4207inOPP0OGem0P1nOWh30861P@80Q8B41025QHD2
08J6QP@0QHF50`22PX8207]kN`80M7Ad0P1bLW880<SPf0001P38h=P204i>CP80FUYJ0P1VIVH306UY
J@80Lg=c0P1lO7`208Z:RP80T92@0P2DU9@209:BTP<0V9RH0P2OWil20:NWY`80Z:RX0P2^[Zh209^K
V`80FUYJ0`15ADD202DU9@808b<S100U9BD202LW9`80=3@d0`0n?Sh203Ph>080;bl_100^;Rh202`/
;080:RXZ0P0[:b/302l_;`809RHV100a<C4202l_;`80<S8b0P1SHf<307AdM080Lg=c0P1VIVH205AD
E080DE5A0P1@D50205]KF`<0IfMW0P1ZJVX206a/K080L71`1P1dM7@307QhN0X0OGem0P1oOgl30820
P080PX:21P24Q8@208J6QP80R8R81@29RHT208^;R`80SHf=0P2@T90209:BTP80TI6A0`2@T902096A
T@80TY:B0P2DU9@409JFUP80U9BD0`2?Shl208Z:RP80T92@0P2GUiL=09VIV@80VYZJ0P2LW9`209fM
W@80WinO1@2PX:0209jNWP80W9bL0P2MWId209nOW`80WIfM0P2JVYX309JFUP80Ti>C0P2DU9@209FE
U@80Ti>C0P2@T90208R8R0<0PH610P1nOWh807emO@80OWin0`21PH4208B4Q0@0QHF50P26QXH408F5
Q@<0PX:20P1kNg/207AdM080LW9b2038h=P000H0b>3H0P0Z:RX203/k>`80ADE50`1]KFd208n?S`80
R8R80P2DU9@209^KV`80Y:BT0P2[Zj/30;2`/080];Bd0P2g]kL20;no_`80`l?30P2i^KT20;6a/@<0
Ogmo0P0X:2P2024Q8@809bLW100U9BD202PX:0<0:b/[0P0/;2`202d];@80;Rh^0P0_;bl202d];@80
;2`/0P0];Bd3030`<080:2PX0P0`<30202TY:@80;2`/0P0^;Rh2065QH@<0K6a/0P1`L702061PH080
Cdm?0P1=CDd2059BDP80G5aL0`1WIfL206YZJP80K6a/0P1`L70407AdM080Lg=c0`1hN7P207alO080
Ng]k0P1jNWX207alO080Ogmo0P20P8030861P@80PX:20P23Ph<208B4Q080QXJ60P28R8P708V9R@80
SHf=102ATI44092@T0<0TI6A0P2@T902096AT@80U9BD2`2FUYH209RHV080VIVI0P2JVYX209^KV`80
VYZJ0`2IVIT209^KV`@0W9bL0P2KVi/209fMW@@0WinO0`2NWYh409fMW@80WYjN0P2OWil209bLW080
V9RH0`2EUID409>CT`80U9BD0P2BTY8208f=S@80Ph>30`1jNWX207MgM`80N7Qh0P1kNg/207inOP80
P8201@21PH460820P080PX:21023Ph<30820P080NGUi0P1aLG4206m_K`P0b>3H00060<SPf080:RXZ
0P0k>c/204E5A@<0KFe]0P2?Shl208R8R080U9BD0P2KVi/20:BTY080Zj^[0`2`/;020;Bd]080]kNg
0P2o_kl20<?3``80^KVi0P2a/K4307moO`80:2PX0P0Q8B4202LW9`@09BDU0P0X:2P302/[:`80;2`/
0P0];Bd202h^;P80;bl_0P0];Bd202`/;080;Bd]0`0`<30202PX:080<30`0P0Y:BT202`/;080;Rh^
0P1QHF4306a/K080L71`0P1PH60204m?C`80CDe=0P1BDU8205aLG0<0IfMW0P1ZJVX206a/K080L71`
101dM7@207=cL`<0N7Qh0P1lO7`207]kN`80NWYj0P1lO7`207moO`80P8200`21PH4208:2PP80Ph>3
0P24Q8@208J6QP80R8R81`29RHT208f=S@@0TI6A102@T903096AT@80T92@0P2ATI4209BDU0/0UYJF
0P2HV9P209VIV@80VYZJ0P2KVi/209ZJVP<0VIVI0P2KVi/409bLW080Vi^K0P2MWId409nOW`<0WYjN
102MWId209jNWP80WinO0P2LW9`209RHV0<0UIFE102CTi<209BDU080TY:B0P2=SHd208>3P`<0NWYj
0P1gMgL207QhN080Ng]k0P1nOWh20820P0D0PH611P20P80208:2PP@0Ph>30`20P80207UiN@80LG5a
0P1_Kfl80<SPf0001P38h=P202@T90808R8R0P0U9BD304Y:BP80SXj>0P2IVIT209jNWP80XJ6Q0P2S
Xj<20;:b/P<0_[jn0P2g]kL20;^k^`80`<300P32`/820<G5a@80_;bl0`2JVYX204=3@`809BDU0P0Q
8B42020P80809BDU0P0W9bL302PX:0@09bLW0P0X:2P202XZ:P80;2`/0P0^;Rh2030`<0<0<C4a0P0]
;Bd2030`<0809bLW0P0Y:BT202d];@80GUiN0`1ZJVX2075aL@80I6AT0P1;Bd/204e=C@80E5AD0P1M
GEd306EUI@80IfMW0P1XJ6P206a/K080L71`0P1bLW8207AdM0<0MgMg0P1jNWX207]kN`@0O7al0P1m
OGd20820P0L0PX:20P23Ph<208F5Q@80QhN70P28R8P308V9R@80RXZ:0P2<S8`208n?S`/0TI6A0P2C
Ti<209FEU@@0UiNG1`2FUYH409NGU`80VIVI0P2JVYX509^KV`80WIfM102NWYh209fMW@d0WYjN102O
Wil209^KV`80UYJF0`2EUID409BDU080TY:B0P2?Shl208V9R@80Ogmo1@1gMgL207alO080P8200P22
PX8207emO@80MGEe0`1[Jf/2069RHP80H61P0P1QHF4206YZJP80LW9b0P1aLG4306a/K080IVIV0P1P
H60206=SH`P0b>3H00060<SPf08092@T0P0R8R8202DU9@<0BTY:0P2>SXh209VIV@80WYjN0P2QXJ42
0:>SX`80/[:b0`2n_[h20;Ng]`80^k^k0P30`<020<;2`P80aLG50P2l_;`309ZJVP80@d=30P0U9BD2
024Q8@80820P0P0U9BD202LW9`<0:2PX100W9bL202PX:080:RXZ0P0/;2`202h^;P80<30`0`0a<C42
02d];@80<30`0P0W9bL202TY:@80;Bd]0P1NGUh306YZJP80LG5a0P1TI6@204];B`80CDe=0P1DE5@2
05eMG@<0IFEU0P1WIfL206QXJ080K6a/0P1`L702079bLP80M7Ad0`1gMgL207YjNP80Ng]k101lO7`2
07emO@80P8201`22PX8208>3P`80QHF50P27QhL208R8R0<0RHV90P2:RXX208b<S080Shn?2`2ATI42
09>CT`80UIFE102GUiL709JFUP@0UiNG0P2IVIT209ZJVPD0Vi^K0P2MWId409jNWP80WIfM3@2NWYh4
09nOW`80Vi^K0P2FUYH309FEU@@0U9BD0P2BTY8208n?S`80RHV90P1oOgl507MgM`80O7al0P20P802
08:2PP80OGem0P1eMGD306][J`80HV9R0P1PH602065QH@80JVYZ0P1bLW82075aL@<0K6a/0P1VIVH2
061PH080Hf=S2038h=P000H0b>3H0P0T92@2028R8P809BDU0`1:BTX208j>SP80VIVI0P2NWYh20:6Q
X@80Xj>S0P2b/[830;jn_P80]kNg0P2k^k/20<30`080`/;20P35aLD20;bl_0<0VYZJ0P13@d<202DU
9@808B4Q0P0P820202DU9@809bLW0`0X:2P402LW9`80:2PX0P0Z:RX202`/;080;Rh^0P0`<303034a
<@80;Bd]0P0`<30202LW9`80:BTY0P0];Bd205iNGP<0JVYZ0P1aLG4206ATI080Bd];0P1=CDd205AD
E080GEeM0`1UIFD206MWI`80J6QX0P1/K6`2071`L080LW9b0P1dM7@307MgM`80NWYj0P1kNg/407al
O080OGem0P20P80708:2PP80Ph>30P25QHD208N7Q`80R8R80`29RHT208Z:RP80S8b<0P2?Shl;096A
T@80Ti>C0P2EUID409NGU`L0UYJF102GUiL209VIV@80VYZJ1@2KVi/209fMW@@0WYjN0P2MWId=09jN
WP@0WinO0P2KVi/209JFUP<0UIFE102DU9@209:BTP80Shn?0P29RHT207moO`D0MgMg0P1lO7`20820
P080PX:20P1mOGd207EeM@<0Jf][0P1RHV82061PH080HF5Q0P1ZJVX2079bLP80LG5a0`1/K6`206IV
IP80H61P0P1SHf<80<SPf0001P38h=P2020P80806ATI0P0R8R83034a<@80PH610P2TY:@20:JVYP80
[Jf]0P2_[jl20;^k^`<0aLG50P2g]kL20;no_`@0`<300P34a<@20;Zj^P<0[:b/0P1TI6@203<c<`80
8B4Q0P0P820702PX:0809RHV0P0U9BD202HV9P80:2PX0P0/;2`2030`<080<S8b0`0a<C42030`<080
;Rh^0P0V9RH202LW9`80;2`/0P1JFUX306UYJ@80L71`0P1XJ6P204U9B@80CDe=0P1EEED205aLG0<0
HV9R0P1TI6@206EUI@80JFUY0P1^KVh2079bLP80MGEe0`1gMgL207UiN@80Ng]k101mOGd207alO080
P8200`23Ph<208:2PP80PH610P22PX8208B4Q080QXJ60P27QhL308V9R@80RXZ:0P2;Rh/208b<S080
T92@0P2CTi<209:BTP<0TI6A0P2CTi<209FEU@80UiNG0P2HV9P209NGU`80UYJF1@2GUiL209JFUP80
UIFE0P2GUiL209VIV@80Vi^K0`2MWId209jNWPH0WinO0P2NWYh209fMW@T0WYjN102OWil209ZJVP80
U9BD1@2EUID209BDU080TI6A0P2;Rh/208F5Q@80O7al0`1eMGD207]kN`80Ph>30P27QhL208J6QP80
Ng]k0P1[Jf/305IFEP80ADE50P10@40204=3@`80DU9B0P1RHV82061PH0<0FUYJ0P1GEeL205=CD`80
Fe]K2038h=P000H0b>3H0P0P820201TI6@808R8R0`0a<C420861P@80Y:BT0P2VYZH20:f][@80[jn_
0P2k^k/30<G5a@80]kNg0P2o_kl40<30`080a<C40P2j^[X30:b/[080I6AT0P0c<c<2024Q8@80820P
1`0X:2P202HV9P809BDU0P0V9RH202PX:080;2`/0P0`<302038b<P<0<C4a0P0`<30202h^;P809RHV
0P0W9bL202`/;080FUYJ0`1YJFT2071`L080J6QX0P19BDT204e=C@80EEEE0P1LG5`3069RHP80I6AT
0P1UIFD206UYJ@80KVi^0P1bLW8207EeM@<0MgMg0P1iNGT207]kN`@0OGem0P1lO7`20820P0<0Ph>3
0P22PX820861P@80PX:20P24Q8@208J6QP80QhN70`29RHT208Z:RP80Rh^;0P2<S8`2092@T080Ti>C
0P2BTY83096AT@80Ti>C0P2EUID209NGU`80V9RH0P2GUiL209JFUPD0UiNG0P2FUYH209FEU@80UiNG
0P2IVIT209^KV`<0WIfM0P2NWYh609nOW`80WYjN0P2MWId909jNWP@0WinO0P2JVYX209BDU0D0UIFE
0P2DU9@2096AT@80Rh^;0P25QHD207alO0<0MGEe0P1kNg/208>3P`80QhN70P26QXH207]kN`80Jf][
0`1FEUH204E5A@80@4100P13@d<2059BDP80HV9R0P1PH60305YJFP80EeMG0P1CDe<205]KF`P0b>3H
00060<SPf080:2PX100N7Qh302@T9080G5aL0P2[Zj/20:j^[P@0[jn_0P2f][H30<C4a0@0^;Rh0P2k
^k/20;no_`80_[jn0P2e]KD30;^k^`80W9bL0P1cLg<203Lg=`80:b/[0P0X:2P202DU9@T08b<S0P0U
9BD202XZ:P80;bl_0P0`<30302h^;P80;Bd]0P0Y:BT202PX:0809RHV0P0];Bd205aLG0<0Jf][0P1T
I6@2069RHP80BTY:0P1=CDd205=CD`80FUYJ0`1PH602069RHP80I6AT0P1ZJVX2071`L080Lg=c0P1f
MWH307QhN0@0NWYj0P1kNg/207emO@80Ogmo0P20P8070861P@80Ph>30P26QXH208R8R0L0RXZ:0P2;
Rh/208f=S@80T92@102ATI43092@T080U9BD0P2HV9P209NGU`80UIFE0P2FUYH209NGU`<0V9RH0P2I
VIT209NGU`80UYJF0P2GUiL209VIV@80Vi^K0`2LW9`209fMW@P0WYjN0P2MWId709jNWP80WIfM102O
Wil209ZJVP80UIFE0`2DU9@209>CT`80T92@0P2<S8`208N7Q`80PH610P1jNWX307EeM@80PH610P24
Q8@208V9R@80QhN70P1jNWX206IVIP<0B4Q8100`<30203Ph>080@T920P1>CTh205UIF@<0HV9R0P1U
IFD206ATI080JFUY2038h=P000H0b>3H0P0X:2P401hN7P<092@T0P1LG5`20:^[Z`80[Zj^102_[jl2
0;Jf]P<0a<C4102h^;P20;^k^`80_kno0P2n_[h20;Fe]@<0^k^k0P2LW9`207=cL`80=cLg0P0[:b/2
02PX:0809BDU2@0S8b<202DU9@80:RXZ0P0_;bl2030`<0<0;Rh^0P0];Bd202TY:@80:2PX0P0V9RH2
02d];@80G5aL0`1[Jf/206ATI080HV9R0P1:BTX204e=C@80De=C0P1JFUX3061PH080HV9R0P1TI6@2
06YZJP80L71`0P1cLg<207IfMP<0N7Qh101jNWX207]kN`80OGem0P1oOgl20820P0L0PH610P23Ph<2
08J6QP80R8R81`2:RXX208^;R`80SHf=0P2@T904096AT@<0T92@0P2DU9@209RHV080UiNG0P2EUID2
09JFUP80UiNG0`2HV9P209VIV@80UiNG0P2FUYH209NGU`80VIVI0P2KVi/309bLW080WIfM202NWYh2
09fMW@L0WYjN0P2MWId409nOW`80VYZJ0P2EUID309BDU080Ti>C0P2@T90208b<S080QhN70P21PH42
07YjNP<0MGEe0P21PH4208B4Q080RHV90P27QhL207YjNP80IVIV0`18B4P4030`<080>3Ph0P12@T82
04i>CP80FEUI0`1RHV8206EUI@80I6AT0P1YJFT80<SPf0001P38h=P2020P80807QhN0P0O7al301hN
7P80=CDe0P2VYZH20;>c/`80[Jf]102^[Zh30;jn_P80]kNg0P2`/;020;Jf]P80_;bl0P2h^;P20;6a
/@<0/;2`0P2VYZH209bLW080EeMG0P11@D42030`<0809bLW0`0R8R82024Q8@@08R8R0P0S8b<202PX
:080;Bd]0P0^;Rh302`/;080:2PX0P0U9BD202TY:@809RHV0P0_;bl205iNGP<0KFe]0P1GEeL205YJ
FP80BTY:0P1<C4`2051@D080EUIF0`1MGEd2061PH080I6AT0P1/K6`207=cL`80MGEe0P1fMWH307Ui
N@80O7al0P1jNWX207UiN@80OWin0P22PX820861P@<0OWin0P20P80208:2PP80Q8B40P27QhL208Z:
RP80S8b<0`2;Rh/208Z:RP80S8b<0P2>SXh608n?S`<0T92@0P2EUID209ZJVP80UiNG0P2CTi<209FE
U@80V9RH1@2JVYX209VIV@80UiNG0P2HV9P209ZJVPD0Vi^K0P2LW9`809fMW@@0WYjN0`2OWil209fM
W@80W9bL0P2NWYh209nOW`80VYZJ0P2EUID309>CT`80TI6A0P2=SHd208V9R@80Ph>30P1mOGd207Qh
N0<0MGEe0P26QXH208>3P`@0QhN70P25QHD207alO0<0FUYJ0P0j>SX203@d=080>3Ph0P17AdL205UI
F@80IVIV0`1`L70207IfMP80N7Qh0P1iNGT80<SPf0001P38h=P2020P80807QhN0P0O7al301hN7P80
=CDe0P2VYZH20;>c/`80[Jf]102^[Zh30;jn_P80]kNg0P2`/;020;Jf]P80_;bl0P2h^;P20;6a/@<0
/;2`0P2VYZH209bLW080EeMG0P11@D42030`<0809bLW0`0R8R82024Q8@@08R8R0P0S8b<202PX:080
;Bd]0P0^;Rh302`/;080:2PX0P0U9BD202TY:@809RHV0P0_;bl205iNGP<0KFe]0P1GEeL205YJFP80
BTY:0P1<C4`2051@D080EUIF0`1MGEd2061PH080I6AT0P1/K6`207=cL`80MGEe0P1fMWH307UiN@80
O7al0P1jNWX207UiN@80OWin0P22PX820861P@<0OWin0P20P80208:2PP80Q8B40P27QhL208Z:RP80
S8b<0`2;Rh/208Z:RP80S8b<0P2>SXh608n?S`<0T92@0P2EUID209ZJVP80UiNG0P2CTi<209FEU@80
V9RH1@2JVYX209VIV@80UiNG0P2HV9P209ZJVPD0Vi^K0P2LW9`809fMW@@0WYjN0`2OWil209fMW@80
W9bL0P2NWYh209nOW`80VYZJ0P2EUID309>CT`80TI6A0P2=SHd208V9R@80Ph>30P1mOGd207QhN0<0
MGEe0P26QXH208>3P`@0QhN70P25QHD207alO0<0FUYJ0P0j>SX203@d=080>3Ph0P17AdL205UIF@80
IVIV0`1`L70207IfMP80N7Qh0P1iNGT80<SPf0001P38h=P202DU9@807alO0P0L71`301/K6`8092@T
0P27QhL20;>c/`80Xj>S0P2[Zj/20:ZZZP<0/[:b0P2a/K420:n_[`80/K6a0P2d];@20;Jf]P80]kNg
0`2h^;P20;Ng]`80^k^k0P2IVIT207AdM080CTi>0P0b<S8302TY:@8092@T0P0R8R82024Q8@808R8R
0P0X:2P202h^;P80:RXZ0`0^;Rh202`/;080:BTY0P0X:2P202LW9`80<C4a0P1LG5`306m_K`80I6AT
0P1JFUX404I6AP80Bd];0P1CDe<305aLG080HF5Q0P1TI6@206a/K080M7Ad0P1eMGD207IfMP<0NWYj
1P1mOGd20820P080PX:20P20P80307inOP80P8200P22PX8208B4Q080QXJ60P29RHT208^;R`<0S8b<
1P2=SHd208n?S`@0TI6A0`2@T90209>CT`P0UYJF0P2GUiL309RHV080VIVI0P2GUiL209JFUP80V9RH
0P2JVYX209bLW0<0WIfM0P2KVi/209ZJVP80W9bL102OWil209jNWPD0WinO0P2MWId209bLW0@0WIfM
0P2IVIT209BDU0<0TY:B0P2@T90208n?S`80SHf=0P21PH4207IfMPD0M7Ad0P1oOgl20861P@80QhN7
0P29RHT208J6QP80PH610`1kNg/207MgM`@0M7Ad0P1jNWX40820P0<0OWin101mOGd207alO0P0b>3H
00060<SPf0809BDU0P0O7al201`L70<06a/K0P0T92@208N7Q`80/k>c0P2SXj<20:^[Z`80ZZZZ0`2b
/[820;6a/@80[jn_0P2a/K420;Bd]080][Jf0P2g]kL30;Rh^080]kNg0P2k^k/209VIV@80M7Ad0P1>
CTh2038b<P<0:BTY0P0T92@2028R8P808B4Q0P0R8R8202PX:080;Rh^0P0Z:RX302h^;P80;2`/0P0Y
:BT202PX:0809bLW0P0a<C4205aLG0<0Kfm_0P1TI6@205YJFP@0ATI60P1;Bd/205=CD`<0G5aL0P1Q
HF4206ATI080K6a/0P1dM7@207EeM@80MWIf0`1jNWX607emO@80P8200P22PX820820P0<0OWin0P20
P80208:2PP80Q8B40P26QXH208V9R@80Rh^;0`2<S8`608f=S@80Shn?102ATI43092@T080Ti>C202F
UYH209NGU`<0V9RH0P2IVIT209NGU`80UYJF0P2HV9P209ZJVP80W9bL0`2MWId209^KV`80VYZJ0P2L
W9`409nOW`80WYjN1@2OWil209fMW@80W9bL102MWId209VIV@80U9BD0`2BTY82092@T080Shn?0P2=
SHd20861P@80MWIf1@1dM7@207moO`80PH610P27QhL208V9R@80QXJ60P21PH4307]kN`80MgMg101d
M7@207YjNP@0P8200`1nOWh407emO@80O7al2038h=P000H0b>3H0P0X:2P2024Q8@806QXJ0`0K6a/2
01`L7080HV9R0P2ZZZX209^KV`80YjNW0P2VYZH30:NWY`80ZZZZ0P2][Jd20:ZZZP80Z:RX0P2_[jl2
0;Ng]`<0^KVi0P2h^;P20;Fe]@80[Zj^0P2CTi<207EeM@80BTY:0`0g=cL202XZ:P808b<S0P0Q8B42
028R8P80:2PX0P0_;bl202LW9`<0<30`0P0_;bl202d];@809RHV0P0W9bL203@d=080FUYJ0`1XJ6P2
061PH080DE5A0P12@T820451@@80ATI60P1@D50305]KF`80HF5Q0P1VIVH206e]K@80Lg=c0P1eMGD2
07IfMP<0NWYj0P1nOWh40820P080PH610P22PX820820P0<0Ogmo0P21PH4208>3P`80Q8B40P25QHD2
08N7Q`80RHV90`2=SHd208n?S`80SHf=0P2;Rh/208n?S`@0TY:B1@2ATI4209:BTP80UYJF0P2IVIT2
09RHV0D0UYJF0P2GUiL409JFUP80V9RH0P2KVi/209fMW@<0WinO0P2KVi/209RHV080W9bL102PX:07
09nOW`80WIfM102LW9`209ZJVP80UiNG0P2DU9@3096AT@80Shn?0P2ATI42092@T080P8200P1`L702
06m_K`<0Lg=c0P1hN7P207moO`80QXJ60P2;Rh/208Z:RP80R8R80`26QXH208B4Q080QHF51P28R8P2
08Z:RP<0Rh^;0P24Q8@207emO@80Ng]k2038h=P000H0b>3H0P0X:2P2024Q8@806QXJ0`0K6a/201`L
7080HV9R0P2ZZZX209^KV`80YjNW0P2VYZH30:NWY`80ZZZZ0P2][Jd20:ZZZP80Z:RX0P2_[jl20;Ng
]`<0^KVi0P2h^;P20;Fe]@80[Zj^0P2CTi<207EeM@80BTY:0`0g=cL202XZ:P808b<S0P0Q8B42028R
8P80:2PX0P0_;bl202LW9`<0<30`0P0_;bl202d];@809RHV0P0W9bL203@d=080FUYJ0`1XJ6P2061P
H080DE5A0P12@T820451@@80ATI60P1@D50305]KF`80HF5Q0P1VIVH206e]K@80Lg=c0P1eMGD207If
MP<0NWYj0P1nOWh40820P080PH610P22PX820820P0<0Ogmo0P21PH4208>3P`80Q8B40P25QHD208N7
Q`80RHV90`2=SHd208n?S`80SHf=0P2;Rh/208n?S`@0TY:B1@2ATI4209:BTP80UYJF0P2IVIT209RH
V0D0UYJF0P2GUiL409JFUP80V9RH0P2KVi/209fMW@<0WinO0P2KVi/209RHV080W9bL102PX:0709nO
W`80WIfM102LW9`209ZJVP80UiNG0P2DU9@3096AT@80Shn?0P2ATI42092@T080P8200P1`L70206m_
K`<0Lg=c0P1hN7P207moO`80QXJ60P2;Rh/208Z:RP80R8R80`26QXH208B4Q080QHF51P28R8P208Z:
RP<0Rh^;0P24Q8@207emO@80Ng]k2038h=P000H0b>3H0P0X:2P202XZ:P807alO0`0K6a/201dM7@80
@T920P2GUiL20:RXZ080YZJV0P2WYjL30:BTY080Xj>S0P2RXZ820:BTY080Xj>S0P2KVi/209NGU`<0
WinO0P2ZZZX20;Vi^@80_;bl0P2[Zj/208f=S@80GemO0`10@40202DU9@808b<S0P0P820202@T9080
:2PX0P0];Bd202TY:@<0;Rh^0P0X:2P202/[:`80:BTY0P0V9RH2034a<@80FUYJ0`1]KFd206ATI080
EEEE0P15ADD20451@@80A4A40P1?Cdl305]KF`80GEeM0P1XJ6P206e]K@80LW9b0P1dM7@207IfMP<0
Ng]k0P1nOWh207moO`80OWin0P20P80208:2PP80PH610`20P8020861P@80Ph>30P24Q8@208J6QP80
QhN70P29RHT308b<S080Shn?102>SXh208n?S`@0T92@1@2ATI4209:BTP80UYJF0P2HV9P209NGU`80
UYJF0`2GUiL209VIV@@0VYZJ0P2KVi/209bLW0D0WYjN0P2MWId209^KV`80WYjN102PX:0209nOW`80
WYjN0`2MWId409jNWP80WIfM0P2JVYX209JFUP80Ti>C0`2ATI44092@T080SXj>0P20P80207=cL`80
Jf][0`1aLG4207IfMP80Ogmo0P25QHD208^;R`L0S8b<0P2;Rh/208j>SPH0T92@0P2?Shl308f=S@80
Q8B40P1mOGd207]kN`P0b>3H00060<SPf080:2PX0P0Z:RX201lO7`<06a/K0P0M7Ad20492@P80UiNG
0P2XZ:P20:JVYP80YjNW0`2TY:@20:>SX`80XZ:R0P2TY:@20:>SX`80Vi^K0P2GUiL309nOW`80ZZZZ
0P2i^KT20;bl_080Zj^[0P2=SHd205mOG`<0@4100P0U9BD202<S8`80820P0P0T92@202PX:080;Bd]
0P0Y:BT302h^;P80:2PX0P0[:b/202TY:@809RHV0P0a<C4205YJFP<0KFe]0P1TI6@205EEE@80ADE5
0P11@D4204A4A080Cdm?0`1KFe/205eMG@80J6QX0P1]KFd2079bLP80M7Ad0P1fMWH307]kN`80OWin
0P1oOgl207inOP80P8200P22PX820861P@<0P8200P21PH4208>3P`80Q8B40P26QXH208N7Q`80RHV9
0`2<S8`208n?S`@0SXj>0P2?Shl4092@T0D0TI6A0P2BTY8209JFUP80V9RH0P2GUiL209JFUP<0UiNG
0P2IVIT409ZJVP80Vi^K0P2LW9`509jNWP80WIfM0P2KVi/209jNWP@0X:2P0P2OWil209jNWP<0WIfM
102NWYh209fMW@80VYZJ0P2FUYH209>CT`<0TI6A102@T90208j>SP80P8200P1cLg<206][J`<0LG5a
0P1fMWH207moO`80QHF50P2;Rh/708b<S080Rh^;0P2>SXh6092@T080Shn?0`2=SHd208B4Q080OGem
0P1kNg/80<SPf0001P38h=P202HV9P80<C4a0P0V9RH301dM7@808B4Q0P0Y:BT207YjNP80Zj^[0P2O
Wil20:BTY0<0XJ6Q0P2MWId209JFUP80SHf=0P23Ph<207alO080N7Qh0`1jNWX20861P@80X:2P0P2^
[Zh20;Vi^@80];Bd0P2@T90306IVIP80<C4a0P0U9BD2020P808092@T0P0W9bL202XZ:PD0:b/[0P0Q
8B4202LW9`80:2PX0P0U9BD202d];@80Fe]K0`1aLG4206ATI080F5QH0P17AdL204=3@`80ADE50P1>
CTh305]KF`80FEUI0P1YJFT206e]K@80LG5a0P1dM7@207MgM`<0Ng]k0P1nOWh207emO@80O7al0P1o
Ogl70861P@80PX:20P23Ph<208F5Q@80QhN70P28R8P208V9R@<0Rh^;0P2>SXh4092@T080Shn?0P2>
SXh208n?S`<0TI6A0P2CTi<209BDU080UYJF102GUiL209JFUP<0V9RH0P2KVi/209fMW@H0WYjN0P2M
WId509jNWP80WinO202PX:0209jNWP<0WIfM0P2OWil20:6QX@80WYjN0P2JVYX209JFUP80TY:B0`2A
TI4208n?S`80SXj>0P2:RXX20820P080MgMg0P1XJ6P3071`L080MGEe0P1nOWh208B4Q080RHV90P2=
SHd208j>SP<0Rh^;0P28R8P208Z:RP80SHf=102?Shl208f=S@<0RXZ:0P23Ph<207alO080Ng]k2038
h=P000H0b>3H0P0V9RH2034a<@809RHV0`0M7Ad2024Q8@80:BTY0P1jNWX20:^[Z`80WinO0P2TY:@3
0:6QX@80WIfM0P2FUYH208f=S@80Ph>30P1lO7`207QhN0<0NWYj0P21PH420:2PX080[Zj^0P2i^KT2
0;Bd]080T92@0`1VIVH2034a<@809BDU0P0P820202@T90809bLW0P0Z:RX502/[:`808B4Q0P0W9bL2
02PX:0809BDU0P0];Bd205]KF`<0LG5a0P1TI6@205QHF080AdM70P13@d<204E5A@80CTi>0`1KFe/2
05UIF@80JFUY0P1]KFd2075aL@80M7Ad0P1gMgL307]kN`80OWin0P1mOGd207alO080Ogmo1`21PH42
08:2PP80Ph>30P25QHD208N7Q`80R8R80P29RHT308^;R`80SXj>102@T90208n?S`80SXj>0P2?Shl3
096AT@80Ti>C0P2DU9@209JFUP@0UiNG0P2FUYH309RHV080Vi^K0P2MWId609jNWP80WIfM1@2NWYh2
09nOW`P0X:2P0P2NWYh309fMW@80WinO0P2QXJ4209jNWP80VYZJ0P2FUYH209:BTP<0TI6A0P2?Shl2
08j>SP80RXZ:0P20P80207MgM`80J6QX0`1`L70207EeM@80OWin0P24Q8@208V9R@80SHf=0P2>SXh3
08^;R`80R8R80P2:RXX208f=S@@0Shn?0P2=SHd308Z:RP80Ph>30P1lO7`207]kN`P0b>3H00060<SP
f0809RHV0P0a<C4202HV9P<07AdM0P0Q8B4202TY:@80NWYj0P2[Zj/209nOW`80Y:BT0`2QXJ4209fM
W@80UYJF0P2=SHd208>3P`80O7al0P1hN7P307YjNP80PH610P2PX:020:j^[P80^KVi0P2d];@2092@
T0<0IVIV0P0a<C4202DU9@80820P0P0T92@202LW9`80:RXZ1@0[:b/2024Q8@809bLW0P0X:2P202DU
9@80;Bd]0P1KFe/3075aL@80I6AT0P1HF5P204M7A`80@d=30P15ADD204i>CP<0Fe]K0P1IFET206UY
J@80KFe]0P1aLG4207AdM080MgMg0`1kNg/207inOP80OGem0P1lO7`207moO`L0PH610P22PX8208>3
P`80QHF50P27QhL208R8R080RHV90`2;Rh/208j>SP@0T92@0P2?Shl208j>SP80Shn?0`2ATI4209>C
T`80U9BD0P2FUYH409NGU`80UYJF0`2HV9P209^KV`80WIfM1P2NWYh209fMW@D0WYjN0P2OWil80:2P
X080WYjN0`2MWId209nOW`80XJ6Q0P2NWYh209ZJVP80UYJF0P2BTY83096AT@80Shn?0P2>SXh208Z:
RP80P8200P1gMgL206QXJ0<0L71`0P1eMGD207inOP80Q8B40P29RHT208f=S@80SXj>0`2;Rh/208R8
R080RXZ:0P2=SHd408n?S`80SHf=0`2:RXX208>3P`80O7al0P1kNg/80<SPf0001P38h=P2028R8P80
;Bd]0P0[:b/3028R8P808B4Q0P0P820204a<C080Q8B4102JVYX3096AT@80S8b<0P26QXH207QhN080
LW9b0P1]KFd206IVIP<0M7Ad0P21PH4208b<S080TI6A0P2OWil20:j^[P80WIfM0`1]KFd203Ti>@80
:BTY0P0Q8B4202@T90809BDU0P0W9bL502TY:@80:2PX0P0/;2`204E5A@809BDU0P0^;Rh205YJFP<0
L71`0P1NGUh204i>CP@0A4A40P18B4P204m?C`<0F5QH0P1IFET206EUI@80K6a/0P1bLW8207AdM080
MGEe0`1iNGT607emO@80Ogmo0P21PH450820P080PX:20P24Q8@208J6QP80QhN70P29RHT208^;R`<0
S8b<0P2=SHd2092@T080TY:B0P2@T90208n?S`80TI6A0`2CTi<209FEU@80UiNG102HV9P409NGU`<0
V9RH0P2JVYX209^KV`@0W9bL1`2MWId209jNWP80WinO3@2PX:040:6QX@80WIfM0P2IVIT209NGU`80
UIFE0`2ATI4408f=S@80Rh^;0P20P80207IfMP80Jf][0`1_Kfl207AdM080O7al0P22PX8208R8R080
Rh^;0P2<S8`308Z:RP80R8R80P2;Rh/408j>SP80S8b<0P29RHT308F5Q@80PH610P1mOGd207alO0P0
b>3H00060<SPf0808R8R0P0];Bd202/[:`<08R8R0P0Q8B42020P8080C4a<0P24Q8@409ZJVP<0TI6A
0P2<S8`208J6QP80N7Qh0P1bLW8206e]K@80IVIV0`1dM7@20861P@80S8b<0P2ATI4209nOW`80[Zj^
0P2MWId306e]K@80>CTi0P0Y:BT2024Q8@8092@T0P0U9BD202LW9`D0:BTY0P0X:2P202`/;080ADE5
0P0U9BD202h^;P80FUYJ0`1`L70205iNGP80CTi>1014A4@204Q8B080Cdm?0`1HF5P205UIF@80IFEU
0P1/K6`2079bLP80M7Ad0P1eMGD307UiN@H0OGem0P1oOgl20861P@D0P8200P22PX8208B4Q080QXJ6
0P27QhL208V9R@80Rh^;0`2<S8`208f=S@80T92@0P2BTY82092@T080Shn?0P2ATI4309>CT`80UIFE
0P2GUiL409RHV0@0UiNG0`2HV9P209ZJVP80Vi^K102LW9`709fMW@80WYjN0P2OWil=0:2PX0@0XJ6Q
0P2MWId209VIV@80UiNG0P2EUID3096AT@@0SHf=0P2;Rh/20820P080MWIf0P1[Jf/306m_K`80M7Ad
0P1lO7`208:2PP80R8R80P2;Rh/208b<S0<0RXZ:0P28R8P208^;R`@0SXj>0P2<S8`208V9R@<0QHF5
0P21PH4207emO@80O7al2038h=P000H0b>3H0P0P820202LW9`80;bl_0`0X:2P2024Q8@807alO0P0S
8b<204a<C080N7Qh0P1nOWh507emO@80NWYj0P1UIFD206ATI0@0Jf][0`2BTY820;Bd]080[Zj^0P2R
XZ8208f=S@80SXj>0P2NWYh308F5Q@80FEUI0P15ADD202h^;P808R8R0P0Q8B4202DU9@809bLW1@0X
:2P202LW9`808R8R0P0T92@202`/;080FEUI0`1]KFd205QHF080A4A40P10@40204A4A080C4a<0P1A
DE4305EEE@80Fe]K0P1QHF4206YZJP80LW9b101dM7@307QhN080O7al0P1mOGd207inOP80Ogmo1020
P80307moO`80Ph>31026QXH208N7Q`80RXZ:1`2<S8`208n?S`80TY:B102ATI4209>CT`<0UIFE0P2G
UiL209VIV@80VYZJ0P2IVIT209RHV080UiNG0`2HV9P209ZJVP@0VIVI0P2JVYX209bLW080WIfM1@2N
WYh409nOW`80X:2P102QXJ420::RXP<0Xj>S0P2RXZ820:2PX080W9bL0P2IVIT409RHV0<0TY:B0P2<
S8`208f=S@80S8b<0P21PH4207EeM@80LG5a0`1_Kfl207AdM080NWYj0P20P80208F5Q@T0R8R80P2:
RXX208b<S080RXZ:0P27QhL208>3P`<0P820101nOWh207emO@P0b>3H00060<SPf080820P0P0W9bL2
02l_;`<0:2PX0P0Q8B4201lO7`808b<S0P1<C4`207QhN080OWin1@1mOGd207YjNP80IFEU0P1TI6@4
06][J`<0TY:B0P2d];@20:j^[P80XZ:R0P2=SHd208j>SP80WYjN0`25QHD205UIF@80ADE50P0^;Rh2
028R8P808B4Q0P0U9BD202LW9`D0:2PX0P0W9bL2028R8P8092@T0P0/;2`205UIF@<0KFe]0P1HF5P2
04A4A080@4100P14A4@204a<C080DE5A0`1EEED205]KF`80HF5Q0P1ZJVX2079bLP@0M7Ad0`1hN7P2
07alO080OGem0P1nOWh207moO`@0P8200`1oOgl208>3P`@0QXJ60P27QhL208Z:RPL0S8b<0P2?Shl2
09:BTP@0TI6A0P2CTi<309FEU@80UiNG0P2IVIT209ZJVP80VIVI0P2HV9P209NGU`<0V9RH0P2JVYX4
09VIV@80VYZJ0P2LW9`209fMW@D0WYjN102OWil20:2PX0@0XJ6Q0P2RXZ830:>SX`80XZ:R0P2PX:02
09bLW080VIVI102HV9P309:BTP80S8b<0P2=SHd208b<S080PH610P1eMGD2075aL@<0Kfm_0P1dM7@2
07YjNP80P8200P25QHD908R8R080RXZ:0P2<S8`208Z:RP80QhN70P23Ph<30820P0@0OWin0P1mOGd8
0<SPf0001P38h=P202@T9080:2PX0P0^;Rh3034a<@80:BTY0P0L71`201/K6`80<S8b0P1ADE4206MW
I`<0IFEU0P1fMWH20861P@@0JVYZ0P1cLg<2079bLP<0Shn?0P2i^KT20<g=c@80`L710P2UYJD208J6
QP80T92@0`21PH4203@d=0809BDU0P0R8R82020P80808b<S1`0V9RH202PX:080:BTY0P0U9BD202HV
9P80;Bd]0P1JFUX306][J`80Fe]K0P10@40203lo?`80@T920P1=CDd2055AD@<0EEEE0P1LG5`2065Q
H@80JFUY0P1`L702079bLP80M7Ad0`1hN7P207]kN`80OGem0P1nOWh20820P0@0PH610`22PX8208B4
Q080QXJ61027QhL208R8R0D0RHV90P2;Rh/208j>SP80TY:B102CTi<209BDU0<0UIFE0P2GUiL409VI
V@80V9RH0P2GUiL209JFUP<0V9RH0P2IVIT409ZJVP80W9bL102OWil70:2PX080XJ6Q1P2RXZ820:>S
X`<0Y:BT0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080UYJF0`2BTY8208j>SP80Shn?0P2>SXh208F5
Q@80O7al0P1fMWH3079bLP80M7Ad0P1hN7P207inOP80Ph>30P26QXH208N7Q`D0R8R80P27QhL208J6
QP80Ph>30P21PH4207inOPD0O7al101mOGd80<SPf0001P38h=P202@T9080:2PX0P0^;Rh3034a<@80
:BTY0P0L71`201/K6`80<S8b0P1ADE4206MWI`<0IFEU0P1fMWH20861P@@0JVYZ0P1cLg<2079bLP<0
Shn?0P2i^KT20<g=c@80`L710P2UYJD208J6QP80T92@0`21PH4203@d=0809BDU0P0R8R82020P8080
8b<S1`0V9RH202PX:080:BTY0P0U9BD202HV9P80;Bd]0P1JFUX306][J`80Fe]K0P10@40203lo?`80
@T920P1=CDd2055AD@<0EEEE0P1LG5`2065QH@80JFUY0P1`L702079bLP80M7Ad0`1hN7P207]kN`80
OGem0P1nOWh20820P0@0PH610`22PX8208B4Q080QXJ61027QhL208R8R0D0RHV90P2;Rh/208j>SP80
TY:B102CTi<209BDU0<0UIFE0P2GUiL409VIV@80V9RH0P2GUiL209JFUP<0V9RH0P2IVIT409ZJVP80
W9bL102OWil70:2PX080XJ6Q1P2RXZ820:>SX`<0Y:BT0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080
UYJF0`2BTY8208j>SP80Shn?0P2>SXh208F5Q@80O7al0P1fMWH3079bLP80M7Ad0P1hN7P207inOP80
Ph>30P26QXH208N7Q`D0R8R80P27QhL208J6QP80Ph>30P21PH4207inOPD0O7al101mOGd80<SPf000
1P38h=P202PX:080:RXZ0P0/;2`303Ti>@80<C4a0P0L71`201dM7@808R8R0P0/;2`204i>CP<0CDe=
0P1`L70208Z:RP80MWIf0P1cLg<207moO`80Ng]k0`1oOgl209nOW`@0bLW90P38b<P20:VYZ@80YjNW
0`2PX:0203`l?0809bLW0P0T92@201hN7P808b<S0P0X:2P202LW9`<092@T0P0W9bL202XZ:P809BDU
0P0W9bL202d];@80FUYJ0`1YJFT205eMG@80?clo0P0n?Sh20451@@80C4a<0P1ADE4305IFEP80G5aL
0P1SHf<206UYJ@80KVi^0P1bLW8207EeM@<0N7Qh0P1kNg/207emO@80OWin0P20P80208:2PP80Ph>3
0`24Q8@208F5Q@80QXJ60P27QhL208R8R080QXJ60P25QHD308J6QP80RXZ:0P2=SHd2096AT@80U9BD
102FUYH309FEU@80UiNG102HV9P209NGU`80UYJF0P2GUiL309RHV080VYZJ0P2KVi/209bLW080WYjN
1`2QXJ440::RXP80Xj>S0P2TY:@20:>SX`80XZ:R0P2SXj<30:BTY080XJ6Q0P2OWil209fMW@80W9bL
0P2HV9P209FEU@<0TY:B102ATI4208n?S`80RXZ:0P23Ph<207alO0<0MgMg0P1eMGD207IfMP80O7al
0P21PH4208F5Q@80QXJ61@27QhL208>3P`80Ogmo0P1mOGd207alO080Ng]k0`1jNWX207]kN`@0O7al
2038h=P000H0b>3H0P0X:2P202XZ:P80;2`/0`0i>CT2034a<@8071`L0P0M7Ad2028R8P80;2`/0P1>
CTh304e=C@80L71`0P2:RXX207IfMP80Lg=c0P1oOgl207]kN`<0Ogmo0P2OWil40<W9b@80b<S80P2Y
ZJT20:NWY`<0X:2P0P0l?3`202LW9`8092@T0P0N7Qh202<S8`80:2PX0P0W9bL302@T90809bLW0P0Z
:RX202DU9@809bLW0P0];Bd205YJFP<0JFUY0P1MGEd203lo?`80?Shn0P11@D4204a<C080DE5A0`1F
EUH205aLG080Hf=S0P1YJFT206i^KP80LW9b0P1eMGD307QhN080Ng]k0P1mOGd207inOP80P8200P22
PX8208>3P`<0Q8B40P25QHD208J6QP80QhN70P28R8P208J6QP80QHF50`26QXH208Z:RP80SHf=0P2A
TI4209BDU0@0UYJF0`2EUID209NGU`@0V9RH0P2GUiL209JFUP80UiNG0`2HV9P209ZJVP80Vi^K0P2L
W9`209jNWPL0XJ6Q102RXZ820:>SX`80Y:BT0P2SXj<20::RXP80Xj>S0`2TY:@20:6QX@80WinO0P2M
WId209bLW080V9RH0P2EUID309:BTP@0TI6A0P2?Shl208Z:RP80Ph>30P1lO7`307MgM`80MGEe0P1f
MWH207alO080PH610P25QHD208J6QPD0QhN70P23Ph<207moO`80OGem0P1lO7`207]kN`<0NWYj0P1k
Ng/407alO0P0b>3H00060<SPf0809BDU0P0X:2P202/[:`<0=CDe0P0_;bl202LW9`809BDU100S8b<2
02`/;0<0:b/[0P1FEUH408Z:RP80MGEe0P1kNg/507QhN080Shn?0P2m_Kd20=3@d080e=CD0P36a/H2
0<C4a0<0`l?30P1mOGd202l_;`807QhN0P0Q8B4202@T9080:BTY0P0X:2P302HV9P809bLW0P0X:2P2
02<S8`809RHV0P0[:b/205IFEP<0IVIV0P1JFUX203lo?`80?Shn0P16ATH204Y:BP80DE5A0`1IFET2
05iNGP80Hf=S0P1YJFT206m_K`80Lg=c0P1fMWH307QhN080NWYj0P1mOGd207moO`80PH611023Ph<3
08B4Q080QHF50P26QXH408N7Q`80RHV90P2:RXX308n?S`80RXZ:0P2=SHd2096AT@80U9BD102FUYH3
09FEU@80UiNG0P2HV9P209NGU`80UYJF0P2HV9P509ZJVP80Vi^K102LW9`209fMW@80WYjN0P2OWil3
0:6QX@80Xj>S102UYJD20:BTY080Xj>S102QXJ430::RXP@0XJ6Q0P2OWil209fMW@80VYZJ0P2GUiL3
09BDU080TY:B0P2@T90208f=S@80RHV90P25QHD207moO`<0Ng]k0P1jNWX207]kN`80O7al0P1nOWh2
08:2PP80QHF51@26QXH20861P@@0O7al0P1mOGd207]kN`L0NGUi0P1nOWh80<SPf0001P38h=P202DU
9@80:2PX0P0[:b/303De=@80;bl_0P0W9bL202DU9@@08b<S0P0/;2`302/[:`80EUIF102:RXX207Ee
M@80Ng]k1@1hN7P208n?S`80_Kfm0P3@d=020=CDe080a/K60P34a<@30<?3``80OGem0P0_;bl201hN
7P808B4Q0P0T92@202TY:@80:2PX0`0V9RH202LW9`80:2PX0P0S8b<202HV9P80:b/[0P1FEUH306IV
IP80FUYJ0P0o?cl203hn?P80ATI60P1:BTX2055AD@<0FEUI0P1NGUh206=SH`80JFUY0P1_Kfl207=c
L`80MWIf0`1hN7P207YjNP80OGem0P1oOgl20861P@@0Ph>30`24Q8@208F5Q@80QXJ61027QhL208V9
R@80RXZ:0`2?Shl208Z:RP80SHf=0P2ATI4209BDU0@0UYJF0`2EUID209NGU`80V9RH0P2GUiL209JF
UP80V9RH1@2JVYX209^KV`@0W9bL0P2MWId209jNWP80WinO0`2QXJ420:>SX`@0YJFU0P2TY:@20:>S
X`@0XJ6Q0`2RXZ840:6QX@80WinO0P2MWId209ZJVP80UiNG0`2DU9@209:BTP80T92@0P2=SHd208V9
R@80QHF50P1oOgl307]kN`80NWYj0P1kNg/207alO080OWin0P22PX8208F5Q@D0QXJ60P21PH4407al
O080OGem0P1kNg/707UiN@80OWin2038h=P000H0b>3H0P0Q8B4202LW9`80;bl_0`0h>3P2030`<080
:BTY100O7al202<S8`8071`L0`0R8R8204E5A@80PX:20P2HV9P207QhN080MGEe0P1bLW8307AdM080
Ogmo0P2WYjL20<k>cP80dM7A0P3?cll20<[:bP<0clo?0P2j^[X204];B`80:RXZ100U9BD202XZ:P80
:BTY0`0X:2P402HV9P808B4Q0P0T92@202TY:@80DU9B0`1RHV8205ADE080?Cdm0P0o?cl204Y:BP80
B4Q80P1BDU8305]KF`80H61P0P1TI6@206][J`80LG5a0P1eMGD207QhN0<0NGUi0P1jNWX207emO@80
P8200P22PX8708>3P`80Q8B41026QXH208N7Q`80S8b<0P2>SXh309NGU`80Rh^;0P2>SXh2096AT@80
Ti>C0P2EUID509JFUP80UiNG0P2HV9P409NGU`80VYZJ1@2MWId409bLW0H0WIfM0P2NWYh30:2PX080
Y:BT0P2WYjL20:JVYP80Y:BT0P2RXZ820:6QX@D0X:2P0P2RXZ820:>SX`80XJ6Q0P2OWil209bLW080
VIVI0`2FUYH209>CT`80Shn?0P2;Rh/208R8R080QXJ60P22PX830820P080Ogmo0P20P80207inOP80
OGem0P20P80208B4Q0<0QHF50P24Q8@20820P080Ng]k0P1mOGd207moO`80O7al0`1iNGT207QhN080
MWIf0P1oOgl80<SPf0001P38h=P2024Q8@809bLW0P0_;bl303Ph>080<30`0P0Y:BT401lO7`808b<S
0P0L71`3028R8P80ADE50P22PX8209RHV080N7Qh0P1eMGD2079bLP<0M7Ad0P1oOgl20:NWY`80c/k>
0P3AdM420<o?c`80b/[:0`3?cll20;Zj^P80Bd];0P0Z:RX402DU9@80:RXZ0P0Y:BT302PX:0@09RHV
0P0Q8B4202@T9080:BTY0P1BDU83069RHP80E5AD0P0m?Cd203lo?`80BTY:0P18B4P2059BDP<0Fe]K
0P1PH60206ATI080Jf][0P1aLG4207EeM@80N7Qh0`1iNGT207YjNP80OGem0P20P80208:2PPL0Ph>3
0P24Q8@408J6QP80QhN70P2<S8`208j>SP<0UiNG0P2;Rh/208j>SP80TI6A0P2CTi<209FEU@D0UYJF
0P2GUiL209RHV0@0UiNG0P2JVYX509fMW@@0W9bL1P2MWId209jNWP<0X:2P0P2TY:@20:NWY`80YZJV
0P2TY:@20::RXP80XJ6Q1@2PX:020::RXP80Xj>S0P2QXJ4209nOW`80W9bL0P2IVIT309JFUP80Ti>C
0P2?Shl208^;R`80R8R80P26QXH208:2PP<0P8200P1oOgl20820P080OWin0P1mOGd20820P080Q8B4
0`25QHD208B4Q080P8200P1kNg/207emO@80Ogmo0P1lO7`307UiN@80N7Qh0P1fMWH207moO`P0b>3H
00060<SPf080820P0P0^;Rh203`l?0<0Cdm?0P0e=CD2028R8P808B4Q0P0O7al2020P808061PH0`0N
7Qh203<c<`80JVYZ0P2ATI4208N7Q`80M7Ad0P1`L70307QhN080NGUi0P2>SXh20;bl_080d=3@103=
cLd30=7Ad@80d=3@0P2NWYh203<c<`809bLW0P0Q8B4202LW9`809RHV0`0W9bL202DU9@8092@T0P0R
8R8202HV9P80:BTY0P1>CTh305mOG`80CTi>0P0i>CT203lo?`80ATI60P18B4P2055AD@<0FEUI0P1P
H60206IVIP80K6a/0P1`L70207AdM080N7Qh0`1lO7`407inOP80OGem0P20P80208B4Q080Ph>30`22
PX8208B4Q080QhN70P28R8P208V9R@@0RXZ:0`2BTY8208j>SP80U9BD0P2ATI4209>CT`80U9BD0P2F
UYH709RHV080VYZJ0P2LW9`209jNWP80X:2P0`2NWYh209bLW080WIfM0P2NWYh409nOW`80XJ6Q0`2T
Y:@20:FUY@@0YZJV102UYJD20:BTY080Xj>S0`2RXZ860:>SX`80XZ:R0P2PX:0209fMW@<0VIVI0P2D
U9@2092@T080SHf=0P2:RXX208R8R080QHF50`23Ph<208:2PPH0PH610P22PX8208>3P`<0PX:20P20
P80207inOP80O7al101kNg/207YjNPL0NGUi0P1nOWh80<SPf0001P38h=P2020P8080;Rh^0P0l?3`3
04m?C`80=CDe0P0R8R82024Q8@807alO0P0P820201PH60<07QhN0P0c<c<206YZJP80TI6A0P27QhL2
07AdM080L71`0`1hN7P207UiN@80SXj>0P2l_;`20=3@d0@0cLg=0`3AdM420=3@d080WYjN0P0c<c<2
02LW9`808B4Q0P0W9bL202HV9P<09bLW0P0U9BD202@T90808R8R0P0V9RH202TY:@80CTi>0`1OGel2
04i>CP80>CTi0P0o?cl204I6AP80B4Q80P1ADE4305UIF@80H61P0P1VIVH206a/K080L71`0P1dM7@2
07QhN0<0O7al101nOWh207emO@80P8200P24Q8@208>3P`<0PX:20P24Q8@208N7Q`80R8R80P29RHT4
08Z:RP<0TY:B0P2>SXh209BDU080TI6A0P2CTi<209BDU080UYJF1`2HV9P209ZJVP80W9bL0P2NWYh2
0:2PX0<0WYjN0P2LW9`209fMW@80WYjN102OWil20:6QX@<0Y:BT0P2UYJD40:JVYP@0YJFU0P2TY:@2
0:>SX`<0XZ:R1P2SXj<20::RXP80X:2P0P2MWId309VIV@80U9BD0P2@T90208f=S@80RXZ:0P28R8P2
08F5Q@<0Ph>30P22PX860861P@80PX:20P23Ph<308:2PP80P8200P1nOWh207alO0@0Ng]k0P1jNWX7
07UiN@80OWin2038h=P000H0b>3H0P0P820202h^;P80?3`l0`1?Cdl203De=@808R8R0P0Q8B4201lO
7`80820P0P0H61P301hN7P80<c<c0P1ZJVX2096AT@80QhN70P1dM7@2071`L0<0N7Qh0P1iNGT208j>
SP80_;bl0P3@d=040<g=c@<0dM7A0P3@d=0209jNWP80<c<c0P0W9bL2024Q8@809bLW0P0V9RH302LW
9`809BDU0P0T92@2028R8P809RHV0P0Y:BT204i>CP<0GemO0P1>CTh203Ti>@80?clo0P16ATH204Q8
B080DE5A0`1IFET2061PH080IVIV0P1/K6`2071`L080M7Ad0P1hN7P307alO0@0OWin0P1mOGd20820
P080Q8B40P23Ph<308:2PP80Q8B40P27QhL208R8R080RHV9102:RXX309:BTP80SXj>0P2DU9@2096A
T@80Ti>C0P2DU9@209JFUPL0V9RH0P2JVYX209bLW080WYjN0P2PX:0309jNWP80W9bL0P2MWId209jN
WP@0WinO0P2QXJ430:BTY080YJFU102VYZH40:FUY@80Y:BT0P2SXj<30::RXPH0Xj>S0P2RXZ820:2P
X080WIfM0`2IVIT209BDU080T92@0P2=SHd208Z:RP80R8R80P25QHD308>3P`80PX:21P21PH4208:2
PP80Ph>30`22PX820820P080OWin0P1lO7`407]kN`80NWYj1`1iNGT207inOPP0b>3H00060<SPf080
8b<S0P0g=cL204];B`<0LG5a0P1>CTh202HV9P808B4Q0P0M7Ad201lO7`806a/K0`0O7al202DU9@80
Cdm?0P22PX8209JFUP80N7Qh0P1^KVh307]kN`80MWIf0P1iNGT20:FUY@80bLW90P36a/H20<c<c0<0
cLg=0P3?cll20=?Cd`80QXJ60P0`<30202@T90809RHV0P0U9BD302HV9P8092@T100S8b<202PX:080
:BTY0P1:BTX305eMG@80B4Q80P0e=CD203lo?`80@D510P19BDT2051@D0<0F5QH0P1PH60206QXJ080
KFe]0P1`L70207AdM080N7Qh0`1nOWh208:2PP80Ogmo0P1kNg/207moO`80Q8B40P22PX830861P@80
Q8B40P28R8P208Z:RP80Rh^;0P28R8P208J6QP<0Rh^;0P2@T90209VIV@80TI6A0P2BTY8209>CT`80
UiNG0`2KVi/209VIV@80V9RH0P2LW9`20:6QX@@0XZ:R0`2PX:0209fMW@80WYjN0P2PX:020::RXP80
Xj>S0P2VYZH30:NWY`80YZJV0P2UYJD20:JVYP80YjNW102XZ:P20:NWY`<0YJFU0P2TY:@20:>SX`@0
YJFU0P2SXj<209nOW`<0Vi^K0P2FUYH209:BTP80T92@0P2<S8`208Z:RP80QhN70`25QHD208>3P`80
PX:20P23Ph<208F5Q@80Q8B40P22PX8307moO`H0OGem0P1jNWX207MgM`80N7Qh0`1jNWX207alO080
OGem0P1lO7`80<SPf0001P38h=P202<S8`80=cLg0P1;Bd/3075aL@80CTi>0P0V9RH2024Q8@807AdM
0P0O7al201/K6`<07alO0P0U9BD204m?C`80PX:20P2FUYH207QhN080KVi^0`1kNg/207IfMP80NGUi
0P2UYJD20<W9b@80a/K60P3<c<`30<g=c@80clo?0P3Cdm<208J6QP80<30`0P0T92@202HV9P809BDU
0`0V9RH202@T90@08b<S0P0X:2P202TY:@80BTY:0`1MGEd204Q8B080=CDe0P0o?cl20451@@80BDU9
0P1@D50305QHF080H61P0P1XJ6P206e]K@80L71`0P1dM7@207QhN0<0OWin0P22PX8207moO`80Ng]k
0P1oOgl208B4Q080PX:20`21PH4208B4Q080R8R80P2:RXX208^;R`80R8R80P26QXH308^;R`80T92@
0P2IVIT2096AT@80TY:B0P2CTi<209NGU`<0Vi^K0P2IVIT209RHV080W9bL0P2QXJ440::RXP<0X:2P
0P2MWId209jNWP80X:2P0P2RXZ820:>SX`80YZJV0`2WYjL20:JVYP80YJFU0P2VYZH20:NWY`@0Z:RX
0P2WYjL30:FUY@80Y:BT0P2SXj<40:FUY@80Xj>S0P2OWil309^KV`80UYJF0P2BTY82092@T080S8b<
0P2:RXX208N7Q`<0QHF50P23Ph<208:2PP80Ph>30P25QHD208B4Q080PX:20`1oOgl607emO@80NWYj
0P1gMgL207QhN0<0NWYj0P1lO7`207emO@80O7al2038h=P000H0b>3H0P0/;2`203lo?`80EeMG0`26
QXH207EeM@80ADE50P0S8b<201/K6`807AdM0P0J6QX301dM7@807QhN0P0i>CT206m_K`80W9bL0P2=
SHd206i^KP<0M7Ad0P1bLW8207IfMP80U9BD0P2h^;P20<O7a`80cLg=0`3<c<`20<g=c@80clo?0P32
`/8206UYJ@80:b/[0P0N7Qh202@T90D08b<S0P0T92@2028R8P809BDU0P0[:b/204Q8B0<0F5QH0P13
@d<203Ph>080>c/k0P0o?cl204Q8B080Cdm?0`1GEeL206EUI@80IfMW0P1/K6`2071`L080M7Ad0P1h
N7P307emO@@0P8200P1nOWh20861P@80Ph>30P22PX830861P@80Ph>30P27QhL208V9R@@0RXZ:0P29
RHT308b<S080TI6A0P2GUiL209>CT`80UIFE0P2FUYH209VIV@<0Vi^K102JVYX209jNWP80XZ:R102S
Xj<30:2PX080WYjN0P2PX:020:>SX`80YZJV102WYjL30:JVYP80Z:RX0P2YZJT20:RXZ080YjNW0P2X
Z:P20:VYZ@80Z:RX0`2WYjL20:FUY@80Xj>S0P2TY:@20:FUY@80XZ:R0P2NWYh309^KV`80V9RH0P2E
UID2096AT@80SHf=0P29RHT208N7Q`<0QXJ60P24Q8@208:2PP80Q8B41025QHD208>3P`<0P8200P1n
OWh207moO`80P8200P1lO7`207QhN080NGUi0`1kNg/207alO080OGem0P1lO7`80<SPf0001P38h=P2
02`/;080?clo0P1GEeL308J6QP80MGEe0P15ADD202<S8`806a/K0P0M7Ad201XJ6P<07AdM0P0N7Qh2
03Ti>@80Kfm_0P2LW9`208f=S@80KVi^0`1dM7@2079bLP80MWIf0P2DU9@20;Rh^080alO70P3=cLd3
0<c<c080cLg=0P3?cll20<;2`P80JFUY0P0[:b/201hN7P8092@T1@0S8b<202@T90808R8R0P0U9BD2
02/[:`80B4Q80`1HF5P204=3@`80>3Ph0P0k>c/203lo?`80B4Q80P1?Cdl305MGE`80IFEU0P1WIfL2
06a/K080L71`0P1dM7@207QhN0<0OGem1020P80207inOP80PH610P23Ph<208:2PP<0PH610P23Ph<2
08N7Q`80RHV9102:RXX208V9R@<0S8b<0P2ATI4209NGU`80Ti>C0P2EUID209JFUP80VIVI0`2KVi/4
09ZJVP80WYjN0P2RXZ840:>SX`<0X:2P0P2NWYh20:2PX080Xj>S0P2VYZH40:NWY`<0YZJV0P2XZ:P2
0:VYZ@80Z:RX0P2WYjL20:RXZ080ZJVY0P2XZ:P30:NWY`80YJFU0P2SXj<20:BTY080YJFU0P2RXZ82
09jNWP<0Vi^K0P2HV9P209FEU@80TI6A0P2=SHd208V9R@80QhN70`26QXH208B4Q080PX:20P24Q8@4
08F5Q@80Ph>30`20P80207inOP80Ogmo0P20P80207alO080N7Qh0P1iNGT307]kN`80O7al0P1mOGd2
07alO0P0b>3H00060<SPf080>CTi0P1=CDd206MWI`<0QhN70P1jNWX205=CD`809RHV100M7Ad201/K
6`D071`L0P0X:2P205UIF@80UiNG0P2OWil2075aL@<0KVi^0P1`L70207QhN080QHF50P2VYZH20<K6
aP80bl_;0`39bLT20<g=c@@0c<c<0P2e]KD204A4A0@092@T0`0Q8B4202<S8`809RHV100R8R8202`/
;080ATI60`1EEED203lo?`80>c/k0P0g=cL203dm?@80AdM70P1@D50305MGE`80JFUY0P1VIVH206a/
K080Kfm_0P1dM7@207UiN@<0Ng]k0P1mOGd20820P080PX:20P23Ph<708:2PP80Ph>30P24Q8@208N7
Q`80RXZ:0P2<S8`208f=S@<0Shn?0P2ATI4209>CT`80UIFE0P2HV9P409ZJVPD0Vi^K0P2LW9`209nO
W`80XZ:R102SXj<30:2PX080WinO0P2RXZ820:JVYP80ZJVY0P2[Zj/20:RXZ0<0YJFU0P2YZJT20:f]
[@80Zj^[0P2XZ:P60:VYZ@<0Z:RX0P2VYZH20:>SX`@0Y:BT0P2PX:0209bLW0<0Vi^K0P2JVYX209NG
U`80TY:B0P2=SHd208R8R0D0QhN70P24Q8@208>3P`80Q8B41P25QHD308:2PP80P8201021PH4207em
O@80NGUi0P1jNWX307]kN`80O7al101mOGd80<SPf0001P38h=P203Ti>@80CDe=0P1WIfL308N7Q`80
NWYj0P1CDe<202HV9P@07AdM0P0K6a/501`L7080:2PX0P1IFET209NGU`80WinO0P1aLG4306i^KP80
L71`0P1hN7P208F5Q@80YZJV0P36a/H20<_;b`<0bLW90P3=cLd40<c<c080]KFe0P14A4@402@T90<0
8B4Q0P0S8b<202HV9P@08R8R0P0/;2`204I6AP<0EEEE0P0o?cl203/k>`80=cLg0P0m?Cd204M7A`80
D51@0`1GEeL206UYJ@80IVIV0P1/K6`206m_K`80M7Ad0P1iNGT307]kN`80OGem0P20P80208:2PP80
Ph>31`22PX8208>3P`80Q8B40P27QhL208Z:RP80S8b<0P2=SHd308n?S`80TI6A0P2CTi<209FEU@80
V9RH102JVYX509^KV`80W9bL0P2OWil20::RXP@0Xj>S0`2PX:0209nOW`80XZ:R0P2VYZH20:VYZ@80
Zj^[0P2XZ:P30:FUY@80ZJVY0P2][Jd20:^[Z`80Z:RX1P2YZJT30:RXZ080YZJV0P2SXj<40:BTY080
X:2P0P2LW9`309^KV`80VYZJ0P2GUiL209:BTP80SHf=0P28R8P508N7Q`80Q8B40P23Ph<208B4Q0H0
QHF50`22PX820820P0@0PH610P1mOGd207UiN@80NWYj0`1kNg/207alO0@0OGem2038h=P000H0b>3H
0P14A4@2065QH@80Ph>30`2FUYH20820P080GEeM0P0X:2P201hN7P807alO0P0N7Qh301lO7`8071`L
0P0R8R8203`l?080Ng]k0P2KVi/208>3P`<0LW9b0P1_Kfl2075aL@80Ng]k0P2MWId20<71`@80cLg=
0`38b<P20<k>cP80cLg=0P3De=@20<W9b@80YjNW0P17AdL201hN7P<08R8R100U9BD202<S8`8092@T
0P0X:2P204E5A@<0EEEE0P0j>SX203Lg=`80<c<c0P0l?3`204Q8B080DE5A0`1JFUX406IVIP80Jf][
0P1`L70207AdM080N7Qh0`1jNWX207alO080P8202023Ph<708B4Q080QhN70P2:RXX208f=S@D0Shn?
0P2ATI4209>CT`80UiNG102HV9P209^KV`D0WIfM0P2NWYh209nOW`80X:2P1`2QXJ420::RXP80YZJV
0P2ZZZX20:^[Z`80[:b/0P2YZJT30:NWY`80ZJVY102/[:`40:^[Z`L0ZZZZ0P2WYjL20:BTY0@0YJFU
0P2RXZ8209jNWP<0W9bL0P2JVYX209NGU`80U9BD0P2>SXh208R8R080QhN70`26QXH208F5Q@80Q8B4
0P25QHD208J6QP80QHF50P24Q8@308:2PP@0PH610P20P80207emO@@0NGUi0`1jNWX207emO@@0Ogmo
2038h=P000H0b>3H0P14A4@2065QH@80Ph>30`2FUYH20820P080GEeM0P0X:2P201hN7P807alO0P0N
7Qh301lO7`8071`L0P0R8R8203`l?080Ng]k0P2KVi/208>3P`<0LW9b0P1_Kfl2075aL@80Ng]k0P2M
WId20<71`@80cLg=0`38b<P20<k>cP80cLg=0P3De=@20<W9b@80YjNW0P17AdL201hN7P<08R8R100U
9BD202<S8`8092@T0P0X:2P204E5A@<0EEEE0P0j>SX203Lg=`80<c<c0P0l?3`204Q8B080DE5A0`1J
FUX406IVIP80Jf][0P1`L70207AdM080N7Qh0`1jNWX207alO080P8202023Ph<708B4Q080QhN70P2:
RXX208f=S@D0Shn?0P2ATI4209>CT`80UiNG102HV9P209^KV`D0WIfM0P2NWYh209nOW`80X:2P1`2Q
XJ420::RXP80YZJV0P2ZZZX20:^[Z`80[:b/0P2YZJT30:NWY`80ZJVY102/[:`40:^[Z`L0ZZZZ0P2W
YjL20:BTY0@0YJFU0P2RXZ8209jNWP<0W9bL0P2JVYX209NGU`80U9BD0P2>SXh208R8R080QhN70`26
QXH208F5Q@80Q8B40P25QHD208J6QP80QHF50P24Q8@308:2PP@0PH610P20P80207emO@@0NGUi0`1j
NWX207emO@@0Ogmo2038h=P000H0b>3H0P1CDe<207AdM080W9bL0`2][Jd209VIV@80JVYZ0P0W9bL2
01hN7P@08R8R0`0S8b<201hN7P808R8R0P0U9BD205]KF`80SHf=0P2DU9@307]kN`80Kfm_0P1[Jf/2
07=cL`80UIFE0P2g]kL20<k>cP<0alO70P3=cLd20<o?c`80bl_;0P3>c/h20<O7a`80S8b<0P0_;bl5
02@T90809BDU0P0T92@202LW9`809BDU0P12@T8305EEE@80=cLg0P0c<c<2034a<@80?3`l0P1:BTX2
05ADE0<0G5aL0P1QHF4206IVIP80K6a/0P1`L70207AdM080MgMg0`1iNGT207]kN`80Ogmo1P23Ph<2
08F5Q@<0QXJ61025QHD208N7Q`80Rh^;0P2>SXh208n?S`<0T92@0P2ATI4209FEU@80VIVI0P2HV9P2
09NGU`80VYZJ0`2NWYh:09nOW`80X:2P0`2RXZ820:FUY@80ZZZZ102][Jd20:^[Z`80ZZZZ1@2YZJT2
0:ZZZP80[Jf]0P2^[Zh20:b/[0@0ZZZZ0`2[Zj/20:RXZ0H0YJFU0P2SXj<20:6QX@<0WIfM0P2IVIT2
09NGU`80UIFE0P2?Shl208V9R@80QXJ61`25QHD208N7Q`80R8R80P26QXH208B4Q0<0Ph>30P21PH42
0820P080Ogmo0P1lO7`407UiN@<0NWYj0P1mOGd20861P@80PX:22038h=P000H0b>3H0P1CDe<207Ad
M080W9bL0`2][Jd209VIV@80JVYZ0P0W9bL201hN7P@08R8R0`0S8b<201hN7P808R8R0P0U9BD205]K
F`80SHf=0P2DU9@307]kN`80Kfm_0P1[Jf/207=cL`80UIFE0P2g]kL20<k>cP<0alO70P3=cLd20<o?
c`80bl_;0P3>c/h20<O7a`80S8b<0P0_;bl502@T90809BDU0P0T92@202LW9`809BDU0P12@T8305EE
E@80=cLg0P0c<c<2034a<@80?3`l0P1:BTX205ADE0<0G5aL0P1QHF4206IVIP80K6a/0P1`L70207Ad
M080MgMg0`1iNGT207]kN`80Ogmo1P23Ph<208F5Q@<0QXJ61025QHD208N7Q`80Rh^;0P2>SXh208n?
S`<0T92@0P2ATI4209FEU@80VIVI0P2HV9P209NGU`80VYZJ0`2NWYh:09nOW`80X:2P0`2RXZ820:FU
Y@80ZZZZ102][Jd20:^[Z`80ZZZZ1@2YZJT20:ZZZP80[Jf]0P2^[Zh20:b/[0@0ZZZZ0`2[Zj/20:RX
Z0H0YJFU0P2SXj<20:6QX@<0WIfM0P2IVIT209NGU`80UIFE0P2?Shl208V9R@80QXJ61`25QHD208N7
Q`80R8R80P26QXH208B4Q0<0Ph>30P21PH420820P080Ogmo0P1lO7`407UiN@<0NWYj0P1mOGd20861
P@80PX:22038h=P000H0b>3H0P1KFe/208>3P`80[jn_0`2ZZZX208V9R@80D51@100T92@2028R8P80
9BDU0`0W9bL202@T90809RHV0P0S8b<20451@@80NGUi0P2FUYH308R8R0@0JVYZ0P1_Kfl208F5Q@80
WinO0P3=cLd50<W9b@@0c<c<0P3@d=020=GEe@80^;Rh0P1WIfL502<S8`809BDU0P0S8b<202HV9P80
:b/[0P0n?Sh304i>CP80=SHf100e=CD20410@080CDe=0P1EEED305eMG@80HV9R0P1YJFT206e]K@80
LG5a0P1eMGD207QhN0<0Ng]k0P1nOWh20861P@80Ph>31022PX8208B4Q0L0QhN70P2:RXX208f=S@80
SXj>0P2@T903096AT@80Ti>C0P2FUYH609RHV080Vi^K1`2NWYh20:2PX080XZ:R0P2SXj<20:FUY@<0
YZJV0P2XZ:P20:f][@80/;2`0P2^[Zh40:b/[0L0[Jf]102^[Zh20:^[Z`80ZJVY0P2ZZZX30:^[Z`80
ZJVY0P2WYjL20:FUY@80Y:BT0P2SXj<20:6QX@<0WIfM0P2IVIT209NGU`80UYJF0P2@T90208Z:RP80
R8R82`26QXH208R8R080RHV90`25QHD20861P@80P8200P1oOgl207inOP80O7al1@1kNg/207moO`80
PX:20P23Ph<80<SPf0001P38h=P205]KF`80Ph>30P2_[jl30:ZZZP80RHV90P1@D50402@T90808R8R
0P0U9BD302LW9`8092@T0P0V9RH202<S8`80@D510P1iNGT209JFUP<0R8R8101ZJVX206m_K`80QHF5
0P2OWil20<g=c@D0bLW9103<c<`20=3@d080eMGE0P2h^;P206MWI`D08b<S0P0U9BD202<S8`809RHV
0P0[:b/203hn?P<0CTi>0P0f=SH403De=@80@4100P1=CDd205EEE@<0GEeM0P1RHV8206UYJ@80KFe]
0P1aLG4207EeM@80N7Qh0`1kNg/207inOP80PH610P23Ph<408:2PP80Q8B41`27QhL208Z:RP80SHf=
0P2>SXh2092@T0<0TI6A0P2CTi<209JFUPH0V9RH0P2KVi/709jNWP80X:2P0P2RXZ820:>SX`80YJFU
0`2VYZH20:RXZ080[Jf]0P2`/;020:j^[P@0[:b/1`2][Jd40:j^[P80Zj^[0P2YZJT20:ZZZP<0Zj^[
0P2YZJT20:NWY`80YJFU0P2TY:@20:>SX`80XJ6Q0`2MWId209VIV@80UiNG0P2FUYH2092@T080RXZ:
0P28R8P;08J6QP80R8R80P29RHT308F5Q@80PH610P20P80207moO`80OWin0P1lO7`507]kN`80Ogmo
0P22PX8208>3P`P0b>3H00060<SPf080MgMg0P2FUYH20;Bd]0<0UiNG0P1_Kfl203<c<`808R8R0P0Z
:RX2028R8P809RHV1@0Y:BT202XZ:P809bLW0P0^;Rh2069RHP80T92@0`2CTi<206YZJP80Jf][0P1^
KVh207QhN080QhN70P36a/H30<[:bP80a<C40P39bLT20<_;b`80c/k>0P3@d=020=SHf080Y:BT0`0a
<C4402HV9P808b<S0P0T92@2034a<@80>SXj0`16ATH403Hf=P80>CTi0P14A4@2051@D080EeMG0`1M
GEd206ATI080Jf][0P1_Kfl207=cL`80MWIf0P1iNGT307emO@80PH610P22PX860861P@80Q8B40`27
QhL208R8R080RXZ:0P2<S8`208j>SP80Shn?0P2@T90309>CT`80UYJF102GUiL209RHV080VIVI0P2K
Vi/309fMW@@0W9bL0P2PX:020:FUY@80Z:RX0P2YZJT30:ZZZP80Zj^[0P2_[jl20;:b/P80/;2`0P2]
[Jd20:n_[`D0/K6a0P2`/;020:n_[`80[Jf]0P2ZZZX20:RXZ080ZJVY0`2[Zj/20:ZZZP80Z:RX0P2V
YZH20:>SX`80XZ:R0P2PX:0309bLW080VIVI0P2GUiL209JFUP80TI6A0P2<S8`208Z:RP<0R8R81027
QhL208J6QP80QHF50P2:RXX208j>SP<0QhN71P20P80207moO`80OWin1@1lO7`20820P080Ph>30P24
Q8@80<SPf0001P38h=P207MgM`80UYJF0P2d];@309NGU`80Kfm_0P0c<c<2028R8P80:RXZ0P0R8R82
02HV9PD0:BTY0P0Z:RX202LW9`80;Rh^0P1RHV82092@T0<0Ti>C0P1ZJVX206][J`80KVi^0P1hN7P2
08N7Q`80a/K60`3:b/X20<C4a080bLW90P3;bl/20<k>cP80d=3@0P3Hf=P20:BTY0<0<C4a100V9RH2
02<S8`8092@T0P0a<C4203Xj>P<0ATI6100f=SH203Ti>@80A4A40P1@D50205MGE`<0GEeM0P1TI6@2
06][J`80Kfm_0P1cLg<207IfMP80NGUi0`1mOGd20861P@80PX:21P21PH4208B4Q0<0QhN70P28R8P2
08Z:RP80S8b<0P2>SXh208n?S`80T92@0`2CTi<209JFUP@0UiNG0P2HV9P209VIV@80Vi^K0`2MWId4
09bLW080X:2P0P2UYJD20:RXZ080ZJVY0`2ZZZX20:^[Z`80[jn_0P2b/[820;2`/080[Jf]0P2_[jl5
0;6a/@80/;2`0P2_[jl20:f][@80ZZZZ0P2XZ:P20:VYZ@<0Zj^[0P2ZZZX20:RXZ080YZJV0P2SXj<2
0::RXP80X:2P0`2LW9`209VIV@80UiNG0P2FUYH2096AT@80S8b<0P2:RXX308R8R0@0QhN70P26QXH2
08F5Q@80RXZ:0P2>SXh308N7Q`H0P8200P1oOgl207inOPD0O7al0P20P80208>3P`80Q8B42038h=P0
00H0b>3H102OWil209BDU0<0Kfm_0P1:BTX202/[:`809RHV0P0X:2P2028R8P8092@T1`0W9bL202PX
:080:BTY0P19BDT208>3P`<0UIFE0P1lO7`206MWI`80Kfm_0P1fMWH207emO@80[:b/0`3<c<`20;no
_`80`l?30P36a/H20<_;b`80dM7A0P3Hf=P20<?3``<0LW9b0P0`<30202<S8`@08R8R0P0^;Rh203Hf
=P<0@T920P0a<C4203De=@80>SXj0P0o?cl204E5A@80DU9B0`1OGel206IVIP80Jf][0P1aLG4207Mg
M`80NGUi0P1jNWX307alO080OWin0P1oOgl20820P080PX:21024Q8@308F5Q@80R8R80P2;Rh/208b<
S080SHf=0P2>SXh2092@T0<0Ti>C0P2FUYH409RHV0H0VIVI0`2JVYX209^KV`80W9bL0P2QXJ420:FU
Y@80YjNW0P2XZ:P30:VYZ@80ZZZZ0P2^[Zh20;:b/P80/;2`0P2][Jd20:n_[`D0/[:b0P2a/K420;2`
/080[Zj^0P2[Zj/20:RXZ080ZZZZ0`2/[:`20:ZZZP80Z:RX0P2WYjL20:FUY@80Xj>S0P2PX:0309jN
WP80Vi^K0P2HV9P209FEU@80Ti>C0P2@T90208f=S@<0RXZ:0P29RHT408R8R080RHV90P2;Rh/208f=
S@<0R8R80P23Ph<40861P@80Ogmo0P1mOGd507alO080P8200P23Ph<208B4Q0P0b>3H00060<SPf0@0
WinO0P2DU9@306m_K`80BTY:0P0[:b/202HV9P80:2PX0P0R8R8202@T90L09bLW0P0X:2P202TY:@80
BDU90P23Ph<309FEU@80O7al0P1WIfL206m_K`80MWIf0P1mOGd20:b/[0<0c<c<0P2o_kl20<?3``80
a/K60P3;bl/20=7Ad@80f=SH0P33`l<3079bLP80<30`0P0S8b<4028R8P80;Rh^0P0f=SH30492@P80
<C4a0P0e=CD203Xj>P80?clo0P15ADD2059BDP<0GemO0P1VIVH206][J`80LG5a0P1gMgL207UiN@80
NWYj0`1lO7`207inOP80Ogmo0P20P80208:2PP@0Q8B40`25QHD208R8R080Rh^;0P2<S8`208f=S@80
SXj>0P2@T90309>CT`80UYJF102HV9P609VIV@<0VYZJ0P2KVi/209bLW080XJ6Q0P2UYJD20:NWY`80
Z:RX0`2YZJT20:ZZZP80[Zj^0P2b/[820;2`/080[Jf]0P2_[jl50;:b/P80/K6a0P2`/;020:j^[P80
Zj^[0P2XZ:P20:ZZZP<0[:b/0P2ZZZX20:RXZ080YjNW0P2UYJD20:>SX`80X:2P0`2NWYh209^KV`80
V9RH0P2EUID209>CT`80T92@0P2=SHd308Z:RP80RHV91028R8P208V9R@80Rh^;0P2=SHd308R8R080
Ph>31021PH4207moO`80OGem1@1lO7`20820P080Ph>30P24Q8@80<SPf0001P38h=P409nOW`80U9BD
0`1_Kfl204Y:BP80:b/[0P0V9RH202PX:0808R8R0P0T92@702LW9`80:2PX0P0Y:BT204U9B@80Ph>3
0`2EUID207alO080IfMW0P1_Kfl207IfMP80OGem0P2/[:`30<c<c080_kno0P33`l<20<K6aP80bl_;
0P3AdM420=SHf080`l?30`1bLW82030`<0808b<S100R8R8202h^;P80=SHf0`12@T82034a<@80=CDe
0P0j>SX203lo?`80ADE50P1BDU8305mOG`80IVIV0P1[Jf/2075aL@80MgMg0P1iNGT207YjNP<0O7al
0P1nOWh207moO`80P8200P22PX8408B4Q0<0QHF50P28R8P208^;R`80S8b<0P2=SHd208j>SP80T92@
0`2CTi<209JFUP@0V9RH1P2IVIT309ZJVP80Vi^K0P2LW9`20:6QX@80YJFU0P2WYjL20:RXZ0<0ZJVY
0P2ZZZX20:j^[P80/[:b0P2`/;020:f][@80[jn_1@2b/[820;6a/@80/;2`0P2^[Zh20:^[Z`80Z:RX
0P2ZZZX30:b/[080ZZZZ0P2XZ:P20:NWY`80YJFU0P2SXj<20:2PX0<0WYjN0P2KVi/209RHV080UIFE
0P2CTi<2092@T080SHf=0`2:RXX208V9R@@0R8R80P29RHT208^;R`80SHf=0`28R8P208>3P`@0PH61
0P1oOgl207emO@D0O7al0P20P80208>3P`80Q8B42038h=P000H0b>3H0P2][Jd209>CT`80Jf][0`17
AdL202XZ:P809bLW0P0Z:RX202DU9@808B4Q0P0R8R8302@T90@08b<S100X:2P203@d=080Kfm_0`2@
T90208n?S`80J6QX0P1aLG4207IfMP80NGUi0P2?Shl30<S8b080_;bl0P2n_[h20<;2`P80alO70P3>
c/h20<g=c@80d];B0`2e]KD204E5A@80:2PX0P0U9BD2028R8P80:b/[0P0b<S8303lo?`80;Bd]0P0b
<S8203Ti>@80@T920P1;Bd/205IFEP<0H61P0P1VIVH206][J`80Lg=c0P1jNWX207]kN`80NWYj1@1k
Ng/207emO@80P8200P23Ph<208J6QP80Q8B40`23Ph<208N7Q`80Rh^;102<S8`208j>SP80T92@0`2C
Ti<209JFUP80V9RH1P2IVIT509RHV080VYZJ0P2MWId20::RXP80YJFU102VYZH30:NWY`80ZJVY0P2]
[Jd20;6a/@80/;2`0P2^[Zh20;2`/0<0/[:b0P2c/k<20;:b/P80/;2`0P2_[jl20:^[Z`80ZJVY0P2Z
ZZX30:b/[080Zj^[102XZ:P20:NWY`80Y:BT0P2PX:0309nOW`80WIfM0P2IVIT409BDU080Ti>C0P2@
T90308b<S0@0RXZ:0P2;Rh/208f=S@80S8b<0P2;Rh/308R8R080QHF50P23Ph<20861P@80OWin101l
O7`307emO@80P8200P23Ph<208B4Q0P0b>3H00060<SPf080[Jf]0P2CTi<206][J`<0AdM70P0Z:RX2
02LW9`80:RXZ0P0U9BD2024Q8@808R8R0`0T92@402<S8`@0:2PX0P0d=3@206m_K`<0T92@0P2?Shl2
06QXJ080LG5a0P1fMWH207UiN@80Shn?0`38b<P20;bl_080_[jn0P32`/820<O7a`80c/k>0P3=cLd2
0=;BdP<0]KFe0P15ADD202PX:0809BDU0P0R8R8202/[:`80<S8b0`0o?cl202d];@80<S8b0P0i>CT2
0492@P80Bd];0P1FEUH3061PH080IVIV0P1[Jf/207=cL`80NWYj0P1kNg/207YjNPD0Ng]k0P1mOGd2
0820P080Ph>30P26QXH208B4Q0<0Ph>30P27QhL208^;R`@0S8b<0P2>SXh2092@T0<0Ti>C0P2FUYH2
09RHV0H0VIVI1@2HV9P209ZJVP80WIfM0P2RXZ820:FUY@@0YZJV0`2WYjL20:VYZ@80[Jf]0P2a/K42
0;2`/080[Zj^0P2`/;030;:b/P80/k>c0P2b/[820;2`/080[jn_0P2[Zj/20:VYZ@80ZZZZ0`2/[:`2
0:^[Z`@0Z:RX0P2WYjL20:BTY080X:2P0`2OWil209fMW@80VIVI102DU9@209>CT`80T92@0`2<S8`4
08Z:RP80Rh^;0P2=SHd208b<S080Rh^;0`28R8P208F5Q@80Ph>30P21PH4207inOP@0O7al0`1mOGd2
0820P080Ph>30P24Q8@80<SPf0001P38h=P209RHV080MgMg0P16ATH302l_;`808B4Q0P0X:2P2030`
<080:2PX100Q8B4302<S8`808R8R0P0S8b<202@T90808b<S0P0[:b/205ADE0<0PX:20P2JVYX207Yj
NP80LG5a0P1bLW8207EeM@80OGem0`2d];@20<C4a080^KVi0P2o_kl20<C4a080alO70P38b<P20=;B
dP<0c<c<0P2KVi/203Xj>P808R8R0P0Y:BT202`/;080<30`0`0o?cl202d];@80<S8b0P0g=cL20410
@080BTY:0P1GEeL306=SH`80JFUY0P1]KFd207EeM@80NWYj0P1iNGT207MgM`<0NGUi0P1lO7`207mo
O`80PX:20P25QHD208N7Q`80QHF50`24Q8@208J6QP80RHV90P2<S8`208n?S`@0T92@0`2ATI4209>C
T`80U9BD0P2FUYH209RHV080VIVI1@2JVYX209bLW080WinO0P2RXZ820:FUY@80YjNW0P2XZ:P30:ZZ
ZP80[Jf]0P2`/;020;>c/`80/K6a0P2_[jl20;2`/0<0/K6a0P2c/k<20;Bd]080/[:b0P2_[jl20:b/
[080Zj^[0P2][Jd30:n_[`80[Jf]0P2YZJT20:RXZ080YZJV0P2TY:@20:6QX@<0X:2P0P2NWYh209ZJ
VP80UIFE0P2BTY8408n?S`<0SXj>0P2<S8`208^;R`80SXj>0P2@T90208j>SP80RXZ:0`29RHT208N7
Q`80Q8B40P21PH4207inOP80O7al0P1mOGd307moO`80PX:20P23Ph<208B4Q0P0b>3H00060<SPf080
V9RH0P1gMgL204I6AP<0;bl_0P0Q8B4202PX:080<30`0P0X:2P4024Q8@<08b<S0P0R8R8202<S8`80
92@T0P0S8b<202/[:`80E5AD0`22PX8209ZJVP80NWYj0P1aLG42079bLP80MGEe0P1mOGd30;Bd]080
a<C40P2i^KT20;no_`80a<C40P37alL20<S8b080d];B0`3<c<`209^KV`80>SXj0P0R8R8202TY:@80
;2`/0P0`<30303lo?`80;Bd]0P0b<S8203Lg=`80@4100P1:BTX205MGE`<0Hf=S0P1YJFT206e]K@80
MGEe0P1jNWX207UiN@80MgMg0`1iNGT207alO080Ogmo0P22PX8208F5Q@80QhN70P25QHD308B4Q080
QXJ60P29RHT208b<S080Shn?102@T903096AT@80Ti>C0P2DU9@209JFUP80V9RH0P2IVIT509ZJVP80
W9bL0P2OWil20::RXP80YJFU0P2WYjL20:RXZ0<0ZZZZ0P2][Jd20;2`/080/k>c0P2a/K420:n_[`80
/;2`0`2a/K420;>c/`80];Bd0P2b/[820:n_[`80[:b/0P2[Zj/20:f][@<0[jn_0P2][Jd20:VYZ@80
Z:RX0P2VYZH20:BTY080XJ6Q0`2PX:0209jNWP80VYZJ0P2EUID209:BTP@0Shn?0`2>SXh208b<S080
Rh^;0P2>SXh2092@T080SXj>0P2:RXX308V9R@80QhN70P24Q8@20861P@80OWin0P1lO7`207emO@<0
Ogmo0P22PX8208>3P`80Q8B42038h=P000H0b>3H0P1fMWH205IFEP80:b/[1`0R8R8802<S8`L092@T
100O7al202LW9`80>CTi0`1_Kfl209bLW080Shn?0P1dM7@206m_K`@0Lg=c0`2LW9`20<W9b@80^;Rh
0P2o_kl20<30`080`L710P34a<@20<G5a@<0c<c<0P2o_kl206MWI`80=3@d0P0_;bl202`/;080;bl_
0`0m?Cd202h^;P80<C4a0P0e=CD203lo?`80Bd];0P1HF5P306ATI080Jf][0P1`L70207IfMP80NGUi
0P1gMgL207EeM@<0NGUi0P1nOWh20861P@80Q8B40P26QXH208N7Q`80QXJ61@25QHD208J6QP80S8b<
102ATI47092@T080TY:B0P2DU9@209NGU`80VYZJ0P2LW9`309fMW@80WinO0P2RXZ820:BTY080YZJV
0P2XZ:P20:ZZZP<0[Zj^0P2a/K420;>c/`80];Bd0P2b/[870;6a/@80];Bd0P2f][H20;>c/`80[jn_
102][Jd20;2`/0<0/[:b0P2^[Zh20:VYZ@80Z:RX0P2WYjL20:BTY080XZ:R0`2PX:0209jNWP80Vi^K
0P2GUiL2096AT@80S8b<0P2>SXh3092@T080SXj>0P2<S8`2092@T080Ti>C0P2@T90208^;R`<0RHV9
0P27QhL208F5Q@80PX:20P1nOWh207alO080OWin0`21PH4208>3P`@0Q8B42038h=P000H0b>3H0P1f
MWH205IFEP80:b/[1`0R8R8802<S8`L092@T100O7al202LW9`80>CTi0`1_Kfl209bLW080Shn?0P1d
M7@206m_K`@0Lg=c0`2LW9`20<W9b@80^;Rh0P2o_kl20<30`080`L710P34a<@20<G5a@<0c<c<0P2o
_kl206MWI`80=3@d0P0_;bl202`/;080;bl_0`0m?Cd202h^;P80<C4a0P0e=CD203lo?`80Bd];0P1H
F5P306ATI080Jf][0P1`L70207IfMP80NGUi0P1gMgL207EeM@<0NGUi0P1nOWh20861P@80Q8B40P26
QXH208N7Q`80QXJ61@25QHD208J6QP80S8b<102ATI47092@T080TY:B0P2DU9@209NGU`80VYZJ0P2L
W9`309fMW@80WinO0P2RXZ820:BTY080YZJV0P2XZ:P20:ZZZP<0[Zj^0P2a/K420;>c/`80];Bd0P2b
/[870;6a/@80];Bd0P2f][H20;>c/`80[jn_102][Jd20;2`/0<0/[:b0P2^[Zh20:VYZ@80Z:RX0P2W
YjL20:BTY080XZ:R0`2PX:0209jNWP80Vi^K0P2GUiL2096AT@80S8b<0P2>SXh3092@T080SXj>0P2<
S8`2092@T080Ti>C0P2@T90208^;R`<0RHV90P27QhL208F5Q@80PX:20P1nOWh207alO080OWin0`21
PH4208>3P`@0Q8B42038h=P000H0b>3H0P1HF5P203lo?`80:RXZ1`0U9BD202LW9`809RHV0P0T92@5
02DU9@80;2`/0P0T92@6024Q8@80:RXZ0`1EEED208j>SP80TY:B0P1kNg/206UYJ@80Lg=c0P1eMGD3
08F5Q@80^;Rh0P34a<@20<71`@80^k^k0P32`/820<71`@80_kno0`34a<@20=?Cd`80Zj^[0P0j>SX2
02l_;`809bLW0P0[:b/3034a<@80;Bd]0P0`<30203Hf=P80@D510P1=CDd205QHF0<0HV9R0P1[Jf/2
079bLP80MGEe101gMgL207QhN0<0O7al0P20P8020861P@80PX:20P23Ph<208B4Q0L0QHF50P26QXH2
08Z:RP80SXj>0P2ATI4509>CT`80TY:B0P2CTi<209FEU@80UiNG0P2KVi/209jNWP<0XJ6Q0P2SXj<2
0:JVYP80YjNW0P2YZJT20:^[Z`80[Jf]0`2_[jl20;6a/@80/[:b102c/k<20;:b/P80]KFe1@2g]kL2
0;Fe]@80/[:b0P2^[Zh20:b/[080Zj^[0P2][Jd30:n_[`80[:b/0P2YZJT40:ZZZP80YZJV0P2QXJ43
09nOW`80WYjN0P2LW9`209VIV@80UIFE102ATI4309:BTP80T92@0P2?Shl209:BTP80Ti>C0P2@T902
08b<S0<0RXZ:0P28R8P208N7Q`80Q8B40P20P80207alO080Ogmo0`22PX8208B4Q0@0QHF52038h=P0
00H0b>3H0P1HF5P203lo?`80:RXZ1`0U9BD202LW9`809RHV0P0T92@502DU9@80;2`/0P0T92@6024Q
8@80:RXZ0`1EEED208j>SP80TY:B0P1kNg/206UYJ@80Lg=c0P1eMGD308F5Q@80^;Rh0P34a<@20<71
`@80^k^k0P32`/820<71`@80_kno0`34a<@20=?Cd`80Zj^[0P0j>SX202l_;`809bLW0P0[:b/3034a
<@80;Bd]0P0`<30203Hf=P80@D510P1=CDd205QHF0<0HV9R0P1[Jf/2079bLP80MGEe101gMgL207Qh
N0<0O7al0P20P8020861P@80PX:20P23Ph<208B4Q0L0QHF50P26QXH208Z:RP80SXj>0P2ATI4509>C
T`80TY:B0P2CTi<209FEU@80UiNG0P2KVi/209jNWP<0XJ6Q0P2SXj<20:JVYP80YjNW0P2YZJT20:^[
Z`80[Jf]0`2_[jl20;6a/@80/[:b102c/k<20;:b/P80]KFe1@2g]kL20;Fe]@80/[:b0P2^[Zh20:b/
[080Zj^[0P2][Jd30:n_[`80[:b/0P2YZJT40:ZZZP80YZJV0P2QXJ4309nOW`80WYjN0P2LW9`209VI
V@80UIFE102ATI4309:BTP80T92@0P2?Shl209:BTP80Ti>C0P2@T90208b<S0<0RXZ:0P28R8P208N7
Q`80Q8B40P20P80207alO080Ogmo0`22PX8208B4Q0@0QHF52038h=P000H0b>3H0P14A4@2030`<080
<C4a0`0Z:RX202LW9`80:2PX0P0Z:RX202PX:0809bLW0P0X:2P302LW9`80<c<c0P0V9RH202DU9@80
92@T0P0M7Ad2028R8P<0?3`l0P1gMgL209JFUP80TY:B0P1`L70207=cL`80NGUi0`1cLg<20:6QX@80
c<c<0P34a<@20;Jf]P80`l?30P30`<020;fm_@<0^KVi0P3;bl/20<c<c080Shn?0P0a<C4202LW9`80
:BTY0`0X:2P202`/;080<30`0P0f=SH20492@P80Cdm?0P1HF5P3061PH080JVYZ0P1cLg<407EeM@80
N7Qh0P1jNWX307inOP@0PH610P1oOgl20820P080PH610P23Ph<708J6QP80R8R80P2;Rh/2096AT@D0
UYJF0P2DU9@209FEU@80UiNG0P2IVIT209bLW080X:2P0`2TY:@20:NWY`80ZZZZ0P2[Zj/20:b/[080
[Zj^0P2_[jl30;2`/080/K6a1P2b/[820;Bd]080^KVi0`2m_Kd20;Vi^@80];Bd0P2a/K420:j^[P80
Zj^[0P2ZZZX20:^[Z`<0[:b/0P2[Zj/20:ZZZP80[:b/0P2][Jd20:NWY`80XJ6Q0`2OWil209fMW@80
W9bL0P2KVi/209VIV@80UiNG0P2EUID309>CT`@0TY:B102CTi<2092@T080SHf=0`2;Rh/208V9R@80
R8R80P26QXH208:2PP80OWin0P1oOgl308:2PP80Q8B40P25QHD208J6QPP0b>3H00060<SPf080A4A4
0P0`<302034a<@<0:RXZ0P0W9bL202PX:080:RXZ0P0X:2P202LW9`80:2PX0`0W9bL203<c<`809RHV
0P0U9BD202@T90807AdM0P0R8R8303`l?080MgMg0P2FUYH209:BTP80L71`0P1cLg<207UiN@<0Lg=c
0P2QXJ420<c<c080a<C40P2f][H20<?3``80`<300P2m_Kd30;Vi^@80bl_;0P3<c<`208n?S`80<C4a
0P0W9bL202TY:@<0:2PX0P0/;2`2030`<080=SHf0P12@T8204m?C`80F5QH0`1PH60206YZJP80Lg=c
101eMGD207QhN080NWYj0`1nOWh40861P@80Ogmo0P20P8020861P@80Ph>31`26QXH208R8R080Rh^;
0P2ATI4509JFUP80U9BD0P2EUID209NGU`80VIVI0P2LW9`20:2PX0<0Y:BT0P2WYjL20:ZZZP80Zj^[
0P2/[:`20:j^[P80[jn_0`2`/;020;6a/@H0/[:b0P2d];@20;Vi^@<0_Kfm0P2i^KT20;Bd]080/K6a
0P2^[Zh20:^[Z`80ZZZZ0P2[Zj/30:b/[080Zj^[0P2ZZZX20:b/[080[Jf]0P2WYjL20:6QX@<0WinO
0P2MWId209bLW080Vi^K0P2IVIT209NGU`80UIFE0`2CTi<409:BTP@0Ti>C0P2@T90208f=S@<0Rh^;
0P29RHT208R8R080QXJ60P22PX8207inOP80Ogmo0`22PX8208B4Q080QHF50P26QXH80<SPf0001P38
h=P2059BDP80<30`0P0a<C4303<c<`80>3Ph0P0a<C4402XZ:P80:b/[0P0Y:BT302LW9`80<C4a0P0]
;Bd202TY:@8092@T0P0O7al202<S8`<0<S8b0P1HF5P2092@T080XZ:R0P26QXH2071`L080MGEe0`1d
M7@208V9R@80^k^k0P3=cLd20;:b/P80`<300P2n_[h20;bl_0<0^KVi0P34a<@20=;BdP80]KFe0P1]
KFd202d];@808R8R0`0W9bL202h^;P80<C4a0P0g=cL20410@080BTY:0P1EEED3065QH@80JVYZ0P1a
LG4207EeM@80MgMg0P1hN7P207YjNP<0OGem0P1oOgl207emO@80O7al0P1nOWh20820P080Ph>30`26
QXH208R8R0@0Rh^;0P2<S8`209:BTPL0UiNG0P2HV9P209VIV@80Vi^K0P2MWId20:2PX0<0Y:BT0P2Y
ZJT20:b/[0@0[Jf]0P2^[Zh20;2`/0<0/[:b102c/k<20;:b/P80/k>c0P2d];@20;Ng]`<0^;Rh0P2d
];@40;2`/080/K6a0P2][Jd20:ZZZP80[Jf]0`2_[jl20:f][@80Zj^[0P2/[:`20:f][@80ZJVY0P2T
Y:@30::RXP80WinO0P2NWYh209fMW@80VYZJ0P2GUiL209JFUP<0UIFE0P2DU9@209:BTP80Ti>C0P2D
U9@2096AT@80SXj>0`2<S8`208^;R`80RHV90P26QXH208>3P`80PH610P20P80307moO`80PX:21025
QHD80<SPf0001P38h=P2059BDP80<30`0P0a<C4303<c<`80>3Ph0P0a<C4402XZ:P80:b/[0P0Y:BT3
02LW9`80<C4a0P0];Bd202TY:@8092@T0P0O7al202<S8`<0<S8b0P1HF5P2092@T080XZ:R0P26QXH2
071`L080MGEe0`1dM7@208V9R@80^k^k0P3=cLd20;:b/P80`<300P2n_[h20;bl_0<0^KVi0P34a<@2
0=;BdP80]KFe0P1]KFd202d];@808R8R0`0W9bL202h^;P80<C4a0P0g=cL20410@080BTY:0P1EEED3
065QH@80JVYZ0P1aLG4207EeM@80MgMg0P1hN7P207YjNP<0OGem0P1oOgl207emO@80O7al0P1nOWh2
0820P080Ph>30`26QXH208R8R0@0Rh^;0P2<S8`209:BTPL0UiNG0P2HV9P209VIV@80Vi^K0P2MWId2
0:2PX0<0Y:BT0P2YZJT20:b/[0@0[Jf]0P2^[Zh20;2`/0<0/[:b102c/k<20;:b/P80/k>c0P2d];@2
0;Ng]`<0^;Rh0P2d];@40;2`/080/K6a0P2][Jd20:ZZZP80[Jf]0`2_[jl20:f][@80Zj^[0P2/[:`2
0:f][@80ZJVY0P2TY:@30::RXP80WinO0P2NWYh209fMW@80VYZJ0P2GUiL209JFUP<0UIFE0P2DU9@2
09:BTP80Ti>C0P2DU9@2096AT@80SXj>0`2<S8`208^;R`80RHV90P26QXH208>3P`80PH610P20P803
07moO`80PX:21025QHD80<SPf0001P38h=P2065QH@80=cLg0P0b<S8302LW9`809BDU0P0W9bL202/[
:`80;Bd]0P0^;Rh202XZ:P<0:2PX0P0];Bd203<c<`80;2`/0P0T92@202<S8`809bLW0`0^;Rh203dm
?@80NGUi0P2IVIT209>CT`80LW9b0P1aLG4307YjNP80MWIf0P2SXj<20<k>cP80/;2`0P2j^[X40;fm
_@D0_;bl0P3;bl/20=?Cd`80[:b/0P10@40202TY:@<0:b/[0P0_;bl2034a<@80=SHf0P0l?3`204A4
A080De=C0`1QHF4206UYJ@80KVi^0P1eMGD607UiN@<0Ng]k0P1lO7`207]kN`80NWYj0P1mOGd20861
P@80Ph>30`26QXH208^;R`H0Shn?0P2CTi<209NGU`<0V9RH0P2IVIT209ZJVP80Vi^K0P2MWId209jN
WP80XJ6Q0`2UYJD20:ZZZP@0[Zj^0P2][Jd20:j^[P80/;2`0`2c/k<20;Fe]@80];Bd2`2c/k<20:n_
[`80[Jf]0P2`/;020;>c/`80/;2`0P2/[:`20:n_[`<0/[:b0P2`/;020:f][@80[:b/0P2[Zj/20:ZZ
ZP80Z:RX0`2UYJD20:6QX@80WinO0P2MWId209ZJVP@0UYJF0`2GUiL209BDU080TY:B0P2CTi<209BD
U080TY:B0P2?Shl308f=S@80S8b<0P29RHT408F5Q@80Q8B40P20P80307emO@80P8200P23Ph<208B4
Q0P0b>3H00060<SPf080HF5Q0P0g=cL2038b<P<09bLW0P0U9BD202LW9`80:b/[0P0];Bd202h^;P80
:RXZ0`0X:2P202d];@80<c<c0P0/;2`202@T90808b<S0P0W9bL302h^;P80?Cdm0P1iNGT209VIV@80
Ti>C0P1bLW82075aL@<0NWYj0P1fMWH20:>SX`80c/k>0P2`/;020;Zj^P@0_Kfm1@2l_;`20<_;b`80
dm?C0P2/[:`20410@080:BTY0`0[:b/202l_;`80<C4a0P0f=SH203`l?080A4A40P1CDe<3065QH@80
JFUY0P1^KVh207EeM@H0NGUi0`1kNg/207alO080Ng]k0P1jNWX207emO@80PH610P23Ph<308J6QP80
Rh^;1P2?Shl209>CT`80UiNG0`2HV9P209VIV@80VYZJ0P2KVi/209fMW@80WYjN0P2QXJ430:FUY@80
ZZZZ102^[Zh20:f][@80[Zj^0P2`/;030;>c/`80]KFe0P2d];@;0;>c/`80[jn_0P2][Jd20;2`/080
/k>c0P2`/;020:b/[080[jn_0`2b/[820;2`/080[Jf]0P2/[:`20:^[Z`80ZZZZ0P2XZ:P30:FUY@80
XJ6Q0P2OWil209fMW@80VYZJ102FUYH309NGU`80U9BD0P2BTY8209>CT`80U9BD0P2BTY8208n?S`<0
SHf=0P2<S8`208V9R@@0QHF50P24Q8@20820P0<0OGem0P20P80208>3P`80Q8B42038h=P000H0b>3H
0P1QHF4203Lg=`80<S8b0`0W9bL202DU9@809bLW0P0[:b/202d];@80;Rh^0P0Z:RX302PX:080;Bd]
0P0c<c<202`/;08092@T0P0S8b<202LW9`<0;Rh^0P0m?Cd207UiN@80VIVI0P2CTi<2079bLP80LG5a
0`1jNWX207IfMP80Xj>S0P3>c/h20;2`/080^[Zj102m_Kd50;bl_080bl_;0P3Cdm<20:b/[080@410
0P0Y:BT302/[:`80;bl_0P0a<C4203Hf=P80?3`l0P14A4@205=CD`<0HF5Q0P1YJFT206i^KP80MGEe
1P1iNGT307]kN`80O7al0P1kNg/207YjNP80OGem0P21PH4208>3P`<0QXJ60P2;Rh/608n?S`80Ti>C
0P2GUiL309RHV080VIVI0P2JVYX209^KV`80WIfM0P2NWYh20:6QX@<0YJFU0P2ZZZX40:j^[P80[Jf]
0P2^[Zh20;2`/0<0/k>c0P2e]KD20;Bd]0/0/k>c0P2_[jl20:f][@80/;2`0P2c/k<20;2`/080[:b/
0P2_[jl30;:b/P80/;2`0P2][Jd20:b/[080Zj^[0P2ZZZX20:RXZ0<0YJFU0P2QXJ4209nOW`80WIfM
0P2JVYX409JFUP<0UiNG0P2DU9@209:BTP80Ti>C0P2DU9@209:BTP80Shn?0`2=SHd208b<S080RHV9
1025QHD208B4Q080P8200`1mOGd20820P080Ph>30P24Q8@80<SPf0001P38h=P204i>CP80=cLg0P0_
;bl502XZ:P80:b/[1P0];Bd202`/;0<0:b/[0P0/;2`202l_;`80;Bd]0P0Z:RX202PX:080:BTY0`0Z
:RX203<c<`80Fe]K0P28R8P209VIV@80Q8B40P1_Kfl307QhN080MWIf0P28R8P20;>c/`80][Jf0P2_
[jl20;bl_080_Kfm0`30`<020;no_`80alO70P3Jf]X20<W9b@80UYJF0P0j>SX301`L70809RHV0P0^
;Rh2038b<P80>c/k0P14A4@205=CD`<0H61P0P1WIfL206a/K080Lg=c0P1hN7P407YjNP<0Ng]k0P1m
OGd407alO080Ogmo0P22PX8208B4Q0<0QXJ60P2:RXX208j>SP80TI6A0P2BTY8209>CT`80UIFE0`2G
UiL209ZJVP80Vi^K0P2LW9`209nOW`80XZ:R0P2TY:@30:FUY@80ZJVY0P2/[:`40:f][@80[Zj^0P2`
/;030;:b/PH0];Bd0P2b/[820;6a/@D0/[:b0P2a/K420:n_[`80/;2`0P2a/K420;2`/080[jn_0P2a
/K450;:b/P80/K6a0P2^[Zh20:b/[080ZZZZ0P2XZ:P30:FUY@80XZ:R0P2OWil209bLW080Vi^K0P2J
VYX209NGU`<0U9BD202CTi<2092@T080SXj>0`2<S8`208Z:RP80QhN70P25QHD408B4Q080PX:22@20
P8080<SPf0001P38h=P204i>CP80=cLg0P0_;bl502XZ:P80:b/[1P0];Bd202`/;0<0:b/[0P0/;2`2
02l_;`80;Bd]0P0Z:RX202PX:080:BTY0`0Z:RX203<c<`80Fe]K0P28R8P209VIV@80Q8B40P1_Kfl3
07QhN080MWIf0P28R8P20;>c/`80][Jf0P2_[jl20;bl_080_Kfm0`30`<020;no_`80alO70P3Jf]X2
0<W9b@80UYJF0P0j>SX301`L70809RHV0P0^;Rh2038b<P80>c/k0P14A4@205=CD`<0H61P0P1WIfL2
06a/K080Lg=c0P1hN7P407YjNP<0Ng]k0P1mOGd407alO080Ogmo0P22PX8208B4Q0<0QXJ60P2:RXX2
08j>SP80TI6A0P2BTY8209>CT`80UIFE0`2GUiL209ZJVP80Vi^K0P2LW9`209nOW`80XZ:R0P2TY:@3
0:FUY@80ZJVY0P2/[:`40:f][@80[Zj^0P2`/;030;:b/PH0];Bd0P2b/[820;6a/@D0/[:b0P2a/K42
0:n_[`80/;2`0P2a/K420;2`/080[jn_0P2a/K450;:b/P80/K6a0P2^[Zh20:b/[080ZZZZ0P2XZ:P3
0:FUY@80XZ:R0P2OWil209bLW080Vi^K0P2JVYX209NGU`<0U9BD202CTi<2092@T080SXj>0`2<S8`2
08Z:RP80QhN70P25QHD408B4Q080PX:22@20P8080<SPf0001P38h=P203Xj>P80=SHf1@0/;2`602h^
;P80;Bd]0P0/;2`202d];@<0;bl_0P0/;2`202XZ:P80;Bd]0P0_;bl202`/;080:RXZ0`0X:2P2030`
<080?Shn0P1^KVh209JFUP80V9RH0P1aLG4307EeM@80NGUi0P1bLW8209BDU080^[Zj0P2WYjL20;Vi
^@80_[jn0`34a<@20<?3``80`/;20P3?cll20=7Ad@80a/K60P1oOgl3034a<@807QhN0P0W9bL202h^
;P80>CTi0P15ADD2059BDP<0GUiN0P1UIFD206YZJP80LG5a0P1gMgL207UiN@80NWYj0`1lO7`207em
O@80OWin0P20P80208:2PP80Q8B40P25QHD308N7Q`80RXZ:0P2=SHd2096AT@@0U9BD0P2CTi<309JF
UP80VIVI0P2KVi/209bLW080X:2P0P2TY:@50:JVYP80Z:RX0P2ZZZX20:b/[080[Jf]0P2^[Zh20:n_
[`<0/K6a0P2b/[820;>c/`80];Bd0P2a/K420:n_[`80/K6a1@2c/k<20;:b/P80/;2`0P2^[Zh20;2`
/080/[:b1@2a/K420;:b/P80/k>c0P2a/K420:f][@80ZZZZ0P2WYjL30:FUY@80Xj>S0P2OWil209^K
V`@0W9bL0P2FUYH3096AT@80TY:B0P2DU9@209>CT`80TI6A0P2?Shl208f=S@<0RXZ:0P27QhL208F5
Q@80Q8B40P23Ph<408B4Q0<0Ph>30P21PH4407inOPP0b>3H00060<SPf080>SXj0P0f=SH502`/;0H0
;Rh^0P0];Bd202`/;080;Bd]0`0_;bl202`/;080:RXZ0P0];Bd202l_;`80;2`/0P0Z:RX302PX:080
<30`0P0n?Sh206i^KP80UYJF0P2HV9P2075aL@<0MGEe0P1iNGT2079bLP80U9BD0P2j^[X20:NWY`80
^KVi0P2n_[h30<C4a080`l?30P32`/820<o?c`80dM7A0P36a/H207moO`<0<C4a0P0N7Qh202LW9`80
;Rh^0P0i>CT204E5A@80DU9B0`1NGUh206EUI@80JVYZ0P1aLG4207MgM`80NGUi0P1jNWX307alO080
OGem0P1nOWh20820P080PX:20P24Q8@208F5Q@<0QhN70P2:RXX208f=S@80TI6A102DU9@209>CT`<0
UYJF0P2IVIT209^KV`80W9bL0P2PX:020:BTY0D0YZJV0P2XZ:P20:ZZZP80[:b/0P2][Jd20:j^[P80
[jn_0`2a/K420;:b/P80/k>c0P2d];@20;6a/@80[jn_0P2a/K450;>c/`80/[:b0P2`/;020:j^[P80
/;2`0P2b/[850;6a/@80/[:b0P2c/k<20;6a/@80[Jf]0P2ZZZX20:NWY`<0YJFU0P2SXj<209nOW`80
Vi^K102LW9`209JFUP<0TI6A0P2BTY8209BDU080Ti>C0P2ATI4208n?S`80SHf=0`2:RXX208N7Q`80
QHF50P24Q8@208>3P`@0Q8B40`23Ph<20861P@@0OWin2038h=P000H0b>3H0P11@D4203<c<`80;Bd]
0`0^;Rh2038b<P80<C4a1P0_;bl=02h^;P80;2`/0P0[:b/302PX:080:b/[0P0`<30204m?C`80QXJ6
0P2SXj<20820P0<0L71`0P1aLG4206i^KP80PX:20P2c/k<20;Fe]@80/K6a0P2k^k/30<71`@@0`/;2
0P39bLT20<k>cP80f=SH0P2b/[8305MGE`80;Rh^0P0T92@202XZ:P80=CDe0P14A4@204m?C`<0FEUI
0P1QHF4206MWI`80Kfm_0P1fMWH407QhN0<0NWYj0P1mOGd207inOP80P8200P21PH4208>3P`80QXJ6
0`29RHT208^;R`80SHf=0P2@T90209>CT`@0UIFE0`2FUYH209RHV080Vi^K0P2NWYh20:6QX@80XZ:R
0P2UYJD30:NWY`80ZZZZ102/[:`20:^[Z`80[Jf]0P2`/;030;>c/`80];Bd0P2a/K420:j^[P80[Jf]
0P2^[Zh20;6a/@D0/k>c0P2b/[880;6a/@80/;2`0`2_[jl20;2`/080/K6a0P2`/;020:n_[`80[:b/
0P2YZJT30:NWY`80YJFU0P2QXJ4209fMW@80VYZJ0P2GUiL209FEU@D0Ti>C0P2EUID209>CT`80TI6A
0P2?Shl208f=S@<0RXZ:0P27QhL208F5Q@P0Q8B42@21PH480<SPf0001P38h=P20451@@80<c<c0P0]
;Bd302h^;P80<S8b0P0a<C4602l_;`d0;Rh^0P0/;2`202/[:`<0:2PX0P0[:b/2030`<080Cdm?0P26
QXH20:>SX`80P8200`1`L702075aL@80KVi^0P22PX820;>c/`80]KFe0P2a/K420;^k^`<0`L711032
`/820<W9b@80c/k>0P3Hf=P20;:b/P<0EeMG0P0^;Rh202@T9080:RXZ0P0e=CD204A4A080Cdm?0`1I
FET2065QH@80IfMW0P1_Kfl207IfMP@0N7Qh0`1jNWX207emO@80OWin0P20P8020861P@80Ph>30P26
QXH308V9R@80Rh^;0P2=SHd2092@T080Ti>C102EUID309JFUP80V9RH0P2KVi/209jNWP80XJ6Q0P2R
XZ820:FUY@<0YjNW0P2ZZZX40:b/[080Zj^[0P2][Jd20;2`/0<0/k>c0P2d];@20;6a/@80[Zj^0P2]
[Jd20:j^[P80/K6a1@2c/k<20;:b/PP0/K6a0P2`/;030:n_[`80/;2`0P2a/K420;2`/080[jn_0P2/
[:`20:VYZ@<0YjNW0P2UYJD20:6QX@80WIfM0P2JVYX209NGU`80UIFE1@2CTi<209FEU@80Ti>C0P2A
TI4208n?S`80SHf=0`2:RXX208N7Q`80QHF52024Q8@90861P@P0b>3H00060<SPf080BDU90P0`<302
02h^;P<0;bl_0P0d=3@2038b<P80<30`100a<C4202h^;P<0;2`/0P0_;bl2038b<P80;bl_1P0/;2`3
02XZ:P80:BTY0P0X:2P203<c<`80L71`0P2UYJD2096AT@<0L71`0P1YJFT2071`L080MGEe0P2UYJD2
0<;2`P80Zj^[0P2f][H30;bl_080`<300P32`/820<C4a080aLG50P3Cdm<20<g=c@<0ZJVY0P0l?3`2
02XZ:P80:BTY0P0c<c<20492@P80Bd];0`1DE5@205eMG@80IFEU0P1^KVh207EeM@@0MWIf0`1iNGT2
07alO080OWin0P1oOgl20820P080PH610P26QXH308Z:RP80S8b<0P2=SHd208n?S`80TY:B0P2FUYH2
09RHV0D0UiNG0P2KVi/60:2PX080Y:BT0`2XZ:P20:^[Z`80[Zj^0P2/[:`20:ZZZP80[Jf]0P2`/;03
0;Bd]080]KFe0P2_[jl20:VYZ@80ZZZZ0P2^[Zh20;6a/@<0/k>c0P2b/[820;2`/080/[:b0P2d];@2
0;6a/@L0[Zj^102_[jl40;2`/080[Zj^0P2[Zj/30:VYZ@80YjNW0P2SXj<209nOW`80V9RH102CTi<7
09BDU080Ti>C0P2ATI42092@T080SHf=0`2:RXX208J6QPP0QHF50P22PX8307moO`80PX:20P24Q8@2
08F5Q@P0b>3H00060<SPf080BDU90P0`<30202h^;P<0;bl_0P0d=3@2038b<P80<30`100a<C4202h^
;P<0;2`/0P0_;bl2038b<P80;bl_1P0/;2`302XZ:P80:BTY0P0X:2P203<c<`80L71`0P2UYJD2096A
T@<0L71`0P1YJFT2071`L080MGEe0P2UYJD20<;2`P80Zj^[0P2f][H30;bl_080`<300P32`/820<C4
a080aLG50P3Cdm<20<g=c@<0ZJVY0P0l?3`202XZ:P80:BTY0P0c<c<20492@P80Bd];0`1DE5@205eM
G@80IFEU0P1^KVh207EeM@@0MWIf0`1iNGT207alO080OWin0P1oOgl20820P080PH610P26QXH308Z:
RP80S8b<0P2=SHd208n?S`80TY:B0P2FUYH209RHV0D0UiNG0P2KVi/60:2PX080Y:BT0`2XZ:P20:^[
Z`80[Zj^0P2/[:`20:ZZZP80[Jf]0P2`/;030;Bd]080]KFe0P2_[jl20:VYZ@80ZZZZ0P2^[Zh20;6a
/@<0/k>c0P2b/[820;2`/080/[:b0P2d];@20;6a/@L0[Zj^102_[jl40;2`/080[Zj^0P2[Zj/30:VY
Z@80YjNW0P2SXj<209nOW`80V9RH102CTi<709BDU080Ti>C0P2ATI42092@T080SHf=0`2:RXX208J6
QPP0QHF50P22PX8307moO`80PX:20P24Q8@208F5Q@P0b>3H00060<SPf080DE5A0P0`<30202PX:0<0
:b/[0P0d=3@203<c<`80<C4a0P0_;bl202d];@D0;2`/0P0^;Rh2030`<080;Rh^0P0/;2`402d];@<0
:RXZ0P0X:2P202DU9@80;Rh^0P1FEUH209:BTP80W9bL0`24Q8@206MWI`80J6QX0P1/K6`208f=S@80
]kNg0P2f][H20:f][@<0^KVi0P2l_;`20<71`@@0`<300P3<c<`20=7Ad@<0aLG50P2=SHd203De=@80
<S8b0P0d=3@20410@080ATI60`1@D50205]KF`80IFEU0P1]KFd207=cL`@0M7Ad0`1gMgL207]kN`80
OWin1P21PH4208F5Q@<0RHV90P2;Rh/208j>SP80T92@0P2BTY8209JFUP80VYZJ1@2IVIT209bLW080
X:2P0P2QXJ420::RXP80YJFU0`2XZ:P20:ZZZP80[:b/0P2[Zj/20:ZZZP80[:b/0P2_[jl30;6a/@80
/[:b0P2^[Zh20:ZZZP80[Zj^0P2b/[820;>c/`<0/[:b0P2`/;040:n_[`80/;2`0P2/[:`20:VYZ@80
Zj^[0`2][Jd20:n_[`H0/K6a0P2_[jl20:b/[0<0Z:RX0P2TY:@20:2PX080W9bL0P2HV9P209FEU@80
Ti>C0`2BTY82096AT@80T92@0P2ATI4209:BTP80T92@0P2=SHd308V9R@80QXJ60P24Q8@208>3P`80
Q8B40P26QXH207emO@<0Ogmo0P20P80208:2PP80PH612038h=P000H0b>3H0P1ADE42030`<080:2PX
0`0[:b/203@d=080<c<c0P0a<C4202l_;`80;Bd]1@0/;2`202h^;P80<30`0P0^;Rh202`/;0@0;Bd]
0`0Z:RX202PX:0809BDU0P0^;Rh205IFEP80TY:B0P2LW9`308B4Q080IfMW0P1XJ6P206a/K080SHf=
0P2g]kL20;Jf]P80[Jf]0`2i^KT20;bl_080`L711030`<020<c<c080dM7A0`35aLD208f=S@80=CDe
0P0b<S8203@d=080@4100P16ATH3051@D080Fe]K0P1UIFD206e]K@80Lg=c101dM7@307MgM`80Ng]k
0P1nOWh60861P@80QHF50`29RHT208^;R`80SXj>0P2@T90209:BTP80UYJF0P2JVYX509VIV@80W9bL
0P2PX:020:6QX@80XZ:R0P2UYJD30:RXZ080ZZZZ0P2/[:`20:^[Z`80ZZZZ0P2/[:`20:n_[`<0/K6a
0P2b/[820:j^[P80ZZZZ0P2^[Zh20;:b/P80/k>c0`2b/[820;2`/0@0[jn_0P2`/;020:b/[080ZJVY
0P2[Zj/30:f][@80[jn_1P2a/K420:n_[`80[:b/0`2XZ:P20:BTY080X:2P0P2LW9`209RHV080UIFE
0P2CTi<309:BTP80TI6A0P2@T902096AT@80TY:B0P2@T90208f=S@<0RHV90P26QXH208B4Q080Ph>3
0P24Q8@208J6QP80OGem0`1oOgl20820P080PX:20P21PH480<SPf0001P38h=P20451@@809bLW0P0T
92@302TY:@80<c<c0P0b<S82030`<080;2`/0P0Y:BT202XZ:P<0;2`/200];Bd402h^;P<0:b/[0P0Y
:BT202HV9P80;bl_0P0n?Sh207IfMP80WYjN0`2HV9P206a/K080Hf=S0P1VIVH207MgM`80Y:BT0P30
`<020:NWY`<0];Bd0P2h^;P20<30`080_[jn0P2m_Kd20<C4a080bl_;0`3?cll20<C4a080O7al0P0d
=3@203<c<`80?clo0P15ADD304i>CP80FEUI0P1TI6@206a/K080LG5a0P1cLg<207AdM0<0MgMg0P1j
NWX207inOP@0PX:20P21PH4208B4Q0<0R8R80P2;Rh/208j>SP80T92@0P2CTi<209NGU`L0Vi^K0P2M
WId209nOW`80XJ6Q0P2SXj<20:JVYP<0Z:RX102YZJT20:ZZZP80Zj^[0P2/[:`20:f][@D0[Zj^102]
[Jd20;6a/@80]KFe0P2c/k<30:n_[`80[Zj^0P2][Jd20:b/[080Zj^[0P2XZ:P20:JVYP80Z:RX0`2/
[:`20:n_[`@0/K6a0P2`/;020:n_[`80[Jf]0`2WYjL20:6QX@80WIfM0P2IVIT209RHV080UiNG0P2C
Ti<308n?S`80S8b<0P2;Rh/208n?S`80Ti>C0P2@T90208b<S0<0R8R80P25QHD208:2PP80PH610P23
Ph<208J6QP80NWYj0`1oOgl207inOP80Ogmo0P1nOWh80<SPf0001P38h=P20451@@809bLW0P0T92@3
02TY:@80<c<c0P0b<S82030`<080;2`/0P0Y:BT202XZ:P<0;2`/200];Bd402h^;P<0:b/[0P0Y:BT2
02HV9P80;bl_0P0n?Sh207IfMP80WYjN0`2HV9P206a/K080Hf=S0P1VIVH207MgM`80Y:BT0P30`<02
0:NWY`<0];Bd0P2h^;P20<30`080_[jn0P2m_Kd20<C4a080bl_;0`3?cll20<C4a080O7al0P0d=3@2
03<c<`80?clo0P15ADD304i>CP80FEUI0P1TI6@206a/K080LG5a0P1cLg<207AdM0<0MgMg0P1jNWX2
07inOP@0PX:20P21PH4208B4Q0<0R8R80P2;Rh/208j>SP80T92@0P2CTi<209NGU`L0Vi^K0P2MWId2
09nOW`80XJ6Q0P2SXj<20:JVYP<0Z:RX102YZJT20:ZZZP80Zj^[0P2/[:`20:f][@D0[Zj^102][Jd2
0;6a/@80]KFe0P2c/k<30:n_[`80[Zj^0P2][Jd20:b/[080Zj^[0P2XZ:P20:JVYP80Z:RX0`2/[:`2
0:n_[`@0/K6a0P2`/;020:n_[`80[Jf]0`2WYjL20:6QX@80WIfM0P2IVIT209RHV080UiNG0P2CTi<3
08n?S`80S8b<0P2;Rh/208n?S`80Ti>C0P2@T90208b<S0<0R8R80P25QHD208:2PP80PH610P23Ph<2
08J6QP80NWYj0`1oOgl207inOP80Ogmo0P1nOWh80<SPf0001P38h=P2038b<P80:2PX0P0[:b/3030`
<080=CDe0P0b<S8202h^;P80;Bd]0P0/;2`502XZ:P80;2`/100_;bl2034a<@@0<30`0`0^;Rh202`/
;080;Bd]0P0Z:RX2034a<@80E5AD0P29RHT309jNWP80Q8B40P1XJ6P206MWI`80KVi^0P2ATI420;^k
^`80]KFe0`2YZJT20;Bd]0H0_[jn0P33`l<20<O7a`<0bl_;0P34a<@20;Rh^080Fe]K0P0b<S8203Hf
=P80AdM70`1>CTh205MGE`80H61P0P1YJFT206m_K`80LW9b0P1dM7@307QhN080Ng]k0P1nOWh20820
P080PH610P22PX8208J6QP<0Rh^;0P2<S8`208f=S@80T92@0P2DU9@209NGU`80VIVI0`2KVi/209bL
W080WIfM0P2NWYh20:6QX@80YJFU0P2WYjL30:RXZ080YZJV0P2UYJD20:NWY`80ZZZZ0P2/[:`20:j^
[PD0[jn_0P2][Jd20:^[Z`80[:b/0P2][Jd20:b/[0L0Zj^[0P2/[:`20:f][@80Zj^[0P2ZZZX50:VY
Z@80ZZZZ0P2/[:`40:f][@80[:b/0P2[Zj/30:NWY`80XZ:R0P2NWYh209^KV`80VIVI0P2GUiL2096A
T@<0S8b<0P2:RXX208^;R`80Shn?0P2ATI4208f=S@80R8R80`26QXH208F5Q@80Ph>31022PX8208>3
P`80OWin0`21PH420820P080Ogmo0P23Ph<80<SPf0001P38h=P2038b<P80:2PX0P0[:b/3030`<080
=CDe0P0b<S8202h^;P80;Bd]0P0/;2`502XZ:P80;2`/100_;bl2034a<@@0<30`0`0^;Rh202`/;080
;Bd]0P0Z:RX2034a<@80E5AD0P29RHT309jNWP80Q8B40P1XJ6P206MWI`80KVi^0P2ATI420;^k^`80
]KFe0`2YZJT20;Bd]0H0_[jn0P33`l<20<O7a`<0bl_;0P34a<@20;Rh^080Fe]K0P0b<S8203Hf=P80
AdM70`1>CTh205MGE`80H61P0P1YJFT206m_K`80LW9b0P1dM7@307QhN080Ng]k0P1nOWh20820P080
PH610P22PX8208J6QP<0Rh^;0P2<S8`208f=S@80T92@0P2DU9@209NGU`80VIVI0`2KVi/209bLW080
WIfM0P2NWYh20:6QX@80YJFU0P2WYjL30:RXZ080YZJV0P2UYJD20:NWY`80ZZZZ0P2/[:`20:j^[PD0
[jn_0P2][Jd20:^[Z`80[:b/0P2][Jd20:b/[0L0Zj^[0P2/[:`20:f][@80Zj^[0P2ZZZX50:VYZ@80
ZZZZ0P2/[:`40:f][@80[:b/0P2[Zj/30:NWY`80XZ:R0P2NWYh209^KV`80VIVI0P2GUiL2096AT@<0
S8b<0P2:RXX208^;R`80Shn?0P2ATI4208f=S@80R8R80`26QXH208F5Q@80Ph>31022PX8208>3P`80
OWin0`21PH420820P080Ogmo0P23Ph<80<SPf0001P38h=P2038b<P80:2PX0P0[:b/3030`<080=CDe
0P0b<S8202h^;P80;Bd]0P0/;2`502XZ:P80;2`/100_;bl2034a<@@0<30`0`0^;Rh202`/;080;Bd]
0P0Z:RX2034a<@80E5AD0P29RHT309jNWP80Q8B40P1XJ6P206MWI`80KVi^0P2ATI420;^k^`80]KFe
0`2YZJT20;Bd]0H0_[jn0P33`l<20<O7a`<0bl_;0P34a<@20;Rh^080Fe]K0P0b<S8203Hf=P80AdM7
0`1>CTh205MGE`80H61P0P1YJFT206m_K`80LW9b0P1dM7@307QhN080Ng]k0P1nOWh20820P080PH61
0P22PX8208J6QP<0Rh^;0P2<S8`208f=S@80T92@0P2DU9@209NGU`80VIVI0`2KVi/209bLW080WIfM
0P2NWYh20:6QX@80YJFU0P2WYjL30:RXZ080YZJV0P2UYJD20:NWY`80ZZZZ0P2/[:`20:j^[PD0[jn_
0P2][Jd20:^[Z`80[:b/0P2][Jd20:b/[0L0Zj^[0P2/[:`20:f][@80Zj^[0P2ZZZX50:VYZ@80ZZZZ
0P2/[:`40:f][@80[:b/0P2[Zj/30:NWY`80XZ:R0P2NWYh209^KV`80VIVI0P2GUiL2096AT@<0S8b<
0P2:RXX208^;R`80Shn?0P2ATI4208f=S@80R8R80`26QXH208F5Q@80Ph>31022PX8208>3P`80OWin
0`21PH420820P080Ogmo0P23Ph<80<SPf0001P38h=P203<c<`80<S8b0P0a<C4303De=@80=cLg0P0b
<S8202`/;080;Bd]0P0_;bl202/[:`<0:2PX0P0/;2`2034a<@80<S8b0P0c<c<2038b<PD0<C4a0P0`
<30203<c<`809RHV0P0Z:RX203Hf=P80K6a/0`2JVYX209^KV`80LW9b0P1ZJVX206][J`80Ogmo0P2]
[Jd20<30`0<0XJ6Q0P2_[jl20;^k^`@0_kno1030`<030<K6aP80b<S80P39bLT20;6a/@80CTi>0P0g
=cL204M7A`<0CDe=0P1EEED205eMG@80IFEU0P1]KFd2075aL@80MGEe0`1hN7P207alO080OGem0P1o
Ogl20820P080PX:20P28R8P308j>SP80SHf=0P2<S8`2092@T080UIFE0P2FUYH209RHV0<0Vi^K1P2M
WId20::RXP80YZJV0P2XZ:P30:VYZ@80Y:BT0P2QXJ420:BTY080ZJVY0P2/[:`70:n_[`80[:b/0P2X
Z:P20:JVYP80YJFU0P2VYZH30:NWY`80Z:RX0P2YZJT20:b/[0@0[jn_0P2^[Zh20:ZZZPD0YZJV0P2W
YjL20:VYZ@@0ZZZZ0P2YZJT30:NWY`80Y:BT0P2QXJ4209jNWP80VYZJ0P2EUID208j>SP<0RHV90P2:
RXX208b<S080SXj>0P2?Shl208^;R`80QXJ60`25QHD408B4Q080Ph>30P22PX820861P@80PX:20`23
Ph<208:2PP80Ogmo0P29RHT80<SPf0001P38h=P203<c<`80<S8b0P0a<C4303De=@80=cLg0P0b<S82
02`/;080;Bd]0P0_;bl202/[:`<0:2PX0P0/;2`2034a<@80<S8b0P0c<c<2038b<PD0<C4a0P0`<302
03<c<`809RHV0P0Z:RX203Hf=P80K6a/0`2JVYX209^KV`80LW9b0P1ZJVX206][J`80Ogmo0P2][Jd2
0<30`0<0XJ6Q0P2_[jl20;^k^`@0_kno1030`<030<K6aP80b<S80P39bLT20;6a/@80CTi>0P0g=cL2
04M7A`<0CDe=0P1EEED205eMG@80IFEU0P1]KFd2075aL@80MGEe0`1hN7P207alO080OGem0P1oOgl2
0820P080PX:20P28R8P308j>SP80SHf=0P2<S8`2092@T080UIFE0P2FUYH209RHV0<0Vi^K1P2MWId2
0::RXP80YZJV0P2XZ:P30:VYZ@80Y:BT0P2QXJ420:BTY080ZJVY0P2/[:`70:n_[`80[:b/0P2XZ:P2
0:JVYP80YJFU0P2VYZH30:NWY`80Z:RX0P2YZJT20:b/[0@0[jn_0P2^[Zh20:ZZZPD0YZJV0P2WYjL2
0:VYZ@@0ZZZZ0P2YZJT30:NWY`80Y:BT0P2QXJ4209jNWP80VYZJ0P2EUID208j>SP<0RHV90P2:RXX2
08b<S080SXj>0P2?Shl208^;R`80QXJ60`25QHD408B4Q080Ph>30P22PX820861P@80PX:20`23Ph<2
08:2PP80Ogmo0P29RHT80<SPf0001P38h=P202l_;`@0<C4a1@0c<c<2030`<0@0;2`/0P0];Bd202/[
:`<0:RXZ0P0^;Rh2034a<@80>CTi0P0a<C47038b<P80<C4a0P0b<S8202TY:@80:2PX0P0^;Rh2055A
D@<0QHF50P2NWYh208F5Q@80J6QX0P1TI6@2071`L080T92@0P2e]KD30:ZZZP80Zj^[0P2g]kL20;^k
^`80_Kfm0P2n_[h20<30`0<0aLG50P38b<P20=OGe`80b<S80P2TY:@204A4A080=CDe0`13@d<205EE
E@80Fe]K0P1TI6@206a/K080LG5a0P1dM7@307IfMP80NGUi0P1lO7`207moO`80PX:20P25QHD208R8
R0<0RXZ:0P2<S8`208f=S@80TI6A0P2EUID209NGU`80V9RH0`2KVi/409jNWP80WinO0P2RXZ820:JV
YP80YjNW0`2XZ:P20:BTY080XJ6Q0P2TY:@20:VYZ@80[:b/0P2_[jl30:j^[P80[:b/0P2YZJT80:JV
YPD0YjNW0P2XZ:P20:b/[080/;2`0P2_[jl20:f][@80[:b/0`2[Zj/20:VYZ@80Z:RX102WYjL20:VY
Z@80Zj^[0`2XZ:P20:>SX`80Z:RX0P2QXJ4209^KV`80U9BD0P2>SXh508Z:RP80Rh^;0P2>SXh2096A
T@80SHf=0P28R8P308N7Q`80QXJ60P25QHD208>3P`80PX:20P21PH4508:2PP80PH610P1oOgl208Z:
RPP0b>3H00060<SPf080;bl_100a<C4503<c<`80<30`100/;2`202d];@80:b/[0`0Z:RX202h^;P80
<C4a0P0i>CT2034a<@L0<S8b0P0a<C42038b<P80:BTY0P0X:2P202h^;P80DE5A0`25QHD209jNWP80
QHF50P1XJ6P206ATI080L71`0P2@T9020;Fe]@<0ZZZZ0P2[Zj/20;Ng]`80^k^k0P2m_Kd20;jn_P80
`<300`35aLD20<S8b080emOG0P38b<P20:BTY080A4A40P0e=CD304=3@`80EEEE0P1KFe/206ATI080
K6a/0P1aLG4207AdM0<0MWIf0P1iNGT207alO080Ogmo0P22PX8208F5Q@80R8R80`2:RXX208b<S080
SHf=0P2ATI4209FEU@80UiNG0P2HV9P309^KV`@0WYjN0P2OWil20::RXP80YZJV0P2WYjL30:RXZ080
Y:BT0P2QXJ420:BTY080ZJVY0P2/[:`20:n_[`<0[Zj^0P2/[:`20:VYZ@P0YZJV1@2WYjL20:RXZ080
[:b/0P2`/;020:n_[`80[Jf]0P2/[:`30:^[Z`80ZJVY0P2XZ:P40:NWY`80ZJVY0P2[Zj/30:RXZ080
Xj>S0P2XZ:P20:6QX@80Vi^K0P2DU9@208j>SPD0RXZ:0P2;Rh/208j>SP80TI6A0P2=SHd208R8R0<0
QhN70P26QXH208F5Q@80Ph>30P22PX820861P@D0PX:20P21PH4207moO`80RXZ:2038h=P000H0b>3H
1P0^;Rh502l_;`80;Rh^0P0/;2`202/[:`80:RXZ0P0[:b/302d];@80<30`0P0a<C4203dm?@80;bl_
0P0a<C47038b<P80;Rh^0P0/;2`202PX:080;Bd]0P0h>3P306UYJ@@0UIFE0P1/K6`2065QH@80IFEU
0P1dM7@20::RXP<0];Bd0P2YZJT20;>c/`80][Jf0P2j^[X20;fm_@80`<300`34a<@20<O7a`80d=3@
0P3>c/h20<;2`P80RXZ:0P16ATH303hn?P80D51@0P1IFET206=SH`80JVYZ0P1_Kfl207=cL`<0M7Ad
0P1eMGD207YjNP80Ogmo0P24Q8@208R8R080QhN70`26QXH208Z:RP80T92@0P2CTi<209JFUP80UiNG
0P2HV9P309^KV`80WYjN102OWil20::RXP80YJFU1@2VYZH20:BTY080XZ:R0P2TY:@20:NWY`80ZZZZ
0P2][Jd30:ZZZP80YjNW0P2TY:@20:>SX`80YJFU0P2XZ:P20:JVYPD0YJFU0P2WYjL20:^[Z`80[jn_
0P2/[:`20:VYZ@80[:b/0`2_[jl20:f][@80ZJVY0P2VYZH20:FUY@80ZJVY0P2][Jd30:VYZ@80XZ:R
0P2][Jd20:BTY080WIfM0P2CTi<208n?S`<0Rh^;1029RHT208f=S@80TI6A0P2?Shl208^;R`<0RHV9
0P28R8P208F5Q@80Ph>31022PX820861P@D0P8200P1oOgl208Z:RPP0b>3H00060<SPf0H0;Rh^1@0_
;bl202h^;P80;2`/0P0[:b/202XZ:P80:b/[0`0];Bd2030`<080<C4a0P0m?Cd202l_;`80<C4a1`0b
<S8202h^;P80;2`/0P0X:2P202d];@80>3Ph0`1YJFT409FEU@80K6a/0P1QHF4206EUI@80M7Ad0P2R
XZ830;Bd]080ZJVY0P2c/k<20;Jf]P80^[Zj0P2m_Kd20<30`0<0a<C40P37alL20=3@d080c/k>0P32
`/8208Z:RP80ATI60`0n?Sh2051@D080FEUI0P1SHf<206YZJP80Kfm_0P1cLg<307AdM080MGEe0P1j
NWX207moO`80Q8B40P28R8P208N7Q`<0QXJ60P2:RXX2092@T080Ti>C0P2FUYH209NGU`80V9RH0`2K
Vi/209jNWP@0WinO0P2RXZ820:FUY@D0YZJV0P2TY:@20::RXP80Y:BT0P2WYjL20:ZZZP80[Jf]0`2Z
ZZX20:NWY`80Y:BT0P2SXj<20:FUY@80Z:RX0P2VYZH50:FUY@80YjNW0P2[Zj/20:n_[`80[:b/0P2Y
ZJT20:b/[0<0[jn_0P2][Jd20:VYZ@80YZJV0P2UYJD20:VYZ@80[Jf]0`2YZJT20::RXP80[Jf]0P2T
Y:@209fMW@80Ti>C0P2?Shl308^;R`@0RHV90P2=SHd2096AT@80Shn?0P2;Rh/308V9R@80R8R80P25
QHD208>3P`@0PX:20P21PH450820P080Ogmo0P2:RXX80<SPf0001P38h=P202h^;P80;Bd]0P0/;2`3
02d];@@0;Rh^0P0];Bd202/[:`@0:RXZ0`0/;2`2034a<@80=3@d0P0i>CT402l_;`80<30`1@0a<C42
02`/;0809bLW0P0T92@202PX:080;2`/0`19BDT207moO`80V9RH0P28R8P206][J`80HV9R0P1[Jf/2
08b<S0<0/K6a0P2d];@20:n_[`80];Bd0P2g]kL20;Vi^@80^k^k0`2o_kl20<C4a080bl_;0P3?cll2
0=KFeP80_[jn0P20P80304E5A@80>CTi0P1DE5@205eMG@80IVIV0P1/K6`2071`L0<0LW9b0P1dM7@2
07QhN080OGem0P23Ph<208R8R080QhN70`26QXH208^;R`80T92@0P2DU9@209NGU`80V9RH0P2IVIT3
09ZJVP80Vi^K0P2LW9`209fMW@80X:2P0P2RXZ870:>SX`@0XZ:R1P2SXj<30:2PX080WIfM102LW9`2
09nOW`80XJ6Q0P2PX:0309nOW`80X:2P0P2RXZ820:FUY@80Z:RX0P2VYZH20:FUY@80Z:RX1@2/[:`2
0:^[Z`80Z:RX0P2VYZH20:RXZ080ZZZZ0`2VYZH20:6QX@80ZJVY0P2VYZH20:2PX080UiNG0P2@T903
08Z:RP80QXJ60P25QHD208R8R080S8b<0P2=SHd208b<S0<0RXZ:0P27QhL208>3P`80P8200P21PH42
08:2PP80PH610`20P8020861P@80PX:20P2<S8`80<SPf0001P38h=P202h^;P80;Bd]0P0/;2`302d]
;@@0;Rh^0P0];Bd202/[:`@0:RXZ0`0/;2`2034a<@80=3@d0P0i>CT402l_;`80<30`1@0a<C4202`/
;0809bLW0P0T92@202PX:080;2`/0`19BDT207moO`80V9RH0P28R8P206][J`80HV9R0P1[Jf/208b<
S0<0/K6a0P2d];@20:n_[`80];Bd0P2g]kL20;Vi^@80^k^k0`2o_kl20<C4a080bl_;0P3?cll20=KF
eP80_[jn0P20P80304E5A@80>CTi0P1DE5@205eMG@80IVIV0P1/K6`2071`L0<0LW9b0P1dM7@207Qh
N080OGem0P23Ph<208R8R080QhN70`26QXH208^;R`80T92@0P2DU9@209NGU`80V9RH0P2IVIT309ZJ
VP80Vi^K0P2LW9`209fMW@80X:2P0P2RXZ870:>SX`@0XZ:R1P2SXj<30:2PX080WIfM102LW9`209nO
W`80XJ6Q0P2PX:0309nOW`80X:2P0P2RXZ820:FUY@80Z:RX0P2VYZH20:FUY@80Z:RX1@2/[:`20:^[
Z`80Z:RX0P2VYZH20:RXZ080ZZZZ0`2VYZH20:6QX@80ZJVY0P2VYZH20:2PX080UiNG0P2@T90308Z:
RP80QXJ60P25QHD208R8R080S8b<0P2=SHd208b<S0<0RXZ:0P27QhL208>3P`80P8200P21PH4208:2
PP80PH610`20P8020861P@80PX:20P2<S8`80<SPf0001P38h=P202l_;`80;2`/0P0Z:RX302`/;0H0
;Rh^0P0/;2`402/[:`<0;2`/0P0b<S8203Hf=P80<c<c0P0_;bl202h^;P80;Bd]0`0_;bl2030`<080
:BTY0P0S8b<2028R8P8092@T0P0U9BD302h^;P80Hf=S0P2BTY8209nOW`80NWYj0P1UIFD206UYJ@80
NGUi0`2WYjL20;fm_@80[Jf]0P2a/K420;:b/P80];Bd0P2f][H30;Zj^P80`<300P36a/H20<c<c080
bLW90P3?cll20;Zj^P<0LG5a0P0l?3`2055AD@80EEEE0P1QHF4206MWI`80K6a/0`1`L70207AdM080
MgMg0P1kNg/20861P@80QXJ61@27QhL208b<S080TI6A0P2EUID209RHV0@0VIVI0`2HV9P209NGU`80
V9RH0P2JVYX209fMW@80WinO1@2PX:040:6QX@80WinO0P2MWId209^KV`80VIVI0`2FUYH209>CT`80
U9BD0P2FUYH609RHV0<0UiNG0P2IVIT209bLW080WYjN0P2OWil40:2PX080Xj>S0`2UYJD20:RXZ080
ZZZZ0P2YZJT20:NWY`80YZJV0P2UYJD30::RXP80X:2P0P2SXj<20:NWY`80Xj>S0P2LW9`2096AT@<0
R8R80P23Ph<20861P@80Ph>30P26QXH208Z:RP80S8b<0`2:RXX208N7Q`80PH610P1mOGd20820P080
Ph>30P21PH430820P080Ph>30P25QHD208f=S@P0b>3H00060<SPf080;bl_0P0/;2`202XZ:P<0;2`/
1P0^;Rh202`/;0@0:b/[0`0/;2`2038b<P80=SHf0P0c<c<202l_;`80;Rh^0P0];Bd302l_;`80<30`
0P0Y:BT202<S8`808R8R0P0T92@202DU9@<0;Rh^0P1SHf<209:BTP80WinO0P1jNWX206EUI@80JFUY
0P1iNGT30:NWY`80_Kfm0P2][Jd20;6a/@80/[:b0P2d];@20;Jf]P<0^[Zj0P30`<020<K6aP80c<c<
0P39bLT20<o?c`80^[Zj0`1aLG4203`l?080DE5A0P1EEED2065QH@80IfMW0P1/K6`3071`L080M7Ad
0P1gMgL207]kN`80PH610P26QXH508N7Q`80S8b<0P2ATI4209FEU@80V9RH102IVIT309RHV080UiNG
0P2HV9P209ZJVP80WIfM0P2OWil50:2PX0@0XJ6Q0P2OWil209fMW@80Vi^K0P2IVIT309JFUP80Ti>C
0P2DU9@209JFUPH0V9RH0`2GUiL209VIV@80W9bL0P2NWYh209nOW`@0X:2P0P2SXj<30:FUY@80Z:RX
0P2ZZZX20:VYZ@80YjNW0P2VYZH20:FUY@<0XZ:R0P2PX:020:>SX`80YjNW0P2SXj<209bLW080TI6A
0`28R8P208>3P`80PH610P23Ph<208J6QP80RXZ:0P2<S8`308Z:RP80QhN70P21PH4207emO@80P820
0P23Ph<20861P@<0P8200P23Ph<208F5Q@80SHf=2038h=P000H0b>3H100/;2`502d];@80;Rh^100_
;bl202`/;080:b/[0P0];Bd3030`<080<S8b0P0d=3@2034a<@80;bl_0P0^;Rh702d];@80:BTY100T
92@202DU9@808B4Q0`0U9BD204=3@`80O7al0P2GUiL2096AT@80M7Ad0P1WIfL206i^KP<0U9BD0P2i
^KT20;Ng]`80Zj^[0P2YZJT20:f][@80]KFe0`2g]kL20;^k^`80`<300P36a/H20<S8b080dM7A0P3@
d=030:j^[P80KFe]0P17AdL204A4A080G5aL0P1QHF4206UYJ@<0Kfm_0P1dM7@207QhN080Ng]k0P20
P80208J6QP80QhN70`29RHT208f=S@80TY:B0P2DU9@209JFUP80VIVI0P2KVi/309ZJVPH0V9RH0P2I
VIT209ZJVP80Vi^K1@2LW9`209^KV`80VIVI0P2GUiL209JFUP80UIFE0`2BTY82092@T080TY:B1P2D
U9@209>CT`<0TY:B0P2DU9@209FEU@80UYJF0P2GUiL209ZJVP80WIfM0P2OWil309jNWP80XZ:R0P2T
Y:@20:FUY@80Y:BT0P2VYZH20:NWY`<0XZ:R0P2NWYh20:2PX080YJFU0P2TY:@20:6QX@80UIFE0`28
R8P208>3P`80PH610P22PX8208F5Q@80R8R80P2:RXX308V9R@80QhN70P23Ph<40820P080PH610P20
P80307moO`80PX:20P24Q8@208f=S@P0b>3H00060<SPf0@0;2`/1@0];Bd202h^;P@0;bl_0P0/;2`2
02/[:`80;Bd]0`0`<302038b<P80=3@d0P0a<C4202l_;`80;Rh^1`0];Bd202TY:@@092@T0P0U9BD2
024Q8@<09BDU0P13@d<207alO080UiNG0P2ATI4207AdM080IfMW0P1^KVh309BDU080^KVi0P2g]kL2
0:^[Z`80ZJVY0P2][Jd20;Fe]@<0]kNg0P2k^k/20<30`080a/K60P38b<P20=7Ad@80d=3@0`2^[Zh2
06e]K@80AdM70P14A4@205aLG080HF5Q0P1YJFT306m_K`80M7Ad0P1hN7P207]kN`80P8200P26QXH2
08N7Q`<0RHV90P2=SHd209:BTP80U9BD0P2FUYH209VIV@80Vi^K0`2JVYX609RHV080VIVI0P2JVYX2
09^KV`D0W9bL0P2KVi/209VIV@80UiNG0P2FUYH209FEU@<0TY:B0P2@T90209:BTPH0U9BD0P2CTi<3
09:BTP80U9BD0P2EUID209JFUP80UiNG0P2JVYX209fMW@80WinO0`2NWYh20::RXP80Y:BT0P2UYJD2
0:BTY080YZJV0P2WYjL30::RXP80WYjN0P2PX:020:FUY@80Y:BT0P2QXJ4209FEU@<0R8R80P23Ph<2
0861P@80PX:20P25QHD208R8R080RXZ:0`29RHT208N7Q`80Ph>31020P8020861P@80P8200`1oOgl2
08:2PP80Q8B40P2=SHd80<SPf0001P38h=P202TY:@80;2`/0P0a<C4902l_;`80;Bd]0P0[:b/202l_
;`<0<c<c0P0b<S82034a<@@0<30`0P0_;bl202d];@<0;2`/0P0[:b/202TY:@809bLW100V9RH201lO
7`<08R8R0P0W9bL205mOG`80Q8B40P2QXJ4208J6QP80JFUY0P1WIfL307moO`80[:b/0P2o_kl20:JV
YP80XJ6Q0P2XZ:P20;>c/`<0];Bd0P2e]KD20;Zj^P80`<300P36a/H20<[:bP80bLW90`3<c<`20:BT
Y080GemO0P1>CTh205MGE`80Fe]K0P1TI6@306a/K080M7Ad0P1hN7P207]kN`80P8200P24Q8@208N7
Q`<0RXZ:0P2>SXh209:BTP80Ti>C0P2DU9@209RHV080Vi^K0`2JVYX209VIV@80UiNG1P2FUYH509NG
U`80UYJF0P2EUID209>CT`80TY:B0P2CTi<209BDU0<0TI6A0P2>SXh2092@T080Ti>C0P2ATI4208n?
S`80SXj>0`2=SHd208j>SP@0Shn?0P2@T90209BDU080V9RH0P2IVIT309RHV080VYZJ0P2MWId209nO
W`80XJ6Q0P2UYJD20:NWY`<0XZ:R0P2LW9`209fMW@80X:2P102SXj<209NGU`<0RXZ:0P24Q8@20861
P@80PX:20P24Q8@208J6QPD0R8R80P27QhL208J6QP80Ph>30P21PH4707moO`80PH610P23Ph<208f=
S@P0b>3H00060<SPf080:BTY0P0/;2`2034a<@T0;bl_0P0];Bd202/[:`80;bl_0`0c<c<2038b<P80
<C4a100`<30202l_;`80;Bd]0`0/;2`202/[:`80:BTY0P0W9bL402HV9P807alO0`0R8R8202LW9`80
GemO0P24Q8@20:6QX@80QXJ60P1YJFT206MWI`<0Ogmo0P2/[:`20;no_`80YZJV0P2QXJ420:RXZ080
/k>c0`2d];@20;Fe]@80^[Zj0P30`<020<K6aP80b/[:0P39bLT30<c<c080Y:BT0P1OGel204i>CP80
EeMG0P1KFe/206ATI0<0K6a/0P1dM7@207QhN080Ng]k0P20P80208B4Q080QhN70`2:RXX208j>SP80
TY:B0P2CTi<209BDU080V9RH0P2KVi/309ZJVP80VIVI0P2GUiL609JFUPD0UiNG0P2FUYH209FEU@80
Ti>C0P2BTY8209>CT`80U9BD0`2ATI4208j>SP80T92@0P2CTi<2096AT@80Shn?0P2>SXh308f=S@80
SXj>102?Shl2092@T080U9BD0P2HV9P209VIV@<0V9RH0P2JVYX209fMW@80WinO0P2QXJ420:FUY@80
YjNW0`2RXZ8209bLW080WIfM0P2PX:040:>SX`80UiNG0`2:RXX208B4Q080PH610P22PX8208B4Q080
QXJ61@28R8P208N7Q`80QXJ60P23Ph<20861P@L0Ogmo0P21PH4208>3P`80SHf=2038h=P000H0b>3H
0P0Y:BT202`/;080<C4a2@0_;bl202d];@80:b/[0P0_;bl303<c<`80<S8b0P0a<C44030`<080;bl_
0P0];Bd302`/;080:b/[0P0Y:BT202LW9`@09RHV0P0O7al3028R8P809bLW0P1OGel208B4Q080XJ6Q
0P26QXH206UYJ@80IfMW0`1oOgl20:b/[080_kno0P2VYZH20:6QX@80Z:RX0P2c/k<30;Bd]080]KFe
0P2j^[X20<30`080a/K60P3:b/X20<W9b@<0c<c<0P2TY:@205mOG`80CTi>0P1GEeL205]KF`80I6AT
0`1/K6`207AdM080N7Qh0P1kNg/20820P080Q8B40P27QhL308Z:RP80SXj>0P2BTY8209>CT`80U9BD
0P2HV9P209^KV`<0VYZJ0P2IVIT209NGU`H0UYJF1@2GUiL209JFUP80UIFE0P2CTi<209:BTP80Ti>C
0P2DU9@3096AT@80SXj>0P2@T90209>CT`80TI6A0P2?Shl208j>SP<0SHf=0P2>SXh408n?S`80T92@
0P2DU9@209RHV080VIVI0`2HV9P209ZJVP80WIfM0P2OWil20:6QX@80YJFU0P2WYjL30::RXP80W9bL
0P2MWId20:2PX0@0Xj>S0P2GUiL308Z:RP80Q8B40P21PH4208:2PP80Q8B40P26QXH508R8R080QhN7
0P26QXH208>3P`80PH611`1oOgl20861P@80Ph>30P2=SHd80<SPf0001P38h=P402`/;080;Bd]0`0d
=3@202l_;`@0<30`0P0^;Rh202`/;080;bl_0`0b<S82034a<@H0;bl_100`<303034a<@80<30`0P0[
:b/202LW9`809BDU0P0T92@201lO7`<0820P0P0O7al20410@080LG5a0P2JVYX209RHV080Lg=c0P1R
HV83075aL@80T92@0P2g]kL20:j^[P80WinO0P2UYJD20:j^[P<0];Bd0P2a/K420;Jf]P80^k^k0P32
`/820<S8b080bLW90`3?cll20<K6aP80XZ:R0P1PH60204m?C`80D51@0P1IFET306EUI@80Kfm_0P1f
MWH207YjNP80Ogmo0P23Ph<208F5Q@<0R8R80P2;Rh/208n?S`80TY:B0P2CTi<409BDU0<0UIFE202F
UYH209FEU@80U9BD0`2BTY84092@T080TI6A0P2BTY8209FEU@80UYJF0`2@T90208V9R@80SHf=0P2@
T90208b<S0L0R8R80P27QhL208V9R@80Rh^;102=SHd2092@T080RHV90`2DU9@209FEU@80VYZJ0P2I
VIT209nOW`@0X:2P0`2LW9`209RHV0@0UiNG0P2JVYX209bLW080UYJF0`2>SXh208>3P`80Ng]k0P1m
OGd208:2PP80QHF51@27QhL208F5Q@80Q8B40P23Ph<20861P@L0Ogmo0P23Ph<208F5Q@80Shn?2038
h=P000H0b>3H100/;2`202d];@<0=3@d0P0_;bl4030`<080;Rh^0P0/;2`202l_;`<0<S8b0P0a<C46
02l_;`@0<30`0`0a<C42030`<080:b/[0P0W9bL202DU9@8092@T0P0O7al3020P80807alO0P10@402
075aL@80VYZJ0P2HV9P207=cL`80HV9R0`1aLG42092@T080]kNg0P2^[Zh209nOW`80YJFU0P2^[Zh3
0;Bd]080/K6a0P2f][H20;^k^`80`/;20P38b<P20<W9b@<0clo?0P36a/H20::RXP80H61P0P1?Cdl2
051@D080FEUI0`1UIFD206m_K`80MWIf0P1jNWX207moO`80Ph>30P25QHD308R8R080Rh^;0P2?Shl2
09:BTP80Ti>C102DU9@309FEU@P0UYJF0P2EUID209BDU0<0TY:B102@T902096AT@80TY:B0P2EUID2
09JFUP<0T92@0P29RHT208f=S@80T92@0P2<S8`708R8R080QhN70P29RHT208^;R`@0SHf=0P2@T902
08V9R@<0U9BD0P2EUID209ZJVP80VIVI0P2OWil40:2PX0<0W9bL0P2HV9P409NGU`80VYZJ0P2LW9`2
09JFUP<0SXj>0P23Ph<207]kN`80OGem0P22PX8208F5Q@D0QhN70P25QHD208B4Q080Ph>30P21PH47
07moO`80Ph>30P25QHD208n?S`P0b>3H00060<SPf080;bl_0P0/;2`202LW9`<0=SHf0P0`<302034a
<@80<30`0P0^;Rh202`/;080;Rh^0`0a<C4202l_;`80;Bd]0P0^;Rh202l_;`80<C4a0P0d=3@303De
=@80=3@d0P0^;Rh202LW9`8092@T0P0R8R82020P80D07alO0P0V9RH205YJFP80QhN70P2PX:020820
P080HV9R0`1VIVH207=cL`80Z:RX0P2g]kL20:>SX`80YZJV0P2XZ:P30;>c/`80[Zj^0P2b/[820;Jf
]P80_[jn0P36a/H20<W9b@<0b<S80P3;bl/20<71`@80X:2P101GEeL204m?C`<0G5aL0P1[Jf/207=c
L`80NGUi0P1nOWh20861P@80Ph>30`25QHD208R8R080S8b<0P2@T90209>CT`80T92@0P2=SHd308n?
S`80TY:B0P2DU9@209FEU@80UYJF0P2EUID2096AT@<0SXj>102<S8`208n?S`80Ti>C0P2GUiL209RH
V0<0Shn?0P25QHD208R8R080Rh^;0P27QhL208:2PPL0P8200P24Q8@208R8R080S8b<1028R8P207Ui
N@<0TI6A0P2?Shl209:BTP80T92@0P2OWil209bLW080V9RH0`2GUiL209JFUP80Ti>C0P2@T90209:B
TP@0U9BD0`2?Shl208:2PP80MWIf0P1iNGT20820P080Ph>30P26QXH308F5Q@80Ph>31022PX820861
P@@0Ogmo0`20P80208F5Q@80R8R80P2ATI480<SPf0001P38h=P202l_;`80;2`/0P0W9bL303Hf=P80
<30`0P0a<C42030`<080;Rh^0P0/;2`202h^;P<0<C4a0P0_;bl202d];@80;Rh^0P0_;bl2034a<@80
=3@d0`0e=CD203@d=080;Rh^0P0W9bL202@T90808R8R0P0P820501lO7`809RHV0P1JFUX208N7Q`80
X:2P0P20P802069RHP<0IVIV0P1cLg<20:RXZ080]kNg0P2SXj<20:JVYP80Z:RX0`2c/k<20:j^[P80
/[:b0P2f][H20;jn_P80a/K60P39bLT30<S8b080bl_;0P31`L420:2PX0@0EeMG0P1?Cdl305aLG080
Jf][0P1cLg<207UiN@80OWin0P21PH4208>3P`<0QHF50P28R8P208b<S080T92@0P2CTi<2092@T080
SHf=0`2?Shl209:BTP80U9BD0P2EUID209JFUP80UIFE0P2ATI4308j>SP@0S8b<0P2?Shl209>CT`80
UiNG0P2HV9P308n?S`80QHF50P28R8P208^;R`80QhN70P22PX870820P080Q8B40P28R8P208b<S0@0
R8R80P1iNGT3096AT@80Shn?0P2BTY82092@T080WinO0P2LW9`209RHV0<0UiNG0P2FUYH209>CT`80
T92@0P2BTY8409BDU0<0Shn?0P22PX8207IfMP80NGUi0P20P80208>3P`80QXJ60`25QHD208>3P`@0
PX:20P21PH4407moO`<0P8200P25QHD208R8R080TI6A2038h=P000H0b>3H0P0[:b/2034a<@80=cLg
0`0h>3P602d];@@0;2`/0P0_;bl3034a<@80;bl_0P0/;2`202d];@80<30`0P0c<c<203Hf=P<0=CDe
0P0b<S8202d];@H09BDU0P0S8b<3024Q8@807QhN0P0Q8B4203`l?080J6QX0P2@T90209:BTP80L71`
0`1PH60206EUI@80TY:B0P2h^;P20;>c/`80ZZZZ0P2OWil30:j^[P80[Jf]0P2b/[820;Fe]@80_;bl
0P32`/820<O7a`<0bLW90P3;bl/20<S8b080^k^k0P2HV9P205eMG@80F5QH0`1EEED206UYJ@80L71`
0P1hN7P207alO080P8200P23Ph<308J6QP80R8R80P2;Rh/208f=S@80T92@0P2>SXh208b<S0<0SXj>
0P2@T90209:BTP80Ti>C0P2BTY82096AT@80T92@0`2?Shl408j>SP80T92@0P2CTi<209FEU@80U9BD
0`2;Rh/208:2PP80NWYj0P22PX820861P@80Ogmo0P1eMGD306e]K@80Ogmo0P21PH4208N7Q`80R8R8
0P29RHT207UiN@80KFe]0`25QHD208J6QP80PX:20P27QhL20:6QX@80VYZJ0P2CTi<309NGU`80WIfM
0P2KVi/209RHV080UIFE0P2CTi<208j>SP<0R8R80P1nOWh207IfMP80N7Qh0P1lO7`20861P@D0Q8B4
0P23Ph<408:2PP@0PH610P1oOgl30820P080QhN70P2=SHd209>CT`P0b>3H00060<SPf080:b/[0P0a
<C4203Lg=`<0>3Ph1P0];Bd402`/;080;bl_0`0a<C4202l_;`80;2`/0P0];Bd2030`<080<c<c0P0f
=SH303De=@80<S8b0P0];Bd602DU9@808b<S0`0Q8B4201hN7P808B4Q0P0l?3`206QXJ080T92@0P2B
TY82071`L0<0H61P0P1UIFD209:BTP80^;Rh0P2c/k<20:ZZZP80WinO0`2^[Zh20:f][@80/[:b0P2e
]KD20;bl_080`/;20P37alL30<W9b@80bl_;0P38b<P20;^k^`80V9RH0P1MGEd205QHF0<0EEEE0P1Y
JFT2071`L080N7Qh0P1lO7`20820P080Ph>30`26QXH208R8R080Rh^;0P2=SHd2092@T080SXj>0P2<
S8`308j>SP80T92@0P2BTY8209>CT`80TY:B0P2ATI42092@T0<0Shn?102>SXh2092@T080Ti>C0P2E
UID209BDU0<0Rh^;0P22PX8207YjNP80PX:20P21PH4207moO`80MGEe0`1]KFd207moO`80PH610P27
QhL208R8R080RHV90P1iNGT206e]K@<0QHF50P26QXH208:2PP80QhN70P2QXJ4209ZJVP80Ti>C0`2G
UiL209fMW@80Vi^K0P2HV9P209FEU@80Ti>C0P2>SXh308R8R080OWin0P1fMWH207QhN080O7al0P21
PH4508B4Q080Ph>31022PX840861P@80Ogmo0`20P80208N7Q`80SHf=0P2CTi<80<SPf0001P38h=P2
02TY:@80:RXZ3@0[:b/202`/;080;bl_0`0b<S8202l_;`80;2`/0P0];Bd2030`<080<c<c0P0f=SH3
03@d=080<30`0P0[:b/402HV9P809bLW0P0U9BD302<S8`807alO0P0R8R8202<S8`80AdM70P1fMWH2
09fMW@80PH610`1QHF4205iNGP80O7al0P2c/k<20<;2`P80/K6a0P2JVYX30:VYZ@80[:b/0P2a/K42
0;Fe]@80^[Zj0P30`<020<G5a@<0bLW90P38b<P20<G5a@80bLW90P34a<@209NGU`80F5QH0`1@D502
06UYJ@80KVi^0P1eMGD207YjNP80OWin0P23Ph<308N7Q`80R8R80P29RHT208Z:RPH0S8b<0`2=SHd2
08n?S`80T92@0P2ATI4208n?S`80SXj>0P2@T90309:BTP80TI6A102@T90408n?S`80SXj>0`26QXH2
07moO`80KVi^0P1gMgL207]kN`80OGem0P1/K6`305aLG0@0Ogmo1028R8P208f=S@80LW9b0P1^KVh3
0861P@80Ng]k0P1WIfL207]kN`80Xj>S0P2LW9`209:BTP<0Vi^K0P2UYJD20:JVYP80XZ:R0P2LW9`2
09BDU080RXZ:0`22PX8207alO0@0N7Qh0P1jNWX207inOP80PX:21@23Ph<208:2PP80PH611022PX85
0820P080RHV90P2BTY8209BDU0P0b>3H00060<SPf080:BTY0P0Z:RX=02/[:`80;2`/0P0_;bl3038b
<P80;bl_0P0/;2`202d];@80<30`0P0c<c<203Hf=P<0=3@d0P0`<30202/[:`@09RHV0P0W9bL202DU
9@<08b<S0P0O7al2028R8P808b<S0P17AdL207IfMP80WIfM0P21PH43065QH@80GUiN0P1lO7`20;>c
/`80`/;20P2a/K4209ZJVP<0ZJVY0P2/[:`20;6a/@80]KFe0P2j^[X20<30`080aLG50`39bLT20<S8
b080aLG50P39bLT20<C4a080UiNG0P1HF5P3051@D080JFUY0P1^KVh207EeM@80NWYj0P1nOWh208>3
P`<0QhN70P28R8P208V9R@80RXZ:1P2<S8`308f=S@80Shn?0P2@T902096AT@80Shn?0P2>SXh2092@
T0<0TY:B0P2ATI44092@T0@0Shn?0P2>SXh308J6QP80Ogmo0P1^KVh207MgM`80Ng]k0P1mOGd206a/
K0<0G5aL101oOgl408R8R080SHf=0P1bLW8206i^KP<0PH610P1kNg/206MWI`80Ng]k0P2SXj<209bL
W080TY:B0`2KVi/20:FUY@80YZJV0P2RXZ8209bLW080U9BD0P2:RXX308:2PP80O7al101hN7P207Yj
NP80OWin0P22PX8508>3P`80PX:20P21PH4408:2PPD0P8200P29RHT209:BTP80U9BD2038h=P000H0
b>3H0P0Z:RX702TY:@80:b/[0P0/;2`402d];@80;Rh^0P0_;bl3030`<080;Rh^100/;2`202d];@80
<30`1`0d=3@202XZ:P80;Rh^0P0Y:BT202DU9@8092@T0`0U9BD4028R8P8071`L0P0`<30205MGE`80
SXj>0P2DU9@307AdM080F5QH0P1ZJVX209jNWP80`<300P31`L420:NWY`<0YJFU0P2ZZZX20:j^[P80
];Bd0P2i^KT20;fm_@80`l?30`37alL40<W9b@80b/[:0P39bLT20;Fe]@80UIFE0`1`L70205iNGP80
HV9R0P1_Kfl207IfMP80O7al0P20P80308B4Q0@0QHF50P2:RXX208J6QP@0QhN70`2;Rh/208n?S`@0
T92@0P2?Shl208j>SP80T92@0`2BTY8208n?S`80Rh^;0P27QhL208B4Q080QHF50P29RHT308F5Q@80
OGem0P1]KFd206a/K080Lg=c0P1iNGT206UYJ@<0FEUI0P1kNg/20820P080QXJ60P23Ph<207inOP@0
JVYZ0`1oOgl207EeM@80IFEU0P1nOWh20:>SX`80YJFU0P2QXJ430:NWY`80[:b/0P2][Jd20:b/[080
YJFU0P2LW9`2096AT@<0QhN70P1oOgl207]kN`80NWYj101lO7`207emO@<0Ogmo0P21PH440820P080
PH610P23Ph<20861P@<0PX:20P2:RXX209>CT`80U9BD2038h=P000H0b>3H0P0Z:RX702TY:@80:b/[
0P0/;2`402d];@80;Rh^0P0_;bl3030`<080;Rh^100/;2`202d];@80<30`1`0d=3@202XZ:P80;Rh^
0P0Y:BT202DU9@8092@T0`0U9BD4028R8P8071`L0P0`<30205MGE`80SXj>0P2DU9@307AdM080F5QH
0P1ZJVX209jNWP80`<300P31`L420:NWY`<0YJFU0P2ZZZX20:j^[P80];Bd0P2i^KT20;fm_@80`l?3
0`37alL40<W9b@80b/[:0P39bLT20;Fe]@80UIFE0`1`L70205iNGP80HV9R0P1_Kfl207IfMP80O7al
0P20P80308B4Q0@0QHF50P2:RXX208J6QP@0QhN70`2;Rh/208n?S`@0T92@0P2?Shl208j>SP80T92@
0`2BTY8208n?S`80Rh^;0P27QhL208B4Q080QHF50P29RHT308F5Q@80OGem0P1]KFd206a/K080Lg=c
0P1iNGT206UYJ@<0FEUI0P1kNg/20820P080QXJ60P23Ph<207inOP@0JVYZ0`1oOgl207EeM@80IFEU
0P1nOWh20:>SX`80YJFU0P2QXJ430:NWY`80[:b/0P2][Jd20:b/[080YJFU0P2LW9`2096AT@<0QhN7
0P1oOgl207]kN`80NWYj101lO7`207emO@<0Ogmo0P21PH440820P080PH610P23Ph<20861P@<0PX:2
0P2:RXX209>CT`80U9BD2038h=P000H0b>3H0P0/;2`202PX:0809BDU0`0W9bL202/[:`80;Rh^1P0`
<30202l_;`<0;Rh^100_;bl202d];@80:b/[0P0];Bd2030`<0<0=3@d0P0h>3P202/[:`80=cLg0P0/
;2`402<S8`<09RHV0P0T92@202<S8`807AdM0P0Q8B4203/k>`80M7Ad0P2MWId308V9R@80G5aL0P1O
Gel208J6QP80]KFe0P3;bl/20;Rh^0<0YJFU0P2WYjL20:ZZZP80/K6a0P2f][H20;^k^`80`<300`34
a<@20<W9b@80bl_;0P38b<P20<?3``80aLG50P2n_[h308j>SP80GemO0P1NGUh206UYJ@80LG5a0P1i
NGT207inOP<0P8200P21PH420820P080RXZ:0P21PH4408:2PP<0R8R80P2?Shl4092@T080Shn?0P2>
SXh508n?S`80Rh^;0P25QHD207alO080MWIf0P1jNWX50861P@80Ng]k0P1`L70206MWI`80L71`0P1i
NGT206a/K0<0H61P0P1hN7P208B4Q080SHf=0P2BTY82096AT@80U9BD0P2FUYH30:RXZ080W9bL0P2B
TY8209RHV080XJ6Q0P2YZJT20:j^[P<0[jn_0P2][Jd40:n_[`80ZJVY0P2PX:0209JFUP<0S8b<0P24
Q8@207inOP@0OGem0P1jNWX207MgM`<0NWYj0P1nOWh407moO`80PH611023Ph<308B4Q080Rh^;0P2B
TY8209BDU0P0b>3H00060<SPf080;2`/0P0X:2P202DU9@<09bLW0P0[:b/202h^;PH0<30`0P0_;bl3
02h^;P@0;bl_0P0];Bd202/[:`80;Bd]0P0`<30303@d=080>3Ph0P0[:b/203Lg=`80;2`/100S8b<3
02HV9P8092@T0P0S8b<201dM7@808B4Q0P0k>c/207AdM080WIfM0`29RHT205aLG080GemO0P26QXH2
0;Fe]@80bl_;0P2h^;P30:FUY@80YjNW0P2ZZZX20;6a/@80][Jf0P2k^k/20<30`0<0a<C40P39bLT2
0<_;b`80b<S80P33`l<20<G5a@80_[jn0`2>SXh205mOG`80GUiN0P1YJFT2075aL@80NGUi0P1nOWh3
0820P080PH610P20P80208Z:RP80PH611022PX8308R8R080Shn?102@T90208n?S`80SXj>1@2?Shl2
08^;R`80QHF50P1lO7`207IfMP80NWYj1@21PH4207]kN`80L71`0P1WIfL2071`L080NGUi0P1/K6`3
061PH080N7Qh0P24Q8@208f=S@80TY:B0P2ATI4209BDU080UYJF0`2XZ:P209bLW080TY:B0P2HV9P2
0:6QX@80ZJVY0P2^[Zh30:n_[`80[Jf]102_[jl20:VYZ@80X:2P0P2FUYH308b<S080Q8B40P1nOWh4
07emO@80NWYj0P1gMgL307YjNP80OWin101oOgl20861P@@0Ph>30`24Q8@208^;R`80TY:B0P2DU9@8
0<SPf0001P38h=P202`/;0809bLW0P0S8b<302DU9@80:BTY0P0];Bd2030`<080<C4a0P0`<30502l_
;`80=CDe0P0i>CT203@d=0@0;bl_0P0`<30502h^;P80;Bd]0P0j>SX2034a<@80:BTY1@0V9RH202@T
90808b<S0P0Q8B4202<S8`80;Bd]0P1DE5@208V9R@<0UYJF0P1bLW82055AD@80Kfm_0P2JVYX20<71
`@80b/[:0`2`/;020:>SX`80YZJV0P2/[:`20;:b/P80^;Rh0P2l_;`30<30`080alO70P3;bl/20<W9
b@80aLG50P38b<P20<K6aP<0[Jf]0P2>SXh2075aL@80GUiN0P1TI6@207UiN@80O7al0`1mOGd207in
OP80Ogmo0P25QHD208:2PP80P8200P1oOgl308R8R080T92@0P2BTY8608n?S`80SHf=0`2;Rh/208J6
QP80Ogmo0P1fMWH206a/K080L71`1@1WIfL207IfMP80LW9b0P1]KFd207UiN@80QXJ60P2;Rh/308f=
S@80U9BD0P2FUYH209^KV`80WinO0P2RXZ820:NWY`80Zj^[0`2e]KD20:n_[`80Zj^[0P2`/;020;Bd
]080_;bl0P2n_[h30;2`/080X:2P0P2MWId209bLW080TY:B0P2;Rh/208R8R0<0QhN70P24Q8@208:2
PP80Ogmo0P1lO7`207UiN@80MWIf0`1hN7P207alO080Ogmo2022PX8308>3P`80S8b<0P2DU9@209JF
UPP0b>3H00060<SPf080;2`/0P0W9bL202<S8`<09BDU0P0Y:BT202d];@80<30`0P0a<C42030`<0D0
;bl_0P0e=CD203Ti>@80=3@d100_;bl2030`<0D0;Rh^0P0];Bd203Xj>P80<C4a0P0Y:BT502HV9P80
92@T0P0S8b<2024Q8@808b<S0P0];Bd205ADE080RHV90`2FUYH2079bLP80DE5A0P1_Kfl209ZJVP80
`L710P3:b/X30;2`/080Xj>S0P2VYZH20:b/[080/[:b0P2h^;P20;bl_0<0`<300P37alL20<_;b`80
bLW90P35aLD20<S8b080a/K60`2][Jd208j>SP80LG5a0P1NGUh206ATI080NGUi0P1lO7`307emO@80
OWin0P1oOgl208F5Q@80PX:20P20P80207moO`<0R8R80P2@T90209:BTPH0Shn?0P2=SHd308^;R`80
QXJ60P1oOgl207IfMP80K6a/0P1`L70506MWI`80MWIf0P1bLW8206e]K@80NGUi0P26QXH208^;R`<0
SHf=0P2DU9@209JFUP80Vi^K0P2OWil20::RXP80YjNW0P2[Zj/30;Fe]@80[jn_0P2[Zj/20;2`/080
];Bd0P2l_;`20;jn_P<0/;2`0P2PX:0209fMW@80W9bL0P2BTY8208^;R`80R8R80`27QhL208B4Q080
PX:20P1oOgl207alO080NGUi0P1fMWH307QhN080O7al0P1oOgl808:2PP<0Ph>30P2<S8`209BDU080
UYJF2038h=P000H0b>3H0P0/;2`202LW9`808b<S0`0U9BD202TY:@80;Bd]0P0`<302034a<@80<30`
1@0_;bl203De=@80>CTi0P0d=3@402l_;`80<30`1@0^;Rh202d];@80>SXj0P0a<C4202TY:@D09RHV
0P0T92@202<S8`808B4Q0P0S8b<202d];@80E5AD0P29RHT309JFUP80LW9b0P1ADE4206m_K`80VYZJ
0P31`L420<[:bP<0/;2`0P2SXj<20:JVYP80[:b/0P2b/[820;Rh^080_;bl0`30`<020<O7a`80bl_;
0P39bLT20<G5a@80b<S80P36a/H30:f][@80SXj>0P1aLG4205iNGP80I6AT0P1iNGT207alO0<0OGem
0P1nOWh207moO`80QHF50P22PX820820P080Ogmo0`28R8P2092@T080TY:B1P2?Shl208f=S@<0Rh^;
0P26QXH207moO`80MWIf0P1/K6`2071`L0D0IfMW0P1fMWH2079bLP80KFe]0P1iNGT208J6QP80Rh^;
0`2=SHd209BDU080UYJF0P2KVi/209nOW`80XZ:R0P2WYjL20:^[Z`<0]KFe0P2_[jl20:^[Z`80/;2`
0P2d];@20;bl_080_[jn0`2`/;020:2PX080WIfM0P2LW9`209:BTP80Rh^;0P28R8P308N7Q`80Q8B4
0P22PX8207moO`80O7al0P1iNGT207IfMP<0N7Qh0P1lO7`207moO`P0PX:20`23Ph<208b<S080U9BD
0P2FUYH80<SPf0001P38h=P202/[:`809bLW1@0T92@202LW9`80;2`/0P0a<C42038b<P80<C4a1@0`
<30203Xj>P80@D510P0k>c/203<c<`80;bl_0P0];Bd3030`<080=CDe0P0h>3P203Ti>@80=3@d0P0^
;Rh202TY:@<09RHV100S8b<202DU9@80:b/[0P0U9BD203Ti>@80Jf][0`2FUYH2092@T080GemO0P1W
IfL207]kN`80Zj^[0P3Bd]830;fm_@@0XJ6Q0P2WYjL20:j^[P80]KFe0P2i^KT30;bl_080`l?3103:
b/X20<S8b080a/K60P33`l<30<G5a@80_[jn0P2=SHd2061PH080GemO1`1iNGT207alO080OWin0P20
P80208:2PP80Ogmo0P1mOGd308N7Q`80TI6A0P2BTY8408n?S`80SHf=0P29RHT308>3P`80O7al0P1e
MGD206e]K@80Hf=S0P1WIfL205=CD`<0DE5A0P1`L70207emO@80R8R80P2<S8`208n?S`80UYJF0`2M
WId20:2PX080Y:BT0P2XZ:P20:j^[P80];Bd0P2k^k/20;no_`<0`L710P35aLD20<C4a080^[Zj0P2^
[Zh20:^[Z`80YjNW0`2MWId209:BTP80S8b<0P27QhL207]kN`80M7Ad0P1iNGT30820P080Ph>30P24
Q8@20820P080NWYj0P1gMgL207IfMP<0MgMg0P1jNWX207moO`80Q8B40P23Ph<40861P@<0Ph>30P2<
S8`209JFUP80V9RH2038h=P000H0b>3H0P0[:b/202LW9`D092@T0P0W9bL202`/;080<C4a0P0b<S82
034a<@D0<30`0P0j>SX20451@@80>c/k0P0c<c<202l_;`80;Bd]0`0`<30203De=@80>3Ph0P0i>CT2
03@d=080;Rh^0P0Y:BT302HV9P@08b<S0P0U9BD202/[:`809BDU0P0i>CT206][J`<0UYJF0P2@T902
05mOG`80IfMW0P1kNg/20:^[Z`80d];B0`2m_Kd40:6QX@80YjNW0P2^[Zh20;Fe]@80^KVi0`2l_;`2
0<?3``@0b/[:0P38b<P20<K6aP80`l?30`35aLD20;jn_P80SHf=0P1PH60205mOG`L0NGUi0P1lO7`2
07inOP80P8200P22PX8207moO`80OGem0`27QhL2096AT@80TY:B102?Shl208f=S@80RHV90`23Ph<2
07alO080MGEe0P1]KFd206=SH`80IfMW0P1CDe<3055AD@80L71`0P1mOGd208R8R080S8b<0P2?Shl2
09JFUP<0WIfM0P2PX:020:BTY080Z:RX0P2^[Zh20;Bd]080^k^k0P2o_kl30<71`@80aLG50P34a<@2
0;Zj^P80[Zj^0P2[Zj/20:NWY`<0WIfM0P2BTY8208b<S080QhN70P1kNg/207AdM080NGUi0`20P802
08>3P`80Q8B40P20P80207YjNP80MgMg0P1fMWH307MgM`80NWYj0P1oOgl208B4Q080Ph>31021PH43
08>3P`80S8b<0P2FUYH209RHV0P0b>3H00060<SPf0@0:b/[0P0Z:RX302TY:@80:2PX0P0];Bd2038b
<P@0=3@d0P0a<C4302l_;`80<S8b100n?Sh2030`<080<S8b0P0e=CD3034a<@80;Rh^0P0b<S8203@d
=080=SHf0P0Y:BT502PX:0809RHV0P0S8b<2024Q8@807alO0P0i>CT202`/;080E5AD0`24Q8@209ZJ
VP80Ng]k0P1QHF4206ATI080RHV90P30`<030<71`@80WYjN0P2FUYH20:>SX`80[Jf]0P2g]kL50;Rh
^080_kno0P37alL40<S8b080alO70P35aLD30<S8b080aLG50P2][Jd209:BTP80Lg=c0P1UIFD206m_
K`<0OWin0P1oOgl207alO080Ng]k101lO7`207emO@<0QXJ60P2@T90208^;R`80Shn?0P2<S8`208R8
R080Ogmo0`1eMGD206QXJ080G5aL101IFET206=SH`80HF5Q0`1UIFD207YjNP80Ph>30P2:RXX208N7
Q`80PX:20P23Ph<308R8R080T92@0P2LW9`20:f][@80_;bl0P31`L420<?3``80alO70`38b<P20<_;
b`@0cLg=0P38b<P20;Bd]080WinO0`2ATI4208Z:RP80TY:B0P2FUYH208b<S080L71`0P1cLg<307al
O080PH610P23Ph<207emO@@0MWIf0P1gMgL307UiN@80O7al0P1oOgl20861P@H0PX:20`24Q8@208b<
S080Ti>C0P2DU9@80<SPf0001P38h=P402/[:`80:RXZ0`0Y:BT202PX:080;Bd]0P0b<S8403@d=080
<C4a0`0_;bl2038b<P@0?Shn0P0`<302038b<P80=CDe0`0a<C4202h^;P80<S8b0P0d=3@203Hf=P80
:BTY1@0X:2P202HV9P808b<S0P0Q8B4201lO7`80>CTi0P0/;2`205ADE0<0Q8B40P2JVYX207]kN`80
HF5Q0P1TI6@208V9R@80`<300`31`L4209jNWP80UYJF0P2SXj<20:f][@80]kNg1@2h^;P20;no_`80
alO71038b<P20<O7a`80aLG50`38b<P20<G5a@80[Jf]0P2BTY8207=cL`80IFEU0P1_Kfl307inOP80
Ogmo0P1lO7`207]kN`@0O7al0P1mOGd308J6QP80T92@0P2;Rh/208n?S`80S8b<0P28R8P207moO`<0
MGEe0P1XJ6P205aLG0@0FEUI0P1SHf<2065QH@<0IFEU0P1jNWX208>3P`80RXZ:0P27QhL208:2PP80
Ph>30`28R8P2092@T080W9bL0P2][Jd20;bl_080`L710P33`l<20<O7a`<0b<S80P3;bl/40<g=c@80
b<S80P2d];@209nOW`<0TI6A0P2:RXX209:BTP80UYJF0P2<S8`2071`L080Lg=c0`1lO7`20861P@80
Ph>30P1mOGd407IfMP80MgMg0`1iNGT207alO080Ogmo0P21PH4608:2PP<0Q8B40P2<S8`209>CT`80
U9BD2038h=P000H0b>3H0P0/;2`202h^;P80<30`0`0];Bd202XZ:P80;Rh^0P0d=3@203Xj>P80?Shn
0P0e=CD302d];@80:BTY0P0g=cL20410@080;Rh^0P0Y:BT202DU9@<09bLW0P0Z:RX202h^;P80;bl_
0P0f=SH202<S8`809bLW0`0[:b/202LW9`808R8R0P0Q8B4202@T9080:RXZ0P0f=SH203`l?0<0F5QH
0P2:RXX209JFUP80I6AT0P1FEUH206MWI`80Xj>S0`34a<@20:^[Z`80UYJF0P2OWil20:ZZZP80]kNg
0P2f][H30;Fe]@80^k^k0P33`l<20<K6aPH0alO70`35aLD20<;2`P80alO70P33`l<209ZJVP80Kfm_
0P1[Jf/3075aL@80MGEe0P1iNGT207QhN080MWIf0P1iNGT207inOP<0QHF50P2<S8`208:2PP80SHf=
0P27QhL207moO`80Lg=c0`1VIVH2055AD@80@D510P15ADD2055AD@80HV9R0P1dM7@307IfMP80Lg=c
0P1nOWh208F5Q@80NWYj0P1]KFd206IVIP<0IfMW0P1dM7@208V9R@80Y:BT0P2l_;`20<C4a080alO7
0P3:b/X30<c<c080clo?0P3AdM420<o?c`80b/[:0P30`<020;:b/P<0Vi^K0P27QhL208b<S0@0TI6A
0P1`L70207=cL`<0NWYj0P1mOGd207inOP80NGUi0P1cLg<207AdM080N7Qh0`1jNWX207alO080OGem
0P1nOWh20861P@80Ph>30P24Q8@308J6QP80Rh^;0P2@T902096AT@P0b>3H00060<SPf080;2`/0P0^
;Rh2030`<0<0;Bd]0P0Z:RX202h^;P80=3@d0P0j>SX203hn?P80=CDe0`0];Bd202TY:@80=cLg0P10
@40202h^;P80:BTY0P0U9BD302LW9`80:RXZ0P0^;Rh202l_;`80=SHf0P0S8b<202LW9`<0:b/[0P0W
9bL2028R8P808B4Q0P0T92@202XZ:P80=SHf0P0l?3`305QHF080RXZ:0P2FUYH206ATI080EUIF0P1W
IfL20:>SX`<0a<C40P2[Zj/209JFUP80WinO0P2ZZZX20;Ng]`80][Jf0`2e]KD20;^k^`80`l?30P36
a/H60<O7a`<0aLG50P32`/820<O7a`80`l?30P2JVYX206m_K`80Jf][0`1aLG4207EeM@80NGUi0P1h
N7P207IfMP80NGUi0P1nOWh308F5Q@80S8b<0P22PX8208f=S@80QhN70P1oOgl207=cL`<0IVIV0P1A
DE420451@@80ADE50P1ADE42069RHP80M7Ad0`1fMWH207=cL`80OWin0P25QHD207YjNP80KFe]0P1V
IVH306MWI`80M7Ad0P29RHT20:BTY080_;bl0P34a<@20<O7a`80b/[:0`3<c<`20<o?c`80dM7A0P3?
cll20<[:bP80`<300P2b/[8309^KV`80QhN70P2<S8`4096AT@80L71`0P1cLg<307YjNP80OGem0P1n
OWh207UiN@80Lg=c0P1dM7@207QhN0<0NWYj0P1lO7`207emO@80OWin0P21PH4208>3P`80Q8B40`26
QXH208^;R`80T92@0P2ATI480<SPf0001P38h=P203`l?080=SHf0P0[:b/302TY:@80:RXZ0P0^;Rh2
03De=@80@d=30P1@D5020410@0<0:RXZ0P0Y:BT203De=@80>SXj0P0a<C4202d];@80:2PX0`0Y:BT2
02/[:`80<30`0P0b<S8203@d=0809bLW0P0Y:BT302/[:`809bLW100T92@202LW9`80;2`/0P0`<302
02h^;P<0?clo0P1[Jf/209NGU`80OGem0P1IFET205=CD`80PX:20`2^[Zh20;Vi^@80WinO0P2EUID2
09nOW`80[Jf]0P2`/;030;6a/@80_;bl0P2n_[h20<?3``80alO71038b<P30<K6aP80a<C41039bLT2
0;Fe]@80VIVI0P1nOWh306UYJ@80IfMW0P1eMGD407MgM`80O7al1`22PX8207emO@80Ph>30P1mOGd2
07=cL`80Jf][0`1FEUH20451@@80<C4a0P0h>3P204Y:BP80GEeM0P1_Kfl307MgM`80NWYj0P1iNGT2
075aL@80G5aL0P1@D50204A4A0<0@4100P1<C4`2061PH080Ogmo0P2PX:020;bl_080cLg=0P3>c/h3
0<g=c@80d=3@0P3AdM420=3@d080c<c<0P35aLD20;Vi^@<0YZJV0P2BTY8208Z:RP80Ph>30P1nOWh2
06QXJ080MgMg0`1mOGd207YjNP80LW9b0P1aLG4207=cL`80MgMg0P1jNWX307UiN@80MgMg0P1kNg/2
07moO`80PX:20P25QHD208N7Q`<0RHV90P2>SXh209:BTP80V9RH2038h=P000H0b>3H0P0l?3`203Hf
=P80:b/[0`0Y:BT202XZ:P80;Rh^0P0e=CD204=3@`80D51@0P10@40302XZ:P80:BTY0P0e=CD203Xj
>P80<C4a0P0];Bd202PX:0<0:BTY0P0[:b/2030`<080<S8b0P0d=3@202LW9`80:BTY0`0[:b/202LW
9`@092@T0P0W9bL202`/;080<30`0P0^;Rh303lo?`80Jf][0P2GUiL207emO@80FEUI0P1CDe<208:2
PP<0[Zj^0P2i^KT209nOW`80UIFE0P2OWil20:f][@80/;2`0`2a/K420;bl_080_[jn0P33`l<20<O7
a`@0b<S80`36a/H20<C4a0@0bLW90P2e]KD209VIV@80OWin0`1YJFT206MWI`80MGEe101gMgL207al
O0L0PX:20P1mOGd208>3P`80OGem0P1cLg<206][J`<0EUIF0P11@D42034a<@80>3Ph0P1:BTX205eM
G@80Kfm_0`1gMgL207YjNP80NGUi0P1aLG4205aLG080D51@0P14A4@30410@080C4a<0P1PH60207mo
O`80X:2P0P2l_;`20<g=c@80c/k>0`3=cLd20=3@d080dM7A0P3@d=020<c<c080aLG50P2i^KT30:JV
YP80TY:B0P2:RXX208>3P`80OWin0P1XJ6P207MgM`<0OGem0P1jNWX2079bLP80LG5a0P1cLg<207Mg
M`80NWYj0`1iNGT207MgM`80Ng]k0P1oOgl208:2PP80QHF50P27QhL308V9R@80SXj>0P2BTY8209RH
V0P0b>3H00060<SPf080>3Ph0P0a<C4202LW9`<09RHV0P0Y:BT202`/;080=SHf0P1GEeL2075aL@80
DE5A0`0Y:BT202XZ:P80<S8b100c<c<202l_;`D0:b/[0P0];Bd203<c<`80=cLg0P0a<C4202`/;0D0
:RXZ0P0X:2P202LW9`80:2PX0P0Z:RX202/[:`80;2`/0P0W9bL302`/;080@D510P1lO7`208Z:RP80
IVIV0P1?Cdl206MWI`<0QXJ60P2WYjL209nOW`80TY:B0P2KVi/20:FUY@80ZJVY0`2][Jd20;Zj^P80
^;Rh0P2o_kl20<G5a@@0b<S80`37alL20<K6aP80a<C40P33`l<20<W9b@80aLG50P2HV9P306][J`80
H61P0P1aLG4207AdM080N7Qh0P1nOWh208:2PP<0OGem101fMWH207EeM@80Kfm_0P1UIFD2061PH0<0
AdM70P0d=3@202LW9`80<C4a0P15ADD205QHF080JFUY0`1eMGD207]kN`80KVi^0P1KFe/203lo?`80
>SXj0P0h>3P303/k>`80>CTi0P0m?Cd204m?C`80Jf][0P2NWYh20<[:bP80d=3@0`3>c/h40=3@d080
c/k>0P3:b/X20<S8b080`/;20`2a/K4209fMW@80QHF50P1_Kfl206EUI@80HV9R0P1kNg/307inOP80
M7Ad0P1WIfL206][J`80Lg=c0P1hN7P207]kN`<0MWIf0P1bLW8207QhN080P8200P24Q8@208J6QP80
RHV90`2;Rh/2092@T080U9BD0P2NWYh80<SPf0001P38h=P203Ph>080<C4a0P0W9bL302HV9P80:BTY
0P0/;2`203Hf=P80EeMG0P1aLG42055AD@<0:BTY0P0Z:RX2038b<P@0<c<c0P0_;bl502/[:`80;Bd]
0P0c<c<203Lg=`80<C4a0P0/;2`502XZ:P80:2PX0P0W9bL202PX:080:RXZ0P0[:b/202`/;0809bLW
0`0/;2`20451@@80O7al0P2:RXX206IVIP80Cdm?0P1WIfL308J6QP80YjNW0P2OWil209:BTP80Vi^K
0P2UYJD20:VYZ@<0[Jf]0P2j^[X20;Rh^080_kno0P35aLD40<S8b0<0alO70P36a/H20<C4a080`l?3
0P39bLT20<G5a@80V9RH0`1[Jf/2061PH080LG5a0P1dM7@207QhN080OWin0P22PX8307emO@@0MWIf
0P1eMGD206m_K`80IFEU0P1PH60304M7A`80=3@d0P0W9bL2034a<@80ADE50P1HF5P206UYJ@<0MGEe
0P1kNg/206i^KP80Fe]K0P0o?cl203Xj>P80>3Ph0`0k>c/203Ti>@80?Cdm0P1?Cdl206][J`80WYjN
0P3:b/X20=3@d0<0c/k>103@d=020<k>cP80b/[:0P38b<P20<;2`P<0/K6a0P2MWId208F5Q@80Kfm_
0P1UIFD2069RHP80Ng]k0`1nOWh207AdM080IfMW0P1[Jf/207=cL`80N7Qh0P1kNg/307IfMP80LW9b
0P1hN7P20820P080Q8B40P26QXH208V9R@<0Rh^;0P2@T90209BDU080WYjN2038h=P000H0b>3H0P0j
>SX202d];@80:2PX0`0V9RH202PX:080<30`0P0j>SX206QXJ080NGUi0P1>CTh303<c<`80;Bd]0P0^
;Rh202d];@80;bl_0P0];Bd202`/;0<0:b/[0P0/;2`203<c<`80>3Ph0P0a<C4202XZ:P80:2PX1@0Y
:BT202XZ:P80:BTY0P0W9bL402PX:0D092@T0P0a<C4205UIF@80MWIf0P1`L70205MGE`80FUYJ0`1j
NWX209jNWP80[Zj^0P2QXJ4209FEU@@0UYJF0`2GUiL20:JVYP80[Zj^0P2f][H20;fm_@80`l?30P37
alL50<W9b@80a/K60P34a<@20<W9b@80b/[:0P2d];@309RHV080MgMg0P1WIfL206IVIP80Lg=c0P1l
O7`207YjNP<0Lg=c0P1ZJVX206MWI`80Hf=S0P1MGEd205ADE080Bd];0`0i>CT2038b<P80<30`0P15
ADD2051@D080GEeM0P1_Kfl307YjNP80Lg=c0P1BDU8203dm?@80?3`l0P1<C4`205ADE0<0FEUI0P1B
DU8204Q8B080>SXj0P12@T8206UYJ@80ZJVY0P3>c/h30=7Ad@80d=3@0P3Bd]820<o?c`@0cLg=0P39
bLT30;Jf]P80WYjN0P1jNWX205aLG080De=C0P1UIFD207inOP<0MWIf0P1WIfL2065QH@80K6a/0P1`
L70207AdM080MGEe1@1dM7@207UiN@80OWin0P23Ph<208J6QP80QhN70`29RHT2092@T080UiNG0P2L
W9`80<SPf0001P38h=P203Xj>P80;Bd]0P0X:2P302HV9P80:2PX0P0`<30203Xj>P80J6QX0P1iNGT2
04i>CP<0<c<c0P0];Bd202h^;P80;Bd]0P0_;bl202d];@80;2`/0`0[:b/202`/;080<c<c0P0h>3P2
034a<@80:RXZ0P0X:2P502TY:@80:RXZ0P0Y:BT202LW9`@0:2PX1@0T92@2034a<@80FEUI0P1fMWH2
071`L080EeMG0P1JFUX307YjNP80WYjN0P2^[Zh20:6QX@80UIFE102FUYH309NGU`80YZJV0P2^[Zh2
0;Jf]P80_Kfm0P33`l<20<O7a`D0bLW90P36a/H20<C4a080bLW90P3:b/X20;Bd]0<0V9RH0P1gMgL2
06MWI`80IVIV0P1cLg<207alO080NWYj0`1cLg<206YZJP80IfMW0P1SHf<205eMG@80E5AD0P1;Bd/3
03Ti>@80<S8b0P0`<30204E5A@80D51@0P1MGEd206m_K`<0NWYj0P1cLg<2059BDP80?Cdm0P0l?3`2
04a<C080E5AD0`1IFET2059BDP80B4Q80P0j>SX20492@P80JFUY0P2YZJT20<k>cP<0dM7A0P3@d=02
0=;BdP80clo?103=cLd20<W9b@<0][Jf0P2NWYh207YjNP80G5aL0P1CDe<206EUI@80OWin0`1fMWH2
06MWI`80HF5Q0P1/K6`2071`L080M7Ad0P1eMGD507AdM080NGUi0P1nOWh208>3P`80QXJ60P27QhL3
08V9R@80T92@0P2GUiL209bLW0P0b>3H00060<SPf080>3Ph0P0Y:BT202/[:`D09RHV0P0d=3@204=3
@`80NWYj0P1hN7P204M7A`<0?Shn0P0_;bl202XZ:P80:2PX0P0Z:RX202/[:`80;2`/0`0Z:RX202/[
:`80<c<c0P0h>3P2034a<@809bLW0P0V9RH302PX:080:RXZ0P0/;2`202TY:@@09BDU0P0V9RH202<S
8`<092@T0P0b<S8204M7A`80JVYZ0P25QHD206m_K`80F5QH0`1`L70208j>SP80_Kfm0P31`L420:ZZ
ZP80XZ:R0P2IVIT309BDU080Vi^K0P2WYjL20:j^[P80]KFe0P2m_Kd20<G5a@<0bLW90P3<c<`20<W9
b@H0aLG50P3:b/X30<G5a@80UiNG0P1XJ6P205aLG080Jf][0P1fMWH206i^KP<0J6QX0P1NGUh205MG
E`80D51@0P1;Bd/204I6AP80>CTi0`0_;bl202/[:`80;2`/0P15ADD204Y:BP80Fe]K0P1eMGD307]k
N`80HV9R0P11@D4203dm?@80Cdm?0P1SHf<205eMG@<0E5AD0P1GEeL205QHF080@T920P0k>c/204A4
A080P8200P36a/H30=;BdP80clo?0P3Bd]820=3@d080c/k>0P3?cll20<[:bP<0];Bd0P2GUiL206a/
K080C4a<0P18B4P206][J`80OWin0`1ZJVX205aLG080HF5Q0P1`L70206i^KP@0Kfm_0`1cLg<207Mg
M`80NWYj0P1mOGd208:2PP80QXJ60P27QhL308R8R080T92@0P2GUiL209RHV0P0b>3H00060<SPf080
>3Ph0P0Y:BT202/[:`D09RHV0P0d=3@204=3@`80NWYj0P1hN7P204M7A`<0?Shn0P0_;bl202XZ:P80
:2PX0P0Z:RX202/[:`80;2`/0`0Z:RX202/[:`80<c<c0P0h>3P2034a<@809bLW0P0V9RH302PX:080
:RXZ0P0/;2`202TY:@@09BDU0P0V9RH202<S8`<092@T0P0b<S8204M7A`80JVYZ0P25QHD206m_K`80
F5QH0`1`L70208j>SP80_Kfm0P31`L420:ZZZP80XZ:R0P2IVIT309BDU080Vi^K0P2WYjL20:j^[P80
]KFe0P2m_Kd20<G5a@<0bLW90P3<c<`20<W9b@H0aLG50P3:b/X30<G5a@80UiNG0P1XJ6P205aLG080
Jf][0P1fMWH206i^KP<0J6QX0P1NGUh205MGE`80D51@0P1;Bd/204I6AP80>CTi0`0_;bl202/[:`80
;2`/0P15ADD204Y:BP80Fe]K0P1eMGD307]kN`80HV9R0P11@D4203dm?@80Cdm?0P1SHf<205eMG@<0
E5AD0P1GEeL205QHF080@T920P0k>c/204A4A080P8200P36a/H30=;BdP80clo?0P3Bd]820=3@d080
c/k>0P3?cll20<[:bP<0];Bd0P2GUiL206a/K080C4a<0P18B4P206][J`80OWin0`1ZJVX205aLG080
HF5Q0P1`L70206i^KP@0Kfm_0`1cLg<207MgM`80NWYj0P1mOGd208:2PP80QXJ60P27QhL308R8R080
T92@0P2GUiL209RHV0P0b>3H00060<SPf080>3Ph0P0Y:BT202/[:`D09RHV0P0d=3@204=3@`80NWYj
0P1hN7P204M7A`<0?Shn0P0_;bl202XZ:P80:2PX0P0Z:RX202/[:`80;2`/0`0Z:RX202/[:`80<c<c
0P0h>3P2034a<@809bLW0P0V9RH302PX:080:RXZ0P0/;2`202TY:@@09BDU0P0V9RH202<S8`<092@T
0P0b<S8204M7A`80JVYZ0P25QHD206m_K`80F5QH0`1`L70208j>SP80_Kfm0P31`L420:ZZZP80XZ:R
0P2IVIT309BDU080Vi^K0P2WYjL20:j^[P80]KFe0P2m_Kd20<G5a@<0bLW90P3<c<`20<W9b@H0aLG5
0P3:b/X30<G5a@80UiNG0P1XJ6P205aLG080Jf][0P1fMWH206i^KP<0J6QX0P1NGUh205MGE`80D51@
0P1;Bd/204I6AP80>CTi0`0_;bl202/[:`80;2`/0P15ADD204Y:BP80Fe]K0P1eMGD307]kN`80HV9R
0P11@D4203dm?@80Cdm?0P1SHf<205eMG@<0E5AD0P1GEeL205QHF080@T920P0k>c/204A4A080P820
0P36a/H30=;BdP80clo?0P3Bd]820=3@d080c/k>0P3?cll20<[:bP<0];Bd0P2GUiL206a/K080C4a<
0P18B4P206][J`80OWin0`1ZJVX205aLG080HF5Q0P1`L70206i^KP@0Kfm_0`1cLg<207MgM`80NWYj
0P1mOGd208:2PP80QXJ60P27QhL308R8R080T92@0P2GUiL209RHV0P0b>3H00060<SPf080<30`0P0_
;bl202d];@<09bLW0P0X:2P203@d=080E5AD0P23Ph<205QHF080=CDe0`11@D42038b<P80:BTY0P0V
9RH202LW9`80:BTY1`0/;2`203<c<`80=cLg0P0a<C4202XZ:P809bLW0`0V9RH2034a<@80>CTi0P0b
<S8202XZ:P@09bLW0P0X:2P303Hf=P80ATI60P1;Bd/2065QH@80SXj>0P2ATI4207=cL`<0I6AT0P1c
Lg<20:VYZ@80b<S80P2l_;`20:RXZ080XJ6Q1@2/[:`20:j^[P80/[:b0P2g]kL20;Zj^P80_[jn0`36
a/H20<g=c@80bl_;0P38b<P40<O7a`80cLg=0`3;bl/20;:b/P80TI6A0P1YJFT205QHF080Hf=S0P1W
IfL3065QH@80EUIF0P1<C4`20492@P80>CTi0P0a<C4502h^;P80;Bd]0P0_;bl20451@@80BTY:0P1N
GUh2075aL@<0Jf][0P18B4P203lo?`80FUYJ0P1LG5`205YJFP80Bd];0`0o?cl204Q8B080FUYJ0P1W
IfL204];B`80>3Ph0P1HF5P20;6a/@<0clo?103=cLd40<k>cP80b/[:0P31`L430:RXZ080Ogmo0P1K
Fe/204E5A@80EUIF0P1lO7`207QhN0<0GEeM0P1LG5`206YZJP80Lg=c0P1bLW82071`L080Kfm_0`1e
MGD207alO080Ogmo0P20P80208B4Q080QhN70P29RHT308^;R`80Shn?0P2BTY8209RHV0P0b>3H0006
0<SPf080<30`0P0_;bl202d];@<09bLW0P0X:2P203@d=080E5AD0P23Ph<205QHF080=CDe0`11@D42
038b<P80:BTY0P0V9RH202LW9`80:BTY1`0/;2`203<c<`80=cLg0P0a<C4202XZ:P809bLW0`0V9RH2
034a<@80>CTi0P0b<S8202XZ:P@09bLW0P0X:2P303Hf=P80ATI60P1;Bd/2065QH@80SXj>0P2ATI42
07=cL`<0I6AT0P1cLg<20:VYZ@80b<S80P2l_;`20:RXZ080XJ6Q1@2/[:`20:j^[P80/[:b0P2g]kL2
0;Zj^P80_[jn0`36a/H20<g=c@80bl_;0P38b<P40<O7a`80cLg=0`3;bl/20;:b/P80TI6A0P1YJFT2
05QHF080Hf=S0P1WIfL3065QH@80EUIF0P1<C4`20492@P80>CTi0P0a<C4502h^;P80;Bd]0P0_;bl2
0451@@80BTY:0P1NGUh2075aL@<0Jf][0P18B4P203lo?`80FUYJ0P1LG5`205YJFP80Bd];0`0o?cl2
04Q8B080FUYJ0P1WIfL204];B`80>3Ph0P1HF5P20;6a/@<0clo?103=cLd40<k>cP80b/[:0P31`L43
0:RXZ080Ogmo0P1KFe/204E5A@80EUIF0P1lO7`207QhN0<0GEeM0P1LG5`206YZJP80Lg=c0P1bLW82
071`L080Kfm_0`1eMGD207alO080Ogmo0P20P80208B4Q080QhN70P29RHT308^;R`80Shn?0P2BTY82
09RHV0P0b>3H00060<SPf080:BTY0P0e=CD202h^;P<0:BTY0P0[:b/203<c<`80IVIV0P2?Shl204Y:
BP80<30`0`0n?Sh2038b<P80:RXZ0P0V9RH202DU9@80:2PX0P0/;2`302d];@80;Rh^0P0b<S8203Hf
=P80<c<c0P0^;Rh202/[:`<0:2PX0P0];Bd2038b<P@0<c<c0P0/;2`202PX:080;Rh^0`19BDT204a<
C080>3Ph0P0j>SX2075aL@80WIfM0P2ATI4306ATI080G5aL0P2=SHd20<;2`P80c<c<0P2c/k<20:>S
X`<0/K6a0P2c/k<20;Rh^080^KVi0P2j^[X40;Ng]`<0`/;20P3<c<`20<g=c@@0b/[:1039bLT50<K6
aP80_;bl0P1mOGd205ADE080EEEE0P1PH60305]KF`80DE5A0P14A4@203Ti>@80=SHf0P0e=CD2034a
<@D0;Rh^0P0a<C4203Ti>@80ATI60P1LG5`206UYJ@<0FEUI0P0a<C4203Hf=P80HF5Q0P1JFUX204];
B`80=SHf0`0V9RH202XZ:P80A4A40P1bLW8204e=C@80=3@d0P11@D420:2PX0<0bl_;0P3:b/X20<K6
aP@0bLW90P2o_kl20:j^[P<0TY:B0P1RHV8204Y:BP80@D510P1TI6@208F5Q@80K6a/0`1ADE42061P
H080M7Ad101gMgL207=cL`80LG5a0`1hN7P20861P@80Ph>30P24Q8@208N7Q`80RXZ:0P2<S8`508j>
SP80SHf=0P2IVIT80<SPf0001P38h=P202TY:@80=CDe0P0^;Rh302TY:@80:b/[0P0c<c<206IVIP80
Shn?0P1:BTX2030`<0<0?Shn0P0b<S8202XZ:P809RHV0P0U9BD202PX:080;2`/0`0];Bd202h^;P80
<S8b0P0f=SH203<c<`80;Rh^0P0[:b/302PX:080;Bd]0P0b<S8403<c<`80;2`/0P0X:2P202h^;P<0
BDU90P1<C4`203Ph>080>SXj0P1aLG4209fMW@80TI6A0`1TI6@205aLG080SHf=0P32`/820<c<c080
/k>c0P2SXj<30;6a/@80/k>c0P2h^;P20;Vi^@80^[Zj102g]kL30<;2`P80c<c<0P3=cLd40<[:bP@0
bLW91@36a/H20;bl_080OGem0P1DE5@205EEE@80H61P0`1KFe/2055AD@80A4A40P0i>CT203Hf=P80
=CDe0P0a<C4502h^;P80<C4a0P0i>CT204I6AP80G5aL0P1YJFT305UIF@80<C4a0P0f=SH2065QH@80
FUYJ0P1;Bd/203Hf=P<09RHV0P0Z:RX204A4A080LW9b0P1=CDd203@d=080@D510P2PX:030<_;b`80
b/[:0P36a/H40<W9b@80_kno0P2^[Zh309:BTP80HV9R0P1:BTX20451@@80I6AT0P25QHD206a/K0<0
DE5A0P1PH60207AdM0@0MgMg0P1cLg<2075aL@<0N7Qh0P21PH4208>3P`80Q8B40P27QhL208Z:RP80
S8b<1@2>SXh208f=S@80VIVI2038h=P000H0b>3H0P0[:b/2038b<P80;Bd]0`0W9bL202h^;P80>c/k
0P1gMgL207emO@80>CTi0P0/;2`303De=@80<30`0P0];Bd202XZ:P80:2PX0P0Z:RX502d];@80;Rh^
100`<302034a<@80<c<c0P0X:2P302`/;080=3@d0P14A4@204Y:BP80@d=30P0i>CT203Ph>080:2PX
1@0U9BD2020P8080:2PX0P1CDe<208b<S080WYjN0`20P80205eMG@80LG5a0P2OWil20<?3``80`L71
0P2YZJT30:b/[080[jn_0P2d];@20;Jf]P80]kNg102e]KD30;^k^`80`l?30P39bLT20<g=c@80bl_;
0P37alL20<K6aP<0aLG50P3=cLd20<O7a`80]kNg0P1/K6`4055AD@<0E5AD0P1EEED204a<C080@T92
0P0k>c/203Hf=P80;bl_1@0[:b/202h^;P80=3@d0P0m?Cd204m?C`80FEUI0`1@D502034a<@80>SXj
0P1BDU8204E5A@80<c<c0P0X:2P302@T90807alO0P0l?3`205UIF@80?clo0P0g=cL204M7A`80WYjN
0`3?cll20=3@d080aLG50P33`l<20;^k^`80/[:b0P2:RXX306YZJP80@d=30P0k>c/203dm?@80GEeM
0P1ZJVX205ADE0<0CDe=0P1SHf<207]kN`80O7al0P1jNWX207IfMP80M7Ad0`1jNWX20861P@80Q8B4
0P26QXH208R8R080Rh^;0P2>SXh3092@T0@0TI6A0P2GUiL80<SPf0001P38h=P202/[:`80<S8b0P0]
;Bd302LW9`80;Rh^0P0k>c/207MgM`80OGem0P0i>CT202`/;0<0=CDe0P0`<30202d];@80:RXZ0P0X
:2P202XZ:PD0;Bd]0P0^;Rh4030`<080<C4a0P0c<c<202PX:0<0;2`/0P0d=3@204A4A080BTY:0P13
@d<203Ti>@80>3Ph0P0X:2P502DU9@80820P0P0X:2P205=CD`80S8b<0P2NWYh30820P080GEeM0P1a
LG4209nOW`80`l?30P31`L420:VYZ@<0[:b/0P2_[jl20;Bd]080][Jf0P2g]kL40;Fe]@<0^k^k0P33
`l<20<W9b@80cLg=0P3;bl/20<O7a`80a/K60`35aLD20<g=c@80alO70P2g]kL206a/K0@0DE5A0`1D
E5@205EEE@80C4a<0P12@T8203/k>`80=SHf0P0_;bl502/[:`80;Rh^0P0d=3@203dm?@80Cdm?0P1I
FET3051@D080<C4a0P0j>SX2059BDP80ADE50P0c<c<202PX:0<092@T0P0O7al203`l?080FEUI0P0o
?cl203Lg=`80AdM70P2NWYh30<o?c`80d=3@0P35aLD20<?3``80^k^k0P2b/[8208Z:RP<0JVYZ0P13
@d<203/k>`80?Cdm0P1MGEd206YZJP80E5AD0`1=CDd206=SH`80Ng]k0P1lO7`207YjNP80MWIf0P1d
M7@307YjNP80PH610P24Q8@208J6QP80R8R80P2;Rh/208j>SP<0T92@102ATI4209NGU`P0b>3H0006
0<SPf0@0;bl_0P0`<30302XZ:P80<C4a0P16ATH208>3P`80IFEU0P0^;Rh202XZ:P<0;Bd]0P0^;Rh2
02l_;`80;Rh^100/;2`702d];@80<30`0P0b<S8203Hf=P80?3`l0P0[:b/303Hf=P80>CTi0P1>CTh2
05YJFP80Cdm?0P0a<C4202XZ:P809RHV0`0U9BD2020P80807alO0P0T92@2038b<P80KFe]0P2NWYh3
09bLW080JVYZ0P1NGUh207QhN080/K6a0P39bLT20;2`/0<0YJFU0P2WYjL20:j^[P80/K6a102c/k<2
0;Bd]0<0]KFe0P2i^KT20<G5a@80clo?0P3;bl/20<C4a080`l?30`34a<@40<K6aP80`L710P2a/K42
06UYJ@80CTi>0`1?Cdl205UIF@80E5AD0P1=CDd204A4A080>SXj0P0`<30302XZ:P80:BTY0P0/;2`2
02l_;`80=CDe0P11@D4204Q8B0<0@4100P0X:2P203<c<`80?Cdm0P0h>3P2030`<0809RHV0`0U9BD2
02`/;080FEUI0P1FEUH204=3@`80FEUI0P1hN7P20:j^[PD0c<c<0P2m_Kd20;Fe]@80Xj>S0P2LW9`2
06=SH`<0@d=30P0[:b/202l_;`80>SXj0P1?Cdl204];B`80?Shn0`1>CTh206IVIP80Ogmo0P21PH42
07alO080NWYj0P1hN7P307]kN`80PH610P24Q8@208N7Q`80RXZ:0P2<S8`208n?S`<0TI6A0P2DU9@4
09JFUPP0b>3H00060<SPf0@0;bl_0P0`<30302XZ:P80<C4a0P16ATH208>3P`80IFEU0P0^;Rh202XZ
:P<0;Bd]0P0^;Rh202l_;`80;Rh^100/;2`702d];@80<30`0P0b<S8203Hf=P80?3`l0P0[:b/303Hf
=P80>CTi0P1>CTh205YJFP80Cdm?0P0a<C4202XZ:P809RHV0`0U9BD2020P80807alO0P0T92@2038b
<P80KFe]0P2NWYh309bLW080JVYZ0P1NGUh207QhN080/K6a0P39bLT20;2`/0<0YJFU0P2WYjL20:j^
[P80/K6a102c/k<20;Bd]0<0]KFe0P2i^KT20<G5a@80clo?0P3;bl/20<C4a080`l?30`34a<@40<K6
aP80`L710P2a/K4206UYJ@80CTi>0`1?Cdl205UIF@80E5AD0P1=CDd204A4A080>SXj0P0`<30302XZ
:P80:BTY0P0/;2`202l_;`80=CDe0P11@D4204Q8B0<0@4100P0X:2P203<c<`80?Cdm0P0h>3P2030`
<0809RHV0`0U9BD202`/;080FEUI0P1FEUH204=3@`80FEUI0P1hN7P20:j^[PD0c<c<0P2m_Kd20;Fe
]@80Xj>S0P2LW9`206=SH`<0@d=30P0[:b/202l_;`80>SXj0P1?Cdl204];B`80?Shn0`1>CTh206IV
IP80Ogmo0P21PH4207alO080NWYj0P1hN7P307]kN`80PH610P24Q8@208N7Q`80RXZ:0P2<S8`208n?
S`<0TI6A0P2DU9@409JFUPP0b>3H00060<SPf080<30`0P0^;Rh503`l?080<S8b0P1EEED208R8R080
E5AD0P0Z:RX202TY:@<0<30`0P0_;bl202d];@80;2`/100Z:RX202/[:`D0:BTY0P0e=CD204i>CP80
GUiN0P1PH602059BDP<0DE5A0P1GEeL206a/K080FEUI0P0h>3P202TY:@80:b/[0P0V9RH3024Q8@80
7alO0P0Q8B4201lO7`809bLW0P1?Cdl208Z:RP<0WinO0P29RHT2069RHP80Hf=S0P2GUiL20;jn_P80
`L710`2`/;020:FUY@80Zj^[0P2/[:`20:n_[`80/K6a0P2d];@30;Jf]P80^KVi0P34a<@20<g=c@80
bl_;0P36a/H20<G5a@<0a<C40P2o_kl20;^k^`80b<S80P34a<@20:b/[080HV9R0`14A4@204Q8B080
Cdm?0P1;Bd/204Y:BP80ADE50P0m?Cd302d];@80;2`/0P0^;Rh202l_;`80<C4a0P0f=SH203Ti>@<0
=cLg0P0^;Rh203<c<`80=CDe0P0b<S8202d];@D0:BTY0P0];Bd204A4A080@D510P0n?Sh205]KF`80
Ogmo0P2TY:@30;^k^`80_Kfm0P2_[jl209NGU`80MgMg0P1SHf<203Xj>P<0;Bd]0P0X:2P402HV9P80
;2`/0P0Z:RX203Lg=`<0EEEE0P1^KVh208>3P`80QHF50P22PX8207inOP80O7al0`1nOWh208:2PP80
QHF50P29RHT208Z:RP80S8b<0P2?Shl309:BTP80UIFE0P2GUiL209JFUPP0b>3H00060<SPf080<30`
0P0^;Rh503`l?080<S8b0P1EEED208R8R080E5AD0P0Z:RX202TY:@<0<30`0P0_;bl202d];@80;2`/
100Z:RX202/[:`D0:BTY0P0e=CD204i>CP80GUiN0P1PH602059BDP<0DE5A0P1GEeL206a/K080FEUI
0P0h>3P202TY:@80:b/[0P0V9RH3024Q8@807alO0P0Q8B4201lO7`809bLW0P1?Cdl208Z:RP<0WinO
0P29RHT2069RHP80Hf=S0P2GUiL20;jn_P80`L710`2`/;020:FUY@80Zj^[0P2/[:`20:n_[`80/K6a
0P2d];@30;Jf]P80^KVi0P34a<@20<g=c@80bl_;0P36a/H20<G5a@<0a<C40P2o_kl20;^k^`80b<S8
0P34a<@20:b/[080HV9R0`14A4@204Q8B080Cdm?0P1;Bd/204Y:BP80ADE50P0m?Cd302d];@80;2`/
0P0^;Rh202l_;`80<C4a0P0f=SH203Ti>@<0=cLg0P0^;Rh203<c<`80=CDe0P0b<S8202d];@D0:BTY
0P0];Bd204A4A080@D510P0n?Sh205]KF`80Ogmo0P2TY:@30;^k^`80_Kfm0P2_[jl209NGU`80MgMg
0P1SHf<203Xj>P<0;Bd]0P0X:2P402HV9P80;2`/0P0Z:RX203Lg=`<0EEEE0P1^KVh208>3P`80QHF5
0P22PX8207inOP80O7al0`1nOWh208:2PP80QHF50P29RHT208Z:RP80S8b<0P2?Shl309:BTP80UIFE
0P2GUiL209JFUPP0b>3H00060<SPf080<S8b0P0i>CT205EEE@<0De=C0P0`<302061PH080R8R80P16
ATH402TY:@<0=3@d0P0_;bl202XZ:PH0:2PX0P0Y:BT302LW9`80;2`/0P11@D4206a/K080Ng]k101`
L70306QXJ080Bd];0P0m?Cd202d];@808b<S0P0W9bL202/[:`80:2PX0`0T92@202DU9@809bLW0P0O
7al2028R8P80<c<c0P1[Jf/309JFUP80Y:BT0P1cLg<205]KF`80OWin0P2[Zj/20<_;b`<0_Kfm0P2X
Z:P20:VYZ@80Z:RX0P2/[:`20;2`/080];Bd0`2g]kL20;Zj^P80`l?30P3:b/X20<_;b`80bLW90P36
a/H30<?3``80`<300P2o_kl20<;2`P@0`L710P2XZ:P305QHF080@4100P1;Bd/204M7A`80@d=30P0k
>c/203lo?`D0<S8b0P0a<C44030`<080;bl_0P0^;Rh3034a<@@0<c<c0P0a<C42030`<080;Rh^1@0]
;Bd202h^;P80;bl_0P0c<c<203`l?080B4Q80P1MGEd208>3P`<0Xj>S0P2MWId208R8R080JVYZ0P1<
C4`203Lg=`80:b/[0`0Y:BT202/[:`80:BTY0P0X:2P202LW9`80;Bd]0P15ADD305mOG`80MGEe0P25
QHD208R8R080QXJ60P22PX8207moO`<0P8200P22PX8208J6QP80RXZ:0P2;Rh/208b<S080Shn?0`2C
Ti<209JFUP80UiNG0P2HV9P80<SPf0001P38h=P2038b<P80>CTi0P1EEED305=CD`80<30`0P1PH602
08R8R080ATI6100Y:BT303@d=080;bl_0P0Z:RX602PX:080:BTY0`0W9bL202`/;080@D510P1/K6`2
07]kN`@0L71`0`1XJ6P204];B`80?Cdm0P0];Bd202<S8`809bLW0P0[:b/202PX:0<092@T0P0U9BD2
02LW9`807alO0P0R8R8203<c<`80Jf][0`2FUYH20:BTY080Lg=c0P1KFe/207inOP80Zj^[0P3;bl/3
0;fm_@80Z:RX0P2YZJT20:RXZ080[:b/0P2`/;020;Bd]0<0]kNg0P2j^[X20<?3``80b/[:0P3;bl/2
0<W9b@80a/K60`33`l<20<30`080_kno0P32`/840<71`@80Z:RX0`1HF5P20410@080Bd];0P17AdL2
04=3@`80>c/k0P0o?cl5038b<P80<C4a100`<30202l_;`80;Rh^0`0a<C4403<c<`80<C4a0P0`<302
02h^;PD0;Bd]0P0^;Rh202l_;`80<c<c0P0l?3`204Q8B080GEeM0P23Ph<30:>SX`80WIfM0P28R8P2
06YZJP80C4a<0P0g=cL202/[:`<0:BTY0P0[:b/202TY:@80:2PX0P0W9bL202d];@80ADE50`1OGel2
07EeM@80QHF50P28R8P208J6QP80PX:20P1oOgl30820P080PX:20P26QXH208Z:RP80Rh^;0P2<S8`2
08n?S`<0Ti>C0P2FUYH209NGU`80V9RH2038h=P000H0b>3H0P0V9RH20492@P80Bd];0`16ATH202l_
;`80GemO0P1nOWh203Ti>@80:RXZ0P0V9RH302l_;`80:b/[0P0W9bL402DU9@808b<S0P0X:2P302XZ
:P80C4a<0P1OGel207QhN080OGem0P1_Kfl205mOG`<0BTY:0P0a<C4202@T9080820P0P0U9BD202/[
:`80;bl_0P0[:b/702HV9P8092@T0P0O7al202<S8`80ADE50`1mOGd20::RXP80TY:B0P1VIVH206i^
KP80T92@0P2i^KT30<?3``80]KFe0P2UYJD20:RXZ080[:b/0P2_[jl20;:b/P<0]KFe0P2h^;P20<30
`080alO7103:b/X20<K6aP<0`L710P2n_[h20;fm_@80_kno0P31`L420<K6aP80`L710`2WYjL206AT
I080BTY:1P10@40204A4A0<0=CDe0P0d=3@203<c<`80<S8b0P0a<C42030`<080<C4a0`0b<S8203@d
=080<c<c0P0b<S82030`<080;bl_1`0^;Rh202d];@80;Rh^0P0c<c<20451@@80AdM70P1SHf<307Ui
N@80L71`0P1NGUh204Y:BP80>3Ph0P0/;2`202PX:0<09bLW0P0Y:BT402DU9@80;2`/0P0l?3`205UI
F@<0LW9b0P20P80408N7Q`80Q8B40P21PH4207moO`<0P8200P22PX8208N7Q`80Rh^;0P2<S8`208f=
S@80T92@0`2CTi<209JFUP80VIVI0P2JVYX80<SPf0001P38h=P202HV9P80@T920P1;Bd/304I6AP80
;bl_0P1OGel207inOP80>CTi0P0Z:RX202HV9P<0;bl_0P0[:b/202LW9`@09BDU0P0S8b<202PX:0<0
:RXZ0P1<C4`205mOG`80N7Qh0P1mOGd206m_K`80GemO0`1:BTX2034a<@8092@T0P0P820202DU9@80
:b/[0P0_;bl202/[:`L09RHV0P0T92@201lO7`808b<S0P15ADD307emO@80XZ:R0P2BTY8206IVIP80
KVi^0P2@T9020;Vi^@<0`l?30P2e]KD20:FUY@80Z:RX0P2/[:`20:n_[`80/[:b0`2e]KD20;Rh^080
`<300P37alL40<[:bP80a/K60`31`L420;jn_P80_Kfm0P2o_kl20<71`@80a/K60P31`L430:NWY`80
I6AT0P1:BTX60410@080A4A40`0e=CD203@d=080<c<c0P0b<S82034a<@80<30`0P0a<C43038b<P80
=3@d0P0c<c<2038b<P80<30`0P0_;bl702h^;P80;Bd]0P0^;Rh203<c<`80@D510P17AdL206=SH`<0
NGUi0P1`L70205iNGP80BTY:0P0h>3P202`/;080:2PX0`0W9bL202TY:@@09BDU0P0/;2`203`l?080
FEUI0`1bLW820820P0@0QhN70P24Q8@20861P@80Ogmo0`20P80208:2PP80QhN70P2;Rh/208b<S080
SHf=0P2@T90309>CT`80UYJF0P2IVIT209ZJVPP0b>3H00060<SPf0809RHV0P12@T8204];B`<0ATI6
0P0_;bl205mOG`80OWin0P0i>CT202XZ:P809RHV0`0_;bl202/[:`809bLW100U9BD202<S8`80:2PX
0`0Z:RX204a<C080GemO0P1hN7P207emO@80Kfm_0P1OGel304Y:BP80<C4a0P0T92@2020P80809BDU
0P0[:b/202l_;`80:b/[1`0V9RH202@T90807alO0P0S8b<204E5A@<0OGem0P2RXZ8209:BTP80IVIV
0P1^KVh2092@T080^KVi0`33`l<20;Fe]@80YJFU0P2XZ:P20:b/[080[jn_0P2b/[830;Fe]@80^;Rh
0P30`<020<O7a`@0b/[:0P36a/H30<71`@80_[jn0P2m_Kd20;no_`80`L710P36a/H20<71`@<0YjNW
0P1TI6@204Y:BPH0@4100P14A4@303De=@80=3@d0P0c<c<2038b<P80<C4a0P0`<302034a<@<0<S8b
0P0d=3@203<c<`80<S8b0P0`<30202l_;`L0;Rh^0P0];Bd202h^;P80<c<c0P11@D4204M7A`80Hf=S
0`1iNGT2071`L080GUiN0P1:BTX203Ph>080;2`/0P0X:2P302LW9`80:BTY100U9BD202`/;080?3`l
0P1IFET3079bLP80P8201027QhL208B4Q080PH610P1oOgl30820P080PX:20P27QhL208^;R`80S8b<
0P2=SHd2092@T0<0Ti>C0P2FUYH209VIV@80VYZJ2038h=P000H0b>3H0P0i>CT205IFEP80>SXj0`0b
<S8202l_;`80Fe]K0P1cLg<202l_;`80:b/[0P0T92@302PX:0809RHV0P0U9BD402<S8`808R8R0P0Z
:RX303Hf=P80Kfm_0P1gMgL207IfMP80Kfm_0P1RHV8204=3@`<09bLW0P0S8b<202HV9P809bLW0P0Z
:RX202l_;`80<S8b0P0^;Rh302PX:0809RHV0P0S8b<202XZ:P807QhN0P0L71`202@T90<0GUiN0P2A
TI420:^[Z`80NGUi0P1WIfL207QhN080WYjN0`31`L420<;2`P80YJFU0P2YZJT20:f][@80[jn_0P2a
/K430;>c/`80][Jf0P2m_Kd20<C4a080b<S80P3:b/X20<K6aP<0`L710P2n_[h20;bl_080^k^k0P2m
_Kd20;Bd]080`l?30`31`L4209nOW`80GUiN0P14A4@20410@080A4A40P18B4P303/k>`80>3Ph0P0f
=SH203De=@80=3@d0P0e=CD203Hf=P<0=CDe1P0d=3@203<c<`80<C4a0P0_;bl302h^;P@0;bl_0P0^
;Rh202`/;080>SXj0P0c<c<204A4A0<0DE5A0P16ATH203Hf=P80<C4a0P0^;Rh202`/;080:b/[1@0Z
:RX202LW9`80:BTY0P0l?3`205EEE@80Kfm_0`24Q8@208V9R@80QhN70P25QHD20861P@80Ogmo0P1n
OWh307moO`80PX:20P27QhL208b<S080SXj>0P2?Shl2096AT@<0Ti>C0P2HV9P209^KV`80W9bL2038
h=P000H0b>3H0P0i>CT205IFEP80>SXj0`0b<S8202l_;`80Fe]K0P1cLg<202l_;`80:b/[0P0T92@3
02PX:0809RHV0P0U9BD402<S8`808R8R0P0Z:RX303Hf=P80Kfm_0P1gMgL207IfMP80Kfm_0P1RHV82
04=3@`<09bLW0P0S8b<202HV9P809bLW0P0Z:RX202l_;`80<S8b0P0^;Rh302PX:0809RHV0P0S8b<2
02XZ:P807QhN0P0L71`202@T90<0GUiN0P2ATI420:^[Z`80NGUi0P1WIfL207QhN080WYjN0`31`L42
0<;2`P80YJFU0P2YZJT20:f][@80[jn_0P2a/K430;>c/`80][Jf0P2m_Kd20<C4a080b<S80P3:b/X2
0<K6aP<0`L710P2n_[h20;bl_080^k^k0P2m_Kd20;Bd]080`l?30`31`L4209nOW`80GUiN0P14A4@2
0410@080A4A40P18B4P303/k>`80>3Ph0P0f=SH203De=@80=3@d0P0e=CD203Hf=P<0=CDe1P0d=3@2
03<c<`80<C4a0P0_;bl302h^;P@0;bl_0P0^;Rh202`/;080>SXj0P0c<c<204A4A0<0DE5A0P16ATH2
03Hf=P80<C4a0P0^;Rh202`/;080:b/[1@0Z:RX202LW9`80:BTY0P0l?3`205EEE@80Kfm_0`24Q8@2
08V9R@80QhN70P25QHD20861P@80Ogmo0P1nOWh307moO`80PX:20P27QhL208b<S080SXj>0P2?Shl2
096AT@<0Ti>C0P2HV9P209^KV`80W9bL2038h=P000H0b>3H0P19BDT204=3@`80<C4a0`0[:b/2030`
<080GEeM0P1ZJVX202d];@80:BTY0P0R8R8902HV9P80:2PX0P0[:b/203Lg=`<0FUYJ0P1hN7P207al
O080KFe]0P1@D50203<c<`80:RXZ0`0X:2P202LW9`809RHV0P0];Bd202`/;080;bl_0P0a<C4202`/
;0<09RHV0P0Y:BT202/[:`80;Rh^0P0J6QX401lO7`<0@4100P1`L7020:JVYP80TI6A0P1fMWH206i^
KP80P8200`2XZ:P20<K6aP80];Bd0P2WYjL20:b/[080[Jf]0P2`/;030;:b/P80]KFe0P2l_;`20<?3
``80b<S80P3;bl/20<S8b0<0a<C40P2o_kl20;^k^`80^[Zj0P2k^k/20;Bd]080_Kfm0`3Bd]820<S8
b080TI6A0P1GEeL203dm?@80@T920P19BDT304Q8B080ATI60P12@T8203hn?P80>SXj0P0f=SH2038b
<P<0=CDe0P0h>3P203Lg=`80=3@d0P0c<c<2038b<P80<30`0`0_;bl202h^;P@0<30`0P0_;bl203Hf
=P80<30`0P0c<c<303Ph>080>SXj0P0k>c/203<c<`80:2PX0P0U9BD202LW9`<0:BTY0P0/;2`2034a
<@80=cLg0P1OGel208:2PPD0R8R80P25QHD408:2PP80Ph>30P1oOgl207emO@<0P8200P25QHD208V9
R@80S8b<0P2>SXh2092@T080U9BD0`2HV9P209ZJVP80W9bL0P2MWId80<SPf0001P38h=P204U9B@80
@d=30P0a<C4302/[:`80<30`0P1MGEd206YZJP80;Bd]0P0Y:BT2028R8PT09RHV0P0X:2P202/[:`80
=cLg0`1JFUX207QhN080O7al0P1]KFd2051@D080<c<c0P0Z:RX302PX:0809bLW0P0V9RH202d];@80
;2`/0P0_;bl2034a<@80;2`/0`0V9RH202TY:@80:b/[0P0^;Rh201XJ6P@07alO0`10@402071`L080
YZJV0P2ATI4207IfMP80KVi^0P20P8030:RXZ080a/K60P2d];@20:NWY`80[:b/0P2][Jd20;2`/0<0
/[:b0P2e]KD20;bl_080`l?30P38b<P20<_;b`80b<S80`34a<@20;no_`80^k^k0P2j^[X20;^k^`80
];Bd0P2m_Kd30=;BdP80b<S80P2ATI4205MGE`80?Cdm0P12@T8204U9B@<0B4Q80P16ATH20492@P80
?Shn0P0j>SX203Hf=P80<S8b0`0e=CD203Ph>080=cLg0P0d=3@203<c<`80<S8b0P0`<30302l_;`80
;Rh^100`<30202l_;`80=SHf0P0`<30203<c<`<0>3Ph0P0j>SX203/k>`80<c<c0P0X:2P202DU9@80
9bLW0`0Y:BT202`/;080<C4a0P0g=cL205mOG`80PX:21@28R8P208F5Q@@0PX:20P23Ph<207moO`80
OGem0`20P80208F5Q@80RHV90P2<S8`208j>SP80T92@0P2DU9@309RHV080VYZJ0P2LW9`209fMW@P0
b>3H00060<SPf080EUIF0P0^;Rh202XZ:P<0:BTY0P0a<C4205mOG`80HV9R0P0^;Rh202PX:0808R8R
1@0U9BD202PX:080:b/[0P0a<C4203Xj>P80ATI60`1nOWh207YjNP80Hf=S0P11@D42034a<@80:2PX
0P0Y:BT302h^;P80;Bd]0P0[:b/203De=@80;Bd]100_;bl202XZ:P<09BDU0P0T92@202<S8`80:2PX
0P0L71`202PX:0808R8R0`0W9bL204e=C@80TI6A0P2RXZ8208Z:RP80KFe]0P1WIfL308^;R`80`<30
0P31`L420:NWY`@0Zj^[0P2_[jl30;2`/080];Bd0P2k^k/20<?3``80alO7103:b/X30<S8b080`L71
0P2k^k/40;Vi^@80][Jf0P2c/k<30;jn_P80`l?30P38b<P209bLW080HV9R0P18B4P204Y:BP<0E5AD
0P1BDU8204i>CP80BDU90P13@d<203Xj>P80<c<c0`0i>CT20410@080?3`l0P0f=SH403De=@80=3@d
0`0c<c<6038b<P80=3@d0P0e=CD203Hf=P80<c<c0`0`<30202h^;P80;Bd]0P0/;2`202/[:`809bLW
0P0V9RH302d];@80=SHf0P12@T8204a<C080KFe]0P28R8P208^;R`<0R8R80P21PH4207]kN`80Ogmo
0P23Ph<207moO`80Ng]k0`20P80208N7Q`80RXZ:0P2<S8`208n?S`80TY:B0P2GUiL309bLW0H0WIfM
2038h=P000H0b>3H0P1FEUH202h^;P80:RXZ0`0Y:BT2034a<@80GemO0P1RHV8202h^;P80:2PX0P0R
8R8502DU9@80:2PX0P0[:b/2034a<@80>SXj0P16ATH307inOP80NWYj0P1SHf<20451@@80<C4a0P0X
:2P202TY:@<0;Rh^0P0];Bd202/[:`80=CDe0P0];Bd402l_;`80:RXZ0`0U9BD202@T90808b<S0P0X
:2P201`L7080:2PX0P0R8R8302LW9`80CDe=0P2ATI420::RXP80RXZ:0P1]KFd206MWI`<0Rh^;0P30
`<020<71`@80YjNW102[Zj/20:n_[`<0/;2`0P2d];@20;^k^`80`l?30P37alL40<[:bP<0b<S80P31
`L420;^k^`@0^KVi0P2f][H20;>c/`<0_[jn0P33`l<20<S8b080W9bL0P1RHV8204Q8B080BTY:0`1D
E5@2059BDP80CTi>0P19BDT204=3@`80>SXj0P0c<c<303Ti>@80@4100P0l?3`203Hf=P@0=CDe0P0d
=3@303<c<`H0<S8b0P0d=3@203De=@80=SHf0P0c<c<3030`<080;Rh^0P0];Bd202`/;080:b/[0P0W
9bL202HV9P<0;Bd]0P0f=SH20492@P80C4a<0P1]KFd208R8R080Rh^;0`28R8P20861P@80Ng]k0P1o
Ogl208>3P`80Ogmo0P1kNg/30820P080QhN70P2:RXX208b<S080Shn?0P2BTY8209NGU`<0W9bL1P2M
WId80<SPf0001P38h=P204=3@`80;2`/0P0Z:RX302`/;080=3@d0P1JFUX205mOG`80;bl_0P0/;2`7
02DU9@809bLW0P0Z:RX202h^;P80BDU90P1GEeL307EeM@80GUiN0P0o?cl202TY:@809BDU0P0X:2P2
02XZ:PD0;Rh^0P0];Bd2038b<P@0;Rh^0P0];Bd202/[:`<0:BTY0P0U9BD202<S8`8092@T0P0a<C42
03De=@808B4Q0`0L71`2038b<P80JFUY0P2HV9P209bLW080OGem0P1QHF4307EeM@80WinO0P2m_Kd2
0;Zj^P80[jn_0P2VYZH20:b/[0<0[Jf]0P2`/;020;Ng]`80`<300P35aLD20<S8b0D0bl_;0P35aLD2
0;fm_@80^KVi0P2e]KD20;:b/P80[jn_0`2f][H20;no_`80e]KF0P3<c<`209^KV`80IfMW0P19BDT3
051@D080De=C0P1HF5P205IFEP80DE5A0P1=CDd204];B`<0CDe=0P1?Cdl20492@P80?clo100m?Cd2
03hn?P<0?Cdm0P0n?Sh203@d=080<C4a0P0`<302038b<P80=CDe0P0o?cl303Hf=P80=3@d0P0/;2`2
02/[:`80<c<c0P0d=3@2030`<0<0?Shn0P1;Bd/207AdM080H61P0P1RHV8207UiN@80RXZ:0`21PH42
07inOP80NGUi0P1jNWX207alO080NWYj0P1hN7P307emO@80Ph>30P27QhL208^;R`80TI6A0P2FUYH2
09ZJVP<0WIfM1P2NWYh80<SPf0001P38h=P204=3@`80;2`/0P0Z:RX302`/;080=3@d0P1JFUX205mO
G`80;bl_0P0/;2`702DU9@809bLW0P0Z:RX202h^;P80BDU90P1GEeL307EeM@80GUiN0P0o?cl202TY
:@809BDU0P0X:2P202XZ:PD0;Rh^0P0];Bd2038b<P@0;Rh^0P0];Bd202/[:`<0:BTY0P0U9BD202<S
8`8092@T0P0a<C4203De=@808B4Q0`0L71`2038b<P80JFUY0P2HV9P209bLW080OGem0P1QHF4307Ee
M@80WinO0P2m_Kd20;Zj^P80[jn_0P2VYZH20:b/[0<0[Jf]0P2`/;020;Ng]`80`<300P35aLD20<S8
b0D0bl_;0P35aLD20;fm_@80^KVi0P2e]KD20;:b/P80[jn_0`2f][H20;no_`80e]KF0P3<c<`209^K
V`80IfMW0P19BDT3051@D080De=C0P1HF5P205IFEP80DE5A0P1=CDd204];B`<0CDe=0P1?Cdl20492
@P80?clo100m?Cd203hn?P<0?Cdm0P0n?Sh203@d=080<C4a0P0`<302038b<P80=CDe0P0o?cl303Hf
=P80=3@d0P0/;2`202/[:`80<c<c0P0d=3@2030`<0<0?Shn0P1;Bd/207AdM080H61P0P1RHV8207Ui
N@80RXZ:0`21PH4207inOP80NGUi0P1jNWX207alO080NWYj0P1hN7P307emO@80Ph>30P27QhL208^;
R`80TI6A0P2FUYH209ZJVP<0WIfM1P2NWYh80<SPf0001P38h=P202h^;P80;Bd]0P0/;2`3030`<080
=cLg0P1EEED205eMG@80<C4a0P0`<30202PX:0<09bLW0P0T92@202HV9P80<S8b0P10@40205eMG@80
Hf=S0`1]KFd205MGE`80=3@d0P0Z:RX202TY:@80;Rh^1@0];Bd202h^;P80;bl_2P0];Bd302`/;080
:2PX0P0Z:RX202HV9P80ADE50P0m?Cd2020P80<06ATI0P0P82020410@080P8200P2TY:@208n?S`80
IVIV0`1WIfL207alO080[jn_0P37alL20;Bd]080Y:BT0P2ZZZX30:VYZ@80[:b/0P2c/k<20;bl_080
`L710P36a/H20<[:bP<0c<c<0P37alL20<71`@80^;Rh0P2a/K420:f][@80Zj^[0`2_[jl20;Fe]@80
_[jn0P35aLD20<_;b`80Zj^[0P1VIVH305ADE080EEEE0P1QHF42061PH080GUiN0P1QHF4506ATI080
HV9R101<C4`204U9B@80BTY:1@1;Bd/204m?C`80?Cdm0P0a<C4202`/;080?Cdm0P1@D50206YZJP<0
G5aL0P1?Cdl2038b<P80;2`/0P11@D4204I6AP80?Shn0`1GEeL2071`L080Ng]k0P20P80205UIF@80
HV9R0P20P80307MgM`80NGUi0P1fMWH207EeM@80M7Ad0P1cLg<207AdM0<0NGUi0P20P80208J6QP80
SHf=0P2DU9@209ZJVP80WIfM0`2NWYh209nOW`@0X:2P2038h=P000H0b>3H0P0^;Rh202d];@80;2`/
0`0`<30203Lg=`80EEEE0P1MGEd2034a<@80<30`0P0X:2P302LW9`8092@T0P0V9RH2038b<P80@410
0P1MGEd206=SH`<0KFe]0P1GEeL203@d=080:RXZ0P0Y:BT202h^;PD0;Bd]0P0^;Rh202l_;`X0;Bd]
0`0/;2`202PX:080:RXZ0P0V9RH204E5A@80?Cdm0P0P820301TI6@80820P0P10@4020820P080Y:BT
0P2?Shl206IVIP<0IfMW0P1lO7`20:n_[`80alO70P2d];@20:BTY080ZZZZ0`2YZJT20:b/[080/k>c
0P2l_;`20<71`@80a/K60P3:b/X30<c<c080alO70P31`L420;Rh^080/K6a0P2][Jd20:^[Z`<0[jn_
0P2e]KD20;jn_P80aLG50P3;bl/20:^[Z`80IVIV0`1DE5@205EEE@80HF5Q0P1PH60205iNGP80HF5Q
1@1TI6@2069RHP@0C4a<0P19BDT204Y:BPD0Bd];0P1?Cdl203dm?@80<C4a0P0/;2`203dm?@80D51@
0P1ZJVX305aLG080Cdm?0P0b<S8202`/;080@D510P16ATH203hn?P<0EeMG0P1`L70207]kN`80P820
0P1IFET2069RHP80P8200`1gMgL207UiN@80MWIf0P1eMGD207AdM080Lg=c0P1dM7@307UiN@80P820
0P26QXH208f=S@80U9BD0P2JVYX209fMW@<0WYjN0P2OWil40:2PX0P0b>3H00060<SPf080;Bd]0P0/
;2`202XZ:P<0<30`0P0f=SH205EEE@80EeMG0P0a<C4202/[:`809RHV0`0X:2P202DU9@80:BTY0P0b
<S8204];B`80I6AT0P1ZJVX3061PH080=CDe0P0U9BD402LW9`80:RXZ0P0[:b/302`/;080;bl_0P0`
<30202`/;080:BTY0P0Z:RX202TY:@80:RXZ0`0Y:BT202HV9P80;Bd]0P0k>c/204Q8B080<S8b0P0M
7Ad301/K6`807QhN0P0_;bl205YJFP80Ti>C0P2IVIT207inOP<0IVIV0P1^KVh2092@T080]KFe0P2n
_[h20;Fe]@80YZJV0`2WYjL20:^[Z`80/;2`0P2f][H20;fm_@80`/;20P36a/H30<S8b080alO70P33
`l<20;Vi^@80[Zj^0P2YZJT20:JVYP<0ZJVY0P2^[Zh20;Ng]`80^;Rh0P3?cll20<O7a`80/;2`0`1a
LG42061PH080HF5Q0P1NGUh206QXJ080K6a/0P1]KFd306MWI`80H61P0P1KFe/206=SH`80HV9R0P1Q
HF4206QXJ0<0K6a/0P1ZJVX205IFEP80A4A40P0[:b/204M7A`80JVYZ0P28R8P308V9R@80N7Qh0P1A
DE4204M7A`80IFEU0P1XJ6P204Y:BP<0GUiN0P1aLG4207emO@80P8200P1UIFD206=SH`80MGEe0`1c
Lg<2071`L080Jf][0P1/K6`206i^KP80KFe]0P1_Kfl307MgM`80PX:20P2<S8`209BDU080VIVI0P2K
Vi/209jNWP<0X:2P0P2QXJ440::RXPP0b>3H00060<SPf080;Bd]0P0/;2`202XZ:P<0<30`0P0f=SH2
05EEE@80EeMG0P0a<C4202/[:`809RHV0`0X:2P202DU9@80:BTY0P0b<S8204];B`80I6AT0P1ZJVX3
061PH080=CDe0P0U9BD402LW9`80:RXZ0P0[:b/302`/;080;bl_0P0`<30202`/;080:BTY0P0Z:RX2
02TY:@80:RXZ0`0Y:BT202HV9P80;Bd]0P0k>c/204Q8B080<S8b0P0M7Ad301/K6`807QhN0P0_;bl2
05YJFP80Ti>C0P2IVIT207inOP<0IVIV0P1^KVh2092@T080]KFe0P2n_[h20;Fe]@80YZJV0`2WYjL2
0:^[Z`80/;2`0P2f][H20;fm_@80`/;20P36a/H30<S8b080alO70P33`l<20;Vi^@80[Zj^0P2YZJT2
0:JVYP<0ZJVY0P2^[Zh20;Ng]`80^;Rh0P3?cll20<O7a`80/;2`0`1aLG42061PH080HF5Q0P1NGUh2
06QXJ080K6a/0P1]KFd306MWI`80H61P0P1KFe/206=SH`80HV9R0P1QHF4206QXJ0<0K6a/0P1ZJVX2
05IFEP80A4A40P0[:b/204M7A`80JVYZ0P28R8P308V9R@80N7Qh0P1ADE4204M7A`80IFEU0P1XJ6P2
04Y:BP<0GUiN0P1aLG4207emO@80P8200P1UIFD206=SH`80MGEe0`1cLg<2071`L080Jf][0P1/K6`2
06i^KP80KFe]0P1_Kfl307MgM`80PX:20P2<S8`209BDU080VIVI0P2KVi/209jNWP<0X:2P0P2QXJ44
0::RXPP0b>3H00060<SPf080;bl_0P0[:b/202PX:0<0;Rh^0P0d=3@205ADE080Cdm?0P0c<c<202HV
9P8092@T0`0X:2P202HV9P80:b/[0P0b<S8205EEE@80IFEU0P1ZJVX305aLG080;Bd]0P0Y:BT202LW
9`@09RHV0P0X:2P302/[:`80;bl_0P0`<30202/[:`809RHV0P0Y:BT202/[:`D0:BTY0P0m?Cd2059B
DP80G5aL0P13@d<202PX:0808R8R0`0P8202028R8P809RHV0P0d=3@207MgM`80VIVI0P2FUYH3071`
L080KFe]0P1cLg<209^KV`80`<300P32`/820:FUY@<0YjNW0P2[Zj/20:f][@80/K6a0P2h^;P20;no
_`80`/;20`34a<@20<K6aP80aLG50P2k^k/20:j^[P80YZJV0P2QXJ430::RXP80YjNW0P2i^KT20;Zj
^P80`l?30P37alL20<G5a@<0][Jf0P24Q8@206IVIP80GEeM0P1_Kfl2071`L080LG5a0`1dM7@207If
MP@0MgMg0P1iNGT207YjNPD0Ng]k0P1jNWX2079bLP80Fe]K0P0b<S8205YJFP80R8R80P2BTY83096A
T@80Shn?0P1eMGD205iNGP80N7Qh0P1oOgl205UIF@<0HV9R0P1[Jf/207AdM080N7Qh0P1aLG4206EU
I@80IfMW0`1/K6`206IVIP80H61P0P1RHV8206MWI`80J6QX0P1[Jf/307QhN080QhN70P2DU9@409jN
WP80WIfM0P2OWil30::RXP80Xj>S0P2TY:@20:FUY@P0b>3H00060<SPf080;bl_0P0[:b/202PX:0<0
;Rh^0P0d=3@205ADE080Cdm?0P0c<c<202HV9P8092@T0`0X:2P202HV9P80:b/[0P0b<S8205EEE@80
IFEU0P1ZJVX305aLG080;Bd]0P0Y:BT202LW9`@09RHV0P0X:2P302/[:`80;bl_0P0`<30202/[:`80
9RHV0P0Y:BT202/[:`D0:BTY0P0m?Cd2059BDP80G5aL0P13@d<202PX:0808R8R0`0P8202028R8P80
9RHV0P0d=3@207MgM`80VIVI0P2FUYH3071`L080KFe]0P1cLg<209^KV`80`<300P32`/820:FUY@<0
YjNW0P2[Zj/20:f][@80/K6a0P2h^;P20;no_`80`/;20`34a<@20<K6aP80aLG50P2k^k/20:j^[P80
YZJV0P2QXJ430::RXP80YjNW0P2i^KT20;Zj^P80`l?30P37alL20<G5a@<0][Jf0P24Q8@206IVIP80
GEeM0P1_Kfl2071`L080LG5a0`1dM7@207IfMP@0MgMg0P1iNGT207YjNPD0Ng]k0P1jNWX2079bLP80
Fe]K0P0b<S8205YJFP80R8R80P2BTY83096AT@80Shn?0P1eMGD205iNGP80N7Qh0P1oOgl205UIF@<0
HV9R0P1[Jf/207AdM080N7Qh0P1aLG4206EUI@80IfMW0`1/K6`206IVIP80H61P0P1RHV8206MWI`80
J6QX0P1[Jf/307QhN080QhN70P2DU9@409jNWP80WIfM0P2OWil30::RXP80Xj>S0P2TY:@20:FUY@P0
b>3H00060<SPf080;bl_0P0[:b/202PX:0<0;Rh^0P0d=3@205ADE080Cdm?0P0c<c<202HV9P8092@T
0`0X:2P202HV9P80:b/[0P0b<S8205EEE@80IFEU0P1ZJVX305aLG080;Bd]0P0Y:BT202LW9`@09RHV
0P0X:2P302/[:`80;bl_0P0`<30202/[:`809RHV0P0Y:BT202/[:`D0:BTY0P0m?Cd2059BDP80G5aL
0P13@d<202PX:0808R8R0`0P8202028R8P809RHV0P0d=3@207MgM`80VIVI0P2FUYH3071`L080KFe]
0P1cLg<209^KV`80`<300P32`/820:FUY@<0YjNW0P2[Zj/20:f][@80/K6a0P2h^;P20;no_`80`/;2
0`34a<@20<K6aP80aLG50P2k^k/20:j^[P80YZJV0P2QXJ430::RXP80YjNW0P2i^KT20;Zj^P80`l?3
0P37alL20<G5a@<0][Jf0P24Q8@206IVIP80GEeM0P1_Kfl2071`L080LG5a0`1dM7@207IfMP@0MgMg
0P1iNGT207YjNPD0Ng]k0P1jNWX2079bLP80Fe]K0P0b<S8205YJFP80R8R80P2BTY83096AT@80Shn?
0P1eMGD205iNGP80N7Qh0P1oOgl205UIF@<0HV9R0P1[Jf/207AdM080N7Qh0P1aLG4206EUI@80IfMW
0`1/K6`206IVIP80H61P0P1RHV8206MWI`80J6QX0P1[Jf/307QhN080QhN70P2DU9@409jNWP80WIfM
0P2OWil30::RXP80Xj>S0P2TY:@20:FUY@P0b>3H00060<SPf080:2PX0P0Z:RX202d];@<0:RXZ0P0d
=3@204i>CP80A4A40P0g=cL202h^;P80:RXZ0`0W9bL202/[:`80;bl_0P0f=SH205]KF`80Hf=S0P1W
IfL304];B`80<S8b0P0X:2P202HV9P809BDU0P0V9RH202PX:0<0:RXZ0P0/;2`202d];@80:RXZ0P0Y
:BT202DU9@80=CDe0P0f=SH304I6AP80KVi^0P1YJFT204U9B@80:b/[0P0Y:BT203<c<`<07AdM0P0O
7al2024Q8@808b<S0P1ADE4207inOP80VIVI0`2>SXh20820P080MGEe0P23Ph<20:BTY080^;Rh0P2i
^KT30:n_[`80YJFU0P2YZJT20:n_[`80];Bd0P2i^KT20;fm_@<0`L710P36a/H20<O7a`80_kno0P2d
];@20:JVYPD0W9bL0P2QXJ420:n_[`80]KFe0P2m_Kd20<G5a@80d=3@0`3;bl/20:j^[P80U9BD0P1h
N7P206i^KP80Jf][0P1hN7P307]kN`80OGem101oOgl208B4Q080RHV90P2:RXX308R8R080QhN70P22
PX8206YZJP80EEEE0P1eMGD209ZJVP80X:2P0`2NWYh209VIV@80R8R80P1cLg<208:2PP80Rh^;0P1a
LG43061PH0H0JVYZ0P1VIVH205iNGP80FUYJ0`1KFe/205IFEP@0De=C0P1GEeL2061PH080KFe]0`1m
OGd208j>SP80Vi^K102UYJD20::RXP80Xj>S0`2UYJD40:NWY`80Z:RX2038h=P000H0b>3H0P0X:2P2
02XZ:P80;Bd]0`0Z:RX203@d=080CTi>0P14A4@203Lg=`80;Rh^0P0Z:RX302LW9`80:b/[0P0_;bl2
03Hf=P80Fe]K0P1SHf<206MWI`<0Bd];0P0b<S8202PX:0809RHV0P0U9BD202HV9P80:2PX0`0Z:RX2
02`/;080;Bd]0P0Z:RX202TY:@809BDU0P0e=CD203Hf=P<0ATI60P1^KVh206UYJ@80BDU90P0[:b/2
02TY:@80<c<c0`0M7Ad201lO7`808B4Q0P0S8b<2055AD@80OWin0P2IVIT308j>SP80P8200P1eMGD2
08>3P`80Y:BT0P2h^;P20;Vi^@<0[jn_0P2UYJD20:VYZ@80[jn_0P2d];@20;Vi^@80_Kfm0`31`L42
0<K6aP80alO70P2o_kl20;Bd]080YZJV1@2LW9`20:6QX@80[jn_0P2e]KD20;fm_@80aLG50P3@d=03
0<_;b`80[Zj^0P2DU9@207QhN080KVi^0P1[Jf/207QhN0<0Ng]k0P1mOGd407moO`80Q8B40P29RHT2
08Z:RP<0R8R80P27QhL208:2PP80JVYZ0P1EEED207EeM@80VYZJ0P2PX:0309jNWP80VIVI0P28R8P2
07=cL`80PX:20P2;Rh/2075aL@<0H61P1P1ZJVX206IVIP80GUiN0P1JFUX305]KF`80EUIF101CDe<2
05MGE`80H61P0P1]KFd307emO@80SXj>0P2KVi/40:FUY@80XZ:R0P2SXj<30:FUY@@0YjNW0P2XZ:P8
0<SPf0001P38h=P2028R8P80:2PX0P0a<C4302HV9P80<S8b0P17AdL203Xj>P80>c/k0P0h>3P202l_
;`<09RHV0P0a<C4202l_;`80>3Ph0P1LG5`205mOG`80GUiN0`0i>CT203/k>`80;2`/100U9BD202PX
:0T0:BTY0P0X:2P202d];@80<C4a0P1GEeL205ADE0<0GemO0P20P80205ADE0809BDU0P0[:b/204a<
C080FUYJ0`0W9bL201hN7P807AdM0P0L71`202h^;P80GEeM0P2ATI430:JVYP80UYJF0P20P802075a
L@80PX:20P2VYZH20<O7a`<0]kNg0P2RXZ820:JVYP80[Zj^0P2a/K420;>c/`80^KVi0`2n_[h20<C4
a080b<S80P34a<@20;^k^`80ZJVY0P2IVIT309NGU`80W9bL0P2UYJD20;2`/080^;Rh0P2o_kl20<?3
``<0a<C40P39bLT20<?3``80VYZJ0P1bLW8206][J`80Ogmo0`21PH4208>3P`80PX:20P23Ph<208^;
R`@0TY:B0`2@T90208n?S`80SXj>0P1hN7P207]kN`80SXj>0P2TY:@20:JVYP<0XJ6Q0P2IVIT2096A
T@80PH610P23Ph<208b<S080PH610`1KFe/206EUI@80GUiN0P1KFe/205MGE`80De=C0P1?Cdl504];
B`80C4a<0P1;Bd/204m?C`80H61P0P1eMGD308J6QP80UYJF0P2SXj<20:^[Z`80ZZZZ0P2VYZH20:NW
Y`D0ZJVY102ZZZX80<SPf0001P38h=P2028R8P80:2PX0P0a<C4302HV9P80<S8b0P17AdL203Xj>P80
>c/k0P0h>3P202l_;`<09RHV0P0a<C4202l_;`80>3Ph0P1LG5`205mOG`80GUiN0`0i>CT203/k>`80
;2`/100U9BD202PX:0T0:BTY0P0X:2P202d];@80<C4a0P1GEeL205ADE0<0GemO0P20P80205ADE080
9BDU0P0[:b/204a<C080FUYJ0`0W9bL201hN7P807AdM0P0L71`202h^;P80GEeM0P2ATI430:JVYP80
UYJF0P20P802075aL@80PX:20P2VYZH20<O7a`<0]kNg0P2RXZ820:JVYP80[Zj^0P2a/K420;>c/`80
^KVi0`2n_[h20<C4a080b<S80P34a<@20;^k^`80ZJVY0P2IVIT309NGU`80W9bL0P2UYJD20;2`/080
^;Rh0P2o_kl20<?3``<0a<C40P39bLT20<?3``80VYZJ0P1bLW8206][J`80Ogmo0`21PH4208>3P`80
PX:20P23Ph<208^;R`@0TY:B0`2@T90208n?S`80SXj>0P1hN7P207]kN`80SXj>0P2TY:@20:JVYP<0
XJ6Q0P2IVIT2096AT@80PH610P23Ph<208b<S080PH610`1KFe/206EUI@80GUiN0P1KFe/205MGE`80
De=C0P1?Cdl504];B`80C4a<0P1;Bd/204m?C`80H61P0P1eMGD308J6QP80UYJF0P2SXj<20:^[Z`80
ZZZZ0P2VYZH20:NWY`D0ZJVY102ZZZX80<SPf0001P38h=P202<S8`809BDU0P0Z:RX3038b<P80ADE5
0P1NGUh204e=C@80ADE50P0g=cL203De=@<0@D510P1KFe/204M7A`80@T920P1EEED205UIF@80B4Q8
0`0^;Rh203Ph>080=SHf0P0W9bL402HV9P809bLW0`0X:2P402HV9P809bLW0P0^;Rh203De=@80D51@
0P1JFUX306=SH`80P8200P1CDe<201dM7@80;2`/0P1LG5`205MGE`<0<30`0P0/;2`201hN7P80820P
0P0S8b<203lo?`80MgMg0`2MWId20:6QX@80R8R80P1^KVh206a/K080SXj>0P2e]KD30<30`080/K6a
0P2UYJD20:JVYP80[:b/0P2b/[820;Ng]`<0^k^k0P31`L440<G5a@80`<300P2_[jl209jNWP<0V9RH
0P2GUiL209nOW`80ZZZZ0P2b/[820;Zj^P80_kno0`32`/840<S8b080_;bl0P2XZ:P208J6QP80LW9b
0`1cLg<207alO080Ph>30P2:RXX2092@T080UIFE1@2HV9P209:BTP80SHf=0P22PX8209>CT`80W9bL
102TY:@309nOW`80UYJF0P2>SXh20861P@80Ng]k0P1jNWX2075aL@<0GEeM0P1QHF4205IFEP80CTi>
0P18B4P204A4A0D0@d=30P10@4020492@P80DE5A0P1TI6@207QhN080RXZ:0`2HV9P20::RXP80Z:RX
102[Zj/70:VYZ@80ZZZZ0P2/[:`20:f][@P0b>3H00060<SPf0808b<S0P0U9BD202XZ:P<0<S8b0P15
ADD205iNGP80CDe=0P15ADD203Lg=`80=CDe0`11@D4205]KF`80AdM70P12@T8205EEE@80FEUI0P18
B4P302h^;P80>3Ph0P0f=SH202LW9`@09RHV0P0W9bL302PX:0@09RHV0P0W9bL202h^;P80=CDe0P1@
D50205YJFP<0Hf=S0P20P80205=CD`807AdM0P0/;2`205aLG080EeMG0`0`<30202`/;0807QhN0P0P
820202<S8`80?clo0P1gMgL309fMW@80XJ6Q0P28R8P206i^KP80K6a/0P2>SXh20;Fe]@<0`<300P2a
/K420:FUY@80YZJV0P2/[:`20;:b/P80]kNg0`2k^k/20<71`@@0aLG50P30`<020:n_[`80WYjN0`2H
V9P209NGU`80WinO0P2ZZZX20;:b/P80^[Zj0P2o_kl30<;2`P@0b<S80P2l_;`20:RXZ080QXJ60P1b
LW8307=cL`80O7al0P23Ph<208Z:RP80T92@0P2EUID509RHV080TY:B0P2=SHd208:2PP80Ti>C0P2L
W9`40:BTY0<0WinO0P2FUYH208j>SP80PH610P1kNg/207YjNP80LG5a0`1MGEd2065QH@80EUIF0P1>
CTh204Q8B080A4A41@13@d<20410@080@T920P1ADE4206ATI080N7Qh0P2:RXX309RHV080XZ:R0P2X
Z:P40:^[Z`L0ZJVY0P2ZZZX20:b/[080[Jf]2038h=P000H0b>3H0P0V9RH202DU9@809RHV0`0[:b/2
02l_;`80BTY:0P11@D420410@080>SXj0P0a<C4303/k>`80DU9B0P0[:b/203<c<`80CTi>0P1EEED2
03@d=0<0:2PX0P0c<c<203lo?`80:RXZ0P0X:2P202DU9@809RHV0`0X:2P202DU9@8092@T0P0X:2P2
038b<P80Cdm?0P1UIFD205]KF`<0?Cdm0P1WIfL2069RHP80:2PX0P0d=3@205eMG@80>CTi0`0_;bl2
03hn?P808R8R0P0W9bL2024Q8@80:2PX0P1GEeL308J6QP80XZ:R0P2@T90207AdM080GUiN0P1gMgL2
09VIV@<0_kno0P2n_[h20:NWY`80X:2P0P2WYjL20;:b/P80]KFe0`2h^;P20;fm_@80`L710P35aLD2
0<C4a080][Jf0P2VYZH309ZJVP80U9BD0P2KVi/20:FUY@80[Jf]0P2d];@20;Vi^@<0_Kfm0P32`/82
0<C4a080a/K60P30`<020:JVYP80RXZ:0`1mOGd207QhN080P8200P2<S8`2092@T080Ti>C0P2HV9P3
09bLW080VYZJ0P2IVIT2096AT@80X:2P0P2NWYh209bLW080VYZJ0`2GUiL208j>SP80Ph>30P1iNGT2
06i^KP80IFEU0P1LG5`3059BDPH0AdM70P11@D4203dm?@80?Shn0`14A4@204a<C080F5QH0P1[Jf/2
0820P080TY:B0P2QXJ430:VYZ@@0[Jf]0P2ZZZX20:^[Z`80[:b/0P2ZZZX30:VYZ@80Zj^[0P2][Jd2
0:j^[PP0b>3H00060<SPf0809RHV0P0U9BD202HV9P<0:b/[0P0_;bl204Y:BP80@D510P10@40203Xj
>P80<C4a0`0k>c/2059BDP80:b/[0P0c<c<204i>CP80EEEE0P0d=3@302PX:080<c<c0P0o?cl202XZ
:P80:2PX0P0U9BD202HV9P<0:2PX0P0U9BD202@T9080:2PX0P0b<S8204m?C`80IFEU0P1KFe/303dm
?@80IfMW0P1RHV8202PX:080=3@d0P1MGEd203Ti>@<0;bl_0P0n?Sh2028R8P809bLW0P0Q8B4202PX
:080EeMG0`26QXH20::RXP80T92@0P1dM7@205iNGP80MgMg0P2IVIT30;no_`80_[jn0P2WYjL20:2P
X080YjNW0P2b/[820;Fe]@<0^;Rh0P2m_Kd20<71`@80aLG50P34a<@20;Jf]P80YZJV0`2JVYX209BD
U080Vi^K0P2UYJD20:f][@80];Bd0P2i^KT30;fm_@80`/;20P34a<@20<K6aP80`<300P2VYZH208Z:
RP<0OGem0P1hN7P20820P080S8b<0P2@T90209>CT`80V9RH0`2LW9`209ZJVP80VIVI0P2ATI420:2P
X080WYjN0P2LW9`209ZJVP<0UiNG0P2>SXh208>3P`80NGUi0P1^KVh206EUI@80G5aL0`1BDU8604M7
A`80@D510P0m?Cd203hn?P<0A4A40P1<C4`205QHF080Jf][0P20P80209:BTP80XJ6Q0`2YZJT40:f]
[@80ZZZZ0P2[Zj/20:b/[080ZZZZ0`2YZJT20:^[Z`80[Jf]0P2^[Zh80<SPf0001P38h=P202DU9@80
9bLW0P0X:2P302XZ:P80:b/[0P11@D4404M7A`80DE5A0P12@T8303/k>`80?Shn0P0U9BD203Ph>080
Bd];0P19BDT202l_;`<0:BTY0P0_;bl203dm?@80;Rh^0P0/;2`202PX:0D0:BTY0P0[:b/202HV9P80
>3Ph0P19BDT206EUI@80Hf=S0P0e=CD302XZ:P80B4Q80P1RHV8202XZ:P80B4Q80P1KFe/202`/;0<0
;bl_0P1;Bd/202PX:0808b<S0P0O7al202LW9`80>c/k0`1TI6@208n?S`80VIVI0P2:RXX2061PH080
IVIV0P1iNGT309fMW@80^[Zj0P2d];@20:NWY`80Y:BT0P2_[jl20;:b/P<0]KFe0P2i^KT20;bl_080
`l?30P35aLD20;bl_080[jn_0`2QXJ4209JFUP80V9RH0P2OWil20:JVYP80[jn_0P2g]kL30;fm_@80
`<300P31`L420<C4a080aLG50P32`/820;Jf]P<0UYJF0P1jNWX207]kN`80QHF50P29RHT208j>SP80
U9BD0`2JVYX209VIV@80UYJF0P2CTi<209VIV@80Ti>C0P2;Rh/208R8R0<0Q8B40P1lO7`2079bLP80
J6QX0P1LG5`204a<C080@4100`13@d<204E5A@80@4100P0l?3`204A4A080Cdm?0P1EEED305eMG@80
Kfm_0P23Ph<208j>SP80UiNG0P2SXj<20:b/[0T0[jn_0P2`/;020;6a/@80[Zj^1@2/[:`20:f][@80
[Zj^2038h=P000H0b>3H0P0U9BD202LW9`80:2PX0`0Z:RX202/[:`80@D511017AdL2055AD@80@T92
0`0k>c/203hn?P809BDU0P0h>3P204];B`80BDU90P0_;bl302TY:@80;bl_0P0m?Cd202h^;P80;2`/
0P0X:2P502TY:@80:b/[0P0V9RH203Ph>080BDU90P1UIFD206=SH`80=CDe0`0Z:RX204Q8B080HV9R
0P0Z:RX204Q8B080Fe]K0P0/;2`302l_;`80Bd];0P0X:2P202<S8`807alO0P0W9bL203/k>`<0I6AT
0P2?Shl209VIV@80RXZ:0P1PH60206IVIP80NGUi0`2MWId20;Zj^P80];Bd0P2WYjL20:BTY080[jn_
0P2b/[830;Fe]@80^KVi0P2l_;`20<?3``80aLG50P2l_;`20:n_[`<0XJ6Q0P2FUYH209RHV080WinO
0P2VYZH20:n_[`80]kNg0`2m_Kd20<30`080`L710P34a<@20<G5a@80`/;20P2f][H309JFUP80NWYj
0P1kNg/208F5Q@80RHV90P2>SXh209BDU0<0VYZJ0P2IVIT209JFUP80Ti>C0P2IVIT209>CT`80Rh^;
0P28R8P308B4Q080O7al0P1bLW8206QXJ080G5aL0P1<C4`20410@0<0@d=30P15ADD20410@080?3`l
0P14A4@204m?C`80EEEE0`1MGEd206m_K`80Ph>30P2>SXh209NGU`80Xj>S0P2/[:`90:n_[`80/;2`
0P2a/K420:j^[PD0[:b/0P2][Jd20:j^[PP0b>3H00060<SPf08092@T0P0Y:BT202h^;P<0:RXZ0P0W
9bL202/[:`80=cLg0P0j>SX205EEE@80AdM70`0f=SH203<c<`80=cLg0P19BDT204I6AP80>c/k0P0_
;bl302d];@80;2`/0P0i>CT203<c<`80<30`0P0[:b/502`/;080<30`0P0X:2P204I6AP80GemO0P1/
K6`204e=C@80A4A40`0b<S8203dm?@80HF5Q0P0];Bd205eMG@80EEEE0P0S8b<302h^;P80EEEE0P0`
<30401lO7`80:RXZ0P0T92@30492@P80LW9b0P2JVYX209jNWP80K6a/0P1OGel205iNGP<0N7Qh0P2[
Zj/20;bl_080/;2`0P2UYJD20:b/[080[Zj^0`2b/[820;Bd]080]kNg0P2o_kl20<G5a@80`<300P2f
][H30:NWY`80VYZJ0P2GUiL209ZJVP80XJ6Q0P2ZZZX20;Bd]0<0_Kfm102n_[h20<30`080`/;20P34
a<@20<;2`P<0/;2`0P2IVIT208>3P`80Lg=c0P1hN7P208B4Q080Rh^;1@2ATI4208j>SP80SHf=0P29
RHT20861P@80N7Qh0P1dM7@3071`L080JVYZ0P1SHf<205QHF080CDe=0P14A4@203lo?`<0@d=31019
BDT204];B`80FEUI0P1YJFT207=cL`<0O7al0P2=SHd209fMW@80YJFU0P2[Zj/20;2`/080/k>c0`2a
/K420:n_[`80/;2`0P2c/k<20;Bd]080]KFe0P2b/[830;2`/080[Zj^102][Jd80<SPf0001P38h=P2
02@T9080:BTY0P0^;Rh302XZ:P809bLW0P0[:b/203Lg=`80>SXj0P1EEED204M7A`<0=SHf0P0c<c<2
03Lg=`80BDU90P16ATH203/k>`80;bl_0`0];Bd202`/;080>CTi0P0c<c<2030`<080:b/[1@0/;2`2
030`<080:2PX0P16ATH205mOG`80K6a/0P1=CDd204A4A0<0<S8b0P0m?Cd2065QH@80;Bd]0P1MGEd2
05EEE@808b<S0`0^;Rh205EEE@80<30`100O7al202XZ:P8092@T0`12@T82079bLP80VYZJ0P2NWYh2
06a/K080GemO0P1NGUh307QhN080Zj^[0P2l_;`20;2`/080YJFU0P2/[:`20:j^[P<0/[:b0P2d];@2
0;Ng]`80_kno0P35aLD20<30`080][Jf0`2WYjL209ZJVP80UiNG0P2JVYX20:6QX@80ZZZZ0P2d];@3
0;fm_@@0_[jn0P30`<020<;2`P80a<C40P32`/830;2`/080VIVI0P23Ph<207=cL`80N7Qh0P24Q8@2
08^;R`D0TI6A0P2>SXh208f=S@80RHV90P21PH4207QhN080M7Ad0`1`L70206YZJP80Hf=S0P1HF5P2
04e=C@80A4A40P0o?cl304=3@`@0BDU90P1;Bd/205UIF@80JFUY0P1cLg<307alO080SHf=0P2MWId2
0:FUY@80Zj^[0P2`/;020;>c/`<0/K6a0P2_[jl20;2`/080/k>c0P2d];@20;Fe]@80/[:b0`2`/;02
0:j^[P@0[Jf]2038h=P000H0b>3H0P0U9BD202TY:@80>3Ph0`0/;2`202TY:@80;2`/0P0e=CD2030`
<080>3Ph0P0e=CD3038b<P80=SHf0P0n?Sh204M7A`80>SXj0P0c<c<502d];@80;2`/0P0g=cL203Ph
>080<S8b0P0/;2`202d];@<0<C4a0P10@40204U9B@80C4a<0P1FEUH204m?C`80=CDe0P0h>3P303dm
?@80>3Ph0P1FEUH2034a<@80J6QX0P1:BTX202PX:0<0<C4a0P1MGEd203Ph>0@08R8R0P0[:b/201lO
7`<0;2`/0P1<C4`208F5Q@80X:2P0P25QHD206a/K080FEUI0`1VIVH208^;R`80ZZZZ0P2g]kL20;Fe
]@80ZJVY0P2ZZZX30:j^[P80/;2`0P2c/k<20;^k^`80`L710P30`<020;Zj^P<0ZZZZ0P2KVi/209RH
V080VYZJ0P2MWId20:>SX`80[jn_0`2k^k/20;jn_P80_kno0P32`/820<C4a0@0aLG50`37alL20<30
`080W9bL0P1fMWH206UYJ@80IVIV0P1]KFd3075aL@80MGEe101hN7P207AdM080KVi^0P1ZJVX206MW
I`<0I6AT0P1SHf<2065QH@80F5QH101@D50205=CD`<0F5QH0P1OGel206UYJ@80Lg=c0P1kNg/208B4
Q080S8b<0`2EUID20:2PX080ZZZZ0P2_[jl20;:b/P80]KFe0P2f][H30;Bd]0@0/K6a1P2c/k<20;:b
/P<0/K6a0P2_[jl40:b/[0P0b>3H00060<SPf0809BDU0P0Y:BT203Ph>0<0;2`/0P0Y:BT202`/;080
=CDe0P0`<30203Ph>080=CDe0`0b<S8203Hf=P80?Shn0P17AdL203Xj>P80<c<c1@0];Bd202`/;080
=cLg0P0h>3P2038b<P80;2`/0P0];Bd3034a<@80@4100P19BDT204a<C080EUIF0P1?Cdl203De=@80
>3Ph0`0m?Cd203Ph>080EUIF0P0a<C4206QXJ080BTY:0P0X:2P3034a<@80GEeM0P0h>3P4028R8P80
:b/[0P0O7al302`/;080C4a<0P25QHD20:2PX080QHF50P1/K6`205UIF@<0IVIV0P2;Rh/20:ZZZP80
]kNg0P2e]KD20:VYZ@80ZZZZ0`2^[Zh20;2`/080/k>c0P2k^k/20<71`@80`<300P2j^[X30:ZZZP80
Vi^K0P2HV9P209ZJVP80WIfM0P2SXj<20:n_[`<0^k^k0P2n_[h20;no_`80`/;20P34a<@40<G5a@<0
alO70P30`<0209bLW080MWIf0P1YJFT206IVIP80KFe]0`1aLG4207EeM@@0N7Qh0P1dM7@206i^KP80
JVYZ0P1WIfL306ATI080Hf=S0P1QHF4205QHF0@0D51@0P1CDe<305QHF080GemO0P1YJFT207=cL`80
Ng]k0P24Q8@208b<S0<0UIFE0P2PX:020:ZZZP80[jn_0P2b/[820;Fe]@80][Jf0`2d];@40;6a/@H0
/k>c0P2b/[830;6a/@80[jn_102/[:`80<SPf0001P38h=P202DU9@80:BTY0P0h>3P302`/;080:BTY
0P0/;2`203De=@80<30`0P0h>3P203De=@<0<S8b0P0f=SH203hn?P80AdM70P0j>SX203<c<`D0;Bd]
0P0/;2`203Lg=`80>3Ph0P0b<S8202`/;080;Bd]0`0a<C420410@080BDU90P1<C4`205IFEP80Cdm?
0P0e=CD203Ph>0<0?Cdm0P0h>3P205IFEP80<C4a0P1XJ6P204Y:BP80:2PX0`0a<C4205eMG@80>3Ph
100R8R8202/[:`807alO0`0/;2`204a<C080QHF50P2PX:0208F5Q@80K6a/0P1IFET306IVIP80Rh^;
0P2ZZZX20;Ng]`80]KFe0P2YZJT20:ZZZP<0[Zj^0P2`/;020;>c/`80^k^k0P31`L420<30`080^[Zj
0`2ZZZX209^KV`80V9RH0P2JVYX209fMW@80Xj>S0P2_[jl30;^k^`80_[jn0P2o_kl20<;2`P80a<C4
1035aLD30<O7a`80`<300P2LW9`207IfMP80JFUY0P1VIVH206e]K@<0LG5a0P1eMGD407QhN080M7Ad
0P1^KVh206YZJP80IfMW0`1TI6@206=SH`80HF5Q0P1HF5P4051@D080De=C0`1HF5P205mOG`80JFUY
0P1cLg<207]kN`80Q8B40P2<S8`309FEU@80X:2P0P2ZZZX20:n_[`80/[:b0P2e]KD20;Jf]P<0];Bd
102a/K460;>c/`80/[:b0`2a/K420:n_[`@0[:b/2038h=P000H0b>3H0P0V9RH202TY:@80@4100`0^
;Rh202`/;080;bl_0P0d=3@203Hf=P80=CDe0P0b<S8302h^;P80<S8b0P0d=3@203/k>`80<30`0P0_
;bl202d];@<0;2`/0P0];Bd203@d=080>SXj0P0c<c<202`/;080<C4a0`0h>3P203<c<`80=3@d0P0b
<S8204e=C@80@4100P0c<c<202XZ:P<0;Bd]0P0f=SH206ATI080B4Q80P1]KFd203hn?P80;bl_0`0c
<c<205iNGP80A4A40P0Y:BT2028R8P808B4Q0P0L71`3024Q8@80:b/[0P1WIfL209BDU080VIVI0P20
P802069RHP<0GemO0P1ZJVX2096AT@80][Jf0P32`/840:VYZ@<0ZZZZ0P2/[:`20:n_[`80][Jf0P2m
_Kd20;no_`80_;bl0`2/[:`209bLW080VYZJ102KVi/209fMW@80Zj^[0`2i^KT20;jn_P80`L710P33
`l<40<C4a0D0`/;20P2o_kl20;Zj^P80ZZZZ0P1mOGd2059BDP80F5QH0`1FEUH205aLG080H61P201Q
HF45061PH080I6AT0P1WIfL2061PH080G5aL0P1UIFD2071`L0<0MWIf0P1jNWX207moO`80QHF50P2A
TI4209fMW@80Xj>S0`2XZ:P20:b/[080[jn_0P2b/[820;Bd]080][Jf0P2g]kL30;Fe]@80/k>c102b
/[820;6a/@80/;2`0P2a/K430;:b/P80[jn_0P2][Jd20:b/[0P0b>3H00060<SPf0809RHV0P0Y:BT2
0410@0<0;Rh^0P0/;2`202l_;`80=3@d0P0f=SH203De=@80<S8b0`0^;Rh2038b<P80=3@d0P0k>c/2
030`<080;bl_0P0];Bd302`/;080;Bd]0P0d=3@203Xj>P80<c<c0P0/;2`2034a<@<0>3Ph0P0c<c<2
03@d=080<S8b0P1=CDd20410@080<c<c0P0Z:RX302d];@80=SHf0P1TI6@204Q8B080KFe]0P0n?Sh2
02l_;`<0<c<c0P1NGUh204A4A080:BTY0P0R8R82024Q8@8071`L0`0Q8B4202/[:`80IfMW0P2DU9@2
09VIV@80P8200P1RHV8305mOG`80JVYZ0P2ATI420;Jf]P80`/;2102YZJT30:ZZZP80[:b/0P2_[jl2
0;Jf]P80_Kfm0P2o_kl20;bl_0<0[:b/0P2LW9`209ZJVP@0Vi^K0P2MWId20:^[Z`<0^KVi0P2n_[h2
0<71`@80`l?31034a<@50<;2`P80_kno0P2j^[X20:ZZZP80OGem0P1BDU8205QHF0<0EUIF0P1LG5`2
061PH0P0HF5Q1@1PH60206ATI080IfMW0P1PH60205aLG080IFEU0P1`L70307IfMP80NWYj0P1oOgl2
08F5Q@80TI6A0P2MWId20:>SX`<0Z:RX0P2/[:`20:n_[`80/[:b0P2d];@20;Jf]P80]kNg0`2e]KD2
0;>c/`@0/[:b0P2a/K420;2`/080/K6a0`2b/[820:n_[`80[Jf]0P2/[:`80<SPf0001P38h=P202<S
8`80:BTY0P0j>SX302l_;`80<30`0P0g=cL203hn?P80>SXj0P0b<S82034a<@<0<c<c0P0_;bl203Hf
=P80?Shn0P0Z:RX402/[:`D0:BTY0P0];Bd2038b<P80<30`0P0];Bd2034a<@<0=CDe0P0h>3P203De
=@80:b/[0P1:BTX203De=@80;2`/0P0U9BD302XZ:P80<30`0P1MGEd205QHF080Jf][0P0l?3`202TY
:@<0;2`/0P1GEeL205eMG@@0<S8b0P0^;Rh202HV9PD08R8R0P15ADD206m_K`80TY:B0P2EUID207al
O0<0J6QX0P1LG5`207QhN080Vi^K0P2m_Kd20;Zj^P80/[:b0`2VYZH20:NWY`80Zj^[0P2b/[820;Ng
]`80^[Zj0P2i^KT30:f][@80X:2P0P2KVi/209ZJVP80VIVI0P2KVi/20:NWY`<0]KFe0P2l_;`20<71
`@80`/;20P31`L420<?3``80a<C40`32`/840<30`080_;bl0P2WYjL208b<S080Cdm?0`15ADD204M7
A`80E5AD0P1IFET205eMG@80IfMW0P1VIVH206UYJ@<0Jf][0P1bLW8207QhN0@0MgMg0P1nOWh208F5
Q@<0R8R80P2<S8`209:BTP80VIVI0P2PX:020:JVYP80ZZZZ0`2][Jd20;2`/080/K6a0P2b/[820;Bd
]080][Jf0P2g]kL30;Fe]@80/k>c0P2a/K460;2`/0D0/K6a102`/;020:n_[`P0b>3H00060<SPf080
8b<S0P0Y:BT203Xj>P<0;bl_0P0`<30203Lg=`80?Shn0P0j>SX2038b<P80<C4a0`0c<c<202l_;`80
=SHf0P0n?Sh202XZ:P@0:b/[1@0Y:BT202d];@80<S8b0P0`<30202d];@80<C4a0`0e=CD203Ph>080
=CDe0P0[:b/204Y:BP80=CDe0P0/;2`202DU9@<0:RXZ0P0`<30205eMG@80F5QH0P1[Jf/203`l?080
:BTY0`0/;2`205MGE`80GEeM100b<S8202h^;P809RHV1@0R8R8204E5A@80Kfm_0P2BTY8209FEU@80
O7al0`1XJ6P205aLG080N7Qh0P2KVi/20;fm_@80^[Zj0P2b/[830:JVYP80YjNW0P2[Zj/20;:b/P80
]kNg0P2j^[X20;Vi^@<0[Jf]0P2PX:0209^KV`80VYZJ0P2IVIT209^KV`80YjNW0`2e]KD20;bl_080
`L710P32`/820<71`@80`l?30P34a<@30<;2`P@0`<300P2l_;`20:NWY`80S8b<0P1?Cdl304E5A@80
AdM70P1DE5@205UIF@80GEeM0P1WIfL206IVIP80JFUY0`1[Jf/2079bLP80N7Qh101gMgL207inOP80
QHF50`28R8P208b<S080TY:B0P2IVIT20:2PX080YZJV0P2ZZZX30:f][@80/;2`0P2a/K420;:b/P80
];Bd0P2f][H20;Ng]`<0]KFe0P2c/k<20;6a/@H0/;2`1@2a/K440;2`/080[jn_2038h=P000H0b>3H
0P0P820202PX:080<S8b1@0a<C4203`l?080ATI60P18B4P204M7A`80@4100`0j>SX202l_;`80>SXj
0P13@d<602/[:`<0:2PX0P0V9RH202LW9`80:BTY0P0/;2`202l_;`80<C4a0`0b<S8203Ph>080<30`
0P0a<C4205]KF`80@D510P0Y:BT2028R8P<09bLW0P0Z:RX205ADE080IVIV0P1ZJVX203`l?0808b<S
0`0U9BD204];B`80Kfm_0P0n?Sh204Y:BP80Bd];0P0k>c/302PX:0808b<S0P0Y:BT204M7A`80OGem
0P2OWil209JFUP<0MgMg0P1IFET2069RHP80NWYj0P2][Jd20<O7a`80^[Zj0`2UYJD20:BTY080Z:RX
0P2][Jd20;:b/P@0]KFe0`2][Jd20:BTY080WIfM0P2IVIT209RHV080Vi^K0P2UYJD30;6a/@80^[Zj
1030`<020;jn_P80`L710P34a<@30<30`080^k^k0P2j^[X20;Vi^@80_;bl0P2f][H209fMW@<0KFe]
0P1CDe<204A4A080D51@0P1RHV8207AdM080LG5a0P1gMgL307alO080Ph>30P2:RXX208n?S`80Ti>C
0P2DU9@209FEU@<0UiNG0P2IVIT209nOW`80YJFU0P2XZ:P20:ZZZP80[:b/0`2][Jd20:n_[`H0/K6a
0P2d];@20;Jf]P<0]KFe0P2b/[820;6a/@80[jn_0P2`/;070;6a/@80/[:b102c/k<80<SPf0001P38
h=P2020P8080:2PX0P0b<S85034a<@80?3`l0P16ATH204Q8B080AdM70P10@40303Xj>P80;bl_0P0j
>SX204=3@`H0:b/[0`0X:2P202HV9P809bLW0P0Y:BT202`/;080;bl_0P0a<C43038b<P80>3Ph0P0`
<302034a<@80Fe]K0P11@D4202TY:@808R8R0`0W9bL202XZ:P80E5AD0P1VIVH206YZJP80?3`l0P0S
8b<302DU9@80Bd];0P1_Kfl203hn?P80BTY:0P1;Bd/203/k>`<0:2PX0P0S8b<202TY:@80AdM70P1m
OGd209nOW`80UYJF0`1gMgL205UIF@80HV9R0P1jNWX20:f][@80alO70P2j^[X30:FUY@80Y:BT0P2X
Z:P20:f][@80/[:b102e]KD30:f][@80Y:BT0P2MWId209VIV@80V9RH0P2KVi/20:FUY@<0/K6a0P2j
^[X40<30`080_[jn0P31`L420<C4a0<0`<300P2k^k/20;Zj^P80^KVi0P2l_;`20;Jf]P80WIfM0`1]
KFd205=CD`80A4A40P1@D502069RHP80M7Ad0P1aLG4207MgM`<0O7al0P23Ph<208Z:RP80Shn?0P2C
Ti<209BDU080UIFE0`2GUiL209VIV@80WinO0P2UYJD20:RXZ080ZZZZ0P2/[:`30:f][@80[jn_1P2a
/K420;Bd]080][Jf0`2e]KD20;:b/P80/K6a0P2_[jl20;2`/0L0/K6a0P2b/[840;>c/`P0b>3H0006
0<SPf0807alO0P0V9RH202`/;0<0=CDe0P0[:b/202`/;080;bl_0P14A4@205UIF@80GemO0`1MGEd2
05EEE@80AdM70P15ADD20410@080>CTi0P0b<S8302d];@809bLW0P0X:2P202XZ:P80;2`/0P0`<302
03@d=0<0=cLg0P0e=CD202h^;P80;bl_0P1DE5@205QHF080:2PX1@0U9BD202XZ:P80@d=30P1SHf<2
06QXJ080>CTi0P0U9BD302@T9080>c/k0P1SHf<204E5A@80;Rh^0P0k>c/203Lg=`<0<S8b0P0Z:RX2
02HV9P80<S8b0P1CDe<208J6QP80W9bL0`2;Rh/206ATI080GEeM0P1TI6@208Z:RP80/[:b0P2l_;`3
0;6a/@80Z:RX0P2SXj<20:VYZ@80[jn_102a/K430:j^[P80Z:RX0P2RXZ8209fMW@80Vi^K0P2NWYh2
0:NWY`<0/K6a0P2j^[X20<30`080_kno0P2l_;`20;jn_P80_kno0`2n_[h20;bl_080^KVi0P2g]kL4
0;Vi^@80]KFe0`2VYZH208Z:RP80L71`0P1ZJVX206e]K@80NWYj0P1oOgl208J6QP<0Rh^;0P2@T902
09BDU080VIVI0P2LW9`209jNWP80WinO0`2PX:020::RXP80YJFU0P2YZJT40:ZZZP80[:b/0`2_[jl4
0;2`/0@0/K6a0P2c/k<70;Bd]080/[:b1P2a/K420;:b/P<0/k>c0P2e]KD40;Jf]PP0b>3H00060<SP
f0807alO0P0V9RH202`/;0<0=CDe0P0[:b/202`/;080;bl_0P14A4@205UIF@80GemO0`1MGEd205EE
E@80AdM70P15ADD20410@080>CTi0P0b<S8302d];@809bLW0P0X:2P202XZ:P80;2`/0P0`<30203@d
=0<0=cLg0P0e=CD202h^;P80;bl_0P1DE5@205QHF080:2PX1@0U9BD202XZ:P80@d=30P1SHf<206QX
J080>CTi0P0U9BD302@T9080>c/k0P1SHf<204E5A@80;Rh^0P0k>c/203Lg=`<0<S8b0P0Z:RX202HV
9P80<S8b0P1CDe<208J6QP80W9bL0`2;Rh/206ATI080GEeM0P1TI6@208Z:RP80/[:b0P2l_;`30;6a
/@80Z:RX0P2SXj<20:VYZ@80[jn_102a/K430:j^[P80Z:RX0P2RXZ8209fMW@80Vi^K0P2NWYh20:NW
Y`<0/K6a0P2j^[X20<30`080_kno0P2l_;`20;jn_P80_kno0`2n_[h20;bl_080^KVi0P2g]kL40;Vi
^@80]KFe0`2VYZH208Z:RP80L71`0P1ZJVX206e]K@80NWYj0P1oOgl208J6QP<0Rh^;0P2@T90209BD
U080VIVI0P2LW9`209jNWP80WinO0`2PX:020::RXP80YJFU0P2YZJT40:ZZZP80[:b/0`2_[jl40;2`
/0@0/K6a0P2c/k<70;Bd]080/[:b1P2a/K420;:b/P<0/k>c0P2e]KD40;Jf]PP0b>3H00060<SPf080
8R8R0P0U9BD202PX:0<0=SHf0P0U9BD202TY:@80;Bd]0P0i>CT204M7A`80F5QH0`1SHf<206a/K080
EUIF0P1:BTX205=CD`80AdM70P0j>SX3038b<P@0:b/[0P0/;2`202d];@80<30`0P0g=cL303dm?@80
<S8b0P0[:b/202d];@80Bd];0P1_Kfl202`/;080:BTY0`0T92@202XZ:P80=3@d0P1TI6@207EeM@80
?clo0P0Y:BT302<S8`80;2`/0P1KFe/206IVIP80:RXZ0P0Y:BT202h^;P<0>SXj0P0b<S8202PX:080
92@T0P0[:b/206=SH`80U9BD0`2GUiL2079bLP80GemO0P1FEUH206UYJ@80UYJF0P2d];@30;Rh^080
[Zj^0P2RXZ820:JVYP80[:b/1`2][Jd20:^[Z`80YZJV0P2PX:0209nOW`80X:2P0P2XZ:P30;:b/P80
^[Zj0P30`<020;jn_P80^k^k0P2j^[X20;^k^`D0_;bl0P2g]kL20;:b/P80/K6a102b/[830;>c/`80
Zj^[0P2PX:0208^;R`80Ng]k0P21PH4208f=S@80Ti>C0`2HV9P209ZJVP80Vi^K0P2NWYh20:2PX080
Xj>S0P2UYJD30:JVYP@0YjNW102XZ:P20:VYZ@80[:b/0`2^[Zh40:n_[`80/;2`102b/[820;6a/@<0
/k>c0P2e]KD20;Bd]080/k>c102a/K420;>c/`<0]KFe0P2g]kL40;Rh^0P0b>3H00060<SPf0808R8R
0P0U9BD202PX:0<0=SHf0P0U9BD202TY:@80;Bd]0P0i>CT204M7A`80F5QH0`1SHf<206a/K080EUIF
0P1:BTX205=CD`80AdM70P0j>SX3038b<P@0:b/[0P0/;2`202d];@80<30`0P0g=cL303dm?@80<S8b
0P0[:b/202d];@80Bd];0P1_Kfl202`/;080:BTY0`0T92@202XZ:P80=3@d0P1TI6@207EeM@80?clo
0P0Y:BT302<S8`80;2`/0P1KFe/206IVIP80:RXZ0P0Y:BT202h^;P<0>SXj0P0b<S8202PX:08092@T
0P0[:b/206=SH`80U9BD0`2GUiL2079bLP80GemO0P1FEUH206UYJ@80UYJF0P2d];@30;Rh^080[Zj^
0P2RXZ820:JVYP80[:b/1`2][Jd20:^[Z`80YZJV0P2PX:0209nOW`80X:2P0P2XZ:P30;:b/P80^[Zj
0P30`<020;jn_P80^k^k0P2j^[X20;^k^`D0_;bl0P2g]kL20;:b/P80/K6a102b/[830;>c/`80Zj^[
0P2PX:0208^;R`80Ng]k0P21PH4208f=S@80Ti>C0`2HV9P209ZJVP80Vi^K0P2NWYh20:2PX080Xj>S
0P2UYJD30:JVYP@0YjNW102XZ:P20:VYZ@80[:b/0`2^[Zh40:n_[`80/;2`102b/[820;6a/@<0/k>c
0P2e]KD20;Bd]080/k>c102a/K420;>c/`<0]KFe0P2g]kL40;Rh^0P0b>3H00060<SPf080;2`/0P0Y
:BT202@T90<0<S8b0P0a<C4202PX:080=CDe0P0m?Cd204I6AP80BDU90`1>CTh206IVIP80Lg=c0P1T
I6@204U9B@80B4Q80P19BDT303Ti>@80<30`0P0V9RH202XZ:P80:b/[0P0];Bd503Xj>P80;bl_0P0W
9bL202XZ:P80@T920P1aLG4203/k>`80:2PX0`0V9RH202`/;080>3Ph0P1RHV8206i^KP80?Cdm0P0d
=3@302h^;P809bLW0P18B4P207QhN080>SXj0P0[:b/2024Q8@<0=3@d0P0b<S8202l_;`809BDU0P0T
92@20451@@80LG5a0`2ATI4208^;R`80K6a/0P1GEeL205IFEP80L71`0P2EUID30;Jf]P80^;Rh0P2Q
XJ4209fMW@80YJFU1`2XZ:P20:NWY`80Xj>S0P2OWil209jNWP80XJ6Q0P2XZ:P30;6a/@80^[Zj0P30
`<020;no_`80_;bl0P2i^KT20;Ng]`<0^[Zj0P2k^k/20;Jf]P80/;2`102a/K420;Bd]0<0/;2`0P2a
/K420;2`/080YjNW0P2MWId209NGU`80UIFE0P2GUiL309^KV`80WYjN0P2QXJ420:>SX`80Y:BT0P2U
YJD;0:JVYP80YjNW0P2YZJT20:ZZZP<0Zj^[0P2][Jd20:j^[P80/;2`0P2b/[820;6a/@80/;2`0`2a
/K440;>c/`@0/[:b1`2a/K420;Bd]0@0^;Rh2038h=P000H0b>3H0P0/;2`202TY:@8092@T0`0b<S82
034a<@80:2PX0P0e=CD203dm?@80ATI60P19BDT304i>CP80IVIV0P1cLg<206ATI080BDU90P18B4P2
04U9B@<0>CTi0P0`<30202HV9P80:RXZ0P0[:b/202d];@D0>SXj0P0_;bl202LW9`80:RXZ0P12@T82
075aL@80>c/k0P0X:2P302HV9P80;2`/0P0h>3P2069RHP80KVi^0P0m?Cd203@d=0<0;Rh^0P0W9bL2
04Q8B080N7Qh0P0j>SX202/[:`808B4Q0`0d=3@2038b<P80;bl_0P0U9BD202@T9080@D510P1aLG43
096AT@80Rh^;0P1/K6`205MGE`80EUIF0P1`L70209FEU@<0][Jf0P2h^;P20:6QX@80WIfM0P2UYJD7
0:RXZ080YjNW0P2SXj<209nOW`80WYjN0P2QXJ420:RXZ0<0/K6a0P2j^[X20<30`080_kno0P2l_;`2
0;Vi^@80]kNg0`2j^[X20;^k^`80][Jf0P2`/;040;6a/@80];Bd0`2`/;020;6a/@80/;2`0P2WYjL2
09fMW@80UiNG0P2EUID209NGU`<0Vi^K0P2NWYh20:6QX@80Xj>S0P2TY:@20:FUY@/0YZJV0P2WYjL2
0:VYZ@80ZZZZ0`2[Zj/20:f][@80[Zj^0P2`/;020;:b/P80/K6a0P2`/;030;6a/@@0/k>c102b/[87
0;6a/@80];Bd102h^;P80<SPf0001P38h=P203Hf=P80<c<c0P0S8b<302d];@80?3`l0P0[:b/203hn
?P80?clo0P10@40203Hf=P<0=3@d0P1:BTX206e]K@80K6a/100o?cl204=3@`<0=CDe0P0f=SH202@T
90809bLW0P0X:2P202/[:`80>c/k0`0f=SH202d];@8092@T0P0W9bL203Xj>P80JVYZ0P1<C4`502LW
9`80;bl_0P10@40205eMG@80HV9R0P0i>CT203`l?0<0>c/k0P0Y:BT202HV9P80Fe]K0P1hN7P20410
@0809bLW0`0];Bd202DU9@808b<S0P0P820202DU9@80:2PX0P1;Bd/307MgM`80RXZ:0P1`L702065Q
H@80GEeM0P1SHf<207EeM@<0Vi^K0P2j^[X20;:b/PH0XJ6Q1@2TY:@20:>SX`80X:2P0P2MWId209jN
WP80XJ6Q0P2XZ:P30;2`/080^KVi1030`<020;fm_@80^KVi0P2e]KD30;Rh^080^[Zj0P2e]KD40:j^
[P80[Jf]0P2k^k/30;Fe]@80[jn_0P2VYZH40:NWY`80XZ:R0P2MWId509^KV`80WinO0P2TY:@80:FU
Y@<0Y:BT1P2SXj<20:JVYP@0Z:RX0`2WYjL20:ZZZP80[Jf]0P2`/;020;:b/P80/;2`1@2_[jl20;2`
/0@0/K6a102b/[820;2`/0<0[Zj^0P2b/[820;Rh^080^KVi2038h=P000H0b>3H0P0f=SH203<c<`80
8b<S0`0];Bd203`l?080:b/[0P0n?Sh203lo?`80@4100P0f=SH303@d=080BTY:0P1]KFd206a/K0@0
?clo0P13@d<303De=@80=SHf0P0T92@202LW9`80:2PX0P0[:b/203/k>`<0=SHf0P0];Bd202@T9080
9bLW0P0j>SX206YZJP80C4a<1@0W9bL202l_;`80@4100P1MGEd2069RHP80>CTi0P0l?3`303/k>`80
:BTY0P0V9RH205]KF`80N7Qh0P10@40202LW9`<0;Bd]0P0U9BD202<S8`80820P0P0U9BD202PX:080
Bd];0`1gMgL208Z:RP80L71`0P1QHF4205eMG@80Hf=S0P1eMGD309^KV`80^[Zj0P2b/[860:6QX@D0
Y:BT0P2SXj<20:2PX080WIfM0P2NWYh20:6QX@80Z:RX0`2`/;020;Vi^@@0`<300P2m_Kd20;Vi^@80
]KFe0`2h^;P20;Zj^P80]KFe102^[Zh20:f][@80^k^k0`2e]KD20:n_[`80YZJV102WYjL20::RXP80
WIfM1@2KVi/209nOW`80Y:BT202UYJD30:BTY0H0Xj>S0P2VYZH40:RXZ0<0YjNW0P2ZZZX20:f][@80
/;2`0P2b/[820;2`/0D0[jn_0P2`/;040;6a/@@0/[:b0P2`/;030:j^[P80/[:b0P2h^;P20;Vi^@P0
b>3H00060<SPf080>c/k0P1>CTh202`/;0<0:2PX0P0d=3@203<c<`80=CDe0P0c<c<2034a<@D0;Bd]
0P0`<30204M7A`80IfMW0P1[Jf/206=SH`80BTY:0`0c<c<203Lg=`80;2`/0P0V9RH202LW9`80;2`/
1@0i>CT202l_;`809bLW0P0X:2P203@d=0@0GEeM0P0Y:BT302@T9080;bl_0P14A4@204];B`80DE5A
0P0l?3`203lo?`<0?3`l0P0`<30202HV9P80ADE50P1aLG4206YZJP80ADE50`0Z:RX4024Q8@807alO
0P0Q8B42020P8080<S8b0`1BDU82071`L080OGem0P1nOWh2075aL@80J6QX0P1/K6`308>3P`80Xj>S
0P2^[Zh20;6a/@80YZJV0P2MWId70:6QX@80X:2P0P2OWil20:2PX080XZ:R0P2YZJT30;2`/080^;Rh
102o_kl20;bl_080^KVi0P2g]kL30;Vi^@80^k^k0P2e]KD20:j^[P80XJ6Q0P2OWil20;Bd]0<0][Jf
0P2e]KD20;2`/080Z:RX0P2YZJT20:JVYP80XZ:R0P2NWYh309^KV`80WIfM0P2PX:020::RXP80Y:BT
0P2UYJD20:JVYP<0Y:BT102QXJ420::RXP80Y:BT0P2WYjL50:JVYP80ZZZZ0P2][Jd20:n_[`80/;2`
0P2_[jl50:j^[P80[jn_0P2a/K420;:b/P80/k>c0P2d];@20;:b/P<0/K6a0P2e]KD20;Vi^@80^[Zj
2038h=P000H0b>3H0P0k>c/204i>CP80;2`/0`0X:2P203@d=080<c<c0P0e=CD203<c<`80<C4a1@0]
;Bd2030`<080AdM70P1WIfL206][J`80Hf=S0P1:BTX303<c<`80=cLg0P0/;2`202HV9P809bLW0P0/
;2`503Ti>@80;bl_0P0W9bL202PX:080=3@d101MGEd202TY:@<092@T0P0_;bl204A4A080Bd];0P1A
DE4203`l?080?clo0`0l?3`2030`<0809RHV0P15ADD2075aL@80JVYZ0P15ADD302XZ:P@08B4Q0P0O
7al2024Q8@80820P0P0b<S83059BDP80L71`0P1mOGd207inOP80LG5a0P1XJ6P206a/K0<0Ph>30P2S
Xj<20:j^[P80/K6a0P2VYZH209fMW@L0XJ6Q0P2PX:0209nOW`80X:2P0P2RXZ820:VYZ@<0/;2`0P2h
^;P40;no_`80_;bl0P2i^KT20;Ng]`<0^KVi0P2k^k/20;Fe]@80[Zj^0P2QXJ4209nOW`80];Bd0`2f
][H20;Fe]@80/;2`0P2XZ:P20:VYZ@80YZJV0P2RXZ8209jNWP<0Vi^K0P2MWId20:2PX080XZ:R0P2T
Y:@20:FUY@80YZJV0`2TY:@40:6QX@80XZ:R0P2TY:@20:NWY`D0YZJV0P2ZZZX20:f][@80[jn_0P2`
/;020:n_[`D0[Zj^0P2_[jl20;6a/@80/[:b0P2c/k<20;Bd]080/[:b0`2a/K420;Fe]@80^KVi0P2j
^[X80<SPf0001P38h=P203/k>`80CTi>0P0/;2`302PX:080=3@d0P0c<c<203De=@80<c<c0P0a<C45
02d];@80<30`0P17AdL206MWI`80Jf][0P1SHf<204Y:BP<0<c<c0P0g=cL202`/;0809RHV0P0W9bL2
02`/;0D0>CTi0P0_;bl202LW9`80:2PX0P0d=3@405eMG@80:BTY0`0T92@202l_;`80A4A40P1;Bd/2
055AD@80?3`l0P0o?cl303`l?080<30`0P0V9RH204E5A@80LG5a0P1ZJVX204E5A@<0:RXZ100Q8B42
01lO7`808B4Q0P0P8202038b<P<0DU9B0P1`L70207emO@80OWin0P1aLG4206QXJ080K6a/0`23Ph<2
0:>SX`80[Zj^0P2a/K420:JVYP80WIfM1`2QXJ420:2PX080WinO0P2PX:020::RXP80ZJVY0`2`/;02
0;Rh^0@0_kno0P2l_;`20;Vi^@80]kNg0`2i^KT20;^k^`80]KFe0P2^[Zh20:6QX@80WinO0P2d];@3
0;Jf]P80]KFe0P2`/;020:RXZ080ZJVY0P2VYZH20::RXP80WYjN0`2KVi/209fMW@80X:2P0P2RXZ82
0:BTY080YJFU0P2VYZH30:BTY0@0XJ6Q0P2RXZ820:BTY080YjNW1@2VYZH20:ZZZP80[Jf]0P2_[jl2
0;2`/080[jn_1@2^[Zh20:n_[`80/K6a0P2b/[820;>c/`80];Bd0P2b/[830;6a/@80]KFe0P2i^KT2
0;Zj^PP0b>3H00060<SPf080?Cdm0P1QHF4203De=@<092@T0P0X:2P203/k>`80:RXZ0P0W9bL202<S
8`809bLW0`0/;2`203<c<`80?Shn0P1?Cdl2061PH080KVi^0P1RHV830492@P80=cLg0P0d=3@202DU
9@80:2PX0P0];Bd203De=@<0>c/k0P0b<S8202XZ:P80:BTY0P0_;bl204e=C@80J6QX0P0^;Rh3028R
8P80<C4a0P1:BTX203/k>`80@D510P0d=3@202XZ:P<0;Rh^0P0f=SH202l_;`80;Rh^0P1QHF4208f=
S@80HV9R0`0Y:BT201hN7P807alO0P0M7Ad401hN7P809BDU0`14A4@206][J`80Shn?0P2CTi<208N7
Q`80MgMg0P1^KVh306e]K@80R8R80P2UYJD20;^k^`80[Jf]0P2LW9`20:2PX0<0WinO1P2QXJ420::R
XP80Y:BT0P2ZZZX30;6a/@80^;Rh102m_Kd20;^k^`@0^[Zj0`2k^k/20;Zj^P80]KFe0P2][Jd209:B
TP80T92@0P2][Jd30;Jf]P80^[Zj0P2h^;P20:NWY`80Z:RX102VYZH20:6QX@<0W9bL0P2JVYX209^K
V`80WIfM0P2QXJ420:BTY080YZJV0`2SXj<409nOW`80XJ6Q0P2SXj<40:FUY@<0YZJV0P2ZZZX20:f]
[@H0[Zj^0P2][Jd30:j^[P80[jn_0P2a/K420;:b/P80];Bd1`2e]KD20;Rh^0@0^k^k2038h=P000H0
b>3H0P0m?Cd2065QH@80=CDe0`0T92@202PX:080>c/k0P0Z:RX202LW9`808b<S0P0W9bL302`/;080
<c<c0P0n?Sh204m?C`80H61P0P1^KVh2069RHP<0@T920P0g=cL203@d=0809BDU0P0X:2P202d];@80
=CDe0`0k>c/2038b<P80:RXZ0P0Y:BT202l_;`80CDe=0P1XJ6P202h^;P<08R8R0P0a<C4204Y:BP80
>c/k0P11@D4203@d=080:RXZ0`0^;Rh203Hf=P80;bl_0P0^;Rh2065QH@80SHf=0P1RHV8302TY:@80
7QhN0P0O7al201dM7@@07QhN0P0U9BD304A4A080Jf][0P2?Shl209>CT`80QhN70P1gMgL206i^KP<0
KFe]0P28R8P20:FUY@80^k^k0P2][Jd209bLW080X:2P0`2OWil60:6QX@80XZ:R0P2TY:@20:ZZZP<0
/K6a0P2h^;P40;fm_@80^k^k102j^[X30;^k^`80^[Zj0P2e]KD20:f][@80TY:B0P2@T9020:f][@<0
][Jf0P2j^[X20;Rh^080YjNW0P2XZ:P40:JVYP80XJ6Q0`2LW9`209ZJVP80Vi^K0P2MWId20:6QX@80
Y:BT0P2VYZH30:>SX`@0WinO0P2QXJ420:>SX`@0YJFU0`2VYZH20:ZZZP80[Jf]1P2^[Zh20:f][@<0
[Zj^0P2_[jl20;6a/@80/[:b0P2d];@70;Fe]@80^;Rh102k^k/80<SPf0001P38h=P202@T90@0CDe=
0`0j>SX202d];@80>CTi0P0Y:BT202DU9@808R8R0P0W9bL303Xj>P80DE5A0P18B4P20410@080>c/k
0P1CDe<205iNGP<0D51@0P0m?Cd203De=@809bLW0P0Y:BT202l_;`80<c<c1@0f=SH202/[:`80:2PX
0P0/;2`204=3@`80IVIV0P0i>CT302HV9P80>c/k0P1GEeL403De=@80=SHf0P0V9RH302TY:@80<30`
0P0h>3P2030`<080EeMG0P1kNg/205EEE@<092@T0P0M7Ad2020P80807AdM0P0N7Qh2028R8P80<c<c
0`1NGUh206QXJ080Ph>30P2DU9@209jNWP80SHf=0P1iNGT306YZJP80N7Qh0P2>SXh20:6QX@80[jn_
0P2ZZZX50:2PX0@0XJ6Q0P2RXZ820:BTY080YjNW0P2^[Zh30;Fe]@80^[Zj0P2l_;`20;^k^`80^KVi
102k^k/30;Zj^P80][Jf0P2^[Zh20::RXP80PX:20P24Q8@20:ZZZP<0/[:b0P2m_Kd20<30`080];Bd
0P2_[jl20:ZZZP80YZJV0P2QXJ4309fMW@80VYZJ0P2IVIT209ZJVP80W9bL0P2NWYh20:2PX0<0WinO
0P2LW9`209jNWP80XJ6Q0P2RXZ820:>SX`80Y:BT0`2VYZH20:VYZ@80[:b/102][Jd40:b/[0<0[Zj^
0P2`/;020;6a/@80/[:b0P2c/k<70;Fe]@80^;Rh0P2l_;`20;fm_@P0b>3H00060<SPf08092@T101=
CDd303Xj>P80;Bd]0P0i>CT202TY:@809BDU0P0R8R8202LW9`<0>SXj0P1ADE4204Q8B080@4100P0k
>c/205=CD`80GUiN0`1@D50203dm?@80=CDe0P0W9bL202TY:@80;bl_0P0c<c<503Hf=P80:b/[0P0X
:2P202`/;080@d=30P1VIVH203Ti>@<09RHV0P0k>c/205MGE`@0=CDe0P0f=SH202HV9P<0:BTY0P0`
<30203Ph>080<30`0P1GEeL207]kN`80EEEE0`0T92@201dM7@80820P0P0M7Ad201hN7P808R8R0P0c
<c<305iNGP80J6QX0P23Ph<209BDU080WYjN0P2=SHd207UiN@<0JVYZ0P1hN7P208j>SP80XJ6Q0P2_
[jl20:ZZZPD0X:2P102QXJ420::RXP80Y:BT0P2WYjL20:j^[P<0]KFe0P2j^[X20;bl_080^k^k0P2i
^KT40;^k^`<0^[Zj0P2f][H20:j^[P80XZ:R0P22PX8208B4Q080ZZZZ0`2b/[820;fm_@80`<300P2d
];@20:n_[`80ZZZZ0P2VYZH20:6QX@<0WIfM0P2JVYX209VIV@80VYZJ0P2LW9`209jNWP80X:2P0`2O
Wil209bLW080WYjN0P2QXJ420::RXP80Xj>S0P2TY:@30:JVYP80ZJVY0P2/[:`40:f][@@0[:b/0`2^
[Zh20;2`/080/K6a0P2b/[820;>c/`L0]KFe0P2h^;P20;bl_080_Kfm2038h=P000H0b>3H0P0W9bL2
038b<P80@T920`0f=SH202HV9P80;bl_0P0/;2`402PX:080<C4a0`1<C4`205iNGP80>SXj0P0_;bl2
02TY:@80?Shn0P1CDe<305UIF@80ADE50P0g=cL402/[:`80;Rh^0P0a<C43038b<P80>SXj0P0/;2`2
02PX:080:b/[0P0j>SX205mOG`80ADE50`0[:b/204A4A080GemO0P0b<S8202h^;P80=SHf0P0U9BD3
02TY:@80;Bd]0P0o?cl203Lg=`80Cdm?0P1OGel20492@P<08B4Q0P0N7Qh202<S8`807alO0P0Q8B42
02XZ:P80CDe=0`20P80206MWI`80GemO0P1bLW8209bLW080WinO0P2:RXX3071`L080Kfm_0P1hN7P2
08>3P`80ZZZZ0P2d];@50::RXP80XJ6Q0P2RXZ820:>SX`80YZJV0P2[Zj/20;:b/P<0^;Rh0P2k^k/2
0;bl_080^[Zj0P2h^;P20;^k^`80_;bl0`2h^;P20;6a/@80YJFU0P2GUiL207IfMP80OGem0P2YZJT3
0:f][@80_Kfm0P34a<@20<30`080]kNg0P2^[Zh20:JVYP80XZ:R0`2OWil209bLW080VIVI102HV9P2
09VIV@80Vi^K1@2JVYX209fMW@H0XJ6Q0P2SXj<30:JVYP80ZJVY0P2[Zj/40:b/[0@0Zj^[0`2^[Zh6
0;6a/@80/k>c1`2d];@20;Vi^@80_;bl0P2m_Kd80<SPf0001P38h=P202LW9`80<S8b0P12@T8303Hf
=P809RHV0P0_;bl202`/;0@0:2PX0P0a<C4304a<C080GUiN0P0j>SX202l_;`80:BTY0P0n?Sh205=C
D`<0FEUI0P15ADD203Lg=`@0:b/[0P0^;Rh2034a<@<0<S8b0P0j>SX202`/;080:2PX0P0[:b/203Xj
>P80GemO0P15ADD302/[:`80A4A40P1OGel2038b<P80;Rh^0P0f=SH202DU9@<0:BTY0P0];Bd203lo
?`80=cLg0P1?Cdl205mOG`80@T920`0Q8B4201hN7P808b<S0P0O7al2024Q8@80:RXZ0P1=CDd30820
P080IfMW0P1OGel2079bLP80W9bL0P2OWil208Z:RP<0L71`0P1_Kfl207QhN080Ph>30P2ZZZX20;Bd
]0D0XZ:R0P2QXJ420::RXP80Xj>S0P2VYZH20:^[Z`80/[:b0`2h^;P20;^k^`80_;bl0P2j^[X20;Rh
^080^k^k0P2l_;`30;Rh^080/K6a0P2UYJD209NGU`80MWIf0P1mOGd20:VYZ@<0[Jf]0P2m_Kd20<C4
a080`<300P2g]kL20:j^[P80YZJV0P2RXZ8309nOW`80W9bL0P2IVIT409RHV080VIVI0P2KVi/509ZJ
VP80WIfM1P2QXJ420:>SX`<0YZJV0P2YZJT20:^[Z`@0[:b/102[Zj/30:j^[PH0/K6a0P2c/k<70;Bd
]080^KVi0P2l_;`20;fm_@P0b>3H00060<SPf08092@T0P0[:b/203Ph>0<0<S8b0P0Y:BT202/[:`80
:BTY0P0^;Rh203@d=080Cdm?0`1LG5`204i>CP80=3@d0P0Z:RX202PX:080=3@d0P14A4@305ADE080
DU9B0P0o?cl202l_;`80<S8b0P0h>3P203Lg=`<0<c<c0P0l?3`202`/;080:BTY0P0[:b/203De=@80
EEEE0P1>CTh302d];@80?Cdm0P1>CTh402h^;P80<c<c0P0];Bd303Xj>P80@D51100b<S8204i>CP80
EUIF0P0n?Sh302@T9080820P0P0R8R8201dM7@808b<S0P0d=3@207=cL`<0Q8B40P1IFET203`l?080
DE5A0P21PH4209bLW080V9RH0`21PH4206i^KP80M7Ad0P1nOWh209FEU@80ZJVY0P2[Zj/30:NWY`80
WinO0P2RXZ820:JVYP80ZZZZ0P2_[jl20;6a/@<0];Bd0P2k^k/20<30`080_;bl0P2h^;P20;^k^`80
_Kfm0`2g]kL20:n_[`80UYJF0P2HV9P207MgM`80PH611@2/[:`20;Zj^P80`<300P32`/820;no_`80
]kNg0P2^[Zh20:RXZ0<0Y:BT0P2NWYh209^KV`80WYjN0P2QXJ420:BTY080WYjN0`2FUYH209VIV@80
W9bL0P2PX:020::RXPL0Xj>S0P2WYjL20:^[Z`H0[:b/0P2][Jd30:j^[P80/;2`1P2a/K420;:b/P80
];Bd0`2g]kL20;Zj^P80_;bl0P2m_Kd80<SPf0001P38h=P202@T9080:b/[0P0h>3P3038b<P80:BTY
0P0[:b/202TY:@80;Rh^0P0d=3@204m?C`<0G5aL0P1>CTh203@d=080:RXZ0P0X:2P203@d=080A4A4
0`1DE5@2059BDP80?clo0P0_;bl2038b<P80>3Ph0P0g=cL303<c<`80?3`l0P0/;2`202TY:@80:b/[
0P0e=CD205EEE@80CTi>0`0];Bd203dm?@80CTi>100^;Rh203<c<`80;Bd]0`0j>SX20451@@@0<S8b
0P1>CTh205IFEP80?Shn0`0T92@2020P80808R8R0P0M7Ad202<S8`80=3@d0P1cLg<308B4Q080FEUI
0P0l?3`2055AD@80PH610P2LW9`209RHV0<0PH610P1^KVh207AdM080OWin0P2EUID20:VYZ@80Zj^[
0`2WYjL209nOW`80XZ:R0P2VYZH20:ZZZP80[jn_0P2a/K430;Bd]080^k^k0P30`<020;bl_080^;Rh
0P2k^k/20;fm_@<0]kNg0P2_[jl209JFUP80V9RH0P1gMgL20861P@D0[:b/0P2j^[X20<30`080`/;2
0P2o_kl20;Ng]`80[Zj^0P2XZ:P30:BTY080WYjN0P2KVi/209jNWP80XJ6Q0P2TY:@209jNWP<0UYJF
0P2IVIT209bLW080X:2P0P2RXZ870:>SX`80YjNW0P2[Zj/60:b/[080[Jf]0`2^[Zh20;2`/0H0/K6a
0P2b/[820;Bd]0<0]kNg0P2j^[X20;bl_080_Kfm2038h=P000H0b>3H0P0U9BD202PX:0L0:b/[0P0W
9bL202PX:080=SHf0P14A4@206YZJP<0I6AT0P0i>CT2030`<080:b/[0P0`<30202l_;`80<c<c0`18
B4P205UIF@80B4Q80P0c<c<202d];@80:b/[0P0b<S8303Lg=`80?clo0P0];Bd202/[:`80;Bd]0P0b
<S8204Y:BP80De=C0`0`<30203De=@80>SXj0P0[:b/402l_;`80=SHf0`1?Cdl205MGE`809bLW0P0b
<S8204i>CP80Cdm?0P10@40302`/;08092@T0P0Q8B4201lO7`80:b/[0P16ATH209>CT`<0OGem0P18
B4P201dM7@80<C4a0P1LG5`208b<S080WYjN0`2CTi<407IfMP80OWin0P1mOGd209RHV080/;2`0`2Z
ZZX20:2PX080Xj>S0P2YZJT20:f][@80/K6a1@2`/;020;Zj^P80`l?30P2n_[h20;Rh^080^k^k0P2l
_;`30;Fe]@80[Zj^0P2:RXX209^KV`80OGem0P28R8P20:n_[`<0Zj^[0P2d];@20;Vi^@80`L710P36
a/H20<30`080]kNg0P2`/;030:VYZ@80Xj>S0P2OWil209bLW080Vi^K0P2WYjL20:BTY0<0UYJF102K
Vi/209jNWP80XJ6Q0P2TY:@20::RXP<0X:2P0P2UYJD20:ZZZP80Zj^[0P2/[:`20:f][@D0[Zj^0P2]
[Jd20:n_[`80/K6a102`/;020;Fe]@<0^KVi0P2k^k/40;bl_0P0b>3H00060<SPf0809BDU0P0X:2P7
02/[:`809bLW0P0X:2P203Hf=P80A4A40P1ZJVX306ATI080>CTi0P0`<30202/[:`80<30`0P0_;bl2
03<c<`<0B4Q80P1IFET204Q8B080<c<c0P0];Bd202/[:`80<S8b0`0g=cL203lo?`80;Bd]0P0[:b/2
02d];@80<S8b0P1:BTX205=CD`<0<30`0P0e=CD203Xj>P80:b/[100_;bl203Hf=P<0Cdm?0P1GEeL2
02LW9`80<S8b0P1>CTh204m?C`80@4100`0/;2`202@T90808B4Q0P0O7al202/[:`80ATI60P2CTi<3
07emO@80B4Q80P0M7Ad2034a<@80G5aL0P2<S8`209jNWP<0Ti>C101fMWH207inOP80OGem0P2HV9P2
0;2`/0<0ZZZZ0P2PX:020:>SX`80ZJVY0P2][Jd20;6a/@D0/;2`0P2j^[X20<?3``80_[jn0P2h^;P2
0;^k^`80_;bl0`2e]KD20:j^[P80RXZ:0P2KVi/207emO@80R8R80P2_[jl30:^[Z`80];Bd0P2i^KT2
0<71`@80a/K60P30`<020;Ng]`80/;2`0`2YZJT20:>SX`80WinO0P2LW9`209^KV`80YjNW0P2TY:@3
09JFUP@0Vi^K0P2NWYh20:6QX@80Y:BT0P2RXZ830:2PX080YJFU0P2ZZZX20:^[Z`80[:b/0P2][Jd5
0:j^[P80[Jf]0P2_[jl20;6a/@@0/;2`0P2e]KD30;Vi^@80^k^k102l_;`80<SPf0001P38h=P202DU
9@809bLW0P0X:2P302TY:@80:RXZ0P0W9bL202/[:`80?3`l0P1HF5P206IVIP<0Cdm?0P0m?Cd203lo
?`80?3`l0P0b<S8203@d=080>CTi0`13@d<204U9B@80ATI60P0c<c<202h^;P80;Bd]0P0c<c<303Ph
>080?3`l0P0c<c<2030`<080;bl_0P0c<c<20451@@80CTi>0`0o?cl403Lg=`80:RXZ0P0Y:BT202d]
;@80=cLg0`1QHF4205iNGP80;Rh^0P1<C4`404i>CP80ATI60`0_;bl202TY:@80:2PX0P0T92@2030`
<080JVYZ0P2BTY8306MWI`80=3@d0P0H61P202DU9@80>c/k0P1YJFT208^;R`<0VIVI0P2ATI4207al
O080NGUi0P1cLg<208B4Q080Vi^K0`2XZ:P20:n_[`80[:b/0P2XZ:P20:ZZZP80[Zj^0P2`/;030;>c
/`80^[Zj0P30`<020;fm_@80^KVi0P2h^;P20;Jf]P<0];Bd0P2a/K4208b<S080VYZJ0P28R8P208b<
S080Zj^[0`2UYJD20:f][@80/k>c0P2n_[h20<K6aP80aLG50P2o_kl20;Jf]P<0Zj^[0P2VYZH20::R
XP@0X:2P0P2VYZH20:BTY0<0WIfM0P2OWil209ZJVP80UiNG0P2KVi/20:6QX@80X:2P0`2OWil20:>S
X`80YjNW102YZJT20:^[Z`L0[Jf]0P2^[Zh20:n_[`80/K6a0P2c/k<20;Jf]P<0^KVi0P2l_;`20;fm
_@80_[jn2038h=P000H0b>3H0P0U9BD202LW9`80:2PX0`0Y:BT202XZ:P809bLW0P0[:b/203`l?080
F5QH0P1VIVH304m?C`80?Cdm0P0o?cl203`l?080<S8b0P0d=3@203Ti>@<0@d=30P19BDT204I6AP80
<c<c0P0^;Rh202d];@80<c<c0`0h>3P203`l?080<c<c0P0`<30202l_;`80<c<c0P11@D4204i>CP<0
?clo100g=cL202XZ:P80:BTY0P0];Bd203Lg=`<0HF5Q0P1NGUh202h^;P80C4a<101>CTh204I6AP<0
;bl_0P0Y:BT202PX:08092@T0P0`<30206YZJP80TY:B0`1WIfL203@d=08061PH0P0U9BD203/k>`80
JFUY0P2;Rh/309VIV@80TI6A0P1lO7`207UiN@80Lg=c0P24Q8@209^KV`<0Z:RX0P2_[jl20:b/[080
Z:RX0P2ZZZX20:j^[P80/;2`0`2c/k<20;Zj^P80`<300P2m_Kd20;Vi^@80^;Rh0P2f][H30;Bd]080
/K6a0P2<S8`209ZJVP80R8R80P2<S8`20:^[Z`<0YJFU0P2][Jd20;>c/`80_[jn0P36a/H20<G5a@80
_kno0P2f][H30:^[Z`80YZJV0P2RXZ840:2PX080YZJV0P2TY:@309fMW@80WinO0P2JVYX209NGU`80
Vi^K0P2QXJ420:2PX0<0WinO0P2SXj<20:NWY`@0ZJVY0P2[Zj/70:f][@80[Zj^0P2_[jl20;6a/@80
/k>c0P2f][H30;Vi^@80_;bl0P2m_Kd20;jn_PP0b>3H00060<SPf0@09bLW1@0X:2P402TY:@80;bl_
0P12@T8206UYJ@80FEUI0`0e=CD20492@P@0CTi>0P0e=CD202d];@809bLW0`0`<30203Ph>080@d=3
0P0c<c<2030`<080;Bd]0P0c<c<503Ti>@80>3Ph0P0d=3@2038b<P80=CDe0P0i>CT204A4A0<0CDe=
0P0k>c/203Lg=`80:b/[0P0T92@202d];@80>CTi0`1]KFd205eMG@80?3`l0P1VIVH204A4A080@T92
0P1@D50304I6AP80>CTi0P0^;Rh203De=@80Cdm?0P2HV9P208N7Q`<0DU9B0P0U9BD201`L70808B4Q
0P0P820204=3@`80Kfm_0`2DU9@20:JVYP80QHF50P1iNGT2071`L080MGEe0P23Ph<30:2PX080^KVi
0P2d];@20:VYZ@80YjNW0P2YZJT20;2`/0<0]kNg0P2k^k/20;bl_080^k^k0P2i^KT20;Bd]080/;2`
0`2b/[820;Bd]080TY:B0P2GUiL409:BTP80YjNW0`2OWil20:NWY`80[Zj^0P2j^[X20<G5a@80b<S8
0P36a/H20;^k^`<0[jn_0P2XZ:P40:BTY080YJFU102TY:@30:FUY@80Y:BT0P2JVYX209:BTP80UYJF
102MWId309jNWP80XJ6Q0P2TY:@20:FUY@80YZJV0P2YZJT20:^[Z`D0[:b/0P2][Jd20:j^[P80/[:b
0P2g]kL20;Rh^0<0^KVi0P2l_;`20;no_`80`<302038h=P000H0b>3H100W9bL502PX:0@0:BTY0P0_
;bl20492@P80JFUY0P1IFET303De=@80@T92101>CTh203De=@80;Bd]0P0W9bL3030`<080>3Ph0P13
@d<203<c<`80<30`0P0];Bd203<c<`D0>CTi0P0h>3P203@d=080<S8b0P0e=CD203Ti>@80A4A40`1=
CDd203/k>`80=cLg0P0[:b/202@T9080;Bd]0P0i>CT306e]K@80GEeM0P0l?3`206IVIP80A4A40P12
@T82051@D0<0ATI60P0i>CT202h^;P80=CDe0P1?Cdl209RHV080QhN70`1BDU8202DU9@8071`L0P0Q
8B42020P8080@d=30P1_Kfl309BDU080YZJV0P25QHD207UiN@80L71`0P1eMGD208>3P`<0X:2P0P2i
^KT20;Bd]080ZJVY0P2WYjL20:VYZ@80/;2`0`2g]kL20;^k^`80_;bl0P2k^k/20;Vi^@80];Bd0P2`
/;030;:b/P80];Bd0P2BTY8209NGU`@0TY:B0P2WYjL309nOW`80YjNW0P2^[Zh20;Zj^P80aLG50P38
b<P20<K6aP80^k^k0`2_[jl20:RXZ0@0Y:BT0P2UYJD40:BTY0<0YJFU0P2TY:@209ZJVP80TY:B0P2F
UYH409fMW@<0WYjN0P2QXJ420:BTY080YJFU0P2VYZH20:VYZ@80Zj^[1@2/[:`20:f][@80[Zj^0P2b
/[820;Ng]`80^;Rh0`2i^KT20;bl_080_kno0P30`<080<SPf0001P38h=P402LW9`D0:2PX100Y:BT2
02l_;`80@T920P1YJFT205UIF@<0=CDe0P12@T8404i>CP80=CDe0P0];Bd202LW9`<0<30`0P0h>3P2
04=3@`80<c<c0P0`<30202d];@80<c<c1@0i>CT203Ph>080=3@d0P0b<S8203De=@80>CTi0P14A4@3
04e=C@80>c/k0P0g=cL202/[:`8092@T0P0];Bd203Ti>@<0KFe]0P1MGEd203`l?080IVIV0P14A4@2
0492@P80D51@0`16ATH203Ti>@80;Rh^0P0e=CD204m?C`80V9RH0P27QhL3059BDP809BDU0P0L71`2
024Q8@80820P0P13@d<206m_K`<0U9BD0P2VYZH208F5Q@80NGUi0P1`L70207EeM@80Ph>30`2PX:02
0;Vi^@80];Bd0P2YZJT20:NWY`80ZJVY0P2`/;030;Ng]`80^k^k0P2l_;`20;^k^`80^KVi0P2d];@2
0;2`/0<0/[:b0P2d];@209:BTP80UiNG102BTY820:NWY`<0WinO0P2WYjL20:j^[P80^[Zj0P35aLD2
0<S8b080a/K60P2k^k/30:n_[`80Z:RX102TY:@20:FUY@@0Y:BT0`2UYJD20:BTY080VYZJ0P2BTY82
09JFUP@0WIfM0`2NWYh20:6QX@80Y:BT0P2UYJD20:JVYP80ZJVY0P2[Zj/50:b/[080[Jf]0P2^[Zh2
0;:b/P80]kNg0P2h^;P30;Vi^@80_;bl0P2o_kl20<30`0P0b>3H00060<SPf080:b/[0P0X:2P202DU
9@<0:2PX0P0[:b/202TY:@80;bl_0P19BDT206i^KP80C4a<0`0];Bd202l_;`80=CDe0P0l?3`203Ph
>080=CDe0P0b<S8302h^;P80<c<c0P10@40203dm?@80=3@d0P0/;2`202l_;`<0=SHf0P0h>3P203/k
>`80=SHf0P0a<C42038b<P80=CDe0P0h>3P304];B`80?3`l0P0d=3@202PX:0808B4Q0P0`<3020492
@P<0JFUY0P1IFET204a<C080I6AT0P0m?Cd204Y:BP80Fe]K0`1PH60205YJFP80EeMG0P1CDe<207Ad
M080[jn_0P2;Rh/305aLG080;2`/0P0O7al201hN7P806ATI0P0];Bd204U9B@<0M7Ad0P2KVi/209JF
UP80QhN70P1gMgL207=cL`80N7Qh0`2;Rh/20:RXZ080];Bd0P2i^KT20:j^[P80YZJV0P2^[Zh30;Rh
^0@0^KVi0P2h^;P20;Jf]P80/[:b0P2`/;030;>c/`80];Bd0P2IVIT2096AT@80UIFE0P2JVYX20:>S
X`<0XJ6Q0P2WYjL20:n_[`80^[Zj0P33`l<40<S8b080`L710`2h^;P20:j^[P80YJFU0P2VYZH20:VY
Z@80YjNW1@2VYZH20:>SX`80WYjN0P2IVIT209NGU`80UYJF0P2HV9P309bLW080WinO1P2SXj<20:NW
Y`/0Zj^[0P2a/K420;Jf]P80^;Rh0`2j^[X20;fm_@@0`<302038h=P000H0b>3H0P0[:b/202PX:080
9BDU0`0X:2P202/[:`80:BTY0P0_;bl204U9B@80KVi^0P1<C4`302d];@80;bl_0P0e=CD203`l?080
>3Ph0P0e=CD2038b<P<0;Rh^0P0c<c<20410@080?Cdm0P0d=3@202`/;080;bl_0`0f=SH203Ph>080
>c/k0P0f=SH2034a<@80<S8b0P0e=CD203Ph>0<0Bd];0P0l?3`203@d=080:2PX0P0Q8B42030`<080
@T920`1YJFT205UIF@80C4a<0P1TI6@203dm?@80BTY:0P1KFe/3061PH080FUYJ0P1GEeL205=CD`80
M7Ad0P2_[jl208^;R`<0G5aL0P0/;2`201lO7`807QhN0P0I6AT202d];@80BDU90`1dM7@209^KV`80
UYJF0P27QhL207MgM`80Lg=c0P1hN7P308^;R`80Z:RX0P2d];@20;Vi^@80[Zj^0P2VYZH20:j^[P<0
^;Rh102i^KT20;Rh^080][Jf0P2b/[820;2`/0<0/k>c0P2d];@209VIV@80TI6A0P2EUID209ZJVP80
Xj>S0`2QXJ420:NWY`80[jn_0P2j^[X20<?3``@0b<S80P31`L430;Rh^080[Zj^0P2UYJD20:JVYP80
ZJVY0P2WYjL50:JVYP80Xj>S0P2NWYh209VIV@80UiNG0P2FUYH209RHV0<0W9bL0P2OWil60:>SX`80
YjNW2`2[Zj/20;6a/@80][Jf0P2h^;P30;Zj^P80_Kfm1030`<080<SPf0001P38h=P202l_;`80:RXZ
0P0T92@302PX:080;Bd]0P0[:b/202l_;`80DE5A0P1^KVh203hn?P<0:2PX0P0U9BD202d];@80<C4a
0P0g=cL203/k>`80?Shn0`0_;bl2038b<P80?3`l0P16ATH203Ph>080:b/[0P0/;2`3038b<P80=cLg
0P0k>c/203Lg=`80<S8b0P0_;bl2034a<@80;bl_0`14A4@203`l?080<S8b0P0_;bl2030`<080?Cdm
0P18B4P305EEE@80AdM70P1BDU8205eMG@80B4Q80P1YJFT206=SH`<0G5aL0P1CDe<2059BDP80?Shn
0P1XJ6P20:BTY080SHf=0`1XJ6P203Hf=P8092@T0P0M7Ad201XJ6P80820P0P0Y:BT304m?C`80Ph>3
0P2NWYh209FEU@80Ph>30P1hN7P207AdM0<0MWIf0P2@T9020:b/[080a<C40P2e]KD20:FUY@80[:b/
0`2g]kL20;Rh^080]kNg0P2d];@20;6a/@@0/;2`0`2c/k<20;:b/P80WYjN0P2;Rh/209FEU@@0XZ:R
0`2UYJD20:ZZZP80/;2`0P2i^KT20<71`@80aLG50P37alL20<G5a@<0`<300P2b/[820:JVYP80Z:RX
0P2/[:`20:^[Z`80ZJVY0`2UYJD20::RXP@0Xj>S0P2KVi/209>CT`80UIFE0`2IVIT209fMW@H0XJ6Q
0P2VYZH50:ZZZP@0ZJVY0P2ZZZX20:n_[`80]KFe0P2h^;P30;^k^`80_[jn0P30`<020<71`@P0b>3H
00060<SPf080;bl_0P0Z:RX202@T90<0:2PX0P0];Bd202/[:`80;bl_0P1ADE4206i^KP80?Shn0`0X
:2P202DU9@80;Bd]0P0a<C4203Lg=`80>c/k0P0n?Sh302l_;`80<S8b0P0l?3`204I6AP80>3Ph0P0[
:b/202`/;0<0<S8b0P0g=cL203/k>`80=cLg0P0b<S8202l_;`80<C4a0P0_;bl304A4A080?3`l0P0b
<S8202l_;`80<30`0P0m?Cd204Q8B0<0EEEE0P17AdL2059BDP80GEeM0P18B4P206UYJ@80Hf=S0`1L
G5`205=CD`80DU9B0P0n?Sh206QXJ080Y:BT0P2=SHd306QXJ080=SHf0P0T92@201dM7@806QXJ0P0P
820202TY:@<0Cdm?0P23Ph<209jNWP80UIFE0P23Ph<207QhN080M7Ad0`1fMWH2092@T080[:b/0P34
a<@20;Fe]@80YJFU0P2/[:`30;Ng]`80^;Rh0P2g]kL20;Bd]080/K6a102`/;030;>c/`80/[:b0P2N
WYh208^;R`80UIFE102RXZ830:FUY@80ZZZZ0P2`/;020;Vi^@80`L710P35aLD20<O7a`80aLG50`30
`<020;:b/P80YZJV0P2XZ:P20:b/[080Zj^[0P2YZJT30:FUY@80XZ:R102SXj<209^KV`80Ti>C0P2E
UID309VIV@80WIfM1P2QXJ420:JVYPD0ZZZZ102YZJT20:ZZZP80[jn_0P2e]KD20;Rh^0<0^k^k0P2n
_[h20<30`080`L712038h=P000H0b>3H0P0^;Rh202XZ:P809bLW0`0V9RH402l_;`80=CDe0P1NGUh2
06e]K@80?clo0`0W9bL202@T9080:RXZ0P0/;2`203<c<`80A4A40P1ADE4303hn?P@0<c<c0P0n?Sh2
03`l?080:b/[0P0^;Rh3038b<P80=SHf0P0i>CT203Xj>P80=cLg0P0`<30202`/;080;Bd]0`0k>c/2
0410@080=SHf0P0e=CD203@d=080=SHf0P0j>SX304U9B@80D51@0P1WIfL206i^KP80JVYZ0P1fMWH2
05YJFP<0D51@0P0n?Sh203Xj>P80;Rh^0P1PH60209:BTP80KFe]0`10@40202<S8`808B4Q100N7Qh2
01lO7`80820P0`0d=3@205iNGP80P8200P2KVi/209ZJVP80RHV90P1iNGT307=cL`80Ogmo0P2HV9P2
0;2`/080^[Zj0P2^[Zh50:f][@80][Jf0P2e]KD20;:b/P80[Jf]102[Zj/30:j^[P80[Jf]0P2LW9`2
08Z:RP80TI6A0P2WYjL20:b/[0<0ZJVY0P2/[:`20;6a/@80][Jf0P2l_;`20<71`@80aLG50P34a<@3
0;no_`80];Bd102YZJT20:b/[080ZZZZ0P2YZJT30:RXZ0@0YjNW0P2VYZH20:6QX@80W9bL0P2HV9P3
09JFUP80UiNG0P2JVYX209bLW080X:2P0P2UYJD90:VYZ@80Zj^[0P2_[jl20;Bd]080^;Rh0`2k^k/2
0;jn_P80`<300P31`L480<SPf0001P38h=P202h^;P80:RXZ0P0W9bL302HV9P@0;bl_0P0e=CD205iN
GP80KFe]0P0o?cl302LW9`8092@T0P0Z:RX202`/;080<c<c0P14A4@2055AD@<0?Shn100c<c<203hn
?P80?3`l0P0[:b/202h^;P<0<S8b0P0f=SH203Ti>@80>SXj0P0g=cL2030`<080;2`/0P0];Bd303/k
>`80@4100P0f=SH203De=@80=3@d0P0f=SH203Xj>P<0BDU90P1@D50206MWI`80KVi^0P1ZJVX207If
MP80FUYJ0`1@D50203hn?P80>SXj0P0^;Rh2061PH080TY:B0P1]KFd30410@0808b<S0P0Q8B4401hN
7P807alO0P0P820303@d=080GUiN0P20P80209^KV`80VYZJ0P29RHT207UiN@<0Lg=c0P1oOgl209RH
V080/;2`0P2j^[X20:j^[PD0[Jf]0P2f][H20;Fe]@80/[:b0P2][Jd40:^[Z`<0[Zj^0P2][Jd209bL
W080RXZ:0P2ATI420:NWY`80[:b/0`2YZJT20:b/[080/K6a0P2f][H20;bl_080`L710P35aLD20<C4
a0<0_kno0P2d];@40:VYZ@80[:b/0P2ZZZX20:VYZ@<0Z:RX102WYjL20:JVYP80XJ6Q0P2LW9`209RH
V0<0UYJF0P2GUiL209ZJVP80W9bL0P2PX:020:FUY@T0ZJVY0P2[Zj/20:n_[`80];Bd0P2h^;P30;^k
^`80_[jn0P30`<020<71`@P0b>3H00060<SPf080;bl_0P0^;Rh202l_;`<09RHV0P0`<30203<c<`80
>c/k0P1WIfL206][J`80A4A40`0Y:BT202LW9`80;Bd]0P0/;2`202h^;P80?Shn0P1<C4`304=3@`80
=cLg0P0^;Rh203De=@80?Shn0P0^;Rh2030`<0<0<S8b0P0d=3@203Hf=P@0>c/k0P0b<S8202PX:080
;Rh^0`0e=CD20492@P80?3`l0P0j>SX203Lg=`80;bl_0P0^;Rh304=3@`80G5aL0P1^KVh206UYJ@80
Ng]k0P1nOWh204e=C@<0?Cdm0P0_;bl203@d=080<c<c0P1XJ6P208f=S@80F5QH0`0W9bL2020P8080
9BDU0P0O7al2024Q8@808b<S0P0P8203024Q8@80>SXj0P1KFe/209>CT`80YjNW0P2JVYX208>3P`<0
N7Qh0P1dM7@208:2PP80U9BD0P2f][H20;Bd]080[Zj^0`2TY:@20;Fe]@80/k>c0P2`/;020:VYZ@80
YZJV0P2UYJD50:RXZ080UiNG0P2:RXX208j>SP80ZJVY0P2d];@30:b/[080[Zj^0P2_[jl20;>c/`80
]kNg0P2m_Kd20<;2`P80`L710`2l_;`20;Bd]080[:b/102ZZZX20:VYZ@80Z:RX0`2[Zj/20:f][@80
ZZZZ102XZ:P20:NWY`80WYjN0`2FUYH209>CT`80U9BD0P2IVIT209nOW`80Xj>S0P2WYjL30:RXZ080
ZJVY0P2ZZZX20:b/[080[jn_0P2c/k<20;Ng]`<0^k^k0P2n_[h40<30`0P0b>3H00060<SPf080;bl_
0P0^;Rh202l_;`<09RHV0P0`<30203<c<`80>c/k0P1WIfL206][J`80A4A40`0Y:BT202LW9`80;Bd]
0P0/;2`202h^;P80?Shn0P1<C4`304=3@`80=cLg0P0^;Rh203De=@80?Shn0P0^;Rh2030`<0<0<S8b
0P0d=3@203Hf=P@0>c/k0P0b<S8202PX:080;Rh^0`0e=CD20492@P80?3`l0P0j>SX203Lg=`80;bl_
0P0^;Rh304=3@`80G5aL0P1^KVh206UYJ@80Ng]k0P1nOWh204e=C@<0?Cdm0P0_;bl203@d=080<c<c
0P1XJ6P208f=S@80F5QH0`0W9bL2020P80809BDU0P0O7al2024Q8@808b<S0P0P8203024Q8@80>SXj
0P1KFe/209>CT`80YjNW0P2JVYX208>3P`<0N7Qh0P1dM7@208:2PP80U9BD0P2f][H20;Bd]080[Zj^
0`2TY:@20;Fe]@80/k>c0P2`/;020:VYZ@80YZJV0P2UYJD50:RXZ080UiNG0P2:RXX208j>SP80ZJVY
0P2d];@30:b/[080[Zj^0P2_[jl20;>c/`80]kNg0P2m_Kd20<;2`P80`L710`2l_;`20;Bd]080[:b/
102ZZZX20:VYZ@80Z:RX0`2[Zj/20:f][@80ZZZZ102XZ:P20:NWY`80WYjN0`2FUYH209>CT`80U9BD
0P2IVIT209nOW`80Xj>S0P2WYjL30:RXZ080ZJVY0P2ZZZX20:b/[080[jn_0P2c/k<20;Ng]`<0^k^k
0P2n_[h40<30`0P0b>3H00060<SPf080@d=30P0j>SX202h^;P<09bLW0P0];Bd2034a<@80>SXj0P1W
IfL206][J`80BTY:0`0/;2`202TY:@80;2`/0P0[:b/202`/;080=cLg0P11@D4304I6AP80?Shn100f
=SH203/k>`80<c<c0P0a<C4302h^;P80<30`100d=3@203dm?@80<S8b0P0X:2P2034a<@<0>SXj100o
?cl203Ti>@80=3@d0P0b<S8203Hf=P<0C4a<0P1PH60206m_K`80H61P0P1WIfL207QhN080@4100`0b
<S8202d];@80;bl_0P0m?Cd207emO@80R8R80P14A4@302LW9`8092@T0P0V9RH2028R8P@08b<S0P0R
8R83020P80808R8R0P0_;bl2061PH080SXj>0P2TY:@209FEU@<0Ph>30P1`L702079bLP80Ng]k0P2Q
XJ420;Fe]@80^[Zj0`2[Zj/20;6a/@80[:b/0P2ZZZX20:JVYP@0YJFU0`2WYjL20:JVYP80U9BD0P26
QXH209:BTP80ZJVY0P2b/[830:j^[P80ZJVY0P2VYZH20;2`/080^[Zj0P2n_[h20<30`080_kno0`2k
^k/20;Fe]@80[Zj^0P2[Zj/20:VYZ@80Z:RX0P2YZJT30:^[Z`80[Jf]0P2[Zj/20:ZZZP80Zj^[0P2/
[:`20:RXZ0<0XZ:R0P2KVi/209FEU@80UYJF0P2JVYX20:2PX080YZJV0`2WYjL20:RXZ080ZZZZ0P2/
[:`20:j^[P80/K6a0P2d];@30;Rh^080^k^k0P2n_[h20;no_`P0b>3H00060<SPf080@d=30P0j>SX2
02h^;P<09bLW0P0];Bd2034a<@80>SXj0P1WIfL206][J`80BTY:0`0/;2`202TY:@80;2`/0P0[:b/2
02`/;080=cLg0P11@D4304I6AP80?Shn100f=SH203/k>`80<c<c0P0a<C4302h^;P80<30`100d=3@2
03dm?@80<S8b0P0X:2P2034a<@<0>SXj100o?cl203Ti>@80=3@d0P0b<S8203Hf=P<0C4a<0P1PH602
06m_K`80H61P0P1WIfL207QhN080@4100`0b<S8202d];@80;bl_0P0m?Cd207emO@80R8R80P14A4@3
02LW9`8092@T0P0V9RH2028R8P@08b<S0P0R8R83020P80808R8R0P0_;bl2061PH080SXj>0P2TY:@2
09FEU@<0Ph>30P1`L702079bLP80Ng]k0P2QXJ420;Fe]@80^[Zj0`2[Zj/20;6a/@80[:b/0P2ZZZX2
0:JVYP@0YJFU0`2WYjL20:JVYP80U9BD0P26QXH209:BTP80ZJVY0P2b/[830:j^[P80ZJVY0P2VYZH2
0;2`/080^[Zj0P2n_[h20<30`080_kno0`2k^k/20;Fe]@80[Zj^0P2[Zj/20:VYZ@80Z:RX0P2YZJT3
0:^[Z`80[Jf]0P2[Zj/20:ZZZP80Zj^[0P2/[:`20:RXZ0<0XZ:R0P2KVi/209FEU@80UYJF0P2JVYX2
0:2PX080YZJV0`2WYjL20:RXZ080ZZZZ0P2/[:`20:j^[P80/K6a0P2d];@30;Rh^080^k^k0P2n_[h2
0;no_`P0b>3H00060<SPf080D51@0P1>CTh204M7A`<0=SHf0P0X:2P202/[:`80=cLg0P1RHV8206][
J`80DU9B0`0a<C4402/[:`@0:RXZ0P0];Bd2038b<P<0ADE50P14A4@203lo?`@0=cLg0P0i>CT2034a
<@<0:b/[0P0/;2`2038b<P80;Bd]0P0l?3`203<c<`80;Bd]0P0g=cL30492@P80>c/k0P11@D4203Ph
>080<S8b0P0h>3P20492@P<0EeMG0P1RHV82061PH080?Cdm0P0o?cl206e]K@80=cLg0`0/;2`202l_
;`80<c<c0P1?Cdl2096AT@80PX:20P0f=SH302h^;P80;2`/0P0X:2P202HV9P8092@T100S8b<302@T
9080820P0P0U9BD203Ph>080JVYZ0P2MWId209nOW`<0Shn?0P1fMWH206][J`80JFUY0P1oOgl209ZJ
VP80]KFe0`2d];@20;2`/080Z:RX0P2VYZH20:FUY@@0YZJV0`2WYjL20:FUY@80TI6A0P22PX8209BD
U080YjNW0P2][Jd30:j^[P80YJFU0P2NWYh20:f][@80_Kfm102o_kl20;fm_@<0^KVi0P2e]KD20;2`
/080Zj^[102XZ:P20:VYZ@<0ZZZZ102[Zj/20:ZZZP80[:b/0P2][Jd20:n_[`<0[Zj^0P2UYJD209bL
W080UiNG0P2HV9P209fMW@80Xj>S0`2UYJD20:NWY`80ZJVY0P2/[:`20:f][@80[Zj^0P2a/K430;Fe
]@80^KVi0P2l_;`20;fm_@P0b>3H00060<SPf080D51@0P1>CTh204M7A`<0=SHf0P0X:2P202/[:`80
=cLg0P1RHV8206][J`80DU9B0`0a<C4402/[:`@0:RXZ0P0];Bd2038b<P<0ADE50P14A4@203lo?`@0
=cLg0P0i>CT2034a<@<0:b/[0P0/;2`2038b<P80;Bd]0P0l?3`203<c<`80;Bd]0P0g=cL30492@P80
>c/k0P11@D4203Ph>080<S8b0P0h>3P20492@P<0EeMG0P1RHV82061PH080?Cdm0P0o?cl206e]K@80
=cLg0`0/;2`202l_;`80<c<c0P1?Cdl2096AT@80PX:20P0f=SH302h^;P80;2`/0P0X:2P202HV9P80
92@T100S8b<302@T9080820P0P0U9BD203Ph>080JVYZ0P2MWId209nOW`<0Shn?0P1fMWH206][J`80
JFUY0P1oOgl209ZJVP80]KFe0`2d];@20;2`/080Z:RX0P2VYZH20:FUY@@0YZJV0`2WYjL20:FUY@80
TI6A0P22PX8209BDU080YjNW0P2][Jd30:j^[P80YJFU0P2NWYh20:f][@80_Kfm102o_kl20;fm_@<0
^KVi0P2e]KD20;2`/080Zj^[102XZ:P20:VYZ@<0ZZZZ102[Zj/20:ZZZP80[:b/0P2][Jd20:n_[`<0
[Zj^0P2UYJD209bLW080UiNG0P2HV9P209fMW@80Xj>S0`2UYJD20:NWY`80ZJVY0P2/[:`20:f][@80
[Zj^0P2a/K430;Fe]@80^KVi0P2l_;`20;fm_@P0b>3H00060<SPf0@0Fe]K0P1GEeL304M7A`80=CDe
0P0`<30203<c<`80Fe]K0P1WIfL205]KF`<0=CDe0P0_;bl202XZ:P80:BTY0P0Z:RX202/[:`80;Bd]
0`0l?3`20410@080>SXj0P0b<S8203Hf=P80?Cdm0P0e=CD302`/;080;Rh^0P0b<S8202h^;P80=3@d
0P0i>CT203hn?P80A4A40`18B4P203lo?`@0?Cdm0P0d=3@203`l?080BDU90`1?Cdl205iNGP80EUIF
0P0b<S8203<c<`80G5aL0P0i>CT502l_;`80ADE50P1^KVh2096AT@80Kfm_0P0/;2`302XZ:P@09RHV
0P0W9bL202@T90@08R8R0`0S8b<601hN7P80>CTi0P1_Kfl209VIV@<0YjNW0P2DU9@207MgM`80IfMW
0P1_Kfl208B4Q080XJ6Q0`2_[jl20;Jf]P80]KFe0P2[Zj/20:>SX`80YJFU1@2VYZH20:>SX`80TI6A
0P23Ph<208Z:RP80XZ:R0P2VYZH30:ZZZP80YZJV0P2SXj<20:NWY`80][Jf0P31`L420;jn_P80^;Rh
0`2a/K420;>c/`80]KFe0P2^[Zh40:RXZ0L0ZZZZ0P2XZ:P20:NWY`80Z:RX0P2YZJT20:f][@D0[jn_
0P2[Zj/209jNWP80RXZ:0P2ATI4209^KV`<0XJ6Q0P2VYZH20:VYZ@80[:b/0P2][Jd20:n_[`80/[:b
0`2e]KD20;Rh^0@0^[Zj2038h=P000H0b>3H101KFe/205MGE`<0AdM70P0e=CD2030`<080<c<c0P1K
Fe/206MWI`80Fe]K0`0e=CD202l_;`80:RXZ0P0Y:BT202XZ:P80:b/[0P0];Bd303`l?080@4100P0j
>SX2038b<P80=SHf0P0m?Cd203De=@<0;2`/0P0^;Rh2038b<P80;Rh^0P0d=3@203Ti>@80?Shn0P14
A4@304Q8B080?clo100m?Cd203@d=080?3`l0P19BDT304m?C`80GUiN0P1FEUH2038b<P80<c<c0P1L
G5`203Ti>@D0;bl_0P15ADD206i^KP80TI6A0P1_Kfl202`/;0<0:RXZ100V9RH202LW9`8092@T100R
8R8302<S8`H07QhN0P0i>CT206m_K`80VIVI0`2WYjL209BDU080MgMg0P1WIfL206m_K`80Q8B40P2Q
XJ430:n_[`80][Jf0P2e]KD20:^[Z`80Xj>S0P2UYJD50:JVYP80Xj>S0P2ATI4208>3P`80RXZ:0P2R
XZ820:JVYP<0ZZZZ0P2VYZH20:>SX`80YjNW0P2f][H20<71`@80_[jn0P2h^;P30;6a/@80/k>c0P2e
]KD20:j^[P@0Z:RX1`2ZZZX20:RXZ080YjNW0P2XZ:P20:VYZ@80[Jf]1@2_[jl20:^[Z`80WYjN0P2:
RXX2096AT@80Vi^K0`2QXJ420:JVYP80ZJVY0P2/[:`20:f][@80[jn_0P2b/[830;Fe]@80^;Rh102j
^[X80<SPf0001P38h=P405]KF`80EeMG0`17AdL203De=@80<30`0P0c<c<205]KF`80IfMW0P1KFe/3
03De=@80;bl_0P0Z:RX202TY:@80:RXZ0P0[:b/202d];@<0?3`l0P10@40203Xj>P80<S8b0P0f=SH2
03dm?@80=CDe0`0/;2`202h^;P80<S8b0P0^;Rh203@d=080>CTi0P0n?Sh204A4A0<0B4Q80P0o?cl4
03dm?@80=3@d0P0l?3`204U9B@<0Cdm?0P1NGUh205IFEP80<S8b0P0c<c<205aLG080>CTi1@0_;bl2
04E5A@80KVi^0P2ATI4206m_K`80;2`/0`0Z:RX402HV9P809bLW0P0T92@4028R8P<08b<S1P0N7Qh2
03Ti>@80Kfm_0P2IVIT30:NWY`80U9BD0P1gMgL206MWI`80Kfm_0P24Q8@20:6QX@<0[jn_0P2f][H2
0;Fe]@80Zj^[0P2SXj<20:FUY@D0YZJV0P2SXj<2096AT@80Ph>30P2:RXX20::RXP80YZJV0`2ZZZX2
0:JVYP80Xj>S0P2WYjL20;Jf]P80`L710P2n_[h20;Rh^0<0/K6a0P2c/k<20;Fe]@80[Zj^102XZ:P7
0:ZZZP80Z:RX0P2WYjL20:RXZ080ZJVY0P2][Jd50:n_[`80Zj^[0P2NWYh208Z:RP80TI6A0P2KVi/3
0:6QX@80YZJV0P2YZJT20:b/[080[Jf]0P2_[jl20;:b/P<0]KFe0P2h^;P40;Zj^PP0b>3H00060<SP
f0@0@4100P0o?cl303Ti>@80<S8b0P0];Bd202l_;`80E5AD0P1RHV82065QH@<0>c/k0P0a<C4402PX
:0@0:RXZ0P0/;2`303<c<`80>SXj0P0c<c<202d];@80=SHf0P0n?Sh203Lg=`<0;bl_0P0`<30203<c
<`80<C4a0P0`<3020410@0@0Cdm?0`1:BTX204=3@`80>SXj0P13@d<203Ph>080@4100P1:BTX304E5
A@80FUYJ0P1>CTh202TY:@80;Bd]0P1;Bd/203dm?@<0<C4a0P0_;bl205MGE`80RXZ:0P2=SHd205eM
G@809bLW0`0X:2P202@T9080:2PX0P0[:b/202LW9`@08B4Q0`0R8R8201lO7`@07QhN0P0W9bL203lo
?`80LG5a0`2VYZH20:b/[080R8R80P1_Kfl206UYJ@80L71`0P27QhL30:>SX`80]KFe0P2n_[h20;6a
/@80Xj>S0P2TY:@20:JVYP<0YJFU0P2QXJ42092@T080Q8B40P20P80209fMW@80Xj>S0`2XZ:P20:ZZ
ZP80Zj^[0P2SXj<20;2`/080`L710P2n_[h20;Fe]@<0Zj^[0P2b/[820;Vi^@80/[:b102YZJT20:ZZ
ZP<0ZJVY0P2XZ:P20:FUY@@0Xj>S0P2TY:@20:RXZ0<0[Jf]0P2d];@20;Ng]`80];Bd0P2KVi/209JF
UP80UIFE0`2LW9`20:FUY@80Z:RX0P2[Zj/20:f][@80[jn_0P2b/[830;Jf]P80]kNg102h^;P80<SP
f0001P38h=P40410@080?clo0`0i>CT2038b<P80;Bd]0P0_;bl205ADE080HV9R0P1QHF4303/k>`80
<C4a100X:2P402XZ:P80;2`/0`0c<c<203Xj>P80<c<c0P0];Bd203Hf=P80?Shn0P0g=cL302l_;`80
<30`0P0c<c<2034a<@80<30`0P10@40404m?C`<0BTY:0P13@d<203Xj>P80@d=30P0h>3P20410@080
BTY:0`15ADD205YJFP80CTi>0P0Y:BT202d];@80Bd];0P0m?Cd3034a<@80;bl_0P1GEeL208Z:RP80
SHf=0P1MGEd202LW9`<0:2PX0P0T92@202PX:080:b/[0P0W9bL4024Q8@<08R8R0P0O7al401hN7P80
9bLW0P0o?cl2075aL@<0YZJV0P2/[:`208R8R080Kfm_0P1YJFT2071`L080QhN70`2SXj<20;Fe]@80
_[jn0P2a/K420:>SX`80Y:BT0P2VYZH30:FUY@80XJ6Q0P2@T90208B4Q080P8200P2MWId20:>SX`<0
Z:RX0P2ZZZX20:^[Z`80Xj>S0P2`/;020<71`@80_[jn0P2e]KD30:^[Z`80/[:b0P2i^KT20;:b/P@0
ZJVY0P2ZZZX30:VYZ@80Z:RX0P2UYJD40:>SX`80Y:BT0P2XZ:P30:f][@80];Bd0P2g]kL20;Bd]080
Vi^K0P2FUYH209FEU@<0W9bL0P2UYJD20:RXZ080Zj^[0P2][Jd20:n_[`80/[:b0`2f][H20;Ng]`@0
^;Rh2038h=P000H0b>3H0P1LG5`205=CD`80ATI60`0c<c<202l_;`80;Rh^0P0e=CD204i>CP80GEeM
0P1PH60304];B`80;bl_0P0Y:BT202LW9`@0:RXZ0P0[:b/3034a<@80=cLg0P0a<C4202`/;080<C4a
0P0h>3P203@d=0<0;bl_0P0`<302038b<P80=SHf0P0k>c/204U9B@80E5AD0P1<C4`70451@@80B4Q8
0P11@D420492@P80?Cdm0`13@d<205mOG`80DU9B0P0X:2P202d];@80?clo0P12@T8303Ph>080=3@d
0P1DE5@2092@T080RHV90P1IFET502XZ:P80:b/[100/;2`202XZ:P80:BTY0P0V9RH302@T90808R8R
0P0P820201dM7@807alO0P0Z:RX204a<C0<0PX:20P2PX:0209NGU`80RXZ:0P1gMgL206][J`80Lg=c
0`25QHD209jNWP80^k^k0P2m_Kd20:f][@80XZ:R0P2VYZH30::RXP80WYjN0P2<S8`207emO@80Q8B4
0P2MWId20:j^[P<0/K6a0P2`/;020:n_[`80Y:BT0P2c/k<20;no_`80`<300P2j^[X30;>c/`80][Jf
0P2j^[X20;:b/P80ZZZZ102XZ:P30:NWY`80YJFU0P2SXj<20::RXP80X:2P0P2QXJ420:FUY@<0ZZZZ
0P2a/K420;Jf]P80_;bl0P2d];@20:VYZ@80WinO0`2LW9`209fMW@80XZ:R0P2XZ:P20:ZZZP80[:b/
0P2_[jl30;:b/P80];Bd0P2e]KD20;Zj^PP0b>3H00060<SPf080G5aL0P1CDe<204I6AP<0<c<c0P0_
;bl202h^;P80=CDe0P1>CTh205eMG@80H61P0`1;Bd/202l_;`80:BTY0P0W9bL402XZ:P80:b/[0`0a
<C4203Lg=`80<C4a0P0/;2`2034a<@80>3Ph0P0d=3@302l_;`80<30`0P0b<S8203Hf=P80>c/k0P19
BDT205ADE080C4a<1`11@D4204Q8B080@D510P12@T8203dm?@<0@d=30P1OGel2059BDP80:2PX0P0]
;Bd203lo?`80@T920`0h>3P203@d=080E5AD0P2@T90208V9R@80FEUI1@0Z:RX202/[:`@0;2`/0P0Z
:RX202TY:@809RHV0`0T92@2028R8P80820P0P0M7Ad201lO7`80:RXZ0P1<C4`308:2PP80X:2P0P2G
UiL208Z:RP80MgMg0P1[Jf/207=cL`<0QHF50P2NWYh20;^k^`80_Kfm0P2][Jd20::RXP80YZJV0`2R
XZ8209jNWP80S8b<0P1mOGd208B4Q080WIfM0P2^[Zh30;6a/@80/;2`0P2_[jl20:BTY080/k>c0P2o
_kl20<30`080^[Zj0`2c/k<20;Jf]P80^[Zj0P2b/[820:ZZZP@0Z:RX0`2WYjL20:FUY@80Xj>S0P2R
XZ820:2PX080XJ6Q0P2UYJD30:ZZZP80/K6a0P2f][H20;bl_080];Bd0P2YZJT209nOW`<0W9bL0P2M
WId20::RXP80Z:RX0P2ZZZX20:b/[080[jn_0`2b/[820;Bd]080]KFe0P2j^[X80<SPf0001P38h=P2
07MgM`80Hf=S0P18B4P502/[:`809RHV0P0/;2`20410@080EeMG0P1LG5`305YJFP80;Rh^0P0[:b/2
02LW9`80:b/[0P0Z:RX202/[:`<0<C4a0P0f=SH2034a<@80;2`/0P0^;Rh2034a<@80<30`0`0_;bl2
030`<080<c<c0P0n?Sh204U9B@80DE5A0P1CDe<204I6AP<0>CTi0P11@D4404];B`80AdM70P11@D42
02h^;P<0@T920P1TI6@205MGE`80:BTY0P0_;bl203Lg=`80>c/k0`0[:b/2038b<P80DU9B0P2@T902
08J6QP80FEUI0P0d=3@303Lg=`80ADE50P18B4P204I6AP80>SXj0P0];Bd202PX:0<09RHV0P0T92@2
02<S8`808B4Q100P820202TY:@<0E5AD0P23Ph<209VIV@80WinO0P29RHT2071`L080IVIV0`1YJFT2
07UiN@80WIfM0P2g]kL20;>c/`80XZ:R0P2XZ:P30:2PX080V9RH0P26QXH207UiN@80S8b<0P2QXJ42
0;^k^`<0^KVi0P2f][H20;6a/@80Z:RX0P2g]kL20;bl_080`l?30P30`<030;fm_@80_;bl0P2k^k/2
0;>c/`80[:b/0P2YZJT20:NWY`<0YJFU0P2SXj<20:6QX@80X:2P102OWil20::RXP<0Z:RX0P2][Jd2
0;>c/`80]kNg0P2j^[X20;Bd]080[:b/0`2PX:0209RHV080WIfM0P2TY:@20:NWY`80Z:RX0P2[Zj/3
0:j^[P80/K6a0P2b/[820;bl_0P0b>3H00060<SPf080MgMg0P1SHf<204Q8B0D0:b/[0P0V9RH202`/
;080@4100P1GEeL205aLG0<0FUYJ0P0^;Rh202/[:`809bLW0P0[:b/202XZ:P80:b/[0`0a<C4203Hf
=P80<C4a0P0/;2`202h^;P80<C4a0P0`<30302l_;`80<30`0P0c<c<203hn?P80BDU90P1ADE4205=C
D`80ATI60`0i>CT20451@@@0Bd];0P17AdL20451@@80;Rh^0`12@T8206ATI080EeMG0P0Y:BT202l_
;`80=cLg0P0k>c/302/[:`80<S8b0P1BDU82092@T080QXJ60P1IFET203@d=0<0=cLg0P15ADD204Q8
B080ATI60P0j>SX202d];@80:2PX0`0V9RH202@T90808b<S0P0Q8B44020P8080:BTY0`1DE5@208>3
P`80VIVI0P2OWil208V9R@80L71`0P1VIVH306UYJ@80NGUi0P2MWId20;Ng]`80/k>c0P2RXZ820:RX
Z0<0X:2P0P2HV9P208J6QP80NGUi0P2<S8`20:6QX@80^k^k0`2i^KT20;Jf]P80/K6a0P2XZ:P20;Ng
]`80_;bl0P33`l<20<30`0<0_Kfm0P2l_;`20;^k^`80/k>c0P2/[:`20:VYZ@80YjNW0`2UYJD20:>S
X`80XJ6Q0P2PX:0409nOW`80XZ:R0`2XZ:P20:f][@80/k>c0P2g]kL20;Zj^P80];Bd0P2/[:`30:2P
X080V9RH0P2MWId20:BTY080YjNW0P2XZ:P20:^[Z`<0[Zj^0P2a/K420;:b/P80_;bl2038h=P000H0
b>3H0P1gMgL206UYJ@80De=C0`0d=3@402HV9P80;Bd]0P0l?3`204=3@`80DE5A0`1LG5`203Ph>080
<c<c200];Bd302XZ:P80:2PX0P0[:b/202h^;P80<30`0P0a<C4202l_;`<0;Bd]0P0c<c<203`l?080
CTi>0P1BDU8204m?C`80B4Q80P12@T8303lo?`80BTY:0P1CDe<204e=C@80@d=30P0g=cL202XZ:P<0
>c/k0P1TI6@205MGE`809RHV0P0Y:BT202l_;`80=cLg0`0[:b/20451@@80HF5Q0P2>SXh208V9R@80
Hf=S0P1@D50305EEE@80Hf=S0P1ZJVX206UYJ@80D51@0P0e=CD202XZ:P<09BDU0P0S8b<202@T9080
8R8R0P0P820201lO7`808b<S0`0g=cL205IFEP80PX:20P2SXj<209jNWP80Ph>30P1/K6`305aLG080
HV9R0P1nOWh20:>SX`80/k>c0P2ZZZX20:FUY@<0WYjN0P2@T90207]kN`80N7Qh0P2<S8`20:b/[080
^k^k0`2l_;`20;Ng]`80/;2`0P2_[jl20;Vi^@80_;bl0P30`<020<71`@D0`<300P2n_[h20;Rh^080
/K6a0P2/[:`20:NWY`<0YJFU0P2TY:@20::RXP80X:2P0P2OWil20:2PX080Xj>S0`2WYjL20:^[Z`80
/;2`0P2e]KD20;Vi^@80]kNg0P2b/[830:ZZZP80XZ:R0P2QXJ420::RXP80Y:BT0P2WYjL20:^[Z`<0
[Zj^0P2a/K420;>c/`80^;Rh2038h=P000H0b>3H0P1gMgL206UYJ@80De=C0`0d=3@402HV9P80;Bd]
0P0l?3`204=3@`80DE5A0`1LG5`203Ph>080<c<c200];Bd302XZ:P80:2PX0P0[:b/202h^;P80<30`
0P0a<C4202l_;`<0;Bd]0P0c<c<203`l?080CTi>0P1BDU8204m?C`80B4Q80P12@T8303lo?`80BTY:
0P1CDe<204e=C@80@d=30P0g=cL202XZ:P<0>c/k0P1TI6@205MGE`809RHV0P0Y:BT202l_;`80=cLg
0`0[:b/20451@@80HF5Q0P2>SXh208V9R@80Hf=S0P1@D50305EEE@80Hf=S0P1ZJVX206UYJ@80D51@
0P0e=CD202XZ:P<09BDU0P0S8b<202@T90808R8R0P0P820201lO7`808b<S0`0g=cL205IFEP80PX:2
0P2SXj<209jNWP80Ph>30P1/K6`305aLG080HV9R0P1nOWh20:>SX`80/k>c0P2ZZZX20:FUY@<0WYjN
0P2@T90207]kN`80N7Qh0P2<S8`20:b/[080^k^k0`2l_;`20;Ng]`80/;2`0P2_[jl20;Vi^@80_;bl
0P30`<020<71`@D0`<300P2n_[h20;Rh^080/K6a0P2/[:`20:NWY`<0YJFU0P2TY:@20::RXP80X:2P
0P2OWil20:2PX080Xj>S0`2WYjL20:^[Z`80/;2`0P2e]KD20;Vi^@80]kNg0P2b/[830:ZZZP80XZ:R
0P2QXJ420::RXP80Y:BT0P2WYjL20:^[Z`<0[Zj^0P2a/K420;>c/`80^;Rh2038h=P000H0b>3H0P1d
M7@205YJFP80=SHf0`0[:b/202HV9P80:b/[0P0`<30203Xj>P80<C4a0P17AdL305UIF@80A4A40P0l
?3`203@d=080<30`100];Bd302h^;PH0;bl_0P0b<S8203<c<`80;Rh^0`0/;2`203Ti>@80AdM70P1M
GEd205MGE`80Bd];0P0l?3`20410@0<0B4Q80P1DE5@205YJFP80CDe=0P0l?3`202d];@80:b/[0`0h
>3P2065QH@80E5AD100S8b<202XZ:P80=CDe0`0c<c<205ADE080LW9b0P29RHT208N7Q`80JVYZ0P1V
IVH3069RHP80H61P0P1GEeL204Y:BP80=SHf0P0U9BD202<S8`<09RHV0P0U9BD202@T90H08b<S0P0U
9BD302@T9080;Bd]0P1GEeL208:2PP80Vi^K0P2DU9@207MgM`<0F5QH0P1GEeL2069RHP80Ng]k0P2E
UID20:f][@80^;Rh0`2XZ:P208J6QP80N7Qh0P2@T90209JFUP80/[:b0P2g]kL30;bl_080][Jf0P2`
/;020;Fe]@80^[Zj0P2k^k/20;fm_@80_kno1@32`/820<71`@80_Kfm0P2g]kL20;2`/080ZZZZ0`2W
YjL20:JVYP80XZ:R0P2OWil20:2PX080XZ:R0P2TY:@30:JVYP80ZJVY0P2][Jd20;6a/@80/k>c102f
][H30;>c/`80[Zj^0P2WYjL20:6QX@80XZ:R0P2VYZH20:ZZZP<0[Zj^0P2a/K440;>c/`P0b>3H0006
0<SPf080M7Ad0P1JFUX203Hf=P<0:b/[0P0V9RH202/[:`80<30`0P0j>SX2034a<@80AdM70`1IFET2
04A4A080?3`l0P0d=3@2030`<0@0;Bd]0`0^;Rh602l_;`80<S8b0P0c<c<202h^;P<0;2`/0P0i>CT2
04M7A`80GEeM0P1GEeL204];B`80?3`l0P10@40304Q8B080E5AD0P1JFUX204e=C@80?3`l0P0];Bd2
02/[:`<0>3Ph0P1QHF4205ADE0@08b<S0P0Z:RX203De=@<0<c<c0P1DE5@2079bLP80RHV90P27QhL2
06YZJP80IVIV0`1RHV82061PH080EeMG0P1:BTX203Hf=P809BDU0P0S8b<302HV9P809BDU0P0T92@6
02<S8`809BDU0`0T92@202d];@80EeMG0P22PX8209^KV`80U9BD0P1gMgL305QHF080EeMG0P1RHV82
07]kN`80UIFE0P2][Jd20;Rh^0<0Z:RX0P26QXH207QhN080T92@0P2FUYH20;:b/P80]kNg0`2l_;`2
0;Jf]P80/;2`0P2e]KD20;Zj^P80^k^k0P2m_Kd20;no_`D0`/;20P31`L420;fm_@80]kNg0P2`/;02
0:ZZZP<0YjNW0P2VYZH20::RXP80WinO0P2PX:020::RXP80Y:BT0`2VYZH20:VYZ@80[Jf]0P2a/K42
0;>c/`@0][Jf0`2c/k<20:j^[P80YjNW0P2QXJ420::RXP80YZJV0P2ZZZX30:j^[P80/K6a102c/k<8
0<SPf0001P38h=P207EeM@80EEEE0P0/;2`302XZ:P80:b/[0P0`<30203@d=080<S8b0P0Y:BT203lo
?`D0De=C0P10@40203Ph>080<30`0P0^;Rh502d];@80;Rh^0P0_;bl2030`<0@0<C4a0P0^;Rh302l_
;`80@d=30P1FEUH205eMG@80DE5A0P15ADD203dm?@80A4A40`1?Cdl205IFEP80GemO0P18B4P2030`
<080:b/[0P0`<3030410@080Fe]K0P19BDT202@T90809RHV0P0W9bL203hn?P<0EEEE0P1VIVH207]k
N`80SXj>0P26QXH205aLG080Bd];0`0m?Cd203Lg=`80<30`100/;2`202d];@80:RXZ1`0X:2P202DU
9@808R8R0P0S8b<202@T90<0820P0P0S8b<203dm?@80G5aL0P1nOWh208f=S@80O7al0`1RHV8206=S
H`80Fe]K0P1OGel207MgM`80VYZJ0P2c/k<30:j^[P80RHV90P1gMgL20::RXP80V9RH0P2TY:@20;Zj
^P<0]kNg0P2f][H20;:b/P80][Jf0P2h^;P20;Vi^@80^[Zj0P2m_Kd30;no_`@0`<300P2l_;`20;Ng
]`80/k>c0P2^[Zh30:VYZ@80YJFU0P2RXZ8209nOW`80X:2P0P2QXJ420:>SX`<0YJFU0P2WYjL20:VY
Z@80[:b/0P2_[jl20;Fe]@80^;Rh0`2e]KD20;2`/080Z:RX0P2RXZ840:2PX080Xj>S0`2WYjL20:f]
[@@0/[:b2038h=P000H0b>3H0P1eMGD205EEE@80;2`/0`0Z:RX202/[:`80<30`0P0d=3@2038b<P80
:BTY0P0o?cl505=CD`80@4100P0h>3P2030`<080;Rh^1@0];Bd202h^;P80;bl_0P0`<304034a<@80
;Rh^0`0_;bl204=3@`80EUIF0P1MGEd2055AD@80ADE50P0m?Cd204A4A0<0Cdm?0P1FEUH205mOG`80
B4Q80P0`<30202/[:`80<30`0`10@40205]KF`80BDU90P0T92@202HV9P809bLW0P0n?Sh305EEE@80
IVIV0P1kNg/208j>SP80QXJ60P1LG5`204];B`<0?Cdm0P0g=cL2030`<0@0;2`/0P0];Bd202XZ:PL0
:2PX0P0U9BD2028R8P808b<S0P0T92@3020P80808b<S0P0m?Cd205aLG080OWin0P2=SHd207alO0<0
HV9R0P1SHf<205]KF`80GemO0P1gMgL209ZJVP80/k>c0`2^[Zh208V9R@80MgMg0P2RXZ8209RHV080
Y:BT0P2j^[X30;Ng]`80][Jf0P2b/[820;Jf]P80^;Rh0P2i^KT20;Zj^P80_Kfm0`2o_kl40<30`080
_;bl0P2g]kL20;>c/`80[Zj^0`2YZJT20:FUY@80XZ:R0P2OWil20:2PX080XJ6Q0P2SXj<30:FUY@80
YjNW0P2YZJT20:b/[080[jn_0P2e]KD20;Rh^0<0]KFe0P2`/;020:RXZ080XZ:R102PX:020:>SX`<0
YjNW0P2][Jd40;:b/PP0b>3H00060<SPf080LW9b0P1MGEd20492@P<0>CTi0P0d=3@203Lg=`80>SXj
0P0_;bl202TY:@80>c/k0`1<C4`205iNGP80ADE50P0l?3`2034a<@80;Rh^1@0];Bd202h^;PX0;bl_
0`0c<c<204a<C080HF5Q0P1HF5P204];B`80@d=30P11@D4204U9B@<0EEEE0P1FEUH2065QH@80@d=3
0P0V9RH202XZ:P80=SHf0`19BDT205ADE080?Shn0P0V9RH402/[:`80B4Q80`1gMgL207UiN@80PH61
0P20P802069RHP80=cLg0P0Z:RX302PX:0@0;bl_0P0`<302038b<P80<c<c0P0_;bl302XZ:P80:b/[
0P0/;2`202PX:08092@T0P0S8b<202@T90<08b<S0P0T92@202TY:@80=cLg0P1JFUX207]kN`80NWYj
0`1^KVh207IfMP80GUiN0P1<C4`205YJFP80MWIf0P2ATI430::RXP80RXZ:0P1iNGT20;>c/`80VYZJ
0P2CTi<20;Zj^P<0/k>c0P2f][H20;Bd]080]KFe102f][H20;Rh^080^[Zj0`2l_;`40;fm_@80^[Zj
0P2g]kL20;Fe]@80/k>c0`2/[:`20:FUY@80XZ:R102PX:020:6QX@80Xj>S1@2UYJD20:JVYP80Z:RX
0P2/[:`20;>c/`80^;Rh0`2e]KD20:n_[`80ZZZZ0P2TY:@209jNWP80Vi^K0P2MWId30::RXP80ZJVY
0P2_[jl20;6a/@P0b>3H00060<SPf080LW9b0P1MGEd20492@P<0>CTi0P0d=3@203Lg=`80>SXj0P0_
;bl202TY:@80>c/k0`1<C4`205iNGP80ADE50P0l?3`2034a<@80;Rh^1@0];Bd202h^;PX0;bl_0`0c
<c<204a<C080HF5Q0P1HF5P204];B`80@d=30P11@D4204U9B@<0EEEE0P1FEUH2065QH@80@d=30P0V
9RH202XZ:P80=SHf0`19BDT205ADE080?Shn0P0V9RH402/[:`80B4Q80`1gMgL207UiN@80PH610P20
P802069RHP80=cLg0P0Z:RX302PX:0@0;bl_0P0`<302038b<P80<c<c0P0_;bl302XZ:P80:b/[0P0/
;2`202PX:08092@T0P0S8b<202@T90<08b<S0P0T92@202TY:@80=cLg0P1JFUX207]kN`80NWYj0`1^
KVh207IfMP80GUiN0P1<C4`205YJFP80MWIf0P2ATI430::RXP80RXZ:0P1iNGT20;>c/`80VYZJ0P2C
Ti<20;Zj^P<0/k>c0P2f][H20;Bd]080]KFe102f][H20;Rh^080^[Zj0`2l_;`40;fm_@80^[Zj0P2g
]kL20;Fe]@80/k>c0`2/[:`20:FUY@80XZ:R102PX:020:6QX@80Xj>S1@2UYJD20:JVYP80Z:RX0P2/
[:`20;>c/`80^;Rh0`2e]KD20:n_[`80ZZZZ0P2TY:@209jNWP80Vi^K0P2MWId30::RXP80ZJVY0P2_
[jl20;6a/@P0b>3H00060<SPf080LW9b0P1MGEd20492@P<0>CTi0P0d=3@203Lg=`80>SXj0P0_;bl2
02TY:@80>c/k0`1<C4`205iNGP80ADE50P0l?3`2034a<@80;Rh^1@0];Bd202h^;PX0;bl_0`0c<c<2
04a<C080HF5Q0P1HF5P204];B`80@d=30P11@D4204U9B@<0EEEE0P1FEUH2065QH@80@d=30P0V9RH2
02XZ:P80=SHf0`19BDT205ADE080?Shn0P0V9RH402/[:`80B4Q80`1gMgL207UiN@80PH610P20P802
069RHP80=cLg0P0Z:RX302PX:0@0;bl_0P0`<302038b<P80<c<c0P0_;bl302XZ:P80:b/[0P0/;2`2
02PX:08092@T0P0S8b<202@T90<08b<S0P0T92@202TY:@80=cLg0P1JFUX207]kN`80NWYj0`1^KVh2
07IfMP80GUiN0P1<C4`205YJFP80MWIf0P2ATI430::RXP80RXZ:0P1iNGT20;>c/`80VYZJ0P2CTi<2
0;Zj^P<0/k>c0P2f][H20;Bd]080]KFe102f][H20;Rh^080^[Zj0`2l_;`40;fm_@80^[Zj0P2g]kL2
0;Fe]@80/k>c0`2/[:`20:FUY@80XZ:R102PX:020:6QX@80Xj>S1@2UYJD20:JVYP80Z:RX0P2/[:`2
0;>c/`80^;Rh0`2e]KD20:n_[`80ZZZZ0P2TY:@209jNWP80Vi^K0P2MWId30::RXP80ZJVY0P2_[jl2
0;6a/@P0b>3H00060<SPf080Kfm_0P1PH60204m?C`<0ADE5101>CTh204a<C080>CTi0P0/;2`203Ph
>0<0BDU90P1OGel205YJFP80C4a<0P0k>c/2030`<080<C4a1@0_;bl202h^;P80;Bd]0P0^;Rh2030`
<080<S8b0`0h>3P204a<C080G5aL0P1<C4`203Xj>P80@T920P13@d<204e=C@<0EEEE0P1IFET205IF
EP80@D510P0];Bd202PX:080>3Ph0`19BDT2059BDP80>SXj0P0V9RH202d];@80A4A40P1BDU8307]k
N`80Ogmo0P1gMgL206m_K`80BTY:0P0];Bd502PX:0@0;Bd]0P0_;bl2034a<@80<S8b0P0`<30302d]
;@P0;2`/0P0Y:BT202HV9PD09BDU0P0Q8B4202@T9080?Cdm0P1JFUX206QXJ0<0KVi^0P1oOgl206][
J`80D51@0P1?Cdl2061PH080M7Ad0`2<S8`20820P080Ogmo0P2b/[8209ZJVP80RXZ:0P2`/;030;Jf
]P80^;Rh1P2d];@20;Fe]@80][Jf0P2g]kL30;Rh^080^k^k0P2l_;`20;^k^`80^KVi0P2h^;P20;Fe
]@<0/;2`0P2ZZZX20:JVYP80Y:BT102RXZ820:BTY0<0YjNW102XZ:P20:^[Z`80[Jf]0P2b/[820;Jf
]P<0];Bd0P2a/K420:j^[P80Zj^[0P2RXZ8209bLW080WinO0`2UYJD20:VYZ@80[:b/0P2][Jd80<SP
f0001P38h=P206m_K`80H61P0P1?Cdl304E5A@@0CTi>0P1<C4`203Ti>@80;2`/0P0h>3P304U9B@80
GemO0P1JFUX204a<C080>c/k0P0`<302034a<@D0;bl_0P0^;Rh202d];@80;Rh^0P0`<302038b<P<0
>3Ph0P1<C4`205aLG080C4a<0P0j>SX20492@P80@d=30P1=CDd305EEE@80FEUI0P1FEUH20451@@80
;Bd]0P0X:2P203Ph>0<0BDU90P1BDU8203Xj>P809RHV0P0];Bd204A4A080DU9B0`1kNg/207moO`80
MgMg0P1_Kfl204Y:BP80;Bd]1@0X:2P402d];@80;bl_0P0a<C42038b<P80<30`0`0];Bd802`/;080
:BTY0P0V9RH502DU9@808B4Q0P0T92@203dm?@80FUYJ0P1XJ6P306i^KP80Ogmo0P1[Jf/2051@D080
Cdm?0P1PH60207AdM0<0S8b<0P20P80207moO`80/[:b0P2JVYX208Z:RP80/;2`0`2f][H20;Rh^0H0
];Bd0P2e]KD20;Jf]P80]kNg0`2h^;P20;^k^`80_;bl0P2k^k/20;Vi^@80^;Rh0P2e]KD30;2`/080
ZZZZ0P2VYZH20:BTY0@0XZ:R0P2TY:@30:NWY`@0Z:RX0P2[Zj/20:f][@80/[:b0P2f][H30;Bd]080
/K6a0P2^[Zh20:^[Z`80XZ:R0P2LW9`209nOW`<0YJFU0P2YZJT20:b/[080[Jf]2038h=P000H0b>3H
0P1[Jf/206=SH`80G5aL0`1@D50206IVIP80HF5Q0P1JFUX204e=C@80@d=30P12@T8304M7A`80DU9B
0P1LG5`2059BDP80ADE50P0c<c<203@d=0<0<30`0P0_;bl202`/;080:b/[0P0];Bd2034a<@80=CDe
0`0j>SX204Q8B080De=C0P1?Cdl204I6AP80Cdm?0P13@d<204e=C@<0E5AD0P1KFe/204];B`80@410
0P0f=SH202LW9`80>CTi0`17AdL2059BDP80>SXj0P0V9RH202d];@80Fe]K0P1IFET307QhN080PH61
0P1^KVh205mOG`80=CDe0P0X:2P202d];@<0;Rh^1P0b<S84034a<@80<30`0`0_;bl202d];@80:b/[
0P0`<30203<c<`80;bl_0P0Y:BT302PX:0@09bLW0P0Z:RX2030`<080?3`l0P1FEUH306e]K@80R8R8
0P1gMgL205QHF080BTY:0P1@D50205eMG@<0KFe]0P1UIFD207]kN`80[Zj^0P2JVYX208B4Q080YjNW
0`2l_;`20;^k^`80];Bd102b/[820;Bd]080][Jf1@2e]KD20;Vi^@80_;bl0P2m_Kd20;bl_080^[Zj
0P2g]kL30;>c/`80[Zj^0P2ZZZX20:NWY`80Y:BT0P2SXj<20:JVYP<0ZZZZ0P2[Zj/20:b/[080[Zj^
0P2`/;020;:b/PD0/k>c102b/[820;6a/@80YjNW0P2NWYh20:>SX`<0ZZZZ0P2[Zj/40:VYZ@P0b>3H
00060<SPf080Jf][0P1SHf<205aLG0<0D51@0P1VIVH2065QH@80FUYJ0P1=CDd204=3@`80@T920`17
AdL2059BDP80G5aL0P1BDU8204E5A@80<c<c0P0d=3@3030`<080;bl_0P0/;2`202/[:`80;Bd]0P0a
<C4203De=@<0>SXj0P18B4P205=CD`80Cdm?0P16ATH204m?C`80@d=30P1=CDd305ADE080Fe]K0P1;
Bd/20410@080=SHf0P0W9bL203Ti>@<0AdM70P1BDU8203Xj>P809RHV0P0];Bd205]KF`80FEUI0`1h
N7P20861P@80KVi^0P1OGel203De=@80:2PX0P0];Bd302h^;PH0<S8b100a<C42030`<0<0;bl_0P0]
;Bd202/[:`80<30`0P0c<c<202l_;`80:BTY0`0X:2P402LW9`80:RXZ0P0`<30203`l?080EUIF0`1]
KFd208R8R080MgMg0P1HF5P204Y:BP80D51@0P1MGEd306e]K@80IFEU0P1kNg/20:j^[P80VYZJ0P24
Q8@20:NWY`<0_;bl0P2k^k/20;Bd]0@0/[:b0P2d];@20;Jf]PD0]KFe0P2i^KT20;bl_080_Kfm0P2l
_;`20;Zj^P80]kNg0`2c/k<20:j^[P80ZZZZ0P2WYjL20:BTY080Xj>S0P2VYZH30:ZZZP80Zj^[0P2/
[:`20:j^[P80/;2`0P2b/[850;>c/`@0/[:b0P2a/K420:NWY`80WYjN0P2SXj<30:ZZZP80Zj^[102Y
ZJT80<SPf0001P38h=P207UiN@80JVYZ0P1MGEd305UIF@80Ng]k0P1bLW8206EUI@80GEeM0P1EEED2
04a<C0<0ATI60P18B4P2055AD@80CDe=0P17AdL203Xj>P80@4100`0g=cL202h^;P@0:b/[0P0/;2`2
034a<@80>c/k0`16ATH204e=C@80DE5A0P1<C4`204A4A080D51@0P13@d<204e=C@<0E5AD0P1KFe/2
04U9B@80?clo0P0h>3P202LW9`80>CTi0`17AdL2055AD@80>3Ph0P0V9RH203De=@80KFe]0P1SHf<3
07UiN@80O7al0P1PH60205EEE@80<C4a0P0V9RH202d];@<0;bl_0P0a<C44038b<P80<C4a1`0`<302
02d];@80:b/[0P0`<30203De=@80<30`0P0Z:RX502PX:0809bLW0P0X:2P202LW9`80:b/[0P12@T83
05iNGP80JFUY0P23Ph<206MWI`80FEUI101FEUH305eMG@80DE5A0P1cLg<20:j^[P80W9bL0P23Ph<2
0:2PX0<0];Bd0P2b/[820:^[Z`80[Zj^0P2b/[820;Bd]080][Jf1@2e]KD20;Rh^080_;bl0P2m_Kd2
0;bl_080^[Zj0P2g]kL30;>c/`80[jn_0P2[Zj/20:RXZ080Y:BT0P2SXj<20:JVYP<0ZZZZ0P2[Zj/2
0:b/[080[Zj^0P2`/;020;:b/PD0/k>c0P2b/[820;>c/`80/[:b0P2XZ:P209nOW`80Y:BT1@2[Zj/4
0:VYZ@P0b>3H00060<SPf080NGUi0P1ZJVX205eMG@<0FEUI0P1kNg/2079bLP80IFEU0P1MGEd205EE
E@80C4a<0`16ATH204Q8B080DE5A0P1=CDd204M7A`80>SXj0P10@40303Lg=`80;Rh^100[:b/202`/
;080<C4a0P0k>c/304I6AP80CDe=0P1ADE4204a<C080A4A40P1@D50204=3@`80CDe=0`1DE5@205]K
F`80BDU90P0o?cl203Ph>0809bLW0P0i>CT304M7A`80DE5A0P0h>3P202HV9P80=CDe0P1]KFd206=S
H`<0NGUi0P1lO7`2061PH080EEEE0P0a<C4202HV9P80;Bd]0`0_;bl2034a<@@0<S8b0P0a<C47030`
<080;Bd]0P0[:b/2030`<080=CDe0P0`<30202XZ:PD0:2PX0P0W9bL202PX:0809bLW0P0[:b/20492
@P<0GUiN0P1YJFT208>3P`80IfMW0P1IFET405IFEP<0GEeM0P1ADE4207=cL`80[Zj^0P2LW9`208>3
P`80X:2P0`2d];@20;:b/P80Zj^[0P2^[Zh20;:b/P80];Bd0P2f][H50;Fe]@80^;Rh0P2l_;`20;fm
_@80_;bl0P2j^[X20;Ng]`<0/k>c0P2_[jl20:^[Z`80Z:RX0P2TY:@20:>SX`80YZJV0`2ZZZX20:^[
Z`80[:b/0P2^[Zh20;2`/080/[:b1@2c/k<20;:b/P80/k>c0P2b/[820:RXZ080WinO0P2TY:@50:^[
Z`@0ZJVY2038h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P0
0?l0b>3H8@38h=P00?l0b>3H8@38h=P00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.20067, -3.20067, 0.468297, \
0.468297}}]
}, Open  ]],

Cell["\<\
Soft thresholding shrinks the magnitude of the coefficient values outside the \
threshold, but it's worse in our example.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SoftThresh[
          N_] := \ {\((X_?NumberQ \[RuleDelayed] 
              0\  /; \ Abs[X] \[LessEqual] \ N)\), \((X_?
                NumberQ \[RuleDelayed] \ 
              X - N\  /; \ Abs[X] > N)\)};\)\), "\[IndentingNewLine]", 
    \(\(shdecomp\  = \ decomp;\)\), "\[IndentingNewLine]", 
    \(\(shdecomp[\([2, 2]\)]\  = \ 
        decomp[\([2, 2]\)] /. SoftThresh[32];\)\), "\[IndentingNewLine]", 
    \(\(shdecomp[\([1, 2]\)]\  = \ 
        decomp[\([1, 2]\)] /. SoftThresh[8];\)\), "\[IndentingNewLine]", 
    \(\(shdecomp[\([2, 1]\)]\  = \ 
        decomp[\([2, 1]\)] /. SoftThresh[8];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics[Raster[\((ImgIDWT[Interleave2[shdecomp]] + 128)\)/255]], 
        AspectRatio \[Rule] 1];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
576881B1AC4A192B1F1F24313A4E3333333536302B4032322D4233404C583D3B38312B28
2A2B3B7062635B7763535A5E656D73747186797E7F81817F7E7E7F818386888A8A898889
8B8E908D8B8E908D8988898A8C8C8C8C8D8E8F909192929191909091929394918F919492
909498969496999A9B9DA0A3A9B4C3CBCFCECCC2
595D6DA6C299452F2D2D242E374030363A3834312E3932312E443347464E3E3833302E2A
292C3B6B62645B7C5D535B626B6F717374807B7E7F8182817F808081838587898A89888A
8C8E8F8D8A8B8C8D8D8A898B8E8D8C8D8E90929393939292939291929496979592939493
9193969695989A9A9B9DA0A3A9B5C4CDD2CFCBC6
5A595E7191C7913A202B252E342F2C38423A3031333130303044314E40413E332E2F322B
272D3D6862655C8156555C6772716F7377797D7E7F81828281818282828486888989898B
8D8E8E8C8A89888D918D898C908F8D8E909294969695949495949495979A9C9995959594
9293949596999B9A9A9C9FA3A8B6C4CED4D0CAC9
5D575A657EB6B176322922272E2D30363B342D30332F2E30333B30513F3D39322F31322A
2530437161665F7B54585F687071717478787B7D7F80818283838281818488898889898B
8D8D8C8C8B8B8B8E908E8B8D8F8F8F91939495969696969595969797989B9D9A96949392
92959797969798999A9B9DA1A7B4C1CDD4CFC9C6
5F5A5A5D6A90BEB454391F20282E3333322E2A2F332F2C3035312D4F403B313132323127
2131477A61676274545B63696E71737678797A7D80808082848381807F858A8A8889898B
8C8C8B8B8C8D8E8E8D8E8E8E8E8F9194969696969697989695979999999B9C9A96939191
93979A9895949597999A9B9FA5B1BECAD2CEC7C1
5C6457596178A2CDA5363424272A2F2E2D2C2C3033302D2F343A40543B42453C302E2E2F
33354577686C6370535D676C6F7072777C7B7B7D7F7F808081808081838587888A8A8B8B
8C8C8C8C8C8C8C8C8C8D8F8E8E919497989897979897979797989A9A9A9B9B9997949394
95979795939495949597999CA1ADBAC8D1CCC4BF
586D55575D6A85C8C69732282B2A2B2B2B2D2F3233302D2F322F2B44383733312E2D2B24
232644746F6F646C545E6A6F717171787E7E7C7D7E7F807F7E7E8083868483878B8C8C8C
8C8E8E8D8B8A898B8C8E8F8F909397999A9998999A989697999A9A9B9C9B9A9998969596
9896949393939492909397999DA9B6C5CFC9C1BD
4B6A58575D6E8BB8CDB57D492528312F2F333736353A40434446474F46464543403B3838
3E435C7A6C686864565E696D707274797D7E7E7D7D8082817F808183858687898C8D8D8D
8D8D8D8C8B8C8D8E8E8F91929497999A9999999A9A99999A9C9D9D9D9C9C9B9997969798
9997949494949391909194979DA6B1C0CBC4BFB6
49635A5A5F7793A1BECAC577332E363334393E3C38333031333739383733302E2C2A2926
293453716C626B5D585D666B6F7377797B7D7F7E7D8082828182828283878B8B8C8C8D8D
8D8C8C8C8C8F92919091929597999A9A999A9A9A9A9B9B9D9F9F9F9E9D9D9D9A97979899
9997959596949291919090959DA3ABBAC5C0BBAE
66606E725C6F868FA5C1D1B1592A2F353034373736343334363B3E3A38363533312F2E2B
2F3A5B7175616759565C656A6E7376797A7C7E7D7D7E807E7D808383828588898A8B8C8C
8C8D8F8F8E8F90919191929294979A9A9A9A9B9B9B9C9E9FA19F9D9D9E9E9E9B999A9B9A
97969595959492908E8D8E91969CA4B1BBC0AFA7
955B5A725E6A757D88AECDDA993E29332A30353431333537393D3F3B373737363432302C
303C5F717E626256535A656A6E7275787A7B7C7C7C7D7D7B797E83838182848688898A8B
8C8F9191908F8F8F919191909094999A9B9B9B9B9C9D9FA0A19E9C9D9E9E9E9C9B9C9D9A
969595949393928E8B8A8B8C8E949CA8AFBBA19F
B69061696866696E7898B6E1BF80312A262A2F2D2B2E3232333A403932323433322E2B25
2C3964707C616152535A656C7072747678797A7B7C7D7E7D7D7F8181818385878988888A
8C8F9191908F8F9091929393949597999B9B9B9B9C9C9B9D9F9F9E9E9E9D9C9C9C9C9B98
969595939291908C88878787888D939CA2A59291
A6AC6B617167626671859CD4D3BF462F23242A2826292E32353B3E372E2E30302F2A2621
273463707761604F535A666D7273737477787A7B7C7D7F8182807F80828486888A88868A
8E8F90909090909192939597989795999C9B9A9B9D9A989A9E9FA09F9E9C9B9C9C9A9797
96959391908E8C888483838385878B91958D8583
869E917368716D70747B89BAD4D9A02C2F1F272424272D3642505748342E2B2C2D29282E
2A39687C75665E51515A666B6F72737475787B7D7E7D7D7F81828181818486888988878C
919190919192929292929395969696989B99979A9C9B9A9D9F9F9D9E9E9D9B9A99979696
95928E8C8B8885817E8082838485878A8B827C7A
5E6B7D6D64807D8181808298AFB1AA6E2920272424252B3D4D4B44413C3228292C2A2C3D
2E2E4C75756C5A53505A65696C70747475797D7F7F7D7C7D80828483818487888988888E
939290919394959392919192959697999A9896999C9D9EA0A19E9B9D9E9E9C9895959594
928D888685827E7B7A7D818384848484837C7674
525E626C7584888E9294979FAAB1B597624B2422262527343E3A3333332E2A2A2D2C2E32
2C38657972645550515B676A6C70747474787D7D7D7D7D7F8082848484868889898B8D90
929190919294969594919093979999999999999A9C9D9FA0A09E9C9D9F9D9A9693949593
9088817E7D7D7D7D7E81848585868685827B7471
233E41698B8C9299A2AAB1B3B5BCBFBBAB822621272525282C2B2B2C2D2C2C2D2E2E2E28
2A315D6A71604F4D525C676A6C70747473787C7B7A7C7F808182838486888989898D9191
909091909194969796959497999B9B9A999B9C9C9B9D9F9F9E9D9D9E9F9C989593939492
8D837A77787B7E8081818080808284838079726F
2026294E8A9C9CA3A9B4BDBABABEC2C5B99F3F2620212527282726282A2C2F3030302F25
28325C6871674A4C545D6567686C707274777A7B7C7C7D8082828283858788898A8C8F91
91919191939597979696969697999A9B9B9D9E9E9D9E9E9E9E9E9E9F9F9B96959494928F
897F77777D80827C746A6260626A72706C655F66
1F161E357DA9A4ABADB9C3BDBDBFC1C4B9AF5D361F20282828262526282C303232302E25
253158676E6D464C555C626465696E727577797B7D7D7C8083828182848687898A8B8C90
9392919395979897969797969597999B9D9E9F9F9F9E9D9E9E9E9E9F9F9A94959594918B
857C757A8387867A6954433F43525F5F5A565161
2E201B2857AFABB0ADB8C2BBB7BCC0BDB5C09E7B3329292623232324252A2F302F2C282A
2332596C6068474C535A6062646A707376787A7A7B7D7F808181818386888A8A8A8B8D90
9191909498979596979899989697999B9C9D9E9E9E9E9D9E9E9E9D9F9F9A959493908C87
817974848388877C6B4E35313744535C6264636C
1E1D1E2331AAAFB1AAB3BCB6B0B6BCB8B2AEA29F524031282221222223282D2E2C28232E
22335A6F515E484C50575D60646C737576797C7A797E82817E808284878A8C8B8A8C8E8F
8F8F90959A979395989A9A9997989A9B9B9C9D9D9D9D9E9E9F9D9C9E9F9A9593918D8983
7D77738B818787857A5735303744546471767979
251E1A212188B0A9A8ACB1B1AFB1B4B6B8B6B5BF9D764C352724232222272D2D2D2B292A
24355777665F44454B535C61656C7475767A7D7D7D8082807E80828486898B8C8D8D8D8F
91919093969696969798999796989A9C9D9B9A9C9F9F9E9F9F9D9C9D9D999492908F8D81
7673738280868985807D7B79797F84827E7D7D7B
292118201A60A8A1A5A5A7AAADA9A5AEB7B9B7B1AA90704E3328242223272D2D2E2E2E25
2539566B5C4F424246505B61666D7375767A7E80808182807F8183848587898D8F8D8B8F
92929191929699989696979696989B9D9F9B989CA0A09F9F9F9D9C9C9A9794918F919080
706F73777F868B8B88858283858686898B847D7B
252D1D1D1B4493ADA3A6A5A3A2A7A99D96A0AEC0BFAE91664329211F24282C2C2C2A282B
2234567161544542444E5A60676D7274767B7E7F7E808281808183848687898C8F8E8E8F
90909191929698979697999A9A9B9C9E9E9D9B9EA0A09F9E9D9E9E9D9A96939190908E7F
726E70757F858B8C8C8C8B8D8F908F8F8D857D7B
2136241C1F2E76AE9AA2A19D968C817976767BA2A7B4B18A5F32211E25272A2B29241E2E
1C2F577663574844454D585E676C7174777B7E7D7C7F8181818283858788898B8E90908F
8E8F91939496979796989B9D9E9E9E9D9E9E9FA0A0A0A09E9D9FA19E9A9692918F8E8A7F
746D6E757E84898D8E8B888A8D8F8F8D8A837C7B
202F2A2020224A899F9C918C85796F726B78849293A4B0A26D422B2224252727282F3344
2B3656735C504344484F565C646B727475797D7D7D7F81808082848687898B8C8D909290
8F9193959798989797989A9B9C9C9D9D9D9E9FA0A0A0A0A0A0A1A19D999795918D8D8B80
746E6E747C83888B8C8A898B8E8E8D8985817D7C
20262F28221F244B767D7E7D786A606E678EB0A99C8E859F7D593E2B2221252729262029
1B2E557254483E444D51555B616A727474787C7D7E7F80807F838686878A8C8C8C8F9291
91939597999A999897989A99999A9C9D9E9E9F9FA0A1A1A2A3A2A09C999898928C8D8C81
76706F747A8085888888888A8C8A8783807E7E7D
25272D33271E1A314F6963757F6F65776D93BBD3C2AF8794823D26252023262726272728
2130566F56453D414D51555B6269707274787B7D7E80818182848687878889888B8E9293
93949597999998979698999A9A9C9F9FA0A0A0A1A2A2A2A3A4A29F9D9A9896928E8F8E86
7C767274787E8386878888878683817E7C7D7D7C
282A2A3D2C2018202A52486D887B6F83778399CCC3CAA3A29A3D21281D23282724272B24
2631556D59443C414C51565C63696E7275787B7D7E80828384858687888685868A8E9194
969695979898979697989A9B9C9EA1A1A1A2A2A3A4A3A2A3A4A19F9D9C98959291918F8A
837C7775767C8185868787837F7D7C7B7A7B7C7B
2528293A2B2B2A2622312E5A878E727C767A8DBECED8C9CBC58229231D232A2826272922
242F526955433B484951595E63696F7376787A7D7F8183838485868787898892898C9194
96969597989796989A9A9B9C9C9D9E9FA1A3A5A5A4A3A1A1A2A1A19F9D9A979492908D89
857F7B7A7B7C7E82858686817C7C7D7B79797780
21272C3C2C261D1F231A1E487E9C7674737480A8CFCFCBCDC9BC45331F222A2928272621
222D4E6650413A4F45515B60646B717578797A7D8082838383848687888B8C9C898D9194
959696979897979A9D9D9C9C9D9D9D9EA0A4A7A6A4A2A1A0A0A2A3A19F9C9996938F8B88
8682807F807E7D80848584807B7D7F7D79777485
212D395637261F1E21171B38669585756E7A7791BAD2CBCECCD5A02E3025282527252421
242D4A634A3D3C4947515A5F676C7074787C7E7E7D80848382848789898A89948B969092
94969898989A9C9EA09E9C9D9E9F9FA1A4A5A6A6A5A5A4A3A2A3A3A3A2A09D9994908D8A
88858382818181828382807E7C7B7B7A7A797881
24374A7244291F1D1F1B1D2A4B86927D6A80727DA1CEC4CCCBD3CD8E2A22272526242322
262D466044393D404950585F686D7074787E827F7B7F84828184888A8B88878A8E9F8F92
93979B99989CA1A2A2A09D9EA0A2A3A6A7A6A5A6A7A8A8A7A5A4A3A5A5A39F9B9692908C
8A87858382838584827F7D7D7D7A77787A7C7D7C
2D3F558D7649221B1D1A1C20367397916B76707991BBC6CBCBD1D1B8692F1C2523232522
232F445C403A3A3F484F5668666C7074787D80807E818382818387898A8A898B909A9295
97999B9A9A9EA2A3A3A09EA0A3A6A7A7A6A8A9A8A7A8A9A8A7A5A3A4A5A29E9B9895918D
898786848284858583807E7F807C78797B7C7D7C
394D658A734F271D1D1B1C1B265D92A3706D707885A6C7CBCACCC8D3AA4B1D2820232621
203042593D3A373E474F556F646B7075797B7D8082838282828384878A8C8D8F91939698
9A9A9B9B9C9FA2A3A3A09FA2A6A9ABA8A5A9ADABA8A9A9A9A8A6A3A4A4A09C9B9A97928D
888787848384858585828081817D797A7B7C7D7D
4460809D8261271D1F1E1F1B2041779F80746F717B9CC0D0C7CBCADFCFA248241E272422
222C40593836333D48515868656B7074787A7C8083838383848484878A8D8F9091939798
989B9D9D9E9FA0A1A1A1A2A6AAABACA9A7A9ACACABABAAAAAAA7A4A5A5A29E9C9A97948E
888786858485868584828181807D79797A7D7F7F
51739AB1926D251D2222231D1F2A56918F7F6D6B7494B5D3C5CCCDCEC5CE8632202A2323
252A3E593533313C4A545C61676C707477797B7F83838385868585878B8E8F9091959998
979A9E9F9F9F9F9FA0A2A5AAADADABAAA9A9AAADAEACAAAAABA8A5A5A5A3A19D9997958F
8986858585878886848381807F7C79797A7D8182
5F86AEAB855521262125272425253F7B938D686A70859DD2C5CBCBCDCCDAB36B20252523
252D3B52343435404C555D62696D7175787B7E81838282848787878A8D8E909193969898
989B9E9E9EA0A2A3A5A6A8ADB0AEACACADADADAEAEABA9AAABA9A7A5A4A3A19D99979690
8A88868686868688898581807F7E7C7B7B7F8283
7294B4976D381E2E2026292A2A272E618E98686A6E7785CAC6C9C7CACCD5D3A82F242723
2530384B333639434E565D656B6F7376797D81828181818487888A8C8E8F909396979798
999B9D9C9CA0A5A8A9AAABAFB2B0ADAFB1B1B0AFADAAA8A9ABAAA8A6A3A2A09C99979691
8C8A88878786858A8E878080807F7E7C7C808384
A4A1946E4A2D232A21242727262A274B809A78696D787AB0C8C4C1C6CBD3D5C66E322124
222D34472F343A424B555F656B7177797A7C7E7F8082848485888B8C8D8E909396989899
99999A9B9CA1A5A7A8A9AAAEB2B0ADAFB2B2B1B0AEABA8AAACAAA8A7A5A3A09E9B989593
908D8A898888898B8D888381817F7D7C7C808384
AB926B472A26272322222423212D23386B958B6C6D7B7492C4C0BCC2C8CECCD5AC4D2229
202A30442B323A41495560666B737A7B7A7B7B7D8083868483878B8C8C8E909396989999
9998989A9DA2A5A6A6A7A9ADB1B0AEB0B2B3B2B0AFABA9AAACABA8A8A7A4A09F9D999494
93908C8A8A8B8D8C8B888583817E7C7C7D808384
9876472E212B362B212123222226202E5284987C6E737281B0C9B7BFC4C5C6DBD1963A2A
25292E442B3138404A5763696D757A7977797C7F828587858486898C8F90909193949698
999A9A9C9FA2A5A7A8AAADB0B3B1AFB0B1B3B4B2AFACABADAFADA9A8A6A4A1A09E9A9592
8F8F8E8C8B8E908E8A898784817E7C7D7F828384
76562B232221212223232423251F1F27396E9D8D726C717797CEB5BEC0C1C2C8C3C65E3D
28292D432C31363F4B58646B7076797775797E81848687868585868C9191909090929497
9A9C9D9FA2A4A6A8AAAEB1B3B4B2B1B1B1B4B6B3AFADADB0B2AEA9A8A7A4A2A09E9B9791
8C8E908E8C9093908B898785827E7C7E81838484
57412924242526252525242F2321212029578C967E6C707A81BAC3C0BAC5BFC0C0D6AD33
3A2A2A332C3036414E58626B72757777787C8081828384858585868A8E91939392939597
9B9EA1A3A6A7A9ABADAFB1B2B3B3B2B5B7B7B5B2AEACABADAFACA9AAAAA6A19F9E9C9995
919192908F9293908C8A888784807C7F82848585
3F342F2925272A29272725382325241D1F42739789726F7E71A0CDC3B4C8BDBDBACACA92
2D242A282C3036424F58606A737575787A7E81817F808183868686888B91969694959799
9CA0A4A7AAABACAEAFB0B1B2B2B2B4B9BDB9B4B1AEABAAABACABAAACADA7A19F9D9C9B99
97959392929393908D8B898886827E7F82848586
4C342E353E342A292B2926342C29241F22345496A28D6D76738BB9CFB0C2BEBCB9C6D0B7
682F1F282E3137404A55616A717577787A7D7F7D7C7E808386888B8B8C9297979798999B
9DA0A4A9ACADADAEB0B2B3B3B2B3B4B7B8B4B0B0B1ADAAADAFADABACADA9A4A29F9E9D9A
97969594929394918E8C8B89868381807F828585
5C3C302623262B2D2E2A282D342C2424272E3B7C92967070787A9ED3AEB9BEBCBAC1C7D5
A347202E2D31363C445361696E757979797B7C7B7A7D8183868B8F8F8F939798999A9B9D
9EA1A5AAAEAEADAEB0B3B5B4B3B3B3B3B3AFADB0B3B0ACAFB2B0ADACABAAA8A5A19F9D9A
96969794929394928F8D8C89858584807D808384
4D392E2A292B2D2D2D2C2B2C2F2D2A2929293160839E8170747B85B5B5B1BBBDBFC1C4DF
D0953F26222E323B445360676C73787A7A7B7D7C7C7F8284868A8E91929395979A9B9C9F
A2A4A5A9ACADADAEB0B2B4B4B4B2B1B2B2B1AFB0B1B0AFB1B2B2B1AEACAAA8A5A29F9C9B
9A979493939393908E8C8A878584848280808080
3B352C2D2E2E2E2D2C2D2F2C2A2D2F2D2A282E426A9A9475707E7093B8ADB7BDC4C4C2CD
CBCC7338182B2C3945525E656A7177797A7C7D7E80828485878A8D9194949396999B9CA0
A4A6A6A8AAACADAEAFB1B2B3B4B1AFB1B3B3B2B0AEB0B2B1B1B2B3B1ADAAA7A5A39F9B9C
9C9691929493918F8D8A87858483848483817E7E
3E352D2E32312F2F2F2E2E2E2E2E2E2D2B282A324D88A2826E736D84AFBBAFBAC1C2C2C8
CCDCB34F2E2C2734444F5961676F7678787A7D7E80818386898B8D9093959596989B9EA1
A2A5A7AAACACABADB0B3B4B1AEADAEB1B3B3B2B1B1B1B1B0AFB0B1B0AFACA9A7A5A19D9A
979593939593918F8D8A87858484848382818181
42332C2F34333031312E2C2F322F2C2C2C2A2928336FA59170686E7AA0C6A9B5BCC0C2C5
C6D1C9B233332532424C545D656E757676797C7E7F8081868A8C8D8F92969897979BA0A0
A0A4A8ABAEACAAADB0B4B5AFA9AAAEB1B3B2B0B2B4B1AEAEAEAFAFB0B0AEABA9A7A39F98
93939494949391908D8A86858585858280828485
5137262A3433312F2D2C2C2E302E2C2D2D2A28242D58909E8268666E8ABBB3AFB8BCC1C1
C1CAD0CB8F2C36344046515B656D737474777B7E81818185898B8E9092969A99999CA0A1
A2A5A8AAACABAAACAFB1B2AEAAAEB2B3B2B0AFAFB0ACA9ABADAFB1B1B1AFACA8A4A09C98
95939291909192908D898684838484807E7F8281
382922293333302C292A2C2D2D2D2D2E2E2B29252D4372A29470616575A9BBACB2B8C0BE
BDC5CBCDC0852E3040454E59646C717374777A7E82828184888B8E9093979B9B9B9D9FA1
A3A6A8A9A9AAABACADAEAEADADB1B5B3AFAEADACABA8A6A8ACAFB1B1B0AFADA7A19D9998
97938F8C8B8F93908C8885838182847F7D7D7F7E
342D292F36322E2D2C2A2A2C2F2E3130302E2B2F2734528A9B8A66656D96B6B9A7B3BEBF
BEC2C7CBC8B3623833484D5761696F7274787B7E808182868B8C8D909497999B9C9D9EA1
A5A7A8A6A5A7AAACAEAFAFADABACADACABABABACADABAAA9A9AAACADADACABA7A29D9B99
96918C8A8B8F918D8886858382828281807F7E86
3131313537322C2D2F2B282C3132343331302D382429376B98A170686983A9C49FAFBCBF
BFC0C1C6C4D0A3522F4A4B555D666D7175787C7D7F8082888E8D8C909596989B9D9D9DA2
A6A8A9A4A1A4A9ACAFAFAFACA8A6A5A6A7A8A9ACAFAFAEAAA6A6A7A9AAAAA9A7A4A09E9A
958E898A8C8E8F8B868584838382818283817D8E
2F30313333302C2C2D2B2A2D303B30323232303528272E5381A3816A62718DB9A7ADB7BA
BDBFC0C4C6DECDA1493D3F565A656C717476797C7F8285888A8C8D919597989B9E9E9FA2
A6A7A8A4A1A4A9ACAFAEACA9A6A6A6A6A7A7A8ACB0AFADACABA9A8A7A7A9ABA8A2AAA09B
948E8A8A8B8E918D888786848382818282807D8F
2E2E2E2F2F2E2C2B2A2B2D2F2F422C303233322E2C272B3D649991715F6472A6AFAEB1B5
BABDC0C4C8CDC8C97F45385457636A707374757A7F848887868A90939697989B9E9F9FA2
A5A6A6A4A2A4A7AAADAAA7A4A3A5A8A6A5A5A7ABAFACA9ACAFADA9A6A5A9ADA8A0B2A29C
938F8B89898D918F8B89888583828281807F7D8F
2F2D2B2D2E2E2D2B2A2B2C31333C2D2F3031312B2824272F4780958D68636891ACB9ADB3
B7B9BBC0C5C9CCDEBD88463F515B676C707274787D838887868B90949798999A9B9C9DA0
A2A3A3A3A2A2A3A3A3A09D9C9C9FA1A09FA0A2A5A8A6A5A8ACACABA8A6A8AAA5A0ACA5A0
97908A8685888C8D8C8A87838081828280818091
2F2C2A2C2E2E2E2C2B2B2C3237322F2E2D2F3029232224252F6290A4766A657CA3C2ABB1
B2B4B6BBC0C6CACDC9BA683D4E5462676C7074777B818687878C91959899999897989A9D
9FA0A0A1A19F9D9B999693949698989897999C9E9FA0A0A3A5A8AAA9A7A6A5A2A0A3A7A3
9C9188838183868A8C8A87817D80838280828292
2B2C2E2D2E2F2E2C2B2D30323431302E2D2D2D292424252024457A998F76647290BDB4AD
A8ADB5B7BBC0C6C9CED6AE7747495A60696F74787B808687898D929496999B9A98989899
9A9B9C9C9B999796959290929494949392949596979A9D9F9EA2A5A5A4A6A7A29EA0A5A4
A1958883818285888A898783808081807F818292
292C312F2F2F2F2D2B2F33323130302F2D2C2B292726261F202D5D84A286676C7BAFBBAB
9FA8B4B4B6BBC0C6C9CDC6A454555159656D74787B8084878A8E929394989B9A99979696
969797969593929394918E9093918F8E8D8E8F8F90949899989A9D9FA1A5A7A29C9DA0A3
A3978A84818284868888878683817F7F7F818192
2C2C2B372E30302E2C2F32312F2F2F303031302B2725241F1F223F6F9A9A70666C93B3B3
9DA5ADB6B0B5BBC2C8CACCCAA85F5755586370767A7F8385888B8F929394949596969696
95949290909192959690898D908D88888886898B8E8C908C9394989B9EA0A09C9897979A
9C968E837B7D82858787858483817F7F80828394
302A223A2D31302E2C2E312F2D2E2F313435342E27242220201F275985A57B666277A4BB
A1A5A6B8ACB2B7BFC6C9C9C9BAA74E5A4E5C6B73797E818385888C9093908D8F92949596
95918E8C8C8F9397988F85888B878280808084888C87867F8F8C8E949D9B989796939092
94948F82767980838685838282817F7F80848696
2A333B3E2B2C2E2D2C2F312F2C2D30333535332C25252523211D203F669290715D6A8EBE
B1A99DB4ABB1B6BCC3C7CACAC6C09B4F5B59676F787C808386898B8D908E8C8E90929392
91908F8E8E909395948A807D81817F756C828087878A7571818A83909E9993989D9B9895
938E887E76787C81848483828281818080868C95
292929292B2B2B2B2C2F322F2C2D30333634302B26262725231F202845759E805F6278B8
C0B098AEAAB1B5BBC0C5C9C8C5C9C29A5153666E757A7E8387888A8A8C8C8C8D8F90918F
8E90929190908F908E857D73757A7D6B5A857D8683906C6F7B7C5E7DA19D939BA5A6A29C
948A827C78787A7E828383828182828080899294
2A2929282B2C2D2D2E2F302E2C2C2D313433322C2D2825242522211F2E598C96725D669F
BEC3A3AAA8AEB4B9BDC3C7C9C9C9C9B998765C616F767C818485848D8586878B8F90908F
8E90928F8B8784858A857C6F6A727A6856807E8887866B73817C6782A2A4A1A6ACADACA5
9C91877F7B7A7C7C7D7F818080818381828A9393
2C2925282B2E3030302F2E2F2F2D2B2D3132342F342B23242625231C1F3F70A2855F5A84
B3D0B3A9A5AAB2B7BBC0C4C9CBC8C3C3BC8D5F5E69717A7E80807E8F7F8182898F90908F
8E8F8F8B857C767A82817C6F646F7A6A5B7C828C908E9099A49991969FA6ACAEADAFAFA9
A0968C847E7D7D7A777A7E7F7F818383848B9294
2C282325292D3031302F2F353A332F2E2F303233382F2927262423202231518A92795571
99C3C8B2A2A5ADB2B8BCC0C7CBC9C6C7C6AD8E715D67777B7C7E7E88807F7F8891919090
8F8D8B867F756B7265697474737C868D929A949A9FA0A6ADB3AEABB1B9C1C3B29F9C9B91
8B888784827F7C7976787C7F82828282838C9496
2B272324272C31323130303A423B342E2B2E323739342E2926232325292A376891935A65
7BABD3BC9FA0A7AEB5B9BCC3CACAC8C6C3C6BE8D5E637476777B7F80827F7D8791918F8F
8D89837D756D616C4E556C7A868C90959B9FA4A9AEB5BBBFC1C5C5B8A9A6A39B928B857A
7479808384807A7776777A7F84838181838C9698
2A2A2A29282D333434302D343B402F353A342D313339272828252222232F2E5A86A07762
628ABEC6A09BA2ACB7B8B9BFC7C8C8C7C6C8C5AD9078697483817C7A7C7C7D868E8D8E8C
887E75685C5959655E6B7E8689868283878F9DADBBC1C3C6C8CBCDCFCCB9A3938A949B92
6E727C81837D767677797C7F81828282848C9393
292D302D2A2E34393C332B2E32452C2823262A2E2C3C20262B2722201F352F3E528C8F68
526B9FC5A2989DAAB7B7B5BBC3C6C7C7C7C4C2C7C3986D696F747978767A7F8489878A86
7F736651424551627474717D857B6D65657389A3BAC3C7CACCD0D1CEC8BEB09A888A8C95
6E727A7E7E797374787A7C7D7E818384868B9091
42382B292A2D35455642292B323D2F2C28292B2F313725282B28242425312D2F3B729884
53577FB2BBA4939EADAFB0BEBDC3C7C8C8C6C4C9C9B4997D676A7476787C82828080827C
726E554031374A5C70767A776F5E4E46454E6082A5BECDCDCED0D1D0CCC4B9A6928A8180
66797C79737173777A79777B7F828587898D919A
362F2727292D36556F50292A3232332F2B2B2D3337312C2A2A2827282B2B2C272B44738A
5F536685A59D9198A3A7A8BEB5BFC6C8C8C7C6C4C3C9C69769656F73787E837D7676756F
63664532252F435769767C6C5644383537373E4D669BCAD0CED0D0CECAC8C2B29D857064
60817C73676B73787B767278808486898B9092A4
372F27262830396A7550322C2E2D2F2D2C2B2C3339302A28292929282827292324355B7C
725C59779DB3A49D9A9A9AABADB6BDC3C7C9C9C6C4CACAB3977A6568717F78726A67635C
534D3834344D53626C7C71563F414B565E53473B456EA7D0CED2D1CFCDCDC9B69F7A5B55
618372695F6F6F73757474797E8386888A90959E
332E29262734417D714A3C2F2A292A2B2C2A2B333831272728292A272525262425304365
816D59708CC1BAAC9E949099A7AEB5BDC5C9CCC9C5C5C5CAC6966661677A6C675F58504A
4338302A2847435E71805E43364C645D5255563E35467CCACED4D0D0CECFCAB4976B494D
668266605D756C6F6F73777A7D82868788909797
2B342B272735518A583D3E31292627292C2C2C3337312A2726343F352A262629334A4D68
9195706671AAC4BFA4A6B0AEAEB2B7BABEC6CDCBC8C7C7CDCBB18F6C55646761564C413C
37302E2C2E43465F6E6F43465D5E59493D4C5C6D4B3F52B4CBD2CBCECEC9C0AB7E5B4458
7A795B5F677671706F757C7F808487898B8E919B
24392C282938629243333C322A2625282C2D2E3236332E2B292C3032342A2431424D2F3B
6BA08D695A8BC1D1AFA6ADB2B8B9BAB7B7C2CCCDCACAC9C9C6C5B87F5053615B51453934
322F2E2E3139465C675D2A385D574935252D3B7145353BA3C7CFC4C9C9BFAC97604A4264
856C5160757777737178818384878A8C8E8E8B9E
29332C262C407280352D34302D2A282A2D2D2E303130312A2A35404B413D3B30272D222D
508D9B855A729CC8BCAEA9AEB4B6B7B5B5BBC3C9CDCBC7C5C5D0D0B273574F52564C423B
352E2B2B2F343E4E5758333D5147392A22263B63403D48A5CBD1C3C2BAB4876C423A3C5E
68554C627B7C7A76747A818486888B8E9091909A
302E2E282F4B7F692C2A2D2E2F2E2C2C2D2D2D303234372F313C485E4A362522231D1D23
336C9DA0666273B5C4B5A3A7AEB1B3B3B4B5B9C5CFCBC4C4C4C3BDC5A36F484C5A554D43
382F2A292C2F3541464424313E382E25233053583F5471B2CBCBBBB3A1A05E412B2E3551
44424C667F817C7A787B8184878A8C8F91949695
2D313F412F5685592828302F2D2B2A2B2B2828374C6464564D5F6E5D362C2924211E221E
265186A485676198BBC6ADA7AAACAFB2B4B6B9C4CDCBC6C5C4C0BDD2C9A9684B45514A4C
49422B2B2E2F313638392C3236322C28282F42423D5C83A9BABFB59975683E2F28282A34
2D3C546D8385827E7C7E8285898A8C8F92959796
2B3B4E572F5E864B2728342F2A28282829262946687F6C6D664E362924272B282425281E
20386799A0775A7DA9D0B8ACA6A8ADB0B4B7BAC3CACBC9C6C3C0BDBEBCC79A5E3A504641
364330313231302F2F30343331302E2D2D2E30333C475B82A49C85694C3629282B282624
2B446075858886827F8082868A8B8C8F93969798
264947472D607C3D28262F2B27252523272C4A61757E6D5D49362821252B2F2C26262426
1D25437E9F9663708FBAC0BAA3A7ADB0B2B5B8C0C7CACAC6C1BFBDBCBDD1C6A264503D3D
3D4A3333333231303131343332302F2E2E2E2E2E324446627A705C49382B27272924252B
3B577380878784817F8082878B8C8D909396999A
325939312D606E332924292625232421283B6D75746D6043272224252A2F322E29241F2E
1C1B255D8FB0746C769CC0C7A3A8ADAFB1B3B6BDC4C8CAC6C1BEBCBCBBB7BBC7965F403E
434D383837353435363534343433312F2E2F302D2A4031445145342F2E2C2C2A2A262A3B
536E84898785817F7E7F82878C8E8F9193989B9C
44482F2A2E626531272226262626282A355F767C7355392D282525302A2F312B262C2E36
171F1E426DAA8E786C81A5CAB1A9ABADB0B2B5BCC3C8CBC8C4BFBBBABBB5BAD7C99B5841
404A4746423E3A353235383734333231302E30302E382E31373D4135282528282A343561
888B88858282837F7D8085898C8E9094989A9C9D
5233282830645E3226212526282A2F384482765F3C2E26292E2C293A2B2E2F2B25231E2B
182C1E2B4896A0896B6C86C3BDACA9AAAFB1B4BBC3C7CACAC8C1BBB9B9B6B4BCBFC99363
454855534E49433A3339403C3635353433313233343334302F2B2B2B2B27262B324C486A
868A89827B7F837F7B80878A8C8F92979C9D9D9D
412E2A2B325F5B332A242625272C334E537B5F462C26272A2E2E2C352C2E2E2C29242028
2D391E1E2F6E959D7A6670A3B8BFABA8ABACB0B8C0C5C8CBCBC5BDB9B5B2B0B4BED9CCA5
674E4E525956514D4B4D4E443E3D3D3D3B413330303439473938292B30352F3F4E6E6165
768C807E797B7C7A787D83878B91969A9D9E9E9E
2E2D2C2F355958352E27272527303B625F6E4E3525272E2E2D2E2F2D2D2D2D2D2D272629
41421E181E457CA88B6A6281ABCBAFA9A8A8ACB4BCC1C6CACCC7C1B8B1ADABB0B5BBBFCA
A06D4D5262615F6264625D504A494A4A46533A312C3C4C6B53512E303A4A3C556C85795C
5E85757876757473747980868D949A9D9E9FA0A0
2D2C2A2F3559523628252824283448656667372A25262A2B2C2F302C2A2929292A283041
43361B191E315698958263708EB7BABAA3A6ABB0B6BDC2C6C8C7C3B9AEA9A6A9ADBBBBD7
CDAE77655E60676B6E6964616160616B706F54452A46688D8A804C4D6670485D70817D67
617771706C6C6E6D6F77828C94999B9EA0A1A2A2
2F2B282D33584B37242429262937536468602926282626282B2F302C272829282A3A4B5D
3C2A1E1E2326327B949A6E6C749ABEC8A3A6ABADB1B8BFC2C4C6C5BBAEA6A1A2A4BEB6BF
C1CCAB8562626D707273737577797A7A79787160305988918D937160718257626B747970
66676C66606267686B7887949E9E9D9FA2A3A4A5
292A2C2C305240392E29262C2B3B596165502F27272626282A2C2D2A282A383A44716A52
2C3235211D2220557A9E8C7E7586A2BBB8AEA5A9AFB4B9BDC1C6C7BFB4A79C9CA0B2B3BB
C3D6CDB2927A6B6D767A7D7F8084898988857F6F52749A9F9D9B85777D8F6E6269696B66
5E5A5B56525357606D7D8E9BA5A5A2A3A5A7A7A8
22282F2A2B49363A382E2233283C5B5E5C3F392B26262828292929282B344E5459814C25
254C52291A2217325996A4957E7780A5C8B7A2A6AEB1B3B9BEC4C8C4BBA999979CA4B0B8
BFC1C2C8C3986E6E7B808483838B9293908D897B798EA5A6A1988F867F907D5F605C5B57
534F4B49494A4F60758696A3ABAAA6A7A9A9AAAA
2424293747694F44363A42664748525A4533353826262727282526272D39526363895422
2662583727221D253E799BA486706B8DB4C2AEA7A5ABB3B7BBC1C5C5C0AF9E98979EABB3
BABEC2C8C9BEAC8E75757C828A9095989894908A919BA4A49F968D83797B6E6265594D47
44434343465364778A98A2A8ABABA9A9A9AAACAD
262626292B4C3B3B3634345222344A5A2F2C2E432827262728242428324D615D34675C2C
316033313A272521295683A78E735E7797C3B9AC9EA7B2B6B8BDC1C5C4B6A69A949BA5AD
B4B9BEC2C4C5BEA28679767E8A8F93999C9894959E9E9D9B978E84796E635A4F45444540
3D3F444953698092A1A9ADADAAABACAAA9ABADAE
252729292A44494F53463841263F484B2D2B2B422C2B2829282D25374868662A31505C2C
445F2833472D211D263D6291978C5F6676A2B5B9A4A6AEB2B5B9BCC3C5BCAFA196989FA6
AFB7BDC0C1C4C4C3BA9B7E80898B8E939B98949598928B88847C72685C4E464544424147
4F545C72879097A2ACAFAFAFAFB0B1AEACACADAE
24292E2B282A333C4E443730304C443B2F2C293E312F2B2C2A3423445D7046452A3D5B31
59591F3251351D1C2629407198A46A5E5C7DA7BFABAAAAAEB2B4B7BFC5C0B6A79A979AA1
AAB4BDBEBEC0C2C4C0AC957E6E76848B92918E8C89817874706A63584E433D424A464657
6A737C8C9BA4ABB0B3B1AFB0B3B4B5B2B0AEADAD
232B362F282B34353B363237414F38312E2C2B3937322C2C30454C505353393E3F425738
644E24355A3921242F252A4D81A5836B596988ACB4BAA6AAAEB0B3BBC1C0BAAA9B989A9D
A3AFBBBEBFC2C4C5C4C9C5A0796B656E70757877746E6A6764636158504F52585F6B777E
848C95A0AAAFB2B5B6B4B1B1B3B3B3B2B1AFACAC
222D3B332A2F353431302F30303F2E2E2D2C2D333A332C3239312F34493D312729385D4B
69422A375D442A201D181F306398977F625F6A90B4C7A7A9AAACAFB6BDBFBCAC9C9A9B9B
9DABB9BEC1C3C4C4C2C1BDB6A67A505D52585E6061616160606467605C6570767B7E828F
9DA4A8ACAFB2B4B6B7B5B3B2B2B1B0B1B2AFADAC
212B38322F363E3C373331303243282A2B2A292C32302E31343930334D372C2328345958
68402431545E31333328212442748E977C675D7799C2B9B1A7A8ABB2B7BAB9ADA09B9A99
9BA7B5BCC1C2C1C3C4C2BFC2C0AA91454F4E595B5C6A65686B727877777E85888C92989F
A6AAADB0B1B3B4B6B7B5B3B1B0B0B0B1B1B0B0AF
20283231323B4445423C36333648292B2B282627292C2F31303D2B34573F2A2124305263
66401E2947733A474A3A2922274C78A49477596278B2C5B9A6A5A8ADB2B5B5ADA49D9998
9BA5B1BAC0C0BEC1C4C0BBB9B7BBB4A0664F434F607A6F767C838A8F93949597999FA5A8
AAACADAFB1B1B1B4B6B5B2B1AFB0B1B1B1B2B3B3
20252B37292E344A5E63605C42483E39322C28282A2D303336382B33505A2824242C4167
6A412224386A46333836332A243351889A8D625C628FAEBDAFA7A3A8AFB1B1AEA8A29D9B
9EA7B1BAC0BFBCBEBFBEBCB9B7B9B9B8A98B6E696B7D7E868B9094999C9E9FA0A2A6A9AA
AAACAFB0B0B1B1B3B4B4B4B2B1B1B1B2B3B5B6B6
2224253B22272B3845565F6E504E514538302B2B2C2D30373D31293147732A28252A3267
6E4228232B5D5A30222C3B3126222C62929B6E5D546C8FB6B4ABA0A5ACADADADABA6A09F
A0A8B2BAC0BEBBBABBBCBCB7B2B2B2AFAFA89E89797F8D93989A9B9EA0A3A5A6A7A7A8A8
A9ACAEAFAFB0B2B2B1B3B5B4B3B1B1B3B5B7B8B8
2A2C22352F2A333C46484B6D736A46484D3E2E28292A2C3D392D252F3D75372A252C3667
6840312F24507D3932273234342723426D988C70545A72A0B8BFA4A1A4A7A8A9A7A39F9E
A1A8B1BAC0BFBCB9B7BABBB6B0B0B1B8B4B6B5ACA29995979B9EA1A3A4A5A6A6A6A6A6A7
A9AAABADAEB0B2B1B0B1B3B3B2B2B1B1B1B4B8B8
3238212C3A303C3F4037324C646E3B3B3C37322925272941342C222C356E482C252E3E62
5E3C353F2529527F372A2B24211F232E47788173605B5F7795BCABA59FA1A4A4A3A09D9E
A1A8B0B9C0C0BDB9B5B8BAB5AFADABBFB1ACA4A4A5A19D9B9B9FA4A5A5A5A5A4A3A3A3A6
A8A8A7AAADB0B2B0AFAFB0B1B1B2B2B0AEB2B8B9
3652282930383333312D2C34496D6D694B3A323123262B3C382E262A325D592F222E4250
4E4043422D27427367472921201E2022305572857B6E676E80A4AAB5A39FA0A1A1A09FA0
A2A9B0B8BFBFBCB9B7BABBB5AEA39CB9B3B3AEAAA8A5A29E9B9DA0A2A4A6A6A4A1A1A2A4
A7A6A6AAADAFB0AFAEAEAFB1B2B3B4B2B1B5B9BA
36632F26223E282723272D313A4A59705C44333823272D353C322A29304C6633202F4841
3F32282D372E2F618E61291E1F1D1E1E254267918E85786E6D87A3BFA8A19E9FA1A1A1A2
A4AAB1B8BDBDBBBABABBBBB4AB978CB1B4B9B6ADA6A6A6A19C9A9B9DA1A4A6A39F9FA1A3
A5A5A6AAADAEAEAEADAEAFB1B2B4B5B5B5B8BBBB
275350422F412723212937554C443F575A543A3726292E3236392A272C44653B263A553A
323725272F3B30567D55241E211D1E24315F648996A38C786B778CA5AAAF9E9FA1A1A2A4
A7AEB5BABCBBB9BBBBBAB6ADA08780AEB0BDBFB7AEA9A6A19D9A999A9C9DA09E9C9EA1A2
A3A4A6A9ACADADACACAEB0B1B2B3B5B5B5B8BCBD
253040322133292726364862362D273C515F43362B2A2C2F2F402A2728405D442C445D36
293B23272B44354E5F42211F231E1F2F498563626B9F9D8A706E7687A6B9A0A1A1A2A3A6
ABB2B8BBBCBAB8BBBCB8B1A5967B79AEABBDC4C0B7AEA6A29F9C999695979B9A9A9DA1A1
A1A3A6A9ABACACABABAEB1B1B1B3B4B4B4B9BCBD
242A3831272D282D32535853312829334256513E2F353D3930422A28293B51502C3C4C33
2B352B3C3E372E50543D2420221C21396F8855404D829A9B7F70708291ABABA79FA2A6AA
AFB1B4BBC0BCB8BBBDB7AE98957B7CB1AAB9C0C2BFB7ADA8A49E9BA1A5AA9B98989CA0A2
A3A3A3A7ABACACACADAEB0B1B1B1B2B4B7BABCBD
26282B2B2B272835426E603E2E2B312E30465948342C293035442B2A2B3745582E343830
2E2E3454532B2D524B3D2B24221D27498F8044222F5A8AA38E7A72837B97B0ABA0A3A9AD
B1B0B0BAC3BEB8BBBDB5AC8F968083B3A9B4B9C1C6C0B7B0A9A4A09B96AB9F9B989A9EA1
A4A2A0A5AAABACADAEAEADAFB1B0B0B5B9BBBCBC
2627282A2B272A3E546A4C3E3D3E31373F454848322E2C32373F322F2E363F4F3D3A352C
272B3666593247554F4E332B262832708D6C311A243D678D9696797B72849BA8AFACA8AA
AEB0B3BAC0BDB9B8B6B3AF91968989B1A3ADB3BEC6C5BFB6ABA6A2A09EA8A1A09E9A979C
A1A09FA3A7A9A9ABADADADAEAFB1B3B6B9BCBDBE
2727282829282D47645E333F4952332B252E364931302E333939383432353A424A413529
222C3770563F6246395040352A3646998358241B1F26416D92AB8378707583A0B9B4A9A7
A9B0B7BBBCBBB9B4B0B2B297959190AC9DA6AEBBC5C8C6BBAFA8A4A4A5A4A4A5A49A9296
9D9D9EA1A4A5A6A9ABACACADAEB2B7B8B9BCBFC0
2B2826282B292E4B6B502A3039423633302F30423D332C3036383B363231343B483D332B
27323F705C4F60434B62635E595C74B4875D2B1E1D1C2B4B71A194867773778DA6B3B9AE
A6AEB9B9BAB8B6B2B0B3B39B90949AA5A0A7AFBAC3C8C8C1B8AEA5A6A9A7A7A5A39E9997
96989C9FA3A3A3A7ABABABABABB1B6B8BABDC0C0
2F2A25282D2B2F506C4326232A30383A3933303B46382B2C32373B37322E2F34423B332E
2E3B465A434E594C65605B504B3E5FA58A6534231E191E2D4B879C958478727C8EACC4B5
A5ACB7B7B7B4B1B0B0B3B29E8B94A2A2A5AAB0B9C1C5C7C5C0B2A6A8ACABA9A5A2A3A39B
9395999DA1A1A1A6AAAAA9A9AAAFB5B8BBBEC0C1
2E2A25292E2F345F6A4425232A2B3347564331343C3F2A2D3236393937302B2F39413634
3336394B4D6B716D745B4F3F3D37609B6E4726271C1C1F23325F7E9D998979777E97AFBD
ADABACBAB4B2ADABABAEAD9B8994A4AEA8ACB1B6BCC1C5C4BFB4A9A9ACAAA9A8A7A7A6A1
9C9896979A9DA0A5A9A9A9A9ABAFB4B8BBBEC0C1
2F2D2A2B2E32396C674827262D2C2E3D4A41353330432C303234363A3C32292D3348393A
37302E435A7163767D533B2D3036628E522919291D21242022385797A5998378748292BA
B0ABA2BBB1AFA9A7A5A8A8968893A4B9AAADAFB3B7BDC2C1BCB4ACAAAAA9A8ABADAAA8A8
A79E969394999FA4A7A8A9AAACAFB3B7BBBEC0C0
423B322D2B2F386C684B2C292C2B2C363F483C39333E32302E3032373C32293038453D38
3533374A5E77626A7545302E2C41788C4028222921232421212332688AA4948171717AA7
B8BFA9B4ABAAA7A6A5A7A6948594A7B5ACA9A6B0BABDC0BFBBB5AEABA9A8A9ABADABAAAB
ACA8A29B96959AA0A6A7A8AAACAEB1B4B8BBBEBF
4E4B4233262A35676951312C2B2A2A2D304A423E373739312B2C2F3339332E3640403F37
3238425661633742693B28332F538D87342D2C2826242323241E203A639F9B8D776C697D
95BAB1AFA9A6A5A5A6A7A5918293A8ADAEA59EADBDBFBFBDB9B5B0ABA8A8A9AAABABAAAC
ADAFAEA69C96959CA3A5A7A9ACADAEB1B5B9BCBD
5F605C4C3A312F5F645C342E2A292A2B2C3F3F3A33363D352C2E313033383E4447413B40
333B48525B5A2D3859392B3341728F712A2D252526242222231D1C223B7A9AAB9179666E
82A4AEB4B5ABA3A5A6A7A391828CA1A5ABA6A2A9B4C3BDB8B1B3B5AEA8A8AAAAAAA8A7A8
A9ADAFAEA9A48E939BA1A6A9ACADAFB2B5B8BAB9
3E3E3D37302A2A575D66393129282A2A2C333A332D363E372F30333030404F4F4A423849
363E484A55522532493A2D32538F8B5C252D20252926222122201F1C23416BA9A88E6D69
7188A3B4BCB0A3A4A6A6A18F82869BA2A9A9A9A7ACC6BBB4ABB2B9B2A9A9AAA9A8A5A3A3
A4A8ADB4B5B69493969DA5A8ABADAFB2B6B7B8B7
5B5244342D3039525B62493128272A2A2B3037312C3138342F3033353C49544C4141404A
3E4439475A56252E3D463B3C5094875A282F2F31302C28262422211C1D2B49849D998876
6C7284A4BEC2A9A3A4A19E8B7B869BB1B0AFACAAAFC1BFBAB3B7BAB2AAA8A8A7A5A3A2A0
A1A5AAB0B5C1B7AC9F9C9DA2A8AAACAFB2B4B3BD
7762432F29252A3F575B583329272B2B2B3034302C2E31302F30343D4A51534639414B4A
45462945605C272F363F24354E94825E3234414342372B272624232120202A5483989D88
7066677D96B9ACA5A49F998677899FC1B7B5AEAEB5BBC3C1BDBCBBB3ACA9A7A5A3A1A09F
9FA2A8ADB3B6B8B3ACA1989DA4A7A8ABAEB0B0C1
776B563A25242C3F43505A3D312C2D2C2C2D2E2E2E30312F2D333A51514F48423F4A534C
423A263F605C24272D3C27425E9284674E56686E6D553A2C25232422211F24365684A8A4
816B5B647BA6B6B2A8A18E7F7C90AABDBBB6AFB1B8BBC0C1C0C0BEB8B1ACA7A5A4A2A09F
A0A3A7ABB0B4B9B7B2AAA2A1A2A4A7ABAEB1B1BB
75573129272A2E3F2F4557493A33302E2D2D2D2E2F32332F2C384563554A3D4048535A4D
3C2C293C5D582122283B3152708C806D645F5C524633232226252423232325252D557D9F
92775957637A94A9B1AB837B8999B1B6BCB6B0B4BABBBDBFC2C2C1BDB7B0AAA7A6A29FA0
A2A4A6A9ADB1B3B6B6B3AEA7A1A2A6AAAEB1B3B3
7557312B2B303335273D50593E37302E2D2D2D2E3031312E2F43555F4F443E444E585E48
302A2F42594B22282442526779958763483F3C36312E2C2A2828282522232420233C5981
8C7B62655A60769BB6B6847A9D9DA1BBB7B6B3B5B8B9BABDBFC0C0BCB7B3AEA9A5A29FA0
A1A3A5A7A9ACAFB5B8B5B0A8A2A0A0A3A7ADB2B2
725D403734383B2E27394A62403A312F2D2E2F2F2F2F2F2F344C625749424249525B5E42
272A3649543D2430274C737D7D835C3B28272D2D2E31332F2A2B2C282423242324283559
7C7A6C7A595158748DA4847CAF9E8EBFB1B6B5B5B6B6B8BABCBDBDBAB7B5B3ACA5A2A0A0
A1A3A5A5A6A8ACB3B8B5AFAAA49E9B9DA2A9AFB1
6F604E474D4D4B3B313A47645E4E39322F2F2F2E2D2E3032374C5C4F3F47424B535E5440
2C2B3748533A24313F5577837372463126272C2D2E3133302D2C2C2C2C29262525252A40
59666B8565544D5E72938185AF9B87B5B3B7B3B4B4B5B6B7B8BBBCBBB9B8B5B0AAA6A4A2
A2A4A7A8A8ABADB2B6B4B1AEABA29C9FA5A9ACAD
69625A54615E584A3E404750584F43372F2E2F2D2B2E31333847534D4154414C5260493E
342C3646523A2531545C75846762322C2B2E3232323130302F2D2B30332F29282726282F
3A536791715A454F5B6F5C7DAC9983ABB7B8B2B2B2B4B6B5B5B9BCBDBCBAB7B3AEAAA7A4
A3A6AAABACAEB0B2B3B3B2B2B1A79EA3AAABA9A9
7F6C5B617E766A62594D4649554E444343392E2B2B2C303E4B50514A4055414C5261473E
352C36465237243C6E697482625C2D2B2B2E323332313030302D2B3035302A2828262628
30496664836F5C5754635179AD9981A8B7B7B0B1B2B4B6B5B5B8BCBDBCBAB7B3AFABA8A4
A3A6AAABACAEB0B2B3B3B2B3B2A89FA4ABABA9A9
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf0001P38h=P205MGE`80J6QX0P21PH430;6a/@80[:b/
0P1:BTX201TI6@80:b/[100O7al302@T9080<C4a0P0j>SX204i>CPH0<c<c0`0e=CD203Hf=P80<30`
0P0[:b/20410@0@0<S8b0`0];Bd20492@P80<c<c0P10@40204a<C080F5QH0P0m?Cd203/k>`<0>3Ph
0P0a<C4202/[:`80:2PX0P0Z:RX202/[:`80>c/k0`1`L702069RHP80Hf=S0P1KFe/207MgM`80Hf=S
0P1CDe<305YJFP80GUiN0P1UIFD206e]K@80Lg=c0P1dM7@2075aL@<0QXJ60P1iNGT207inOP80Ogmo
1021PH4207moO`D0OWin0P1oOgl20861P@80Ph>30P26QXH208R8R0D0RXZ:0P29RHT208R8R080RHV9
0P2;Rh/208j>SP<0T92@0P2=SHd208^;R`80SXj>0P2@T90208f=S@80RHV90`28R8P208V9R@80RXZ:
202<S8`308f=S@80SXj>0P2?Shl2092@T080TI6A102BTY85096AT@@0T92@0P2ATI4209:BTP80Ti>C
0P2DU9@3096AT@80Shn?0P2ATI4209BDU080TY:B0P2@T90209BDU0<0V9RH0P2FUYH209BDU080UYJF
0P2IVIT209ZJVP80Vi^K0`2MWId20:2PX080Xj>S0P2YZJT20;Bd]080`l?30P3;bl/30<o?c`80c/k>
0P3<c<`20<;2`PP0b>3H00060<SPf080EeMG0P1XJ6P20861P@<0/K6a0P2/[:`204Y:BP806ATI0P0[
:b/401lO7`<092@T0P0a<C4203Xj>P80CTi>1P0c<c<303De=@80=SHf0P0`<30202/[:`80@410100b
<S8302d];@80@T920P0c<c<20410@080C4a<0P1HF5P203dm?@80>c/k0`0h>3P2034a<@80:b/[0P0X
:2P202XZ:P80:b/[0P0k>c/3071`L080HV9R0P1SHf<205]KF`80MgMg0P1SHf<205=CD`<0FUYJ0P1N
GUh206EUI@80KFe]0P1cLg<207AdM080LG5a0`26QXH207UiN@80OWin0P1oOgl40861P@80Ogmo1@1n
OWh207moO`80PH610P23Ph<208J6QP80R8R81@2:RXX208V9R@80R8R80P29RHT208^;R`80SXj>0`2@
T90208f=S@80Rh^;0P2>SXh2092@T080SHf=0P29RHT308R8R080RHV90P2:RXX808b<S0<0SHf=0P2>
SXh208n?S`80T92@0P2ATI4409:BTPD0TI6A102@T902096AT@80TY:B0P2CTi<209BDU0<0TI6A0P2?
Shl2096AT@80U9BD0P2BTY82092@T080U9BD0`2HV9P209JFUP80U9BD0P2FUYH209VIV@80VYZJ0P2K
Vi/309fMW@80X:2P0P2SXj<20:VYZ@80];Bd0P33`l<20<_;b`<0clo?0P3>c/h20<c<c080`/;22038
h=P000H0b>3H0P1IFET205eMG@80KFe]0`2VYZH20<;2`P80VIVI0P15ADD202l_;`@0;Bd]0`0T92@2
02h^;P80=cLg0P10@402030`<080=SHf0P0j>SX303Ph>080=3@d0P0a<C4202h^;P80>CTi0P0b<S82
034a<@<0;Rh^0P14A4@203<c<`80AdM70P16ATH204i>CP80?Shn0P0h>3P303<c<`80<30`0P0^;Rh2
02XZ:P80:BTY0P0/;2`203/k>`<0Jf][0P1RHV8206ATI080Fe]K0P1lO7`205eMG@80De=C0`1KFe/2
069RHP80Jf][0P1_Kfl2075aL@80Lg=c0P1dM7@30820P080Ng]k0P1nOWh207moO`80PH610P22PX82
0861P@<0Ogmo1020P8020861P@80Ph>30P25QHD208N7Q`<0RHV90P2:RXX208V9R@80R8R80P2:RXX2
08b<S080SXj>0`2?Shl208f=S@80RXZ:0P2;Rh/208b<S0@0SHf=0`2:RXX208V9R@80Rh^;0P2>SXh2
08f=S@80S8b<0P2=SHd308j>SP80T92@0P2BTY8609>CT`@0TY:B0`2CTi<209:BTP80TI6A0P2BTY82
09BDU080UYJF0P2GUiL309FEU@80TY:B0P2CTi<209BDU080Ti>C0P2ATI4209>CT`D0UYJF0P2EUID2
09RHV0@0VYZJ0P2KVi/309fMW@80X:2P0P2SXj<20:VYZ@80]KFe0P34a<@20<g=c@<0d];B0P3?cll2
0<_;b`80a/K62038h=P000H0b>3H0P1IFET205eMG@80KFe]0`2VYZH20<;2`P80VIVI0P15ADD202l_
;`@0;Bd]0`0T92@202h^;P80=cLg0P10@402030`<080=SHf0P0j>SX303Ph>080=3@d0P0a<C4202h^
;P80>CTi0P0b<S82034a<@<0;Rh^0P14A4@203<c<`80AdM70P16ATH204i>CP80?Shn0P0h>3P303<c
<`80<30`0P0^;Rh202XZ:P80:BTY0P0/;2`203/k>`<0Jf][0P1RHV8206ATI080Fe]K0P1lO7`205eM
G@80De=C0`1KFe/2069RHP80Jf][0P1_Kfl2075aL@80Lg=c0P1dM7@30820P080Ng]k0P1nOWh207mo
O`80PH610P22PX820861P@<0Ogmo1020P8020861P@80Ph>30P25QHD208N7Q`<0RHV90P2:RXX208V9
R@80R8R80P2:RXX208b<S080SXj>0`2?Shl208f=S@80RXZ:0P2;Rh/208b<S0@0SHf=0`2:RXX208V9
R@80Rh^;0P2>SXh208f=S@80S8b<0P2=SHd308j>SP80T92@0P2BTY8609>CT`@0TY:B0`2CTi<209:B
TP80TI6A0P2BTY8209BDU080UYJF0P2GUiL309FEU@80TY:B0P2CTi<209BDU080Ti>C0P2ATI4209>C
T`D0UYJF0P2EUID209RHV0@0VYZJ0P2KVi/309fMW@80X:2P0P2SXj<20:VYZ@80]KFe0P34a<@20<g=
c@<0d];B0P3?cll20<_;b`80a/K62038h=P000H0b>3H0P1JFUX205UIF@80GUiN0`1aLG42096AT@80
alO70P2ATI4203Xj>P80820P0P0[:b/302DU9@80;Rh^0P0d=3@202l_;`80;2`/0P0h>3P20492@P<0
>SXj0P0`<302034a<@80<c<c0P0a<C47030`<080A4A40P0a<C4204i>CP80@4100P11@D4203hn?P80
<c<c0`0^;Rh202l_;`80<S8b0P0[:b/202LW9`80;Bd]0P0m?Cd306QXJ080HV9R0P1UIFD205aLG080
PH610P1FEUH205EEE@<0G5aL0P1WIfL2079bLP80LG5a0P1_Kfl207=cL`80MgMg0`1iNGT207emO@80
OWin0P1oOgl20861P@@0PX:21@21PH4608:2PP80Q8B40P26QXH308R8R0H0RHV90P2;Rh/208f=S@D0
SXj>0P2<S8`208Z:RP80RHV90P28R8P208f=S@80TI6A0`2=SHd208V9R@80S8b<0P2@T90208n?S`80
SHf=0P2>SXh3092@T080TY:B0P2DU9@409JFUP80UIFE102DU9@309FEU@@0U9BD0P2EUID209NGU`80
VYZJ0P2LW9`309VIV@H0UIFE0P2DU9@209:BTP80Ti>C0`2DU9@209FEU@80UYJF0P2IVIT209^KV`@0
VYZJ0`2LW9`209nOW`80Xj>S0P2XZ:P20;Jf]P80a<C40P3>c/h30=CDe080d=3@0P3:b/X20<W9b@P0
b>3H00060<SPf080FUYJ0P1IFET205iNGP<0LG5a0P2ATI420<O7a`80TI6A0P0j>SX2020P8080:b/[
0`0U9BD202h^;P80=3@d0P0_;bl202`/;080>3Ph0P12@T8303Xj>P80<30`0P0a<C4203<c<`80<C4a
1`0`<30204A4A080<C4a0P1>CTh20410@080@D510P0n?Sh203<c<`<0;Rh^0P0_;bl2038b<P80:b/[
0P0W9bL202d];@80?Cdm0`1XJ6P2069RHP80IFEU0P1LG5`20861P@80EUIF0P1EEED305aLG080IfMW
0P1bLW82075aL@80Kfm_0P1cLg<207MgM`<0NGUi0P1mOGd207inOP80Ogmo0P21PH4408:2PPD0PH61
1P22PX8208B4Q080QXJ60`28R8P608V9R@80Rh^;0P2=SHd508j>SP80S8b<0P2:RXX208V9R@80R8R8
0P2=SHd2096AT@<0SHf=0P29RHT208b<S080T92@0P2?Shl208f=S@80SXj>0`2@T90209:BTP80U9BD
102FUYH209FEU@@0U9BD0`2EUID409BDU080UIFE0P2GUiL209ZJVP80W9bL0`2IVIT609FEU@80U9BD
0P2BTY8209>CT`<0U9BD0P2EUID209JFUP80VIVI0P2KVi/409ZJVP<0W9bL0P2OWil20:>SX`80Z:RX
0P2f][H20<C4a080c/k>0`3De=@20=3@d080b/[:0P39bLT80<SPf0001P38h=P205eMG@80EeMG0P1J
FUX306EUI@80OWin0P2f][H20;6a/@80MWIf0P0b<S8202TY:@<08R8R0P0W9bL202h^;P80;Bd]0P0`
<30203Hf=P80>c/k0`0d=3@202d];@80<30`0P0c<c<202l_;`80;Rh^0P0`<30303<c<`80>c/k0P0`
<302055AD@80?clo0P0m?Cd203Ti>@80<S8b0`0_;bl2034a<@80<S8b0P0Z:RX202DU9@80<30`0P13
@d<3075aL@80HF5Q0P1VIVH205mOG`80Ng]k0P1DE5@205QHF0<0GemO0P1XJ6P2071`L0@0LG5a0P1d
M7@507QhN080Ng]k0P1mOGd207moO`80P8200P21PH4208:2PPD0Ph>30P22PX840861P@80Q8B40P28
R8P308V9R@80R8R81029RHT208^;R`@0SHf=1@2<S8`608^;R`80SXj>0P2@T90308j>SP80Rh^;0P2=
SHd608n?S`80TI6A0`2CTi<209BDU080UIFE202FUYH509FEU@80UYJF102GUiL209RHV080Vi^K0P2M
WId309ZJVP80UYJF0P2DU9@209>CT`@0TY:B0P2EUID509NGU`80UYJF0P2GUiL209RHV080VIVI0P2J
VYX309^KV`80WIfM0P2QXJ420:NWY`80];Bd0P31`L420<g=c@<0e=CD0P3?cll20<W9b@80a/K62038
h=P000H0b>3H0P1MGEd205MGE`80FUYJ0`1UIFD207inOP80][Jf0P2a/K4207IfMP80<S8b0P0Y:BT3
028R8P809bLW0P0^;Rh202d];@80<30`0P0f=SH203/k>`<0=3@d0P0];Bd2030`<080<c<c0P0_;bl2
02h^;P80<30`0`0c<c<203/k>`80<30`0P1ADE4203lo?`80?Cdm0P0i>CT2038b<P<0;bl_0P0a<C42
038b<P80:RXZ0P0U9BD2030`<080@d=30`1aLG42065QH@80IVIV0P1OGel207]kN`80E5AD0P1HF5P3
05mOG`80J6QX0P1`L704075aL@80M7Ad1@1hN7P207]kN`80OGem0P1oOgl20820P080PH610P22PX85
08>3P`80PX:21021PH4208B4Q080R8R80`29RHT208R8R0@0RHV90P2;Rh/408f=S@D0S8b<1P2;Rh/2
08j>SP80T92@0`2>SXh208^;R`80SHf=1P2?Shl2096AT@<0Ti>C0P2DU9@209FEU@P0UYJF1@2EUID2
09JFUP@0UiNG0P2HV9P209^KV`80WIfM0`2JVYX209JFUP80U9BD0P2CTi<409:BTP80UIFE1@2GUiL2
09JFUP80UiNG0P2HV9P209VIV@80VYZJ0`2KVi/209fMW@80XJ6Q0P2WYjL20;Bd]080`L710P3=cLd3
0=CDe080clo?0P39bLT20<K6aPP0b>3H00060<SPf080GEeM0P1GEeL205YJFP<0IFEU0P1nOWh20;Jf
]P80/K6a0P1fMWH2038b<P80:BTY0`0R8R8202LW9`80;Rh^0P0];Bd2030`<080=SHf0P0k>c/303@d
=080;Bd]0P0`<30203<c<`80;bl_0P0^;Rh2030`<0<0<c<c0P0k>c/2030`<080DE5A0P0o?cl203dm
?@80>CTi0P0b<S8302l_;`80<C4a0P0b<S8202XZ:P809BDU0P0`<30204=3@`<0LG5a0P1QHF4206IV
IP80GemO0P1kNg/205ADE080F5QH0`1OGel206QXJ080L71`101aLG4207AdM0D0N7Qh0P1kNg/207em
O@80Ogmo0P20P8020861P@80PX:21@23Ph<208:2PP@0PH610P24Q8@208R8R0<0RHV90P28R8P408V9
R@80Rh^;102=SHd508b<S0H0Rh^;0P2>SXh2092@T0<0SXj>0P2;Rh/208f=S@H0Shn?0P2ATI4309>C
T`80U9BD0P2EUID809JFUPD0UIFE0P2FUYH409NGU`80V9RH0P2KVi/209fMW@<0VYZJ0P2FUYH209BD
U080Ti>C102BTY8209FEU@D0UiNG0P2FUYH209NGU`80V9RH0P2IVIT209ZJVP<0Vi^K0P2MWId20:6Q
X@80YjNW0P2d];@20<71`@80cLg=0`3De=@20<o?c`80bLW90P36a/H80<SPf0001P38h=P205mOG`@0
FUYJ0`1MGEd206YZJP80T92@0P2n_[h20;Bd]080E5AD0P0i>CT301lO7`80820P0P0X:2P202h^;P@0
<c<c0P0b<S8302h^;P80:RXZ0P0_;bl203<c<`80;bl_0P0/;2`2030`<0<0=CDe0P0a<C4202d];@80
Cdm?0P10@40203/k>`@0<C4a1@0b<S82034a<@809bLW0P0Q8B42034a<@80AdM70`1jNWX2065QH@80
IfMW0P1RHV8207AdM080E5AD0P1KFe/306=SH`80JFUY0P1^KVh2075aL@80Lg=c0P1fMWH207QhN0<0
NGUi0P1jNWX207emO@H0P8200P22PX8308B4Q080Ph>30P21PH420820P080Ogmo0P25QHD508Z:RP80
R8R81029RHT208^;R`@0S8b<1@2;Rh/208b<S080SHf=102>SXh208f=S@T0SXj>0P2?Shl2096AT@80
U9BD2`2FUYH209NGU`80V9RH0P2FUYH309FEU@80UiNG1P2IVIT209^KV`80W9bL0`2JVYX209JFUP80
Ti>C102ATI4209>CT`80UiNG0`2JVYX209RHV080UIFE0P2DU9@209FEU@80UiNG0P2IVIT309ZJVP80
Vi^K0P2OWil20:FUY@80/K6a0P2n_[h20<[:bP<0d];B0P3>c/h20<O7a`80`L712038h=P000H0b>3H
0P1OGel405YJFP<0GEeM0P1ZJVX2092@T080_[jn0P2d];@205ADE080>CTi0`0O7al2020P8080:2PX
0P0^;Rh403<c<`80<S8b0`0^;Rh202XZ:P80;bl_0P0c<c<202l_;`80;2`/0P0`<30303De=@80<C4a
0P0];Bd204m?C`80@4100P0k>c/4034a<@D0<S8b0P0a<C4202LW9`808B4Q0P0a<C4204M7A`<0NWYj
0P1QHF4206MWI`80HV9R0P1dM7@205ADE080Fe]K0`1SHf<206UYJ@80KVi^0P1aLG4207=cL`80MWIf
0P1hN7P307UiN@80NWYj0P1mOGd60820P080PX:20`24Q8@208>3P`80PH610P20P80207moO`80QHF5
1@2:RXX208R8R0@0RHV90P2;Rh/408b<S0D0Rh^;0P2<S8`208f=S@@0SXj>0P2=SHd908j>SP80Shn?
0P2ATI4209BDU0/0UYJF0P2GUiL209RHV080UYJF0`2EUID209NGU`H0VIVI0P2KVi/209bLW0<0VYZJ
0P2FUYH209>CT`@0TI6A0P2CTi<209NGU`<0VYZJ0P2HV9P209FEU@80U9BD0P2EUID209NGU`80VIVI
0`2JVYX209^KV`80WinO0P2UYJD20;6a/@80_[jn0P3:b/X30=;BdP80c/k>0P37alL20<71`@P0b>3H
00060<SPf080G5aL0P1TI6@205MGE`<0FEUI0P1QHF4207QhN080XZ:R0P3=cLd20:FUY@80=SHf0`0d
=3@202@T90809bLW0P0Z:RX202l_;`80;Rh^0P0];Bd502`/;080<30`0P0c<c<2030`<080;Bd]0P0_
;bl303@d=080>SXj0P10@40205ADE080>c/k0P12@T8204E5A@80?3`l0`0`<30402h^;P80;bl_0P0c
<c<203De=@80ADE50`1gMgL206QXJ080K6a/0P1SHf<2071`L080De=C0P1MGEd306MWI`80K6a/0P1_
Kfl2071`L080LW9b0P1gMgL207alO0D0Ng]k0P1mOGd407moO`@0P8200`21PH440820P080PH610P23
Ph<208F5Q@80QhN70`28R8P408Z:RP@0Rh^;4`2<S8`308f=S@80Shn?102>SXh2096AT@80U9BD0P2G
UiL509RHV0@0UiNG0P2HV9P909NGU`80V9RH1P2JVYX409^KV`<0VIVI0P2GUiL209BDU080Ti>C0P2D
U9@209FEU@D0UiNG0P2EUID209>CT`80U9BD0P2EUID209BDU080UIFE0`2GUiL209VIV@80W9bL0P2Q
XJ420:f][@80^[Zj0P38b<P30=7Ad@80c<c<0P34a<@20;no_`P0b>3H00060<SPf080G5aL0P1TI6@2
05MGE`<0FEUI0P1QHF4207QhN080XZ:R0P3=cLd20:FUY@80=SHf0`0d=3@202@T90809bLW0P0Z:RX2
02l_;`80;Rh^0P0];Bd502`/;080<30`0P0c<c<2030`<080;Bd]0P0_;bl303@d=080>SXj0P10@402
05ADE080>c/k0P12@T8204E5A@80?3`l0`0`<30402h^;P80;bl_0P0c<c<203De=@80ADE50`1gMgL2
06QXJ080K6a/0P1SHf<2071`L080De=C0P1MGEd306MWI`80K6a/0P1_Kfl2071`L080LW9b0P1gMgL2
07alO0D0Ng]k0P1mOGd407moO`@0P8200`21PH440820P080PH610P23Ph<208F5Q@80QhN70`28R8P4
08Z:RP@0Rh^;4`2<S8`308f=S@80Shn?102>SXh2096AT@80U9BD0P2GUiL509RHV0@0UiNG0P2HV9P9
09NGU`80V9RH1P2JVYX409^KV`<0VIVI0P2GUiL209BDU080Ti>C0P2DU9@209FEU@D0UiNG0P2EUID2
09>CT`80U9BD0P2EUID209BDU080UIFE0`2GUiL209VIV@80W9bL0P2QXJ420:f][@80^[Zj0P38b<P3
0=7Ad@80c<c<0P34a<@20;no_`P0b>3H00060<SPf080F5QH0P1]KFd205EEE@<0EeMG0P1MGEd206YZ
JP80QHF50P38b<P20<K6aP80UiNG0`0b<S8202PX:080:b/[0P0Z:RX602/[:`<0;Bd]0P0_;bl2038b
<P80<c<c0P0`<30202d];@80;bl_0`0b<S8202l_;`80:b/[0P14A4@203Ph>080=cLg0P0c<c<2034a
<@<0;Rh^0P0];Bd202/[:`8092@T0P0S8b<202HV9P80A4A40`1dM7@406m_K`80I6AT0P1/K6`205AD
E080GUiN0`1ZJVX206m_K`H0LG5a0P1hN7P507inOP80O7al0P1mOGd207inOP80Ogmo0P20P80207mo
O`D0OWin0P20P80208>3P`80QXJ60P24Q8@208>3P`<0QhN70P2;Rh/808b<S0D0SXj>0P2=SHd208^;
R`80RXZ:0P29RHT208^;R`80S8b<0`2>SXh408n?S`80T92@0P2CTi<209NGU`80VIVI0`2JVYX209VI
V@80V9RH0P2IVIT209ZJVP80V9RH0P2FUYH209NGU`<0VIVI102JVYX209^KV`80W9bL0P2KVi/209ZJ
VP<0VIVI0P2HV9P209JFUP80UIFE0P2FUYH209RHV080UYJF0`2DU9@609>CT`80U9BD0P2BTY82092@
T0<0Ti>C0P2GUiL209VIV@80WIfM0P2YZJT20;Jf]P80aLG50`3?cll20<W9b@80`L710P2m_Kd80<SP
f0001P38h=P205QHF080KFe]0P1EEED305MGE`80GEeM0P1ZJVX208F5Q@80b<S80P36a/H209NGU`<0
<S8b0P0X:2P202/[:`80:RXZ1P0[:b/302d];@80;bl_0P0b<S8203<c<`80<30`0P0];Bd202l_;`<0
<S8b0P0_;bl202/[:`80A4A40P0h>3P203Lg=`80<c<c0P0a<C4302h^;P80;Bd]0P0[:b/202@T9080
8b<S0P0V9RH204A4A0<0M7Ad101_Kfl206ATI080K6a/0P1DE5@205iNGP<0JVYZ0P1_Kfl6075aL@80
N7Qh1@1nOWh207alO080OGem0P1nOWh207moO`80P8200P1oOgl507inOP80P8200P23Ph<208J6QP80
Q8B40P23Ph<308N7Q`80Rh^;202<S8`508j>SP80SHf=0P2;Rh/208Z:RP80RHV90P2;Rh/208b<S0<0
SXj>102?Shl2092@T080Ti>C0P2GUiL209VIV@<0VYZJ0P2IVIT209RHV080VIVI0P2JVYX209RHV080
UYJF0P2GUiL309VIV@@0VYZJ0P2KVi/209bLW080Vi^K0P2JVYX309VIV@80V9RH0P2FUYH209FEU@80
UYJF0P2HV9P209JFUP<0U9BD1P2CTi<209BDU080TY:B0P2@T90309>CT`80UiNG0P2IVIT209fMW@80
ZJVY0P2f][H20<G5a@<0clo?0P39bLT20<71`@80_Kfm2038h=P000H0b>3H0P1;Bd/206YZJP80F5QH
0`1GEeL205eMG@80KVi^0P2;Rh/20;Rh^080cLg=0P2e]KD307emO@80BDU90P0U9BD202PX:080<C4a
100_;bl303<c<`80=cLg0P0f=SH203De=@80>SXj0P10@40204=3@`<0A4A40P16ATH204M7A`80Cdm?
1016ATH204E5A@80@d=30`10@40203/k>`@0>3Ph0P0n?Sh204=3@`80G5aL0`1jNWX206a/K0@0J6QX
0P1TI6@205IFEP80GUiN0`1YJFT206e]K@80L71`0P1bLW8207AdM080NGUi0P1mOGd507inOP@0OGem
0P20P80208:2PP80PH610`1oOgl20820P080PH610P23Ph<208F5Q@80QXJ60P27QhL308V9R@80S8b<
3@2=SHd208b<S080Rh^;0P2<S8`208f=S@@0SXj>0`2?Shl2096AT@80TY:B0P2DU9@209NGU`80VIVI
0P2JVYX709VIV@@0VYZJ102IVIT209ZJVP<0W9bL1P2MWId409bLW080Vi^K0`2IVIT209NGU`80UYJF
0P2GUiL209RHV080VIVI0P2GUiL909BDU080Ti>C0P2ATI42092@T0<0TI6A0P2DU9@209NGU`80WIfM
0P2VYZH20;6a/@80`<300`3;bl/20<C4a080_kno0P2f][H80<SPf0001P38h=P204];B`80JVYZ0P1H
F5P305MGE`80GEeM0P1^KVh208^;R`80^;Rh0P3=cLd20;Fe]@<0OGem0P19BDT202DU9@80:2PX0P0a
<C4402l_;`<0<c<c0P0g=cL203Hf=P80=CDe0P0j>SX20410@080@d=30`14A4@204I6AP80AdM70P1?
Cdl404I6AP80ADE50P13@d<30410@080>c/k100h>3P203hn?P80@d=30P1LG5`307YjNP80K6a/101X
J6P206ATI080EUIF0P1NGUh306UYJ@80KFe]0P1`L702079bLP80M7Ad0P1iNGT207emO@D0OWin101m
OGd20820P080PX:20P21PH4307moO`80P8200P21PH4208>3P`80QHF50P26QXH208N7Q`<0RHV90P2<
S8`=08f=S@80S8b<0P2;Rh/208b<S080SHf=102>SXh308n?S`80TI6A0P2BTY8209BDU080UiNG0P2I
VIT209ZJVPL0VIVI102JVYX409VIV@80VYZJ0`2LW9`609fMW@@0W9bL0P2KVi/309VIV@80UiNG0P2F
UYH209NGU`80V9RH0P2IVIT209NGU`T0U9BD0P2CTi<2096AT@80T92@0`2ATI4209BDU080UiNG0P2M
WId20:JVYP80/K6a0P30`<030<_;b`80a<C40P2o_kl20;Jf]PP0b>3H00060<SPf080BDU90P1SHf<5
05YJFP80GemO0P1gMgL209>CT`80XJ6Q0P2n_[h20<[:bP<0aLG50P1gMgL203<c<`80;Rh^0P0f=SH2
03<c<`80=3@d0`0i>CT203hn?P80?3`l0P0h>3P203<c<`80<30`0P0a<C4303<c<`80=cLg0P0i>CT2
03Ph>080=cLg0P0c<c<2030`<080;Rh^0`0/;2`202XZ:P80:BTY0P0V9RH202TY:@80=3@d0P1CDe<3
075aL@80K6a/0P1RHV8206][J`80GEeM0P1HF5P205eMG@<0IVIV0P1[Jf/206m_K`80Lg=c0P1gMgL2
07UiN@80Ng]k0`1mOGd207moO`80OWin0P1mOGd20820P0@0PX:20`21PH4608:2PP80Ph>30P27QhL5
08^;R`@0S8b<1P2=SHd908b<S080Shn?0P2BTY82096AT@80T92@0`2ATI4209:BTP80UIFE0P2GUiL2
09VIV@@0VYZJ0`2IVIT809ZJVP@0Vi^K0P2MWId709nOW`80WYjN1P2MWId309ZJVP@0UiNG0P2HV9P4
09VIV@80UiNG1@2EUID209JFUP80U9BD0P2BTY84096AT@D0T92@0P2EUID209fMW@80Xj>S0P2[Zj/2
0;Zj^P<0aLG50P30`<020;^k^`80[Zj^2038h=P000H0b>3H0P19BDT206=SH`D0FUYJ0P1OGel207Mg
M`80Ti>C0P2QXJ420;jn_P80b/[:0`35aLD207MgM`80<c<c0P0^;Rh203Hf=P80<c<c0P0d=3@303Ti
>@80?Shn0P0l?3`203Ph>080<c<c0P0`<302034a<@<0<c<c0P0g=cL203Ti>@80>3Ph0P0g=cL203<c
<`80<30`0P0^;Rh302`/;080:RXZ0P0Y:BT202HV9P80:BTY0P0d=3@205=CD`<0LG5a0P1/K6`2069R
HP80Jf][0P1MGEd205QHF080GEeM0`1VIVH206][J`80Kfm_0P1cLg<207MgM`80NGUi0P1kNg/307em
O@80Ogmo0P1nOWh207emO@80P8201022PX830861P@H0PX:20P23Ph<208N7Q`D0Rh^;102<S8`608f=
S@T0S8b<0P2?Shl209:BTP80TI6A0P2@T903096AT@80TY:B0P2EUID209NGU`80VIVI102JVYX309VI
V@P0VYZJ102KVi/209fMW@L0WinO0P2NWYh609fMW@<0VYZJ102GUiL209RHV0@0VIVI0P2GUiL509FE
U@80UYJF0P2DU9@209:BTP@0TI6A1@2@T90209FEU@80WIfM0P2SXj<20:^[Z`80^[Zj0`35aLD20<30
`080^k^k0P2^[Zh80<SPf0001P38h=P206IVIP80H61P0P1^KVh3079bLP80G5aL0P1_Kfl208J6QP80
Shn?0P2UYJD20<71`@<0dM7A0P2a/K4205UIF@80:RXZ0P0_;bl203De=@80<30`0`0d=3@403Lg=`80
=SHf0P0d=3@203<c<`80=3@d0`0f=SH203/k>`80?Shn0P0j>SX203Ph>080=SHf0P0e=CD203<c<`<0
<C4a0P0_;bl202h^;P80:b/[0P0_;bl203Xj>P80Fe]K0`1aLG4207EeM@80HF5Q0P1WIfL205UIF@80
EUIF0P1LG5`306EUI@80JVYZ0P1^KVh207=cL`80MWIf0P1iNGT207YjNP<0O7al0P1nOWh407emO@80
OWin0P20P80207inOP<0OGem0P20P80408>3P`80PX:20P25QHD208R8R0<0RHV90P2:RXX208^;R`H0
S8b<0P2=SHd508n?S`80SXj>0P2?Shl2092@T0L0TI6A102BTY8209BDU080UiNG2@2JVYX609^KV`80
W9bL0P2NWYh209nOW`<0XJ6Q0P2OWil409fMW@H0WYjN0`2KVi/209VIV@80VYZJ0P2KVi/209ZJVP80
UiNG0P2FUYH709FEU@80U9BD0P2BTY82092@T080SXj>0`2=SHd208j>SP80TI6A0P2FUYH209bLW080
Y:BT0P2a/K430;^k^`80`<300P2_[jl20:NWY`P0b>3H00060<SPf080IVIV0P1PH60206i^KP<0LW9b
0P1LG5`206m_K`80QXJ60P2?Shl20:FUY@80`L710`3AdM420;6a/@80FEUI0P0Z:RX202l_;`80=CDe
0P0`<30303@d=0@0=cLg0P0f=SH203@d=080<c<c0P0d=3@303Hf=P80>c/k0P0n?Sh203Xj>P80>3Ph
0P0f=SH203De=@80<c<c0`0a<C4202l_;`80;Rh^0P0[:b/202l_;`80>SXj0P1KFe/3075aL@80MGEe
0P1QHF4206MWI`80FEUI0P1FEUH205aLG0<0IFEU0P1ZJVX206i^KP80Lg=c0P1fMWH207UiN@80NWYj
0`1lO7`207inOP@0OGem0P1nOWh20820P080OWin0`1mOGd20820P0@0Ph>30P22PX8208F5Q@80R8R8
0`29RHT208Z:RP80Rh^;1P2<S8`208f=S@D0Shn?0P2>SXh208n?S`80T92@1`2ATI4409:BTP80U9BD
0P2GUiL909ZJVPH0Vi^K0P2LW9`209jNWP80WinO0`2QXJ4209nOW`@0WIfM1P2NWYh309^KV`80VIVI
0P2JVYX209^KV`80VYZJ0P2GUiL209JFUPL0UIFE0P2DU9@209:BTP80T92@0P2>SXh308f=S@80SXj>
0P2ATI4209JFUP80W9bL0P2TY:@20;6a/@<0^k^k0P30`<020:n_[`80YjNW2038h=P000H0b>3H0P2E
UID205]KF`80FUYJ0`1bLW8205iNGP80JVYZ0P1eMGD207emO@80R8R80P2^[Zh30<g=c@80f][J0P2I
VIT203hn?P80:BTY0P0c<c<202XZ:P<0<30`0P0e=CD203@d=080<C4a0P0c<c<203De=@80=cLg0`0i
>CT203dm?@80?clo0P0k>c/603Lg=`80=SHf0`0d=3@2038b<P80<30`0P0/;2`2030`<080?3`l0P1O
Gel3075aL@80OWin101RHV8205IFEP80De=C0P1JFUX306EUI@80JVYZ0P1^KVh2079bLP80MGEe0P1h
N7P207YjNP<0Ng]k1P1lO7`407emO@80Ng]k0`1iNGT207inOP@0Ph>30P21PH4208:2PP80Q8B40`26
QXH208R8R080RHV90P2:RXX208^;R`80S8b<0P2?Shl5096AT@80T92@1P2?Shl7096AT@@0T92@0P2D
U9@209VIV@80VYZJ2@2KVi/209bLW080WIfM0P2OWil20:2PX0<0XJ6Q0P2NWYh209bLW080WIfM1P2N
WYh309bLW080Vi^K0P2LW9`209fMW@80VYZJ0P2FUYH509FEU@80U9BD102CTi<209:BTP80SXj>0P2;
Rh/308Z:RP80Rh^;0P2<S8`208j>SP80U9BD0P2LW9`20:RXZ0<0[jn_0P2k^k/20:6QX@80WinO2038
h=P000H0b>3H0P2EUID205]KF`80FUYJ0`1bLW8205iNGP80JVYZ0P1eMGD207emO@80R8R80P2^[Zh3
0<g=c@80f][J0P2IVIT203hn?P80:BTY0P0c<c<202XZ:P<0<30`0P0e=CD203@d=080<C4a0P0c<c<2
03De=@80=cLg0`0i>CT203dm?@80?clo0P0k>c/603Lg=`80=SHf0`0d=3@2038b<P80<30`0P0/;2`2
030`<080?3`l0P1OGel3075aL@80OWin101RHV8205IFEP80De=C0P1JFUX306EUI@80JVYZ0P1^KVh2
079bLP80MGEe0P1hN7P207YjNP<0Ng]k1P1lO7`407emO@80Ng]k0`1iNGT207inOP@0Ph>30P21PH42
08:2PP80Q8B40`26QXH208R8R080RHV90P2:RXX208^;R`80S8b<0P2?Shl5096AT@80T92@1P2?Shl7
096AT@@0T92@0P2DU9@209VIV@80VYZJ2@2KVi/209bLW080WIfM0P2OWil20:2PX0<0XJ6Q0P2NWYh2
09bLW080WIfM1P2NWYh309bLW080Vi^K0P2LW9`209fMW@80VYZJ0P2FUYH509FEU@80U9BD102CTi<2
09:BTP80SXj>0P2;Rh/308Z:RP80Rh^;0P2<S8`208j>SP80U9BD0P2LW9`20:RXZ0<0[jn_0P2k^k/2
0:6QX@80WinO2038h=P000H0b>3H0P2EUID205]KF`80FUYJ0`1bLW8205iNGP80JVYZ0P1eMGD207em
O@80R8R80P2^[Zh30<g=c@80f][J0P2IVIT203hn?P80:BTY0P0c<c<202XZ:P<0<30`0P0e=CD203@d
=080<C4a0P0c<c<203De=@80=cLg0`0i>CT203dm?@80?clo0P0k>c/603Lg=`80=SHf0`0d=3@2038b
<P80<30`0P0/;2`2030`<080?3`l0P1OGel3075aL@80OWin101RHV8205IFEP80De=C0P1JFUX306EU
I@80JVYZ0P1^KVh2079bLP80MGEe0P1hN7P207YjNP<0Ng]k1P1lO7`407emO@80Ng]k0`1iNGT207in
OP@0Ph>30P21PH4208:2PP80Q8B40`26QXH208R8R080RHV90P2:RXX208^;R`80S8b<0P2?Shl5096A
T@80T92@1P2?Shl7096AT@@0T92@0P2DU9@209VIV@80VYZJ2@2KVi/209bLW080WIfM0P2OWil20:2P
X0<0XJ6Q0P2NWYh209bLW080WIfM1P2NWYh309bLW080Vi^K0P2LW9`209fMW@80VYZJ0P2FUYH509FE
U@80U9BD102CTi<209:BTP80SXj>0P2;Rh/308Z:RP80Rh^;0P2<S8`208j>SP80U9BD0P2LW9`20:RX
Z0<0[jn_0P2k^k/20:6QX@80WinO2038h=P000H0b>3H0P2f][H2092@T080HF5Q0`1YJFT206QXJ080
IVIV0P1YJFT206i^KP80N7Qh0P2HV9P30;Jf]P80hN7Q0P2o_kl20820P080<C4a0P0Z:RX202HV9P<0
:RXZ0P0_;bl202d];@80:b/[0P0^;Rh4038b<P<0<c<c0P0j>SX20410@080>CTi100b<S8203@d=080
<c<c0`0b<S8202h^;P80:b/[0P0U9BD202`/;080>CTi0P1TI6@3071`L080O7al101QHF42059BDP80
De=C0P1JFUX306EUI@80K6a/0P1`L702079bLP80M7Ad0P1fMWH207QhN0<0NGUi0P1jNWX207]kN`80
O7al0P1mOGd207inOPD0OGem0P1oOgl60861P@80Ph>30P25QHD308N7Q`80RHV91028R8P208Z:RP80
S8b<0P2?Shl5096AT@80T92@102?Shl2092@T080TI6A0`2BTY8409>CT`80U9BD0P2EUID209NGU`80
VIVI2@2KVi/409bLW080Vi^K0P2MWId509nOW`H0WYjN0P2MWId909bLW080Vi^K0P2HV9P209JFUPD0
UIFE0P2CTi<209:BTP80TI6A0P2@T90208b<S080R8R81`27QhL208R8R080SHf=0P2CTi<209bLW0<0
XZ:R0P2UYJD209:BTP80TI6A2038h=P000H0b>3H0P2f][H2092@T080HF5Q0`1YJFT206QXJ080IVIV
0P1YJFT206i^KP80N7Qh0P2HV9P30;Jf]P80hN7Q0P2o_kl20820P080<C4a0P0Z:RX202HV9P<0:RXZ
0P0_;bl202d];@80:b/[0P0^;Rh4038b<P<0<c<c0P0j>SX20410@080>CTi100b<S8203@d=080<c<c
0`0b<S8202h^;P80:b/[0P0U9BD202`/;080>CTi0P1TI6@3071`L080O7al101QHF42059BDP80De=C
0P1JFUX306EUI@80K6a/0P1`L702079bLP80M7Ad0P1fMWH207QhN0<0NGUi0P1jNWX207]kN`80O7al
0P1mOGd207inOPD0OGem0P1oOgl60861P@80Ph>30P25QHD308N7Q`80RHV91028R8P208Z:RP80S8b<
0P2?Shl5096AT@80T92@102?Shl2092@T080TI6A0`2BTY8409>CT`80U9BD0P2EUID209NGU`80VIVI
2@2KVi/409bLW080Vi^K0P2MWId509nOW`H0WYjN0P2MWId909bLW080Vi^K0P2HV9P209JFUPD0UIFE
0P2CTi<209:BTP80TI6A0P2@T90208b<S080R8R81`27QhL208R8R080SHf=0P2CTi<209bLW0<0XZ:R
0P2UYJD209:BTP80TI6A2038h=P000H0b>3H0P2VYZH20:b/[080Jf][0`1QHF42075aL@80IfMW0P1R
HV8206IVIP80LG5a0P25QHD309bLW080e=CD0P3Cdm<20;no_`80ATI60P0_;bl202<S8`<092@T0P0Z
:RX202PX:0809RHV0P0Y:BT202h^;P80<S8b0`0e=CD203/k>`80?Shn0P0g=cL402h^;P@0<30`0`0_
;bl202XZ:P809RHV0P0Q8B4202LW9`80=3@d0P1SHf<3071`L080MgMg0P1QHF42061PH080Cdm?0P1C
De<205YJFP<0IVIV0P1]KFd2079bLP@0Lg=c0P1dM7@207MgM`<0N7Qh0P1jNWX207]kN`80O7al0P1m
OGd207moO`80PH610`22PX820820P080Ogmo0P20P80208:2PP80Q8B40P26QXH308R8R080RXZ:0P28
R8P208J6QP80RXZ:0P2>SXh208n?S`/0T92@0P2ATI4209:BTP<0Ti>C0P2EUID209NGU`80V9RH0P2G
UiL209FEU@80VIVI0`2LW9`209^KV`80VYZJ0P2KVi/209fMW@80VYZJ0P2HV9P209ZJVP<0WYjN0P2O
Wil20:2PX080WinO0P2NWYh209bLW080Vi^K1@2LW9`209ZJVP@0UiNG0P2FUYH209FEU@<0Ti>C0P2A
TI42092@T080SXj>0P2<S8`208R8R080Q8B41`23Ph<208F5Q@80QhN70P2;Rh/2096AT@<0UIFE0P2=
SHd208F5Q@80Ph>32038h=P000H0b>3H0P2VYZH20:b/[080Jf][0`1QHF42075aL@80IfMW0P1RHV82
06IVIP80LG5a0P25QHD309bLW080e=CD0P3Cdm<20;no_`80ATI60P0_;bl202<S8`<092@T0P0Z:RX2
02PX:0809RHV0P0Y:BT202h^;P80<S8b0`0e=CD203/k>`80?Shn0P0g=cL402h^;P@0<30`0`0_;bl2
02XZ:P809RHV0P0Q8B4202LW9`80=3@d0P1SHf<3071`L080MgMg0P1QHF42061PH080Cdm?0P1CDe<2
05YJFP<0IVIV0P1]KFd2079bLP@0Lg=c0P1dM7@207MgM`<0N7Qh0P1jNWX207]kN`80O7al0P1mOGd2
07moO`80PH610`22PX820820P080Ogmo0P20P80208:2PP80Q8B40P26QXH308R8R080RXZ:0P28R8P2
08J6QP80RXZ:0P2>SXh208n?S`/0T92@0P2ATI4209:BTP<0Ti>C0P2EUID209NGU`80V9RH0P2GUiL2
09FEU@80VIVI0`2LW9`209^KV`80VYZJ0P2KVi/209fMW@80VYZJ0P2HV9P209ZJVP<0WYjN0P2OWil2
0:2PX080WinO0P2NWYh209bLW080Vi^K1@2LW9`209ZJVP@0UiNG0P2FUYH209FEU@<0Ti>C0P2ATI42
092@T080SXj>0P2<S8`208R8R080Q8B41`23Ph<208F5Q@80QhN70P2;Rh/2096AT@<0UIFE0P2=SHd2
08F5Q@80Ph>32038h=P000H0b>3H0P26QXH209jNWP80TI6A0`1cLg<206QXJ080LG5a0P1]KFd2071`
L080M7Ad0P1kNg/308V9R@80^[Zj0P3De=@20=WIf@80X:2P0P0/;2`202l_;`<07alO0P0W9bL402@T
90809bLW0P0];Bd203Hf=P<0@T920P1@D50205MGE`80B4Q80P0d=3@202h^;P80:b/[0P0/;2`302d]
;@80:BTY0P0X:2P202h^;P80:RXZ0P0i>CT206QXJ0<0O7al0P1eMGD206IVIP80GUiN101ADE4205YJ
FP<0IVIV0P1[Jf/206m_K`80LW9b0P1cLg<207AdM080MGEe0`1hN7P207]kN`80OGem0P1nOWh407em
O@80Ogmo0`21PH4208:2PPH0PH610P24Q8@208J6QP<0R8R80P29RHT208R8R080QhN70P2<S8`4096A
T@<0T92@102ATI4;09:BTP80Ti>C0P2EUID609JFUP80V9RH0`2KVi/209VIV@80UiNG0P2JVYX209bL
W080Vi^K0P2JVYX209fMW@D0WinO0P2MWId409jNWP80WIfM0P2KVi/309ZJVP80VIVI0P2GUiL409JF
UP80UIFE0P2BTY8308j>SP80S8b<0P2;Rh/208R8R080QHF50P21PH4207inOP<0P8200P22PX8208>3
P`80Q8B40P25QHD208N7Q`80RXZ:0`2;Rh/208:2PP80O7al0P1jNWX80<SPf0001P38h=P208J6QP80
WYjN0P2ATI4307=cL`80J6QX0P1aLG4206e]K@80L71`0P1dM7@207]kN`<0RHV90P2j^[X20=CDe080
fMWI0P2PX:0202`/;080;bl_0`0O7al202LW9`@092@T0P0W9bL202d];@80=SHf0`12@T82051@D080
EeMG0P18B4P203@d=080;Rh^0P0[:b/202`/;0<0;Bd]0P0Y:BT202PX:080;Rh^0P0Z:RX203Ti>@80
J6QX0`1lO7`207EeM@80IVIV0P1NGUh4055AD@80FUYJ0`1VIVH206][J`80Kfm_0P1bLW8207=cL`80
M7Ad0P1eMGD307QhN080Ng]k0P1mOGd207inOP@0OGem0P1oOgl30861P@80PX:21P21PH4208B4Q080
QXJ60`28R8P208V9R@80R8R80P27QhL208b<S0@0TI6A0`2@T904096AT@/0TY:B0P2CTi<209FEU@H0
UYJF0P2HV9P309^KV`80VIVI0P2GUiL209ZJVP80W9bL0P2KVi/209ZJVP80WIfM1@2OWil209fMW@@0
WYjN0P2MWId209^KV`<0VYZJ0P2IVIT209NGU`@0UYJF0P2EUID209:BTP<0SXj>0P2<S8`208^;R`80
R8R80P25QHD20861P@80OWin0`20P80208:2PP80Ph>30P24Q8@208F5Q@80QhN70P2:RXX308^;R`80
PX:20P1lO7`207YjNPP0b>3H00060<SPf080GUiN0P1[Jf/207emO@<0KFe]0P1TI6@20820P080OGem
1021PH420820P0<0PX:20P2HV9P20:n_[`80/K6a0P2ZZZX206i^KP80:BTY0`0P820202LW9`@092@T
0P0U9BD202/[:`80?Cdm0`1=CDd204];B`80A4A40P11@D4203`l?080<S8b0P0X:2P202TY:@<0;2`/
0P0Z:RX202`/;080?Cdm100^;Rh204a<C0D0MGEe0P1/K6`205YJFP80De=C0P1@D50205YJFP<0IFEU
0P1YJFT206a/K080L71`101dM7@207EeM@<0NGUi0P1mOGd407moO`80OGem0P1lO7`207emO@<0P820
0P22PX8208B4Q080Ph>30P21PH4208B4Q080QhN70`28R8P208V9R@@0R8R80P2>SXh209>CT`80TY:B
0`2@T902096AT@80Ti>C0P2DU9@209FEU@80Ti>C0P2BTY85096AT@80TY:B0P2EUID209JFUP80UiNG
0P2IVIT309ZJVP80V9RH0P2FUYH209VIV@80W9bL0P2MWId209jNWP80X:2P0`2QXJ4209jNWP80Vi^K
0P2MWId409jNWP80W9bL0`2HV9P609FEU@80U9BD0P2BTY8208f=S@<0R8R80P26QXH208F5Q@80PX:2
0P1nOWh207]kN`80NWYj0`1mOGd20861P@80Ph>32024Q8@308>3P`80O7al0P1fMWH207AdM0P0b>3H
00060<SPf080GUiN0P1[Jf/207emO@<0KFe]0P1TI6@20820P080OGem1021PH420820P0<0PX:20P2H
V9P20:n_[`80/K6a0P2ZZZX206i^KP80:BTY0`0P820202LW9`@092@T0P0U9BD202/[:`80?Cdm0`1=
CDd204];B`80A4A40P11@D4203`l?080<S8b0P0X:2P202TY:@<0;2`/0P0Z:RX202`/;080?Cdm100^
;Rh204a<C0D0MGEe0P1/K6`205YJFP80De=C0P1@D50205YJFP<0IFEU0P1YJFT206a/K080L71`101d
M7@207EeM@<0NGUi0P1mOGd407moO`80OGem0P1lO7`207emO@<0P8200P22PX8208B4Q080Ph>30P21
PH4208B4Q080QhN70`28R8P208V9R@@0R8R80P2>SXh209>CT`80TY:B0`2@T902096AT@80Ti>C0P2D
U9@209FEU@80Ti>C0P2BTY85096AT@80TY:B0P2EUID209JFUP80UiNG0P2IVIT309ZJVP80V9RH0P2F
UYH209VIV@80W9bL0P2MWId209jNWP80X:2P0`2QXJ4209jNWP80Vi^K0P2MWId409jNWP80W9bL0`2H
V9P609FEU@80U9BD0P2BTY8208f=S@<0R8R80P26QXH208F5Q@80PX:20P1nOWh207]kN`80NWYj0`1m
OGd20861P@80Ph>32024Q8@308>3P`80O7al0P1fMWH207AdM0P0b>3H00060<SPf080DU9B0P1NGUh2
069RHP<0K6a/0P1eMGD208B4Q080R8R80P2>SXh209:BTP80U9BD0`2GUiL209nOW`80ZZZZ0P2a/K42
0;Fe]@80UiNG0P1RHV8304];B`8092@T0P0R8R8202HV9P809BDU0P0W9bL203@d=0<0?Shn0P0j>SX6
03<c<`80;Rh^100Z:RX302d];@80;2`/0P0^;Rh2038b<P80;2`/0P0h>3P206EUI@<0NGUi0P1bLW82
06ATI080EEEE0P1@D502055AD@80Fe]K0`1WIfL206YZJP80K6a/0P1`L70607AdM0<0N7Qh2P1mOGd2
07moO`<0P8200P22PX8608B4Q080QXJ60P28R8P508V9R@80Rh^;0P2=SHd2092@T080TY:B0P2ATI43
092@T080TI6A0P2BTY8209BDU080UYJF0P2EUID209BDU0<0TI6A0P2@T90209>CT`80UiNG3@2IVIT2
09ZJVP80W9bL0P2MWId209nOW`D0X:2P0P2NWYh209bLW080WIfM0P2OWil209fMW@80VYZJ0`2FUYH2
09>CT`80U9BD0P2EUID209>CT`80T92@0P28R8P30861P@80OWin201mOGd207inOP<0PH610P24Q8@4
08F5Q@@0QXJ60P25QHD308:2PP80Ng]k0P1dM7@2075aL@P0b>3H00060<SPf080DU9B0P1NGUh2069R
HP<0K6a/0P1eMGD208B4Q080R8R80P2>SXh209:BTP80U9BD0`2GUiL209nOW`80ZZZZ0P2a/K420;Fe
]@80UiNG0P1RHV8304];B`8092@T0P0R8R8202HV9P809BDU0P0W9bL203@d=0<0?Shn0P0j>SX603<c
<`80;Rh^100Z:RX302d];@80;2`/0P0^;Rh2038b<P80;2`/0P0h>3P206EUI@<0NGUi0P1bLW8206AT
I080EEEE0P1@D502055AD@80Fe]K0`1WIfL206YZJP80K6a/0P1`L70607AdM0<0N7Qh2P1mOGd207mo
O`<0P8200P22PX8608B4Q080QXJ60P28R8P508V9R@80Rh^;0P2=SHd2092@T080TY:B0P2ATI43092@
T080TI6A0P2BTY8209BDU080UYJF0P2EUID209BDU0<0TI6A0P2@T90209>CT`80UiNG3@2IVIT209ZJ
VP80W9bL0P2MWId209nOW`D0X:2P0P2NWYh209bLW080WIfM0P2OWil209fMW@80VYZJ0`2FUYH209>C
T`80U9BD0P2EUID209>CT`80T92@0P28R8P30861P@80OWin201mOGd207inOP<0PH610P24Q8@408F5
Q@@0QXJ60P25QHD308:2PP80Ng]k0P1dM7@2075aL@P0b>3H00060<SPf0808b<S0P0n?Sh20451@@<0
JFUY0P2;Rh/208b<S080TY:B0P2IVIT20::RXP80ZZZZ0`2a/K420;>c/`80]KFe0P2l_;`20;no_`80
^k^k0P2[Zj/308:2PP809RHV0P0Q8B4202LW9`@09BDU0P0X:2P302`/;0@0:b/[0P0/;2`202d];@@0
;2`/0P0];Bd702h^;P80:2PX0P0Z:RX2034a<@80GEeM0`1ZJVX2075aL@80H61P0P1?Cdl204e=C@80
DU9B0P1LG5`306MWI`80JVYZ0P1/K6`2071`L0@0M7Ad0P1cLg<307QhN080O7al0P1kNg/207YjNP80
O7al0P1oOgl20820P0<0PH610P22PX8208>3P`80Q8B40P26QXH208R8R0L0RHV90P2=SHd4096AT@@0
T92@0`2ATI42092@T080TI6A0P2DU9@209JFUP80UiNG0P2FUYH309FEU@80U9BD0P2GUiL209VIV@@0
Vi^K0P2JVYX309VIV@80Vi^K102LW9`209^KV`80WIfM102OWil309jNWP@0WIfM0P2NWYh209nOW`80
W9bL0P2HV9P309FEU@@0Ti>C0P2DU9@209:BTP80SHf=0P23Ph<307YjNP80MgMg0P1hN7P207]kN`80
OWin0P20P8050861P@H0P8200P22PX8208B4Q080Ph>30`20P80207UiN@80LW9b0P1_Kfl80<SPf000
1P38h=P202<S8`80?Shn0P11@D4306UYJ@80Rh^;0P2<S8`209:BTP80VIVI0P2RXZ820:ZZZP<0/K6a
0P2c/k<20;Fe]@80_;bl0P2o_kl20;^k^`80Zj^[0`22PX8202HV9P808B4Q0P0W9bL402DU9@80:2PX
0`0/;2`402/[:`80;2`/0P0];Bd402`/;080;Bd]1`0^;Rh202PX:080:RXZ0P0a<C4205eMG@<0JVYZ
0P1aLG42061PH080Cdm?0P1=CDd2059BDP80G5aL0`1WIfL206YZJP80K6a/0P1`L70407AdM080Lg=c
0`1hN7P207alO080Ng]k0P1jNWX207alO080Ogmo0P20P8030861P@80PX:20P23Ph<208B4Q080QXJ6
0P28R8P708V9R@80SHf=102ATI44092@T0<0TI6A0P2@T902096AT@80U9BD0P2FUYH209NGU`80UYJF
0`2EUID209BDU080UiNG0P2IVIT409^KV`80VYZJ0`2IVIT209^KV`@0W9bL0P2KVi/209fMW@@0WinO
0`2NWYh409fMW@80WYjN0P2OWil209bLW080V9RH0`2EUID409>CT`80U9BD0P2BTY8208f=S@80Ph>3
0`1jNWX207MgM`80N7Qh0P1kNg/207inOP80P8201@21PH460820P080PX:20P24Q8@208>3P`<0P820
0P1iNGT2079bLP80Kfm_2038h=P000H0b>3H0P0P820202HV9P80:BTY0`1>CTh208Z:RP@0W9bL0P2S
Xj<20:VYZ@80];Bd0`2m_Kd40;Zj^P80_[jn0P32`/820<G5a@80^KVi0`2OWil203lo?`809RHV0P0P
8202024Q8@809BDU0P0W9bL302PX:0809bLW0P0V9RH202PX:080:RXZ0P0/;2`202l_;`L0<30`0P0_
;bl202DU9@80:2PX0P0b<S8205aLG0<0J6QX0P1aLG4206MWI`80BTY:0P1<C4`205ADE080GEeM0`1U
IFD206MWI`80J6QX0P1/K6`2071`L080LW9b0P1dM7@307MgM`80NWYj0P1kNg/407alO080OGem0P20
P80708:2PP80Ph>30P25QHD208N7Q`80R8R80`29RHT208Z:RP80S8b<0P2?Shl;096AT@80Ti>C0P2E
UID409NGU`T0UYJF0P2GUiL209VIV@80VYZJ1@2KVi/209fMW@@0WYjN0P2MWId=09jNWP@0WinO0P2K
Vi/209JFUP<0UIFE102DU9@209:BTP80Shn?0P29RHT207moO`D0MgMg0P1mOGd20820P080PX:20P1l
O7`207AdM0<0JVYZ0P1RHV82061PH080HV9R0P1ZJVX2079bLP80L71`0`1/K6`206EUI@80GemO0P1V
IVH80<SPf0001P38h=P2020P80809RHV0P0Y:BT304i>CP80RXZ:102LW9`20:>SX`80ZJVY0P2d];@3
0;fm_@@0^[Zj0P2n_[h20<;2`P80aLG50P2i^KT309nOW`80?clo0P0V9RH2020P80808B4Q0P0U9BD2
02LW9`<0:2PX0P0W9bL202HV9P80:2PX0P0Z:RX202`/;080;bl_1`0`<30202l_;`809BDU0P0X:2P2
038b<P80G5aL0`1XJ6P2075aL@80IfMW0P1:BTX204a<C080E5AD0P1MGEd306EUI@80IfMW0P1XJ6P2
06a/K080L71`0P1bLW8207AdM0<0MgMg0P1jNWX207]kN`@0O7al0P1mOGd20820P0L0PX:20P23Ph<2
08F5Q@80QhN70P28R8P308V9R@80RXZ:0P2<S8`208n?S`/0TI6A0P2CTi<209FEU@@0UiNG2@2FUYH2
09NGU`80VIVI0P2JVYX509^KV`80WIfM102NWYh209fMW@d0WYjN102OWil209^KV`80UYJF0`2EUID4
09BDU080TY:B0P2?Shl208V9R@80Ogmo1@1gMgL207emO@80P8200P22PX8207alO080M7Ad0`1ZJVX2
069RHP80H61P0P1RHV8206YZJP80LW9b0P1`L70306a/K080IFEU0P1OGel206IVIPP0b>3H00060<SP
f080820P0P0V9RH202TY:@<0CTi>0P2:RXX409bLW080Xj>S0P2YZJT20;Bd]0<0_Kfm102j^[X20;jn
_P80`/;20P35aLD20;Vi^@<0WinO0P0o?cl202HV9P80820P0P0Q8B4202DU9@809bLW0`0X:2P202LW
9`809RHV0P0X:2P202XZ:P80;2`/0P0_;bl7030`<080;bl_0P0U9BD202PX:080<S8b0P1LG5`306QX
J080LG5a0P1WIfL204Y:BP80C4a<0P1DE5@205eMG@<0IFEU0P1WIfL206QXJ080K6a/0P1`L702079b
LP80M7Ad0`1gMgL207YjNP80Ng]k101lO7`207emO@80P8201`22PX8208>3P`80QHF50P27QhL208R8
R0<0RHV90P2:RXX208b<S080Shn?2`2ATI4209>CT`80UIFE102GUiL909JFUP80UiNG0P2IVIT209ZJ
VPD0Vi^K0P2MWId409jNWP80WIfM3@2NWYh409nOW`80Vi^K0P2FUYH309FEU@@0U9BD0P2BTY8208n?
S`80RHV90P1oOgl507MgM`80OGem0P20P80208:2PP80O7al0P1dM7@306YZJP80HV9R0P1PH602069R
HP80JVYZ0P1bLW82071`L0<0K6a/0P1UIFD205mOG`80IVIV2038h=P000H0b>3H0P0O7al201HF5P80
7QhN0`0e=CD207emO@80ZJVY0P2TY:@20:^[Z`80[Jf]0P2i^KT30<?3``@0_Kfm0P2o_kl20<71`@80
a<C40P2i^KT30:n_[`80GEeM0P0f=SH201lO7`80820P1`0X:2P202HV9P809BDU0P0V9RH202PX:080
;2`/0P0`<305038b<P80<30`0P0^;Rh402DU9@80<C4a0P1HF5P306MWI`80KVi^0P1]KFd204I6AP80
C4a<0P1EEED205aLG0<0HV9R0P1TI6@206EUI@80JFUY0P1^KVh2079bLP80MGEe0`1gMgL207UiN@80
Ng]k101mOGd207alO080P8200`23Ph<208:2PP80PH610P22PX8208B4Q080QXJ60P27QhL308V9R@80
RXZ:0P2;Rh/208b<S080T92@0P2CTi<209:BTP<0TI6A0P2CTi<209FEU@80UiNG0P2HV9P209NGU`80
UYJF1@2GUiL209JFUP80UIFE0P2GUiL209VIV@80Vi^K0`2MWId209jNWPH0WinO0P2NWYh209fMW@T0
WYjN102OWil209ZJVP80U9BD1@2EUID209BDU080TI6A0P2;Rh/208F5Q@80O7al0`1eMGD207YjNP80
Ph>30P27QhL208J6QP80NWYj0P1YJFT305ADE080@d=30P0o?cl204=3@`80DU9B101OGel305YJFP80
EUIF0P1ADE42065QH@P0b>3H00060<SPf0807alO0P0F5QH201hN7P<0=CDe0P1mOGd20:VYZ@80Y:BT
0P2[Zj/20:f][@80^KVi0`33`l<40;fm_@80_kno0P31`L420<C4a080^KVi0`2_[jl205eMG@80=SHf
0P0O7al2020P80L0:2PX0P0V9RH202DU9@809RHV0P0X:2P202`/;080<30`1@0b<S82030`<080;Rh^
100U9BD2034a<@80F5QH0`1WIfL206i^KP80KFe]0P16ATH204a<C080EEEE0P1LG5`3069RHP80I6AT
0P1UIFD206UYJ@80KVi^0P1bLW8207EeM@<0MgMg0P1iNGT207]kN`@0OGem0P1lO7`20820P0<0Ph>3
0P22PX820861P@80PX:20P24Q8@208J6QP80QhN70`29RHT208Z:RP80Rh^;0P2<S8`2092@T080Ti>C
0P2BTY83096AT@80Ti>C0P2EUID209NGU`80V9RH0P2GUiL209JFUPD0UiNG0P2FUYH209FEU@80UiNG
0P2IVIT209^KV`<0WIfM0P2NWYh609nOW`80WYjN0P2MWId909jNWP@0WinO0P2JVYX209BDU0D0UIFE
0P2DU9@2096AT@80Rh^;0P25QHD207alO0<0MGEe0P1jNWX208>3P`80QhN70P26QXH207YjNP80JFUY
0`1DE5@204=3@`80?clo0P13@d<2059BDP@0GemO0`1JFUX205IFEP80DE5A0P1QHF480<SPf0001P38
h=P202h^;P80820P0P0K6a/302PX:080EeMG0P2_[jl20:^[Z`80/;2`0P2][Jd20;Rh^0<0`/;20P2k
^k/20;Ng]`80_;bl0P30`<020;fm_@80]KFe0`30`<0209jNWP80Ng]k0P0c<c<402TY:@809RHV1`0S
8b<202@T90809BDU0P0Z:RX202l_;`80<30`0`0_;bl202`/;080:2PX0P0Z:RX202<S8`80<S8b0P1I
FET306a/K080H61P0P1XJ6P204M7A`80C4a<0P1CDe<205YJFP<0H61P0P1RHV8206ATI080JVYZ0P1`
L70207=cL`80MWIf0`1hN7P407YjNP80Ng]k0P1mOGd207moO`80P8201`21PH4208>3P`80QXJ60P28
R8P708Z:RP80Rh^;0P2=SHd2092@T0@0TI6A0`2@T90209BDU080V9RH0P2GUiL209FEU@80UYJF0P2G
UiL309RHV080VIVI0P2HV9P209JFUP80UiNG0P2IVIT209^KV`<0W9bL0P2MWId809jNWP80WIfM1`2N
WYh209fMW@@0WinO0P2JVYX209FEU@<0U9BD0P2CTi<2092@T080S8b<0P27QhL20861P@80NGUi0`1d
M7@208B4Q080Ph>30P28R8P208N7Q`80O7al0P1[Jf/304i>CP80=CDe0P0a<C4203Lg=`80A4A40P1C
De<205aLG0<0HV9R0P1TI6@206=SH`80K6a/2038h=P000H0b>3H0P0^;Rh2020P80806a/K0`0X:2P2
05MGE`80[jn_0P2[Zj/20;2`/080[Jf]0P2h^;P30<;2`P80^k^k0P2g]kL20;bl_080`<300P2m_Kd2
0;Fe]@<0`<300P2NWYh207]kN`80<c<c100Y:BT202HV9PL08b<S0P0T92@202DU9@80:RXZ0P0_;bl2
030`<0<0;bl_0P0/;2`202PX:080:RXZ0P0S8b<2038b<P80FEUI0`1/K6`2061PH080J6QX0P17AdL2
04a<C080De=C0P1JFUX3061PH080HV9R0P1TI6@206YZJP80L71`0P1cLg<207IfMP<0N7Qh101jNWX2
07]kN`80OGem0P1oOgl20820P0L0PH610P23Ph<208J6QP80R8R81`2:RXX208^;R`80SHf=0P2@T904
096AT@<0T92@0P2DU9@209RHV080UiNG0P2EUID209JFUP80UiNG0`2HV9P209VIV@80V9RH0P2FUYH2
09NGU`80VIVI0P2KVi/309bLW080WIfM202NWYh209fMW@L0WYjN0P2MWId409nOW`80VYZJ0P2EUID3
09BDU080Ti>C0P2@T90208b<S080QhN70P21PH4207UiN@<0M7Ad0P24Q8@208>3P`80R8R80P27QhL2
07alO080Jf][0`1>CTh203De=@80<C4a0P0g=cL204A4A080De=C0P1LG5`3069RHP80I6AT0P1SHf<2
06a/K0P0b>3H00060<SPf0807QhN0P0M7Ad201hN7P<08b<S0P0a<C420:ZZZP80[jn_0P2a/K420:ZZ
ZP80/k>c0`2l_;`20;Jf]P80/;2`0P2f][H20;bl_080^;Rh0P2b/[830:j^[P80XZ:R0P2OWil2059B
DP80@4100P0a<C4202PX:0<08R8R0P0Q8B44028R8P808b<S0P0X:2P202d];@80;Rh^0`0/;2`202PX
:0808b<S0P0^;Rh2028R8P80<c<c0P1JFUX306m_K`80DE5A0P1NGUh204Q8B080C4a<0P1@D50205MG
E`<0GEeM0P1PH60206ATI080K6a/0P1cLg<207EeM@80MWIf0`1iNGT207alO080NWYj0P1iNGT207in
OP80PX:20P21PH4307inOP80P8200P22PX8208B4Q080QhN70P2:RXX208b<S0<0Rh^;0P2:RXX208b<
S080SXj>1P2?Shl3092@T080UIFE0P2JVYX209NGU`80Ti>C0P2EUID209RHV0D0VYZJ0P2IVIT209NG
U`80V9RH0P2JVYX509^KV`80W9bL202MWId409jNWP<0WinO0P2MWId209bLW080WYjN0P2OWil209ZJ
VP80UIFE0`2CTi<2096AT@80SHf=0P29RHT208>3P`80OGem0P1gMgL307=cL`80Rh^;0P21PH4408N7
Q`80QHF50P1jNWX305MGE`80=CDe0P0`<30203Lg=`80A4A40P1DE5@206ATI0<0LG5a0P1fMWH407Ui
N@P0b>3H00060<SPf0807QhN0P0M7Ad201hN7P<08b<S0P0a<C420:ZZZP80[jn_0P2a/K420:ZZZP80
/k>c0`2l_;`20;Jf]P80/;2`0P2f][H20;bl_080^;Rh0P2b/[830:j^[P80XZ:R0P2OWil2059BDP80
@4100P0a<C4202PX:0<08R8R0P0Q8B44028R8P808b<S0P0X:2P202d];@80;Rh^0`0/;2`202PX:080
8b<S0P0^;Rh2028R8P80<c<c0P1JFUX306m_K`80DE5A0P1NGUh204Q8B080C4a<0P1@D50205MGE`<0
GEeM0P1PH60206ATI080K6a/0P1cLg<207EeM@80MWIf0`1iNGT207alO080NWYj0P1iNGT207inOP80
PX:20P21PH4307inOP80P8200P22PX8208B4Q080QhN70P2:RXX208b<S0<0Rh^;0P2:RXX208b<S080
SXj>1P2?Shl3092@T080UIFE0P2JVYX209NGU`80Ti>C0P2EUID209RHV0D0VYZJ0P2IVIT209NGU`80
V9RH0P2JVYX509^KV`80W9bL202MWId409jNWP<0WinO0P2MWId209bLW080WYjN0P2OWil209ZJVP80
UIFE0`2CTi<2096AT@80SHf=0P29RHT208>3P`80OGem0P1gMgL307=cL`80Rh^;0P21PH4408N7Q`80
QHF50P1jNWX305MGE`80=CDe0P0`<30203Lg=`80A4A40P1DE5@206ATI0<0LG5a0P1fMWH407UiN@P0
b>3H00060<SPf0809BDU0P0N7Qh201XJ6PD08B4Q0P28R8P20;2`/080ZJVY0P2XZ:P20:b/[0D0/K6a
0P2_[jl20;6a/@80];Bd0P2f][H20;Rh^0<0][Jf0P2e]KD20;no_`80WIfM0P1fMWH204a<C080=CDe
0`0W9bL202@T90808b<S100R8R8202LW9`L0;Bd]0P0[:b/202TY:@80:RXZ0P0T92@203De=@80EeMG
0`1gMgL206IVIP80GemO0P14A4@204E5A@80Bd];0P1CDe<305aLG080HF5Q0P1UIFD206a/K080M7Ad
0P1eMGD207IfMP<0NWYj1P1mOGd20820P080PX:20P20P80307inOP80P8200P22PX8208B4Q080QXJ6
0P29RHT208^;R`<0S8b<1P2=SHd208n?S`@0TI6A0`2@T90209>CT`P0UYJF0P2GUiL309RHV080VIVI
0P2GUiL209JFUP80V9RH0P2JVYX209bLW0<0WIfM0P2KVi/209ZJVP80W9bL102OWil209jNWPD0WinO
0P2MWId209bLW0@0WIfM0P2IVIT209BDU0<0TY:B0P2@T90208n?S`80SHf=0P21PH4207IfMPD0Lg=c
0P22PX820820P080QXJ60P29RHT208F5Q@80P8200`1mOGd207]kN`@0NGUi0P1oOgl208B4Q080PX:2
0`1nOWh407emO@80Ng]k2038h=P000H0b>3H0P0U9BD201hN7P806QXJ1@0Q8B4208R8R080/;2`0P2Y
ZJT20:RXZ080[:b/1@2a/K420:n_[`80/K6a0P2d];@20;Jf]P80^;Rh0`2f][H20;Fe]@80_kno0P2M
WId207IfMP80C4a<0P0e=CD302LW9`8092@T0P0S8b<4028R8P809bLW1`0];Bd202/[:`80:BTY0P0Z
:RX202@T9080=CDe0P1GEeL307MgM`80IVIV0P1OGel204A4A080ADE50P1;Bd/205=CD`<0G5aL0P1Q
HF4206EUI@80K6a/0P1dM7@207EeM@80MWIf0`1jNWX607emO@80P8200P22PX820820P0<0OWin0P20
P80208:2PP80Q8B40P26QXH208V9R@80Rh^;0`2<S8`608f=S@80Shn?102ATI43092@T080Ti>C202F
UYH209NGU`<0V9RH0P2IVIT209NGU`80UYJF0P2HV9P209ZJVP80W9bL0`2MWId209^KV`80VYZJ0P2L
W9`409nOW`80WYjN1@2OWil209fMW@80W9bL102MWId209VIV@80U9BD0`2BTY82092@T080Shn?0P2=
SHd20861P@80MWIf1@1cLg<208:2PP80P8200P26QXH208V9R@80QHF50P20P80307emO@80Ng]k101i
NGT207moO`80Q8B40P22PX8307inOP@0OGem0P1kNg/80<SPf0001P38h=P202TY:@808B4Q0P0H61P3
020P80806QXJ0P1PH6020:RXZ080XJ6Q102UYJD30:NWY`80ZZZZ0P2][Jd20:VYZ@80YJFU0P2^[Zh2
0;Ng]`<0^KVi0P2g]kL20;6a/@80ZZZZ0P2@T902071`L080CTi>0`0c<c<202PX:08092@T0P0R8R82
02<S8`809bLW100];Bd702h^;P@09BDU0P0i>CT205IFEP<0Jf][0P1LG5`204m?C`@0@T920P16ATH2
051@D0<0Fe]K0P1QHF4206IVIP80KFe]0P1cLg<207EeM@80MWIf0`1jNWX207inOP@0P8200P21PH42
08:2PP80P8200`1oOgl20861P@80Ph>30P24Q8@208F5Q@80QhN70P29RHT308f=S@80Shn?0P2=SHd2
08^;R`80Shn?102BTY85096AT@80TY:B0P2FUYH209VIV@80V9RH1@2FUYH209NGU`@0UYJF0P2HV9P2
09^KV`80WIfM0`2OWil209^KV`80V9RH0P2LW9`40:2PX0L0WinO0P2MWId409bLW080VYZJ0P2GUiL2
09BDU0<0TI6A0P2?Shl2096AT@80T92@0P20P802071`L080Kfm_0`1cLg<207MgM`80Ogmo0P26QXH4
08^;R`80R8R80`25QHD208:2PP80Ph>30P25QHD408J6QP80RHV90`2;Rh/208B4Q080OGem0P1kNg/8
0<SPf0001P38h=P202TY:@808B4Q0P0H61P3020P80806QXJ0P1PH6020:RXZ080XJ6Q102UYJD30:NW
Y`80ZZZZ0P2][Jd20:VYZ@80YJFU0P2^[Zh20;Ng]`<0^KVi0P2g]kL20;6a/@80ZZZZ0P2@T902071`
L080CTi>0`0c<c<202PX:08092@T0P0R8R8202<S8`809bLW100];Bd702h^;P@09BDU0P0i>CT205IF
EP<0Jf][0P1LG5`204m?C`@0@T920P16ATH2051@D0<0Fe]K0P1QHF4206IVIP80KFe]0P1cLg<207Ee
M@80MWIf0`1jNWX207inOP@0P8200P21PH4208:2PP80P8200`1oOgl20861P@80Ph>30P24Q8@208F5
Q@80QhN70P29RHT308f=S@80Shn?0P2=SHd208^;R`80Shn?102BTY85096AT@80TY:B0P2FUYH209VI
V@80V9RH1@2FUYH209NGU`@0UYJF0P2HV9P209^KV`80WIfM0`2OWil209^KV`80V9RH0P2LW9`40:2P
X0L0WinO0P2MWId409bLW080VYZJ0P2GUiL209BDU0<0TI6A0P2?Shl2096AT@80T92@0P20P802071`
L080Kfm_0`1cLg<207MgM`80Ogmo0P26QXH408^;R`80R8R80`25QHD208:2PP80Ph>30P25QHD408J6
QP80RHV90`2;Rh/208B4Q080OGem0P1kNg/80<SPf0001P38h=P202DU9@80;Bd]1@0M7Ad201/K6`80
A4A40P2CTi<20:f][@80Xj>S0P2VYZH30:FUY@80Xj>S0P2RXZ820:NWY`80ZJVY0P2MWId209JFUP<0
X:2P0P2^[Zh20<30`080_kno0P2^[Zh2096AT@80IVIV0`13@d<202TY:@808B4Q0P0O7al202@T9080
:2PX1`0/;2`202XZ:P80:2PX0P0[:b/2028R8P80=3@d0P1FEUH3075aL@80HF5Q0P1DE5@204E5A@80
@T920P14A4@204i>CP<0FUYJ0P1PH60206MWI`80KFe]0P1bLW8207AdM080MWIf0`1kNg/207inOP80
Ogmo0P1nOWh20820P080PX:20P21PH430820P080PH610P23Ph<208B4Q080QXJ60P27QhL208V9R@<0
S8b<0P2?Shl408j>SP80Shn?102@T905096AT@80TY:B0P2FUYH209RHV080UiNG0P2FUYH309NGU`80
VIVI102JVYX209^KV`80W9bL1@2NWYh209fMW@80Vi^K0P2NWYh40:2PX080WinO0P2NWYh309fMW@@0
WYjN0P2MWId209ZJVP80UYJF0P2CTi<3096AT@@0T92@0P2>SXh207moO`80LW9b0P1^KVh3071`L080
MGEe0P1oOgl208F5Q@80Rh^;1`2<S8`208^;R`80SHf=0P2?Shl2092@T0@0Shn?0`2=SHd208F5Q@80
OGem0P1kNg/80<SPf0001P38h=P202DU9@80;Bd]1@0M7Ad201/K6`80A4A40P2CTi<20:f][@80Xj>S
0P2VYZH30:FUY@80Xj>S0P2RXZ820:NWY`80ZJVY0P2MWId209JFUP<0X:2P0P2^[Zh20<30`080_kno
0P2^[Zh2096AT@80IVIV0`13@d<202TY:@808B4Q0P0O7al202@T9080:2PX1`0/;2`202XZ:P80:2PX
0P0[:b/2028R8P80=3@d0P1FEUH3075aL@80HF5Q0P1DE5@204E5A@80@T920P14A4@204i>CP<0FUYJ
0P1PH60206MWI`80KFe]0P1bLW8207AdM080MWIf0`1kNg/207inOP80Ogmo0P1nOWh20820P080PX:2
0P21PH430820P080PH610P23Ph<208B4Q080QXJ60P27QhL208V9R@<0S8b<0P2?Shl408j>SP80Shn?
102@T905096AT@80TY:B0P2FUYH209RHV080UiNG0P2FUYH309NGU`80VIVI102JVYX209^KV`80W9bL
1@2NWYh209fMW@80Vi^K0P2NWYh40:2PX080WinO0P2NWYh309fMW@@0WYjN0P2MWId209ZJVP80UYJF
0P2CTi<3096AT@@0T92@0P2>SXh207moO`80LW9b0P1^KVh3071`L080MGEe0P1oOgl208F5Q@80Rh^;
1`2<S8`208^;R`80SHf=0P2?Shl2092@T0@0Shn?0`2=SHd208F5Q@80OGem0P1kNg/80<SPf0001P38
h=P2024Q8@80=SHf0P0T92@301`L70807alO0P0^;Rh207IfMP80[Zj^0P2JVYX20::RXP<0XJ6Q0P2M
WId209JFUP80S8b<0P21PH4207UiN@D0MWIf0P1kNg/20::RXP80YjNW0P2d];@20;6a/@80RXZ:0`1O
Gel2038b<P808B4Q0P0N7Qh202DU9@809bLW0P0Z:RX202/[:`<0:BTY0P0T92@201hN7P80;Rh^0P0L
71`202l_;`80EeMG0`1fMWH206=SH`80EeMG0P18B4P204A4A080ADE50P1=CDd305QHF080GUiN0P1W
IfL206a/K080LG5a0P1dM7@207MgM`<0Ng]k0P1nOWh207emO@80O7al0P1oOgl70861P@80PX:20P23
Ph<208F5Q@80QhN70P28R8P208V9R@<0Rh^;0P2>SXh4092@T080Shn?0P2>SXh208n?S`<0TI6A0P2C
Ti<209BDU080UYJF102GUiL209JFUP<0V9RH0P2KVi/209fMW@H0WYjN0P2MWId509jNWP80WinO202P
X:0209jNWP<0WIfM0P2OWil20:6QX@80WYjN0P2JVYX209JFUP80TY:B0`2ATI4208n?S`80SXj>0P2:
RXX207moO`80M7Ad0P1]KFd306i^KP80MGEe0P1nOWh208B4Q080RHV90P2=SHd208j>SP<0Rh^;0P28
R8P208Z:RP80SHf=102?Shl208f=S@<0RXZ:0P23Ph<207alO080Ng]k2038h=P000H0b>3H0P0Q8B42
03Hf=P8092@T0`0L71`201lO7`80;Rh^0P1fMWH20:j^[P80VYZJ0P2RXZ830:6QX@80WIfM0P2FUYH2
08b<S080PH610P1iNGT507IfMP80Ng]k0P2RXZ820:NWY`80];Bd0P2a/K4208Z:RP<0GemO0P0b<S82
024Q8@807QhN0P0U9BD202LW9`80:RXZ0P0[:b/302TY:@8092@T0P0N7Qh202h^;P8071`L0P0_;bl2
05MGE`<0MWIf0P1SHf<205MGE`80B4Q80P14A4@204E5A@80CDe=0`1HF5P205iNGP80IfMW0P1/K6`2
075aL@80M7Ad0P1gMgL307]kN`80OWin0P1mOGd207alO080Ogmo1`21PH4208:2PP80Ph>30P25QHD2
08N7Q`80R8R80P29RHT308^;R`80SXj>102@T90208n?S`80SXj>0P2?Shl3096AT@80Ti>C0P2DU9@2
09JFUP@0UiNG0P2FUYH309RHV080Vi^K0P2MWId609jNWP80WIfM1@2NWYh209nOW`P0X:2P0P2NWYh3
09fMW@80WinO0P2QXJ4209jNWP80VYZJ0P2FUYH209:BTP<0TI6A0P2?Shl208j>SP80RXZ:0P1oOgl2
07AdM080KFe]0`1^KVh207EeM@80OWin0P24Q8@208V9R@80SHf=0P2>SXh308^;R`80R8R80P2:RXX2
08f=S@@0Shn?0P2=SHd308Z:RP80Ph>30P1lO7`207]kN`P0b>3H00060<SPf0808B4Q0P0f=SH202@T
90<071`L0P0O7al202h^;P80MWIf0P2^[Zh209ZJVP80XZ:R0`2QXJ4209fMW@80UYJF0P2<S8`20861
P@80NGUi1@1fMWH207]kN`80XZ:R0P2WYjL20;Bd]080/K6a0P2:RXX305mOG`80<S8b0P0Q8B4201hN
7P809BDU0P0W9bL202XZ:P80:b/[0`0Y:BT202@T90807QhN0P0^;Rh201`L7080;bl_0P1GEeL307If
MP80Hf=S0P1GEeL204Q8B080A4A40P15ADD204e=C@<0F5QH0P1NGUh206MWI`80K6a/0P1aLG4207Ad
M080MgMg0`1kNg/207inOP80OGem0P1lO7`207moO`L0PH610P22PX8208>3P`80QHF50P27QhL208R8
R080RHV90`2;Rh/208j>SP@0T92@0P2?Shl208j>SP80Shn?0`2ATI4209>CT`80U9BD0P2FUYH409NG
U`80UYJF0`2HV9P209^KV`80WIfM1P2NWYh209fMW@D0WYjN0P2OWil80:2PX080WYjN0`2MWId209nO
W`80XJ6Q0P2NWYh209ZJVP80UYJF0P2BTY83096AT@80Shn?0P2>SXh208Z:RP80Ogmo0P1dM7@206e]
K@<0KVi^0P1eMGD207inOP80Q8B40P29RHT208f=S@80SXj>0`2;Rh/208R8R080RXZ:0P2=SHd408n?
S`80SHf=0`2:RXX208>3P`80O7al0P1kNg/80<SPf0001P38h=P2020P8080;bl_0P0Z:RX5020P8080
8R8R0P1:BTX208V9R@80WinO0P2LW9`3096AT@80S8b<0P25QHD207UiN@80Kfm_0P1bLW8206][J`<0
N7Qh0P24Q8@209:BTP80Ti>C0P2TY:@20;2`/080XZ:R0`1]KFd20492@P80:b/[0P0R8R8202@T9080
9BDU100W9bL302PX:080;bl_0P0c<c<204A4A080:b/[0P0f=SH205IFEP<0Lg=c0P1LG5`2051@D080
@d=30P14A4@204Q8B080Cdm?0`1FEUH205aLG080I6AT0P1[Jf/2079bLP80M7Ad0P1eMGD307UiN@H0
OGem0P1oOgl20861P@D0P8200P22PX8208B4Q080QXJ60P27QhL208V9R@80Rh^;0`2<S8`208f=S@80
T92@0P2BTY82092@T080Shn?0P2ATI4309>CT`80UIFE0P2GUiL409RHV0@0UiNG0`2HV9P209ZJVP80
Vi^K102LW9`709fMW@80WYjN0P2OWil=0:2PX0@0XJ6Q0P2MWId209VIV@80UiNG0P2EUID3096AT@@0
SHf=0P2;Rh/20820P080M7Ad1@1^KVh207AdM080O7al0P23Ph<208R8R080Rh^;0P2<S8`308Z:RP80
RHV90P2;Rh/408j>SP80SHf=0P29RHT308F5Q@80PH610P1mOGd207alO0P0b>3H00060<SPf080820P
0P0_;bl202XZ:PD0820P0P0R8R8204Y:BP80RHV90P2OWil209bLW0<0TI6A0P2<S8`208F5Q@80NGUi
0P1_Kfl2079bLP80Jf][0`1hN7P208B4Q080TY:B0P2CTi<20:BTY080/;2`0P2RXZ8306e]K@80@T92
0P0[:b/2028R8P8092@T0P0U9BD402LW9`<0:2PX0P0_;bl203<c<`80A4A40P0[:b/203Hf=P80EUIF
0`1cLg<205aLG080D51@0P13@d<204A4A080B4Q80P1?Cdl305IFEP80G5aL0P1TI6@206][J`80LW9b
0P1dM7@207EeM@<0NGUi1P1mOGd207moO`80PH611@20P80208:2PP80Q8B40P26QXH208N7Q`80RHV9
0P2;Rh/308b<S080SHf=0P2@T90209:BTP80T92@0P2?Shl2096AT@<0Ti>C0P2EUID209NGU`@0V9RH
102GUiL309RHV080VYZJ0P2KVi/409bLW0L0WIfM0P2NWYh209nOW`d0X:2P102QXJ4209fMW@80VIVI
0P2GUiL209FEU@<0TI6A102=SHd208^;R`80P8200P1dM7@506i^KP80M7Ad0P1lO7`208>3P`80R8R8
0P2;Rh/208b<S0<0RXZ:0P29RHT208^;R`@0SXj>0P2=SHd208V9R@<0QHF50P21PH4207emO@80O7al
2038h=P000H0b>3H0P0P820202HV9P80;bl_0`0X:2P2028R8P807alO0P0T92@204];B`80MWIf0P1m
OGd307inOP80OGem0P1hN7P206YZJP80H61P0P1^KVh206MWI`<0SXj>0P2`/;020:VYZ@80W9bL0P2>
SXh208F5Q@80WinO0`1mOGd205UIF@80?Shn0P0[:b/2028R8P808B4Q0P0U9BD202LW9`<0:BTY0P0V
9RH2020P8080:BTY0P0K6a/202h^;P80EEEE0`1bLW8205ADE080B4Q80P0n?Sh204A4A080CDe=0P1A
DE4305EEE@80Fe]K0P1QHF4206YZJP80LW9b101dM7@307QhN080O7al0P1mOGd207inOP80Ogmo1020
P80307moO`80Ph>31026QXH208N7Q`80RXZ:1`2<S8`208n?S`80TY:B102ATI4209>CT`<0UIFE0P2G
UiL209VIV@80VYZJ0P2IVIT209RHV080UiNG0`2HV9P209ZJVP@0VIVI0P2JVYX209bLW080WIfM1@2N
WYh409nOW`80X:2P102QXJ420::RXP<0Xj>S0P2RXZ820:2PX080W9bL0P2IVIT409RHV0<0TY:B0P2<
S8`208f=S@80S8b<0P21PH4207IfMP80L71`0`1_Kfl207AdM080NWYj0P20P80208F5Q@T0R8R80P2:
RXX208b<S080RXZ:0P27QhL208>3P`<0P820101nOWh207emO@P0b>3H00060<SPf080820P0P0V9RH2
02l_;`<0:2PX0P0R8R8201lO7`8092@T0P1;Bd/207IfMP80OGem0`1nOWh207emO@80N7Qh0P1ZJVX2
061PH080KVi^0P1WIfL308j>SP80/;2`0P2YZJT209bLW080SXj>0P25QHD209nOW`<0OGem0P1IFET2
03hn?P80:b/[0P0R8R82024Q8@809BDU0P0W9bL302TY:@809RHV0P0P820202TY:@806a/K0P0^;Rh2
05EEE@<0LW9b0P1DE5@204Q8B080?Shn0P14A4@204e=C@80DE5A0`1EEED205]KF`80HF5Q0P1ZJVX2
079bLP@0M7Ad0`1hN7P207alO080OGem0P1nOWh207moO`@0P8200`1oOgl208>3P`@0QXJ60P27QhL2
08Z:RPL0S8b<0P2?Shl209:BTP@0TI6A0P2CTi<309FEU@80UiNG0P2IVIT209ZJVP80VIVI0P2HV9P2
09NGU`<0V9RH0P2JVYX409VIV@80VYZJ0P2LW9`209fMW@D0WYjN102OWil20:2PX0@0XJ6Q0P2RXZ83
0:>SX`80XZ:R0P2PX:0209bLW080VIVI102HV9P309:BTP80S8b<0P2=SHd208b<S080PH610P1fMWH2
071`L0<0Kfm_0P1dM7@207YjNP80P8200P25QHD908R8R080RXZ:0P2<S8`208Z:RP80QhN70P23Ph<3
0820P0@0OWin0P1mOGd80<SPf0001P38h=P202DU9@809bLW0P0];Bd303<c<`809bLW0P0N7Qh201XJ
6P80<C4a0P1?Cdl206UYJ@<0Hf=S0P1eMGD207moO`80Kfm_0P1UIFD207MgM`80KFe]0`2CTi<20;^k
^`80dm?C0P32`/820:n_[`80QhN70P2DU9@308:2PP80?Cdm0P0V9RH202DU9@80820P0P0S8b<202HV
9P809bLW0`0V9RH402LW9`80:2PX0P0Q8B42030`<080EUIF0`1_Kfl205IFEP80ADE50P0m?Cd20451
@@80CDe=0P1ADE4305EEE@80Fe]K0P1RHV8206UYJ@80L71`0P1bLW8207AdM0<0N7Qh0P1kNg/207em
O@80OWin0P20P8040861P@<0PX:20P24Q8@208J6QP@0QhN70P28R8P208V9R@<0R8R80P2;Rh/208j>
SP80TY:B102CTi<209BDU0<0UIFE0P2GUiL409VIV@80V9RH0P2GUiL209JFUP<0V9RH0P2IVIT409ZJ
VP80W9bL102OWil70:2PX080XJ6Q1P2RXZ820:>SX`<0Y:BT0P2RXZ8209nOW`80WIfM0P2JVYX209RH
V080UYJF0`2BTY8208j>SP80Shn?0P2>SXh208J6QP80O7al0P1fMWH3079bLP80M7Ad0P1hN7P207in
OP80Ph>30P26QXH208N7Q`D0R8R80P27QhL208J6QP80Ph>30P21PH4207inOP<0O7al101mOGd207al
O0P0b>3H00060<SPf0809BDU0P0W9bL202d];@<0<c<c0P0W9bL201hN7P806QXJ0P0a<C4204m?C`80
JFUY0`1SHf<207EeM@80Ogmo0P1_Kfl206EUI@80MgMg0P1]KFd309>CT`80^k^k0P3Cdm<20<;2`P80
[jn_0P27QhL209BDU0<0PX:20P0m?Cd202HV9P809BDU0P0P820202<S8`809RHV0P0W9bL302HV9P@0
9bLW0P0X:2P2024Q8@80<30`0P1FEUH306m_K`80EUIF0P15ADD203dm?@80@D510P1=CDd2055AD@<0
EEEE0P1KFe/2069RHP80JFUY0P1`L702079bLP80M7Ad0`1hN7P207]kN`80OGem0P1nOWh20820P0@0
PH610`22PX8208B4Q080QXJ61027QhL208R8R080RHV90`28R8P208^;R`80SXj>0P2BTY8409>CT`80
U9BD0`2EUID209NGU`@0VIVI0P2HV9P209NGU`80UYJF0`2HV9P209VIV@@0VYZJ0P2LW9`409nOW`L0
X:2P0P2QXJ460::RXP80Xj>S0`2TY:@20::RXP80WinO0P2MWId209ZJVP80V9RH0P2FUYH309:BTP80
SXj>0P2?Shl208j>SP80QXJ60P1lO7`207IfMP<0LW9b0P1dM7@207QhN080OWin0P23Ph<208J6QP80
QhN71@28R8P208N7Q`80QXJ60P23Ph<20861P@80OWin0`1lO7`407emO@80O7al2038h=P000H0b>3H
0P0X:2P402XZ:P<0?Cdm0P0/;2`2020P808061PH0P0P820202XZ:P80DU9B0`18B4P206e]K@80R8R8
0P1kNg/206m_K`80Ph>30P1gMgL308>3P`80VIVI0P3<c<`20<?3``80b/[:0P2SXj<20::RXP<0VYZJ
0P0m?Cd2024Q8@80:2PX0P0M7Ad202<S8`80:2PX0P0W9bL302@T90809bLW0P0[:b/202@T90809RHV
0P0a<C4205EEE@<0KFe]0P1IFET204A4A080?3`l0P11@D4204a<C080DE5A0`1FEUH205aLG080Hf=S
0P1YJFT206i^KP80LW9b0P1eMGD307QhN080Ng]k0P1mOGd207inOP80P8200P22PX8208>3P`<0Q8B4
0P25QHD208J6QP80QhN70P28R8P208J6QP80QHF50`26QXH208Z:RP80SXj>0P2ATI4209BDU0@0UYJF
0`2EUID209NGU`@0V9RH0P2GUiL209JFUP80UiNG0`2HV9P209ZJVP80Vi^K0P2LW9`209jNWPL0XJ6Q
102RXZ820:>SX`80Y:BT0P2SXj<20::RXP80Xj>S0`2TY:@20:6QX@80WinO0P2MWId209bLW080V9RH
0P2EUID309:BTP@0TI6A0P2?Shl208Z:RP80Ph>30P1lO7`307MgM`80MGEe0P1fMWH207alO080PH61
0P25QHD208J6QPD0QhN70P23Ph<207moO`80OGem0P1lO7`207]kN`<0NWYj0P1kNg/207alO080Ng]k
2038h=P000H0b>3H0P0X:2P402XZ:P<0?Cdm0P0/;2`2020P808061PH0P0P820202XZ:P80DU9B0`18
B4P206e]K@80R8R80P1kNg/206m_K`80Ph>30P1gMgL308>3P`80VIVI0P3<c<`20<?3``80b/[:0P2S
Xj<20::RXP<0VYZJ0P0m?Cd2024Q8@80:2PX0P0M7Ad202<S8`80:2PX0P0W9bL302@T90809bLW0P0[
:b/202@T90809RHV0P0a<C4205EEE@<0KFe]0P1IFET204A4A080?3`l0P11@D4204a<C080DE5A0`1F
EUH205aLG080Hf=S0P1YJFT206i^KP80LW9b0P1eMGD307QhN080Ng]k0P1mOGd207inOP80P8200P22
PX8208>3P`<0Q8B40P25QHD208J6QP80QhN70P28R8P208J6QP80QHF50`26QXH208Z:RP80SXj>0P2A
TI4209BDU0@0UYJF0`2EUID209NGU`@0V9RH0P2GUiL209JFUP80UiNG0`2HV9P209ZJVP80Vi^K0P2L
W9`209jNWPL0XJ6Q102RXZ820:>SX`80Y:BT0P2SXj<20::RXP80Xj>S0`2TY:@20:6QX@80WinO0P2M
WId209bLW080V9RH0P2EUID309:BTP@0TI6A0P2?Shl208Z:RP80Ph>30P1lO7`307MgM`80MGEe0P1f
MWH207alO080PH610P25QHD208J6QPD0QhN70P23Ph<207moO`80OGem0P1lO7`207]kN`<0NWYj0P1k
Ng/207alO080Ng]k2038h=P000H0b>3H0P0U9BD202PX:080:BTY0`0j>SX402/[:`80:RXZ0P0V9RH2
028R8P80<C4a0`0^;Rh205YJFP80QhN70P2>SXh2079bLP80O7al0P1fMWH307YjNP80SHf=0P2n_[h2
0<k>cP80f=SH0P39bLT20<_;b`<0aLG50P22PX8202TY:@808b<S0P0M7Ad202<S8`80:RXZ0P0X:2P3
02HV9P809bLW0P0Y:BT2028R8P8092@T0P0_;bl2059BDP<0JFUY0P1EEED204=3@`80>c/k0P18B4P2
04U9B@80DE5A0`1IFET205iNGP80Hf=S0P1YJFT206m_K`80Lg=c0P1fMWH307QhN080NWYj0P1mOGd2
07moO`80PH611023Ph<308B4Q080QHF50P26QXH408N7Q`80RHV90P28R8P309:BTP80RHV90P2<S8`2
096AT@80U9BD102FUYH309FEU@80UiNG0P2HV9P209NGU`80UYJF0P2HV9P509ZJVP80Vi^K102LW9`2
09fMW@80WYjN0P2OWil30:6QX@80Xj>S102UYJD20:BTY080Xj>S102QXJ430::RXP@0XJ6Q0P2OWil2
09fMW@80VYZJ0P2GUiL309BDU080TY:B0P2@T90208f=S@80RHV90P25QHD207moO`<0Ng]k0P1jNWX2
07]kN`80O7al0P1nOWh208:2PP80QHF51@26QXH20861P@@0O7al0P1mOGd207]kN`D0NGUi0P1gMgL2
0820P0P0b>3H00060<SPf0809BDU0P0X:2P202TY:@<0>SXj100[:b/202XZ:P809RHV0P0R8R82034a
<@<0;Rh^0P1JFUX208N7Q`80SXj>0P1bLW8207alO080MWIf0`1jNWX208f=S@80_[jn0P3>c/h20=SH
f080bLW90P3;bl/30<G5a@80PX:20P0Y:BT202<S8`807AdM0P0S8b<202XZ:P80:2PX0`0V9RH202LW
9`80:BTY0P0R8R8202@T9080;bl_0P1BDU8306UYJ@80EEEE0P13@d<203/k>`80B4Q80P19BDT2055A
D@<0FEUI0P1NGUh206=SH`80JFUY0P1_Kfl207=cL`80MWIf0`1hN7P207YjNP80OGem0P1oOgl20861
P@@0Ph>30`24Q8@208F5Q@80QXJ61027QhL208V9R@80R8R80`2BTY8208V9R@80S8b<0P2ATI4209BD
U0@0UYJF0`2EUID209NGU`80V9RH0P2GUiL209JFUP80V9RH1@2JVYX209^KV`@0W9bL0P2MWId209jN
WP80WinO0`2QXJ420:>SX`@0YJFU0P2TY:@20:>SX`@0XJ6Q0`2RXZ840:6QX@80WinO0P2MWId209ZJ
VP80UiNG0`2DU9@209:BTP80T92@0P2=SHd208V9R@80QHF50P1oOgl307]kN`80NWYj0P1kNg/207al
O080OWin0P22PX8208F5Q@D0QXJ60P21PH4407alO080OGem0P1kNg/507UiN@80MgMg0P20P8080<SP
f0001P38h=P2024Q8@809bLW0P0/;2`303`l?080;2`/0P0V9RH201dM7@807alO0P0S8b<201XJ6P<0
7QhN0P18B4P207inOP80W9bL0P1fMWH207AdM080Lg=c0`1dM7@20820P080Z:RX103?cll20<_;b`80
cLg=0`39bLT20;bl_080ADE50P0c<c<201lO7`808R8R0P0Z:RX202TY:@<0:2PX0P0W9bL202HV9P80
8B4Q0P0R8R8202d];@80CTi>0`1VIVH2051@D080@D510P0j>SX204m?C`80ADE50P1ADE4305]KF`80
H61P0P1TI6@206][J`80LG5a0P1eMGD207QhN0<0NGUi0P1jNWX207emO@80P8200P22PX8708>3P`80
Q8B40P26QXH208N7Q`80R8R80P2;Rh/208b<S0<0W9bL0P29RHT208f=S@80TI6A0P2DU9@209FEU@D0
UYJF0P2GUiL209RHV0@0UiNG0P2JVYX509fMW@@0W9bL1P2MWId209jNWP<0X:2P0P2TY:@20:NWY`80
YZJV0P2TY:@20::RXP80XJ6Q1@2PX:020::RXP80Xj>S0P2QXJ4209nOW`80W9bL0P2IVIT309JFUP80
Ti>C0P2?Shl208^;R`80R8R80P26QXH208:2PP<0P8200P1oOgl20820P080OWin0P1mOGd20820P080
Q8B40`25QHD208B4Q080P8200P1kNg/207emO@80Ogmo0P1mOGd307UiN@80MgMg0P1dM7@208F5Q@P0
b>3H00060<SPf0808B4Q0P0W9bL202`/;0<0?3`l0P0/;2`202HV9P807AdM0P0O7al202<S8`806QXJ
0`0N7Qh204Q8B080OWin0P2LW9`207IfMP80M7Ad0P1cLg<307AdM080P8200P2XZ:P40<o?c`80bl_;
0P3=cLd30<W9b@80_;bl0P15ADD203<c<`807alO0P0R8R8202XZ:P80:BTY0`0X:2P202LW9`809RHV
0P0Q8B42028R8P80;Bd]0P1>CTh306IVIP80D51@0P11@D4203Xj>P80Cdm?0P15ADD2055AD@<0Fe]K
0P1PH60206ATI080Jf][0P1aLG4207EeM@80N7Qh0`1iNGT207YjNP80OGem0P20P80208:2PPL0Ph>3
0P24Q8@208J6QP80QhN70P28R8P208^;R`80S8b<0`2LW9`208V9R@80SHf=0P2ATI4209BDU080UIFE
1@2FUYH209NGU`80V9RH102GUiL209ZJVPD0WIfM102LW9`609fMW@80WYjN0`2PX:020:BTY080YjNW
0P2VYZH20:BTY080XZ:R0P2QXJ450:2PX080XZ:R0P2SXj<20:6QX@80WinO0P2LW9`209VIV@<0UYJF
0P2CTi<208n?S`80Rh^;0P28R8P208J6QP80PX:20`20P80207moO`80P8200P1nOWh207emO@80P820
0P24Q8@308F5Q@80Q8B40P20P80207]kN`80OGem0P1oOgl207emO@<0NGUi0P1gMgL207AdM080QHF5
2038h=P000H0b>3H0P0Q8B4202d];@80>CTi0`1FEUH203Lg=`809RHV0P0O7al201hN7P808B4Q0P0G
5aL301/K6`80>3Ph0P1VIVH209FEU@80QHF50P1eMGD206i^KP<0NWYj0P1gMgL2096AT@80^[Zj0P3B
d]820<_;b`80c/k>0`3<c<`20=GEe@80X:2P0P0^;Rh2030`<0809BDU0P0X:2P202DU9@<09bLW0P0U
9BD202@T90808B4Q0P0T92@202d];@80BTY:0`1SHf<204Y:BP80?Cdm0P0l?3`204U9B@80AdM70P1A
DE4305YJFP80GemO0P1WIfL206a/K080L71`0P1dM7@207QhN0<0O7al101nOWh207emO@80P8200P24
Q8@208>3P`<0PX:20P24Q8@208N7Q`@0RHV90P2:RXX208V9R@<0U9BD0P2;Rh/209JFUP80T92@0P2B
TY8209BDU080UYJF1`2HV9P209ZJVP80W9bL0P2NWYh20:2PX0<0WYjN0P2LW9`209fMW@80WYjN102O
Wil20:6QX@<0Y:BT0P2UYJD40:JVYP@0YJFU0P2TY:@20:>SX`<0XZ:R1P2SXj<20::RXP80X:2P0P2M
WId309VIV@80U9BD0P2@T90208f=S@80RXZ:0P28R8P208F5Q@<0Ph>30P22PX860861P@80PX:20P23
Ph<308:2PP80P8200P1nOWh207alO0@0Ng]k1@1jNWX207UiN@80N7Qh0P21PH480<SPf0001P38h=P2
024Q8@80;Bd]0P0i>CT305IFEP80=cLg0P0V9RH201lO7`807QhN0P0Q8B4201LG5`<06a/K0P0h>3P2
06IVIP80UIFE0P25QHD207EeM@80KVi^0`1jNWX207MgM`80TI6A0P2j^[X20=;BdP80bl_;0P3>c/h3
0<c<c080eMGE0P2PX:0202h^;P80<30`0P0U9BD202PX:0809BDU0`0W9bL202DU9@8092@T0P0Q8B42
02@T9080;Bd]0P1:BTX306=SH`80BTY:0P0m?Cd203`l?080BDU90P17AdL2055AD@<0FUYJ0P1OGel2
06MWI`80K6a/0P1`L70207AdM080N7Qh0`1lO7`407inOP80OGem0P20P80208B4Q080Ph>30`22PX82
08B4Q080QhN71029RHT208Z:RP80RHV90`2DU9@208^;R`80UYJF0P2@T90209:BTP80U9BD0P2FUYH7
09RHV080VYZJ0P2LW9`209jNWP80X:2P0`2NWYh209bLW080WIfM0P2NWYh409nOW`80XJ6Q0`2TY:@2
0:FUY@@0YZJV102UYJD20:BTY080Xj>S0`2RXZ860:>SX`80XZ:R0P2PX:0209fMW@<0VIVI0P2DU9@2
092@T080SHf=0P2:RXX208R8R080QHF50`23Ph<208:2PPH0PH610P22PX8208>3P`<0PX:20P20P802
07inOP80O7al101kNg/507YjNP80NGUi0P1hN7P20861P@P0b>3H00060<SPf0808B4Q0P0];Bd203Ti
>@<0EUIF0P0g=cL202HV9P807alO0P0N7Qh2024Q8@805aLG0`0K6a/203Ph>080IVIV0P2EUID208F5
Q@80MGEe0P1^KVh307YjNP80MgMg0P2ATI420;Zj^P80d];B0P3;bl/20<k>cP<0c<c<0P3EeMD20:2P
X080;Rh^0P0`<30202DU9@80:2PX0P0U9BD302LW9`809BDU0P0T92@2024Q8@8092@T0P0];Bd204Y:
BP<0Hf=S0P1:BTX203dm?@80?3`l0P19BDT204M7A`80DE5A0`1JFUX205mOG`80IfMW0P1/K6`2071`
L080M7Ad0P1hN7P307alO0@0OWin0P1mOGd20820P080Q8B40P23Ph<308:2PP80Q8B40P27QhL408V9
R@80RXZ:0P29RHT309BDU080Rh^;0P2FUYH2092@T080TY:B0P2DU9@209JFUPL0V9RH0P2JVYX209bL
W080WYjN0P2PX:0309jNWP80W9bL0P2MWId209jNWP@0WinO0P2QXJ430:BTY080YJFU102VYZH40:FU
Y@80Y:BT0P2SXj<30::RXPH0Xj>S0P2RXZ820:2PX080WIfM0`2IVIT209BDU080T92@0P2=SHd208Z:
RP80R8R80P25QHD308>3P`80PX:21P21PH4208:2PP80Ph>30`22PX820820P080OWin0P1lO7`407]k
N`D0NWYj0P1iNGT207QhN080PH612038h=P000H0b>3H0P0T92@203Lg=`80BTY:0`1bLW8204A4A080
:BTY0P0O7al201dM7@807alO0P0K6a/301dM7@80:RXZ0P1;Bd/208J6QP80TY:B0P1mOGd206YZJP<0
P8200P1bLW8207emO@80XJ6Q0P3>c/h20<C4a080c<c<0`3;bl/20=?Cd`80cLg=0P2>SXh202XZ:P80
8R8R0P0W9bL202DU9@<09RHV0P0T92@202<S8`808R8R0P0V9RH202d];@80ATI60`1PH60204A4A080
>CTi0P0m?Cd20410@080BDU90P1@D50305QHF080GemO0P1XJ6P206e]K@80L71`0P1dM7@207QhN0<0
OWin0P22PX8207moO`80Ng]k0P1oOgl208B4Q080PX:20`21PH4208B4Q080R8R80P2:RXX208^;R`80
R8R80P27QhL308Z:RP80SXj>0P2OWil208n?S`80TY:B0P2CTi<209NGU`<0Vi^K0P2IVIT209RHV080
W9bL0P2QXJ440::RXP<0X:2P0P2MWId209jNWP80X:2P0P2RXZ820:>SX`80YZJV0`2WYjL20:JVYP80
YJFU0P2VYZH20:NWY`@0Z:RX0P2WYjL30:FUY@80Y:BT0P2SXj<40:FUY@80Xj>S0P2OWil309^KV`80
UYJF0P2BTY82092@T080S8b<0P2:RXX208N7Q`<0QHF50P23Ph<208:2PP80Ph>30P25QHD208B4Q080
PX:20`1oOgl607emO@80NWYj0P1gMgL207QhN0<0NWYj0P1lO7`207emO@80O7al2038h=P000H0b>3H
0P0T92@203Lg=`80BTY:0`1bLW8204A4A080:BTY0P0O7al201dM7@807alO0P0K6a/301dM7@80:RXZ
0P1;Bd/208J6QP80TY:B0P1mOGd206YZJP<0P8200P1bLW8207emO@80XJ6Q0P3>c/h20<C4a080c<c<
0`3;bl/20=?Cd`80cLg=0P2>SXh202XZ:P808R8R0P0W9bL202DU9@<09RHV0P0T92@202<S8`808R8R
0P0V9RH202d];@80ATI60`1PH60204A4A080>CTi0P0m?Cd20410@080BDU90P1@D50305QHF080GemO
0P1XJ6P206e]K@80L71`0P1dM7@207QhN0<0OWin0P22PX8207moO`80Ng]k0P1oOgl208B4Q080PX:2
0`21PH4208B4Q080R8R80P2:RXX208^;R`80R8R80P27QhL308Z:RP80SXj>0P2OWil208n?S`80TY:B
0P2CTi<209NGU`<0Vi^K0P2IVIT209RHV080W9bL0P2QXJ440::RXP<0X:2P0P2MWId209jNWP80X:2P
0P2RXZ820:>SX`80YZJV0`2WYjL20:JVYP80YJFU0P2VYZH20:NWY`@0Z:RX0P2WYjL30:FUY@80Y:BT
0P2SXj<40:FUY@80Xj>S0P2OWil309^KV`80UYJF0P2BTY82092@T080S8b<0P2:RXX208N7Q`<0QHF5
0P23Ph<208:2PP80Ph>30P25QHD208B4Q080PX:20`1oOgl607emO@80NWYj0P1gMgL207QhN0<0NWYj
0P1lO7`207emO@80O7al2038h=P000H0b>3H0P0];Bd203lo?`80EEEE0`2=SHd207IfMP80BDU90P0R
8R8201/K6`807AdM0P0J6QX301`L7080820P0P0f=SH207=cL`80UiNG0P2ATI4206][J`<0MWIf0P1`
L70207UiN@80TI6A0P2k^k/20<K6aPD0bl_;103AdM420;Rh^080JFUY0P0_;bl201`L70809BDU1@0S
8b<202DU9@808R8R0P0S8b<202l_;`80A4A40`1LG5`20410@0@0>SXj0P0o?cl204Q8B080Cdm?0`1F
EUH206QXJ080IVIV0P1/K6`2071`L080M7Ad0P1hN7P307emO@@0P8200P1nOWh20861P@80Ph>30P22
PX830861P@80Ph>30P27QhL208V9R@@0RXZ:0P29RHT308^;R`80T92@0P2JVYX209:BTP80UIFE0P2G
UiL209VIV@<0Vi^K102JVYX209jNWP80XZ:R102SXj<30:2PX080WYjN0P2PX:020:>SX`80YZJV102W
YjL30:JVYP80Z:RX0P2YZJT20:RXZ080YjNW0P2XZ:P20:VYZ@80Z:RX0`2WYjL20:FUY@80Xj>S0P2T
Y:@20:FUY@80XZ:R0P2NWYh309^KV`80V9RH0P2EUID2096AT@80SHf=0P29RHT208N7Q`<0QXJ60P24
Q8@208:2PP80Q8B41025QHD208>3P`<0P8200P1nOWh207moO`80P8200P1lO7`207QhN080NGUi0`1k
Ng/207alO080OGem0P1lO7`80<SPf0001P38h=P202d];@80?clo0P1EEED308f=S@80MWIf0P19BDT2
028R8P806a/K0P0M7Ad201XJ6P<071`L0P0P820203Hf=P80Lg=c0P2GUiL2096AT@80Jf][0`1fMWH2
071`L080NGUi0P2ATI420;^k^`80a/K61@3;bl/40=7Ad@80^;Rh0P1YJFT202l_;`8071`L0P0U9BD5
02<S8`809BDU0P0R8R8202<S8`80;bl_0P14A4@305aLG080@410100j>SX203lo?`80B4Q80P1?Cdl3
05IFEP80J6QX0P1VIVH206a/K080L71`0P1dM7@207QhN0<0OGem1020P80207inOP80PH610P23Ph<2
08:2PP<0PH610P23Ph<208N7Q`80RHV9102:RXX208V9R@<0Rh^;0P2@T90209ZJVP80TY:B0P2EUID2
09NGU`80VIVI0`2KVi/409ZJVP80WYjN0P2RXZ840:>SX`<0X:2P0P2NWYh20:2PX080Xj>S0P2VYZH4
0:NWY`<0YZJV0P2XZ:P20:VYZ@80Z:RX0P2WYjL20:RXZ080ZJVY0P2XZ:P30:NWY`80YJFU0P2SXj<2
0:BTY080YJFU0P2RXZ8209jNWP<0Vi^K0P2HV9P209FEU@80TI6A0P2=SHd208V9R@80QhN70`26QXH2
08B4Q080PX:20P24Q8@408F5Q@80Ph>30`20P80207inOP80Ogmo0P20P80207alO080N7Qh0P1iNGT3
07]kN`80O7al0P1mOGd207alO0P0b>3H00060<SPf080>CTi0P1=CDd206EUI@<0RXZ:0P1cLg<204m?
C`809bLW100M7Ad201/K6`<071`L0P0K6a/202HV9P80GEeM0P2BTY820:>SX`80L71`0`1]KFd2071`
L080N7Qh0P25QHD20:JVYP80alO70P3;bl/30<[:bP80c<c<0P38b<P20=?Cd`80ZZZZ0P1;Bd/201dM
7@80:2PX0`0P820202<S8`809RHV0P0Q8B42020P8080<30`0P12@T8305UIF@80?Cdm0P0j>SX203Lg
=`80?Shn0P17AdL204m?C`<0EEEE0P1_Kfl206ATI080Jf][0P1`L70207EeM@80NGUi0`1kNg/207em
O@80P8200P22PX8208>3P`L0PX:20P23Ph<208B4Q080QhN70P2:RXX208b<S080SHf=0`2?Shl2096A
T@80Ti>C0P2FUYH209RHV0@0VYZJ1@2KVi/209bLW080WinO0P2RXZ840:>SX`<0X:2P0P2OWil20::R
XP80YZJV0P2YZJT20:^[Z`80Z:RX0`2UYJD20:VYZ@80[Jf]0P2[Zj/20:RXZ0H0ZJVY0`2XZ:P20:JV
YP80Xj>S102TY:@20:2PX080W9bL0`2KVi/209ZJVP80UiNG0P2BTY8208f=S@80R8R81@27QhL208B4
Q080Ph>30P24Q8@608F5Q@<0PX:20P20P8040861P@80OGem0P1iNGT207YjNP<0Ng]k0P1lO7`407em
O@P0b>3H00060<SPf080>CTi0P1=CDd206EUI@<0RXZ:0P1cLg<204m?C`809bLW100M7Ad201/K6`<0
71`L0P0K6a/202HV9P80GEeM0P2BTY820:>SX`80L71`0`1]KFd2071`L080N7Qh0P25QHD20:JVYP80
alO70P3;bl/30<[:bP80c<c<0P38b<P20=?Cd`80ZZZZ0P1;Bd/201dM7@80:2PX0`0P820202<S8`80
9RHV0P0Q8B42020P8080<30`0P12@T8305UIF@80?Cdm0P0j>SX203Lg=`80?Shn0P17AdL204m?C`<0
EEEE0P1_Kfl206ATI080Jf][0P1`L70207EeM@80NGUi0`1kNg/207emO@80P8200P22PX8208>3P`L0
PX:20P23Ph<208B4Q080QhN70P2:RXX208b<S080SHf=0`2?Shl2096AT@80Ti>C0P2FUYH209RHV0@0
VYZJ1@2KVi/209bLW080WinO0P2RXZ840:>SX`<0X:2P0P2OWil20::RXP80YZJV0P2YZJT20:^[Z`80
Z:RX0`2UYJD20:VYZ@80[Jf]0P2[Zj/20:RXZ0H0ZJVY0`2XZ:P20:JVYP80Xj>S102TY:@20:2PX080
W9bL0`2KVi/209ZJVP80UiNG0P2BTY8208f=S@80R8R81@27QhL208B4Q080Ph>30P24Q8@608F5Q@<0
PX:20P20P8040861P@80OGem0P1iNGT207YjNP<0Ng]k0P1lO7`407emO@P0b>3H00060<SPf080A4A4
0P1PH6020820P0<0WIfM0P22PX82065QH@809bLW0P0M7Ad201lO7`807QhN0`0O7al201/K6`80820P
0P11@D4207MgM`80WinO0P20P80307AdM080Kfm_0P1aLG4207]kN`80W9bL0P30`<020=3@d0<0alO7
0P3;bl/20<[:bP80gmoO0P3?cll20::RXP80B4Q80P0T92@301hN7P809bLW0P0T92@4028R8P80;2`/
0P10@40305UIF@80>3Ph0P0f=SH203<c<`80?Cdm0P18B4P2055AD@<0F5QH0P1XJ6P206EUI@80Jf][
0P1`L70207AdM080N7Qh0`1jNWX207alO080P8202023Ph<708B4Q080QhN70P2:RXX208f=S@80Shn?
0`2@T902096AT@80Ti>C0P2GUiL409RHV080Vi^K1@2MWId209jNWP80WinO0P2PX:070:6QX@80XZ:R
0P2VYZH20:ZZZP80Zj^[0P2/[:`20:VYZ@<0YjNW0P2YZJT40:b/[0@0Zj^[1`2ZZZX20:NWY`80Y:BT
102UYJD20::RXP80WYjN0`2LW9`209ZJVP80UiNG0P2DU9@208j>SP80R8R80P27QhL308J6QP80QHF5
0P24Q8@208F5Q@80QXJ60P25QHD208B4Q0<0PX:21021PH420820P080OGem101iNGT307YjNP80OGem
101oOgl80<SPf0001P38h=P204A4A080H61P0P20P80309fMW@80PX:20P1QHF4202LW9`807AdM0P0O
7al201hN7P<07alO0P0K6a/2020P8080@D510P1gMgL209nOW`80P8200`1dM7@206m_K`80LG5a0P1k
Ng/209bLW080`<300P3@d=030<O7a`80bl_;0P3:b/X20=oOg`80clo?0P2RXZ8204Q8B08092@T0`0N
7Qh202LW9`8092@T100R8R8202`/;080@4100`1IFET203Ph>080=SHf0P0c<c<203dm?@80B4Q80P1A
DE4305QHF080J6QX0P1UIFD206][J`80L71`0P1dM7@207QhN0<0NWYj0P1lO7`20820P0P0Ph>31`24
Q8@208N7Q`80RXZ:0P2=SHd208n?S`<0T92@0P2ATI4209>CT`80UiNG102HV9P209^KV`D0WIfM0P2N
WYh209nOW`80X:2P1`2QXJ420::RXP80YZJV0P2ZZZX20:^[Z`80[:b/0P2YZJT30:NWY`80ZJVY102/
[:`40:^[Z`L0ZZZZ0P2WYjL20:BTY0@0YJFU0P2RXZ8209jNWP<0W9bL0P2JVYX209NGU`80U9BD0P2>
SXh208R8R080QhN70`26QXH208F5Q@80Q8B40P25QHD208J6QP80QHF50P24Q8@308:2PP@0PH610P20
P80207emO@@0NGUi0`1jNWX207emO@@0Ogmo2038h=P000H0b>3H0P1ADE4207=cL`80VYZJ0`2a/K42
09:BTP80KFe]0P0U9BD201dM7@@08R8R0`0S8b<201dM7@807alO0P0Z:RX205IFEP80TI6A0P2?Shl3
07moO`80KFe]0P1[Jf/207AdM080U9BD0P2e]KD20=?Cd`<0aLG50P3<c<`20<g=c@80c/k>0P35aLD2
0<k>cP80QXJ60P0b<S83020P8080:RXZ100S8b<202DU9@80:RXZ0P0n?Sh305UIF@80=CDe0P0c<c<2
034a<@80?3`l0P1:BTX205ADE0<0G5aL0P1QHF4206MWI`80K6a/0P1`L70207AdM080MgMg0`1iNGT2
07]kN`80Ogmo1P23Ph<208F5Q@<0QXJ61025QHD208N7Q`80Rh^;0P2>SXh208n?S`<0T92@0P2ATI42
09FEU@80VIVI0P2HV9P209NGU`80VYZJ0`2NWYh:09nOW`80X:2P0`2RXZ820:FUY@80ZZZZ102][Jd2
0:^[Z`80ZZZZ1@2YZJT20:ZZZP80[Jf]0P2^[Zh20:b/[0@0ZZZZ0`2[Zj/20:RXZ0H0YJFU0P2SXj<2
0:6QX@<0WIfM0P2IVIT209NGU`80UIFE0P2?Shl208V9R@80QXJ61`25QHD208N7Q`80R8R80P26QXH2
08B4Q0<0Ph>30P21PH420820P080Ogmo0P1lO7`407UiN@<0NWYj0P1mOGd20861P@80PX:22038h=P0
00H0b>3H0P1ADE4207=cL`80VYZJ0`2a/K4209:BTP80KFe]0P0U9BD201dM7@@08R8R0`0S8b<201dM
7@807alO0P0Z:RX205IFEP80TI6A0P2?Shl307moO`80KFe]0P1[Jf/207AdM080U9BD0P2e]KD20=?C
d`<0aLG50P3<c<`20<g=c@80c/k>0P35aLD20<k>cP80QXJ60P0b<S83020P8080:RXZ100S8b<202DU
9@80:RXZ0P0n?Sh305UIF@80=CDe0P0c<c<2034a<@80?3`l0P1:BTX205ADE0<0G5aL0P1QHF4206MW
I`80K6a/0P1`L70207AdM080MgMg0`1iNGT207]kN`80Ogmo1P23Ph<208F5Q@<0QXJ61025QHD208N7
Q`80Rh^;0P2>SXh208n?S`<0T92@0P2ATI4209FEU@80VIVI0P2HV9P209NGU`80VYZJ0`2NWYh:09nO
W`80X:2P0`2RXZ820:FUY@80ZZZZ102][Jd20:^[Z`80ZZZZ1@2YZJT20:ZZZP80[Jf]0P2^[Zh20:b/
[0@0ZZZZ0`2[Zj/20:RXZ0H0YJFU0P2SXj<20:6QX@<0WIfM0P2IVIT209NGU`80UIFE0P2?Shl208V9
R@80QXJ61`25QHD208N7Q`80R8R80P26QXH208B4Q0<0Ph>30P21PH420820P080Ogmo0P1lO7`407Ui
N@<0NWYj0P1mOGd20861P@80PX:22038h=P000H0b>3H0P1OGel208J6QP80[Zj^0`2[Zj/208F5Q@80
EEEE0P0Q8B4202HV9P808B4Q0P0U9BD302LW9`8092@T100U9BD203lo?`80Ng]k0P2CTi<308f=S@80
J6QX0P1ZJVX2071`L080QHF50P2MWId20=;BdP<0aLG5103;bl/20<g=c@80c<c<0P3Jf]X20;>c/`80
Jf][0`0P820402DU9@808b<S0P0U9BD202d];@80>c/k0`1BDU8403@d=080=CDe0P10@40204a<C080
EEEE0`1MGEd2069RHP80JFUY0P1]KFd2075aL@80MGEe0P1hN7P307]kN`80OWin0P21PH4208>3P`@0
PX:20P24Q8@708N7Q`80RXZ:0P2=SHd208j>SP80T92@0`2ATI4209>CT`80UYJF1P2HV9P209^KV`L0
WYjN0P2PX:020::RXP80Xj>S0P2UYJD30:JVYP80Z:RX0P2][Jd20;2`/080[Zj^102/[:`70:f][@@0
[Zj^0P2[Zj/20:VYZ@80ZZZZ0`2[Zj/20:VYZ@80YjNW0P2UYJD20:BTY080Xj>S0P2QXJ4309fMW@80
VIVI0P2GUiL209JFUP80T92@0P2:RXX208R8R0/0QXJ60P28R8P208V9R@<0QHF50P21PH420820P080
Ogmo0P1nOWh207alO0D0Ng]k0P1oOgl208:2PP80Ph>32038h=P000H0b>3H0P1OGel208J6QP80[Zj^
0`2[Zj/208F5Q@80EEEE0P0Q8B4202HV9P808B4Q0P0U9BD302LW9`8092@T100U9BD203lo?`80Ng]k
0P2CTi<308f=S@80J6QX0P1ZJVX2071`L080QHF50P2MWId20=;BdP<0aLG5103;bl/20<g=c@80c<c<
0P3Jf]X20;>c/`80Jf][0`0P820402DU9@808b<S0P0U9BD202d];@80>c/k0`1BDU8403@d=080=CDe
0P10@40204a<C080EEEE0`1MGEd2069RHP80JFUY0P1]KFd2075aL@80MGEe0P1hN7P307]kN`80OWin
0P21PH4208>3P`@0PX:20P24Q8@708N7Q`80RXZ:0P2=SHd208j>SP80T92@0`2ATI4209>CT`80UYJF
1P2HV9P209^KV`L0WYjN0P2PX:020::RXP80Xj>S0P2UYJD30:JVYP80Z:RX0P2][Jd20;2`/080[Zj^
102/[:`70:f][@@0[Zj^0P2[Zj/20:VYZ@80ZZZZ0`2[Zj/20:VYZ@80YjNW0P2UYJD20:BTY080Xj>S
0P2QXJ4309fMW@80VIVI0P2GUiL209JFUP80T92@0P2:RXX208R8R0/0QXJ60P28R8P208V9R@<0QHF5
0P21PH420820P080Ogmo0P1nOWh207alO0D0Ng]k0P1oOgl208:2PP80Ph>32038h=P000H0b>3H0P1b
LW8209BDU080];Bd0`2GUiL206e]K@80>3Ph0P0N7Qh202h^;P80820P0P0V9RH302TY:@@0:RXZ0P0W
9bL202h^;P80HF5Q0P2>SXh309RHV080J6QX0P1ZJVX206i^KP80MgMg0P25QHD20<[:bP<0a/K60P39
bLT20<O7a`80b/[:0P3<c<`20=GEe@80dm?C0P2XZ:P302l_;`8092@T0P0W9bL202<S8`809BDU0P0`
<30203Ph>0<0Bd];0P0c<c<203Hf=P80>CTi0P13@d<204i>CP80EUIF0`1MGEd206EUI@80Jf][0P1_
Kfl207=cL`80MWIf0P1iNGT307emO@80PH610P22PX860861P@80Q8B40`27QhL208R8R080RXZ:0P2<
S8`208j>SP80Shn?0P2@T90309>CT`80UYJF102GUiL209RHV080VIVI0P2KVi/309fMW@@0W9bL0P2P
X:020:FUY@80Z:RX0P2YZJT30:ZZZP80Zj^[0P2_[jl20;:b/P80/;2`0P2][Jd20:n_[`D0/K6a0P2`
/;020:n_[`80[Jf]0P2ZZZX20:RXZ080ZJVY0`2[Zj/20:ZZZP80Z:RX0P2VYZH20:>SX`80XZ:R0P2P
X:0309bLW080VIVI0P2GUiL209JFUP80TI6A0P2<S8`208Z:RP<0R8R81027QhL208J6QP80QHF50P2:
RXX208j>SP<0QhN71P20P80207moO`80OWin1@1lO7`20820P080Ph>30P24Q8@80<SPf0001P38h=P2
079bLP80U9BD0P2d];@309NGU`80KFe]0P0h>3P201hN7P80;Rh^0P0P820202HV9P<0:BTY100Z:RX2
02LW9`80;Rh^0P1QHF4208j>SP<0V9RH0P1XJ6P206YZJP80KVi^0P1gMgL208F5Q@80b/[:0`36a/H2
0<W9b@80alO70P3:b/X20<c<c080eMGE0P3Cdm<20:RXZ0<0;bl_0P0T92@202LW9`808b<S0P0U9BD2
030`<080>3Ph0`1;Bd/203<c<`80=SHf0P0i>CT204=3@`80CTi>0P1FEUH305eMG@80IFEU0P1[Jf/2
06m_K`80Lg=c0P1fMWH207UiN@<0OGem0P21PH4208:2PPH0PH610P24Q8@308N7Q`80R8R80P2:RXX2
08b<S080SXj>0P2?Shl2092@T0<0Ti>C0P2FUYH409NGU`80V9RH0P2IVIT209^KV`<0WIfM102LW9`2
0:2PX080YJFU0P2XZ:P20:VYZ@<0ZZZZ0P2[Zj/20:n_[`80/[:b0P2`/;020:f][@80[jn_1@2a/K42
0;2`/080[jn_0P2][Jd20:ZZZP80Z:RX0P2YZJT30:^[Z`80ZZZZ0P2XZ:P20:JVYP80Xj>S0P2RXZ82
0:2PX0<0W9bL0P2IVIT209NGU`80UYJF0P2ATI4208b<S080RXZ:0`28R8P408N7Q`80QXJ60P25QHD2
08Z:RP80SXj>0`27QhL60820P080Ogmo0P1nOWh507alO080P8200P23Ph<208B4Q0P0b>3H00060<SP
f080Y:BT0P2QXJ4209BDU0<0KVi^0P1:BTX202d];@808b<S0P0Z:RX2024Q8@8092@T1@0W9bL202HV
9P80:RXZ0P0W9bL204];B`80P8200`2JVYX207QhN080JFUY0P1]KFd207QhN080NWYj0P2`/;030<S8
b080a<C40P31`L420<K6aP80bl_;0P3Cdm<20=GEe@80a/K60`1^KVh2038b<P808B4Q0P0T92@2028R
8P80;Bd]0P0d=3@304M7A`80;bl_0P0d=3@203Xj>P80@T920P1;Bd/205EEE@<0GemO0P1UIFD206][
J`80LG5a0P1gMgL207UiN@80NWYj0`1lO7`207inOP80Ogmo0P20P80208:2PP@0Q8B40`25QHD208R8
R080Rh^;0P2<S8`208f=S@80SXj>0P2@T90309>CT`80UYJF102HV9P609VIV@<0VYZJ0P2KVi/209bL
W080XJ6Q0P2UYJD20:NWY`80Z:RX0`2YZJT20:ZZZP80[Zj^0P2b/[820;2`/080[Jf]0P2_[jl50;:b
/P80/K6a0P2`/;020:j^[P80Zj^[0P2XZ:P20:ZZZP<0[:b/0P2ZZZX20:RXZ080YjNW0P2UYJD20:>S
X`80X:2P0`2NWYh209^KV`80V9RH0P2EUID209>CT`80T92@0P2=SHd308Z:RP80RHV91028R8P208V9
R@80Rh^;0P2=SHd308R8R080Ph>31021PH4207moO`80OGem1@1lO7`20820P080Ph>30P24Q8@80<SP
f0001P38h=P20:BTY080XJ6Q0P2DU9@306i^KP80BTY:0P0];Bd202<S8`80:RXZ0P0Q8B4202@T90D0
9bLW0P0V9RH202XZ:P809bLW0P1;Bd/20820P0<0VYZJ0P1hN7P206UYJ@80KFe]0P1hN7P207YjNP80
/;2`0`38b<P20<C4a080`L710P36a/H20<_;b`80dm?C0P3EeMD20<K6aP<0KVi^0P0b<S82024Q8@80
92@T0P0R8R8202d];@80=3@d0`17AdL202l_;`80=3@d0P0j>SX20492@P80Bd];0P1EEED305mOG`80
IFEU0P1[Jf/2075aL@80MgMg0P1iNGT207YjNP<0O7al0P1nOWh207moO`80P8200P22PX8408B4Q0<0
QHF50P28R8P208^;R`80S8b<0P2=SHd208j>SP80T92@0`2CTi<209JFUP@0V9RH1P2IVIT309ZJVP80
Vi^K0P2LW9`20:6QX@80YJFU0P2WYjL20:RXZ0<0ZJVY0P2ZZZX20:j^[P80/[:b0P2`/;020:f][@80
[jn_1@2b/[820;6a/@80/;2`0P2^[Zh20:^[Z`80Z:RX0P2ZZZX30:b/[080ZZZZ0P2XZ:P20:NWY`80
YJFU0P2SXj<20:2PX0<0WYjN0P2KVi/209RHV080UIFE0P2CTi<2092@T080SHf=0`2:RXX208V9R@@0
R8R80P29RHT208^;R`80SHf=0`28R8P208>3P`@0PH610P1oOgl207emO@D0O7al0P20P80208>3P`80
Q8B42038h=P000H0b>3H0P2TY:@20:6QX@80U9BD0`1^KVh204Y:BP80;Bd]0P0S8b<202XZ:P808B4Q
0P0T92@502LW9`809RHV0P0Z:RX202LW9`80Bd];0P20P80309ZJVP80N7Qh0P1YJFT206e]K@80N7Qh
0P1jNWX20;2`/0<0b<S80P34a<@20<71`@80a/K60P3;bl/20=?Cd`80eMGE0P36a/H306i^KP80<S8b
0P0Q8B4202@T90808R8R0P0];Bd203@d=0<0AdM70P0_;bl203@d=080>SXj0P12@T8204];B`80EEEE
0`1OGel206EUI@80Jf][0P1aLG4207MgM`80NGUi0P1jNWX307alO080OWin0P1oOgl20820P080PX:2
1024Q8@308F5Q@80R8R80P2;Rh/208b<S080SHf=0P2>SXh2092@T0<0Ti>C0P2FUYH409RHV0H0VIVI
0`2JVYX209^KV`80W9bL0P2QXJ420:FUY@80YjNW0P2XZ:P30:VYZ@80ZZZZ0P2^[Zh20;:b/P80/;2`
0P2][Jd20:n_[`D0/[:b0P2a/K420;2`/080[Zj^0P2[Zj/20:RXZ080ZZZZ0`2/[:`20:ZZZP80Z:RX
0P2WYjL20:FUY@80Xj>S0P2PX:0309jNWP80Vi^K0P2HV9P209FEU@80Ti>C0P2@T90208f=S@<0RXZ:
0P29RHT408R8R080RHV90P2;Rh/208f=S@<0R8R80P23Ph<40861P@80Ogmo0P1mOGd507alO080P820
0P23Ph<208B4Q0P0b>3H00060<SPf080Zj^[0P2BTY8206][J`<0AdM70P0Z:RX202HV9P809bLW0P0S
8b<4028R8P<092@T0P0S8b<2024Q8@80;Bd]0P0S8b<203Ph>080Jf][0`2EUID208^;R`80K6a/0P1]
KFd207]kN`80M7Ad0P2BTY830<C4a080`<300P2l_;`20<;2`P80b<S80P3>c/h20<c<c080eMGE0`2/
[:`204e=C@808R8R0P0Y:BT2020P8080:RXZ0P0`<30304A4A080:b/[0P0b<S8203Xj>P80@D510P19
BDT205EEE@<0H61P0P1VIVH206][J`80Lg=c0P1jNWX207]kN`80NWYj1@1kNg/207emO@80P8200P23
Ph<208J6QP80Q8B40`23Ph<208N7Q`80Rh^;102<S8`208j>SP80T92@0`2CTi<209JFUP80V9RH1P2I
VIT509RHV080VYZJ0P2MWId20::RXP80YJFU102VYZH30:NWY`80ZJVY0P2][Jd20;6a/@80/;2`0P2^
[Zh20;2`/0<0/[:b0P2c/k<20;:b/P80/;2`0P2_[jl20:^[Z`80ZJVY0P2ZZZX30:b/[080Zj^[102X
Z:P20:NWY`80Y:BT0P2PX:0309nOW`80WIfM0P2IVIT409BDU080Ti>C0P2@T90308b<S0@0RXZ:0P2;
Rh/208f=S@80S8b<0P2;Rh/308R8R080QHF50P23Ph<20861P@80OWin101lO7`307emO@80P8200P23
Ph<208B4Q0P0b>3H00060<SPf080Zj^[0P2BTY8206][J`<0AdM70P0Z:RX202HV9P809bLW0P0S8b<4
028R8P<092@T0P0S8b<2024Q8@80;Bd]0P0S8b<203Ph>080Jf][0`2EUID208^;R`80K6a/0P1]KFd2
07]kN`80M7Ad0P2BTY830<C4a080`<300P2l_;`20<;2`P80b<S80P3>c/h20<c<c080eMGE0`2/[:`2
04e=C@808R8R0P0Y:BT2020P8080:RXZ0P0`<30304A4A080:b/[0P0b<S8203Xj>P80@D510P19BDT2
05EEE@<0H61P0P1VIVH206][J`80Lg=c0P1jNWX207]kN`80NWYj1@1kNg/207emO@80P8200P23Ph<2
08J6QP80Q8B40`23Ph<208N7Q`80Rh^;102<S8`208j>SP80T92@0`2CTi<209JFUP80V9RH1P2IVIT5
09RHV080VYZJ0P2MWId20::RXP80YJFU102VYZH30:NWY`80ZJVY0P2][Jd20;6a/@80/;2`0P2^[Zh2
0;2`/0<0/[:b0P2c/k<20;:b/P80/;2`0P2_[jl20:^[Z`80ZJVY0P2ZZZX30:b/[080Zj^[102XZ:P2
0:NWY`80Y:BT0P2PX:0309nOW`80WIfM0P2IVIT409BDU080Ti>C0P2@T90308b<S0@0RXZ:0P2;Rh/2
08f=S@80S8b<0P2;Rh/308R8R080QHF50P23Ph<20861P@80OWin101lO7`307emO@80P8200P23Ph<2
08B4Q0P0b>3H00060<SPf080V9RH0P1fMWH204M7A`<0;Rh^0P0Q8B4202/[:`80=SHf0P0[:b/4024Q
8@<08b<S100R8R8202HV9P80820P0P0^;Rh2059BDP<0Q8B40P2HV9P207alO080KVi^0P1cLg<2079b
LP80PH610`2`/;020<W9b@80]kNg0P2o_kl20<C4a080aLG50P36a/H20=_Kf`<0dM7A0P2FUYH203Xj
>P80:RXZ0P0U9BD202TY:@80;Rh^0`14A4@202/[:`80<C4a0P0h>3P20410@080BTY:0P1GEeL306=S
H`80JFUY0P1]KFd207EeM@80NWYj0P1iNGT207MgM`<0NGUi0P1lO7`207moO`80PX:20P25QHD208N7
Q`80QHF50`24Q8@208J6QP80RHV90P2<S8`208n?S`@0T92@0`2ATI4209>CT`80U9BD0P2FUYH209RH
V080VIVI1@2JVYX209bLW080WinO0P2RXZ820:FUY@80YjNW0P2XZ:P30:ZZZP80[Jf]0P2`/;020;>c
/`80/K6a0P2_[jl20;2`/0<0/K6a0P2c/k<20;Bd]080/[:b0P2_[jl20:b/[080Zj^[0P2][Jd30:n_
[`80[Jf]0P2YZJT20:RXZ080YZJV0P2TY:@20:6QX@<0X:2P0P2NWYh209ZJVP80UIFE0P2BTY8408n?
S`<0SXj>0P2<S8`208^;R`80SXj>0P2@T90208j>SP80RXZ:0`29RHT208N7Q`80Q8B40P21PH4207in
OP80O7al0P1mOGd307moO`80PX:20P23Ph<208B4Q0P0b>3H00060<SPf080V9RH0P1fMWH204M7A`<0
;Rh^0P0Q8B4202/[:`80=SHf0P0[:b/4024Q8@<08b<S100R8R8202HV9P80820P0P0^;Rh2059BDP<0
Q8B40P2HV9P207alO080KVi^0P1cLg<2079bLP80PH610`2`/;020<W9b@80]kNg0P2o_kl20<C4a080
aLG50P36a/H20=_Kf`<0dM7A0P2FUYH203Xj>P80:RXZ0P0U9BD202TY:@80;Rh^0`14A4@202/[:`80
<C4a0P0h>3P20410@080BTY:0P1GEeL306=SH`80JFUY0P1]KFd207EeM@80NWYj0P1iNGT207MgM`<0
NGUi0P1lO7`207moO`80PX:20P25QHD208N7Q`80QHF50`24Q8@208J6QP80RHV90P2<S8`208n?S`@0
T92@0`2ATI4209>CT`80U9BD0P2FUYH209RHV080VIVI1@2JVYX209bLW080WinO0P2RXZ820:FUY@80
YjNW0P2XZ:P30:ZZZP80[Jf]0P2`/;020;>c/`80/K6a0P2_[jl20;2`/0<0/K6a0P2c/k<20;Bd]080
/[:b0P2_[jl20:b/[080Zj^[0P2][Jd30:n_[`80[Jf]0P2YZJT20:RXZ080YZJV0P2TY:@20:6QX@<0
X:2P0P2NWYh209ZJVP80UIFE0P2BTY8408n?S`<0SXj>0P2<S8`208^;R`80SXj>0P2@T90208j>SP80
RXZ:0`29RHT208N7Q`80Q8B40P21PH4207inOP80O7al0P1mOGd307moO`80PX:20P23Ph<208B4Q0P0
b>3H00060<SPf080MWIf0P1FEUH202/[:`<08b<S0P0R8R84024Q8@808R8R100S8b<302@T90808b<S
0P0U9BD401lO7`809bLW0P0i>CT306i^KP80WIfM0P2=SHd2079bLP80K6a/0P1aLG4207MgM`<0UiNG
0P3>c/h20;Fe]@80_[jn0P30`<020<71`@80`/;20P38b<P30<?3``80a/K60P1NGUh203dm?@80:2PX
0P0Y:BT202d];@<0@d=30P0/;2`2034a<@80=SHf0P0o?cl204];B`80F5QH0`1TI6@206][J`80L71`
0P1fMWH207UiN@80MgMg0P1eMGD307UiN@80OWin0P21PH4208B4Q080QXJ60P27QhL208J6QPD0QHF5
0P26QXH208b<S0@0TI6A1`2@T90209:BTP80U9BD0P2GUiL209ZJVP80W9bL0`2MWId209nOW`80XZ:R
0P2TY:@20:JVYP80Z:RX0P2ZZZX30:j^[P80/K6a0P2c/k<20;Bd]080/[:b1`2a/K420;Bd]080][Jf
0P2c/k<20:n_[`@0[Jf]0P2`/;030;:b/P80[Zj^0P2YZJT20:RXZ080YjNW0P2TY:@20::RXP<0X:2P
0P2NWYh209^KV`80UiNG0P2ATI4208b<S080SXj>0`2@T90208j>SP80S8b<0P2@T90209>CT`80T92@
0P2;Rh/308V9R@80QhN70P25QHD208:2PP80OWin0P1lO7`207inOP<0PH610P23Ph<408B4Q0P0b>3H
00060<SPf080MWIf0P1FEUH202/[:`<08b<S0P0R8R84024Q8@808R8R100S8b<302@T90808b<S0P0U
9BD401lO7`809bLW0P0i>CT306i^KP80WIfM0P2=SHd2079bLP80K6a/0P1aLG4207MgM`<0UiNG0P3>
c/h20;Fe]@80_[jn0P30`<020<71`@80`/;20P38b<P30<?3``80a/K60P1NGUh203dm?@80:2PX0P0Y
:BT202d];@<0@d=30P0/;2`2034a<@80=SHf0P0o?cl204];B`80F5QH0`1TI6@206][J`80L71`0P1f
MWH207UiN@80MgMg0P1eMGD307UiN@80OWin0P21PH4208B4Q080QXJ60P27QhL208J6QPD0QHF50P26
QXH208b<S0@0TI6A1`2@T90209:BTP80U9BD0P2GUiL209ZJVP80W9bL0`2MWId209nOW`80XZ:R0P2T
Y:@20:JVYP80Z:RX0P2ZZZX30:j^[P80/K6a0P2c/k<20;Bd]080/[:b1`2a/K420;Bd]080][Jf0P2c
/k<20:n_[`@0[Jf]0P2`/;030;:b/P80[Zj^0P2YZJT20:RXZ080YjNW0P2TY:@20::RXP<0X:2P0P2N
WYh209^KV`80UiNG0P2ATI4208b<S080SXj>0`2@T90208j>SP80S8b<0P2@T90209>CT`80T92@0P2;
Rh/308V9R@80QhN70P25QHD208:2PP80OWin0P1lO7`207inOP<0PH610P23Ph<408B4Q0P0b>3H0006
0<SPf080EeMG0P11@D4202TY:@D092@T0P0U9BD202HV9PH09BDU0`0T92@202l_;`808b<S100Q8B42
020P8080:BTY0`1GEeL208b<S080UYJF0P1nOWh206a/K080L71`0P1jNWX30861P@80^[Zj0P33`l<2
0<30`080^[Zj0P35aLD20;no_`D0`<300P3Fe]H20:f][@80<c<c0P0j>SX402XZ:P<0<c<c0P0/;2`2
030`<080=SHf0P11@D4204i>CP80F5QH0`1RHV8206][J`80LW9b0P1eMGD407MgM`80N7Qh0`1lO7`2
0820P080PH610P22PX8208>3P`80Q8B41`25QHD208J6QP80RXZ:0P2>SXh2096AT@D0Ti>C0P2BTY82
09>CT`80UIFE0P2GUiL209^KV`80WYjN0`2QXJ420:>SX`80YZJV0P2WYjL20:VYZ@80Zj^[0P2][Jd3
0:n_[`80/K6a0P2b/[840;>c/`80/[:b0P2e]KD50;Ng]`80]KFe0P2b/[820:j^[P80[:b/0P2[Zj/2
0:f][@<0[jn_0P2/[:`20:VYZ@@0ZZZZ0P2VYZH20:6QX@<0WinO0P2NWYh209bLW080VIVI0P2EUID4
096AT@<0TY:B0P2@T90208n?S`80TY:B0P2CTi<2092@T080S8b<0`2:RXX208R8R080QhN70P24Q8@2
0820P080O7al0P1oOgl308:2PP80Q8B41025QHD80<SPf0001P38h=P205MGE`80@D510P0Y:BT502@T
90809BDU0P0V9RH602DU9@<092@T0P0_;bl202<S8`@08B4Q0P0P820202TY:@<0EeMG0P2<S8`209JF
UP80OWin0P1/K6`2071`L080NWYj0`21PH420;Zj^P80`l?30P30`<020;Zj^P80aLG50P2o_kl50<30
`080e]KF0P2][Jd203<c<`80>SXj100Z:RX303<c<`80;2`/0P0`<30203Hf=P80@D510P1>CTh205QH
F0<0HV9R0P1[Jf/2079bLP80MGEe101gMgL207QhN0<0O7al0P20P8020861P@80PX:20P23Ph<208B4
Q0L0QHF50P26QXH208Z:RP80SXj>0P2ATI4509>CT`80TY:B0P2CTi<209FEU@80UiNG0P2KVi/209jN
WP<0XJ6Q0P2SXj<20:JVYP80YjNW0P2YZJT20:^[Z`80[Jf]0`2_[jl20;6a/@80/[:b102c/k<20;:b
/P80]KFe1@2g]kL20;Fe]@80/[:b0P2^[Zh20:b/[080Zj^[0P2][Jd30:n_[`80[:b/0P2YZJT40:ZZ
ZP80YZJV0P2QXJ4309nOW`80WYjN0P2LW9`209VIV@80UIFE102ATI4309:BTP80T92@0P2?Shl209:B
TP80Ti>C0P2@T90208b<S0<0RXZ:0P28R8P208N7Q`80Q8B40P20P80207alO080Ogmo0`22PX8208B4
Q0@0QHF52038h=P000H0b>3H0P0o?cl203@d=080;bl_0`0Y:BT202DU9@809bLW0P0Z:RX202TY:@@0
9bLW0`0U9BD203Ph>0808b<S0P0U9BD202@T90807AdM0P0O7al30492@P80Lg=c0P2GUiL208V9R@80
LW9b0P1_Kfl207inOP<0LG5a0P2PX:020<g=c@80`l?30P2d];@20<S8b0@0_Kfm0`2j^[X40<[:bP80
TY:B0P0];Bd202@T9080:RXZ0`0X:2P202`/;080<30`0P0f=SH20492@P80Cdm?0P1HF5P3061PH080
JVYZ0P1cLg<407EeM@80N7Qh0P1jNWX307inOP@0PH610P1oOgl20820P080PH610P23Ph<708J6QP80
R8R80P2;Rh/2096AT@D0UYJF0P2DU9@209FEU@80UiNG0P2IVIT209bLW080X:2P0`2TY:@20:NWY`80
ZZZZ0P2[Zj/20:b/[080[Zj^0P2_[jl30;2`/080/K6a1P2b/[820;Bd]080^KVi0`2m_Kd20;Vi^@80
];Bd0P2a/K420:j^[P80Zj^[0P2ZZZX20:^[Z`<0[:b/0P2[Zj/20:ZZZP80[:b/0P2][Jd20:NWY`80
XJ6Q0`2OWil209fMW@80W9bL0P2KVi/209VIV@80UiNG0P2EUID309>CT`@0TY:B102CTi<2092@T080
SHf=0`2;Rh/208V9R@80R8R80P26QXH208:2PP80OWin0P1oOgl308:2PP80Q8B40P25QHD208J6QPP0
b>3H00060<SPf080?clo0P0d=3@202l_;`<0:BTY0P0U9BD202LW9`80:RXZ0P0Y:BT402LW9`<09BDU
0P0h>3P202<S8`809BDU0P0T92@201dM7@807alO0`12@T8207=cL`80UiNG0P29RHT2079bLP80Kfm_
0P1nOWh3075aL@80X:2P0P3=cLd20<?3``80];Bd0P38b<P40;fm_@<0^[Zj103:b/X209:BTP80;Bd]
0P0T92@202XZ:P<0:2PX0P0/;2`2030`<080=SHf0P12@T8204m?C`80F5QH0`1PH60206YZJP80Lg=c
101eMGD207QhN080NWYj0`1nOWh40861P@80Ogmo0P20P8020861P@80Ph>31`26QXH208R8R080Rh^;
0P2ATI4509JFUP80U9BD0P2EUID209NGU`80VIVI0P2LW9`20:2PX0<0Y:BT0P2WYjL20:ZZZP80Zj^[
0P2/[:`20:j^[P80[jn_0`2`/;020;6a/@H0/[:b0P2d];@20;Vi^@<0_Kfm0P2i^KT20;Bd]080/K6a
0P2^[Zh20:^[Z`80ZZZZ0P2[Zj/30:b/[080Zj^[0P2ZZZX20:b/[080[Jf]0P2WYjL20:6QX@<0WinO
0P2MWId209bLW080Vi^K0P2IVIT209NGU`80UIFE0`2CTi<409:BTP@0Ti>C0P2@T90208f=S@<0Rh^;
0P29RHT208R8R080QXJ60P22PX8207inOP80Ogmo0`22PX8208B4Q080QHF50P26QXH80<SPf0001P38
h=P204a<C080=3@d0P0^;Rh303De=@80?Shn0P0d=3@202XZ:P80:BTY0P0[:b/202TY:@<09RHV0P0d
=3@202`/;080:BTY0P0T92@201lO7`808R8R0`0d=3@205ADE080UYJF0P2RXZ8208f=S@80KFe]0P1f
MWH307=cL`80Rh^;0P2i^KT20<o?c`80/;2`0P32`/820;jn_P80_;bl0`2i^KT20<K6aP80d=3@0P2g
]kL206QXJ080;bl_0P0O7al302PX:080;Rh^0P0a<C4203Lg=`80@4100P1:BTX205EEE@<0HF5Q0P1Z
JVX2075aL@80MGEe0P1gMgL207QhN080NWYj0`1mOGd207moO`80OGem0P1lO7`207inOP80P8200P23
Ph<308J6QP80R8R8102;Rh/208b<S080TY:B1`2GUiL209RHV080VIVI0P2KVi/209fMW@80X:2P0`2T
Y:@20:VYZ@80[:b/102][Jd20:j^[P80/;2`0`2b/[840;>c/`80/[:b0P2c/k<20;Bd]080]kNg0`2h
^;P20;Bd]0@0/;2`0P2a/K420:f][@80ZZZZ0P2][Jd30:n_[`80[Jf]0P2[Zj/20:b/[080[Jf]0P2Y
ZJT20:BTY0<0XZ:R0P2OWil209jNWP80WIfM0P2JVYX209NGU`80UYJF0`2EUID209BDU080TY:B0P2C
Ti<209BDU080TI6A0P2>SXh308b<S080Rh^;0P29RHT208J6QP80Ph>30P21PH420820P0<0Ogmo0P22
PX8408F5Q@P0b>3H00060<SPf080C4a<0P0d=3@202h^;P<0=CDe0P0n?Sh203@d=080:RXZ0P0Y:BT2
02/[:`80:BTY0`0V9RH203@d=080;2`/0P0Y:BT202@T90807alO0P0R8R8303@d=080E5AD0P2FUYH2
0::RXP80SHf=0P1]KFd207IfMP<0Lg=c0P2;Rh/20;Vi^@80clo?0P2`/;020<;2`P80_[jn0P2l_;`3
0;Vi^@80a/K60P3@d=020;Ng]`80J6QX0P0_;bl201lO7`<0:2PX0P0^;Rh2034a<@80=cLg0P10@402
04Y:BP80EEEE0`1QHF4206YZJP80LG5a0P1eMGD207MgM`80N7Qh0P1jNWX307emO@80Ogmo0P1mOGd2
07alO080OWin0P20P80208>3P`<0QXJ60P28R8P408^;R`80S8b<0P2BTY8709NGU`80V9RH0P2IVIT2
09^KV`80WIfM0P2PX:030:BTY080ZJVY0P2/[:`40:f][@80[Zj^0P2`/;030;:b/P@0/k>c0P2b/[82
0;>c/`80];Bd0P2g]kL30;Rh^080];Bd102`/;020;6a/@80[Jf]0P2ZZZX20:f][@<0[jn_0P2][Jd2
0:^[Z`80[:b/0P2][Jd20:VYZ@80Y:BT0`2RXZ8209nOW`80WYjN0P2MWId209ZJVP80UiNG0P2FUYH3
09FEU@80U9BD0P2BTY8209>CT`80U9BD0P2ATI4208j>SP<0S8b<0P2;Rh/208V9R@80QXJ60P23Ph<2
0861P@80P8200`1oOgl208:2PP@0QHF52038h=P000H0b>3H0P1LG5`203`l?080<30`0`0V9RH202<S
8`809RHV0P0[:b/202d];@80;Rh^0P0Z:RX302PX:080;Bd]0P0d=3@202`/;0@092@T0P0W9bL302h^
;P80>c/k0P1lO7`209:BTP80UYJF101`L70307QhN080NWYj0P2NWYh20=?Cd`80[Zj^0P2i^KT20;jn
_P80_;bl0`2j^[X20<71`@80alO70P3EeMD20:>SX`80AdM70P0P820302h^;P80;Bd]0P0a<C4203Hf
=P80?3`l0P14A4@205=CD`<0HF5Q0P1YJFT206i^KP80MGEe1P1iNGT307]kN`80O7al0P1kNg/207Yj
NP80OGem0P21PH4208>3P`<0QXJ60P2;Rh/608n?S`80Ti>C0P2GUiL309RHV080VIVI0P2JVYX209^K
V`80WIfM0P2NWYh20:6QX@<0YJFU0P2ZZZX40:j^[P80[Jf]0P2^[Zh20;2`/0<0/k>c0P2e]KD20;Bd
]0/0/k>c0P2_[jl20:f][@80/;2`0P2c/k<20;2`/080[:b/0P2_[jl30;:b/P80/;2`0P2][Jd20:b/
[080Zj^[0P2ZZZX20:RXZ0<0YJFU0P2QXJ4209nOW`80WIfM0P2JVYX409JFUP<0UiNG0P2DU9@209:B
TP80Ti>C0P2DU9@209:BTP80Shn?0`2=SHd208b<S080RHV91025QHD208B4Q080P8200`1mOGd20820
P080Ph>30P24Q8@80<SPf0001P38h=P205aLG080?3`l0P0`<30302HV9P808b<S0P0V9RH202/[:`80
;Bd]0P0^;Rh202XZ:P<0:2PX0P0];Bd203@d=080;2`/100T92@202LW9`<0;Rh^0P0k>c/207alO080
TY:B0P2FUYH4071`L0<0N7Qh0P1jNWX209jNWP80dm?C0P2^[Zh20;Vi^@80_[jn0P2l_;`30;Zj^P80
`L710P37alL20=GEe@80Xj>S0P17AdL2020P80<0;Rh^0P0];Bd2034a<@80=SHf0P0l?3`204A4A080
De=C0`1QHF4206UYJ@80KVi^0P1eMGD607UiN@<0Ng]k0P1lO7`207]kN`80NWYj0P1mOGd20861P@80
Ph>30`26QXH208^;R`H0Shn?0P2CTi<209NGU`<0V9RH0P2IVIT209ZJVP80Vi^K0P2MWId209jNWP80
XJ6Q0`2UYJD20:ZZZP@0[Zj^0P2][Jd20:j^[P80/;2`0`2c/k<20;Fe]@80];Bd2`2c/k<20:n_[`80
[Jf]0P2`/;020;>c/`80/;2`0P2/[:`20:n_[`<0/[:b0P2`/;020:f][@80[:b/0P2[Zj/20:ZZZP80
Z:RX0`2UYJD20:6QX@80WinO0P2MWId209ZJVP@0UYJF0`2GUiL209BDU080TY:B0P2CTi<209BDU080
TY:B0P2?Shl308f=S@80S8b<0P29RHT408F5Q@80Q8B40P20P80307emO@80P8200P23Ph<208B4Q0P0
b>3H00060<SPf080G5aL0P0l?3`2030`<0<09RHV0P0S8b<202HV9P80:b/[0P0];Bd202h^;P80:RXZ
0`0X:2P202d];@80=3@d0P0/;2`402@T90809bLW0`0^;Rh203/k>`80O7al0P2BTY8209JFUP@0L71`
0`1hN7P207YjNP80WYjN0P3Cdm<20:j^[P80^KVi0P2n_[h20;bl_0<0^[Zj0P31`L420<O7a`80eMGE
0P2SXj<204M7A`80820P0`0^;Rh202d];@80<C4a0P0f=SH203`l?080A4A40P1CDe<3065QH@80JFUY
0P1^KVh207EeM@H0NGUi0`1kNg/207alO080Ng]k0P1jNWX207emO@80PH610P23Ph<308J6QP80Rh^;
1P2?Shl209>CT`80UiNG0`2HV9P209VIV@80VYZJ0P2KVi/209fMW@80WYjN0P2QXJ430:FUY@80ZZZZ
102^[Zh20:f][@80[Zj^0P2`/;030;>c/`80]KFe0P2d];@;0;>c/`80[jn_0P2][Jd20;2`/080/k>c
0P2`/;020:b/[080[jn_0`2b/[820;2`/080[Jf]0P2/[:`20:^[Z`80ZZZZ0P2XZ:P30:FUY@80XJ6Q
0P2OWil209fMW@80VYZJ102FUYH309NGU`80U9BD0P2BTY8209>CT`80U9BD0P2BTY8208n?S`<0SHf=
0P2<S8`208V9R@@0QHF50P24Q8@20820P0<0OGem0P20P80208>3P`80Q8B42038h=P000H0b>3H0P1=
CDd203Ti>@80;Rh^0`0Z:RX202TY:@80:b/[1P0];Bd202`/;0<0:b/[0P0/;2`202l_;`80;Bd]0P0Z
:RX702TY:@80<C4a0P1PH60208>3P`80WYjN0P21PH42071`L0<0M7Ad0P1kNg/208F5Q@@0]KFe0P2a
/K420;^k^`80_Kfm0`2o_kl20<71`@80a<C40P3Ogml20=3@d080UIFE0P0o?cl302HV9P808R8R0P0^
;Rh2038b<P80>c/k0P14A4@205=CD`<0H61P0P1WIfL206a/K080Lg=c0P1hN7P407YjNP<0Ng]k0P1m
OGd407alO080Ogmo0P22PX8208B4Q0<0QXJ60P2:RXX208j>SP80TI6A0P2BTY8209>CT`80UIFE0`2G
UiL209ZJVP80Vi^K0P2LW9`209nOW`80XZ:R0P2TY:@30:FUY@80ZJVY0P2/[:`40:f][@80[Zj^0P2`
/;030;:b/PH0];Bd0P2b/[820;6a/@D0/[:b0P2a/K420:n_[`80/;2`0P2a/K420;2`/080[jn_0P2a
/K450;:b/P80/K6a0P2^[Zh20:b/[080ZZZZ0P2XZ:P30:FUY@80XZ:R0P2OWil209bLW080Vi^K0P2J
VYX209NGU`<0U9BD202CTi<2092@T080SXj>0`2<S8`208Z:RP80QhN70P25QHD408B4Q080PX:22@20
P8080<SPf0001P38h=P204e=C@80>CTi0P0^;Rh302XZ:P80:BTY0P0[:b/602d];@80;2`/0`0[:b/2
02`/;080;bl_0P0];Bd202XZ:PL0:BTY0P0a<C42061PH080Ph>30P2NWYh20861P@80L71`0`1dM7@2
07]kN`80QHF5102e]KD20;6a/@80^k^k0P2m_Kd30;no_`80`L710P34a<@20=oOg`80d=3@0P2EUID2
03lo?`<09RHV0P0R8R8202h^;P80<S8b0P0k>c/204A4A080De=C0`1PH60206MWI`80K6a/0P1cLg<2
07QhN0@0NWYj0`1kNg/207emO@@0O7al0P1oOgl208:2PP80Q8B40`26QXH208Z:RP80SXj>0P2ATI42
09:BTP80Ti>C0P2EUID309NGU`80VYZJ0P2KVi/209bLW080WinO0P2RXZ820:BTY0<0YJFU0P2YZJT2
0:b/[0@0[Jf]0P2^[Zh20;2`/0<0/[:b1P2d];@20;:b/P80/K6a1@2b/[820;6a/@80[jn_0P2`/;02
0;6a/@80/;2`0P2_[jl20;6a/@D0/[:b0P2a/K420:j^[P80[:b/0P2ZZZX20:RXZ0<0YJFU0P2RXZ82
09nOW`80W9bL0P2KVi/209ZJVP80UiNG0`2DU9@809>CT`80T92@0P2>SXh308b<S080RXZ:0P27QhL2
08F5Q@@0Q8B40P22PX890820P0P0b>3H00060<SPf080>c/k0P0e=CD202`/;0<0;Bd]1P0^;Rh202d]
;@80;2`/0P0];Bd302l_;`80;2`/0P0Z:RX202d];@80;bl_0P0];Bd202XZ:P<0:2PX0P0^;Rh20492
@P80JVYZ0P2JVYX209BDU080MGEe0`1`L70207inOP80L71`0P2CTi<20;Rh^080[Jf]0P2g]kL20;fm
_@D0a<C40P32`/820<g=c@80bl_;0P3<c<`207=cL`<0>3Ph0P0H61P202/[:`80;2`/0P0i>CT204E5
A@80DU9B0`1NGUh206EUI@80JVYZ0P1aLG4207MgM`80NGUi0P1jNWX307alO080OGem0P1nOWh20820
P080PX:20P24Q8@208F5Q@<0QhN70P2:RXX208f=S@80TI6A102DU9@209>CT`<0UYJF0P2IVIT209^K
V`80W9bL0P2PX:020:BTY0D0YZJV0P2XZ:P20:ZZZP80[:b/0P2][Jd20:j^[P80[jn_0`2a/K420;:b
/P80/k>c0P2d];@20;6a/@80[jn_0P2a/K450;>c/`80/[:b0P2`/;020:j^[P80/;2`0P2b/[850;6a
/@80/[:b0P2c/k<20;6a/@80[Jf]0P2ZZZX20:NWY`<0YJFU0P2SXj<209nOW`80Vi^K102LW9`209JF
UP<0TI6A0P2BTY8209BDU080Ti>C0P2ATI4208n?S`80SHf=0`2:RXX208N7Q`80QHF50P24Q8@208>3
P`@0Q8B40`23Ph<20861P@@0OWin2038h=P000H0b>3H0P0k>c/203De=@80;2`/0`0];Bd602h^;P80
;Bd]0P0/;2`202d];@<0;bl_0P0/;2`202XZ:P80;Bd]0P0_;bl202d];@80:RXZ0`0X:2P202h^;P80
@T920P1ZJVX209ZJVP80U9BD0P1eMGD3071`L080OWin0P1`L70209>CT`80^;Rh0P2][Jd20;Ng]`80
_Kfm1@34a<@20<;2`P80cLg=0P3;bl/20<c<c080Lg=c0`0h>3P201PH6080:b/[0P0/;2`203Ti>@80
ADE50P1BDU8305iNGP80IFEU0P1ZJVX2075aL@80MgMg0P1iNGT207YjNP<0O7al0P1mOGd207inOP80
P8200P22PX8208B4Q080QHF50`27QhL208Z:RP80SHf=0P2ATI4409BDU080Ti>C0`2FUYH209VIV@80
Vi^K0P2LW9`20:2PX080Y:BT1@2VYZH20:RXZ080ZZZZ0P2/[:`20:f][@80[Zj^0P2_[jl30;6a/@80
/[:b0P2c/k<20;Bd]080/K6a0P2_[jl20;6a/@D0/k>c0P2b/[820;2`/080[Zj^0P2`/;020;:b/PD0
/K6a0P2b/[820;>c/`80/K6a0P2][Jd20:ZZZP80YjNW0`2UYJD20:>SX`80WinO0P2KVi/409bLW080
UYJF0`2ATI4209:BTP80U9BD0P2CTi<2096AT@80Shn?0P2=SHd308Z:RP80QhN70P25QHD208B4Q080
Ph>31024Q8@308>3P`80PH61101nOWh80<SPf0001P38h=P203hn?P80=CDe0P0];Bd302h^;P80<S8b
0P0a<C4602l_;`d0;Rh^0P0];Bd202/[:`<0:2PX0P0Z:RX2038b<P80CDe=0P28R8P20::RXP80PX:2
0`1^KVh207=cL`80KFe]0P24Q8@20:n_[`80^k^k0P2_[jl20;Zj^P<0`L711032`/820<S8b080c<c<
0P3Lg=`20;>c/`<0Cdm?0P0^;Rh202`/;0809bLW0P0d=3@204A4A080Cdm?0`1IFET2065QH@80IfMW
0P1_Kfl207IfMP@0N7Qh0`1jNWX207emO@80OWin0P20P8020861P@80Ph>30P26QXH308V9R@80Rh^;
0P2=SHd2092@T080Ti>C102EUID309JFUP80V9RH0P2KVi/209jNWP80XJ6Q0P2RXZ820:FUY@<0YjNW
0P2ZZZX40:b/[080Zj^[0P2][Jd20;2`/0<0/k>c0P2d];@20;6a/@80[Zj^0P2][Jd20:j^[P80/K6a
1@2c/k<20;:b/PP0/K6a0P2`/;030:n_[`80/;2`0P2a/K420;2`/080[jn_0P2/[:`20:VYZ@<0YjNW
0P2UYJD20:6QX@80WIfM0P2JVYX209NGU`80UIFE1@2CTi<209FEU@80Ti>C0P2ATI4208n?S`80SHf=
0`2:RXX208N7Q`80QHF51P24Q8@208>3P`<0PX:21P21PH480<SPf0001P38h=P203hn?P80=CDe0P0]
;Bd302h^;P80<S8b0P0a<C4602l_;`d0;Rh^0P0];Bd202/[:`<0:2PX0P0Z:RX2038b<P80CDe=0P28
R8P20::RXP80PX:20`1^KVh207=cL`80KFe]0P24Q8@20:n_[`80^k^k0P2_[jl20;Zj^P<0`L711032
`/820<S8b080c<c<0P3Lg=`20;>c/`<0Cdm?0P0^;Rh202`/;0809bLW0P0d=3@204A4A080Cdm?0`1I
FET2065QH@80IfMW0P1_Kfl207IfMP@0N7Qh0`1jNWX207emO@80OWin0P20P8020861P@80Ph>30P26
QXH308V9R@80Rh^;0P2=SHd2092@T080Ti>C102EUID309JFUP80V9RH0P2KVi/209jNWP80XJ6Q0P2R
XZ820:FUY@<0YjNW0P2ZZZX40:b/[080Zj^[0P2][Jd20;2`/0<0/k>c0P2d];@20;6a/@80[Zj^0P2]
[Jd20:j^[P80/K6a1@2c/k<20;:b/PP0/K6a0P2`/;030:n_[`80/;2`0P2a/K420;2`/080[jn_0P2/
[:`20:VYZ@<0YjNW0P2UYJD20:6QX@80WIfM0P2JVYX209NGU`80UIFE1@2CTi<209FEU@80Ti>C0P2A
TI4208n?S`80SHf=0`2:RXX208N7Q`80QHF51P24Q8@208>3P`<0PX:21P21PH480<SPf0001P38h=P2
0492@P80<c<c0P0/;2`302l_;`80=3@d0P0c<c<2030`<0@0<C4a0P0^;Rh302`/;080;bl_0P0b<S82
02l_;`H0;2`/0`0Z:RX202TY:@80:2PX0P0c<c<206m_K`80YJFU0P2ATI43071`L080J6QX0P1^KVh2
07YjNP80X:2P0P36a/H20:VYZ@80]KFe0`2l_;`20<30`080`/;20P35aLD20<K6aP80dM7A0P39bLT3
0;:b/P@0<c<c0P0U9BD2038b<P80@T920P1<C4`305ADE080GEeM0P1UIFD206i^KP80MGEe101fMWH3
07UiN@80O7al0P1nOWh207moO`80P8200P21PH4208J6QP<0RXZ:0P2<S8`208f=S@80Shn?0P2BTY82
09JFUP80V9RH1@2GUiL209^KV`H0X:2P0P2TY:@30:RXZ080Zj^[0P2^[Zh20:b/[080ZZZZ0P2][Jd2
0;2`/0<0];Bd0P2e]KD20:n_[`80ZJVY0P2ZZZX20:j^[P80/K6a0`2c/k<20;:b/P80/;2`0P2b/[82
0;Bd]080/K6a1`2^[Zh40:n_[`@0/;2`0P2^[Zh20:^[Z`<0ZJVY0P2WYjL20:>SX`80WinO0P2HV9P4
09>CT`L0U9BD0P2CTi<2096AT@80T92@0P2=SHd308Z:RP80QXJ62025QHD208:2PP<0P8200P22PX82
08B4Q080QHF52038h=P000H0b>3H0P12@T8203<c<`80;2`/0`0_;bl203@d=080<c<c0P0`<304034a
<@80;Rh^0`0/;2`202l_;`80<S8b0P0_;bl602`/;0<0:RXZ0P0Y:BT202PX:080<c<c0P1_Kfl20:FU
Y@80TI6A0`1`L70206QXJ080KVi^0P1jNWX20:2PX080a/K60P2YZJT20;Fe]@<0_;bl0P30`<020<;2
`P80aLG50P36a/H20=7Ad@80bLW90`2b/[8403<c<`809BDU0P0b<S820492@P80C4a<0`1DE5@205eM
G@80IFEU0P1^KVh207EeM@@0MWIf0`1iNGT207alO080OWin0P1oOgl20820P080PH610P26QXH308Z:
RP80S8b<0P2=SHd208n?S`80TY:B0P2FUYH209RHV0D0UiNG0P2KVi/60:2PX080Y:BT0`2XZ:P20:^[
Z`80[Zj^0P2/[:`20:ZZZP80[Jf]0P2`/;030;Bd]080]KFe0P2_[jl20:VYZ@80ZZZZ0P2^[Zh20;6a
/@<0/k>c0P2b/[820;2`/080/[:b0P2d];@20;6a/@L0[Zj^102_[jl40;2`/080[Zj^0P2[Zj/30:VY
Z@80YjNW0P2SXj<209nOW`80V9RH102CTi<709BDU080Ti>C0P2ATI42092@T080SHf=0`2:RXX208J6
QPP0QHF50P22PX830820P080PX:20P24Q8@208F5Q@P0b>3H00060<SPf080DE5A0P0g=cL202HV9P<0
:RXZ0P0d=3@203<c<`80<C4a0P0_;bl202d];@D0;2`/0P0^;Rh2030`<080;Rh^0P0/;2`402d];@<0
:RXZ0P0X:2P202@T9080;Bd]0P1HF5P2092@T080WYjN0`22PX8206QXJ080IVIV0P1^KVh208Z:RP80
^k^k0P2c/k<20:n_[`<0^;Rh0P2l_;`60<71`@80b/[:0P3@d=030<_;b`80Shn?0P0/;2`203Hf=P80
=3@d0P10@40204I6AP<0DE5A0P1KFe/206EUI@80KFe]0P1cLg<407AdM0<0MgMg0P1kNg/207inOPH0
PH610P25QHD308V9R@80Rh^;0P2>SXh2092@T080TY:B0P2FUYH209ZJVPD0VIVI0P2LW9`20:2PX080
XJ6Q0P2RXZ820:FUY@<0Z:RX0P2ZZZX20:b/[080Zj^[0P2ZZZX20:b/[080[jn_0`2a/K420;:b/P80
[Zj^0P2ZZZX20:j^[P80/[:b0P2c/k<30;:b/P80/;2`102_[jl20;2`/080[:b/0P2YZJT20:^[Z`<0
[Jf]0P2_[jl60;6a/@80[jn_0P2/[:`30:RXZ080Y:BT0P2PX:0209bLW080V9RH0P2EUID209>CT`<0
TY:B0P2ATI42092@T080TI6A0P2BTY82092@T080SHf=0`29RHT208J6QP80Q8B40P23Ph<408B4Q080
P8200`1nOWh207moO`80PX:20P21PH480<SPf0001P38h=P2055AD@80=cLg0P0V9RH302XZ:P80=3@d
0P0c<c<2034a<@80;bl_0P0];Bd502`/;080;Rh^0P0`<30202h^;P80;2`/100];Bd302XZ:P80:2PX
0P0T92@202d];@80F5QH0P2@T90209jNWP<0PX:20P1XJ6P206IVIP80KVi^0P2:RXX20;^k^`80/k>c
0P2_[jl30;Rh^080_;bl1P31`L420<[:bP80d=3@0`3;bl/208n?S`80;2`/0P0f=SH203@d=080@410
0P16ATH3055AD@80Fe]K0P1UIFD206e]K@80Lg=c101dM7@307MgM`80Ng]k0P1nOWh60861P@80QHF5
0`29RHT208^;R`80SXj>0P2@T90209:BTP80UYJF0P2JVYX509VIV@80W9bL0P2PX:020:6QX@80XZ:R
0P2UYJD30:RXZ080ZZZZ0P2/[:`20:^[Z`80ZZZZ0P2/[:`20:n_[`<0/K6a0P2b/[820:j^[P80ZZZZ
0P2^[Zh20;:b/P80/k>c0`2b/[820;2`/0@0[jn_0P2`/;020:b/[080ZJVY0P2[Zj/30:f][@80[jn_
1P2a/K420:n_[`80[:b/0`2XZ:P20:BTY080X:2P0P2LW9`209RHV080UIFE0P2CTi<309:BTP80TI6A
0P2@T902096AT@80TY:B0P2@T90208f=S@<0RHV90P26QXH208B4Q080Ph>31024Q8@20820P0<0OWin
0P1oOgl208:2PP80PH612038h=P000H0b>3H0P0h>3P202TY:@808R8R0`0Y:BT403<c<`80<30`0P0/
;2`202TY:@80:RXZ0`0/;2`802d];@@0;Rh^0`0[:b/202TY:@809BDU0P0];Bd204=3@`80LW9b0P2R
XZ8309BDU080L71`0P1QHF4206EUI@80MGEe0P2YZJT20;^k^`80[:b/0`2b/[820;Rh^080`<300P2n
_[h20;fm_@80aLG50P3;bl/30<g=c@80`<300P25QHD202h^;P80<30`0P10@40204E5A@<0CTi>0P1I
FET206ATI080K6a/0P1aLG4207=cL`80M7Ad0`1gMgL207YjNP80OWin1022PX820861P@80Q8B40`28
R8P208^;R`80SXj>0P2@T90209>CT`80UiNG1`2KVi/209fMW@80WinO0P2QXJ420:>SX`80YZJV0`2X
Z:P40:VYZ@80ZZZZ0P2[Zj/20:b/[080[Jf]1@2^[Zh40:f][@80/K6a0P2e]KD20;>c/`<0[jn_0P2^
[Zh20:f][@80[:b/0P2[Zj/20:RXZ080YZJV0P2XZ:P30:b/[080[jn_102a/K420;2`/080[jn_0P2]
[Jd30:NWY`80XJ6Q0P2MWId209VIV@80V9RH0P2GUiL209>CT`<0Shn?0P2<S8`208^;R`80Shn?0P2C
Ti<2092@T080S8b<0`28R8P208F5Q@80Ph>30P21PH4208:2PP80Q8B40P1oOgl507emO@80Ogmo0P1n
OWh80<SPf0001P38h=P203Ph>080:BTY0P0R8R8302TY:@@0<c<c0P0`<30202`/;080:BTY0P0Z:RX3
02`/;0P0;Bd]100^;Rh302/[:`80:BTY0P0U9BD202d];@80@d=30P1bLW820::RXP<0U9BD0P1`L702
065QH@80IFEU0P1eMGD20:VYZ@80^k^k0P2/[:`30;:b/P80^;Rh0P30`<020;jn_P80_Kfm0P35aLD2
0<_;b`<0cLg=0P30`<0208F5Q@80;Rh^0P0`<3020410@080ADE50`1>CTh205UIF@80I6AT0P1/K6`2
075aL@80Lg=c0P1dM7@307MgM`80NWYj0P1nOWh408:2PP80PH610P24Q8@308R8R080Rh^;0P2>SXh2
092@T080Ti>C0P2GUiL709^KV`80WIfM0P2OWil20:6QX@80Xj>S0P2VYZH30:RXZ0@0ZJVY0P2ZZZX2
0:^[Z`80[:b/0P2][Jd50:j^[P@0[Jf]0P2a/K420;Fe]@80/k>c0`2_[jl20:j^[P80[Jf]0P2/[:`2
0:^[Z`80Z:RX0P2VYZH20:RXZ0<0[:b/0P2_[jl40;6a/@80/;2`0P2_[jl20:f][@<0YjNW0P2QXJ42
09fMW@80VIVI0P2HV9P209NGU`80Ti>C0`2?Shl208b<S080Rh^;0P2?Shl209>CT`80T92@0P2<S8`3
08R8R080QHF50P23Ph<20861P@80PX:20P24Q8@207moO`D0OGem0P1oOgl207inOPP0b>3H00060<SP
f080=3@d0P0];Bd202TY:@<0;bl_0P0f=SH2038b<P80;Rh^0P0];Bd202`/;0D0:RXZ0P0/;2`202l_
;`80;Rh^0P0a<C44030`<0<0;Rh^0P0[:b/202l_;`809bLW0P0d=3@2059BDP80RXZ:0`2KVi/208Z:
RP80IVIV0P1UIFD206e]K@80UYJF0P2f][H20;Vi^@<0YjNW0P2c/k<20;jn_P80_kno0P2n_[h20<;2
`P80alO70`3;bl/20<S8b080/k>c0P1RHV8203Ph>080<c<c0P18B4P304e=C@80EeMG0P1QHF4206UY
J@80Kfm_0P1bLW8207AdM0<0N7Qh0P1kNg/207inOP80P8200P21PH4208:2PP80QXJ60`2;Rh/208b<
S080SHf=0P2@T90209BDU080UiNG0P2IVIT309^KV`80W9bL0P2MWId209jNWP80XJ6Q0P2UYJD20:NW
Y`<0Z:RX0P2VYZH20:FUY@80YjNW0P2ZZZX20:b/[080[Zj^1@2_[jl20:f][@80Zj^[0P2/[:`20:f]
[@80[:b/1`2[Zj/20:b/[080[Jf]0P2[Zj/20:ZZZPD0ZJVY0P2ZZZX20:b/[0@0[Jf]0P2/[:`20:^[
Z`<0YjNW0P2RXZ8209fMW@80Vi^K0P2IVIT209JFUP80TI6A0`2<S8`208Z:RP80Rh^;0P2?Shl2096A
T@80SHf=0P28R8P308J6QP80QHF50P23Ph<608:2PP80PH610`20P80207moO`80OWin0P26QXH80<SP
f0001P38h=P203@d=080;Bd]0P0Y:BT302l_;`80=SHf0P0b<S8202h^;P80;Bd]0P0/;2`502XZ:P80
;2`/0P0_;bl202h^;P80<C4a100`<30302h^;P80:b/[0P0_;bl202LW9`80=3@d0P1BDU8208Z:RP<0
Vi^K0P2:RXX206IVIP80IFEU0P1]KFd209JFUP80][Jf0P2i^KT30:NWY`80/k>c0P2n_[h20;no_`80
_[jn0P32`/820<O7a`<0bl_;0P38b<P20;>c/`80HV9R0P0h>3P203<c<`80B4Q80`1=CDd205MGE`80
HF5Q0P1YJFT206m_K`80LW9b0P1dM7@307QhN080Ng]k0P1nOWh20820P080PH610P22PX8208J6QP<0
Rh^;0P2<S8`208f=S@80T92@0P2DU9@209NGU`80VIVI0`2KVi/209bLW080WIfM0P2NWYh20:6QX@80
YJFU0P2WYjL30:RXZ080YZJV0P2UYJD20:NWY`80ZZZZ0P2/[:`20:j^[PD0[jn_0P2][Jd20:^[Z`80
[:b/0P2][Jd20:b/[0L0Zj^[0P2/[:`20:f][@80Zj^[0P2ZZZX50:VYZ@80ZZZZ0P2/[:`40:f][@80
[:b/0P2[Zj/30:NWY`80XZ:R0P2MWId209^KV`80VIVI0P2FUYH2096AT@<0S8b<0P2:RXX208^;R`80
Shn?0P2ATI4208f=S@80R8R80`26QXH208F5Q@80Ph>31P22PX820861P@<0P8200P1oOgl207inOP80
QXJ62038h=P000H0b>3H0P0d=3@202d];@80:BTY0`0_;bl203Hf=P80<S8b0P0^;Rh202d];@80;2`/
1@0Z:RX202`/;080;bl_0P0^;Rh2034a<@@0<30`0`0^;Rh202/[:`80;bl_0P0W9bL203@d=080DU9B
0P2:RXX309^KV`80RXZ:0P1VIVH206EUI@80KFe]0P2FUYH20;Jf]P80^KVi0`2WYjL20;>c/`80_[jn
0P2o_kl20;jn_P80`/;20P37alL30<_;b`80b<S80P2c/k<2069RHP80>3Ph0P0c<c<204Q8B0<0CDe=
0P1GEeL2065QH@80JFUY0P1_Kfl2079bLP80M7Ad0`1hN7P207]kN`80OWin0P20P8020861P@80PX:2
0P26QXH308^;R`80S8b<0P2=SHd2092@T080U9BD0P2GUiL209VIV@<0Vi^K0P2LW9`209fMW@80WYjN
0P2QXJ420:FUY@80YjNW0`2XZ:P20:JVYP80YJFU0P2WYjL20:ZZZP80[:b/0P2^[Zh50:n_[`80[Jf]
0P2[Zj/20:b/[080[Jf]0P2/[:`70:^[Z`80[:b/0P2][Jd20:^[Z`80ZZZZ1@2YZJT20:ZZZP80[:b/
102][Jd20:b/[080Zj^[0`2WYjL20::RXP80WIfM0P2KVi/209VIV@80UYJF0P2ATI4308b<S080RXZ:
0P2;Rh/208n?S`80TI6A0P2=SHd208R8R0<0QXJ60P25QHD208>3P`H0PX:20P21PH430820P080Ogmo
0P1nOWh208J6QPP0b>3H00060<SPf0H0<C4a0`0e=CD203Lg=`80<S8b0P0/;2`202d];@80;bl_0P0[
:b/302PX:080;2`/0P0a<C42038b<P80=3@d0P0c<c<2034a<@<0<30`0P0];Bd203Ph>08092@T0P0Y
:BT203Lg=`80Jf][0`2HV9P20:6QX@80L71`0P1XJ6P206UYJ@80Ph>30P2YZJT20<C4a0<0WinO0P2_
[jl20;bl_0@0_kno0P30`<020<71`@<0a/K60P34a<@20=3@d080Xj>S0P1BDU8202l_;`80BTY:0`1;
Bd/205EEE@80GEeM0P1VIVH206e]K@80LG5a0P1eMGD307QhN080O7al0P1mOGd207moO`80P8200P22
PX8208R8R0<0SXj>0P2=SHd208b<S080T92@0P2EUID209JFUP80V9RH0`2KVi/609fMW@80XZ:R0P2V
YZH20:RXZ0<0ZJVY0P2TY:@20:6QX@80Y:BT0P2YZJT20:b/[0L0[jn_0P2/[:`20:RXZ080YZJV0P2U
YJD20:JVYP<0YjNW0P2XZ:P20:VYZ@80[:b/102_[jl20:j^[P80ZZZZ1@2VYZH20:NWY`80ZJVY102Z
ZZX20:VYZ@<0YjNW0P2TY:@20:2PX080WYjN0P2JVYX209FEU@80SXj>0`29RHT208Z:RP80S8b<0P2>
SXh208n?S`80Rh^;0P26QXH308F5Q@80Q8B41023Ph<208:2PP80PH610P22PX8308>3P`80PH610P1m
OGd208j>SPP0b>3H00060<SPf0H0<C4a0`0e=CD203Lg=`80<S8b0P0/;2`202d];@80;bl_0P0[:b/3
02PX:080;2`/0P0a<C42038b<P80=3@d0P0c<c<2034a<@<0<30`0P0];Bd203Ph>08092@T0P0Y:BT2
03Lg=`80Jf][0`2HV9P20:6QX@80L71`0P1XJ6P206UYJ@80Ph>30P2YZJT20<C4a0<0WinO0P2_[jl2
0;bl_0@0_kno0P30`<020<71`@<0a/K60P34a<@20=3@d080Xj>S0P1BDU8202l_;`80BTY:0`1;Bd/2
05EEE@80GEeM0P1VIVH206e]K@80LG5a0P1eMGD307QhN080O7al0P1mOGd207moO`80P8200P22PX82
08R8R0<0SXj>0P2=SHd208b<S080T92@0P2EUID209JFUP80V9RH0`2KVi/609fMW@80XZ:R0P2VYZH2
0:RXZ0<0ZJVY0P2TY:@20:6QX@80Y:BT0P2YZJT20:b/[0L0[jn_0P2/[:`20:RXZ080YZJV0P2UYJD2
0:JVYP<0YjNW0P2XZ:P20:VYZ@80[:b/102_[jl20:j^[P80ZZZZ1@2VYZH20:NWY`80ZJVY102ZZZX2
0:VYZ@<0YjNW0P2TY:@20:2PX080WYjN0P2JVYX209FEU@80SXj>0`29RHT208Z:RP80S8b<0P2>SXh2
08n?S`80Rh^;0P26QXH308F5Q@80Q8B41023Ph<208:2PP80PH610P22PX8308>3P`80PH610P1mOGd2
08j>SPP0b>3H00060<SPf080;bl_0P0`<302034a<@D0<c<c0P0`<30402`/;080;Bd]0P0[:b/302XZ
:P80;Bd]0P0`<30203/k>`80<30`1`0b<S82030`<080=CDe0P0X:2P202LW9`80;Rh^0P1CDe<30861
P@80Xj>S0P21PH4206YZJP80HV9R0P1aLG4208f=S@80^KVi0`2WYjL20:f][@80]kNg0P2j^[X20;fm
_@80_kno0P30`<030<C4a080a/K60P3Ng]h20<g=c@80XJ6Q0P19BDT203dm?@<0?clo0P1FEUH205YJ
FP80IFEU0P1/K6`2075aL@80M7Ad0`1fMWH207UiN@80O7al0P1oOgl208:2PP80QHF50P28R8P308Z:
RP80S8b<0P2=SHd2096AT@80UIFE0P2GUiL209RHV0<0Vi^K102NWYh209nOW`80XZ:R0P2VYZH20:NW
Y`<0Z:RX0P2TY:@20:6QX@80Y:BT0P2YZJT20:b/[080[jn_0`2^[Zh20:b/[080ZJVY202VYZH50:NW
Y`80Z:RX0P2/[:`20;2`/080[jn_0P2][Jd20:b/[0<0Zj^[0P2YZJT20:RXZ0@0YjNW0P2YZJT20:^[
Z`<0Z:RX0P2RXZ820:ZZZP80X:2P0P2KVi/209BDU080SXj>1@2:RXX208^;R`80SXj>0P2ATI4208f=
S@80R8R80`27QhL208J6QP80Q8B40P23Ph<208:2PP80PH611@22PX820820P080OGem0P2?Shl80<SP
f0001P38h=P202l_;`80<30`0P0a<C4503<c<`80<30`100/;2`202d];@80:b/[0`0Z:RX202d];@80
<30`0P0k>c/2030`<0L0<S8b0P0`<30203De=@80:2PX0P0W9bL202h^;P80De=C0`21PH420:>SX`80
PH610P1ZJVX2069RHP80LG5a0P2=SHd20;Vi^@<0YjNW0P2][Jd20;Ng]`80^[Zj0P2m_Kd20;no_`80
`<300`34a<@20<K6aP80g]kN0P3=cLd20:6QX@80BDU90P0m?Cd303lo?`80EUIF0P1JFUX206EUI@80
K6a/0P1aLG4207AdM0<0MWIf0P1iNGT207alO080Ogmo0P22PX8208F5Q@80R8R80`2:RXX208b<S080
SHf=0P2ATI4209FEU@80UiNG0P2HV9P309^KV`@0WYjN0P2OWil20::RXP80YZJV0P2WYjL30:RXZ080
Y:BT0P2QXJ420:BTY080ZJVY0P2/[:`20:n_[`<0[Zj^0P2/[:`20:VYZ@P0YZJV1@2WYjL20:RXZ080
[:b/0P2`/;020:n_[`80[Jf]0P2/[:`30:^[Z`80ZJVY0P2XZ:P40:NWY`80ZJVY0P2[Zj/30:RXZ080
XZ:R0P2ZZZX20:2PX080Vi^K0P2DU9@208j>SPD0RXZ:0P2;Rh/208j>SP80TI6A0P2=SHd208R8R0<0
QhN70P26QXH208B4Q080Ph>30P22PX820861P@D0PX:20P20P80207emO@80Shn?2038h=P000H0b>3H
1P0^;Rh502l_;`80;Rh^0P0/;2`202/[:`80:RXZ0P0[:b/302d];@@0;bl_0P12@T8202`/;080<30`
0P0b<S8303<c<`80<S8b0P0^;Rh202`/;0809bLW0P0[:b/203dm?@<0I6AT0P2IVIT2096AT@80LG5a
0P1OGel206ATI080LW9b0P2VYZH30:n_[`80[Zj^0P2a/K420;Fe]@80^[Zj0P2m_Kd20<30`0<0a<C4
0P38b<P20<g=c@80b<S80P39bLT207moO`80ADE50`0h>3P205ADE080EeMG0P1SHf<206YZJP80L71`
0P1cLg<307AdM080MGEe0P1jNWX207moO`80Q8B40P28R8P208N7Q`<0QXJ60P2:RXX2092@T080Ti>C
0P2FUYH209NGU`80V9RH0`2KVi/209jNWP@0WinO0P2RXZ820:FUY@D0YZJV0P2TY:@20::RXP80Y:BT
0P2WYjL20:ZZZP80[Jf]0`2ZZZX20:NWY`80Y:BT0P2SXj<20:FUY@80Z:RX0P2VYZH50:FUY@80YjNW
0P2[Zj/20:n_[`80[:b/0P2YZJT20:b/[0<0[jn_0P2][Jd20:VYZ@80YZJV0P2UYJD20:VYZ@80[Jf]
0`2XZ:P20:2PX080/[:b0P2RXZ8209bLW080Ti>C0P2?Shl308^;R`@0RHV90P2=SHd2096AT@80Shn?
0P2;Rh/308V9R@80R8R80P25QHD208>3P`@0PX:20P21PH430820P080Ogmo0P1mOGd208n?S`P0b>3H
00060<SPf0H0;Rh^1@0_;bl202h^;P80;2`/0P0[:b/202XZ:P80:b/[0`0];Bd402l_;`80@T920P0/
;2`2030`<080<S8b0`0c<c<2038b<P80;Rh^0P0/;2`202LW9`80:b/[0P0m?Cd306ATI080VIVI0P2A
TI42075aL@80GemO0P1TI6@2079bLP80YZJV0`2_[jl20:j^[P80/K6a0P2e]KD20;Zj^P80_Kfm0P30
`<030<C4a080b<S80P3=cLd20<S8b080bLW90P1oOgl204E5A@<0>3Ph0P1DE5@205MGE`80Hf=S0P1Z
JVX2071`L080Lg=c0`1dM7@207EeM@80NWYj0P1oOgl208B4Q080R8R80P27QhL308J6QP80RXZ:0P2@
T90209>CT`80UYJF0P2GUiL209RHV0<0Vi^K0P2NWYh409nOW`80XZ:R0P2UYJD50:JVYP80Y:BT0P2R
XZ820:BTY080YjNW0P2ZZZX20:f][@<0ZZZZ0P2WYjL20:BTY080Xj>S0P2UYJD20:RXZ080YZJV1@2U
YJD20:NWY`80Zj^[0P2_[jl20:b/[080ZJVY0P2/[:`30:n_[`80[Jf]0P2YZJT20:JVYP80YJFU0P2Y
ZJT20:f][@<0Z:RX0P2PX:020;:b/P80XZ:R0P2LW9`209>CT`80Shn?0`2;Rh/408V9R@80SHf=0P2A
TI4208n?S`80Rh^;0`29RHT208R8R080QHF50P23Ph<408:2PP80PH610`20P80207moO`80OGem0P2?
Shl80<SPf0001P38h=P202l_;`80;Bd]0P0[:b/302d];@@0;Rh^0P0];Bd202/[:`80:RXZ0P0[:b/3
02`/;080<C4a0P0c<c<203`l?080;Bd]0P0_;bl2030`<0D0<C4a0P0[:b/202PX:08092@T0P0W9bL2
02l_;`<0AdM70P20P80209FEU@80SHf=0P1XJ6P206=SH`80J6QX0P2ATI430:b/[080^KVi0P2][Jd2
0;>c/`80]kNg0P2i^KT20;^k^`<0`<300P35aLD20<W9b@80c<c<0P3Ng]h20;fm_@80R8R80`16ATH2
03lo?`80DE5A0P1KFe/206MWI`80K6a/0P1`L703079bLP80M7Ad0P1hN7P207emO@80Ph>30P28R8P2
08N7Q`<0QXJ60P2;Rh/2092@T080U9BD0P2GUiL209RHV080VIVI0`2JVYX209^KV`80W9bL0P2MWId2
0:2PX080XZ:R1`2SXj<40::RXPH0Xj>S0`2PX:0209fMW@@0W9bL0P2OWil20:6QX@80X:2P0`2OWil2
0:2PX080XZ:R0P2UYJD20:RXZ080YZJV0P2UYJD20:RXZ0D0[:b/0P2[Zj/20:RXZ080YZJV0P2XZ:P2
0:ZZZP<0YJFU0P2PX:020:b/[080YJFU0P2PX:0209NGU`80T92@0`2:RXX208J6QP80QHF50P28R8P2
08b<S080SHf=0P2<S8`308Z:RP80QhN70P23Ph<20820P080PH611022PX830820P080PH610P20P802
096AT@P0b>3H00060<SPf080;bl_0P0];Bd202/[:`<0;Bd]100^;Rh202d];@80:b/[0P0Z:RX202/[
:`<0;2`/0P0a<C4203<c<`80?3`l0P0];Bd202l_;`80<30`1@0a<C4202/[:`80:2PX0P0T92@202LW
9`80;bl_0`17AdL20820P080UIFE0P2=SHd206QXJ080Hf=S0P1XJ6P2096AT@<0[:b/0P2i^KT20:f]
[@80/k>c0P2g]kL20;Vi^@80^k^k0`30`<020<G5a@80bLW90P3<c<`20=kNgP80_Kfm0P28R8P304I6
AP80?clo0P1ADE4205]KF`80IfMW0P1/K6`2071`L0<0LW9b0P1dM7@207QhN080OGem0P23Ph<208R8
R080QhN70`26QXH208^;R`80T92@0P2DU9@209NGU`80V9RH0P2IVIT309ZJVP80Vi^K0P2LW9`209fM
W@80X:2P0P2RXZ870:>SX`@0XZ:R1P2SXj<30:2PX080WIfM102LW9`209nOW`80XJ6Q0P2PX:0309nO
W`80X:2P0P2RXZ820:FUY@80Z:RX0P2VYZH20:FUY@80Z:RX1@2/[:`20:^[Z`80Z:RX0P2VYZH20:RX
Z080ZZZZ0`2UYJD20:2PX080[:b/0P2UYJD20:2PX080UiNG0P2@T90308Z:RP80QXJ60P25QHD208R8
R080S8b<0P2=SHd208b<S0<0RXZ:0P27QhL208>3P`80P8200P21PH4408:2PP<0P8200P21PH420820
P080TI6A2038h=P000H0b>3H0P0_;bl202`/;080:RXZ0`0/;2`602h^;P80;2`/100[:b/302`/;080
<S8b0P0g=cL2038b<P80;bl_0P0^;Rh202d];@<0;bl_0P0`<30202TY:@808b<S0P0R8R8202@T9080
9BDU0`0_;bl2069RHP80T92@0P2TY:@207IfMP80JVYZ0P1UIFD207alO0<0Xj>S0P32`/820:^[Z`80
/K6a0P2b/[820;Bd]080][Jf0`2k^k/20<30`080a/K60P3:b/X20<g=c@80bLW90P2j^[X306QXJ080
?Cdm0P1>CTh205ADE080HV9R0P1WIfL206a/K0<0L71`0P1dM7@207MgM`80Ng]k0P21PH4208J6QPD0
QhN70P2<S8`2096AT@80UIFE0P2HV9P409VIV@<0V9RH0P2GUiL209RHV080VYZJ0P2MWId209nOW`D0
X:2P102QXJ4209nOW`80WIfM0P2KVi/209VIV@<0UYJF0P2CTi<209BDU080UYJF1P2HV9P309NGU`80
VIVI0P2LW9`209jNWP80WinO102PX:020:>SX`<0YJFU0P2XZ:P20:ZZZP80ZJVY0P2WYjL20:JVYP80
YJFU0`2RXZ820:2PX080Xj>S0P2WYjL20:>SX`80W9bL0P2ATI4308R8R080Ph>30P21PH4208>3P`80
QXJ60P2:RXX208b<S0<0RXZ:0P27QhL20861P@80OGem0P20P80208>3P`80PX:20`20P80408:2PP80
TY:B2038h=P000H0b>3H0P0_;bl202`/;080:RXZ0`0/;2`602h^;P80;2`/100[:b/302`/;080<S8b
0P0g=cL2038b<P80;bl_0P0^;Rh202d];@<0;bl_0P0`<30202TY:@808b<S0P0R8R8202@T90809BDU
0`0_;bl2069RHP80T92@0P2TY:@207IfMP80JVYZ0P1UIFD207alO0<0Xj>S0P32`/820:^[Z`80/K6a
0P2b/[820;Bd]080][Jf0`2k^k/20<30`080a/K60P3:b/X20<g=c@80bLW90P2j^[X306QXJ080?Cdm
0P1>CTh205ADE080HV9R0P1WIfL206a/K0<0L71`0P1dM7@207MgM`80Ng]k0P21PH4208J6QPD0QhN7
0P2<S8`2096AT@80UIFE0P2HV9P409VIV@<0V9RH0P2GUiL209RHV080VYZJ0P2MWId209nOW`D0X:2P
102QXJ4209nOW`80WIfM0P2KVi/209VIV@<0UYJF0P2CTi<209BDU080UYJF1P2HV9P309NGU`80VIVI
0P2LW9`209jNWP80WinO102PX:020:>SX`<0YJFU0P2XZ:P20:ZZZP80ZJVY0P2WYjL20:JVYP80YJFU
0`2RXZ820:2PX080Xj>S0P2WYjL20:>SX`80W9bL0P2ATI4308R8R080Ph>30P21PH4208>3P`80QXJ6
0P2:RXX208b<S0<0RXZ:0P27QhL20861P@80OGem0P20P80208>3P`80PX:20`20P80408:2PP80TY:B
2038h=P000H0b>3H0P0[:b/202`/;080;Rh^0`0];Bd202h^;P80;bl_0P0^;Rh202`/;080:b/[0P0]
;Bd3030`<080<S8b0P0d=3@2034a<@80<30`0P0^;Rh702d];@80:BTY100T92@202DU9@80820P0`0T
92@204E5A@80NWYj0P2IVIT208n?S`80MWIf0P1TI6@2079bLP<0T92@0P2m_Kd20;Bd]080[Jf]0P2X
Z:P20:f][@80]KFe0`2g]kL20;^k^`80`<300P36a/H20<W9b@80c/k>0P3Fe]H30:j^[P80MgMg0P17
AdL204U9B@80FUYJ0P1PH60206UYJ@<0Kfm_0P1dM7@207QhN080Ng]k0P20P80208J6QP80QhN70`29
RHT208f=S@80TY:B0P2DU9@209JFUP80VIVI0P2KVi/309ZJVPH0V9RH0P2IVIT209ZJVP80Vi^K1@2L
W9`209^KV`80VIVI0P2GUiL209JFUP80UIFE0`2BTY82092@T080TY:B1P2DU9@209>CT`<0TY:B0P2D
U9@209FEU@80UYJF0P2GUiL209ZJVP80WIfM0P2OWil309jNWP80XZ:R102UYJD20:BTY080YZJV0P2W
YjL30::RXP80WYjN0P2PX:020:FUY@80Y:BT0P2QXJ4209FEU@<0R8R80P23Ph<20861P@80PX:20P25
QHD208R8R080RXZ:0`29RHT208N7Q`80Ph>31020P8020861P@80P8200`1oOgl20861P@80PX:20P2B
TY880<SPf0001P38h=P202/[:`80;2`/0P0^;Rh302d];@80;Rh^0P0_;bl202h^;P80;2`/0P0[:b/2
02d];@<0<30`0P0b<S8203@d=080<C4a0P0`<30202h^;PL0;Bd]0P0Y:BT402@T90809BDU0P0P8203
02@T9080ADE50P1jNWX209VIV@80Shn?0P1fMWH206ATI080LW9b0`2@T9020;fm_@80];Bd0P2][Jd2
0:RXZ080[Jf]0P2e]KD30;Ng]`80^k^k0P30`<020<K6aP80bLW90P3>c/h20=KFeP<0[Zj^0P1gMgL2
04M7A`80BDU90P1JFUX2061PH080JFUY0`1_Kfl207AdM080N7Qh0P1kNg/20820P080QXJ60P27QhL3
08V9R@80SHf=0P2BTY8209BDU080UYJF0P2IVIT209^KV`<0VYZJ1P2HV9P209VIV@80VYZJ0P2KVi/5
09bLW080Vi^K0P2IVIT209NGU`80UYJF0P2EUID309:BTP80T92@0P2BTY8609BDU080Ti>C0`2BTY82
09BDU080UIFE0P2FUYH209NGU`80VYZJ0P2MWId209nOW`<0WYjN0P2RXZ840:FUY@80Y:BT0P2VYZH2
0:NWY`<0XZ:R0P2NWYh20:2PX080YJFU0P2TY:@20:6QX@80UIFE0`28R8P208>3P`80PH610P22PX82
08F5Q@80R8R80P2:RXX308V9R@80QhN70P23Ph<40820P080PH610P20P80307moO`80PH610P22PX82
09:BTPP0b>3H00060<SPf080:BTY0P0/;2`2034a<@T0;bl_0P0];Bd202/[:`80;bl_0`0c<c<2038b
<P80<C4a100`<30202l_;`80;Bd]0`0/;2`202/[:`80:BTY0P0W9bL402HV9P807alO0`0P820202d]
;@80GEeM0P24Q8@20::RXP80QXJ60P1WIfL206a/K0<0Ng]k0P2_[jl20;^k^`80Zj^[0P2OWil20:RX
Z0D0];Bd0P2f][H20;^k^`80`<300P36a/H20<W9b@80cLg=0`36a/H20:BTY080E5AD0P1EEED2055A
D@80FEUI0P1UIFD306e]K@80M7Ad0P1hN7P207]kN`80P8200P24Q8@208N7Q`<0RXZ:0P2>SXh209:B
TP80Ti>C0P2DU9@209RHV080Vi^K0`2JVYX209VIV@80UiNG1P2FUYH509NGU`80UYJF0P2EUID209>C
T`80TY:B0P2CTi<209BDU0<0TI6A0P2>SXh2092@T080Ti>C0P2ATI4208n?S`80SXj>0`2=SHd208j>
SP@0Shn?0P2@T90209BDU080V9RH0P2IVIT309RHV080VYZJ0P2MWId209nOW`80XJ6Q0P2UYJD20:NW
Y`<0XZ:R0P2LW9`209fMW@80X:2P102SXj<209NGU`<0RXZ:0P24Q8@20861P@80PX:20P24Q8@208J6
QPD0R8R80P27QhL208J6QP80Ph>30P21PH4707moO`@0PH610P2BTY880<SPf0001P38h=P202TY:@80
;2`/0P0a<C4902l_;`80;Bd]0P0[:b/202l_;`<0<c<c0P0b<S82034a<@@0<30`0P0_;bl202d];@<0
;2`/0P0[:b/202TY:@809bLW100V9RH201lO7`<0820P0P0];Bd205eMG@80Q8B40P2RXZ8208J6QP80
IfMW0P1/K6`307]kN`80[jn_0P2k^k/20:^[Z`80WinO0P2XZ:P50;Bd]080][Jf0P2k^k/20<30`080
a/K60P39bLT20<g=c@<0a/K60P2TY:@205ADE080EEEE0P1ADE4205UIF@80IFEU0`1]KFd207AdM080
N7Qh0P1kNg/20820P080Q8B40P27QhL308Z:RP80SXj>0P2BTY8209>CT`80U9BD0P2HV9P209^KV`<0
VYZJ0P2IVIT209NGU`H0UYJF1@2GUiL209JFUP80UIFE0P2CTi<209:BTP80Ti>C0P2DU9@3096AT@80
SXj>0P2@T90209>CT`80TI6A0P2?Shl208j>SP<0SHf=0P2>SXh408n?S`80T92@0P2DU9@209RHV080
VIVI0`2HV9P209ZJVP80WIfM0P2OWil20:6QX@80YJFU0P2WYjL30::RXP80W9bL0P2MWId20:2PX0@0
Xj>S0P2GUiL308Z:RP80Q8B40P21PH4208:2PP80Q8B40P26QXH508R8R080QhN70P26QXH208>3P`80
PH611`1oOgl40861P@80TY:B2038h=P000H0b>3H0P0Y:BT202`/;080<C4a2@0_;bl202d];@80:b/[
0P0_;bl303<c<`80<S8b0P0a<C44030`<080;bl_0P0];Bd302`/;080:b/[0P0Y:BT202LW9`@09RHV
0P0O7al3020P8080;Bd]0P1MGEd208B4Q080XZ:R0P26QXH206MWI`80K6a/0`1kNg/20:n_[`80^k^k
0P2[Zj/209nOW`80Z:RX1@2d];@20;Jf]P80^k^k0P30`<020<K6aP80bLW90P3=cLd30<K6aP80Y:BT
0P1DE5@205EEE@80DE5A0P1IFET206EUI@<0KFe]0P1dM7@207QhN080Ng]k0P20P80208B4Q080QhN7
0`2:RXX208j>SP80TY:B0P2CTi<209BDU080V9RH0P2KVi/309ZJVP80VIVI0P2GUiL609JFUPD0UiNG
0P2FUYH209FEU@80Ti>C0P2BTY8209>CT`80U9BD0`2ATI4208j>SP80T92@0P2CTi<2096AT@80Shn?
0P2>SXh308f=S@80SXj>102?Shl2092@T080U9BD0P2HV9P209VIV@<0V9RH0P2JVYX209fMW@80WinO
0P2QXJ420:FUY@80YjNW0`2RXZ8209bLW080WIfM0P2PX:040:>SX`80UiNG0`2:RXX208B4Q080PH61
0P22PX8208B4Q080QXJ61@28R8P208N7Q`80QXJ60P23Ph<20861P@L0Ogmo1021PH4209:BTPP0b>3H
00060<SPf0@0;2`/0P0[:b/303Lg=`80;Rh^100`<30202h^;P80;2`/0P0_;bl3038b<P80<C4a1P0_
;bl4030`<0<0<C4a0P0`<30202/[:`809bLW0P0U9BD202@T90D07alO0P0R8R8203lo?`80Kfm_102J
VYX2071`L080IVIV0`1/K6`209>CT`@0/k>c0P2MWId20:FUY@80[Jf]0`2f][H20;2`/080]KFe0P2k
^k/20<;2`P80b<S80P3:b/X30<c<c080b/[:0P2XZ:P205mOG`80EeMG0P1EEED205QHF0<0Hf=S0P1`
L70207IfMP80NWYj0P1oOgl208>3P`80QHF50`28R8P208^;R`80Shn?0P2BTY8209>CT`@0U9BD0`2E
UID809JFUP80UIFE0P2DU9@309:BTP@0T92@0P2ATI4209:BTP80UIFE0P2FUYH3092@T080RHV90P2=
SHd2092@T080SHf=1`28R8P208J6QP80RHV90P2;Rh/208j>SP80S8b<0P2@T90208b<S0<0Ti>C0P2D
U9@209RHV080Vi^K0P2NWYh40:2PX0<0W9bL0P2HV9P409NGU`80VYZJ0P2LW9`209JFUP<0SXj>0P23
Ph<207]kN`80OGem0P22PX8208F5Q@D0QhN70P25QHD208B4Q080Ph>30P21PH4407moO`<0P8200P22
PX8208>3P`80U9BD2038h=P000H0b>3H100/;2`202/[:`<0=cLg0P0^;Rh4030`<080;Rh^0P0/;2`2
02l_;`<0<S8b0P0a<C4602l_;`@0<30`0`0a<C42030`<080:b/[0P0W9bL202DU9@8092@T1@0O7al2
028R8P80?clo0P1_Kfl409ZJVP80L71`0P1VIVH306a/K080Ti>C102c/k<209fMW@80YJFU0P2][Jd3
0;Jf]P80/;2`0P2e]KD20;^k^`80`/;20P38b<P20<[:bP<0c<c<0P3:b/X20:RXZ080GemO0P1GEeL2
05EEE@80F5QH0`1SHf<2071`L080MWIf0P1jNWX207moO`80Ph>30P25QHD308R8R080Rh^;0P2?Shl2
09:BTP80Ti>C102DU9@309FEU@P0UYJF0P2EUID209BDU0<0TY:B102@T902096AT@80TY:B0P2EUID2
09JFUP<0T92@0P29RHT208f=S@80T92@0P2=SHd708R8R080QXJ60P29RHT208^;R`80SXj>0P2<S8`2
092@T080S8b<0`2CTi<209BDU080V9RH0P2KVi/209jNWP@0X:2P0`2LW9`209RHV0@0UiNG0P2JVYX2
09bLW080UYJF0`2>SXh208>3P`80Ng]k0P1mOGd208:2PP80QHF51@27QhL208F5Q@80Q8B40P23Ph<2
0861P@@0Ogmo0`20P80208:2PP80Ph>30P2DU9@80<SPf0001P38h=P2030`<080:RXZ0P0R8R8303Xj
>P80;Bd]0P0a<C42030`<080;Rh^0P0/;2`202h^;P<0<C4a0P0_;bl202d];@80;Rh^0P0_;bl2034a
<@80=3@d0`0e=CD203@d=080;Rh^0P0W9bL202@T90808R8R1@0P820201lO7`809bLW0P1IFET208F5
Q@80YJFU0P1kNg/206IVIP<0HV9R0P1gMgL20:BTY080^k^k0P2QXJ420:FUY@80YZJV0`2h^;P20:b/
[080/[:b0P2g]kL20;no_`80a/K61`39bLT20;Zj^P80YjNW0P1>CTh205YJFP80CTi>0`1LG5`206][
J`80Lg=c0P1iNGT207inOP80PH610P23Ph<308F5Q@80R8R80P2<S8`2092@T080Ti>C0P2@T90208f=
S@<0Shn?0P2BTY8209BDU080UIFE0P2FUYH209FEU@80TI6A0`2>SXh408b<S080Shn?0P2CTi<209NG
U`80V9RH0`2?Shl208F5Q@80R8R80P2;Rh/208N7Q`80PX:21`20P80208B4Q080R8R80P2<S8`208N7
Q`80QXJ60P1oOgl308n?S`80S8b<0P2>SXh209BDU080WIfM0P2KVi/209RHV0<0UiNG0P2FUYH209>C
T`80T92@0P2BTY8409BDU0<0Shn?0P22PX8207IfMP80NGUi0P20P80208>3P`80QXJ60`25QHD208>3
P`@0PX:20P21PH4407moO`<0P8200P24Q8@208J6QP80UYJF2038h=P000H0b>3H0P0`<30202XZ:P80
8R8R0`0j>SX202d];@80<C4a0P0`<30202h^;P80;2`/0P0^;Rh3034a<@80;bl_0P0];Bd202h^;P80
;bl_0P0a<C4203@d=0<0=CDe0P0d=3@202h^;P809bLW0P0T92@2028R8PD0820P0P0O7al202LW9`80
FEUI0P25QHD20:FUY@80Ng]k0P1VIVH3069RHP80MgMg0P2TY:@20;^k^`80XJ6Q0P2UYJD20:JVYP<0
^;Rh0P2/[:`20;:b/P80]kNg0P2o_kl20<K6aPL0bLW90P2j^[X20:NWY`80CTi>0P1JFUX204i>CP<0
G5aL0P1[Jf/207=cL`80NGUi0P1nOWh20861P@80Ph>30`25QHD208R8R080S8b<0P2@T90209>CT`80
T92@0P2=SHd308n?S`80TY:B0P2DU9@209FEU@80UYJF0P2EUID2096AT@<0SXj>102<S8`208n?S`80
Ti>C0P2GUiL209RHV0<0Shn?0P25QHD208R8R080Rh^;0P27QhL208:2PPL0P8200P24Q8@208R8R080
S8b<0P27QhL208J6QP80Ogmo0`2?Shl208b<S080SXj>0P2DU9@209fMW@80Vi^K0P2HV9P309NGU`80
UYJF0P2CTi<2092@T080TY:B102DU9@308n?S`80PX:20P1fMWH207UiN@80P8200P23Ph<208J6QP<0
QHF50P23Ph<408:2PP80PH61101oOgl30820P080Q8B40P26QXH209JFUPP0b>3H00060<SPf080:RXZ
0P0c<c<203/k>`<0?Shn0P0[:b/202`/;080;Rh^0P0];Bd202`/;080;bl_0`0a<C4202l_;`80;2`/
0P0];Bd2030`<080<c<c1@0e=CD203<c<`80;2`/1P0U9BD202<S8`<08B4Q0P0M7Ad2020P8080?clo
0P1VIVH209:BTP80T92@0P1aLG4305eMG@80JVYZ0P2>SXh20;jn_P80/K6a0P2YZJT209fMW@<0];Bd
0P2[Zj/20;6a/@80][Jf0P2l_;`20<?3``80alO71@3:b/X20<K6aP80`<300P2KVi/204m?C`80Fe]K
0`1IFET206MWI`80Kfm_0P1hN7P207alO080P8200P23Ph<308J6QP80RHV90P2;Rh/208f=S@80T92@
0P2>SXh208b<S0<0SXj>0P2@T90209:BTP80Ti>C0P2BTY82096AT@80T92@0`2?Shl408j>SP80T92@
0P2CTi<209FEU@80U9BD0`2:RXX20820P080OGem1021PH4207moO`80MGEe0`1/K6`208:2PP80P820
1027QhL208Z:RP80MGEe0P1aLG430861P@80RXZ:0P23Ph<2092@T080WYjN0P2IVIT209>CT`<0V9RH
0P2MWId209^KV`80V9RH0P2EUID209>CT`80SXj>0`28R8P207inOP80MWIf0P1hN7P207alO080PH61
1@24Q8@208>3P`@0PX:21021PH450820P080QXJ60P2<S8`209FEU@P0b>3H00060<SPf080:RXZ0P0c
<c<203/k>`<0?Shn0P0[:b/202`/;080;Rh^0P0];Bd202`/;080;bl_0`0a<C4202l_;`80;2`/0P0]
;Bd2030`<080<c<c1@0e=CD203<c<`80;2`/1P0U9BD202<S8`<08B4Q0P0M7Ad2020P8080?clo0P1V
IVH209:BTP80T92@0P1aLG4305eMG@80JVYZ0P2>SXh20;jn_P80/K6a0P2YZJT209fMW@<0];Bd0P2[
Zj/20;6a/@80][Jf0P2l_;`20<?3``80alO71@3:b/X20<K6aP80`<300P2KVi/204m?C`80Fe]K0`1I
FET206MWI`80Kfm_0P1hN7P207alO080P8200P23Ph<308J6QP80RHV90P2;Rh/208f=S@80T92@0P2>
SXh208b<S0<0SXj>0P2@T90209:BTP80Ti>C0P2BTY82096AT@80T92@0`2?Shl408j>SP80T92@0P2C
Ti<209FEU@80U9BD0`2:RXX20820P080OGem1021PH4207moO`80MGEe0`1/K6`208:2PP80P8201027
QhL208Z:RP80MGEe0P1aLG430861P@80RXZ:0P23Ph<2092@T080WYjN0P2IVIT209>CT`<0V9RH0P2M
WId209^KV`80V9RH0P2EUID209>CT`80SXj>0`28R8P207inOP80MWIf0P1hN7P207alO080PH611@24
Q8@208>3P`@0PX:21021PH450820P080QXJ60P2<S8`209FEU@P0b>3H00060<SPf0T0:BTY200[:b/2
02`/;080;bl_0`0b<S8202l_;`80;2`/0P0];Bd2030`<080<c<c0P0f=SH303@d=080<30`0P0[:b/4
02HV9P809bLW0P0U9BD302<S8`807alO0P0P820202PX:080ADE50P1eMGD209jNWP80P8200`1OGel2
069RHP80N7Qh0P2h^;P20<30`080/;2`0P2HV9P30:j^[P80ZZZZ0P2a/K420;Fe]@80^k^k0P30`<02
0<G5a@<0bLW90P38b<P20<G5a@80bLW90P32`/8209ZJVP80DE5A0`1CDe<206IVIP80KVi^0P1eMGD2
07YjNP80OWin0P23Ph<308N7Q`80R8R8102:RXX608b<S0<0SHf=0P2?Shl2092@T080TI6A0P2?Shl2
08j>SP80T92@0`2BTY82096AT@@0T92@0P2?Shl2092@T080SXj>0`25QHD207emO@80Lg=c0P1eMGD2
07YjNP80OGem0P1[Jf/305YJFP80QHF50P1mOGd208J6QP80Ph>30P2@T90206a/K080Kfm_0`1kNg/2
07alO080GUiN0P1mOGd20:6QX@80WIfM0P2CTi<309^KV`80YJFU0P2VYZH20::RXP80W9bL0P2DU9@2
08Z:RP<0PX:20P1lO7`407QhN080NWYj0P1nOWh208:2PPD0Ph>30P22PX820861P@@0PX:21@20P802
08V9R@80TY:B0P2DU9@80<SPf0001P38h=P902TY:@P0:b/[0P0/;2`202l_;`<0<S8b0P0_;bl202`/
;080;Bd]0P0`<30203<c<`80=SHf0`0d=3@2030`<080:b/[100V9RH202LW9`809BDU0`0S8b<201lO
7`80820P0P0X:2P204E5A@80MGEe0P2NWYh20820P0<0GemO0P1RHV8207QhN080^;Rh0P30`<020;2`
/080V9RH0`2^[Zh20:ZZZP80/K6a0P2e]KD20;^k^`80`<300P35aLD30<W9b@80b<S80P35aLD20<W9
b@80`/;20P2JVYX2055AD@<0De=C0P1VIVH206i^KP80MGEe0P1jNWX207inOP80Ph>30`27QhL208R8
R0@0RXZ:1P2<S8`308f=S@80Shn?0P2@T902096AT@80Shn?0P2>SXh2092@T0<0TY:B0P2ATI44092@
T080Shn?0P2@T90208j>SP<0QHF50P1mOGd207=cL`80MGEe0P1jNWX207emO@80Jf][0`1JFUX208F5
Q@80OGem0P26QXH208>3P`80T92@0P1/K6`206m_K`<0Ng]k0P1lO7`205iNGP80OGem0P2QXJ4209fM
W@80Ti>C0`2KVi/20:FUY@80YZJV0P2RXZ8209bLW080U9BD0P2:RXX308:2PP80O7al101hN7P207Yj
NP80OWin0P22PX8508>3P`80PX:20P21PH4408:2PPD0P8200P29RHT209:BTP80U9BD2038h=P000H0
b>3H0P0Z:RX402TY:@<0:2PX0P0[:b/202`/;0@0;Bd]0P0^;Rh202l_;`<0<30`0P0^;Rh402`/;080
;Bd]0P0a<C4203@d=0<0<c<c0P0b<S8202`/;080;Bd]0P0X:2P202DU9@8092@T0`0U9BD2028R8P80
8B4Q0P0O7al202h^;P80FEUI0P2<S8`209JFUP<0LW9b0P1MGEd206IVIP80WinO0P2n_[h20<?3``80
Xj>S0`2ZZZX20:RXZ080[Zj^0P2d];@20;Vi^@80_Kfm0P33`l<30<O7a`P0bLW90P2i^KT209RHV0<0
MWIf0P1LG5`2065QH@80Kfm_0P1fMWH207alO080PH610`24Q8@208F5Q@80Q8B40P2=SHd208F5Q@80
QXJ60P27QhL308^;R`80Shn?102@T90208n?S`80SXj>0P2@T90309:BTP80Shn?0P2;Rh/208N7Q`80
Q8B40P25QHD208Z:RP<0QHF50P1lO7`206m_K`80JVYZ0P1bLW8207YjNP80J6QX0`1FEUH20820P080
OWin0P28R8P208N7Q`80QXJ60P1[Jf/207=cL`<0PH610P1lO7`206MWI`80PX:20P2RXZ820:BTY080
XJ6Q0`2VYZH20:b/[080[Jf]0P2/[:`20:FUY@80W9bL0P2ATI4308N7Q`80Ogmo0P1kNg/207YjNP@0
O7al0P1mOGd307moO`80PH611020P8020861P@80Ph>30P21PH4308:2PP80RXZ:102CTi<80<SPf000
1P38h=P202XZ:P@0:BTY0`0X:2P202/[:`80;2`/100];Bd202h^;P80;bl_0`0`<30202h^;P@0;2`/
0P0];Bd2034a<@80=3@d0`0c<c<2038b<P80;2`/0P0];Bd202PX:0809BDU0P0T92@302DU9@808R8R
0P0Q8B4201lO7`80;Rh^0P1IFET208b<S080UYJF0`1bLW8205eMG@80IVIV0P2OWil20;jn_P80`l?3
0P2SXj<30:ZZZP80Z:RX0P2^[Zh20;Bd]080^KVi0P2m_Kd20<?3``<0alO72039bLT20;Vi^@80V9RH
0`1fMWH205aLG080HF5Q0P1_Kfl207IfMP80O7al0P21PH4308B4Q080QHF50P24Q8@208f=S@80QHF5
0P26QXH208N7Q`<0Rh^;0P2?Shl4092@T080Shn?0P2>SXh2092@T0<0TY:B0P2?Shl208^;R`80QhN7
0P24Q8@208F5Q@80RXZ:0`25QHD207alO080Kfm_0P1ZJVX2079bLP80NWYj0P1XJ6P305IFEP80P820
0P1nOWh208R8R080QhN70P26QXH206][J`80Lg=c0`21PH4207alO080IfMW0P22PX820::RXP80Y:BT
0P2QXJ430:JVYP80[:b/0P2][Jd20:b/[080YJFU0P2LW9`2096AT@<0QhN70P1oOgl207]kN`80NWYj
101lO7`207emO@<0Ogmo0P21PH440820P080PH610P23Ph<20861P@<0PX:20P2:RXX409>CT`P0b>3H
00060<SPf080;2`/0P0Y:BT202DU9@<0:2PX0P0[:b/202h^;PH0<30`0P0_;bl302h^;P@0;bl_0P0]
;Bd202/[:`80;Bd]0P0a<C43038b<P80=3@d0P0_;bl203@d=080:b/[0P0S8b<202@T90<09RHV0P0U
9BD202<S8`8071`L0P0O7al203lo?`80L71`0P2RXZ8308F5Q@80GemO0P1JFUX208B4Q080/k>c0P3@
d=020;>c/`<0ZJVY0P2UYJD20:ZZZP80/[:b0P2g]kL20;^k^`80`<300`34a<@20<W9b@80bl_;0P38
b<P40<?3``80_;bl0`2=SHd205mOG`80GUiN0P1YJFT2075aL@80NWYj0P1nOWh50820P080OWin0P2?
Shl207moO`80PH610P22PX8308V9R@80Shn?102@T90208n?S`80SXj>1@2?Shl208^;R`80QHF50P1l
O7`207IfMP80NWYj0P22PX830861P@80O7al0P1_Kfl206ATI080Kfm_0P1jNWX206YZJP<0Fe]K0P1l
O7`208:2PP80S8b<0P2@T90208j>SP80T92@0P2IVIT30:BTY080VIVI0P2ATI4209JFUP80WinO0P2V
YZH20:b/[0<0[Zj^0P2][Jd40:n_[`80ZJVY0P2PX:0209JFUP<0S8b<0P24Q8@207inOP@0OGem0P1j
NWX207MgM`<0NWYj0P1nOWh407moO`80PH611023Ph<308B4Q080Rh^;0P2BTY8209BDU0P0b>3H0006
0<SPf080;2`/0P0Y:BT202DU9@<0:2PX0P0[:b/202h^;PH0<30`0P0_;bl302h^;P@0;bl_0P0];Bd2
02/[:`80;Bd]0P0a<C43038b<P80=3@d0P0_;bl203@d=080:b/[0P0S8b<202@T90<09RHV0P0U9BD2
02<S8`8071`L0P0O7al203lo?`80L71`0P2RXZ8308F5Q@80GemO0P1JFUX208B4Q080/k>c0P3@d=02
0;>c/`<0ZJVY0P2UYJD20:ZZZP80/[:b0P2g]kL20;^k^`80`<300`34a<@20<W9b@80bl_;0P38b<P4
0<?3``80_;bl0`2=SHd205mOG`80GUiN0P1YJFT2075aL@80NWYj0P1nOWh50820P080OWin0P2?Shl2
07moO`80PH610P22PX8308V9R@80Shn?102@T90208n?S`80SXj>1@2?Shl208^;R`80QHF50P1lO7`2
07IfMP80NWYj0P22PX830861P@80O7al0P1_Kfl206ATI080Kfm_0P1jNWX206YZJP<0Fe]K0P1lO7`2
08:2PP80S8b<0P2@T90208j>SP80T92@0P2IVIT30:BTY080VIVI0P2ATI4209JFUP80WinO0P2VYZH2
0:b/[0<0[Zj^0P2][Jd40:n_[`80ZJVY0P2PX:0209JFUP<0S8b<0P24Q8@207inOP@0OGem0P1jNWX2
07MgM`<0NWYj0P1nOWh407moO`80PH611023Ph<308B4Q080Rh^;0P2BTY8209BDU0P0b>3H00060<SP
f080;2`/0P0X:2P202<S8`<09BDU0P0Y:BT202d];@80<30`0P0a<C42030`<0D0;bl_0P0e=CD203Xj
>P80<c<c0P0_;bl202h^;P80;bl_0`0`<302038b<P80<c<c0P0h>3P202l_;`80:BTY0P0W9bL302HV
9P8092@T0P0S8b<2020P80808R8R0P0a<C42055AD@80RXZ:0`2BTY8207UiN@80EEEE0P1aLG4209VI
V@80`l?30P38b<P30;:b/P80XZ:R0P2UYJD20:f][@80/[:b0P2h^;P20;bl_0<0`<300P37alL20<_;
b`80bLW90P36a/H20<O7a`80a/K60`2][Jd208j>SP80LG5a0P1MGEd206MWI`80MgMg0P1kNg/307al
O0@0OWin0P28R8P20820P0@0Ogmo0`28R8P4096AT@@0T92@0P2?Shl208f=S@<0Rh^;0P26QXH207mo
O`80MGEe0P1[Jf/2079bLP80IFEU0`1YJFT407AdM080Lg=c0P1lO7`208J6QP80SHf=0`2BTY8209ZJ
VP80U9BD0P2JVYX209nOW`80X:2P0P2VYZH20:f][@<0/k>c0P2^[Zh20:^[Z`80/K6a0P2i^KT20<71
`@80`l?30`2b/[8209nOW`80W9bL0P2KVi/2096AT@80Rh^;0P28R8P308N7Q`80Q8B40P22PX8207mo
O`80O7al0P1iNGT207IfMP<0N7Qh0P1lO7`207moO`P0PX:20`23Ph<208b<S080U9BD0P2FUYH80<SP
f0001P38h=P202`/;080:2PX0P0S8b<302DU9@80:BTY0P0];Bd2030`<080<C4a0P0`<30502l_;`80
=CDe0P0j>SX203<c<`80;bl_0P0^;Rh202l_;`<0<30`0P0b<S8203<c<`80>3Ph0P0_;bl202TY:@80
9bLW0`0V9RH202@T90808b<S0P0P8202028R8P80<C4a0P1ADE4208Z:RP<0TY:B0P1iNGT205EEE@80
LG5a0P2IVIT20<?3``80b<S80`2b/[820::RXP80YJFU0P2][Jd20;:b/P80^;Rh0P2l_;`30<30`080
alO70P3;bl/20<W9b@80a/K60P37alL20<K6aP<0[Jf]0P2>SXh2075aL@80GEeM0P1WIfL207MgM`80
Ng]k0`1lO7`407inOP80R8R80P20P80407moO`<0R8R8102ATI44092@T080Shn?0P2=SHd308^;R`80
QXJ60P1oOgl207EeM@80Jf][0P1bLW8206EUI@<0JFUY101dM7@207=cL`80O7al0P26QXH208f=S@<0
TY:B0P2JVYX209BDU080VYZJ0P2OWil20:2PX080YZJV0P2][Jd30;>c/`80[Zj^0P2[Zj/20;6a/@80
^KVi0P31`L420<?3``<0/[:b0P2OWil209bLW080Vi^K0P2ATI4208^;R`80R8R80`27QhL208B4Q080
PX:20P1oOgl207alO080NGUi0P1fMWH307QhN080O7al0P1oOgl808:2PP<0Ph>30P2<S8`209BDU080
UYJF2038h=P000H0b>3H0P0/;2`202PX:0808b<S0`0U9BD202TY:@80;Bd]0P0`<302034a<@80<30`
1@0_;bl203De=@80>SXj0P0c<c<202l_;`80;Rh^0P0_;bl3030`<080<S8b0P0c<c<203Ph>080;bl_
0P0Y:BT202LW9`<09RHV0P0T92@202<S8`80820P0P0R8R82034a<@80DE5A0P2:RXX309:BTP80NGUi
0P1EEED2075aL@80VIVI0P33`l<20<S8b0<0/[:b0P2RXZ820:FUY@80[Jf]0P2b/[820;Rh^080_;bl
0`30`<020<O7a`80bl_;0P39bLT20<K6aP80alO70P36a/H30:f][@80SXj>0P1aLG4205eMG@80IfMW
0P1gMgL207]kN`<0O7al101nOWh208R8R080P820101oOgl308R8R0@0TI6A102@T90208n?S`80SHf=
0`2;Rh/208J6QP80Ogmo0P1eMGD206][J`80LW9b0P1UIFD306UYJ@@0M7Ad0P1cLg<207alO080QXJ6
0P2=SHd309:BTP80VYZJ0P2DU9@209ZJVP80WinO0P2PX:020:JVYP80[Jf]0`2c/k<20:j^[P80Zj^[
0P2a/K420;Vi^@80`L710P33`l<30;:b/P80WinO0P2LW9`209^KV`80TI6A0P2;Rh/208R8R0<0QhN7
0P24Q8@208:2PP80Ogmo0P1lO7`207UiN@80MWIf0`1hN7P207alO080Ogmo2022PX8308>3P`80S8b<
0P2DU9@209JFUPP0b>3H00060<SPf080:b/[0P0W9bL202<S8`<092@T0P0W9bL202`/;080<C4a0P0b
<S82034a<@D0<30`0P0j>SX20492@P80>c/k0P0d=3@202h^;P80:b/[0`0^;Rh2038b<P80=cLg0P0i
>CT203@d=080;Rh^0P0Y:BT302HV9P@08b<S0P0U9BD202TY:@80:RXZ0P0g=cL206QXJ0<0TI6A0P2C
Ti<205YJFP80IFEU0P1kNg/20:^[Z`80dm?C0`2l_;`209nOW`80X:2P0P2WYjL20:j^[P80]KFe0P2i
^KT30;bl_080`l?3103:b/X20<S8b080a/K60P33`l<30<K6aP80_[jn0P2=SHd205iNGP80Hf=S0P1d
M7@207IfMP<0MgMg0P1kNg/207moO`80P8200P22PX8207moO`80OGem0`27QhL4096AT@@0Shn?0P2=
SHd208V9R@<0Ph>30P1mOGd207EeM@80KFe]0P1QHF4206a/K080CTi>0`1EEED206a/K080NWYj0P26
QXH208b<S080T92@0P2EUID309^KV`80WinO0P2TY:@20:VYZ@80[Zj^0P2e]KD20;^k^`80_kno0`31
`L440<G5a@80^;Rh0P2YZJT20:JVYP80Xj>S0`2KVi/209:BTP80Rh^;0P25QHD207YjNP80M7Ad0P1i
NGT30820P080Ph>30P24Q8@20820P080NWYj0P1gMgL207IfMP<0MgMg0P1jNWX207moO`80Q8B40P23
Ph<40861P@<0Ph>30P2<S8`209JFUP80V9RH2038h=P000H0b>3H0P0[:b/202LW9`808b<S0`0T92@2
02LW9`80;2`/0P0a<C42038b<P80<C4a1@0`<30203Xj>P80@T920P0k>c/203@d=080;Rh^0P0[:b/3
02h^;P80<S8b0P0g=cL203Ti>@80=3@d0P0^;Rh202TY:@<09RHV100S8b<202DU9@80:BTY0P0Z:RX2
03Lg=`80J6QX0`2ATI4209>CT`80FUYJ0P1UIFD207]kN`80Zj^[0P3Cdm<30;bl_080WinO0P2PX:02
0:NWY`80[Zj^0P2e]KD20;Vi^@<0_;bl0P33`l<40<[:bP80b<S80P36a/H20<?3``<0a/K60P2n_[h2
08f=S@80GUiN0P1SHf<207AdM080MWIf0`1gMgL207]kN`80Ogmo0P20P80208:2PP80Ogmo0P1mOGd3
08N7Q`@0TI6A102?Shl208f=S@80RHV90`23Ph<207emO@80MGEe0P1]KFd2065QH@80K6a/0P1>CTh3
05EEE@80K6a/0P1jNWX208J6QP80S8b<0P2@T90209FEU@<0Vi^K0P2OWil20:BTY080ZJVY0P2^[Zh2
0;Fe]@80^k^k0P2o_kl30<71`@@0aLG50P2h^;P20:VYZ@80YZJV0P2SXj<309^KV`80TY:B0P2;Rh/2
08F5Q@80NWYj0P1dM7@207UiN@<0P8200P23Ph<208B4Q080P8200P1jNWX207MgM`80MWIf0`1gMgL2
07YjNP80Ogmo0P24Q8@208>3P`@0PH610`23Ph<208b<S080UYJF0P2HV9P80<SPf0001P38h=P602XZ
:P<0:BTY0P0X:2P202d];@80<c<c100d=3@2030`<0<0;Bd]0P0d=3@203/k>`80@4100P0_;bl203De
=@80>SXj0`0d=3@202d];@80<C4a0P0c<c<203Ti>@809bLW1@0X:2P202DU9@@08R8R0P0S8b<202l_
;`80;Rh^0P1JFUX308J6QP80X:2P0P1gMgL4069RHP80RXZ:0P2n_[h30<K6aP80X:2P0P2KVi/20::R
XP80[:b/0P2g]kL20;Rh^0<0^KVi0P2o_kl20<O7a`@0b<S80P37alL20<K6aP<0b<S80P35aLD20:f]
[@80T92@0P1hN7P206UYJ@80M7Ad0`23Ph<20861P@80O7al0P1jNWX407alO080OGem0`26QXH208j>
SP80SHf=0P2>SXh208b<S080R8R80P1nOWh307EeM@80J6QX0P1LG5`405UIF@80IFEU0P1NGUh306][
J`80OWin0P26QXH208V9R@80QXJ60P22PX8208>3P`<0QhN70P2?Shl209fMW@80[Jf]0P2k^k/20<71
`@80`l?30P36a/H30<S8b080bl_;0P3=cLd20<o?c`80c<c<0P2i^KT20:>SX`<0Ti>C0P2:RXX209BD
U080Vi^K0P2BTY8206i^KP80LW9b0`1lO7`20861P@80Ph>30P1mOGd407IfMP80MgMg0`1iNGT207al
O080Ogmo0P21PH4608:2PP<0Q8B40P2<S8`409>CT`P0b>3H00060<SPf0H0:RXZ0`0Y:BT202PX:080
;Bd]0P0c<c<403@d=080<30`0`0];Bd203@d=080>c/k0P10@40202l_;`80=CDe0P0j>SX303@d=080
;Bd]0P0a<C4203<c<`80>CTi0P0W9bL502PX:0809BDU100R8R8202<S8`80;bl_0P0^;Rh205YJFP<0
QXJ60P2PX:0207MgM`@0HV9R0P2:RXX20;jn_P<0a/K60P2PX:0209^KV`80XZ:R0P2/[:`20;Ng]`80
^;Rh0`2i^KT20;no_`80alO71038b<P20<O7a`80a/K60`38b<P20<G5a@80[Jf]0P2@T90207QhN080
JFUY0P1dM7@308>3P`80PH610P1lO7`207YjNP@0O7al0P1mOGd308J6QP80SXj>0P2=SHd208j>SP80
S8b<0P28R8P207inOP<0MGEe0P1XJ6P205aLG0@0FEUI0P1UIFD205iNGP<0Jf][0P1nOWh208J6QP80
RHV90P26QXH208:2PP80Ph>30`27QhL208n?S`80WIfM0P2][Jd20;^k^`80`L710P33`l<20<K6aP<0
b<S80P3;bl/20<g=c@80clo?0P3<c<`20;Vi^@80Xj>S0`2CTi<208Z:RP80U9BD0P2KVi/209:BTP80
KVi^0P1bLW8307alO080PH610P23Ph<207emO@@0MWIf0P1gMgL307UiN@80O7al0P1oOgl20861P@H0
PX:20`24Q8@208b<S0@0Ti>C2038h=P000H0b>3H0P0Y:BT202d];@80<30`0`0];Bd202XZ:P80;Rh^
0P0d=3@203Ti>@80?3`l0P0c<c<302/[:`80;Rh^0P0b<S8204E5A@80;2`/0P0X:2P202<S8`<09RHV
0P0Z:RX202h^;P80;2`/0P0l?3`2020P80809RHV0`0[:b/202LW9`808R8R0P0P820201lO7`80=CDe
0P0_;bl203hn?P<0DU9B0P2<S8`208n?S`80J6QX0P1BDU8206][J`80WinO0`35aLD20::RXP80V9RH
0P2MWId20:ZZZP@0]kNg0`2e]KD20;^k^`80`l?30P36a/H60<O7a`<0a<C40P32`/820<O7a`80`l?3
0P2HV9P206e]K@80JFUY0`1_Kfl207AdM080NGUi0P1hN7P207IfMP80NWYj0P1oOgl308B4Q080RHV9
0P27QhL208Z:RP80QXJ60P1oOgl207=cL`<0IVIV0P1ADE420492@P80ADE50P1ADE42069RHPD0M7Ad
0P1aLG4207emO@80QHF50P1kNg/206e]K@D0IFEU0P1cLg<208V9R@80Xj>S0P2j^[X20<?3``80alO7
0P3:b/X30<c<c080d=3@0P3AdM420<k>cP80b<S80P2n_[h20;2`/0<0VYZJ0P28R8P208Z:RP80S8b<
0P2EUID206i^KP80LW9b0`1jNWX407inOP80NGUi0P1cLg<207AdM080N7Qh0`1jNWX207alO080OGem
0P1nOWh20861P@80Ph>30P24Q8@308J6QP80Rh^;0P2@T902096AT@P0b>3H00060<SPf080:BTY0P0]
;Bd2030`<0<0;Bd]0P0Z:RX202h^;P80=3@d0P0i>CT203`l?080<c<c0`0[:b/202h^;P80<S8b0P15
ADD202`/;080:2PX0P0S8b<302HV9P80:RXZ0P0^;Rh202`/;080?3`l0P0P820202HV9P<0:b/[0P0W
9bL2028R8P80820P0P0O7al203De=@80;bl_0P0n?Sh3059BDP80S8b<0P2?Shl206QXJ080DU9B0P1[
Jf/209nOW`<0aLG50P2RXZ8209RHV080WIfM0P2ZZZX40;Ng]`<0]KFe0P2k^k/20<?3``80a/K61P37
alL30<C4a080`/;20P37alL20<?3``80V9RH0P1]KFd206UYJ@<0Kfm_0P1dM7@207UiN@80N7Qh0P1f
MWH207YjNP80Ogmo0`24Q8@208V9R@80QhN70P2:RXX208J6QP80Ogmo0P1cLg<306IVIP80DE5A0P12
@T8204E5A@80DE5A0P1RHV8507AdM080LG5a0P1mOGd208F5Q@80Ng]k0P1]KFd506EUI@80Lg=c0P29
RHT20:>SX`80^[Zj0P33`l<20<O7a`80b/[:0`3<c<`20=3@d080dM7A0P3>c/h20<S8b080_[jn0P2`
/;0309ZJVP80R8R80P2:RXX208b<S080UIFE0P1^KVh2079bLP<0NWYj101nOWh207UiN@80Lg=c0P1d
M7@207QhN0<0NWYj0P1lO7`207emO@80OWin0P21PH4208>3P`80Q8B40`26QXH208^;R`80T92@0P2A
TI480<SPf0001P38h=P20492@P80>3Ph0P0[:b/302TY:@80:RXZ0P0];Bd203De=@80ADE50P1FEUH2
0492@P<0:BTY0P0[:b/2038b<P80?Cdm0P0_;bl202`/;080:2PX0`0Y:BT202/[:`80;bl_0P0a<C42
03Lg=`809BDU0P0X:2P302/[:`80:2PX100T92@202DU9@80<C4a0P0];Bd202l_;`<0>c/k0P1bLW82
09RHV080Q8B40P1CDe<205MGE`80Ogmo0`2b/[820;^k^`80Y:BT0P2CTi<209jNWP80[Jf]0P2_[jl3
0;2`/080_[jn0P2m_Kd20<?3``80alO71038b<P30<K6aP80a<C41039bLT20;Bd]080VIVI0P1mOGd3
06MWI`80JVYZ0P1dM7@207IfMP80N7Qh0P1lO7`508:2PP@0P8200P22PX8207alO080LW9b0P1^KVh3
05EEE@80@4100P0a<C4203Lg=`80BTY:0P1LG5`2071`L0<0MWIf0P1jNWX207MgM`80Kfm_0P1NGUh2
04i>CP80ATI60`15ADD204i>CP80H61P0P22PX820:FUY@80_[jn103=cLd30<k>cP80d=3@0P3AdM42
0=3@d080c<c<0P34a<@20;Vi^@<0YZJV0P2BTY8208Z:RP80PH610P20P80206IVIP80NGUi0`1lO7`2
07UiN@80Lg=c0P1aLG4207=cL`80MgMg0P1jNWX307UiN@80MgMg0P1kNg/207moO`80PX:20P25QHD2
08N7Q`<0RHV90P2=SHd2096AT@80VYZJ2038h=P000H0b>3H0P12@T8203Ph>080:b/[0`0Y:BT202XZ
:P80;Bd]0P0e=CD204E5A@80EUIF0P12@T8302TY:@80:b/[0P0b<S8203dm?@80;bl_0P0/;2`202PX
:0<0:BTY0P0[:b/202l_;`80<C4a0P0g=cL202DU9@80:2PX0`0[:b/202PX:0@092@T0P0U9BD2034a
<@80;Bd]0P0_;bl303/k>`80LW9b0P2HV9P208B4Q080De=C0P1GEeL207moO`<0/[:b0P2k^k/20:BT
Y080Ti>C0P2NWYh20:f][@80[jn_0`2`/;020;jn_P80_Kfm0P33`l<20<O7a`@0b<S80`36a/H20<C4
a0@0bLW90P2d];@209VIV@80OGem0`1WIfL206YZJP80M7Ad0P1fMWH207QhN080O7al1@22PX840820
P080PX:20P1lO7`2079bLP80KVi^0`1EEED20410@080<C4a0P0g=cL204Y:BP80G5aL0P1`L70307If
MP80NWYj0P1gMgL206m_K`80GUiN0P1>CTh204I6AP<0ADE50P1>CTh2061PH080PX:20P2UYJD20;jn
_P@0cLg=0`3>c/h20=3@d080dM7A0P3@d=020<c<c080a<C40P2i^KT30:JVYP80TY:B0P2:RXX20861
P@80P8200P1VIVH207UiN@<0O7al0P1iNGT207=cL`80LG5a0P1cLg<207MgM`80NWYj0`1iNGT207Mg
M`80Ng]k0P1oOgl208:2PP80QHF50P27QhL308V9R@80SHf=0P2ATI4209ZJVPP0b>3H00060<SPf080
=SHf0P0_;bl502LW9`80:BTY0P0];Bd203Hf=P80EEEE0P1_Kfl2051@D0<0:BTY0P0Z:RX4038b<P80
<c<c0P0_;bl502/[:`80;Bd]0P0c<c<203Lg=`80<C4a0P0/;2`502XZ:P80:2PX0P0W9bL202PX:0@0
:b/[0P0/;2`202LW9`<0:b/[0P14A4@207=cL`80RXZ:0P1OGel205=CD`80IVIV0`25QHD20:FUY@80
WIfM0P2ATI4209RHV080Xj>S0P2WYjL30:RXZ080_[jn0P2e]KD20;no_`80a/K61038b<P30<O7a`80
a/K60P34a<@20<?3``80bLW90P36a/H209NGU`<0JFUY0P1UIFD206m_K`80Lg=c0P1hN7P207inOP80
Ph>30`1mOGd407IfMP80MGEe0P1_Kfl206=SH`80IVIV0`15ADD2038b<P809BDU0P0_;bl204=3@`80
EeMG0P1YJFT307IfMP80O7al0P1/K6`205IFEP80A4A40P0h>3P203De=@D0=cLg0P0n?Sh204e=C@80
IVIV0P2KVi/20<[:bP80d=3@0`3>c/h40=3@d080c/k>0P3:b/X20<S8b080`/;20`2b/[8209fMW@80
QHF50P1`L70206ATI080H61P0P21PH4307alO080Lg=c0P1WIfL206][J`80Lg=c0P1hN7P207]kN`<0
MWIf0P1bLW8207QhN080P8200P24Q8@208J6QP80RHV90`2;Rh/2092@T080TY:B0P2TY:@80<SPf000
1P38h=P203Hf=P80;bl_1@0W9bL202TY:@80;Bd]0P0f=SH205EEE@80Kfm_0P1@D50302TY:@80:RXZ
100b<S8203<c<`80;bl_1@0[:b/202d];@80<c<c0P0g=cL2034a<@80;2`/1@0Z:RX202PX:0809bLW
0P0X:2P402/[:`80;2`/0P0W9bL302/[:`80A4A40P1cLg<208Z:RP80GemO0P1CDe<206IVIP<0QHF5
0P2UYJD209fMW@80TI6A0P2HV9P20:>SX`80YjNW0`2XZ:P20;jn_P80]KFe0P2o_kl20<K6aP@0b<S8
0`37alL20<K6aP80a<C40P33`l<20<W9b@80a/K60P2GUiL306UYJ@80IFEU0P1_Kfl207=cL`80N7Qh
0P1nOWh208>3P`<0OGem101fMWH207EeM@80Kfm_0P1SHf<206IVIP<0ADE50P0b<S8202DU9@80;bl_
0P13@d<205MGE`80JFUY0`1fMWH207alO080K6a/0P1FEUH204A4A080>3Ph0P0e=CD503Lg=`80?Shn
0P1=CDd206IVIP80Vi^K0P3:b/X20=3@d0<0c/k>103@d=020<k>cP80b/[:0P38b<P20<;2`P<0/[:b
0P2MWId208F5Q@80L71`0P1TI6@2061PH080PH610`1lO7`207=cL`80IfMW0P1[Jf/207=cL`80N7Qh
0P1kNg/307IfMP80LW9b0P1hN7P20820P080Q8B40P26QXH208V9R@<0Rh^;0P2@T90209:BTP80Y:BT
2038h=P000H0b>3H0P0g=cL202l_;`809bLW0`0V9RH202PX:080<30`0P0i>CT206YZJP80MGEe0P1@
D503038b<P80;2`/0P0^;Rh202d];@80;bl_0P0];Bd202`/;0<0:b/[0P0/;2`203<c<`80>CTi0P0`
<30202XZ:P80:2PX1`0Y:BT402PX:0809bLW0P0Y:BT202<S8`<092@T0P0e=CD205]KF`80O7al0P1b
LW8205aLG080FEUI0`1gMgL209fMW@80/k>c0P2TY:@209fMW@L0VYZJ0P2[Zj/20:f][@80][Jf0P2m
_Kd20<?3``80alO71@39bLT20<K6aP80a<C4103:b/X20;>c/`<0UiNG0P1jNWX206EUI@80J6QX0P1a
LG4207moO`80N7Qh0`1bLW8206YZJP80IfMW0P1SHf<205aLG080De=C0P1=CDd303Ph>0@0=3@d0P1=
CDd205=CD`80HV9R0P1/K6`307alO080LG5a0P1FEUH203lo?`80@D510P1;Bd/205IFEP<0GUiN0P1C
De<204M7A`80>c/k0P15ADD206i^KP80YjNW0P3@d=030<k>cP80d];B0P3AdM420<o?c`@0cLg=0P39
bLT30;Jf]P80WinO0P1jNWX205]KF`80EEEE0P1QHF4208>3P`<0LW9b0P1YJFT205mOG`@0Kfm_0P1c
Lg<207EeM@D0M7Ad0P1iNGT207inOP80Ph>30P26QXH208R8R0<0RXZ:0P2@T90209FEU@80WYjN2038
h=P000H0b>3H0P0g=cL202l_;`809bLW0`0V9RH202PX:080<30`0P0i>CT206YZJP80MGEe0P1@D503
038b<P80;2`/0P0^;Rh202d];@80;bl_0P0];Bd202`/;0<0:b/[0P0/;2`203<c<`80>CTi0P0`<302
02XZ:P80:2PX1`0Y:BT402PX:0809bLW0P0Y:BT202<S8`<092@T0P0e=CD205]KF`80O7al0P1bLW82
05aLG080FEUI0`1gMgL209fMW@80/k>c0P2TY:@209fMW@L0VYZJ0P2[Zj/20:f][@80][Jf0P2m_Kd2
0<?3``80alO71@39bLT20<K6aP80a<C4103:b/X20;>c/`<0UiNG0P1jNWX206EUI@80J6QX0P1aLG42
07moO`80N7Qh0`1bLW8206YZJP80IfMW0P1SHf<205aLG080De=C0P1=CDd303Ph>0@0=3@d0P1=CDd2
05=CD`80HV9R0P1/K6`307alO080LG5a0P1FEUH203lo?`80@D510P1;Bd/205IFEP<0GUiN0P1CDe<2
04M7A`80>c/k0P15ADD206i^KP80YjNW0P3@d=030<k>cP80d];B0P3AdM420<o?c`@0cLg=0P39bLT3
0;Jf]P80WinO0P1jNWX205]KF`80EEEE0P1QHF4208>3P`<0LW9b0P1YJFT205mOG`@0Kfm_0P1cLg<2
07EeM@D0M7Ad0P1iNGT207inOP80Ph>30P26QXH208R8R0<0RXZ:0P2@T90209FEU@80WYjN2038h=P0
00H0b>3H0P0c<c<202h^;P80:BTY0`0V9RH202LW9`80=3@d0P11@D4207emO@80LG5a0P1:BTX303`l
?080;bl_0P0Z:RX202TY:@80:RXZ0P0[:b/202`/;0<0:RXZ0P0[:b/203<c<`80>3Ph0P0a<C4402LW
9`<0:2PX0P0Y:BT202XZ:P809bLW100U9BD202HV9P8092@T0`0U9BD2030`<080@d=30P1UIFD20861
P@80KFe]0P1IFET3071`L080S8b<0P31`L420;Zj^P80[:b/0P2NWYh209BDU0<0T92@0P2IVIT20:NW
Y`80[Zj^0P2e]KD20;fm_@80aLG50`39bLT20<c<c080bLW91P35aLD20<[:bP<0a/K60P2FUYH206IV
IP80HF5Q0P1WIfL207YjNP80K6a/0`1WIfL205mOG`80F5QH0P1@D50204Y:BP80@d=30P0h>3P3030`
<080:RXZ0P0X:2P204M7A`80@d=30P1NGUh2075aL@<0P8200P1NGUh204=3@`80=SHf0P1<C4`206AT
I080GEeM0`1BDU8205EEE@80EUIF0P0n?Sh203De=@80ATI60P1lO7`20<[:bP<0c/k>0P3De=@40=3@
d080c/k>0P3?cll20<[:bP<0];Bd0P2GUiL206][J`80BDU90P1=CDd206IVIP80PX:20`1VIVH2061P
H080GEeM0P1eMGD206a/K0@0Kfm_0`1cLg<207MgM`80NWYj0P1mOGd208:2PP80QXJ60P27QhL308R8
R080T92@102GUiL80<SPf0001P38h=P203<c<`80;Rh^0P0Y:BT302HV9P809bLW0P0d=3@20451@@80
OGem0P1aLG4204Y:BP<0?3`l0P0_;bl202XZ:P80:BTY0P0Z:RX202/[:`80;2`/0`0Z:RX202/[:`80
<c<c0P0h>3P2034a<@@09bLW0`0X:2P202TY:@80:RXZ0P0W9bL402DU9@809RHV0P0T92@302DU9@80
<30`0P13@d<206EUI@80PH610P1]KFd205UIF@<0L71`0P2<S8`20<71`@80^[Zj0P2/[:`209jNWP80
U9BD0`2@T90209VIV@80YjNW0P2^[Zh20;Fe]@80_Kfm0P35aLD30<W9b@80c<c<0P39bLT60<G5a@80
b/[:0`36a/H209JFUP80IVIV0P1QHF4206MWI`80NWYj0P1/K6`306MWI`80GemO0P1HF5P2051@D080
BTY:0P13@d<203Ph>0<0<30`0P0Z:RX202PX:080AdM70P13@d<205iNGP80LG5a0`20P80205iNGP80
@d=30P0f=SH204a<C080I6AT0P1MGEd3059BDP80EEEE0P1FEUH203hn?P80=CDe0P16ATH207alO080
b/[:0`3>c/h20=CDe0@0d=3@0P3>c/h20<o?c`80b/[:0`2d];@209NGU`80Jf][0P19BDT204e=C@80
IVIV0P22PX8306IVIP80H61P0P1MGEd207EeM@80K6a/101_Kfl307=cL`80MgMg0P1jNWX207emO@80
PX:20P26QXH208N7Q`<0R8R80P2@T90409NGU`P0b>3H00060<SPf080<c<c0P0^;Rh202TY:@<09RHV
0P0W9bL203@d=080@D510P1mOGd2075aL@80BTY:0`0l?3`202l_;`80:RXZ0P0Y:BT202XZ:P80:b/[
0P0/;2`302XZ:P80:b/[0P0c<c<203Ph>080<C4a100W9bL302PX:080:BTY0P0Z:RX202LW9`@09BDU
0P0V9RH202@T90<09BDU0P0`<30204=3@`80IFEU0P21PH4206e]K@80FEUI0`1`L70208b<S080`L71
0P2j^[X20:b/[080WYjN0P2DU9@3092@T080VIVI0P2WYjL20:j^[P80]KFe0P2m_Kd20<G5a@<0bLW9
0P3<c<`20<W9b@H0aLG50P3:b/X30<K6aP80UYJF0P1VIVH2065QH@80IfMW0P1jNWX206a/K0<0IfMW
0P1OGel205QHF080D51@0P1:BTX204=3@`80>3Ph0`0`<30202XZ:P80:2PX0P17AdL204=3@`80GUiN
0P1aLG430820P080GUiN0P13@d<203Hf=P80C4a<0P1TI6@205eMG@<0DU9B0P1EEED205IFEP80?Shn
0P0e=CD204I6AP80O7al0P3:b/X30<k>cP80e=CD103@d=020<k>cP80clo?0P3:b/X30;Bd]080UiNG
0P1[Jf/204U9B@80CDe=0P1VIVH208:2PP<0IVIV0P1PH60205eMG@80MGEe0P1/K6`406m_K`<0Lg=c
0P1gMgL207YjNP80OGem0P22PX8208J6QP80QhN70`28R8P2092@T0@0UiNG2038h=P000H0b>3H0P0[
:b/203@d=080:b/[1@0W9bL203De=@80DE5A0P2:RXX205QHF080?Cdm0`0n?Sh2034a<@80:BTY0P0V
9RH202LW9`80:BTY1`0/;2`203<c<`80=cLg0P0a<C4202XZ:P809bLW0`0V9RH203@d=080?clo0P0e
=CD202XZ:P@09RHV0P0Y:BT303<c<`80BTY:0P1=CDd206QXJ080TI6A0P2EUID2071`L0<0IVIV0P1a
LG420:ZZZP80a<C40P2o_kl20:BTY080YZJV0`2`/;040:j^[P80/[:b0P2g]kL20;Zj^P80_[jn0`36
a/H20<g=c@80bl_;0P38b<P40<O7a`80cLg=0`3;bl/20;6a/@80Shn?0P1/K6`205EEE@80I6AT0P1W
IfL3065QH@80EUIF0P1<C4`20451@@80?3`l0P0g=cL2030`<0<0;Rh^0P0/;2`202h^;P80@d=30P16
ATH205mOG`80KVi^0`1_Kfl204=3@`80ATI60P1MGEd205iNGP80FEUI0P19BDT303dm?@80C4a<0P1L
G5`206e]K@80Bd];0P0o?cl2059BDP80];Bd0`3;bl/20=;BdP80bl_;103>c/h20<W9b@80`<300`2[
Zj/207inOP80Fe]K0P14A4@205QHF080NWYj0P1iNGT305]KF`80GemO0P1WIfL207IfMP80LG5a0P1`
L70206m_K`<0MGEe0P1lO7`207moO`80P8200P24Q8@208N7Q`80RHV90`2;Rh/208j>SP80TI6A0P2K
Vi/80<SPf0001P38h=P202/[:`80=3@d0P0[:b/502LW9`80=CDe0P1ADE4208Z:RP80F5QH0P0m?Cd3
03hn?P80<C4a0P0Y:BT202HV9P809bLW0P0Y:BT702`/;080<c<c0P0g=cL2034a<@80:RXZ0P0W9bL3
02HV9P80=3@d0P0o?cl203De=@80:RXZ100V9RH202TY:@<0<c<c0P1:BTX204e=C@80J6QX0P2ATI42
09FEU@80L71`0`1VIVH2075aL@80ZZZZ0P34a<@20;no_`80Y:BT0P2VYZH30;2`/0@0[Zj^0P2b/[82
0;Ng]`80^[Zj0P2n_[h30<K6aP80cLg=0P3;bl/20<S8b0@0alO70P3=cLd30<_;b`80/K6a0P2?Shl2
06a/K080EEEE0P1TI6@206MWI`<0HF5Q0P1FEUH204a<C080@D510P0l?3`203Lg=`80<30`0`0^;Rh2
02`/;080;Rh^0P13@d<204I6AP80GemO0P1^KVh306m_K`80@d=30P16ATH205eMG@80GUiN0P1IFET2
04U9B@<0?Cdm0P1<C4`205aLG080KFe]0P1;Bd/203lo?`80DU9B0P2d];@30<_;b`80d];B0P3;bl/4
0<k>cP80bLW90P30`<030:^[Z`80OWin0P1KFe/204A4A080F5QH0P1jNWX207UiN@<0Fe]K0P1OGel2
06MWI`80MWIf0P1aLG42071`L080Kfm_0`1eMGD207alO080Ogmo0P20P80208B4Q080QhN70P29RHT3
08^;R`80SXj>0P2ATI4209^KV`P0b>3H00060<SPf08092@T0P0i>CT202`/;0<0:2PX0P0Y:BT203Ph
>080HV9R0P2BTY8204=3@`80<c<c0`0l?3`2038b<P80:RXZ0P0V9RH202DU9@80:2PX0P0/;2`302d]
;@80;Rh^0P0b<S8203Hf=P80<c<c0P0^;Rh202/[:`<0:BTY0P0/;2`2030`<080<S8b0P0d=3@202XZ
:P8092@T0P0a<C430492@P80CDe=0P0_;bl203/k>`80Jf][0P2PX:0208f=S@<0JFUY0P1JFUX208^;
R`80`L710P3AdM420:n_[`80YZJV0`2][Jd20;:b/P80^;Rh0P2i^KT20;Zj^P@0]kNg0`32`/820<c<
c080cLg=103:b/X40<W9b@<0a/K60P35aLD20;Rh^080Ogmo0P1@D50205=CD`80HF5Q0`1KFe/2055A
D@80ADE50P0i>CT203@d=080<S8b0P0_;bl502h^;P80<C4a0P0i>CT204I6AP80G5aL0P1WIfL305eM
G@80:RXZ0P0h>3P205eMG@80EeMG0P19BDT203De=@<09BDU0P0];Bd203/k>`80LG5a0P15ADD203De
=@80>c/k0P2SXj<30<O7a`80clo?0P34a<@40<W9b@80_kno0P2/[:`309NGU`80H61P0P1:BTX20492
@P80I6AT0P25QHD206a/K0<0DE5A0P1PH60207EeM@@0MgMg0P1cLg<2075aL@<0N7Qh0P21PH4208>3
P`80Q8B40P27QhL208Z:RP80S8b<1@2>SXh208^;R`80WYjN2038h=P000H0b>3H0P0T92@203Ti>@80
;2`/0`0X:2P202TY:@80>3Ph0P1RHV8209:BTP80@d=30P0c<c<303`l?080<S8b0P0Z:RX202HV9P80
9BDU0P0X:2P202`/;0<0;Bd]0P0^;Rh2038b<P80=SHf0P0c<c<202h^;P80:b/[0`0Y:BT202`/;080
<30`0P0b<S8203@d=080:RXZ0P0T92@2034a<@<0@T920P1=CDd202l_;`80>c/k0P1[Jf/20:2PX080
SHf=0`1YJFT205YJFP80Rh^;0P31`L420=7Ad@80[jn_0P2VYZH30:f][@80/[:b0P2h^;P20;Vi^@80
^[Zj102g]kL30<;2`P80c<c<0P3=cLd40<[:bP@0bLW90`36a/H20<G5a@80^;Rh0P1oOgl2051@D080
De=C0P1QHF4305]KF`80DE5A0P15ADD203Ti>@80=3@d0P0b<S8202l_;`D0;Rh^0P0a<C4203Ti>@80
ATI60P1LG5`206MWI`<0GEeM0P0Z:RX203Ph>080GEeM0P1GEeL204U9B@80=CDe0`0U9BD202d];@80
>c/k0P1aLG4204E5A@80=CDe0P0k>c/20:>SX`<0alO70P3?cll20<C4a0@0bLW90P2o_kl20:b/[0<0
UiNG0P1PH60204Y:BP80@T920P1TI6@208F5Q@80K6a/0`1ADE42061PH080MGEe101gMgL207=cL`80
LG5a0`1hN7P20861P@80Ph>30P24Q8@208N7Q`80RXZ:0P2<S8`508j>SP80Rh^;0P2NWYh80<SPf000
1P38h=P202TY:@80<c<c0P0/;2`302HV9P80;2`/0P10@402079bLP80P8200P0e=CD202d];@<0=3@d
0P0`<30202d];@80:RXZ0P0X:2P202XZ:PD0;Bd]0P0^;Rh2030`<080<C4a0P0`<302034a<@D0:RXZ
0P0e=CD20410@080Bd];0P11@D4203dm?@80>c/k0P0`<30302LW9`80;Bd]0P0R8R8202d];@80D51@
0P2=SHd209^KV`<0QHF50P1JFUX2079bLP80W9bL0P38b<P20;bl_080[Zj^0`2YZJT20:j^[P80];Bd
0P2f][H20;Ng]`@0]KFe0`2k^k/20<?3``80bLW90P3=cLd20<_;b`80alO71@35aLD40=3@d080/[:b
0P1cLg<205MGE`80Cdm?0`1BDU8205IFEP80C4a<0P12@T8203/k>`80=CDe0P0^;Rh502/[:`80;bl_
0P0d=3@203hn?P80CTi>0P1GEeL305QHF080<c<c0P0m?Cd2055AD@80AdM70P0i>CT202XZ:P<08R8R
0P0V9RH203/k>`80Hf=S0P10@40203dm?@80B4Q80P2UYJD30<_;b`80dM7A0P33`l<20<;2`P80^[Zj
0P2d];@208N7Q`<0K6a/0P12@T8203Xj>P80?3`l0P1NGUh206QXJ080EEEE0`1<C4`2069RHP80Ng]k
0P1lO7`207YjNP80MWIf0P1dM7@307YjNP80PH610P24Q8@208J6QP80R8R80P2;Rh/208j>SP<0T92@
0P2ATI42092@T080VYZJ2038h=P000H0b>3H0P0Y:BT203<c<`80;2`/0`0V9RH202`/;080@4100P1b
LW820820P080=CDe0P0];Bd303@d=080<30`0P0];Bd202XZ:P80:2PX0P0Z:RX502d];@80;Rh^0P0`
<302034a<@80<30`0P0a<C4502XZ:P80=CDe0P10@40204];B`80@D510P0m?Cd203/k>`80<30`0`0W
9bL202d];@808R8R0P0];Bd2051@D080SHf=0P2KVi/308F5Q@80FUYJ0P1bLW8209bLW080b<S80P2l
_;`20:j^[P<0ZJVY0P2^[Zh20;Bd]080][Jf0P2g]kL40;Fe]@<0^k^k0P33`l<20<W9b@80cLg=0P3;
bl/20<O7a`D0aLG5103@d=020;:b/P80Lg=c0P1GEeL204m?C`<0DU9B0P1FEUH204a<C080@T920P0k
>c/203De=@80;Rh^1@0[:b/202l_;`80=3@d0P0n?Sh204i>CP80EeMG0`1HF5P203<c<`80?Cdm0P1A
DE4204M7A`80>CTi0P0Z:RX3028R8P809RHV0P0k>c/206=SH`80@4100P0m?Cd204Q8B080YJFU0`3;
bl/20=7Ad@80`l?30P32`/820;Zj^P80];Bd0P27QhL306a/K080@T920P0j>SX203`l?080GUiN0P1X
J6P205EEE@<0C4a<0P1RHV8207]kN`80O7al0P1jNWX207IfMP80M7Ad0`1jNWX20861P@80Q8B40P26
QXH208R8R080Rh^;0P2>SXh3092@T080TI6A0P2@T90209ZJVPP0b>3H00060<SPf080<30`100^;Rh3
02PX:080;bl_0P1;Bd/207moO`80JFUY0P0/;2`202XZ:P<0;Bd]0P0^;Rh202l_;`80;Rh^100/;2`7
02d];@80<30`0P0b<S8203@d=080=cLg0P0_;bl3034a<@80?3`l0P18B4P205iNGP80BTY:0P0f=SH2
02DU9@808R8R0`0S8b<401dM7@808b<S0P0c<c<206a/K080WIfM0`2PX:0206IVIP80HV9R0P1cLg<2
0;Fe]@80a<C40P2e]KD30:>SX`80YjNW0P2^[Zh20;6a/@@0/k>c0P2d];@30;Fe]@80^KVi0P35aLD2
0<o?c`80bl_;1`34a<@20<?3``80_Kfm0P35aLD20:>SX`80Kfm_0P18B4P304a<C080FUYJ0P1EEED2
04e=C@80@d=30P0h>3P202l_;`<0:RXZ0P0Y:BT202`/;080;bl_0P0e=CD20451@@80ATI60`14A4@2
02@T9080<C4a0P0n?Sh203Ph>080;Rh^0P0U9BD302<S8`80<30`0P1CDe<205QHF080?clo0P1DE5@2
075aL@80/[:b1@3;bl/20;^k^`80/k>c0P2QXJ420:2PX080GUiN0`11@D4202/[:`80;Rh^0P0e=CD2
055AD@80A4A40P12@T8304a<C080IVIV0P1oOgl20861P@80O7al0P1jNWX207QhN0<0Ng]k0P21PH42
08B4Q080QhN70P2:RXX208b<S080Shn?0`2ATI4209BDU080UYJF0P2EUID80<SPf0001P38h=P2030`
<0@0;Rh^0`0X:2P202l_;`80Bd];0P1oOgl206UYJ@80;2`/0P0Z:RX302d];@80;Rh^0P0_;bl202h^
;P@0;2`/1`0];Bd2030`<080<S8b0P0d=3@203Lg=`80;bl_0`0a<C4203`l?080B4Q80P1NGUh204Y:
BP80=SHf0P0U9BD2028R8P<08b<S100M7Ad202<S8`80<c<c0P1/K6`209fMW@<0X:2P0P1VIVH2069R
HP80Lg=c0P2e]KD20<C4a080]KFe0`2SXj<20:NWY`80[Zj^0P2a/K440;>c/`80];Bd0`2e]KD20;Vi
^@80aLG50P3?cll20<_;b`L0a<C40P33`l<20;fm_@80aLG50P2SXj<206m_K`80B4Q80`1<C4`205YJ
FP80EEEE0P1=CDd204=3@`80>3Ph0P0_;bl302XZ:P80:BTY0P0/;2`202l_;`80=CDe0P11@D4204I6
AP<0A4A40P0T92@2034a<@80?Shn0P0h>3P202h^;P809BDU0`0S8b<2030`<080De=C0P1HF5P203lo
?`80E5AD0P1aLG420;:b/PD0bl_;0P2k^k/20;>c/`80XJ6Q0P2PX:0205iNGP<0@D510P0[:b/202h^
;P80=CDe0P1ADE4204A4A080@T920`1<C4`206IVIP80Ogmo0P21PH4207alO080NWYj0P1hN7P307]k
N`80PH610P24Q8@208N7Q`80RXZ:0P2<S8`208n?S`<0TI6A0P2DU9@209JFUP80UIFE2038h=P000H0
b>3H0P0];Bd2034a<@80?clo0`11@D4202l_;`80EUIF0P25QHD205UIF@@0:2PX0`0`<30202l_;`80
;Bd]0P0[:b/202XZ:P@0:b/[1@0X:2P203Lg=`80C4a<101TI6@205IFEP<0CDe=0P1OGel206i^KP80
GEeM0P0f=SH202`/;080:BTY0P0T92@3024Q8@807QhN0P0R8R8201hN7P809RHV0P1ADE4208J6QP<0
Y:BT0P25QHD206MWI`80HF5Q0P2HV9P20;^k^`80a/K60`2][Jd20:NWY`80ZZZZ0P2/[:`20:n_[`80
/[:b0P2d];@30;Jf]P80^KVi0P34a<@20<g=c@80bl_;0P36a/H20<G5a@<0a<C40P30`<020;fm_@80
d];B0P39bLT20:VYZ@80J6QX0`1;Bd/204E5A@80DE5A0P1:BTX204a<C080BDU90P12@T8502/[:`80
;Rh^0P0_;bl2034a<@80=SHf0P0h>3P303Ti>@80;2`/0P0b<S8203Hf=P80<S8b0P0/;2`502PX:080
;bl_1012@T8203dm?@80G5aL0P23Ph<20:VYZ@<0^[Zj0P2o_kl20;Fe]@80VIVI0P1eMGD206QXJ080
?Shn0`0_;bl402PX:080:RXZ0P0d=3@202d];@80?3`l0`1DE5@206e]K@80Ph>30P25QHD208:2PP80
OWin0P1lO7`307inOP80PX:20P25QHD208V9R@80RXZ:0P2<S8`208n?S`<0TY:B0P2EUID209NGU`80
UYJF2038h=P000H0b>3H0P0];Bd2034a<@80?clo0`11@D4202l_;`80EUIF0P25QHD205UIF@@0:2PX
0`0`<30202l_;`80;Bd]0P0[:b/202XZ:P@0:b/[1@0X:2P203Lg=`80C4a<101TI6@205IFEP<0CDe=
0P1OGel206i^KP80GEeM0P0f=SH202`/;080:BTY0P0T92@3024Q8@807QhN0P0R8R8201hN7P809RHV
0P1ADE4208J6QP<0Y:BT0P25QHD206MWI`80HF5Q0P2HV9P20;^k^`80a/K60`2][Jd20:NWY`80ZZZZ
0P2/[:`20:n_[`80/[:b0P2d];@30;Jf]P80^KVi0P34a<@20<g=c@80bl_;0P36a/H20<G5a@<0a<C4
0P30`<020;fm_@80d];B0P39bLT20:VYZ@80J6QX0`1;Bd/204E5A@80DE5A0P1:BTX204a<C080BDU9
0P12@T8502/[:`80;Rh^0P0_;bl2034a<@80=SHf0P0h>3P303Ti>@80;2`/0P0b<S8203Hf=P80<S8b
0P0/;2`502PX:080;bl_1012@T8203dm?@80G5aL0P23Ph<20:VYZ@<0^[Zj0P2o_kl20;Fe]@80VIVI
0P1eMGD206QXJ080?Shn0`0_;bl402PX:080:RXZ0P0d=3@202d];@80?3`l0`1DE5@206e]K@80Ph>3
0P25QHD208:2PP80OWin0P1lO7`307inOP80PX:20P25QHD208V9R@80RXZ:0P2<S8`208n?S`<0TY:B
0P2EUID209NGU`80UYJF2038h=P000H0b>3H0P0[:b/203/k>`80CTi>0`1GEeL202l_;`80GUiN0P26
QXH204];B`809bLW0P0X:2P303@d=080;bl_0P0Z:RX602PX:080:BTY0`0V9RH202TY:@80ATI60P1X
J6P207moO`80K6a/0P1]KFd306IVIP80CTi>0P0f=SH202TY:@8092@T0P0W9bL202/[:`80:2PX0`0T
92@202DU9@80:2PX0P0N7Qh2020P8080>3Ph0P1WIfL309VIV@80X:2P0P1gMgL205YJFP80OGem0P2Y
ZJT20=3@d0<0^;Rh0P2/[:`20:JVYP80Z:RX0P2][Jd20;2`/080];Bd0`2g]kL20;Zj^P80`l?30P3:
b/X20<_;b`80bLW90P36a/H30<?3``80`<300P2m_Kd20;jn_P80_;bl0P37alL209ZJVP<0GUiN0P0j
>SX2051@D080ATI60P11@D4203Hf=P80@d=30`0`<302034a<@80<S8b0P0a<C42030`<0@0;bl_0`0`
<30203@d=080<c<c0P0a<C42030`<080;Rh^1@0];Bd202h^;P80<30`0P0c<c<203`l?080AdM70P1K
Fe/208:2PP<0Y:BT0P2LW9`208F5Q@80JFUY0P1<C4`203Hf=P80:BTY0`0X:2P202/[:`80:2PX0P0V
9RH202@T9080:b/[0P14A4@3061PH080MGEe0P25QHD208R8R080QXJ60P22PX8207moO`<0P8200P22
PX8208J6QP80RXZ:0P2;Rh/208b<S080Shn?0`2CTi<209JFUP80UiNG0P2HV9P80<SPf0001P38h=P2
02/[:`80>c/k0P1>CTh305MGE`80;bl_0P1NGUh208J6QP80Bd];0P0W9bL202PX:0<0=3@d0P0_;bl2
02XZ:PH0:2PX0P0Y:BT302HV9P80:BTY0P16ATH206QXJ080Ogmo0P1/K6`206e]K@<0IVIV0P1>CTh2
03Hf=P80:BTY0P0T92@202LW9`80:b/[0P0X:2P302@T90809BDU0P0X:2P201hN7P80820P0P0h>3P2
06MWI`<0VIVI0P2PX:0207MgM`80FUYJ0P1mOGd20:VYZ@80d=3@0`2h^;P20:b/[080YZJV0P2XZ:P2
0:f][@80/;2`0P2d];@30;Ng]`80^[Zj0P33`l<20<[:bP80bl_;0P39bLT20<K6aP<0`l?30P30`<02
0;fm_@80_[jn0P2l_;`20<O7a`80VYZJ0`1NGUh203Xj>P80D51@0P16ATH20451@@80=SHf0P13@d<3
030`<080<C4a0P0b<S82034a<@80<30`100_;bl3030`<080=3@d0P0c<c<2034a<@80<30`0P0^;Rh5
02d];@80;Rh^0P0`<30203<c<`80?3`l0P17AdL205]KF`80PX:20`2TY:@209bLW080QHF50P1YJFT2
04a<C080=SHf0P0Y:BT302PX:080:b/[0P0X:2P202HV9P8092@T0P0[:b/204A4A0<0H61P0P1eMGD2
08F5Q@80R8R80P26QXH208:2PP80Ogmo0`20P80208:2PP80QXJ60P2:RXX208^;R`80S8b<0P2?Shl3
09>CT`80UYJF0P2GUiL209RHV0P0b>3H00060<SPf0809RHV0P19BDT504M7A`80;Bd]0P1PH60207al
O080?Cdm0P0X:2P202HV9P<0;bl_0P0[:b/202LW9`@09BDU0P0S8b<202LW9`<0;2`/0P1:BTX2065Q
H@80MGEe0P1nOWh206e]K@80GEeM0`19BDT203Hf=P80:2PX0P0Q8B4202DU9@80:b/[0P0_;bl202`/
;0D09RHV0P0T92@202HV9P807AdM0P0U9BD204=3@`<0OWin0P2OWil209JFUP80Hf=S0P1`L70208n?
S`80^[Zj0`30`<020;Zj^P80Xj>S0P2WYjL20:f][@80/;2`0P2b/[830;Fe]@80^;Rh0P30`<020<O7
a`@0b/[:0P36a/H30<71`@80_kno0P2m_Kd20;bl_080_Kfm0P3AdM420<K6aP<0XZ:R0P1TI6@2051@
D0H0?Cdm0P1:BTX703<c<`80<S8b0P0a<C42030`<0D0<C4a0P0d=3@203<c<`80<S8b0P0`<30202l_
;`/0;Rh^0P0b<S8204A4A080ATI60P1RHV8307YjNP80L71`0P1LG5`204U9B@80>3Ph0P0[:b/502LW
9`80:BTY0P0T92@202DU9@80:b/[0P0k>c/205MGE`<0Lg=c0P20P80408N7Q`80Q8B40P21PH4207mo
O`<0P8200P22PX8208N7Q`80Rh^;0P2<S8`208f=S@80T92@0`2CTi<209JFUP80VIVI0P2JVYX80<SP
f0001P38h=P202HV9P80BDU91@17AdL202d];@80H61P0P1lO7`203dm?@80:2PX0P0V9RH302l_;`80
:b/[0P0W9bL402DU9@808b<S0P0W9bL302`/;080BTY:0P1QHF4207EeM@80OWin0P1]KFd205eMG@<0
BDU90P0f=SH202PX:0808B4Q0P0U9BD202/[:`80;bl_0P0/;2`502HV9P8092@T0P0V9RH201dM7@80
9BDU0P13@d<307inOP80WinO0P2FUYH206=SH`80L71`0P2?Shl20;Zj^P<0`<300P2j^[X20:>SX`80
YjNW0P2][Jd20;2`/080/[:b0`2e]KD20;Rh^080`<300P37alL40<[:bP80a/K60`31`L420;no_`80
_Kfm0P2l_;`20;fm_@80dM7A0P36a/H30::RXP80I6AT0P1@D50603dm?@80BTY:1`0c<c<2038b<P80
<C4a0P0`<305034a<@80=3@d0P0c<c<2038b<P80<30`0P0_;bl;02h^;P80<S8b0P14A4@204I6AP80
HV9R0`1jNWX2071`L080G5aL0P19BDT203Ph>080:b/[1@0W9bL202TY:@8092@T0P0U9BD202/[:`80
>c/k0P1GEeL307=cL`80P8201027QhL208B4Q080PH610P1oOgl30820P080PX:20P27QhL208^;R`80
S8b<0P2=SHd2092@T0<0Ti>C0P2FUYH209VIV@80VYZJ2038h=P000H0b>3H0P0V9RH204U9B@D0AdM7
0P0];Bd2061PH080O7al0P0m?Cd202PX:0809RHV0`0_;bl202/[:`809bLW100U9BD202<S8`809bLW
0`0/;2`204Y:BP80HF5Q0P1eMGD207inOP80KFe]0P1MGEd304U9B@80=SHf0P0X:2P2024Q8@809BDU
0P0[:b/202l_;`80;2`/1@0V9RH202@T90809RHV0P0M7Ad202DU9@80@d=30`1nOWh209nOW`80UYJF
0P1SHf<2071`L080Shn?0P2j^[X30<30`080^[Zj0P2SXj<20:NWY`80[Jf]0P2`/;020;:b/P<0]KFe
0P2h^;P20<30`080alO7103:b/X20<K6aP<0`L710P2o_kl20;fm_@80_;bl0P2m_Kd20=7Ad@80a/K6
0`2RXZ8206ATI080D51@1P0m?Cd204Y:BPL0<c<c0P0b<S82034a<@80<30`1@0a<C4203@d=080<c<c
0P0b<S82030`<080;bl_2`0^;Rh2038b<P80A4A40P16ATH2069RHP<0NWYj0P1`L70205aLG080BDU9
0P0h>3P202/[:`D09bLW0P0Y:BT202@T90809BDU0P0[:b/203/k>`80EeMG0`1cLg<20820P0@0QhN7
0P24Q8@20861P@80Ogmo0`20P80208:2PP80QhN70P2;Rh/208b<S080SHf=0P2@T90309>CT`80UYJF
0P2IVIT209ZJVPP0b>3H00060<SPf080<S8b0P1IFET203Ti>@<0<C4a0P0];Bd2061PH080KVi^0P0c
<c<202TY:@8092@T0`0Y:BT202HV9P809BDU0P0S8b<202@T90808B4Q0P0X:2P303/k>`80KFe]0P1e
MGD207AdM080KFe]0P1PH60204=3@`<09bLW0P0R8R8202@T90809BDU0P0Z:RX202l_;`80<S8b0P0^
;Rh302TY:@8092@T0P0O7al202h^;P8071`L0P0K6a/202DU9@<0GEeM0P2?Shl20;2`/080M7Ad0P1/
K6`207IfMP80W9bL0`30`<020<O7a`80Xj>S0P2XZ:P20:f][@80[jn_0P2a/K430;>c/`80][Jf0P2m
_Kd20<C4a080b<S80P3:b/X20<K6aP<0`L710P2n_[h40;bl_080^k^k0P2g]kL20;^k^`<0alO70P2F
UYH205mOG`80@4100P0n?Sh204=3@`80CDe=1@0h>3P203Lg=`80=CDe0P0d=3@203De=@80=SHf0`0e
=CD603@d=080<c<c0P0a<C4202l_;`<0;Rh^0P0_;bl2030`<080;Bd]0P0Z:RX20410@080<C4a0P14
A4@3055AD@80ADE50P0d=3@202l_;`80;Rh^100/;2`502XZ:P809RHV0P0Z:RX203/k>`80De=C0P1^
KVh308B4Q080RHV90P27QhL208F5Q@80PH610P1oOgl207inOP<0Ogmo0P22PX8208N7Q`80S8b<0P2>
SXh208n?S`80TI6A0`2CTi<209RHV080Vi^K0P2LW9`80<SPf0001P38h=P2038b<P80FEUI0P0i>CT3
034a<@80;Bd]0P1PH60206i^KP80<c<c0P0Y:BT202@T90<0:BTY0P0V9RH202DU9@808b<S0P0T92@2
024Q8@80:2PX0`0k>c/206e]K@80MGEe0P1dM7@206e]K@80H61P0P13@d<302LW9`808R8R0P0T92@2
02DU9@80:RXZ0P0_;bl2038b<P80;Rh^0`0Y:BT202@T90807alO0P0^;Rh201`L70806a/K0P0U9BD3
05eMG@80Shn?0P2`/;0207AdM080K6a/0P1fMWH209bLW0<0`<300P37alL20:>SX`80Z:RX0P2][Jd2
0:n_[`80/K6a0`2c/k<20;Jf]P80_Kfm0P34a<@20<S8b080b/[:0P36a/H30<71`@80_[jn102l_;`2
0;^k^`80]kNg0P2k^k/30<O7a`80UYJF0P1OGel20410@080?Shn0P13@d<204e=C@D0>3Ph0P0g=cL2
03De=@80=3@d0P0e=CD203Hf=P<0=CDe1P0d=3@203<c<`80<C4a0P0_;bl302h^;P80;bl_0P0`<302
02d];@80:RXZ0P10@402034a<@80A4A40`1ADE4204E5A@80=3@d0P0_;bl202h^;P@0;2`/1@0Z:RX2
02HV9P80:RXZ0P0k>c/205=CD`80KVi^0`24Q8@208V9R@80QhN70P25QHD20861P@80Ogmo0P1nOWh3
07moO`80PX:20P27QhL208b<S080SXj>0P2?Shl2096AT@<0Ti>C0P2HV9P209^KV`80W9bL2038h=P0
00H0b>3H0P14A4@204Q8B080;bl_0`0Z:RX202h^;P80HV9R0P1UIFD2034a<@809bLW0P0R8R8902HV
9P80:2PX0P0Z:RX203De=@<0GemO0P1fMWH207alO080Lg=c0P1EEED203Ti>@80;Bd]0`0X:2P402DU
9@80<30`0P0Z:RX202l_;`80<C4a0P0[:b/302HV9P80;2`/0P0^;Rh203Hf=P805aLG0P0O7al201hN
7P<0@T920P1]KFd20:ZZZP80SXj>0P1hN7P206a/K080PH610`2UYJD20<[:bP80/K6a0P2YZJT20:^[
Z`80[Jf]0P2`/;030;:b/P80]KFe0P2l_;`20<?3``80b<S80P3;bl/20<S8b0<0a<C40P2o_kl20;^k
^`80^[Zj0P2k^k/20;Fe]@80^[Zj0`3GemL20<W9b@80Vi^K0P1HF5P20451@@80@4100P1:BTX304M7
A`80ATI60P12@T8203hn?P80>SXj0P0e=CD2038b<P<0=CDe0P0h>3P203Lg=`80=3@d0P0c<c<2038b
<P80<C4a0`0`<30202h^;P@0<30`0P0^;Rh203Ph>080;Rh^0P0a<C4303Lg=`80?Cdm0P11@D4203De
=@80:2PX0P0U9BD502PX:080:RXZ0P0d=3@203De=@80HF5Q0P28R8P208^;R`<0R8R80P25QHD408:2
PP80Ph>30P1oOgl207emO@<0P8200P25QHD208V9R@80S8b<0P2>SXh2092@T080U9BD0`2HV9P209ZJ
VP80W9bL0P2MWId80<SPf0001P38h=P204A4A080B4Q80P0_;bl302XZ:P80;Rh^0P1RHV8206EUI@80
<C4a0P0W9bL2028R8PT09RHV0P0X:2P202XZ:P80=CDe0`1OGel207IfMP80O7al0P1cLg<205EEE@80
>CTi0P0];Bd302PX:0@09BDU0P0`<30202XZ:P80;bl_0P0a<C4202/[:`<09RHV0P0/;2`202h^;P80
=SHf0P0G5aL201lO7`807QhN0`12@T8206e]K@80ZZZZ0P2>SXh207QhN080K6a/0P21PH430:FUY@80
b/[:0P2a/K420:VYZ@80Zj^[0P2][Jd20;2`/0<0/[:b0P2e]KD20;bl_080`l?30P38b<P20<_;b`80
b<S80`34a<@20;no_`80^k^k0P2j^[X20;^k^`80]KFe0P2j^[X30=OGe`80bLW90P2KVi/205QHF080
@D510P10@40204Y:BP<0AdM70P16ATH20492@P80?Shn0P0j>SX203De=@80<S8b0`0e=CD203Ph>080
=cLg0P0d=3@203<c<`80<S8b0P0a<C43030`<080;Rh^100`<30202h^;P80>3Ph0P0^;Rh2034a<@<0
=cLg0P0m?Cd20451@@80=CDe0P0X:2P202DU9@D0:2PX0P0Z:RX203@d=080=CDe0P1QHF4208R8R080
Rh^;0`28R8P208F5Q@@0PX:20P23Ph<207moO`80OGem0`20P80208F5Q@80RHV90P2<S8`208j>SP80
T92@0P2DU9@309RHV080VYZJ0P2LW9`209fMW@P0b>3H00060<SPf080DU9B0P0c<c<502PX:080<30`
0P1TI6@205iNGP80<S8b0P0V9RH2024Q8@<09BDU0P0V9RH202PX:080:RXZ0P0_;bl203Ph>080A4A4
0`22PX8207IfMP80GemO0P0l?3`202h^;P809RHV0P0Y:BT302h^;P80;2`/0P0Y:BT203Xj>P80:b/[
0P0^;Rh202l_;`80:b/[0`0U9BD202<S8`807QhN0P0[:b/201PH6080;2`/0P0N7Qh302/[:`80B4Q8
0P2FUYH20:2PX080RHV90P1[Jf/206a/K0<0QXJ60P33`l<20;fm_@80[:b/0P2YZJT20:ZZZP80[jn_
0`2a/K420;Bd]080^k^k0P33`l<20<O7a`@0b/[:0`38b<P20<71`@80^k^k102i^KT20;Jf]P80];Bd
0`2l_;`20;no_`80bLW90P2CTi<206=SH`80ADE50P18B4P305EEE@80De=C0P1>CTh204U9B@80@d=3
0P0j>SX203<c<`<0>CTi0P10@40203`l?080=SHf100e=CD203@d=0<0<c<c0P0a<C42038b<P80<c<c
0P0d=3@203<c<`80=3@d0P0`<30302l_;`P0:b/[0P0W9bL202HV9P<0:b/[0P0b<S8204a<C080B4Q8
0P1ZJVX208J6QP80RXZ:0`29RHT208:2PP80Ng]k0P1oOgl208>3P`80Ogmo0P1kNg/30820P080QhN7
0P2:RXX208b<S080Shn?0P2BTY8209NGU`<0W9bL1P2MWId80<SPf0001P38h=P2059BDP80<c<c1@0X
:2P2030`<080I6AT0P1NGUh2038b<P809RHV0P0Q8B4302DU9@809RHV0P0X:2P202XZ:P80;bl_0P0h
>3P204A4A0<0PX:20P1fMWH205mOG`80?3`l0P0^;Rh202HV9P80:BTY0`0^;Rh202`/;080:BTY0P0j
>SX202/[:`80;Rh^0P0_;bl202/[:`<09BDU0P0S8b<201hN7P80:b/[0P0H61P202`/;0807QhN0`0[
:b/204Q8B080UYJF0P2PX:0208V9R@80Jf][0P1/K6`308J6QP80`l?30P2m_Kd20:b/[080ZJVY0P2Z
ZZX20:n_[`<0/K6a0P2d];@20;^k^`80`l?30P37alL40<[:bP<0b<S80P31`L420;^k^`@0^KVi0P2f
][H20;Bd]0<0_;bl0P2o_kl20<W9b@80Ti>C0P1SHf<204E5A@80B4Q80`1EEED205=CD`80CTi>0P19
BDT204=3@`80>SXj0P0c<c<303Ti>@80@4100P0l?3`203Hf=P@0=CDe0P0d=3@303<c<`80<C4a0P0b
<S8203<c<`80=3@d0P0c<c<203@d=080<30`0`0_;bl802/[:`809bLW0P0V9RH302/[:`80<S8b0P1<
C4`204Q8B080JVYZ0P26QXH208Z:RP<0RHV90P22PX8207]kN`80Ogmo0P23Ph<207moO`80Ng]k0`20
P80208N7Q`80RXZ:0P2<S8`208n?S`80TY:B0P2GUiL309bLW0H0WIfM2038h=P000H0b>3H0P11@D42
02h^;P80:RXZ0`0[:b/2038b<P80GemO0P1KFe/203<c<`80:RXZ0P0T92@302HV9P809BDU0P0W9bL2
02`/;080<c<c0P1>CTh205=CD`<0Ng]k0P1OGel204I6AP80;2`/0P0V9RH202LW9`80:RXZ1@0^;Rh2
02`/;080=CDe0P0/;2`402h^;P80;2`/0`0Y:BT202@T9080820P0P0X:2P202d];@80>CTi1@0N7Qh2
02l_;`80KVi^0P2EUID209fMW@80NWYj0P1VIVH3071`L080Xj>S0P2h^;P20;no_`80Zj^[0P2XZ:P2
0:^[Z`<0[:b/0P2`/;020;Rh^080`<300P35aLD20<S8b0D0bl_;0P35aLD20;fm_@80^KVi0P2e]KD2
0;:b/P80/;2`0`2d];@20;jn_P80fMWI0P3<c<`20:FUY@80IfMW1@1>CTh2059BDP80FEUI0P1FEUH2
055AD@80CDe=0P1;Bd/304e=C@80CTi>0P14A4@203hn?PH0?Cdm0`0k>c/20451@@80<c<c100`<302
03@d=080>CTi0P17AdL303Ti>@80>3Ph0P0Y:BT202/[:`80<30`0P0e=CD202l_;`<0?clo0P1>CTh2
06i^KP80HF5Q0P1UIFD207IfMP80S8b<0`20P80207inOP80NGUi0P1kNg/207alO080NWYj0P1hN7P3
07emO@80Ph>30P27QhL208^;R`80TI6A0P2FUYH209ZJVP<0WIfM1P2NWYh80<SPf0001P38h=P20451
@@80;Rh^0P0Z:RX302/[:`80<S8b0P1OGel205]KF`80<c<c0P0Z:RX202@T90<09RHV0P0U9BD202LW
9`80;2`/0P0c<c<204i>CP80De=C0`1kNg/205mOG`80ATI60P0/;2`202HV9P809bLW0P0Z:RX502h^
;P80;2`/0P0e=CD202`/;0@0;Rh^0P0/;2`302TY:@8092@T0P0P820202PX:080;Bd]0P0i>CT501hN
7P80;bl_0P1^KVh209FEU@80WIfM0P1jNWX206IVIP<0L71`0P2SXj<20;Rh^080_kno0P2[Zj/20:RX
Z080Zj^[0`2/[:`20;2`/080^;Rh0P30`<020<G5a@80b<S81@3;bl/20<G5a@80_Kfm0P2i^KT20;Fe
]@80/[:b0P2`/;030;Bd]080_[jn0P3IfMT20<c<c080YJFU0P1WIfL504i>CP80DU9B0P1IFET205IF
EP80DE5A0P1=CDd204];B`<0CDe=0P1>CTh204A4A080?Shn1P0m?Cd303/k>`80@D510P0c<c<4030`
<080=3@d0P0i>CT204M7A`<0>CTi0P0h>3P202TY:@80:b/[0P0`<30203De=@80;bl_0`0o?cl204i>
CP80KVi^0P1QHF4206EUI@80MWIf0P2<S8`30820P080OWin0P1iNGT207]kN`80O7al0P1jNWX207Qh
N0<0OGem0P23Ph<208N7Q`80Rh^;0P2ATI4209JFUP80VYZJ0`2MWId609jNWPP0b>3H00060<SPf080
;Rh^0P0];Bd202`/;0<0;bl_0P0e=CD205UIF@80F5QH0P0e=CD202h^;PD09bLW0P0U9BD202LW9`80
<30`0P0k>c/2069RHP80GemO0`1^KVh204i>CP80=CDe0P0U9BD202LW9`@0;Rh^0`0];Bd202h^;P80
;bl_3@0];Bd202LW9`809RHV0P0Y:BT20451@@80@T920P0N7Qh301PH60807QhN0P15ADD207alO080
Z:RX0P2;Rh/206YZJP<0HV9R0P21PH420:^[Z`80bl_;0P2_[jl20:VYZ@D0Z:RX0P2/[:`20;Bd]080
_;bl0P31`L420<K6aP80b/[:0`3<c<`20<O7a`80`L710P2h^;P20;6a/@80[Jf]0P2[Zj/30;2`/080
]KFe0P2k^k/20;no_`80b/[:0P2PX:0206e]K@<0CDe=0P1BDU82069RHP80HF5Q0P1OGel2069RHP80
I6AT0`1RHV8205eMG@80D51@0P1:BTX204U9B@@0BTY:0`16ATH205=CD`80>SXj0P0a<C4202`/;080
?3`l0P1<C4`206][J`<0De=C0P1ADE4202h^;P80<30`0P0j>SX204Y:BP80?3`l0`1EEED206a/K080
QHF50P1iNGT205aLG080GUiN0P25QHD307EeM@80N7Qh0P1fMWH207EeM@80M7Ad0P1cLg<207AdM0<0
NGUi0P20P80208J6QP80SHf=0P2DU9@209ZJVP80WIfM0`2NWYh209nOW`@0X:2P2038h=P000H0b>3H
0P0^;Rh202d];@80;2`/0`0_;bl203De=@80FEUI0P1HF5P203De=@80;Rh^1@0W9bL202DU9@809bLW
0P0`<30203/k>`80HV9R0P1OGel306i^KP80CTi>0P0e=CD202DU9@809bLW100^;Rh302d];@80;Rh^
0P0_;bl=02d];@809bLW0P0V9RH202TY:@80@D510P12@T8201hN7P<061PH0P0N7Qh204E5A@80O7al
0P2XZ:P208^;R`80JVYZ0`1RHV820861P@80Zj^[0P3;bl/20:n_[`80ZJVY1@2XZ:P20:b/[080];Bd
0P2l_;`20<71`@80a/K60P3:b/X30<c<c080alO70P31`L420;Rh^080/K6a0P2][Jd20:^[Z`<0/;2`
0P2e]KD20;^k^`80_kno0P3:b/X20:2PX080KFe]0`1=CDd2059BDP80HV9R0P1QHF4205mOG`80HV9R
0P1TI6@3069RHP80GEeM0P1@D50204Y:BP80BDU9101:BTX304I6AP80De=C0P0j>SX2034a<@80;2`/
0P0l?3`204a<C080Jf][0`1CDe<2055AD@80;Rh^0P0`<30203Xj>P80BTY:0P0l?3`305EEE@80K6a/
0P25QHD207UiN@80G5aL0P1NGUh208F5Q@<0MGEe0P1hN7P207IfMP80MGEe0P1dM7@207=cL`80M7Ad
0`1iNGT20820P080QXJ60P2=SHd209BDU080VYZJ0P2MWId309jNWP80WinO102PX:080<SPf0001P38
h=P202d];@80;2`/0P0Z:RX302l_;`80=CDe0P1IFET2059BDP80=SHf0P0X:2P202DU9@<0:2PX0P0T
92@202PX:080=3@d0P18B4P206EUI@80IVIV0`1WIfL203Lg=`80:RXZ0P0U9BD202HV9P80:RXZ0P0[
:b/302`/;080;bl_0P0`<30202`/;080:RXZ1P0Y:BT302XZ:P80:2PX0P0`<3020451@@80@d=30P0f
=SH201/K6`<06ATI0P0N7Qh2034a<@80EUIF0P2HV9P209FEU@80PX:20`1SHf<2071`L080SXj>0P2g
]kL40;Zj^P80Xj>S0`2VYZH20:^[Z`80/;2`0P2f][H20;fm_@80`/;20P36a/H30<S8b080alO70P33
`l<20;Vi^@80[Zj^0P2YZJT20:JVYP<0ZJVY0P2][Jd40;^k^`80emOG0P3=cLd20:j^[P<0MgMg0P1U
IFD205iNGP80H61P0P1WIfL206][J`80KVi^0`1YJFT206ATI0@0HF5Q0P1PH602065QH@80Jf][0`1`
L70206m_K`80E5AD0P15ADD202XZ:P80ATI60P1XJ6P208f=S@<0RXZ:0P20P80204a<C080CDe=0P1V
IVH2071`L080B4Q80`1MGEd2071`L080PH610P1mOGd206MWI`80HF5Q0P1gMgL3075aL@80L71`101/
K6`206i^KP80KFe]0P1_Kfl307MgM`80PX:20P2<S8`209BDU080VIVI0P2KVi/209jNWP<0X:2P0P2Q
XJ440::RXPP0b>3H00060<SPf080;Bd]0P0/;2`202XZ:P<0;bl_0P0e=CD205UIF@80DU9B0P0f=SH2
02PX:0809BDU0`0X:2P202@T9080:2PX0P0d=3@204Q8B080IFEU0P1VIVH306MWI`80=cLg0P0Z:RX2
02DU9@809RHV0P0Z:RX202/[:`<0;2`/0P0_;bl2030`<080;2`/0P0Z:RX602TY:@<0:RXZ0P0X:2P2
030`<080@D510P13@d<203Hf=P806a/K0`0I6AT201hN7P80<C4a0P1FEUH209RHV080UIFE0P22PX83
06=SH`80L71`0P2>SXh20;Ng]`@0^[Zj0P2SXj<30:JVYP80Zj^[0P2`/;020;Jf]P80_Kfm0P32`/82
0<K6aP<0b<S80P37alL20<?3``80^KVi0P2^[Zh20:VYZ@80YZJV0`2YZJT20:f][@@0^k^k0P3GemL2
0<g=c@80[Zj^0`1gMgL206EUI@80GUiN0P1PH60206MWI`80Jf][0P1^KVh306UYJ@80I6AT101QHF42
061PH080HF5Q0P1[Jf/3071`L080Kfm_0P1DE5@204E5A@80:RXZ0P16ATH206QXJ080SHf=0`2:RXX2
0820P080C4a<0P1=CDd206IVIP80L71`0P18B4P305eMG@80L71`0P21PH4207emO@80IfMW0P1QHF42
07MgM`<0LG5a0P1`L70406a/K080KVi^0P1]KFd206m_K`<0MgMg0P22PX8208b<S080U9BD0P2IVIT2
09^KV`80WYjN0`2PX:020:6QX@@0XZ:R2038h=P000H0b>3H0P0_;bl202/[:`80:2PX0`0];Bd203<c
<`80F5QH0P1;Bd/203Lg=`@092@T0`0Y:BT202HV9P80:BTY0P0g=cL205=CD`80I6AT0P1XJ6P3061P
H080:BTY0P0V9RH202PX:0@09RHV0P0X:2P302/[:`80;bl_0P0`<30202`/;0809bLW0P0X:2P202TY
:@80:2PX0`0Z:RX203Xj>P80Bd];0P1MGEd203`l?080:RXZ1@0N7Qh202<S8`809RHV0P0b<S8207]k
N`80U9BD0P2JVYX306i^KP80K6a/0P1dM7@209ZJVP80_[jn0P38b<P20:>SX`<0YZJV0P2[Zj/20:f]
[@80/K6a0P2h^;P20;no_`80`/;20`34a<@20<K6aP80aLG50P2k^k/20:j^[P80YZJV0P2QXJ430::R
XP80Y:BT0P2n_[h20;Jf]P80_kno0P31`L420<c<c0<0Zj^[0P25QHD4069RHP80KFe]0P1`L702079b
LPD0Lg=c0P1eMGD207MgM`80NGUi101jNWX307UiN@80N7Qh0P1aLG42061PH080<30`0P1IFET208R8
R080TI6A0`2=SHd209>CT`80LG5a0P1PH602075aL@80PX:20P1GEeL3069RHP80Jf][0P1dM7@207Ui
N@80L71`0P1VIVH206MWI`<0K6a/0P1VIVH2061PH080HV9R0P1WIfL206QXJ080Jf][0`1hN7P208N7
Q`80U9BD102NWYh209fMW@80WinO0`2RXZ820:>SX`80Y:BT0P2UYJD80<SPf0001P38h=P202l_;`80
:b/[0P0X:2P302d];@80<c<c0P1HF5P204];B`80=cLg100T92@302TY:@809RHV0P0Y:BT203Lg=`80
De=C0P1TI6@206QXJ0<0H61P0P0Y:BT202HV9P80:2PX100V9RH202PX:0<0:b/[0P0_;bl2030`<080
;2`/0P0W9bL202PX:080:BTY0P0X:2P302XZ:P80>SXj0P1;Bd/205eMG@80?3`l0P0Z:RX501hN7P80
8b<S0P0V9RH2038b<P80Ng]k0P2DU9@209ZJVP<0KVi^0P1/K6`207AdM080VYZJ0P2n_[h20<S8b080
Xj>S0`2VYZH20:^[Z`80[Jf]0P2a/K420;Rh^080_kno0P32`/830<C4a080a/K60P35aLD20;^k^`80
[Zj^0P2VYZH20:6QX@<0XZ:R0P2TY:@20;jn_P80][Jf0P2o_kl20<71`@80c<c<0`2[Zj/208F5Q@@0
HV9R0P1]KFd2071`L080LW9b1@1cLg<207EeM@80MgMg0P1iNGT407YjNP<0NGUi0P1hN7P2075aL@80
H61P0P0`<30205UIF@80R8R80P2ATI4308f=S@80Ti>C0P1aLG42061PH080LG5a0P22PX8205MGE`<0
HV9R0P1[Jf/207AdM080NGUi0P1`L70206IVIP80IfMW0`1/K6`206IVIP80H61P0P1RHV8206MWI`80
J6QX0P1[Jf/307QhN080QhN70P2DU9@409jNWP80WIfM0P2OWil30::RXP80Xj>S0P2TY:@20:FUY@P0
b>3H00060<SPf080;bl_0P0[:b/202PX:0<0;Bd]0P0c<c<205QHF080Bd];0P0g=cL402@T90<0:BTY
0P0V9RH202TY:@80=cLg0P1CDe<206ATI080J6QX0`1PH60202TY:@809RHV0P0X:2P402HV9P80:2PX
0`0[:b/202l_;`80<30`0P0/;2`202LW9`80:2PX0P0Y:BT202PX:0<0:RXZ0P0j>SX204];B`80GEeM
0P0l?3`202XZ:PD07QhN0P0S8b<202HV9P80<S8b0P1kNg/209BDU080VYZJ0`1^KVh206a/K080M7Ad
0P2JVYX20;jn_P80b<S80P2SXj<30:JVYP80Zj^[0P2][Jd20;6a/@80^;Rh0P2o_kl20<;2`P<0a<C4
0P36a/H20<G5a@80^k^k0P2^[Zh20:JVYP80XJ6Q0`2RXZ820:BTY080_[jn0P2f][H20;no_`80`L71
0P3<c<`30:^[Z`80QHF5101RHV8206e]K@80L71`0P1bLW8507=cL`80MGEe0P1gMgL207UiN@@0NWYj
0`1iNGT207QhN080LG5a0P1PH602030`<080FEUI0P28R8P2096AT@<0SHf=0P2CTi<2075aL@80H61P
0P1aLG4208:2PP80EeMG0`1RHV8206][J`80M7Ad0P1iNGT2071`L080IVIV0P1WIfL306a/K080IVIV
0P1PH602069RHP80IfMW0P1XJ6P206][J`<0N7Qh0P27QhL209BDU0@0WYjN0P2MWId209nOW`<0XZ:R
0P2SXj<20:BTY080YJFU2038h=P000H0b>3H0P0Y:BT202XZ:PD0;2`/0P0`<302059BDP80@4100P0i
>CT202h^;P80:BTY0`0V9RH202`/;080:b/[0P0k>c/205UIF@80HF5Q0P1UIFD3051@D080;bl_100W
9bL402HV9P80:2PX0`0Z:RX202`/;080;Bd]0P0Z:RX202PX:080:RXZ0P0h>3P203Xj>P<0A4A40P1a
LG4206YZJP80DU9B0P0/;2`2038b<P80=CDe0`0Q8B4201dM7@808R8R0P0P820205EEE@80NWYj0P2N
WYh308b<S080OWin0P1eMGD208J6QP80XZ:R0P2k^k/20;Rh^0<0[Zj^0P2UYJD20:VYZ@80[jn_0P2d
];@20;Vi^@80_Kfm0`31`L420<K6aP80alO70P2o_kl20;Bd]080YjNW1@2LW9`20:2PX080/[:b0P2c
/k<20;^k^`80`l?30P3Fe]H30<g=c@80/[:b0P2BTY8207YjNP80Jf][0P1]KFd207IfMP<0NWYj0P1m
OGd207moO`80P8200P24Q8@408V9R@<0R8R80P25QHD207moO`80Kfm_0P1BDU8207AdM080VYZJ0P2O
Wil309fMW@80Vi^K0P25QHD207MgM`80OGem0P2?Shl206i^KP<0HV9R101YJFT206][J`80IVIV0P1N
GUh205YJFP<0Fe]K0P1FEUH2059BDP80De=C0P1GEeL2061PH080KFe]0`1mOGd208j>SP80Vi^K102U
YJD20::RXP80Xj>S0`2UYJD40:NWY`80Z:RX2038h=P000H0b>3H0P0Y:BT202XZ:PD0;2`/0P0`<302
059BDP80@4100P0i>CT202h^;P80:BTY0`0V9RH202`/;080:b/[0P0k>c/205UIF@80HF5Q0P1UIFD3
051@D080;bl_100W9bL402HV9P80:2PX0`0Z:RX202`/;080;Bd]0P0Z:RX202PX:080:RXZ0P0h>3P2
03Xj>P<0A4A40P1aLG4206YZJP80DU9B0P0/;2`2038b<P80=CDe0`0Q8B4201dM7@808R8R0P0P8202
05EEE@80NWYj0P2NWYh308b<S080OWin0P1eMGD208J6QP80XZ:R0P2k^k/20;Rh^0<0[Zj^0P2UYJD2
0:VYZ@80[jn_0P2d];@20;Vi^@80_Kfm0`31`L420<K6aP80alO70P2o_kl20;Bd]080YjNW1@2LW9`2
0:2PX080/[:b0P2c/k<20;^k^`80`l?30P3Fe]H30<g=c@80/[:b0P2BTY8207YjNP80Jf][0P1]KFd2
07IfMP<0NWYj0P1mOGd207moO`80P8200P24Q8@408V9R@<0R8R80P25QHD207moO`80Kfm_0P1BDU82
07AdM080VYZJ0P2OWil309fMW@80Vi^K0P25QHD207MgM`80OGem0P2?Shl206i^KP<0HV9R101YJFT2
06][J`80IVIV0P1NGUh205YJFP<0Fe]K0P1FEUH2059BDP80De=C0P1GEeL2061PH080KFe]0`1mOGd2
08j>SP80Vi^K102UYJD20::RXP80Xj>S0`2UYJD40:NWY`80Z:RX2038h=P000H0b>3H0P0R8R8202PX
:080;bl_0`0Z:RX202/[:`80BDU90P0f=SH203Xj>P80>3Ph0P0^;Rh3028R8P80<c<c0P0X:2P203`l
?080Fe]K0P1NGUh205aLG0<0?clo0P0i>CT202/[:`@09RHV100X:2P702TY:@80:2PX0P0[:b/203@d
=080CTi>0P1DE5@305UIF@80PH610P1<C4`402DU9@80C4a<0P1BDU8302TY:@806QXJ0P0R8R8201LG
5`80<S8b0P1IFET209JFUP<0Y:BT0P2EUID207inOP80MgMg0P20P8020:FUY@80b<S80`2g]kL20::R
XP80YZJV0P2^[Zh20;6a/@80/k>c0P2i^KT30;jn_P80a<C40P38b<P20<C4a080^k^k0P2YZJT209VI
V@<0UiNG0P2LW9`20:BTY080/;2`0P2h^;P20;no_`80`L710`32`/820<S8b080`l?30P2HV9P406i^
KP80Ng]k0`20P80208B4Q0@0Ph>30P2;Rh/209:BTP80Ti>C0`2@T90208f=S@80RHV90P1kNg/207Ui
N@80SXj>0P2UYJD20:JVYP<0XJ6Q0P2HV9P208n?S`80QXJ60P1oOgl2092@T080OGem0`1OGel2061P
H080G5aL0P1KFe/205MGE`80De=C0P1?Cdl304];B`@0BDU90P1:BTX204m?C`80H61P0P1eMGD308J6
QP80UYJF0P2SXj<20:^[Z`80ZZZZ0P2VYZH20:NWY`D0ZJVY102ZZZX80<SPf0001P38h=P2028R8P80
:2PX0P0_;bl302XZ:P80:b/[0P19BDT203Hf=P80>SXj0P0h>3P202h^;P<08R8R0P0c<c<202PX:080
?3`l0P1KFe/205iNGP80G5aL0`0o?cl203Ti>@80:b/[100V9RH402PX:0L0:BTY0P0X:2P202/[:`80
=3@d0P1>CTh205ADE0<0FEUI0P21PH4204a<C0@09BDU0P1<C4`2059BDP<0:BTY0P0J6QX2028R8P80
5aLG0P0b<S8205UIF@80UYJF0`2TY:@209FEU@80OWin0P1gMgL20820P080YJFU0P38b<P30;Ng]`80
XZ:R0P2VYZH20:j^[P80/K6a0P2c/k<20;Vi^@<0_[jn0P34a<@20<S8b080a<C40P2k^k/20:VYZ@80
VIVI0`2GUiL209bLW080Y:BT0P2`/;020;Rh^080_kno0P31`L430<;2`P80b<S80P33`l<209RHV0@0
KVi^0P1kNg/30820P080Q8B41023Ph<208^;R`80TY:B0P2CTi<3092@T080SHf=0P29RHT207]kN`80
NGUi0P2>SXh20:FUY@80YZJV0`2QXJ4209RHV080Shn?0P26QXH207moO`80T92@0P1mOGd305mOG`80
H61P0P1LG5`205]KF`80EeMG0P1CDe<204m?C`<0Bd];1019BDT204Y:BP80Cdm?0P1PH60207EeM@<0
QXJ60P2FUYH20:>SX`80Zj^[0P2ZZZX20:JVYP80YjNW1@2YZJT40:ZZZPP0b>3H00060<SPf0@092@T
0P0Y:BT303Lg=`80AdM70P1YJFT204m?C`80A4A40P0f=SH203Xj>P<0@T920P1VIVH204M7A`80B4Q8
0P1BDU8205YJFP80ADE50`0c<c<203De=@80>3Ph100V9RH402LW9`<0:2PX0P0U9BD202HV9P809bLW
0P0];Bd203Ti>@80DU9B1@1SHf<208V9R@80E5AD0P0R8R8202HV9P80HV9R0P1HF5P303Lg=`809bLW
0P0R8R8201dM7@809BDU0P0n?Sh207UiN@<0Vi^K0P2TY:@208J6QP80L71`0P1[Jf/208f=S@80];Bd
0`32`/820:j^[P80YjNW0P2UYJD20:^[Z`80/k>c0P2g]kL30;^k^`80`L711035aLD20<30`080[jn_
0P2NWYh309RHV080UiNG0P2NWYh20:^[Z`80/k>c0P2j^[X20;jn_P<0`/;20P38b<P20<W9b@80_[jn
0P2/[:`208j>SPD0MGEe0P1lO7`208:2PP80RXZ:0P2@T90209FEU@D0V9RH0P2DU9@2092@T080RXZ:
0P2ATI4209^KV`@0Y:BT0`2OWil209JFUP80SHf=0P23Ph<207UiN@80Ng]k0P1^KVh3069RHP80IFEU
0P1IFET204e=C@80AdM70P14A4@704=3@`80ATI60P1CDe<206ATI080MgMg0P2:RXX309RHV080XZ:R
0P2XZ:P40:^[Z`L0ZJVY0P2ZZZX20:b/[080[Jf]2038h=P000H0b>3H100T92@202TY:@<0=cLg0P17
AdL206UYJ@80Cdm?0P14A4@203Hf=P80>SXj0`12@T8206IVIP80AdM70P18B4P2059BDP80FUYJ0P15
ADD303<c<`80=CDe0P0h>3P402HV9P@09bLW0`0X:2P202DU9@809RHV0P0W9bL202d];@80>CTi0P1B
DU8506=SH`80RHV90P1DE5@2028R8P809RHV0P1RHV8205QHF0<0=cLg0P0W9bL2028R8P807AdM0P0U
9BD203hn?P80NGUi0`2KVi/20:BTY080QXJ60P1`L70206][J`80SHf=0P2d];@30<;2`P80[Zj^0P2W
YjL20:FUY@80Zj^[0P2c/k<20;Ng]`<0^k^k0P31`L440<G5a@80`<300P2_[jl209jNWP<0V9RH0P2G
UiL209jNWP80Zj^[0P2c/k<20;Zj^P80_[jn0`32`/820<S8b080bLW90P2n_[h20:b/[080SXj>1@1e
MGD207alO080PX:20P2:RXX2092@T080UIFE1@2HV9P209BDU080T92@0P2:RXX2096AT@80Vi^K102T
Y:@309nOW`80UYJF0P2=SHd208>3P`80NGUi0P1kNg/206i^KP<0HV9R0P1UIFD205UIF@80CDe=0P17
AdL204A4A0L0@d=30P16ATH205=CD`80I6AT0P1gMgL208Z:RP<0V9RH0P2RXZ820:RXZ0@0Zj^[1`2Y
ZJT20:ZZZP80[:b/0P2][Jd80<SPf0001P38h=P602HV9P<0:BTY0P0[:b/204a<C0@0>c/k0P0f=SH5
03@d=080DU9B0P0R8R8203@d=080BTY:0P1JFUX202l_;`<0;2`/0P0^;Rh204=3@`80:2PX0P0W9bL2
02HV9P809bLW0`0X:2P402@T9080:2PX0P0b<S8204e=C@80HF5Q0P1MGEd303@d=080IfMW0P1LG5`2
02`/;080<C4a0P1PH60203<c<`<0<C4a0P0j>SX202LW9`809BDU0P0Q8B4202TY:@80EUIF0`23Ph<2
0:NWY`80SXj>0P1cLg<205iNGP80MgMg0P2GUiL30<?3``80^KVi0P2/[:`209jNWP80YjNW0P2b/[82
0;Jf]P<0^;Rh0P2m_Kd20<71`@80aLG50P34a<@20;Jf]P80YZJV0`2JVYX209BDU080Vi^K0P2UYJD2
0:f][@80];Bd0P2i^KT30;jn_P80`/;20P34a<@20<G5a@80_[jn0P2RXZ8208J6QP<0NGUi0P1fMWH2
07inOP80RXZ:0P2?Shl209>CT`80VIVI0`2LW9`209RHV080U9BD0P2EUID409jNWP80WIfM0P2KVi/3
09NGU`80SXj>0P24Q8@207UiN@80KVi^0P1SHf<205YJFP<0Cdm?0P15ADD204A4A080ADE50P10@402
03dm?@80?clo0`14A4@204U9B@80De=C0P1YJFT20820P080TY:B0P2QXJ430:VYZ@@0[Jf]0P2ZZZX2
0:^[Z`80[:b/0P2ZZZX30:VYZ@80Zj^[0P2][Jd20:j^[PP0b>3H00060<SPf0H09RHV0`0Y:BT202/[
:`80C4a<100k>c/203Hf=PD0=3@d0P1BDU82028R8P80=3@d0P1:BTX205YJFP80;bl_0`0/;2`202h^
;P80@d=30P0X:2P202LW9`809RHV0P0W9bL302PX:0@092@T0P0X:2P2038b<P80CDe=0P1QHF4205eM
G@<0=3@d0P1WIfL205aLG080;2`/0P0a<C42061PH080<c<c0`0a<C4203Xj>P809bLW0P0U9BD2024Q
8@80:BTY0P1FEUH308>3P`80YjNW0P2>SXh207=cL`80GUiN0P1gMgL209NGU`<0`l?30P2i^KT20:b/
[080WYjN0P2WYjL20;:b/P80][Jf0`2h^;P20;fm_@80`L710P35aLD20<C4a080][Jf0P2VYZH309ZJ
VP80U9BD0P2KVi/20:FUY@80[Jf]0P2d];@20;Vi^@<0_[jn0P32`/820<C4a080aLG50P2n_[h20::R
XP80QXJ60`1iNGT207IfMP80OWin0P2:RXX208n?S`80Ti>C0P2IVIT309bLW080V9RH0P2DU9@209FE
U@@0WYjN0P2MWId209^KV`<0UiNG0P2>SXh208B4Q080NGUi0P1^KVh206=SH`80FUYJ0`1?Cdl204E5
A@80A4A40P15ADD20410@080?Cdm0P0o?cl304A4A080BDU90P1CDe<206UYJ@80P8200P2BTY820:6Q
X@<0ZJVY102][Jd20:ZZZP80Zj^[0P2/[:`20:ZZZP<0ZJVY0P2[Zj/20:f][@80[Zj^2038h=P000H0
b>3H0P0U9BD202LW9`D0:BTY0P0Z:RX204A4A080BDU90P1?Cdl205=CD`80ATI60`0h>3P20451@@80
9RHV0P0o?cl204Q8B080Bd];0P0];Bd502/[:`80@T920P0/;2`202/[:`80:2PX0P0Y:BT302PX:080
;Bd]0P0U9BD203Lg=`80B4Q80P1XJ6P206IVIP80:RXZ0`0a<C42051@D080G5aL0P0/;2`204A4A080
GemO0P0X:2P303<c<`80AdM70P0];Bd2024Q8@807AdM0P0V9RH203dm?@<0HV9R0P2ATI4209NGU`80
S8b<0P1OGel206IVIP80MWIf0`2RXZ820;Fe]@80^KVi0P2TY:@20:JVYP80[Zj^0P2b/[830;Fe]@80
^KVi0P2l_;`20<?3``80aLG50P2l_;`20:n_[`<0XJ6Q0P2FUYH209RHV080WinO0P2VYZH20:n_[`80
]kNg0`2m_Kd20<30`080`L711034a<@20<?3``80^[Zj0`2KVi/207inOP80P8200P29RHT208^;R`80
SXj>0P2CTi<309^KV`80V9RH0P2DU9@209FEU@80V9RH0P2BTY8208^;R`80R8R80`24Q8@207alO080
LW9b0P1XJ6P205aLG080CTi>0P16ATH304E5A@80A4A40P12@T820451@@80AdM70P1?Cdl205ADE0<0
G5aL0P1bLW8208N7Q`80T92@0P2GUiL20::RXP80[:b/2@2_[jl20;2`/080/K6a0P2^[Zh50:b/[080
[Jf]0P2^[Zh80<SPf0001P38h=P202DU9@809bLW1@0Y:BT202XZ:P80A4A40P19BDT204m?C`80De=C
0P16ATH303Ph>080@D510P0V9RH203lo?`80B4Q80P1;Bd/202d];@D0:b/[0P12@T8202`/;080:b/[
0P0X:2P202TY:@<0:2PX0P0];Bd202DU9@80=cLg0P18B4P206QXJ080IVIV0P0Z:RX3034a<@80D51@
0P1LG5`202`/;080A4A40P1OGel202PX:0<0<c<c0P17AdL202d];@808B4Q0P0M7Ad202HV9P80?Cdm
0`1RHV82096AT@80UiNG0P2<S8`205mOG`80IVIV0P1fMWH30::RXP80]KFe0P2i^KT20:BTY080YZJV
0P2^[Zh20;:b/P<0]KFe0P2i^KT20;bl_080`l?30P35aLD20;bl_080[jn_0`2QXJ4209JFUP80V9RH
0P2OWil20:JVYP80[jn_0P2g]kL30;fm_@80`<300P31`L440<C4a080`l?30P2j^[X309^KV`80OWin
0P20P80208V9R@80Rh^;0P2>SXh209>CT`<0Vi^K0P2HV9P209BDU080UIFE0P2HV9P209:BTP80Rh^;
0P28R8P308B4Q080O7al0P1bLW8206QXJ080G5aL0P1>CTh204I6AP<0ADE50P14A4@20492@P80@D51
0P17AdL204m?C`80E5AD0`1LG5`2079bLP80QhN70P2@T90209NGU`80XZ:R0P2/[:`90:n_[`80/;2`
0P2a/K420:j^[PD0[:b/0P2][Jd20:j^[PP0b>3H00060<SPf08092@T0P0Y:BT202h^;P<0:b/[0P0X
:2P202XZ:P80<c<c0P0l?3`204i>CP80A4A40`0g=cL4030`<080C4a<0P14A4@203/k>`80;bl_0`0/
;2`202TY:@80?Shn0P0a<C4202l_;`80:b/[0P0/;2`302XZ:P80=3@d0P0S8b<204A4A080GEeM0P1`
L70204I6AP80ADE50`0Z:RX203dm?@80Fe]K0P0a<C4405UIF@807alO0`0b<S82055AD@80=CDe0P0M
7Ad201`L70809RHV0P0Y:BT30410@080LG5a0P2HV9P20:BTY080JVYZ0P1NGUh205aLG0<0OGem0P2W
YjL20;no_`80Zj^[102ZZZX20:j^[P<0/[:b0P2d];@20;Ng]`80_kno0P35aLD20<30`080][Jf0`2W
YjL209ZJVP80UiNG0P2JVYX20:6QX@80ZZZZ0P2d];@30;fm_@@0_[jn0P30`<020<;2`P80a<C40P30
`<030:b/[080UIFE0P1nOWh206i^KP80MWIf0P24Q8@208^;R`<0TY:B0P2ATI4208j>SP80S8b<0P29
RHT20861P@80N7Qh0P1dM7@3071`L080JVYZ0P1SHf<205QHF080CTi>0P13@d<203dm?@<0@T920P1:
BTX404I6AP80EeMG0P1ZJVX207=cL`<0O7al0P2<S8`209^KV`80Y:BT0P2[Zj/20;2`/080/k>c0`2a
/K420:n_[`80/;2`0P2c/k<20;Bd]080]KFe0P2b/[830;2`/080[Zj^102][Jd80<SPf0001P38h=P2
02@T9080:BTY0P0^;Rh302/[:`80:2PX0P0Z:RX203<c<`80?3`l0P1>CTh204A4A0<0=cLg100`<302
04a<C080A4A40P0k>c/202l_;`<0;2`/0P0Y:BT203hn?P80<C4a0P0_;bl202/[:`80;2`/0`0Z:RX2
03@d=0808b<S0P14A4@205eMG@80L71`0P16ATH204E5A@<0:RXZ0P0m?Cd205]KF`80<C4a101IFET2
01lO7`<0<S8b0P1ADE4203De=@807AdM0P0L71`202HV9P80:BTY0`10@402075aL@80V9RH0P2TY:@2
06YZJP80GUiN0P1LG5`307emO@80YjNW0P2o_kl20:^[Z`@0ZZZZ0P2^[Zh30;:b/P80];Bd0P2g]kL2
0;no_`80aLG50P30`<020;Jf]P<0YjNW0P2JVYX209NGU`80VYZJ0P2QXJ420:ZZZP80];Bd0`2m_Kd4
0;jn_P80`<300P32`/820<C4a080`<300`2/[:`209FEU@80OWin0P1^KVh207IfMP80Q8B40P2;Rh/3
09:BTP80TI6A0P2>SXh208b<S080RHV90P21PH4207QhN080M7Ad0`1`L70206YZJP80Hf=S0P1HF5P2
04i>CP80@d=30P0m?Cd30492@P80BTY:1016ATH205MGE`80JVYZ0P1cLg<307alO080S8b<0P2KVi/2
0:BTY080Zj^[0P2`/;020;>c/`<0/K6a0P2_[jl20;2`/080/k>c0P2d];@20;Fe]@80/[:b0`2`/;02
0:j^[P@0[Jf]2038h=P000H0b>3H0P0S8b<202/[:`80=SHf0`0_;bl202PX:080:b/[0P0d=3@203De
=@80>c/k0P0f=SH3038b<P80=cLg0P11@D4204m?C`80>3Ph0P0a<C4202h^;P<0;2`/0P0[:b/203Ti
>@80=cLg0P0b<S8402`/;0<0<30`0P15ADD204a<C080D51@101CDe<203Ti>@80?Shn0`0o?cl20492
@P80EeMG0P0h>3P206ATI080CTi>0P0T92@303De=@80FUYJ0P0i>CT2024Q8@8092@T0P0_;bl202DU
9@<0:RXZ0P1=CDd20861P@80YJFU0P23Ph<206][J`80FEUI0`1YJFT208R8R080[:b/0P2d];@20;Zj
^P80YZJV0P2ZZZX30:j^[P80/;2`0P2c/k<20;^k^`80`L710P30`<020;Zj^P<0ZZZZ0P2KVi/209RH
V080VYZJ0P2MWId20:>SX`80[jn_0`2k^k/20;jn_P80_kno0P32`/820<C4a080aLG50P34a<@30<W9
b@80aLG50P2PX:0207UiN@80Jf][0P1UIFD206i^KP<0L71`0P1eMGD207QhN080MgMg0P1dM7@206i^
KP80JVYZ0P1WIfL306ATI080Hf=S0P1QHF4205QHF080D51@0P1?Cdl2059BDP<0F5QH0P1OGel206][
J`80MgMg0P1nOWh208B4Q080S8b<0`2EUID20:2PX080ZZZZ0P2_[jl20;:b/P80]KFe0P2f][H30;Bd
]0@0/K6a1P2c/k<20;:b/P<0/K6a0P2_[jl40:b/[0P0b>3H00060<SPf0808b<S0P0[:b/203Hf=P<0
;bl_0P0X:2P202/[:`80=3@d0P0e=CD203/k>`80=SHf0`0b<S8203Lg=`80@D510P1?Cdl203Ph>080
<C4a0P0^;Rh302`/;080:b/[0P0i>CT203Lg=`80<S8b100/;2`3030`<080ADE50P1<C4`2051@D0@0
De=C0P0i>CT203hn?P<0?clo0P12@T8205MGE`80>3Ph0P1TI6@204i>CP8092@T0`0e=CD205YJFP80
>CTi0P0Q8B4202@T9080;bl_0P0U9BD302XZ:P80CDe=0P21PH420:FUY@80Ph>30P1[Jf/205UIF@<0
JFUY0P28R8P20:b/[080];Bd0P2j^[X20:JVYP80ZZZZ0`2^[Zh20;2`/080/k>c0P2k^k/20<71`@80
`<300P2j^[X30:ZZZP80Vi^K0P2HV9P209ZJVP80WIfM0P2SXj<20:n_[`<0^k^k0P2n_[h20;no_`80
`/;20P34a<@20<G5a@80a<C40`39bLT20<G5a@80X:2P0P1iNGT206][J`80IFEU0P1^KVh3071`L080
MGEe0P1hN7P207MgM`80M7Ad0P1^KVh206YZJP80IfMW0`1TI6@206=SH`80HF5Q0P1HF5P2051@D080
Cdm?0P1BDU8305QHF080GemO0P1[Jf/207MgM`80OWin0P24Q8@208b<S0<0UIFE0P2PX:020:ZZZP80
[jn_0P2b/[820;Fe]@80][Jf0`2d];@40;6a/@H0/k>c0P2b/[830;6a/@80[jn_102/[:`80<SPf000
1P38h=P202<S8`80:b/[0P0f=SH302l_;`80:2PX0P0[:b/203@d=080=CDe0P0k>c/203Hf=P<0<S8b
0P0g=cL20451@@80Cdm?0P0h>3P2034a<@80;Rh^0`0/;2`202/[:`80>CTi0P0g=cL2038b<P@0;2`/
0`0`<30204E5A@80C4a<0P1@D50405=CD`80>CTi0P0n?Sh303lo?`80@T920P1GEeL203Ph>080I6AT
0P1>CTh202@T90<0=CDe0P1JFUX203Ti>@808B4Q0P0T92@202l_;`809BDU0`0Z:RX204e=C@80PH61
0P2UYJD208>3P`80Jf][0P1IFET306UYJ@80R8R80P2/[:`20;Bd]080^[Zj0P2VYZH20:ZZZP<0[Zj^
0P2`/;020;>c/`80^k^k0P31`L420<30`080^[Zj0`2ZZZX209^KV`80V9RH0P2JVYX209fMW@80Xj>S
0P2_[jl30;^k^`80_[jn0P2o_kl20<;2`P80a<C40P35aLD20<C4a0<0bLW90P35aLD20:2PX080NGUi
0P1[Jf/206EUI@80KVi^0`1`L70207EeM@80N7Qh0P1gMgL207AdM080KVi^0P1ZJVX206MWI`<0I6AT
0P1SHf<2065QH@80F5QH0P1@D50204m?C`80DU9B0`1HF5P205mOG`80Jf][0P1gMgL207inOP80Q8B4
0P2<S8`309FEU@80X:2P0P2ZZZX20:n_[`80/[:b0P2e]KD20;Jf]P<0];Bd102a/K460;>c/`80/[:b
0`2a/K420:n_[`@0[:b/2038h=P000H0b>3H0P0R8R8202d];@80>c/k0`0c<c<202XZ:P80;bl_0P0e
=CD203@d=080<C4a0P0`<30302l_;`@0<30`0P0o?cl402h^;P80;Bd]0`0/;2`202d];@80<c<c0P0j
>SX203<c<`80;2`/0P0b<S8303Ti>@80<C4a0P0_;bl203@d=080BDU90P0m?Cd2034a<@809bLW0`0Y
:BT203Ph>080GEeM0P1;Bd/206UYJ@80@T920P0Z:RX303Lg=`80GEeM0P14A4@202XZ:P80820P0P0M
7Ad201PH60<07alO0P0`<30206=SH`80V9RH0P2GUiL207moO`80HV9R0`1OGel206YZJP80T92@0P2d
];@20<O7a`80YjNW0P2YZJT30:ZZZP80[:b/0P2_[jl20;Jf]P80_Kfm0P2o_kl20;bl_0<0[:b/0P2L
W9`209ZJVP@0Vi^K0P2MWId20:^[Z`<0^KVi0P2n_[h20<71`@80`l?31034a<@20<;2`P<0`L710P2m
_Kd20;Jf]P80YZJV0P1jNWX2051@D080GEeM0`1BDU8205QHF080GUiN0P1PH606065QH@D0H61P0P1T
I6@206MWI`80H61P0P1LG5`206EUI@80L71`0`1fMWH207]kN`80OWin0P22PX8208n?S`80WIfM0P2T
Y:@30:RXZ080[:b/0P2_[jl20;:b/P80];Bd0P2f][H20;Ng]`<0]KFe0P2c/k<40;:b/P80/K6a0P2`
/;020;6a/@<0/[:b0P2_[jl20:f][@80[:b/2038h=P000H0b>3H0P0R8R8202d];@80>c/k0`0c<c<2
02XZ:P80;bl_0P0e=CD203@d=080<C4a0P0`<30302l_;`@0<30`0P0o?cl402h^;P80;Bd]0`0/;2`2
02d];@80<c<c0P0j>SX203<c<`80;2`/0P0b<S8303Ti>@80<C4a0P0_;bl203@d=080BDU90P0m?Cd2
034a<@809bLW0`0Y:BT203Ph>080GEeM0P1;Bd/206UYJ@80@T920P0Z:RX303Lg=`80GEeM0P14A4@2
02XZ:P80820P0P0M7Ad201PH60<07alO0P0`<30206=SH`80V9RH0P2GUiL207moO`80HV9R0`1OGel2
06YZJP80T92@0P2d];@20<O7a`80YjNW0P2YZJT30:ZZZP80[:b/0P2_[jl20;Jf]P80_Kfm0P2o_kl2
0;bl_0<0[:b/0P2LW9`209ZJVP@0Vi^K0P2MWId20:^[Z`<0^KVi0P2n_[h20<71`@80`l?31034a<@2
0<;2`P<0`L710P2m_Kd20;Jf]P80YZJV0P1jNWX2051@D080GEeM0`1BDU8205QHF080GUiN0P1PH606
065QH@D0H61P0P1TI6@206MWI`80H61P0P1LG5`206EUI@80L71`0`1fMWH207]kN`80OWin0P22PX82
08n?S`80WIfM0P2TY:@30:RXZ080[:b/0P2_[jl20;:b/P80];Bd0P2f][H20;Ng]`<0]KFe0P2c/k<4
0;:b/P80/K6a0P2`/;020;6a/@<0/[:b0P2_[jl20:f][@80[:b/2038h=P000H0b>3H0P0Q8B4202/[
:`80>3Ph0`0b<S8202l_;`80=SHf0P0n?Sh203`l?080=cLg0P0c<c<3034a<@80<30`0P0b<S8204=3
@`80:2PX0P0Z:RX202/[:`<0:RXZ0P0Y:BT202`/;080<S8b0P0`<30202h^;P80<C4a0`0d=3@203Ti
>@80<30`0P0c<c<204e=C@80=cLg0P0/;2`202<S8`<0:2PX0P0d=3@205UIF@80F5QH0P1XJ6P20410
@08092@T0`0a<C4205ADE080GUiN0P0a<C4403<c<`80:2PX0`0Q8B4202@T9080@T920P1dM7@208j>
SP80UiNG0P1lO7`306MWI`80GEeM0P1gMgL209VIV@80`/;20P2i^KT20;6a/@<0YjNW0P2XZ:P20:^[
Z`80/[:b0P2g]kL20;Zj^P80^KVi0`2][Jd20:2PX080Vi^K0P2JVYX209VIV@80Vi^K0P2WYjL30;Fe
]@80_;bl0P31`L420<;2`P80`L710P33`l<20<C4a0<0`/;20P2o_kl20<;2`P80`<300P2ZZZX2096A
T@80ADE50`1?Cdl204i>CP80FEUI0P1KFe/205aLG080JVYZ0P1UIFD206QXJ0<0Jf][0P1bLW8207Qh
N0@0MgMg0P1nOWh208F5Q@<0R8R80P2<S8`209:BTP80V9RH0P2OWil20:JVYP80ZZZZ0`2][Jd20;2`
/080/K6a0P2c/k<20;Bd]080][Jf0P2g]kL30;Fe]@80/k>c0P2a/K460;2`/0D0/K6a102`/;020:n_
[`P0b>3H00060<SPf0808B4Q0P0[:b/203Ph>0<0<S8b0P0_;bl203Hf=P80?Shn0P0l?3`203Lg=`80
<c<c0`0a<C42030`<080<S8b0P13@d<202PX:080:RXZ0P0[:b/302XZ:P80:BTY0P0/;2`2038b<P80
<30`0P0^;Rh2034a<@<0=3@d0P0i>CT2030`<080<c<c0P1=CDd203Lg=`80;2`/0P0S8b<302PX:080
=3@d0P1IFET205QHF080J6QX0P10@40202@T90<0<C4a0P1DE5@205iNGP80<C4a100c<c<202PX:0<0
8B4Q0P0T92@20492@P80M7Ad0P2>SXh209NGU`80O7al0`1WIfL205eMG@80MgMg0P2IVIT20<;2`P80
^KVi0P2a/K430:NWY`80Z:RX0P2[Zj/20;:b/P80]kNg0P2j^[X20;Vi^@<0[Jf]0P2PX:0209^KV`80
VYZJ0P2IVIT209^KV`80YjNW0`2e]KD20;bl_080`L710P32`/820<71`@80`l?30P34a<@30<;2`P80
_kno0P32`/820<30`080ZZZZ0P2ATI4204E5A@<0Cdm?0P1>CTh205UIF@80Fe]K0P1LG5`206YZJP80
IFEU0P1XJ6P306][J`80LW9b0P1hN7P407MgM`80OWin0P25QHD308R8R080S8b<0P2BTY8209RHV080
WinO0P2VYZH20:ZZZP<0[Jf]0P2`/;020;6a/@80/k>c0P2d];@20;Jf]P80]kNg0`2e]KD20;>c/`80
/K6a1P2`/;050;6a/@@0/;2`0P2_[jl80<SPf0001P38h=P2020P8080:2PX0P0b<S83034a<@80<S8b
0P0k>c/204A4A080ADE50P12@T8203`l?0<0=SHf0P0c<c<203Hf=P80B4Q80P0Y:BT402/[:`<0:2PX
0P0V9RH202LW9`80:BTY0P0/;2`202l_;`80<C4a0`0`<30203dm?@80:b/[0P0d=3@205MGE`80?clo
0P0Z:RX2024Q8@<092@T0P0`<302059BDP80Hf=S0P1VIVH20410@0807QhN0`0Y:BT204M7A`80Lg=c
0P0j>SX204M7A`80BTY:0P0j>SX302TY:@808R8R0P0W9bL204a<C080N7Qh0P2TY:@209BDU0<0MgMg
0P1IFET2069RHP80N7Qh0P2b/[820<G5a@80^KVi0`2VYZH20:FUY@80Z:RX0P2][Jd20;:b/P@0]KFe
0`2][Jd20:BTY080WIfM0P2IVIT209RHV080Vi^K0P2UYJD30;6a/@80^[Zj1030`<020;jn_P80`L71
0P34a<@30<30`080^k^k0P2i^KT20;Ng]`80^k^k0P2d];@20:2PX0<0IVIV0P1?Cdl204=3@`80Cdm?
0P1PH60207YjNP80Kfm_0P1fMWH307alO080Ph>30P2:RXX208n?S`80Ti>C0P2DU9@209FEU@<0UiNG
0P2IVIT209nOW`80YJFU0P2XZ:P20:ZZZP80[:b/0`2][Jd20:n_[`H0/K6a0P2d];@20;Jf]P<0]KFe
0P2b/[820;6a/@80[jn_0P2`/;070;6a/@80/[:b102c/k<80<SPf0001P38h=P2020P8080:2PX0P0b
<S83034a<@80<S8b0P0k>c/204A4A080ADE50P12@T8203`l?0<0=SHf0P0c<c<203Hf=P80B4Q80P0Y
:BT402/[:`<0:2PX0P0V9RH202LW9`80:BTY0P0/;2`202l_;`80<C4a0`0`<30203dm?@80:b/[0P0d
=3@205MGE`80?clo0P0Z:RX2024Q8@<092@T0P0`<302059BDP80Hf=S0P1VIVH20410@0807QhN0`0Y
:BT204M7A`80Lg=c0P0j>SX204M7A`80BTY:0P0j>SX302TY:@808R8R0P0W9bL204a<C080N7Qh0P2T
Y:@209BDU0<0MgMg0P1IFET2069RHP80N7Qh0P2b/[820<G5a@80^KVi0`2VYZH20:FUY@80Z:RX0P2]
[Jd20;:b/P@0]KFe0`2][Jd20:BTY080WIfM0P2IVIT209RHV080Vi^K0P2UYJD30;6a/@80^[Zj1030
`<020;jn_P80`L710P34a<@30<30`080^k^k0P2i^KT20;Ng]`80^k^k0P2d];@20:2PX0<0IVIV0P1?
Cdl204=3@`80Cdm?0P1PH60207YjNP80Kfm_0P1fMWH307alO080Ph>30P2:RXX208n?S`80Ti>C0P2D
U9@209FEU@<0UiNG0P2IVIT209nOW`80YJFU0P2XZ:P20:ZZZP80[:b/0`2][Jd20:n_[`H0/K6a0P2d
];@20;Jf]P<0]KFe0P2b/[820;6a/@80[jn_0P2`/;070;6a/@80/[:b102c/k<80<SPf0001P38h=P2
020P80809BDU0P0[:b/303Lg=`80:BTY0P0^;Rh203@d=080BTY:0P1NGUh206=SH`<0H61P0P1LG5`2
0492@P80B4Q80P0n?Sh203Ti>@80<S8b0`0/;2`402PX:080:RXZ0P0];Bd2030`<080<c<c0`0f=SH2
03Ph>080:b/[0P0c<c<2051@D080FUYJ0P0X:2P502@T9080;2`/0P11@D4206MWI`80JVYZ0P11@D42
028R8P<092@T0P0h>3P206YZJP80ATI60P0c<c<203Ph>080=SHf0`0c<c<202XZ:P8092@T0P0c<c<2
055AD@80R8R80P2JVYX308f=S@80HV9R0P1LG5`2069RHP80Shn?0P2^[Zh20;fm_@<0[jn_0P2WYjL2
0:>SX`80Z:RX0P2_[jl40;6a/@<0[Zj^0P2XZ:P20::RXP80WIfM0P2KVi/209jNWP80YjNW0`2a/K42
0;Zj^P80`<300P2o_kl20;bl_080_[jn0P2o_kl30;jn_P80_;bl0P2i^KT20;Ng]`@0^KVi0P2h^;P3
0:VYZ@80Rh^;0P1^KVh206UYJ@80Jf][0P1mOGd207inOP80QXJ60`2;Rh/2092@T080U9BD0P2IVIT2
09bLW080WYjN0P2OWil30:2PX080XZ:R0P2VYZH20:VYZ@@0ZZZZ0P2/[:`30:n_[`@0/;2`102a/K42
0;>c/`L0];Bd0P2b/[860;6a/@80/[:b0`2c/k<20;Fe]@@0][Jf2038h=P000H0b>3H0P0P820202DU
9@80:b/[0`0g=cL202TY:@80;Rh^0P0d=3@204Y:BP80GUiN0P1SHf<3061PH080G5aL0P12@T8204Q8
B080?Shn0P0i>CT2038b<P<0;2`/100X:2P202XZ:P80;Bd]0P0`<30203<c<`<0=SHf0P0h>3P202/[
:`80<c<c0P1@D50205YJFP80:2PX1@0T92@202`/;080@D510P1WIfL206YZJP80@D510P0R8R8302@T
9080>3Ph0P1ZJVX204I6AP80<c<c0P0h>3P203Hf=P<0<c<c0P0Z:RX202@T9080<c<c0P1ADE4208R8
R080VYZJ0`2=SHd2069RHP80G5aL0P1RHV8208n?S`80[Zj^0P2m_Kd30:n_[`80YjNW0P2SXj<20:RX
Z080[jn_102a/K430:j^[P80Z:RX0P2RXZ8209fMW@80Vi^K0P2NWYh20:NWY`<0/K6a0P2j^[X20<30
`080_kno0P2l_;`20;jn_P80_kno0`2n_[h20;bl_080^KVi0P2g]kL40;Vi^@80^;Rh0`2YZJT208^;
R`80KVi^0P1YJFT206][J`80OGem0P1nOWh208J6QP<0Rh^;0P2@T90209BDU080VIVI0P2LW9`209jN
WP80WinO0`2PX:020::RXP80YZJV0P2YZJT40:ZZZP80[:b/0`2_[jl40;2`/0@0/K6a0P2c/k<70;Bd
]080/[:b1P2a/K420;:b/P<0/k>c0P2e]KD40;Jf]PP0b>3H00060<SPf0808R8R0P0T92@202DU9@<0
>c/k0P0R8R8202LW9`80:b/[0P0h>3P204E5A@80EUIF0`1OGel206i^KP80D51@0P1>CTh2055AD@80
ADE50P0h>3P3030`<0@0:b/[0P0/;2`202d];@80<30`0P0g=cL303dm?@80<C4a0P0Y:BT2034a<@80
AdM70P1cLg<202XZ:P80:2PX0`0U9BD202XZ:P80<S8b0P1WIfL206i^KP80@T920P0X:2P302<S8`80
:b/[0P1MGEd205YJFP80<30`0P0R8R8202`/;0<0>c/k0P0a<C4202HV9P808R8R0P0/;2`2069RHP80
TY:B0`2KVi/206i^KP80GEeM0P1DE5@206a/K080Shn?0P2f][H30;Bd]080Zj^[0P2PX:020:FUY@80
[:b/1`2][Jd20:^[Z`80YZJV0P2PX:0209nOW`80X:2P0P2XZ:P30;:b/P80^[Zj0P30`<020;jn_P80
^k^k0P2j^[X20;^k^`D0_;bl0P2g]kL60;:b/PD0[jn_0P2XZ:P209jNWP80RHV90P1iNGT207moO`80
SHf=0P2CTi<309RHV080VYZJ0P2KVi/209jNWP80X:2P0P2SXj<20:FUY@<0YZJV102WYjL40:RXZ080
ZJVY0P2/[:`30:j^[P@0[jn_0P2`/;040;:b/P80/K6a0`2c/k<20;Fe]@80];Bd0P2c/k<40;6a/@80
/k>c0`2e]KD20;Ng]`@0^;Rh2038h=P000H0b>3H0P0R8R8202@T90809BDU0`0k>c/2028R8P809bLW
0P0[:b/203Ph>080ADE50P1FEUH305mOG`80KVi^0P1@D50204i>CP80DE5A0P15ADD203Ph>0<0<30`
100[:b/202`/;080;Bd]0P0`<30203Lg=`<0?Cdm0P0a<C4202TY:@80<C4a0P17AdL207=cL`80:RXZ
0P0X:2P302DU9@80:RXZ0P0b<S8206MWI`80KVi^0P12@T8202PX:0<08b<S0P0[:b/205eMG@80FUYJ
0P0`<302028R8P80;2`/0`0k>c/2034a<@809RHV0P0R8R8202`/;080HV9R0P2BTY8309^KV`80KVi^
0P1MGEd205ADE080K6a/0P2?Shl20;Jf]P<0];Bd0P2[Zj/20:2PX080YJFU0P2/[:`70:f][@80Zj^[
0P2VYZH20:2PX080WinO0P2PX:020:RXZ0<0/[:b0P2j^[X20<30`080_[jn0P2k^k/20;Zj^P80^k^k
1@2l_;`20;Ng]`H0/[:b1@2_[jl20:RXZ080WYjN0P29RHT207UiN@80Ogmo0P2=SHd209>CT`<0V9RH
0P2JVYX209^KV`80WYjN0P2PX:020:>SX`80YJFU0`2VYZH40:NWY`@0Z:RX0P2YZJT20:b/[0<0[Zj^
102_[jl20;2`/0@0/[:b0P2a/K430;>c/`80]KFe0P2d];@20;>c/`@0/K6a0P2c/k<30;Fe]@80]kNg
102h^;P80<SPf0001P38h=P202XZ:P80;2`/0P0R8R8303De=@80;bl_0P0Z:RX203<c<`80?3`l0P16
ATH204Q8B0<0Bd];0P1]KFd207=cL`80JVYZ0P16ATH204Q8B080CDe=0`0n?Sh202h^;P80:2PX0P0Y
:BT202XZ:P80;2`/0P0m?Cd303Ti>@80;Bd]0P0U9BD202l_;`80?Cdm0P1eMGD203Lg=`80:RXZ0`0U
9BD202`/;080=SHf0P1WIfL206QXJ080@4100P0a<C4302l_;`8092@T0P1@D50207emO@80>CTi0P0b
<S8202LW9`<0<S8b100d=3@202LW9`808b<S0P12@T8206e]K@<0V9RH0P2<S8`2071`L080E5AD0P1J
FUX2079bLP80X:2P0`2h^;P20;no_`80Y:BT0P2QXJ420:BTY080YjNW0P2XZ:P30:VYZ@80YjNW0P2S
Xj<209nOW`80WYjN0P2QXJ420:RXZ0<0/K6a0P2j^[X20<30`080_kno0P2l_;`20;Vi^@80]kNg0`2j
^[X20;^k^`80][Jf102`/;020;6a/@80^;Rh0`2d];@20;Jf]P80]KFe0P2/[:`20::RXP80VIVI0P2E
UID209NGU`<0Vi^K0P2NWYh20:6QX@80Xj>S0P2TY:@20:FUY@/0YZJV0P2WYjL20:VYZ@80ZZZZ0`2[
Zj/20:f][@80[Zj^0P2`/;020;:b/P80/K6a0P2`/;030;6a/@@0/k>c102b/[870;6a/@80];Bd102h
^;P80<SPf0001P38h=P202XZ:P80;2`/0P0R8R8303De=@80;bl_0P0Z:RX203<c<`80?3`l0P16ATH2
04Q8B0<0Bd];0P1]KFd207=cL`80JVYZ0P16ATH204Q8B080CDe=0`0n?Sh202h^;P80:2PX0P0Y:BT2
02XZ:P80;2`/0P0m?Cd303Ti>@80;Bd]0P0U9BD202l_;`80?Cdm0P1eMGD203Lg=`80:RXZ0`0U9BD2
02`/;080=SHf0P1WIfL206QXJ080@4100P0a<C4302l_;`8092@T0P1@D50207emO@80>CTi0P0b<S82
02LW9`<0<S8b100d=3@202LW9`808b<S0P12@T8206e]K@<0V9RH0P2<S8`2071`L080E5AD0P1JFUX2
079bLP80X:2P0`2h^;P20;no_`80Y:BT0P2QXJ420:BTY080YjNW0P2XZ:P30:VYZ@80YjNW0P2SXj<2
09nOW`80WYjN0P2QXJ420:RXZ0<0/K6a0P2j^[X20<30`080_kno0P2l_;`20;Vi^@80]kNg0`2j^[X2
0;^k^`80][Jf102`/;020;6a/@80^;Rh0`2d];@20;Jf]P80]KFe0P2/[:`20::RXP80VIVI0P2EUID2
09NGU`<0Vi^K0P2NWYh20:6QX@80Xj>S0P2TY:@20:FUY@/0YZJV0P2WYjL20:VYZ@80ZZZZ0`2[Zj/2
0:f][@80[Zj^0P2`/;020;:b/P80/K6a0P2`/;030;6a/@@0/k>c102b/[870;6a/@80];Bd102h^;P8
0<SPf0001P38h=P2038b<P80>3Ph0P0Q8B4302`/;080>SXj0P0`<30203`l?080?clo0P10@40203Lg
=`<0<S8b0P1<C4`206ATI080KVi^100k>c/203`l?0<0=cLg0P0b<S8202TY:@809BDU0P0W9bL202TY
:@80@D510`0d=3@202`/;0808R8R0P0/;2`203De=@80KVi^0P18B4P202`/;0<09BDU0P0^;Rh203hn
?P80HV9R0P1NGUh203`l?080=CDe0`0o?cl202DU9@80:BTY0P1BDU8207moO`80=cLg0P0Z:RX302/[
:`8092@T0P0Q8B4201lO7`808b<S0P0^;Rh204M7A`<0N7Qh0P21PH4207=cL`80H61P0P1KFe/205mO
G`80MgMg0`2EUID20;bl_080Zj^[0P2UYJD209nOW`80XJ6Q1@2TY:@20:>SX`80X:2P0P2MWId209jN
WP80XJ6Q0P2XZ:P30;2`/080^KVi1030`<020;fm_@80^KVi0P2e]KD30;Rh^080^[Zj0P2e]KD20:n_
[`80[Jf]0P2[Zj/20;no_`<0/K6a0P2/[:`40:BTY080YJFU0P2QXJ4209fMW@D0Vi^K0P2OWil20:BT
Y0P0YJFU0`2TY:@60:>SX`80YZJV102XZ:P30:NWY`80ZZZZ0P2][Jd20;2`/080/[:b0P2`/;050:n_
[`80/;2`102a/K440;:b/P80/;2`0`2^[Zh20;:b/P80^;Rh0P2i^KT80<SPf0001P38h=P2038b<P80
>3Ph0P0Q8B4302`/;080>SXj0P0`<30203`l?080?clo0P10@40203Lg=`<0<S8b0P1<C4`206ATI080
KVi^100k>c/203`l?0<0=cLg0P0b<S8202TY:@809BDU0P0W9bL202TY:@80@D510`0d=3@202`/;080
8R8R0P0/;2`203De=@80KVi^0P18B4P202`/;0<09BDU0P0^;Rh203hn?P80HV9R0P1NGUh203`l?080
=CDe0`0o?cl202DU9@80:BTY0P1BDU8207moO`80=cLg0P0Z:RX302/[:`8092@T0P0Q8B4201lO7`80
8b<S0P0^;Rh204M7A`<0N7Qh0P21PH4207=cL`80H61P0P1KFe/205mOG`80MgMg0`2EUID20;bl_080
Zj^[0P2UYJD209nOW`80XJ6Q1@2TY:@20:>SX`80X:2P0P2MWId209jNWP80XJ6Q0P2XZ:P30;2`/080
^KVi1030`<020;fm_@80^KVi0P2e]KD30;Rh^080^[Zj0P2e]KD20:n_[`80[Jf]0P2[Zj/20;no_`<0
/K6a0P2/[:`40:BTY080YJFU0P2QXJ4209fMW@D0Vi^K0P2OWil20:BTY0P0YJFU0`2TY:@60:>SX`80
YZJV102XZ:P30:NWY`80ZZZZ0P2][Jd20;2`/080/[:b0P2`/;050:n_[`80/;2`102a/K440;:b/P80
/;2`0`2^[Zh20;:b/P80^;Rh0P2i^KT80<SPf0001P38h=P203Hf=P80DU9B0P0X:2P302TY:@80<30`
0P0h>3P403<c<`80<C4a0P0];Bd302`/;080=3@d0P19BDT406e]K@80JFUY0P1;Bd/303Xj>P80<S8b
0P0a<C4202<S8`809RHV0P0[:b/203`l?0<0>3Ph0P0^;Rh202HV9P80:RXZ0P0b<S8205eMG@80FEUI
0P0_;bl3028R8P80;Rh^0P12@T82051@D080CTi>0P10@40204=3@`<0@T920P0];Bd202LW9`80@T92
0P1cLg<206MWI`80AdM70`0Y:BT2024Q8@80820P0P0N7Qh2020P80808R8R0P0`<30305EEE@80LW9b
0P25QHD207]kN`80KVi^0P1WIfL206i^KP<0P8200P2TY:@20:ZZZP80]KFe0P2SXj<209nOW`80X:2P
1@2QXJ420:2PX080WinO0P2PX:020::RXP80ZJVY0`2`/;020;Rh^0@0_kno0P2l_;`20;Vi^@80]kNg
0`2j^[X20;^k^`80]KFe0P2^[Zh20:>SX`80W9bL0P2i^KT50;>c/`80[Zj^0P2ZZZX20:RXZ080YJFU
0P2RXZ8209jNWP<0Vi^K0P2MWId20:2PX080XZ:R0P2TY:@40:JVYP<0Y:BT102QXJ420::RXP80Y:BT
0P2WYjL50:JVYP80ZZZZ0P2][Jd20:n_[`80/;2`0P2_[jl50:j^[P80[jn_0P2a/K420;:b/P80/k>c
0P2d];@20;:b/P<0/K6a0P2e]KD20;Vi^@80^[Zj2038h=P000H0b>3H0P0f=SH2059BDP80:2PX0`0Y
:BT2030`<080>3Ph100c<c<2034a<@80;Bd]0`0/;2`203@d=080BDU9101]KFd206UYJ@80Bd];0`0j
>SX2038b<P80<C4a0P0S8b<202HV9P80:b/[0P0l?3`303Ph>080;Rh^0P0V9RH202XZ:P80<S8b0P1M
GEd205UIF@80;bl_0`0R8R8202h^;P80@T920P1@D50204i>CP80@4100P13@d<30492@P80;Bd]0P0W
9bL20492@P80Lg=c0P1WIfL204M7A`<0:BTY0P0Q8B42020P80807QhN0P0P8202028R8P80<30`0`1E
EED2079bLP80QHF50P1kNg/206i^KP80IfMW0P1^KVh30820P080Y:BT0P2ZZZX20;Fe]@80Xj>S0P2O
Wil20:2PX0D0XJ6Q0P2PX:0209nOW`80X:2P0P2RXZ820:VYZ@<0/;2`0P2h^;P40;no_`80_;bl0P2i
^KT20;Ng]`<0^[Zj0P2k^k/20;Fe]@80[Zj^0P2SXj<209bLW080^KVi1@2c/k<20:j^[P80ZZZZ0P2X
Z:P20:FUY@80XZ:R0P2NWYh309^KV`80WIfM0P2PX:020::RXP80Y:BT102VYZH30:BTY0@0XJ6Q0P2R
XZ820:BTY080YjNW1@2VYZH20:ZZZP80[Jf]0P2_[jl20;2`/080[jn_1@2^[Zh20:n_[`80/K6a0P2b
/[820;>c/`80];Bd0P2b/[830;6a/@80]KFe0P2i^KT20;Zj^PP0b>3H00060<SPf080=SHf0P1BDU82
02PX:0<0:BTY0P0`<30203Ph>0@0<c<c0P0a<C4202d];@<0;2`/0P0d=3@204U9B@@0KFe]0P1YJFT2
04];B`<0>SXj0P0b<S82034a<@808b<S0P0V9RH202/[:`80?3`l0`0h>3P202h^;P809RHV0P0Z:RX2
038b<P80GEeM0P1IFET202l_;`<08R8R0P0^;Rh20492@P80D51@0P1>CTh20410@080@d=30`12@T82
02d];@809bLW0P12@T8207=cL`80IfMW0P17AdL302TY:@808B4Q0P0P820201hN7P80820P0P0R8R82
030`<0<0EEEE0P1bLW8208F5Q@80Ng]k0P1^KVh206MWI`80KVi^0`20P8020:BTY080ZZZZ0P2e]KD2
0:>SX`80WinO0P2PX:050:6QX@80X:2P0P2OWil20:2PX080XZ:R0P2YZJT30;2`/080^;Rh102o_kl2
0;bl_080^KVi0P2g]kL30;Zj^P80^k^k0P2e]KD20:j^[P80Xj>S0P2LW9`20;Vi^@D0/k>c0P2^[Zh2
0:ZZZP80Z:RX0P2UYJD20::RXP80WYjN0`2KVi/209fMW@80X:2P0P2RXZ820:BTY0@0YZJV0`2TY:@4
0:6QX@80XZ:R0P2TY:@20:NWY`D0YZJV0P2ZZZX20:f][@80[jn_0P2`/;020:n_[`D0[Zj^0P2_[jl2
0;6a/@80/[:b0P2c/k<20;Bd]080/[:b0`2a/K420;Fe]@80^KVi0P2j^[X80<SPf0001P38h=P203Hf
=P80Hf=S0P0_;bl302HV9P808R8R0P0n?Sh202PX:0809bLW0P0S8b<202LW9`<0;Bd]0P0a<C4203Xj
>P80BTY:0P1IFET2071`L080G5aL0`14A4@203<c<`80>3Ph0P0S8b<202LW9`80;Bd]0P0e=CD303`l
?080<S8b0P0Z:RX202TY:@80<30`0P1<C4`206IVIP80<c<c0`0P820202l_;`80B4Q80P11@D4203lo
?`80<S8b0P0X:2P302d];@80=cLg0P0^;Rh202l_;`80HF5Q0P2>SXh2065QH@<0:BTY0P0N7Qh201lO
7`807AdM100N7Qh202DU9@<0@T920P1WIfL2096AT@80SXj>0P25QHD207QhN080KVi^0`1]KFd208N7
Q`80Xj>S0P2o_kl20:RXZ080XJ6Q0P2NWYh309nOW`H0XJ6Q0P2RXZ820:BTY080ZZZZ0`2a/K420;Rh
^0@0_Kfm0P2k^k/40;Zj^PD0^k^k0P2d];@20:^[Z`80UiNG0P2<S8`20;6a/@<0];Bd0P2i^KT20;Jf
]P80[Jf]1P2VYZH20:6QX@<0W9bL0P2JVYX209^KV`80WIfM0P2QXJ420:BTY080YZJV0`2SXj<409nO
W`80XJ6Q0P2SXj<40:FUY@<0YZJV0P2ZZZX20:f][@H0[Zj^0P2][Jd30:j^[P80[jn_0P2a/K420;:b
/P80];Bd1`2e]KD20;Rh^0@0^k^k2038h=P000H0b>3H0P0f=SH206=SH`80;bl_0`0V9RH2028R8P80
?Shn0P0X:2P202LW9`808b<S0P0W9bL302d];@80<C4a0P0j>SX204Y:BP80FEUI0P1`L70205aLG0<0
A4A40P0c<c<203Ph>0808b<S0P0W9bL202d];@80=CDe0`0l?3`2038b<P80:RXZ0P0Y:BT2030`<080
C4a<0P1VIVH203<c<`<0820P0P0_;bl204Q8B080@D510P0o?cl2038b<P80:2PX0`0];Bd203Lg=`80
;Rh^0P0_;bl2065QH@80SXj>0P1QHF4302TY:@807QhN0P0O7al201dM7@@07QhN0P0U9BD30492@P80
IfMW0P2ATI4208j>SP80QHF50P1hN7P206i^KP<0KFe]0P27QhL20:>SX`80_kno0P2XZ:P20:6QX@80
WYjN0`2OWil60:6QX@80XZ:R0P2TY:@20:ZZZP<0/K6a0P2h^;P40;fm_@80^k^k102j^[X50;^k^`80
];Bd0P2[Zj/209NGU`80S8b<0P2a/K430;Bd]080^KVi0P2f][H20:f][@H0YZJV0P2QXJ4309bLW080
VYZJ0P2KVi/209fMW@80XJ6Q0P2TY:@20:JVYP<0Xj>S102OWil20:6QX@80Xj>S102UYJD30:JVYP80
ZZZZ0P2][Jd60:j^[P80[Jf]0`2^[Zh20:n_[`80/K6a0P2b/[820;Bd]0L0]KFe0P2h^;P40;^k^`P0
b>3H00060<SPf0809bLW0P1CDe<2051@D0<0@T920P0_;bl20451@@809bLW0P0S8b<2024Q8@80:BTY
0`0g=cL205EEE@80C4a<0P14A4@203lo?`80EeMG0P1JFUX305ADE080>SXj0P0g=cL202HV9P80:BTY
0P0^;Rh2038b<P<0=SHf0P0i>CT202XZ:P809bLW0P0/;2`204A4A080IFEU0P0k>c/302HV9P80>SXj
0P1EEED203Xj>P80<S8b0P0g=cL202DU9@<09bLW0P0_;bl203/k>`80<30`0P1FEUH207emO@80EEEE
0`0T92@201hN7P808B4Q0P0M7Ad201hN7P8092@T0P0a<C4305mOG`80I6AT0P29RHT209JFUP80Xj>S
0P2<S8`207QhN0<0Jf][0P1gMgL208b<S080YJFU0P2ZZZX20:n_[`80WYjN0`2OWil40:6QX@80XZ:R
0P2TY:@20:NWY`80[Zj^0`2e]KD20;Zj^P80_;bl0P2k^k/20;Vi^@@0^k^k0`2j^[X20;Jf]P80[Jf]
0P2PX:0208N7Q`80P8200P2^[Zh30;2`/080_Kfm0P2o_kl20;Ng]`80[Zj^0P2YZJT20:JVYP80XJ6Q
0`2MWId209ZJVP80VIVI0P2JVYX209bLW080WIfM0P2PX:0309jNWP80W9bL0P2NWYh20:6QX@80XZ:R
0P2SXj<20:BTY0<0YZJV0P2YZJT20:b/[0@0[Jf]102/[:`30:j^[P80/;2`0P2a/K420;:b/P80/k>c
1`2e]KD20;Rh^080_;bl0P2m_Kd80<SPf0001P38h=P202LW9`80De=C0P1@D5030492@P80;bl_0P11
@D4202LW9`808b<S0P0Q8B4202TY:@<0=cLg0P1EEED204a<C080A4A40P0o?cl205MGE`80FUYJ0`1D
E5@203Xj>P80=cLg0P0V9RH202TY:@80;Rh^0P0b<S8303Hf=P80>CTi0P0Z:RX202LW9`80;2`/0P14
A4@206EUI@80>c/k0`0V9RH203Xj>P80EEEE0P0j>SX2038b<P80=cLg0P0U9BD302LW9`80;bl_0P0k
>c/2030`<080EUIF0P1mOGd205EEE@<092@T0P0N7Qh2024Q8@807AdM0P0N7Qh202@T9080<C4a0`1O
Gel206ATI080RHV90P2FUYH20:>SX`80S8b<0P1hN7P306][J`80MgMg0P2<S8`20:FUY@80ZZZZ0P2_
[jl209jNWP<0WinO102QXJ420::RXP80Y:BT0P2WYjL20:j^[P<0]KFe0P2j^[X20;bl_080^k^k0P2i
^KT40;^k^`<0^[Zj0P2f][H20:f][@80X:2P0P27QhL20820P080[Zj^0`2`/;020;fm_@80_kno0P2g
]kL20:j^[P80ZJVY0P2VYZH20:6QX@<0WIfM0P2JVYX209VIV@80VYZJ0P2LW9`209fMW@80X:2P0`2N
WYh209bLW080WYjN0P2QXJ420::RXP80Xj>S0P2TY:@30:JVYP80ZJVY0P2/[:`40:f][@@0[:b/0`2^
[Zh20;2`/080/K6a0P2b/[820;>c/`L0]KFe0P2h^;P20;bl_080_Kfm2038h=P000H0b>3H0P0U9BD2
030`<080@4100`0b<S82024Q8@80<c<c0P0Y:BT202LW9`809RHV0P0f=SH304Q8B080HV9R0P0f=SH2
02d];@809bLW0P0l?3`2055AD@<0GemO0P13@d<203Hf=P80:b/[0P0Z:RX202`/;0D0;bl_0P10@402
02XZ:P809bLW0P0X:2P20410@080GEeM0P14A4@302`/;080A4A40P1MGEd203Hf=P80:BTY0P0k>c/2
02<S8`<09bLW0P0[:b/204A4A080=CDe0P1>CTh205mOG`80@T920`0Q8B4201lO7`808b<S0P0N7Qh2
01lO7`80;bl_0P19BDT308F5Q@80Hf=S0P1RHV8206][J`80WinO0P2MWId208Z:RP<0L71`0P1^KVh2
07IfMP80QhN70P2VYZH20;Vi^@80X:2P1@2QXJ420::RXP80Xj>S0P2VYZH20:^[Z`80/[:b0`2h^;P2
0;^k^`80_;bl0P2j^[X20;Rh^080^k^k0P2l_;`30;Rh^080/K6a0P2UYJD209JFUP80Ng]k0P1iNGT2
0:j^[P<0Zj^[0P2m_Kd20<C4a080`<300P2g]kL20:j^[P80YZJV0P2RXZ8309nOW`80W9bL0P2IVIT2
09JFUP80UIFE0P2GUiL209^KV`D0VYZJ0P2MWId60:6QX@80Xj>S0`2VYZH20:VYZ@80Zj^[102/[:`4
0:^[Z`<0[Zj^1P2a/K420;>c/`L0];Bd0P2i^KT20;bl_080_Kfm2038h=P000H0b>3H0P0U9BD2030`
<080@4100`0b<S82024Q8@80<c<c0P0Y:BT202LW9`809RHV0P0f=SH304Q8B080HV9R0P0f=SH202d]
;@809bLW0P0l?3`2055AD@<0GemO0P13@d<203Hf=P80:b/[0P0Z:RX202`/;0D0;bl_0P10@40202XZ
:P809bLW0P0X:2P20410@080GEeM0P14A4@302`/;080A4A40P1MGEd203Hf=P80:BTY0P0k>c/202<S
8`<09bLW0P0[:b/204A4A080=CDe0P1>CTh205mOG`80@T920`0Q8B4201lO7`808b<S0P0N7Qh201lO
7`80;bl_0P19BDT308F5Q@80Hf=S0P1RHV8206][J`80WinO0P2MWId208Z:RP<0L71`0P1^KVh207If
MP80QhN70P2VYZH20;Vi^@80X:2P1@2QXJ420::RXP80Xj>S0P2VYZH20:^[Z`80/[:b0`2h^;P20;^k
^`80_;bl0P2j^[X20;Rh^080^k^k0P2l_;`30;Rh^080/K6a0P2UYJD209JFUP80Ng]k0P1iNGT20:j^
[P<0Zj^[0P2m_Kd20<C4a080`<300P2g]kL20:j^[P80YZJV0P2RXZ8309nOW`80W9bL0P2IVIT209JF
UP80UIFE0P2GUiL209^KV`D0VYZJ0P2MWId60:6QX@80Xj>S0`2VYZH20:VYZ@80Zj^[102/[:`40:^[
Z`<0[Zj^1P2a/K420;>c/`L0];Bd0P2i^KT20;bl_080_Kfm2038h=P000H0b>3H0P0T92@202XZ:P80
>3Ph0`0a<C4202LW9`80;Bd]0P0X:2P202d];@80<S8b0P1CDe<305QHF080De=C0P0a<C4202PX:080
:BTY0P0c<c<20492@P<0EUIF0P1ADE4203hn?P80;bl_0P0e=CD203dm?@80>CTi0`0`<3020492@P80
:RXZ0P0X:2P202TY:@80>c/k0P1ADE42051@D0<0;2`/0P0l?3`204a<C080<c<c0P0[:b/203De=@80
:b/[0`0l?3`203hn?P80=cLg0P0^;Rh2051@D080E5AD0P0m?Cd302@T9080820P0P0R8R8201`L7080
8B4Q0P0i>CT206m_K`<0R8R80P1EEED20410@080CDe=0P22PX8209ZJVP80Vi^K0`1oOgl4071`L080
PX:20P2ATI440:^[Z`<0YjNW0P2OWil20::RXP80YZJV0P2ZZZX20:n_[`80/K6a0`2d];@20;^k^`80
`<300P2l_;`20;Rh^080^k^k0P2m_Kd30;Ng]`80[Zj^0P2HV9P209FEU@80Ng]k0P1lO7`20;6a/@<0
ZZZZ0P2i^KT20<30`080`/;20P2o_kl20;Ng]`80[Jf]0P2XZ:P30:BTY080WYjN0P2KVi/20:6QX@80
YJFU0P2ZZZX209^KV`D0V9RH0P2LW9`20:2PX080XZ:R1`2SXj<20:NWY`80Zj^[1P2/[:`20:f][@<0
[Zj^0P2`/;060;6a/@80/[:b0P2d];@30;Ng]`80^[Zj0P2l_;`20;fm_@P0b>3H00060<SPf08092@T
0P0Z:RX203Ph>0<0<C4a0P0W9bL202d];@80:2PX0P0];Bd2038b<P80De=C0`1HF5P205=CD`80<C4a
0P0X:2P202TY:@80<c<c0P12@T8305IFEP80DE5A0P0n?Sh202l_;`80=CDe0P0m?Cd203Ti>@<0<30`
0P12@T8202XZ:P80:2PX0P0Y:BT203/k>`80DE5A0P1@D50302`/;080?3`l0P1<C4`203<c<`80:b/[
0P0e=CD202/[:`<0?3`l0P0n?Sh203Lg=`80;Rh^0P1@D50205ADE080?Cdm0`0T92@2020P80808R8R
0P0L71`2024Q8@80>CTi0P1_Kfl308R8R080EEEE0P10@40204e=C@80PX:20P2JVYX209^KV`<0Ogmo
101`L70208:2PP80TI6A102[Zj/30:NWY`80WinO0P2RXZ820:JVYP80ZZZZ0P2_[jl20;6a/@<0];Bd
0P2k^k/20<30`080_;bl0P2h^;P20;^k^`80_Kfm0`2g]kL20:j^[P80V9RH0P2EUID207]kN`80O7al
0P2a/K430:ZZZP80^KVi0P30`<020<;2`P80_kno0P2g]kL20:f][@80Z:RX0`2TY:@209jNWP80Vi^K
0P2QXJ420:FUY@80ZZZZ0P2KVi/509RHV080W9bL0P2PX:020::RXPL0Xj>S0P2WYjL20:^[Z`H0[:b/
0P2][Jd30:j^[P80/;2`1P2a/K420;:b/P80];Bd0`2g]kL20;Zj^P80_;bl0P2m_Kd80<SPf0001P38
h=P202HV9P80:2PX1`0[:b/202LW9`80:2PX0P0e=CD20492@P80KVi^0`1PH60203hn?P80;Rh^0P0[
:b/2034a<@80;Rh^0P0`<30304I6AP80FEUI0P18B4P203@d=080;2`/0P0Y:BT2030`<0<0=CDe0P14
A4@202/[:`80:RXZ0P0[:b/203Lg=`80ADE50P1HF5P302h^;P80=3@d0P0h>3P2030`<0@0;Rh^0P0d
=3@305ADE080De=C0P0[:b/202d];@80DU9B0P1;Bd/203dm?@<0:b/[0P0T92@2028R8P807AdM0P0W
9bL204U9B@80Shn?0`20P80204A4A0808R8R0P0_;bl205YJFP80RXZ:0P2SXj<308j>SP80NWYj0P1b
LW8208>3P`80Ng]k0P2GUiL20;2`/0<0Zj^[0P2PX:020:>SX`80ZJVY0P2][Jd20;6a/@D0/;2`0P2j
^[X20<?3``80_[jn0P2h^;P20;^k^`80_Kfm0`2e]KD20:b/[080Shn?0P2FUYH20820P080Ph>30P2c
/k<30:VYZ@80];Bd0P2i^KT20<71`@80a/K60P30`<020;Ng]`80/;2`0`2YZJT20:BTY080X:2P0P2K
Vi/209JFUP80Zj^[0P2OWil309^KV`80V9RH0P2JVYX209jNWP80XJ6Q0P2TY:@20::RXP<0X:2P0P2U
YJD20:ZZZP80Zj^[0P2/[:`20:f][@D0[Zj^0P2][Jd20:n_[`80/K6a102`/;020;Fe]@<0^KVi0P2k
^k/40;bl_0P0b>3H00060<SPf0809RHV0P0X:2P702/[:`809bLW0P0X:2P203De=@80@T920P1^KVh3
061PH080?Shn0P0^;Rh202/[:`80<C4a0P0^;Rh2030`<0<0ATI60P1IFET204Q8B080=3@d0P0/;2`2
02TY:@80<30`0`0e=CD204A4A080:b/[0P0Z:RX202/[:`80=cLg0P15ADD205QHF0<0;Rh^0P0d=3@2
03Ph>080<30`100^;Rh203@d=0<0E5AD0P1CDe<202/[:`80;Bd]0P1BDU8204];B`80?Cdm0`0[:b/2
02@T90808R8R0P0M7Ad202LW9`80BDU90P2?Shl30820P080A4A40P0R8R8202l_;`80FUYJ0P2:RXX2
0:>SX`<0SXj>0P1jNWX2079bLP80Ph>30P1kNg/209NGU`80/;2`0`2[Zj/20:2PX080Xj>S0P2YZJT2
0:f][@80/K6a1@2`/;020;Zj^P80`l?30P2n_[h20;Rh^080^k^k0P2m_Kd30;Fe]@80[:b/0P2?Shl2
09JFUP80P8200P23Ph<20;>c/`<0ZJVY0P2d];@20;Vi^@80`L710P36a/H20<30`080]kNg0P2`/;03
0:VYZ@80Y:BT0P2PX:0209^KV`80UYJF0P2[Zj/209nOW`<0Vi^K0P2HV9P209ZJVP80WYjN0P2QXJ42
0:BTY080XZ:R0`2PX:020:FUY@80ZZZZ0P2[Zj/20:b/[080[Jf]1@2^[Zh20:f][@80[jn_0P2a/K44
0;2`/080]KFe0`2i^KT20;^k^`@0_;bl2038h=P000H0b>3H0P0V9RH202LW9`80:2PX0`0Z:RX202/[
:`809bLW0P0Z:RX203hn?P80E5AD0P1ZJVX304a<C080?Shn0P0m?Cd203hn?P80<C4a0P0g=cL203lo
?`<0ADE51018B4P2038b<P80;Rh^0P0/;2`2038b<P<0=cLg0P0o?cl2038b<P80;bl_0P0^;Rh203Hf
=P80?clo0P1?Cdl303dm?@80>SXj0P0e=CD202`/;0809bLW0P0[:b/203Hf=P<0IVIV0P1IFET2038b
<P80AdM70P1EEED204m?C`80CTi>0`0c<c<202/[:`809RHV0P0X:2P2038b<P80L71`0P2=SHd306a/
K080<C4a0P0J6QX202@T9080?Cdm0P1WIfL208f=S@D0UYJF0P1iNGT207]kN`80LW9b0P24Q8@209^K
V`<0Z:RX0P2_[jl20:b/[080Z:RX0P2ZZZX20:j^[P80/;2`0`2c/k<20;Zj^P80`<300P2m_Kd20;Vi
^@80^;Rh0P2f][H30;>c/`80[jn_0P2ATI4209JFUP@0RHV90P2a/K430:>SX`80[Jf]0P2c/k<20;jn
_P80a/K60P35aLD20;no_`80][Jf0`2[Zj/20:JVYP80XZ:R0P2PX:0209jNWP80Z:RX0P2QXJ430:2P
X080WYjN0P2JVYX209NGU`80W9bL0P2QXJ420:2PX0<0WinO0P2SXj<20:NWY`@0ZJVY0P2[Zj/70:f]
[@80[Zj^0P2_[jl20;6a/@80/k>c0P2f][H30;Vi^@80_;bl0P2m_Kd20;jn_PP0b>3H00060<SPf080
9RHV0P0W9bL202PX:0<0:RXZ0P0[:b/202LW9`80:RXZ0P0n?Sh205ADE080JVYZ0`1<C4`203hn?P80
?Cdm0P0n?Sh2034a<@80=cLg0P0o?cl304E5A@@0B4Q80P0b<S8202h^;P80;2`/0P0b<S8303Lg=`80
?clo0P0b<S8202l_;`80;Rh^0P0f=SH203lo?`80Cdm?0`0m?Cd203Xj>P80=CDe0P0/;2`202LW9`80
:b/[0P0f=SH306IVIP80FEUI0P0b<S8204M7A`80EEEE0P1?Cdl204i>CP<0<c<c0P0[:b/202HV9P80
:2PX0P0b<S82071`L080SHf=0`1/K6`2034a<@806QXJ0P0T92@203dm?@80IfMW0P2=SHd509JFUP80
NGUi0P1kNg/2079bLP80Q8B40P2KVi/30:RXZ080[jn_0P2/[:`20:RXZ080ZZZZ0P2^[Zh20;2`/0<0
/k>c0P2j^[X20<30`080_Kfm0P2i^KT20;Rh^080][Jf0`2c/k<20:n_[`80TI6A0P2FUYH408V9R@80
/K6a0`2SXj<20:f][@80/k>c0P2n_[h20<K6aP80aLG50P2o_kl20;Jf]P<0Zj^[0P2VYZH20::RXP80
X:2P0P2NWYh20:RXZ080XJ6Q0`2PX:0209jNWP80VYZJ0P2GUiL209bLW080XJ6Q0P2PX:0309nOW`80
Xj>S0P2WYjL40:VYZ@80Zj^[1`2][Jd20:j^[P80[jn_0P2a/K420;>c/`80][Jf0`2i^KT20;bl_080
_Kfm0P2n_[h80<SPf0001P38h=P402LW9`D0:2PX0P0Y:BT202PX:080;Bd]0P17AdL206ATI080GUiN
0`0c<c<203lo?`80BDU90P1BDU8203<c<`80:b/[0P0U9BD302h^;P80=SHf0P19BDT2034a<@80<30`
0P0^;Rh203<c<`D0>CTi0P0h>3P203@d=080<S8b0P0e=CD203Xj>P80@T920`1:BTX20451@@80=CDe
0P0Y:BT2028R8P80;2`/0P0g=cL3071`L080EUIF0P0o?cl2069RHP80ATI60P0i>CT2051@D0<0@410
0P0e=CD202XZ:P80=SHf0P16ATH209VIV@80Ph>30`1HF5P202@T90806a/K0P0O7al202HV9P80@D51
0P1]KFd309:BTP80Zj^[0P23Ph<207QhN080L71`0P1eMGD208>3P`<0X:2P0P2i^KT20;Bd]080ZJVY
0P2WYjL20:VYZ@80/;2`0`2g]kL20;^k^`80_;bl0P2k^k/20;Vi^@80];Bd0P2`/;050;:b/P80UiNG
0P2EUID2096AT@80T92@0P2/[:`309fMW@80YZJV0P2^[Zh20;^k^`80aLG50P38b<P20<K6aP80^k^k
0`2_[jl20:RXZ0@0Y:BT0P2UYJD40:BTY0<0YJFU0P2TY:@209ZJVP80TY:B0P2FUYH409fMW@<0WYjN
0P2QXJ420:BTY080YJFU0P2VYZH20:VYZ@80Zj^[1@2/[:`20:f][@80[Zj^0P2b/[820;Ng]`80^;Rh
0`2i^KT20;bl_080_kno0P30`<080<SPf0001P38h=P402LW9`D0:2PX0P0Y:BT202PX:080;Bd]0P17
AdL206ATI080GUiN0`0c<c<203lo?`80BDU90P1BDU8203<c<`80:b/[0P0U9BD302h^;P80=SHf0P19
BDT2034a<@80<30`0P0^;Rh203<c<`D0>CTi0P0h>3P203@d=080<S8b0P0e=CD203Xj>P80@T920`1:
BTX20451@@80=CDe0P0Y:BT2028R8P80;2`/0P0g=cL3071`L080EUIF0P0o?cl2069RHP80ATI60P0i
>CT2051@D0<0@4100P0e=CD202XZ:P80=SHf0P16ATH209VIV@80Ph>30`1HF5P202@T90806a/K0P0O
7al202HV9P80@D510P1]KFd309:BTP80Zj^[0P23Ph<207QhN080L71`0P1eMGD208>3P`<0X:2P0P2i
^KT20;Bd]080ZJVY0P2WYjL20:VYZ@80/;2`0`2g]kL20;^k^`80_;bl0P2k^k/20;Vi^@80];Bd0P2`
/;050;:b/P80UiNG0P2EUID2096AT@80T92@0P2/[:`309fMW@80YZJV0P2^[Zh20;^k^`80aLG50P38
b<P20<K6aP80^k^k0`2_[jl20:RXZ0@0Y:BT0P2UYJD40:BTY0<0YJFU0P2TY:@209ZJVP80TY:B0P2F
UYH409fMW@<0WYjN0P2QXJ420:BTY080YJFU0P2VYZH20:VYZ@80Zj^[1@2/[:`20:f][@80[Zj^0P2b
/[820;Ng]`80^;Rh0`2i^KT20;bl_080_kno0P30`<080<SPf0001P38h=P402LW9`D0:2PX0P0Y:BT2
02PX:080;Bd]0P17AdL206ATI080GUiN0`0c<c<203lo?`80BDU90P1BDU8203<c<`80:b/[0P0U9BD3
02h^;P80=SHf0P19BDT2034a<@80<30`0P0^;Rh203<c<`D0>CTi0P0h>3P203@d=080<S8b0P0e=CD2
03Xj>P80@T920`1:BTX20451@@80=CDe0P0Y:BT2028R8P80;2`/0P0g=cL3071`L080EUIF0P0o?cl2
069RHP80ATI60P0i>CT2051@D0<0@4100P0e=CD202XZ:P80=SHf0P16ATH209VIV@80Ph>30`1HF5P2
02@T90806a/K0P0O7al202HV9P80@D510P1]KFd309:BTP80Zj^[0P23Ph<207QhN080L71`0P1eMGD2
08>3P`<0X:2P0P2i^KT20;Bd]080ZJVY0P2WYjL20:VYZ@80/;2`0`2g]kL20;^k^`80_;bl0P2k^k/2
0;Vi^@80];Bd0P2`/;050;:b/P80UiNG0P2EUID2096AT@80T92@0P2/[:`309fMW@80YZJV0P2^[Zh2
0;^k^`80aLG50P38b<P20<K6aP80^k^k0`2_[jl20:RXZ0@0Y:BT0P2UYJD40:BTY0<0YJFU0P2TY:@2
09ZJVP80TY:B0P2FUYH409fMW@<0WYjN0P2QXJ420:BTY080YJFU0P2VYZH20:VYZ@80Zj^[1@2/[:`2
0:f][@80[Zj^0P2b/[820;Ng]`80^;Rh0`2i^KT20;bl_080_kno0P30`<080<SPf0001P38h=P202/[
:`80:2PX0P0V9RH302PX:080:b/[0P0Y:BT202h^;P80Bd];0P1[Jf/2051@D0<0:RXZ0P0`<30203Ti
>@80@T920P0f=SH203<c<`80<30`0`0_;bl2030`<080@T920P0m?Cd203<c<`80;2`/0P0`<30303Hf
=P80>3Ph0P0k>c/203Hf=P80<S8b0P0a<C4203@d=080>c/k0`18B4P203dm?@80<c<c0P0[:b/202LW
9`80<S8b0P0o?cl3071`L080G5aL0P1?Cdl2061PH080@d=30P1;Bd/2069RHP<0Hf=S0P1NGUh205UI
F@80G5aL0P1dM7@20;Bd]080QhN70`1MGEd202/[:`807QhN0P0M7Ad201`L7080:b/[0P1;Bd/3075a
L@80XJ6Q0P2DU9@208J6QP80MgMg0P1cLg<207MgM`<0SHf=0P2VYZH20;>c/`80^KVi0P2^[Zh20:JV
YP80[Zj^1@2i^KT20;Zj^P80^;Rh0P2f][H20;:b/P80/;2`1@2c/k<209^KV`80T92@0P2DU9@209ZJ
VP80YJFU0`2PX:020:NWY`80[jn_0P2j^[X20<?3``@0b<S80P31`L430;Rh^080[Zj^0P2UYJD20:JV
YP80ZJVY102WYjL30:FUY@80Xj>S0P2NWYh209VIV@80UiNG0P2FUYH209RHV0<0W9bL0P2OWil60:>S
X`80YjNW2`2[Zj/20;6a/@80][Jf0P2h^;P30;Zj^P80_Kfm1030`<080<SPf0001P38h=P202/[:`80
:2PX0P0V9RH302PX:080:b/[0P0Y:BT202h^;P80Bd];0P1[Jf/2051@D0<0:RXZ0P0`<30203Ti>@80
@T920P0f=SH203<c<`80<30`0`0_;bl2030`<080@T920P0m?Cd203<c<`80;2`/0P0`<30303Hf=P80
>3Ph0P0k>c/203Hf=P80<S8b0P0a<C4203@d=080>c/k0`18B4P203dm?@80<c<c0P0[:b/202LW9`80
<S8b0P0o?cl3071`L080G5aL0P1?Cdl2061PH080@d=30P1;Bd/2069RHP<0Hf=S0P1NGUh205UIF@80
G5aL0P1dM7@20;Bd]080QhN70`1MGEd202/[:`807QhN0P0M7Ad201`L7080:b/[0P1;Bd/3075aL@80
XJ6Q0P2DU9@208J6QP80MgMg0P1cLg<207MgM`<0SHf=0P2VYZH20;>c/`80^KVi0P2^[Zh20:JVYP80
[Zj^1@2i^KT20;Zj^P80^;Rh0P2f][H20;:b/P80/;2`1@2c/k<209^KV`80T92@0P2DU9@209ZJVP80
YJFU0`2PX:020:NWY`80[jn_0P2j^[X20<?3``@0b<S80P31`L430;Rh^080[Zj^0P2UYJD20:JVYP80
ZJVY102WYjL30:FUY@80Xj>S0P2NWYh209VIV@80UiNG0P2FUYH209RHV0<0W9bL0P2OWil60:>SX`80
YjNW2`2[Zj/20;6a/@80][Jf0P2h^;P30;Zj^P80_Kfm1030`<080<SPf0001P38h=P202l_;`80:RXZ
0P0U9BD302PX:080;Bd]0P0[:b/202l_;`80D51@0P1/K6`204=3@`<09RHV0P0S8b<202XZ:P80<30`
0P0h>3P203Xj>P80>CTi0`0c<c<2030`<080>c/k0P16ATH203Ph>080:b/[0P0/;2`3038b<P80=cLg
0P0k>c/203Lg=`80<S8b0P0^;Rh202l_;`80=3@d0`12@T8203/k>`80<c<c100^;Rh203/k>`80ATI6
0`1JFUX204=3@`80CTi>0P1IFET204a<C080IFEU0P1PH60305]KF`80D51@0P1;Bd/203hn?P80GemO
0P2UYJD208Z:RP<0IFEU0P0d=3@202<S8`807QhN0P0I6AT201hN7P80;Bd]0`1;Bd/208N7Q`80W9bL
0P2EUID208B4Q080N7Qh0P1bLW8307alO080SXj>0P2/[:`20<C4a080]KFe0P2UYJD20:b/[0L0]kNg
0P2d];@20;6a/@@0/;2`0`2c/k<20;:b/P80WYjN0P2;Rh/209BDU0@0XZ:R0`2UYJD20:ZZZP80/;2`
0P2i^KT20<71`@80aLG50P37alL20<G5a@<0`<300P2b/[820:JVYP80Z:RX0P2/[:`20:^[Z`80ZJVY
0`2UYJD20::RXP@0Xj>S0P2KVi/209>CT`80UIFE0`2IVIT209fMW@H0XJ6Q0P2VYZH50:ZZZP@0ZJVY
0P2ZZZX20:n_[`80]KFe0P2h^;P30;^k^`80_[jn0P30`<020<71`@P0b>3H00060<SPf080;bl_0P0Z
:RX202DU9@<0:2PX0P0];Bd202/[:`80;bl_0P1@D50206a/K080@d=30`0V9RH202<S8`80:RXZ0P0`
<30203Ph>080>SXj0P0i>CT303<c<`80<30`0P0k>c/204I6AP80>3Ph0P0[:b/202`/;0<0<S8b0P0g
=cL203/k>`80=cLg0P0b<S8202h^;P80;bl_0P0d=3@30492@P80>c/k0P0c<c<402h^;P80>c/k0P16
ATH305YJFP80@d=30P1>CTh205UIF@80C4a<0P1UIFD2061PH0<0Fe]K0P1@D50204];B`80?Shn0P1O
Gel20:FUY@80RXZ:0`1UIFD203@d=0808b<S0P0N7Qh201TI6@807QhN0P0];Bd304];B`80QhN70P2L
W9`209FEU@80Q8B40P1hN7P2079bLP<0O7al0P2>SXh20:b/[080a<C40P2e]KD20:FUY@80[:b/1`2g
]kL20;Bd]080/K6a102`/;030;>c/`80/[:b0P2NWYh208^;R`80U9BD102RXZ830:FUY@80ZZZZ0P2`
/;020;Vi^@80`L710P35aLD20<O7a`80aLG50`30`<020;:b/P80YZJV0P2XZ:P20:b/[080Zj^[0P2Y
ZJT30:FUY@80XZ:R102SXj<209^KV`80Ti>C0P2EUID309VIV@80WIfM1P2QXJ420:JVYPD0ZZZZ102Y
ZJT20:ZZZP80[jn_0P2e]KD20;Rh^0<0^k^k0P2n_[h20<30`080`L712038h=P000H0b>3H0P0^;Rh2
02XZ:P809BDU0`0Y:BT202h^;P80;bl_0P0d=3@205mOG`80JVYZ0P14A4@302DU9@808b<S0P0Z:RX2
02/[:`80<c<c0P17AdL205IFEP<0@d=30P0a<C4203@d=080?3`l0P0o?cl202XZ:P80;Bd]0`0b<S82
03Hf=P@0>CTi0P0g=cL2030`<080:b/[0P0_;bl303Ti>@80@D510P0f=SH203@d=080<c<c0P0f=SH2
03Ti>@<0Bd];0P1=CDd206][J`80LG5a0P1]KFd207AdM080Fe]K0`1?Cdl203lo?`80?Cdm0P0g=cL2
061PH080Vi^K0P1^KVh304M7A`809RHV0P0W9bL401`L70807alO0P0S8b<3038b<P80GemO0P1nOWh2
09fMW@80VIVI0P29RHT207UiN@<0MgMg0P1nOWh209NGU`80[jn_0P2m_Kd20:f][@80Zj^[0`2/[:`2
0;Zj^P80];Bd0P2b/[820:f][@@0Zj^[0`2^[Zh20:f][@80Vi^K0P29RHT209BDU080Y:BT0P2^[Zh3
0:RXZ080[:b/0P2a/K420;Jf]P80_;bl0P31`L420<G5a@80a<C40`2o_kl20;Bd]0@0ZJVY0P2/[:`2
0:ZZZP80ZJVY0`2XZ:P40:NWY`80YZJV0P2QXJ4209bLW080V9RH0`2FUYH209NGU`80VYZJ0P2MWId2
0:2PX080YJFU2@2YZJT20:^[Z`80[jn_0P2d];@20;Rh^0<0^k^k0P2n_[h20<30`080`L712038h=P0
00H0b>3H0P0^;Rh202XZ:P809BDU0`0Y:BT202h^;P80;bl_0P0d=3@205mOG`80JVYZ0P14A4@302DU
9@808b<S0P0Z:RX202/[:`80<c<c0P17AdL205IFEP<0@d=30P0a<C4203@d=080?3`l0P0o?cl202XZ
:P80;Bd]0`0b<S8203Hf=P@0>CTi0P0g=cL2030`<080:b/[0P0_;bl303Ti>@80@D510P0f=SH203@d
=080<c<c0P0f=SH203Ti>@<0Bd];0P1=CDd206][J`80LG5a0P1]KFd207AdM080Fe]K0`1?Cdl203lo
?`80?Cdm0P0g=cL2061PH080Vi^K0P1^KVh304M7A`809RHV0P0W9bL401`L70807alO0P0S8b<3038b
<P80GemO0P1nOWh209fMW@80VIVI0P29RHT207UiN@<0MgMg0P1nOWh209NGU`80[jn_0P2m_Kd20:f]
[@80Zj^[0`2/[:`20;Zj^P80];Bd0P2b/[820:f][@@0Zj^[0`2^[Zh20:f][@80Vi^K0P29RHT209BD
U080Y:BT0P2^[Zh30:RXZ080[:b/0P2a/K420;Jf]P80_;bl0P31`L420<G5a@80a<C40`2o_kl20;Bd
]0@0ZJVY0P2/[:`20:ZZZP80ZJVY0`2XZ:P40:NWY`80YZJV0P2QXJ4209bLW080V9RH0`2FUYH209NG
U`80VYZJ0P2MWId20:2PX080YJFU2@2YZJT20:^[Z`80[jn_0P2d];@20;Rh^0<0^k^k0P2n_[h20<30
`080`L712038h=P000H0b>3H0P0_;bl202d];@80:RXZ0`0[:b/202h^;P80<S8b0P0i>CT206a/K080
IfMW0P18B4P302LW9`809RHV0P0];Bd202`/;080;Rh^0P0m?Cd204Y:BP<0@D510P0e=CD203<c<`80
<30`0P13@d<202`/;080<30`0`0b<S8203@d=080=SHf0P0j>SX203`l?080<S8b0P0Y:BT202d];@<0
<c<c0P18B4P203Ti>@80>SXj0P0g=cL2030`<080;Rh^0`13@d<205YJFP80LG5a0P1SHf<207IfMP80
OGem0P1CDe<303/k>`80;Bd]0P0`<30203Hf=P80HV9R0P2>SXh2059BDP<0:BTY0P0I6AT202TY:@80
7AdM0P0Q8B4202@T9080820P0`0R8R8203Ph>080EeMG0P2GUiL20:FUY@80VIVI0P23Ph<307QhN080
M7Ad0P22PX8209:BTP80^[Zj0P2`/;020:^[Z`<0XZ:R0P2k^k/20;6a/@80[jn_0P2YZJT20:NWY`80
YJFU1@2XZ:P209JFUP80R8R80P2CTi<20:BTY080^KVi0`2ZZZX20:f][@80[jn_0P2c/k<20;Ng]`80
_Kfm0P32`/820<71`@<0_;bl0P2d];@20:b/[0@0ZZZZ0P2YZJT20:RXZ0<0Zj^[0P2][Jd20:ZZZP@0
Z:RX0P2WYjL209jNWP<0UYJF0P2CTi<209BDU080VIVI0P2OWil20:BTY080YjNW0`2XZ:P20:VYZ@80
ZZZZ0P2/[:`20:n_[`80/k>c0P2g]kL30;^k^`80_[jn1030`<080<SPf0001P38h=P202l_;`80;Bd]
0P0Z:RX302/[:`80;Rh^0P0b<S8203Ti>@80K6a/0P1WIfL204Q8B0<09bLW0P0V9RH202d];@80;2`/
0P0^;Rh203dm?@80BTY:0`11@D4203De=@80<c<c0P0`<30204=3@`80;2`/0P0`<303038b<P80=3@d
0P0f=SH203Xj>P80?3`l0P0b<S8202TY:@80;Bd]0`0c<c<204Q8B080>CTi0P0j>SX203Lg=`80<30`
0P0^;Rh304=3@`80FUYJ0P1aLG4206=SH`80MWIf0P1mOGd205=CD`<0>c/k0P0];Bd2030`<080=SHf
0P1RHV8208j>SP80DU9B0`0Y:BT201TI6@80:BTY0P0M7Ad2024Q8@8092@T0P0P8203028R8P80>3Ph
0P1GEeL209NGU`80YJFU0P2IVIT208>3P`<0N7Qh0P1dM7@208:2PP80TY:B0P2j^[X20;2`/080Zj^[
0`2RXZ820;^k^`80/K6a0P2_[jl20:VYZ@80YjNW0P2UYJD50:RXZ080UYJF0P28R8P209>CT`80Y:BT
0P2i^KT30:ZZZP80[Jf]0P2_[jl20;>c/`80]kNg0P2m_Kd20<;2`P80`L710`2l_;`20;Bd]080[:b/
102ZZZX20:VYZ@80Z:RX0`2[Zj/20:f][@80ZZZZ102XZ:P20:NWY`80WYjN0`2FUYH209>CT`80U9BD
0P2IVIT209nOW`80Y:BT0P2WYjL30:RXZ080ZJVY0P2ZZZX20:b/[080[jn_0P2c/k<20;Ng]`<0^k^k
0P2n_[h40<30`0P0b>3H00060<SPf080@T920P0k>c/2038b<P<0;Bd]0P0[:b/202l_;`80>3Ph0P1/
K6`206QXJ080Bd];0`0/;2`202TY:@80;2`/0P0[:b/202`/;080=SHf0P0o?cl304Q8B080?3`l0P0i
>CT203<c<`80?Shn0P0b<S82030`<0<0;Rh^0P0`<302038b<P80=cLg0P0l?3`2038b<P80:BTY0P0`
<30303Ph>080ADE50P0m?Cd203Ph>080=CDe0P0c<c<203Lg=`<0BTY:0P1NGUh207MgM`80HV9R0P1Z
JVX207EeM@80ADE50`0`<30202h^;P80;2`/0P11@D4207QhN080S8b<0P10@40302PX:0808R8R0P0Y
:BT2024Q8@808b<S0P0T92@5024Q8@808b<S0P0b<S8206QXJ080RXZ:0P2TY:@209BDU0<0PH61101a
LG4207YjNP80YjNW0P2h^;P20;no_`<0ZJVY0P2d];@20:^[Z`80ZZZZ0P2WYjL20:JVYP80YJFU0`2W
YjL20:JVYP80U9BD0P25QHD209BDU080YjNW0P2e]KD30:b/[080ZJVY0P2VYZH20;2`/080^[Zj0P2m
_Kd20<30`080_kno0`2k^k/20;Fe]@80[Zj^0P2[Zj/20:VYZ@80Z:RX0P2YZJT30:^[Z`80[Jf]0P2[
Zj/20:ZZZP80Zj^[0P2/[:`20:RXZ0<0XZ:R0P2KVi/209JFUP80UIFE0P2JVYX20:2PX080YZJV0`2W
YjL20:RXZ080ZZZZ0P2/[:`20:j^[P80/K6a0P2d];@30;Rh^080^k^k0P2n_[h20;no_`P0b>3H0006
0<SPf080@T920P0k>c/2038b<P<0;Bd]0P0[:b/202l_;`80>3Ph0P1/K6`206QXJ080Bd];0`0/;2`2
02TY:@80;2`/0P0[:b/202`/;080=SHf0P0o?cl304Q8B080?3`l0P0i>CT203<c<`80?Shn0P0b<S82
030`<0<0;Rh^0P0`<302038b<P80=cLg0P0l?3`2038b<P80:BTY0P0`<30303Ph>080ADE50P0m?Cd2
03Ph>080=CDe0P0c<c<203Lg=`<0BTY:0P1NGUh207MgM`80HV9R0P1ZJVX207EeM@80ADE50`0`<302
02h^;P80;2`/0P11@D4207QhN080S8b<0P10@40302PX:0808R8R0P0Y:BT2024Q8@808b<S0P0T92@5
024Q8@808b<S0P0b<S8206QXJ080RXZ:0P2TY:@209BDU0<0PH61101aLG4207YjNP80YjNW0P2h^;P2
0;no_`<0ZJVY0P2d];@20:^[Z`80ZZZZ0P2WYjL20:JVYP80YJFU0`2WYjL20:JVYP80U9BD0P25QHD2
09BDU080YjNW0P2e]KD30:b/[080ZJVY0P2VYZH20;2`/080^[Zj0P2m_Kd20<30`080_kno0`2k^k/2
0;Fe]@80[Zj^0P2[Zj/20:VYZ@80Z:RX0P2YZJT30:^[Z`80[Jf]0P2[Zj/20:ZZZP80Zj^[0P2/[:`2
0:RXZ0<0XZ:R0P2KVi/209JFUP80UIFE0P2JVYX20:2PX080YZJV0`2WYjL20:RXZ080ZZZZ0P2/[:`2
0:j^[P80/K6a0P2d];@30;Rh^080^k^k0P2n_[h20;no_`P0b>3H00060<SPf080CTi>0P1;Bd/20492
@P<0<c<c0P0V9RH202XZ:P80=CDe0P1WIfL206UYJ@80DE5A0`0a<C4202`/;080:b/[100Z:RX202d]
;@80<30`0`1:BTX20492@P80?Shn100g=cL203Ti>@80<C4a0`0[:b/202`/;080;bl_0P0c<c<203Ti
>@80<c<c0P0^;Rh203Hf=PD0@4100P0o?cl203Lg=`80<S8b0P0h>3P20492@P<0EUIF0P1QHF4206=S
H`80=cLg0P12@T8206UYJ@80>c/k0`0X:2P203<c<`80;bl_0P1CDe<208f=S@80QhN70P0d=3@302d]
;@80;2`/0P0X:2P202HV9P8092@T100S8b<302@T90807QhN0P0P820203Xj>P80Hf=S0P2OWil209^K
V`<0SHf=0P1gMgL206a/K080JFUY0P1mOGd209FEU@80^[Zj0`2a/K420:n_[`80ZJVY0P2VYZH40:FU
Y@80YZJV0`2WYjL20:FUY@80TI6A0P22PX8209>CT`80Z:RX0P2][Jd30:j^[P80YJFU0P2NWYh20:f]
[@80_Kfm102o_kl20;fm_@<0^KVi0P2e]KD20;2`/080Zj^[102XZ:P20:VYZ@<0ZZZZ102[Zj/20:ZZ
ZP80[:b/0P2][Jd20:n_[`<0[Zj^0P2VYZH209bLW080UYJF0P2EUID209bLW080Xj>S0`2UYJD20:NW
Y`80ZJVY0P2/[:`20:f][@80[Zj^0P2a/K430;Fe]@80^KVi0P2l_;`20;fm_@P0b>3H00060<SPf080
CTi>0P1;Bd/20492@P<0<c<c0P0V9RH202XZ:P80=CDe0P1WIfL206UYJ@80DE5A0`0a<C4202`/;080
:b/[100Z:RX202d];@80<30`0`1:BTX20492@P80?Shn100g=cL203Ti>@80<C4a0`0[:b/202`/;080
;bl_0P0c<c<203Ti>@80<c<c0P0^;Rh203Hf=PD0@4100P0o?cl203Lg=`80<S8b0P0h>3P20492@P<0
EUIF0P1QHF4206=SH`80=cLg0P12@T8206UYJ@80>c/k0`0X:2P203<c<`80;bl_0P1CDe<208f=S@80
QhN70P0d=3@302d];@80;2`/0P0X:2P202HV9P8092@T100S8b<302@T90807QhN0P0P820203Xj>P80
Hf=S0P2OWil209^KV`<0SHf=0P1gMgL206a/K080JFUY0P1mOGd209FEU@80^[Zj0`2a/K420:n_[`80
ZJVY0P2VYZH40:FUY@80YZJV0`2WYjL20:FUY@80TI6A0P22PX8209>CT`80Z:RX0P2][Jd30:j^[P80
YJFU0P2NWYh20:f][@80_Kfm102o_kl20;fm_@<0^KVi0P2e]KD20;2`/080Zj^[102XZ:P20:VYZ@<0
ZZZZ102[Zj/20:ZZZP80[:b/0P2][Jd20:n_[`<0[Zj^0P2VYZH209bLW080UYJF0P2EUID209bLW080
Xj>S0`2UYJD20:NWY`80ZJVY0P2/[:`20:f][@80[Zj^0P2a/K430;Fe]@80^KVi0P2l_;`20;fm_@P0
b>3H00060<SPf080GemO0P1PH60205aLG0<0C4a<0P0j>SX2034a<@80;bl_0P1OGel206ATI080G5aL
0`0d=3@202h^;P80:RXZ0P0Y:BT202XZ:P80:b/[0P0/;2`503lo?`80>SXj0P0c<c<203Hf=P80?Cdm
0P0e=CD302`/;080;Rh^0P0a<C42030`<080<c<c0P0h>3P203hn?P80A4A40`17AdL20451@@80>c/k
0P10@40203<c<`80>c/k0P18B4P3059BDP80Fe]K0P1JFUX202d];@80>3Ph0P1IFET203Ti>@<0:b/[
0P0c<c<20451@@80LW9b0P2?Shl2075aL@80:RXZ0`0];Bd402DU9@809RHV0P0T92@4028R8P<08b<S
0P0M7Ad201`L70808R8R0P0k>c/207YjNP80VYZJ0`2[Zj/2096AT@80NGUi0P1VIVH206i^KP80PX:2
0P2TY:@30:j^[P80];Bd0P2e]KD20:^[Z`80Xj>S0P2UYJD20:JVYP<0YjNW0P2SXj<2096AT@80PX:2
0P2<S8`20:6QX@80YJFU0`2[Zj/20:JVYP80XZ:R0P2YZJT20;Bd]080`l?30P2m_Kd20;Rh^0<0/K6a
0P2c/k<20;Fe]@80[Zj^102XZ:P70:ZZZP80Z:RX0P2WYjL20:RXZ080ZJVY0P2][Jd30:n_[`80[Zj^
0P2YZJT20:BTY080SXj>0P2CTi<209^KV`<0XJ6Q0P2VYZH20:VYZ@80[:b/0P2][Jd20:n_[`80/[:b
0`2e]KD20;Rh^080^[Zj0P2i^KT80<SPf0001P38h=P205mOG`80H61P0P1LG5`304a<C080>SXj0P0a
<C4202l_;`80GemO0P1TI6@205aLG0<0=3@d0P0^;Rh202XZ:P80:BTY0P0Z:RX202/[:`80;2`/1@0o
?cl203Xj>P80<c<c0P0f=SH203dm?@80=CDe0`0/;2`202h^;P80<C4a0P0`<30203<c<`80>3Ph0P0n
?Sh204A4A0<0AdM70P11@D4203/k>`80@4100P0c<c<203/k>`80B4Q80`1BDU8205]KF`80FUYJ0P0]
;Bd203Ph>080FEUI0P0i>CT302/[:`80<c<c0P11@D42079bLP80Shn?0P1aLG4202XZ:P<0;Bd]100U
9BD202HV9P8092@T100R8R8302<S8`807AdM0P0L71`2028R8P80>c/k0P1jNWX209ZJVP<0Zj^[0P2A
TI4207UiN@80IVIV0P1^KVh208:2PP80Y:BT0`2^[Zh20;Bd]080]KFe0P2[Zj/20:>SX`80YJFU0P2V
YZH30:NWY`80Xj>S0P2ATI4208:2PP80S8b<0P2QXJ420:FUY@<0Zj^[0P2VYZH20::RXP80ZJVY0P2d
];@20<?3``80_Kfm0P2h^;P30;6a/@80/k>c0P2e]KD20:j^[P@0Z:RX1`2ZZZX20:RXZ080YjNW0P2X
Z:P20:VYZ@80[Jf]0`2_[jl20:j^[P80ZJVY0P2TY:@208j>SP80Ti>C0P2KVi/30:6QX@80YZJV0P2Y
ZJT20:b/[080[Jf]0P2_[jl20;:b/P<0]KFe0P2h^;P20;Zj^P80^KVi2038h=P000H0b>3H0P1OGel2
061PH080G5aL0`1<C4`203Xj>P80<C4a0P0_;bl205mOG`80I6AT0P1LG5`303@d=080;Rh^0P0Z:RX2
02TY:@80:RXZ0P0[:b/202`/;0D0?clo0P0j>SX203<c<`80=SHf0P0m?Cd203De=@<0;2`/0P0^;Rh2
034a<@80<30`0P0c<c<203Ph>080?Shn0P14A4@304M7A`80@D510P0k>c/20410@080<c<c0P0k>c/2
04Q8B0<0DU9B0P1KFe/205YJFP80;Bd]0P0h>3P205UIF@80>CTi0`0[:b/203<c<`80@D510P1bLW82
08n?S`80LG5a0P0Z:RX302d];@@09BDU0P0V9RH202@T90@08R8R0`0S8b<201dM7@8071`L0P0R8R82
03/k>`80NWYj0P2JVYX30:^[Z`80TI6A0P1iNGT206IVIP80KVi^0P22PX820:BTY0<0[Zj^0P2d];@2
0;Fe]@80Zj^[0P2SXj<20:FUY@80YZJV0`2WYjL20:>SX`80TI6A0P22PX8208b<S080XJ6Q0P2UYJD3
0:^[Z`80YZJV0P2RXZ820:VYZ@80];Bd0P33`l<20;fm_@80^;Rh0`2a/K420;>c/`80]KFe0P2^[Zh4
0:RXZ0L0ZZZZ0P2XZ:P20:NWY`80Z:RX0P2YZJT20:f][@<0[jn_0P2^[Zh20:VYZ@80Y:BT0P2>SXh2
09>CT`80Vi^K0`2QXJ420:JVYP80ZJVY0P2/[:`20:f][@80[jn_0P2b/[830;Fe]@80^;Rh0P2j^[X2
0;Vi^@P0b>3H00060<SPf0@0?Shn0P0m?Cd303Lg=`80<30`100Z:RX205MGE`80GEeM0P1VIVH303Ti
>@80<C4a0P0Y:BT202PX:0@0:RXZ0P0/;2`303<c<`80>SXj0P0c<c<202d];@80=SHf0P0n?Sh203Lg
=`<0;bl_0P0`<30203<c<`@0<30`0P10@40404m?C`<0BTY:0P12@T8203Ph>080BDU90P0f=SH203hn
?P80B4Q80`1:BTX205EEE@80DU9B0P0U9BD2038b<P80BDU90P0j>SX302d];@80<S8b0P1CDe<208n?
S`80Rh^;0P1LG5`202DU9@<0;Bd]0P0P820202DU9@80:BTY0P0V9RH2028R8P808B4Q0`0R8R82020P
80807alO0P0L71`202<S8`80@D510P1[Jf/30:VYZ@80Z:RX0P2>SXh206e]K@80JFUY0P1aLG4208R8
R0<0Xj>S0P2d];@20;bl_080/;2`0P2SXj<20:BTY0D0YZJV0P2QXJ4208n?S`80PX:20P26QXH209^K
V`80XZ:R1`2YZJT20:NWY`80[:b/0P36a/H20;^k^`80];Bd0`2[Zj/20;:b/P80^KVi0P2b/[840:VY
Z@80ZZZZ0`2YZJT20:RXZ080YJFU102SXj<20:BTY080Z:RX0`2][Jd20;Bd]080]KFe0P2f][H209BD
U080Ti>C0P2FUYH309fMW@80YJFU0P2XZ:P20:^[Z`80[Jf]0P2_[jl20;:b/P<0][Jf0P2g]kL20;Rh
^080]kNg2038h=P000H0b>3H100n?Sh203dm?@<0=cLg0P0`<30402XZ:P80EeMG0P1MGEd206IVIP<0
>CTi0P0a<C4202TY:@80:2PX100Z:RX202`/;0<0<c<c0P0j>SX203<c<`80;Bd]0P0f=SH203hn?P80
=cLg0`0_;bl2030`<080<c<c100`<3020410@0@0Cdm?0`1:BTX20492@P80>3Ph0P19BDT203Hf=P80
?Shn0P18B4P304Y:BP80EEEE0P1BDU8202DU9@80<S8b0P19BDT203Xj>P<0;Bd]0P0b<S8205=CD`80
Shn?0P2;Rh/205aLG0809BDU0`0];Bd2020P80809BDU0P0Y:BT202HV9P808R8R0P0Q8B43028R8P80
820P0P0O7al201`L70808b<S0P11@D4206][J`<0ZJVY0P2XZ:P208j>SP80KFe]0P1YJFT2075aL@80
R8R80`2SXj<20;Bd]080_;bl0P2`/;020:>SX`80Y:BT1@2VYZH20:6QX@80Shn?0P22PX8208J6QP80
Vi^K0P2RXZ870:VYZ@80YjNW0P2/[:`20<K6aP80^k^k0P2d];@30:^[Z`80/[:b0P2i^KT20;:b/P@0
ZJVY0P2ZZZX30:VYZ@80Z:RX0P2UYJD40:>SX`80Y:BT0P2XZ:P30:f][@80];Bd0P2e]KD20;Jf]P80
U9BD0P2CTi<209JFUP<0WIfM0P2UYJD20:RXZ080Zj^[0P2][Jd20:n_[`80/[:b0`2f][H20;Ng]`80
^;Rh0P2g]kL80<SPf0001P38h=P205]KF`80DU9B0P14A4@303@d=080;Bd]0P0`<30203Ti>@80DU9B
0P1KFe/2069RHP<0BDU90P0a<C4202PX:0809bLW100Z:RX202/[:`<0<30`0P0g=cL2034a<@80;2`/
0P0a<C4203Ph>080=3@d0`0_;bl2030`<080<c<c0P0e=CD203`l?080BDU90P1DE5@204a<C0D0@D51
0P10@40204Y:BP80?Shn0P14A4@203Ti>@<0AdM70P1JFUX205IFEP809BDU0P0^;Rh203dm?@80ATI6
0`0k>c/203`l?080D51@0P2DU9@208N7Q`80FUYJ0P0X:2P502l_;`80<C4a0P0`<30202`/;080:2PX
0P0V9RH302@T90808R8R0P0Q8B4201`L70807AdM0P0[:b/204U9B@<0Q8B40P2MWId209VIV@80R8R8
0P1fMWH206a/K080LW9b0`24Q8@20:BTY080_[jn0P32`/820:VYZ@80Xj>S0P2TY:@30:6QX@80WYjN
0P2;Rh/207]kN`80QXJ60P2KVi/20;6a/@<0/;2`0P2_[jl20:b/[080ZZZZ0P2_[jl20<71`@80_kno
0P2j^[X30;>c/`80]kNg0P2j^[X20;:b/P80ZZZZ102XZ:P30:NWY`80YJFU0P2SXj<20::RXP80X:2P
0P2QXJ420:FUY@<0ZZZZ0P2`/;020;Fe]@80`L710P2g]kL20:b/[080WinO0`2LW9`209fMW@80XZ:R
0P2XZ:P20:ZZZP80[:b/0P2_[jl30;:b/P80];Bd0P2c/k<20;fm_@P0b>3H00060<SPf080Fe]K0P1B
DU8204A4A0<0=3@d0P0];Bd2030`<080>CTi0P1BDU8205]KF`80HV9R0`19BDT2034a<@80:2PX0P0W
9bL402XZ:P80:b/[0`0`<30203Lg=`80<C4a0P0/;2`2034a<@80>3Ph0P0d=3@302l_;`80<30`0P0c
<c<203De=@80?3`l0P19BDT205ADE080C4a<1@11@D420410@080BTY:0P0n?Sh204A4A080>CTi0`17
AdL205YJFP80EUIF0P0U9BD202h^;P80?Cdm0P16ATH303/k>`80?3`l0P1@D50209BDU080QhN70P1J
FUX202PX:0D0;bl_0P0a<C42030`<080;2`/0P0X:2P202HV9P<092@T0P0R8R82024Q8@8071`L0P0M
7Ad202/[:`80BDU90`24Q8@209fMW@80VIVI0P28R8P207IfMP80K6a/0P1bLW8308B4Q080Y:BT0P2n
_[h20<;2`P80ZJVY0P2SXj<20:BTY0<0XJ6Q0P2NWYh208^;R`80Ng]k0P26QXH209^KV`80/K6a0`2`
/;020:n_[`80[:b/0P2ZZZX20:n_[`80`L710P2o_kl20;Zj^P<0/k>c0P2g]kL20;Zj^P80/[:b0P2Z
ZZX40:RXZ0<0YjNW0P2UYJD20:>SX`80XZ:R0P2PX:020:6QX@80YJFU0`2ZZZX20;2`/080]KFe0P31
`L420;Ng]`80[:b/0P2OWil309bLW080WIfM0P2RXZ820:RXZ080ZZZZ0P2/[:`20:n_[`<0/[:b0P2d
];@20;>c/`80_Kfm2038h=P000H0b>3H0P1gMgL2069RHP80@d=30`0_;bl202TY:@809BDU0P0Z:RX2
03lo?`80EeMG0P1KFe/305QHF080<c<c0P0Y:BT202LW9`H0:b/[0`0`<30203@d=080<30`0P0/;2`2
02h^;P80<C4a0P0`<30302l_;`80<30`0P0d=3@203dm?@80BTY:0P1ADE4205=CD`80ATI60`0i>CT2
0451@@80Bd];0P1:BTX204E5A@80ATI60P0Y:BT304E5A@80H61P0P1LG5`202LW9`80;bl_0P0f=SH2
03lo?`<092@T0P0e=CD204i>CP80U9BD0P22PX8205iNGP80<S8b0`0d=3@20451@@80@d=30P12@T82
03Lg=`80:b/[0P0W9bL302HV9P8092@T0P0S8b<2024Q8@@0820P0P0Z:RX305ADE080Ph>30P2HV9P2
09fMW@80R8R80P1`L70206IVIP<0IfMW0P1mOGd209JFUP80^KVi0P2/[:`20:FUY@80Y:BT0`2OWil2
09VIV@80QXJ60P1gMgL208V9R@80WinO0P31`L430;Ng]`80]KFe102^[Zh20;Fe]@80^k^k0P33`l<2
0<71`@<0_Kfm0P2l_;`20;^k^`80/k>c0P2/[:`20:VYZ@80YjNW0`2UYJD20:>SX`80XJ6Q0P2PX:04
09nOW`80XZ:R0`2XZ:P20:f][@80/k>c0P2f][H20;Rh^080/k>c0P2/[:`30:6QX@80V9RH0P2MWId2
0:BTY080YjNW0P2XZ:P20:^[Z`<0[Zj^102`/;020<71`@P0b>3H00060<SPf080MgMg0P1RHV8204=3
@`<0;bl_0P0Y:BT202DU9@80:RXZ0P0o?cl205MGE`80Fe]K0`1HF5P203<c<`80:BTY0P0W9bL602/[
:`<0<30`0P0d=3@2030`<080;2`/0P0^;Rh2034a<@80<30`0`0_;bl2030`<080=3@d0P0m?Cd204Y:
BP80DE5A0P1CDe<204I6AP<0>CTi0P11@D4204];B`80BTY:0P15ADD204I6AP80:BTY0`15ADD2061P
H080G5aL0P0W9bL202l_;`80=SHf0P0o?cl302@T9080=CDe0P1>CTh209BDU080PX:20P1NGUh2038b
<P<0=3@d0P11@D4204=3@`80@T920P0g=cL202/[:`809bLW0`0V9RH202@T90808b<S0P0Q8B44020P
8080:RXZ0`1DE5@208>3P`80V9RH0P2MWId208R8R080L71`0P1VIVH306MWI`80OGem0P2FUYH20;Vi
^@80[:b/0P2UYJD20:BTY0<0WinO0P2IVIT208J6QP80MgMg0P29RHT209nOW`80`L710`2g]kL20;Fe
]@@0[Zj^0P2e]KD20;^k^`80`l?30P31`L430;fm_@80_;bl0P2k^k/20;>c/`80[:b/0P2YZJT20:NW
Y`<0YJFU0P2SXj<20:6QX@80X:2P102OWil20::RXP<0Z:RX0P2][Jd20;>c/`80][Jf0P2h^;P20;>c
/`80[:b/0`2QXJ4209RHV080WIfM0P2TY:@20:NWY`80Z:RX0P2[Zj/30:j^[P@0/;2`0P31`L480<SP
f0001P38h=P207MgM`80Jf][0P1FEUH303Xj>P809BDU0P0T92@202`/;080?clo0P13@d<2051@D0<0
FUYJ0P0m?Cd2034a<@80;2`/0P0];Bd402`/;0<0;Bd]1P0^;Rh2030`<080<C4a0P0_;bl302d];@80
<c<c0P0j>SX4055AD@80Cdm?0P18B4P20492@P<0?clo0P1:BTX205=CD`80C4a<0P12@T8203Xj>P80
9RHV0`0o?cl2061PH080G5aL0P0T92@202LW9`80;Bd]0P0l?3`302LW9`80@T920P1NGUh209:BTP80
Q8B40P1WIfL204i>CP<0EUIF0P1XJ6P206i^KP80KFe]0P1EEED203Xj>P80;2`/0`0U9BD202<S8`80
92@T0P0R8R82024Q8@807alO0P0T92@303Hf=P80EUIF0P24Q8@20:RXZ080Y:BT0P21PH4206][J`<0
Fe]K0P1TI6@207]kN`80YZJV0P2f][H20;:b/P80Z:RX0`2QXJ4208j>SP80Ogmo0P1lO7`2092@T080
ZZZZ0P2m_Kd30;^k^`80][Jf0P2_[jl20;6a/@80^;Rh0P2k^k/20<30`080`L711@30`<020;jn_P80
^;Rh0P2a/K420:b/[080YjNW0`2UYJD20:BTY080XZ:R0P2PX:0209nOW`80X:2P0P2SXj<30:NWY`80
Zj^[0P2`/;020;Bd]080^KVi0P2g]kL20;:b/P<0ZZZZ0P2RXZ820:6QX@80XZ:R0P2TY:@20:NWY`80
Zj^[0`2^[Zh40;6a/@80^k^k2038h=P000H0b>3H0P1gMgL206][J`80EUIF0`0j>SX202DU9@8092@T
0P0/;2`203lo?`80@d=30P1@D50305YJFP80?Cdm0P0a<C4202`/;080;Bd]100/;2`302d];@H0;Rh^
0P0`<302034a<@80;bl_0`0];Bd203<c<`80>SXj101ADE4204m?C`80B4Q80P12@T8303lo?`80BTY:
0P1CDe<204a<C080@T920P0j>SX202HV9P<0?clo0P1PH60205aLG08092@T0P0W9bL202d];@80?3`l
0`0W9bL20492@P80GUiN0P2BTY8208B4Q080IfMW0P1>CTh305IFEP80J6QX0P1^KVh206e]K@80EEEE
0P0j>SX202`/;0<09BDU0P0S8b<202@T90808R8R0P0Q8B4201lO7`8092@T0`0f=SH205IFEP80Q8B4
0P2XZ:P20:BTY080PH610P1[Jf/305]KF`80I6AT0P1kNg/20:JVYP80][Jf0P2b/[820:RXZ0<0XJ6Q
0P2>SXh207moO`80O7al0P2@T9020:ZZZP80_Kfm0`2k^k/20;Jf]P80[jn_0P2a/K420;Rh^080^k^k
0P30`<020<71`@D0`<300P2n_[h20;Rh^080/K6a0P2/[:`20:NWY`<0YJFU0P2TY:@20::RXP80X:2P
0P2OWil20:2PX080Xj>S0`2WYjL20:^[Z`80/;2`0P2d];@20;Vi^@80]kNg0P2b/[830:ZZZP80XZ:R
0P2QXJ420::RXP80Y:BT0P2WYjL20:^[Z`<0[Zj^102a/K420;^k^`P0b>3H00060<SPf080MGEe0P1G
EeL2034a<@<0:BTY0P0W9bL202XZ:P80;Rh^0P0o?cl202l_;`80ADE50`1GEeL204U9B@80>SXj0P0c
<c<2030`<080;Rh^1`0];Bd202h^;P80;bl_0P0b<S8203<c<`80;bl_0`0/;2`203Ph>080ADE50P1S
Hf<205EEE@80BTY:0P0m?Cd20410@0<0B4Q80P1CDe<205YJFP80CDe=0P0l?3`202`/;080:BTY0`0l
?3`205eMG@80F5QH0P0Q8B42028R8P80:2PX0P0k>c/3034a<@80DU9B0P1`L70208b<S080P8200P1]
KFd206ATI0<0GemO0P1LG5`2059BDP80ATI60P0c<c<202<S8`808R8R0`0V9RH202DU9@8092@T1P0S
8b<502DU9@80;Bd]0P1EEED207emO@80WinO0P2BTY8207MgM`<0FEUI0P1GEeL206=SH`80NWYj0P2D
U9@20:VYZ@80/K6a0`2[Zj/208>3P`80Ng]k0P29RHT209VIV@80/K6a0P2f][H30;bl_080][Jf0P2`
/;020;Bd]080^[Zj0P2k^k/20;fm_@80_kno1@32`/820<71`@80_Kfm0P2g]kL20;2`/080ZZZZ0`2W
YjL20:JVYP80XZ:R0P2OWil20:2PX080XZ:R0P2TY:@30:JVYP80ZJVY0P2][Jd20;6a/@80/k>c102f
][H30;>c/`80[Zj^0P2WYjL20:6QX@80XZ:R0P2VYZH20:ZZZP<0[Zj^0P2a/K440;>c/`P0b>3H0006
0<SPf080MGEe0P1GEeL2034a<@<0:BTY0P0W9bL202XZ:P80;Rh^0P0o?cl202l_;`80ADE50`1GEeL2
04U9B@80>SXj0P0c<c<2030`<080;Rh^1`0];Bd202h^;P80;bl_0P0b<S8203<c<`80;bl_0`0/;2`2
03Ph>080ADE50P1SHf<205EEE@80BTY:0P0m?Cd20410@0<0B4Q80P1CDe<205YJFP80CDe=0P0l?3`2
02`/;080:BTY0`0l?3`205eMG@80F5QH0P0Q8B42028R8P80:2PX0P0k>c/3034a<@80DU9B0P1`L702
08b<S080P8200P1]KFd206ATI0<0GemO0P1LG5`2059BDP80ATI60P0c<c<202<S8`808R8R0`0V9RH2
02DU9@8092@T1P0S8b<502DU9@80;Bd]0P1EEED207emO@80WinO0P2BTY8207MgM`<0FEUI0P1GEeL2
06=SH`80NWYj0P2DU9@20:VYZ@80/K6a0`2[Zj/208>3P`80Ng]k0P29RHT209VIV@80/K6a0P2f][H3
0;bl_080][Jf0P2`/;020;Bd]080^[Zj0P2k^k/20;fm_@80_kno1@32`/820<71`@80_Kfm0P2g]kL2
0;2`/080ZZZZ0`2WYjL20:JVYP80XZ:R0P2OWil20:2PX080XZ:R0P2TY:@30:JVYP80ZJVY0P2][Jd2
0;6a/@80/k>c102f][H30;>c/`80[Zj^0P2WYjL20:6QX@80XZ:R0P2VYZH20:ZZZP<0[Zj^0P2a/K44
0;>c/`P0b>3H00060<SPf080MGEe0P1GEeL2034a<@D0:b/[0P0`<30203<c<`80=CDe0P0W9bL203dm
?@<0D51@0P1IFET203hn?P80=cLg0P0`<30202h^;PL0;Bd]0P0^;Rh2030`<0@0<C4a0P0^;Rh302l_
;`80@d=30P1EEED205mOG`80Cdm?0P14A4@203hn?P80A4A40`1>CTh205QHF080GUiN0P18B4P2030`
<080:RXZ0P0_;bl30492@P80FEUI0P1;Bd/2028R8P80:2PX0P0T92@20492@P<0DU9B0P1WIfL207Ui
N@80UIFE0P27QhL206=SH`80B4Q80`0o?cl203`l?080=SHf0P0a<C4202h^;P80;2`/0P0Z:RX702PX
:0809BDU0P0R8R8202<S8`8092@T0`0P820202<S8`80?3`l0P1IFET20861P@80S8b<0P1kNg/3069R
HP80IFEU0P1JFUX2061PH080MWIf0P2KVi/50;Jf]P80Q8B40P1jNWX409fMW@80XJ6Q0P2k^k/30;Ng
]`80][Jf0P2c/k<20;Fe]@80^;Rh0P2i^KT20;Zj^P80_Kfm0`2o_kl40<30`080_;bl0P2g]kL20;>c
/`80[Zj^0`2YZJT20:FUY@80XZ:R0P2OWil20:2PX080XJ6Q0P2SXj<30:FUY@80YjNW0P2YZJT20:b/
[080[jn_0P2e]KD20;Rh^0<0]KFe0P2`/;020:RXZ080XZ:R102PX:020:>SX`<0YjNW0P2][Jd40;:b
/PP0b>3H00060<SPf080MGEe0P1GEeL2034a<@D0:b/[0P0`<30203<c<`80=CDe0P0W9bL203dm?@<0
D51@0P1IFET203hn?P80=cLg0P0`<30202h^;PL0;Bd]0P0^;Rh2030`<0@0<C4a0P0^;Rh302l_;`80
@d=30P1EEED205mOG`80Cdm?0P14A4@203hn?P80A4A40`1>CTh205QHF080GUiN0P18B4P2030`<080
:RXZ0P0_;bl30492@P80FEUI0P1;Bd/2028R8P80:2PX0P0T92@20492@P<0DU9B0P1WIfL207UiN@80
UIFE0P27QhL206=SH`80B4Q80`0o?cl203`l?080=SHf0P0a<C4202h^;P80;2`/0P0Z:RX702PX:080
9BDU0P0R8R8202<S8`8092@T0`0P820202<S8`80?3`l0P1IFET20861P@80S8b<0P1kNg/3069RHP80
IFEU0P1JFUX2061PH080MWIf0P2KVi/50;Jf]P80Q8B40P1jNWX409fMW@80XJ6Q0P2k^k/30;Ng]`80
][Jf0P2c/k<20;Fe]@80^;Rh0P2i^KT20;Zj^P80_Kfm0`2o_kl40<30`080_;bl0P2g]kL20;>c/`80
[Zj^0`2YZJT20:FUY@80XZ:R0P2OWil20:2PX080XJ6Q0P2SXj<30:FUY@80YjNW0P2YZJT20:b/[080
[jn_0P2e]KD20;Rh^0<0]KFe0P2`/;020:RXZ080XZ:R102PX:020:>SX`<0YjNW0P2][Jd40;:b/PP0
b>3H00060<SPf080LW9b0P1MGEd20410@0<0=cLg0P0d=3@203Ph>080>c/k0P0^;Rh202LW9`80>CTi
0`1:BTX2069RHP80@4100P0j>SX2034a<@80;bl_0P0];Bd302h^;P`0;bl_0`0d=3@204a<C080HV9R
0P1GEeL204U9B@@0@T920P19BDT3059BDP80Fe]K0P1NGUh20492@P809bLW0P0Z:RX203Hf=P<0BDU9
0P1DE5@203dm?@8092@T0P0`<30202LW9`80C4a<0`1cLg<407emO@80Ph>30P1LG5`203/k>`80:2PX
0`0W9bL402d];@80;Rh^0P0a<C4203<c<`80;bl_0`0Z:RX202/[:`80;2`/0P0X:2P202@T90808b<S
0P0T92@302<S8`8092@T0P0X:2P203De=@80FEUI0P1lO7`207YjNP<0K6a/0P1jNWX205UIF@80DE5A
0P1HF5P207AdM080SHf=0`2TY:@208B4Q080O7al0P2_[jl209jNWP80SXj>0P2o_kl30;6a/@80][Jf
102e]KD40;Jf]P80^;Rh0P2j^[X30;bl_0@0_Kfm0P2j^[X20;Ng]`80]KFe0P2c/k<30:b/[080YJFU
0P2RXZ840:2PX080XJ6Q0P2SXj<50:FUY@80YZJV0P2XZ:P20:b/[080/k>c0P2h^;P30;Fe]@80[jn_
0P2ZZZX20:BTY080WYjN0P2KVi/209fMW@<0XZ:R0P2YZJT20:n_[`80/K6a2038h=P000H0b>3H0P1b
LW8205eMG@80@4100`0g=cL203@d=080>3Ph0P0k>c/202h^;P809bLW0P0i>CT304Y:BP80HV9R0P10
@40203Xj>P80<C4a0P0_;bl202d];@<0;Rh^300_;bl303@d=080C4a<0P1RHV8205MGE`80BDU91012
@T8204U9B@<0DU9B0P1KFe/205iNGP80@T920P0W9bL202XZ:P80=SHf0`19BDT205ADE080?Cdm0P0T
92@2030`<0809bLW0P1<C4`307=cL`@0OGem0P23Ph<205aLG080>c/k0P0X:2P302LW9`@0;Bd]0P0^
;Rh2034a<@80<c<c0P0_;bl302XZ:P80:b/[0P0/;2`202PX:08092@T0P0S8b<202@T90<08b<S0P0T
92@202PX:080=CDe0P1IFET207alO080NWYj0`1/K6`207YjNP80FEUI0P1ADE4205QHF080M7Ad0P2=
SHd30:BTY080Q8B40P1lO7`20:n_[`80WYjN0P2>SXh20;no_`<0/K6a0P2f][H40;Fe]@@0][Jf0P2h
^;P20;Zj^P<0_;bl102m_Kd20;Zj^P80]kNg0P2e]KD20;>c/`<0[:b/0P2UYJD20::RXP@0X:2P0P2Q
XJ420:>SX`D0YJFU0P2VYZH20:RXZ080[:b/0P2c/k<20;Rh^0<0]KFe0P2_[jl20:ZZZP80Y:BT0P2N
WYh209^KV`80WIfM0`2RXZ820:VYZ@80[jn_0P2a/K480<SPf0001P38h=P2079bLP80GEeM0P10@403
03Lg=`80=3@d0P0h>3P203/k>`80;Rh^0P0W9bL203Ti>@<0BTY:0P1RHV820410@080>SXj0P0a<C42
02l_;`80;Bd]0`0^;Rh<02l_;`<0=3@d0P1<C4`2069RHP80EeMG0P19BDT40492@P80BDU90`1BDU82
05]KF`80GUiN0P12@T8202LW9`80:RXZ0P0f=SH304U9B@80E5AD0P0m?Cd202@T9080<30`0P0W9bL2
04a<C0<0Lg=c101mOGd208>3P`80G5aL0P0k>c/202PX:0<09bLW100];Bd202h^;P80<C4a0P0c<c<2
02l_;`<0:RXZ0P0[:b/202`/;080:2PX0P0T92@202<S8`8092@T0`0S8b<202@T9080:2PX0P0e=CD2
05UIF@80O7al0P1jNWX306a/K080NWYj0P1IFET2055AD@80F5QH0P1dM7@208f=S@<0Y:BT0P24Q8@2
07alO080[jn_0P2NWYh208j>SP80_kno0`2a/K420;Jf]P@0]KFe102f][H20;Rh^080^[Zj0`2l_;`4
0;fm_@80^[Zj0P2g]kL20;Fe]@80/k>c0`2/[:`20:FUY@80XZ:R102PX:020:6QX@80Xj>S1@2UYJD2
0:JVYP80Z:RX0P2/[:`20;>c/`80^;Rh0`2e]KD20:n_[`80ZZZZ0P2TY:@209jNWP80Vi^K0P2MWId3
0::RXP80ZJVY0P2_[jl20;6a/@P0b>3H00060<SPf080Kfm_0P1PH60204i>CP<0AdM7101=CDd204];
B`80>c/k0P0a<C4203Xj>P<0AdM70P1TI6@205iNGP80CTi>0P0i>CT2038b<PL0;bl_0P0^;Rh202d]
;@80;Rh^0P0`<302038b<P<0=cLg0P1<C4`205aLG080Cdm?0P0o?cl204M7A`80@T920P1;Bd/305=C
D`80GUiN0P1DE5@20410@080;2`/0P0[:b/203Lg=`<0B4Q80P1CDe<203Xj>P8092@T0P0a<C4203lo
?`80EEEE0`1gMgL208>3P`80Lg=c0P1bLW8204I6AP80<C4a0P0V9RH302LW9`80;2`/0P0];Bd202h^
;P80<C4a0P0c<c<2030`<0<0;Bd]200/;2`202TY:@809RHV1`0U9BD202XZ:P80@4100P1IFET206IV
IP<0Jf][0P25QHD206EUI@80E5AD0P1=CDd205iNGP80LW9b0`2CTi<20861P@80QHF50P2_[jl209^K
V`80QhN70P2e]KD30;>c/`80]kNg0P2c/k<40;Bd]080]KFe0P2f][H20;Ng]`<0^;Rh0P2k^k/20;bl
_080^k^k0P2i^KT20;Rh^080]KFe0`2`/;020:ZZZP80YZJV0P2TY:@40::RXP80Y:BT0`2WYjL40:RX
Z080Zj^[0P2][Jd20;:b/P80][Jf0`2d];@20;6a/@80[Zj^0P2[Zj/20::RXP80W9bL0P2OWil30:FU
Y@80ZJVY0P2/[:`20:f][@P0b>3H00060<SPf080Kfm_0P1PH60204i>CP<0AdM7101=CDd204];B`80
>c/k0P0a<C4203Xj>P<0AdM70P1TI6@205iNGP80CTi>0P0i>CT2038b<PL0;bl_0P0^;Rh202d];@80
;Rh^0P0`<302038b<P<0=cLg0P1<C4`205aLG080Cdm?0P0o?cl204M7A`80@T920P1;Bd/305=CD`80
GUiN0P1DE5@20410@080;2`/0P0[:b/203Lg=`<0B4Q80P1CDe<203Xj>P8092@T0P0a<C4203lo?`80
EEEE0`1gMgL208>3P`80Lg=c0P1bLW8204I6AP80<C4a0P0V9RH302LW9`80;2`/0P0];Bd202h^;P80
<C4a0P0c<c<2030`<0<0;Bd]200/;2`202TY:@809RHV1`0U9BD202XZ:P80@4100P1IFET206IVIP<0
Jf][0P25QHD206EUI@80E5AD0P1=CDd205iNGP80LW9b0`2CTi<20861P@80QHF50P2_[jl209^KV`80
QhN70P2e]KD30;>c/`80]kNg0P2c/k<40;Bd]080]KFe0P2f][H20;Ng]`<0^;Rh0P2k^k/20;bl_080
^k^k0P2i^KT20;Rh^080]KFe0`2`/;020:ZZZP80YZJV0P2TY:@40::RXP80Y:BT0`2WYjL40:RXZ080
Zj^[0P2][Jd20;:b/P80][Jf0`2d];@20;6a/@80[Zj^0P2[Zj/20::RXP80W9bL0P2OWil30:FUY@80
ZJVY0P2/[:`20:f][@P0b>3H00060<SPf080JFUY0P1RHV8205YJFP<0E5AD0P1QHF4205iNGP80F5QH
0P1:BTX203hn?P80@4100`17AdL2051@D080F5QH0P1?Cdl204=3@`80=cLg0P0_;bl302h^;P80;bl_
0P0];Bd202/[:`80;Rh^0P0a<C4203<c<`<0>3Ph0P17AdL205=CD`80CDe=0P11@D4205ADE080@D51
0P1<C4`3059BDP80H61P0P19BDT203hn?P80=3@d0P0/;2`203Hf=P<0ATI60P1BDU8203Xj>P809BDU
0P0a<C4205ADE080G5aL0`1eMGD208B4Q080IfMW0P1RHV82038b<P80;2`/0P0[:b/302h^;PH0<S8b
0P0a<C44030`<0<0;bl_0P0];Bd202/[:`80<30`0P0c<c<202l_;`80:BTY0`0X:2P202LW9`809RHV
0P0X:2P202l_;`80>SXj0P1CDe<306MWI`80TI6A0P1aLG4205YJFP80ADE50P1?Cdl205]KF`<0Kfm_
0P1LG5`207emO@80[:b/0P2IVIT208>3P`80Zj^[0`2g]kL20;Rh^0H0/[:b0P2d];@20;Jf]PD0]KFe
0P2i^KT20;bl_080_Kfm0P2l_;`20;Zj^P80]kNg0`2c/k<20:j^[P80ZZZZ0P2WYjL20:BTY080Xj>S
0P2VYZH30:ZZZP80Zj^[0P2/[:`20:j^[P80/;2`0P2b/[850;>c/`@0/[:b0P2a/K420:NWY`80WYjN
0P2SXj<30:ZZZP80Zj^[102YZJT80<SPf0001P38h=P206UYJ@80HV9R0P1JFUX305ADE080HF5Q0P1N
GUh205QHF080BTY:0P0n?Sh20410@0<0AdM70P1@D50205QHF080Cdm?0P13@d<203Lg=`80;bl_0`0^
;Rh202l_;`80;Bd]0P0[:b/202h^;P80<C4a0P0c<c<303Ph>080AdM70P1CDe<204e=C@80@D510P1D
E5@20451@@80C4a<0`1BDU82061PH080BDU90P0n?Sh203@d=080;2`/0P0f=SH304I6AP80DU9B0P0j
>SX202DU9@80<C4a0P1DE5@205aLG0<0MGEe0P24Q8@206MWI`80HV9R0P0b<S8202`/;080:b/[0`0^
;Rh6038b<P80<C4a100`<30302l_;`80;Bd]0P0[:b/2030`<080<c<c0P0_;bl202TY:@<0:2PX0P0W
9bL202HV9P80:2PX0P0_;bl203Xj>P80De=C0`1WIfL2096AT@80LG5a0P1JFUX204E5A@80Cdm?0P1K
Fe/306m_K`80G5aL0P1mOGd20:b/[080VIVI0P23Ph<20:^[Z`<0]kNg0P2h^;P60;:b/P80];Bd0P2f
][H50;Fe]@80^KVi0P2l_;`20;fm_@80_;bl0P2j^[X20;Ng]`<0/k>c0P2^[Zh20:ZZZP80YjNW0P2T
Y:@20:>SX`80YZJV0`2ZZZX20:^[Z`80[:b/0P2^[Zh20;2`/080/[:b1@2c/k<40;:b/P80/K6a0P2W
YjL209jNWP80Xj>S0`2ZZZX20:^[Z`@0ZJVY2038h=P000H0b>3H0P1oOgl206a/K080Fe]K0`1QHF42
07inOP80MWIf0P1ZJVX2069RHP80FEUI0P1=CDd304I6AP80BDU90P1EEED204i>CP80A4A41013@d<3
03Ti>@80;Rh^100[:b/202`/;080<30`0P0n?Sh304];B`80D51@0P1ADE4204Y:BP80@4100P1EEED2
0451@@80C4a<0`1BDU82065QH@80AdM70P0n?Sh203De=@80;2`/0P0f=SH304I6AP80DU9B0P0g=cL2
02@T9080?3`l0P1^KVh206UYJ@<0M7Ad0P22PX82069RHP80G5aL0P0];Bd402/[:`<0;Rh^0P0b<S82
03<c<`80<S8b0P0a<C47030`<080;Bd]0P0[:b/2030`<080=CDe0P0`<30202XZ:PD0:2PX100V9RH2
02PX:080<30`0P19BDT306IVIP80I6AT0P23Ph<206m_K`80G5aL0P1GEeL205ADE0<0Hf=S0P1ADE42
07UiN@80[Jf]0P2IVIT20861P@80Z:RX1@2g]kL20;2`/080/K6a0P2b/[820;Bd]080][Jf1@2e]KD2
0;Rh^080_;bl0P2m_Kd20;bl_080^[Zj0P2g]kL30;>c/`80[jn_0P2[Zj/20:RXZ080Y:BT0P2SXj<2
0:JVYP<0ZZZZ0P2[Zj/20:b/[080[Zj^0P2`/;020;:b/PD0/k>c0P2b/[820;>c/`80/[:b0P2XZ:P2
09nOW`80Y:BT1@2[Zj/40:VYZ@P0b>3H00060<SPf080Ogmo0P1/K6`205]KF`<0HF5Q0P1nOWh207If
MP80JVYZ0P1RHV8205UIF@80CDe=0`16ATH204U9B@80EEEE0P1>CTh204A4A0@0@d=30`0i>CT202h^
;P@0:b/[0P0/;2`2030`<080?Shn0`1;Bd/2051@D080DE5A0P1:BTX20410@080EEEE0P11@D4204a<
C0<0DU9B0P1QHF4204M7A`80?Shn0P0e=CD202`/;080=SHf0`16ATH2059BDP80=cLg0P0T92@203`l
?080KVi^0P1YJFT307AdM080PX:20P1RHV8205aLG080;Bd]100[:b/302h^;P80<S8b0P0c<c<2038b
<P80<C4a1`0`<30202d];@80:b/[0P0`<30203De=@80<30`0P0Z:RX502PX:0@09RHV0P0X:2P2030`
<080BDU90`1VIVH206ATI080Ph>30P1_Kfl205aLG080EeMG0P1DE5@306=SH`80DE5A0P1iNGT20:f]
[@80VIVI0P21PH420:RXZ0D0]kNg0P2`/;020;6a/@80/[:b0P2d];@20;Jf]PD0]KFe0P2h^;P20;bl
_080_Kfm0P2l_;`20;Zj^P80]kNg0`2c/k<20:n_[`80Zj^[0P2XZ:P20:BTY080Xj>S0P2VYZH30:ZZ
ZP80Zj^[0P2/[:`20:j^[P80/;2`0P2b/[850;>c/`80/[:b0P2c/k<20;:b/P80Z:RX0P2OWil20:BT
Y0D0Zj^[102YZJT80<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.20067, -3.20067, 0.468297, \
0.468297}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quantization", "Section"],

Cell["\<\
Image compression is based on a slightly different concept - quantization. \
Instead of having 256 levels of grey, we might have only 16. Such an image \
would look bad. But we can do just this on the LH, HL and HH subbands, \
without losing much. All we're going to do is rounding - with different \
amounts depending on the subband. This is called deadzone (rounding down) \
uniform (division by a number) scalar (it operates on individual color \
components of individual pixels which are scalars) quantization. Let's see:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Quantize[N_] := \ 
        X_?NumberQ \[RuleDelayed] \((Round[X/N])\)*
            N;\)\), "\[IndentingNewLine]", 
    \(\(qdecomp\  = \ decomp;\)\), "\[IndentingNewLine]", 
    \(\(qdecomp[\([2, 2]\)]\  = \ 
        decomp[\([2, 2]\)] /. Quantize[64];\)\), "\[IndentingNewLine]", 
    \(\(qdecomp[\([1, 2]\)]\  = \ 
        decomp[\([1, 2]\)] /. Quantize[32];\)\), "\[IndentingNewLine]", 
    \(\(qdecomp[\([2, 1]\)]\  = \ 
        decomp[\([2, 1]\)] /. Quantize[32];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        GraphicsArray[{Graphics[
              Raster[\((ImgIDWT[Interleave2[qdecomp]] + 128)\)/255], 
              AspectRatio \[Rule] 1], 
            Graphics[Raster[\((sub + 128)\)/255], 
              AspectRatio \[Rule] 1]}]];\)\[IndentingNewLine]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
576883A7BC3329242E262231403F3A35323435323034373533343845504B423D38312C28
28303B6D63635A7C67466060646C7375767A7E7F7F80817F7E7E7F818386888A8A898889
8B8E908D8B8E908D8988898A8C8C8C8C8D8E8F909192929191909091929394918F919492
909498969496999A9B9DA0A3A8B5C3CACFD0D3B3
585F70A1BFA64621292526313B3833373A3733323132343434363B424C48403933302F29
272F3A6C62645C7B614F5D626B6E7174767A7E7E7F8082817F808081838587898A89888A
8C8E8F8D8A8B8C8D8D8A898B8E8D8C8D8E90929393939292939291929496979592939493
9193969695989A9A9B9DA0A3A9B6C4CCD1D0CFBE
5B575A7996B4983F28212A2F332F2C38423A313133312F3135393D4146423D342D2F322B
262F3A6B60666079575A5A6672716F72777A7C7E7F81828281818282828486888989898B
8D8E8E8C8A89888D918D898C908F8D8E909294969695949495949495979A9C9995959594
9293949596999B9A9A9C9FA3A8B6C4CFD4D0C9CA
5C57576A83A6B67C3A1D27282D2D2F363B342D2F33302D303436364D403F39332E30322A
2534407061666079545B5E687171717477797B7D7F80818283838281818488898889898B
8D8D8C8C8B8B8B8E908E8B8D8F8F8F91939495969696969595969797989B9D9A96949392
92959797969798999A9B9DA1A7B4C1CDD4CFC7C9
5E5A5A5F7082C4B6592A2522282D3333322E2A2F332F2B30343330573D3C373431313129
2537487563676077525B63696E71737678797A7D80808082848381807F858A8A8889898B
8C8C8B8B8C8D8E8E8D8E8E8E8E8F9194969696969697989695979999999B9C9A96939191
93979A9895949597999A9B9FA5B1BECAD2CDC6C5
635E59596375A8C4A63A3224262A2F2E2D2C2C3033312E323536354C3F3F3A373331302A
292B4A79676D646B565E676C6F7072777C7B7B7D7F7F808081808081838587888A8A8B8B
8C8C8C8C8C8C8C8C8C8D8F8E8E919497989897979897979797989A9A9A9B9B9997949394
95979795939495949597999CA1ADBAC8D1CBC2C4
65605B575A708AB8CE9633272A2A2B2B2B2D303233333234373A3D3E42413E3934312F29
2B1D4D7C6C70695F59606A6E717171787E7E7C7D7E7F807F7E7E8083868483878B8C8C8C
8C8E8E8D8B8A898B8C8E8F8F909397999A9998999A989697999A9A9B9C9B9A9998969596
9896949393939492909397999DA9B6C5CFC8BFBF
575E60585B7390A7D4B87E47272931302F33373736343435383B3E3D3F3D3A36332D2C39
4B32577171646D5E595F686D707274797D7E7E7D7D8082817F808183858687898C8D8D8D
8D8D8D8C8B8C8D8E8E8F91929497999A9999999A9A99999A9C9D9D9D9C9C9B9997969798
9997949494949391909194979DA6B1BFCAC6C1AF
505B655D5E779992C4CEC86D332D363434383D3B37363536393C3E3D3B383533322F2D27
2C29636B76566F60575C666B6F7377797B7D7F7E7D8082828182828283878B8B8C8C8D8D
8D8C8C8C8C8F92919091929597999A9A999A9A9A9A9B9B9D9F9F9F9E9D9D9D9A97979899
9997959596949291919090959DA3ABB9C4C2C1A0
7358616E5C708989A8C1C8C5542B302F3236393835353536383C3E3C3937363433302F2C
332D646F7C566A5C555B656A6E7376797A7C7E7D7D7E807E7D808383828588898A8B8C8C
8C8D8F8F8E8F90919191929294979A9A9A9A9B9B9B9C9E9FA19F9D9D9E9E9E9B999A9B9A
97969595959492908E8D8E91969CA4B2BEBAB5A3
995D5F795C69757D87B1D0CF9B3F2C262F31343331323436383B3E3B3736363534312F2E
362F647481596558535A656A6E7275787A7B7C7C7C7D7D7B797E83838182848688898A8B
8C8F9191908F8F8F919191909094999A9B9B9B9B9C9D9FA0A19E9C9D9E9E9E9C9B9C9D9A
969595949393928E8B8A8B8C8E939BA9B4AEA5A5
A98B67656A68676E779ABAD8C5823A222B2B2E2D2B2E3133343C413A31323333312D2A28
302E6875805564565159656C7072747678797A7B7C7D7E7D7D7F8181818385878988888A
8C8F9191908F8F9091929394949597999B9B9B9B9C9C9B9D9F9F9E9E9E9D9C9C9C9C9B98
969595939291908C88878787888D929DA59E9495
A9B06D50776A61647086A0CCE0C1532927252A27262A2E31343E443A2E2E30302F292522
2A2D6B757C5364565059666D7273737477787A7B7C7D7F8182807F80828486888A88868A
8E8F90909090909192939597989795999C9B9A9B9D9A989A9E9FA09F9E9C9B9C9C9A9797
96959391908E8C888483838385878B91958D8583
87A497706D6B7071757D8CB0CBCA961A3321262324272D3842484940352F2B2B2C2B2A29
312D65727B615F545059666B6F72737475787B7D7E7D7D7F81828181818486888988878C
919190919192929292929395969696989B99979A9C9B9A9D9F9F9D9E9E9D9B9A99979696
95928E8C8B8885817E808283848587898A837C7A
646C787066738283807F8299B0BCB9583121272324252B3D4D4E49433B3128282B2D3130
372D5F6F796D5A52505A65696C70747475797D7F7F7D7C7D80828483818487888988888E
939290919394959392909092959697999A9896999C9D9EA0A19E9B9D9E9E9C9895959594
928D888685827E7B7A7D818384848484837C7674
4850637277818A8E919397A3AFB7B4A7604C2322262527333E3D3937352F2A2A2C2D302D
332D626E7468544F515B676A6C70747474787D7D7D7D7D7F8082848484868889898B8D90
929190919294969594929194979899999999999A9C9D9FA0A09E9C9D9F9D9A9693949593
9088817E7D7D7D7D7E81848585868685827B7472
33374568888F9099A2AAB1B2B2BBC1B1AB852520272625282C2A292A2C2C2C2D2E2E2E29
2D2C656E70604F4D525C676A6C70747473787C7B7A7C7F808182838486888989898D9191
909091909194969796959396999B9B9A999B9C9C9B9D9F9F9E9D9D9E9F9C989593939492
8D837A77787B7E80818180808082848380797170
27242F4D8E959FA4A9B3BCBBB8BDC1C3B99F3E2720212527282725272A2C2F30302F2E28
2B28606D72604D4D545D6567686C707274777A7B7C7C7D8082828283858788898A8C8F91
91919191939597979696959697999A9B9B9D9E9E9D9E9E9E9E9E9E9F9F9B96959494928F
897F76787C80827C746A6260626A72706C666160
22191F30879AABADADB8C2C0BCBFC1C5B9AC5C371F20282828262526282C303232302E27
2A255C6B73604C4E555C626465696E727577797B7D7D7C8083828182848687898A8B8C90
9392919395979897969797969597999B9D9E9F9F9F9E9D9E9E9E9E9F9F9A94959594918B
857B757B838786796753423F43515E5E5A585656
221A1C275BA9ADB4ABB7C1BDB7BBBFBEB5C0A27B3329292624232324252A2F302F2C2A26
2B2661686A5C4D4E53596062646A707376787A7A7B7D7F808181818386888A8A8A8B8D90
9191909498979596979999989697999B9C9D9E9E9E9E9D9E9E9E9D9F9F9A959493908C87
817A777D8588877D6E5036313745555D62646566
231F1D232EAEABB5A8B3BCB6B0B6BBB8B2AEA29B523F31282221222223282D2D2C292724
2B2A656661574D4C50565D60646C737576797C7A797E82817E808284878A8C8B8A8C8E8F
8F8F90959A979395989A9A9997989A9B9B9C9D9D9D9D9E9E9F9D9C9E9F9A9593918D8983
7D79787F86888784795636313642516271767879
25211C1B218DB0A3AAADB1B0AFB2B5B7B8B5B3C0A2784B342625232222272D2D2C2B2A25
26365E64625547464B535C61656D7475767A7D7D7D8082807E80828486898B8C8D8D8D8F
91919093969696969798999796989A9C9D9B9A9C9F9F9E9F9F9D9C9D9D999492908F8D81
7674767C838789857F7C7978798188847E7D7D7C
27221D151F63AE93ABA7A6A9ADACACB2B7B7B4B2AD906E4C3028242223272C2D2D2E2D25
213F57646554424146505B61666D7375767A7E80808182807F8183848587898D8F8D8B8F
92929191929699989696979696989B9D9F9B989CA0A09F9F9F9D9C9C9A9794918F919080
706F73787F868B8B88858284858584898B847D7B
2B2723181E4397A5A8A7A5A4A39F9B9696A6B7B8B6AA966C4922232024272B2B2B2C2D23
28365D6468574441444E5960676D7274767B7E7F7E808281808183848687898C8F8E8E8F
90909191929698979697999A9A9B9C9E9E9D9B9EA0A09F9E9D9E9E9D9A96939190908E7F
716E6F767E858B8C8D8C8B8D8F8F8F8F8D857D7B
2C2B291E202A77B1A0A5A19C968F877D7577819CB6BCB38C6421251F24272A29282A2F1D
312A626768584743454D585F666C7174777B7E7D7C7F8181818283858788898B8E90908F
8E8F91939496979796989B9D9E9E9E9D9E9E9FA0A0A0A09E9D9FA19E9A9692918F8E8A7F
746E6D757E84898D8E8B888A8D8F8F8E8A837C7B
26292C2320204A839295928C847B736E6D757F848E9CA2A075363728232327292926203E
22235E725C504344494F565D646B727475797D7D7D7F81808082848687898B8C8D909290
8F9193959798989797989A9B9C9C9D9D9D9E9FA0A0A0A0A0A0A1A19D999795918D8D8B80
746F6D747C83888B8C8A898B8E8E8D8985817D7C
1F272E28221E234E7C807D7C776C64626B94BAB4A59A8DAB874F4A3021202526282B2F1C
2F27577651483E444D51555B616A727474787C7D7E7F80807F838686878A8C8C8C8F9291
91939597999A999897989A99999A9C9D9E9E9F9FA0A1A1A2A3A2A09C999898928C8D8C81
76706F747A8085888888888A8C8A8783807E7E7D
23292F2D29211A32506C62737E726A6A7391ADCAB79E7E8D79281C192324262626292C23
2B285C6D56483B424D51555B6269707274787B7D7E80818182848687878888898B8E9293
93949597999998979698999A9A9C9F9FA0A0A0A1A2A2A2A3A4A29F9D9A9896928E8F8E86
7C767274787E8386878888878683817E7C7C7D7D
282B2F3131261C212955466B877F74757B8A9AD6CBC5B3AEA4482C1F2224282625272926
292860605D4A39404C51565C63696E7275787B7D7E80828384858687888685878A8D9194
969695979898979697989A9B9C9EA1A1A1A2A2A3A4A3A2A3A4A19F9D9C98959291918F8A
837C7775767C8185868787837F7D7C7B7A7B7C7C
24292F2E30291E1F21342E5D84927475787F8BC4D1CCC1C2BB7A34192324292826262724
27265E5A5A493B414B52595E63696F7376787A7D7F8183838485868687898B8B8B8E9194
96969597989796989A9A9B9C9C9D9E9FA1A3A5A5A4A3A1A1A2A1A19F9D9A979492908D89
857F7B7A7B7C7E82858686817C7C7D7B79797A7A
21283131312A212123181B4D7B9E757573747FA7CED1CDD8D1B4502525242A2928262522
27245A5854483E424B535B60646B717578797A7D8082838383848686878C91908E8F9193
959696979897979A9D9D9C9C9D9D9D9EA0A4A7A6A4A2A1A0A0A2A3A19F9C9996938F8B88
8682807F807E7D80848584807B7D7F7C79797979
202E3D4E3E2023202115183E678D867A70717E8ABBD5C9D1CFD0A12F3026262627252423
2A20525E4A433C414A515960666C7074787C7E7E7D80848382848788898A8C8E91929293
94969898989A9C9EA09E9C9D9E9F9FA1A4A5A6A6A5A5A4A3A2A3A3A3A2A09D9994908D8A
88858382818181828382807E7C7B7B7A797A7B7B
23374C6D4C1A251E1F191A304F7696846F717F72A4D3C2C9CAD6D1822E24262526232324
2C204B64403D3B4149505760686D7074787E827F7B7F84828184888A8B88868C93949493
93979B99989CA1A2A2A09D9EA0A2A3A6A7A6A5A6A7A8A8A7A5A4A3A5A5A39F9B9692908C
8A87858382838584827F7D7D7D7A77787A7C7C7D
2D3E54907C43241B1D191B23376D98966D6E777393BDC4CBCAD0CBC66829212025242422
252A43613D3B393F48505961696D7074787D80807E818382818387898A89898D92949495
96999B9A9A9EA2A3A3A09EA0A3A6A7A7A6A8A9A8A7A8A9A8A7A5A3A4A5A29E9B9895918D
898786848284858583807E7F807C78797B7C7C7D
394D638D6D4E271E1D1B1C1B256090A46F6E707885A5C6CBC9CED2C0C142291D24252621
1E333F5C3B3A373E47515A63696D6F74797B7D8082838282828384878A8C8D8F91939598
9A9A9B9B9C9FA2A3A3A09FA2A6A9ABA8A5A9ADABA8A9A9A9A8A6A3A4A4A09C9B9A97928D
888787848384858585828081817D797A7B7C7D7D
4360819D8960281E1F1E1F1B223D77A27E756E727B9DC4C8CACED0CBC1A7471C24222723
2426415D3735343D48525B62686C6F74787A7C8083838383848484878A8D8F8F90949798
989B9D9D9E9FA0A1A1A1A2A6AAABACA9A7A9ACACABABAAAAAAA7A4A5A5A29E9C9A97948E
888786858485868584828181807D79797A7D7F7F
50739FA59A63291F2221231F251E5A958D7F6D6A7396BBC5CBCCCBD4D0C48B33251E2726
2B1A455B3432313C4A545C61666B707477797B7F83838385868585878B8E8F9091959998
979A9E9F9F9F9F9FA0A2A5AAADADABAAA9A9AAADAEACAAAAABA8A5A5A5A3A19D9997958F
8986858585878886848381807F7C79797A7D8182
6187B1A58D492A2024252724271F417D909166696F87A0CAC8CCC9D0CDD9B46B22202625
2826434A3835353F4C555C63686D7175787B7E81838282848787878A8D8E909193969898
989B9E9E9EA0A2A3A5A6A8ADB0AEACACADADADAEAEABA9AAABA9A7A5A4A3A19D99979690
8A88868686868688898581807F7E7C7B7B7F8283
7695B399732B2A222627292929282E618C9E656A6E7885C9C5CBC6C9CAD9D3A430262623
24333F3B3B3839424E565D656B6F7376797D81828181818487888A8C8E8F909396979798
999B9D9C9CA0A5A8A9AAABAFB2B0ADAFB1B1B0AFADAAA8A9ABAAA8A6A3A2A09C99979691
8C8A88878786858A8E878080807F7E7C7C808384
999B94714D272B242424272728262B4685957C65727380A9CAC6C1C4C9D6D7BE7631251F
2430354231353A424B555F656B7177797A7C7E7F8082848485888B8C8D8E909396989899
99999A9B9CA1A5A7A8A9AAAEB2B0ADAFB2B2B1B0AEABA8AAACAAA8A7A5A3A09E9B989593
908D8A898888898B8D888381817F7D7C7C808384
B0956A4629292C262121232425232D307687956675718085CAC3BBC0C8CED1CCBE432D1F
252A2D4A28313A41495560666B737A7B7A7B7B7D8083868483878B8C8C8E909396989999
9998989A9DA2A5A6A6A7A9ADB1B0AEB0B2B3B2B0AFABA9AAACABA8A8A7A4A09F9D999494
93908C8A8A8B8D8C8B888583817E7C7C7D808384
9A77472F21262926212223232421252A587C9E7971707A75B7C9B7BEC4C8C9CCC19F381E
292C303F2D3237404A5763696D757A7977797C7F828587858486898C8F90909193949698
999A9A9C9FA2A5A7A8AAADB0B3B1AFB0B1B3B4B2AFACABADAFADA9A8A6A4A1A09E9A9592
8F8F8E8C8B8E908E8A898784817E7C7D7F828384
76552B22222426252323232424201F28396F9C8D706F756C9ECBB7BEC0C0C0CFD1B46B35
2B2B34323333353F4B58646B7076797775797E81848687868585868C9191909090929497
9A9C9D9FA2A4A6A8AAAEB1B3B4B2B1B1B1B4B6B3AFADADB0B2AEA9A8A7A4A2A09E9B9791
8C8E908E8C9093908B898785827E7C7E81838484
54432824242528262426272726232020275B8D91846B776D88BAC3C1BCBEC0C5C5CDAE3B
352B2D2B303136414E58626B72757777787C8081828384858585868A8E91939392939597
9B9EA1A3A6A7A9ABADAFB1B2B3B3B2B5B7B7B5B2AEACABADAFACA9AAAAA6A19F9E9C9995
919192908F9293908C8A888784807C7F82848585
3C382E2723262A2827292B2B2927241B1D47768D996B7A7276A2CBC5B9BDC2BEB9CBCC8E
2E2628292B3036424F58606A737575787A7E81817F808183868686888B91969694959799
9CA0A4A7AAABACAEAFB0B1B2B2B2B4B9BDB9B4B1AEABAAABACABAAACADA7A19F9D9C9B99
97959392929393908D8B898886827E7F82848586
51303038413629292B2A292D2F2A241E20395A83A37C75737687BDCCB4BDC0BBB7C8CEB9
6C2A23242F32373F4A55616A717577787A7D7F7D7C7E808386888B8B8C9297979798999B
9DA0A4A9ACADADAEB0B2B3B3B2B3B4B7B8B4B0B0B1ADAAADAFADABACADA9A4A29F9E9D9A
97969594929394918E8C8B89868381807F828585
6831352621252B2D2E2A272E332C2423272E4074A18F74737B72A6CCB1BBBDBCB9C1C3DD
AE3B2A243132363C445361696E757979797B7C7B7A7D8183868B8F8F8F939798999A9B9D
9EA1A5AAAEAEADAEB0B3B5B4B3B3B3B3B3AFADB0B3B0ACAFB2B0ADACABAAA8A5A19F9D9A
96969794929394928F8D8C89858584807D808384
5332312A292A2D2D2D2C2B2D2F2D2A292929335E869D836E7B6F8BB4B8ABBEBEBFC3C4D8
BBA13F1F292A343B445260676C73787A7A7B7D7C7C7F8284868A8E91929395979A9B9C9F
A2A4A5A9ACADADAEB0B2B4B4B4B2B1B2B2B1AFB0B1B0AFB1B2B2B1AEACAAA8A5A29F9C9B
9A979493939393908E8C8A878584848280808080
3A352C2D2E2E2E2D2C2D2F2C2A2D2F2D2A272B4764A0956C7B727497BD9FBDBFC4C2C2D1
D7C07A351F20313A45525E656A7177797A7C7D7E80828485878A8D9194949396999B9CA0
A4A6A6A8AAACADAEAFB1B2B3B4B1AFB1B3B3B2B0AEB0B2B1B1B2B3B1ADAAA7A5A39F9B9C
9C9691929493918F8D8A87858483848483817E7E
3E382B2E32312F2F2F2E2E2E2E2E2E2D2B282935488CA27D736F717FB5B5B1BBC1C2C2C9
D0D8B54F30282935444F5961676F7678787A7D7E80818386898B8D9093959596989B9EA1
A2A5A7AAACACABADB0B3B4B1AEADAEB1B3B3B2B1B1B1B1B0AFB0B1B0AFACA9A7A5A19D9A
979593939593918F8D8A87858484848382818181
45392B2E34333031312E2C2F322F2C2C2C2A29283370A5906F6B726DA5C9A8B5BCC0C2C4
C5D2C9B132342432424C545D656E757676797C7E7F8081868A8C8D8F92969897979BA0A0
A0A4A8ABAEACAAADB0B4B5AFA9AAAEB1B3B2B0B2B4B1AEAEAEAFAFB0B0AEABA9A7A39F98
93939494949391908D8A86858585858280828485
4134252B3433312F2D2C2C2E302E2C2D2D2A2826315092A383636B688FB7B8A9BBBDC1C0
C0CCCFCA8D3231344047505A656D737474777B7E81818185898B8E9092969A99999CA0A1
A2A5A8AAACABAAACAFB1B2AEAAAEB2B3B2B0AFAFB0ACA9ABADAFB1B1B1AFACA8A4A09C98
95939291909192908D898684838484817D7F8282
3B2E21293333302C292A2C2D2D2D2D2E2E2B2928333476AA98616769799EC6A1B7B9BFBE
BDC4CBCFC57831313F464E59646C717374777A7E82828184888B8E9093979B9B9B9D9FA1
A3A6A8A9A9AAABACADAEAEADADB1B5B3AFAEADACABA8A6A8ACAFB1B1B0AFADA7A19D9998
97938F8C8B8F93908C888583818283807C7D7F7F
352F292F36322E2D2C2A2A2C2E3030302F2E2E2A2D2C5391A0786C6A6D92BAB5A9B3BEBF
BEC3C7C8BFC961313842505860686F7274787B7E808182868B8C8D909497999B9C9D9EA1
A5A7A8A6A5A7AAACAEAFAFADABACADACABABABACADABAAA9A9AAACADADACABA7A29E9B99
97918C8A8B8F918D88868583828282817F808080
3131313537322C2D2F2B282C313333323032322D292B366D9E91776B6687A6C69EAEBCBF
BFC0C1C5C5D0B3443B3E51565C656D7175787C7D7F8082888E8D8C909596989B9D9D9DA2
A6A8A9A4A1A4A9ACAFAFAFACA8A6A5A6A7A8A9ACAFAFAEAAA6A6A7A9AAAAA9A6A4A19E9A
958E898A8C8E8F8B868584838382818283828282
2F30313333302C2C2D2B2A2E333433323132332E2A2A314A87A0886164768FB1A9AFB6BA
BDBFC0C5C7D4BAA7503246515C656C717476797C7F8285888A8C8D919597989B9E9E9FA2
A6A7A8A4A1A4A9ACAFAEACA9A6A6A6A6A7A7A8ACB0AFADACABA9A8A7A7A9ABA8A5A4A39C
948E8A8A8B8E918D888786848382818182828282
2E2E2E2F2F2E2C2B2A2B2D31353433323232322E2C2A322C69A2965F66687996B5B3AFB4
BABDC0C3C7D2D2C58C3F40485C646A6F7374757A7F848887868A90939697989B9E9F9FA2
A5A6A6A4A2A4A7AAADAAA7A4A3A5A8A6A5A5A7ABAFACA9ACAFADA9A6A5A9ADA9A5A7A79E
938E8B89898D918F8B8988858382828180818282
2F2D2B2D2E2E2D2B2A2A2C32363431303031312C27252A26498796856B656B8AACBFAAB2
B7B9BBBFC5CCCFD5B17F513B545A676C707274787D838887868B90949798999A9B9C9DA0
A2A3A3A3A2A2A3A3A3A09D9C9C9FA1A09FA0A2A5A8A6A5A8ACACABA8A6A8A9A6A3A6A8A0
97908A8685888C8D8C8A87838081828180828585
2F2C2A2C2E2E2E2C2B2B2C3236332F2E2D2F3029232224262E628EA9746963819EC7A9B0
B2B4B6BBC0C5C8D2CEC16F394E5362676C7074777B818687878C91959899999897989A9D
9FA0A0A1A19F9D9B999693949698989897999C9E9FA0A0A3A5A8AAA9A7A6A5A2A0A4A7A3
9C9188838183868A8C8A87817D80838180838788
2C2C2D2D2E2F2F2C2B2D303234322F2E2D2D2D2924232422273E7B9E8D75637690B9B4B0
A7ADB5B8BBBFC4CDCFD1A4674F51575F696F74787B808687898D929496999B9A98989899
9A9B9C9C9B999796959290929494949392949596979A9CA09EA1A4A5A4A6A7A29EA1A4A4
A1958883818285888A898783808081807F838687
292C30302E2F2F2D2B2F33323130302F2D2C2B292726262025206385A185676D81A3BFB0
9DA6B3B5B5BBC0C4C8D2D29B5C5C4D57656D74787B8084878A8E929394989B9A99979696
969797969593929394918E9093918F8E8D8E8F8F90949899979A9D9FA1A5A7A29C9DA0A3
A3978A84818284868888878683817F7E7F828687
2B2D30313131302D2C2F32312F2F2F303031302B2725241F211C437099996E6A7285BDAE
A0A6AFB1B3B6BBC1C7CDD1BEA1585A56586370767A7F8385888B8F929394949596969696
95949290909192959690898D908D88888886898B8E8D93839696989B9EA0A09C9897979A
9C968E837B7D82858787858483817F7E7F848889
2E2E2F313332302E2C2E312F2D2E2F313435342E272422201F1F275985A5796B666BB1AD
A7A8AAADB1B3B6BEC6C8C7CEC59D54594E5C6B73797E818385888C9093908D8F92949596
95918E8C8C8F9397988F85888B878280808084888C888C70949192979C9B989796939092
94948F82767980838685838282817F7F80858B8C
2B2D2F2F2F2E2D2C2C2F312F2C2D30333535332C26252523211E1F4064938F735E6693B7
B3ACA1A7B0B3B5BCC3C6C8CDCAB99C555A5A676F787C808386888B8E908E8C8E90929392
91908F8E8E909395948A807F80817F746A847F86858E776F88807B8C9D9A93989D9B9895
938E887E76787C81848483828281817F80878F90
282C2F2D2B2B2B2B2C2F322F2C2D30333634312B26262725231E1E2C43769E805E6674BC
BDB29DA4AFB2B5BAC0C5C9C8C5C9C29B5658666D757A7E838788898B8C8C8C8D8F90918F
8E90929190908F908E857B76747A7D6B58887C8581966C7B83776D869F9B939CA5A6A29C
948A827C78787A7E828383828182828080899294
2A2A2A2A2B2C2D2D2E2F302E2C2C2D303333312F2C2825252521202230519097735766A4
C0BAA9A8A9AEB4B9BDC3C7C9C8CBC9B28D705C626F767C80838586878887878B8F90908F
8E90928F8C87838789847C7169727A695A7C808A87835D6C76685E80A3A5A1A6ACADABA5
9C91877F7B7A7C7C7D7F818080818381828A9394
2C2825272B2E3030302F2E2F2F2D2B2D30313133322B23242624231E263077A48B515F87
BABFB9AEA4A9B2B7BBC0C4C9CBC8C2C6C18F5F5D69717A7D7F818384848282888F90908F
8E8F8F8B857C767B81807B6E646E796F6673878D8F8F949FA89F969CA6A9ABACAEAFAFA9
A0968C847E7D7D7A777A7E7F7F818383848B9294
2B272325292D3031302F2F3439342F2F3131323537302927262423212726568B95765771
9CBCCAB5A0A3ADB2B8BCC0C7CBC9C6C8C8AD8E715D66777B7E7F808283807F8891919090
8F8D8B867F776F69676D7474747D8687888D989B9FA0A7AFB4B1ADAAABBBC6B49F9D9D92
8B888784827F7C7976787C7F82828282838C9496
2B272424272C313231303039413B33313131323639342E29262323262D223B6B949A5763
7BADD2BB9E9FA7AEB5B8BCC3CACAC8C6C3C5BE8D5E6374797C7D7E80817E7D8791918F8F
8D89837C756F685B535E6E7B858B8F99A1A3A4A8AEB4BBBFC1C4C4BEB6AA9F98928E8A7C
7478808384807A7776777A7F84838181838C9698
2C2B2A29282D333434302D363E3A332F2D2C2E3336312B29282623201B4127537C977967
6385C0C6A19FA1ACB7B8B8C0C7C8C8C7C5C8C5AD907A6B6F787B7C7C7B7C7E868E8F8D8B
877F75675B5A5C5D6168717F8A87828388909CADBDC2C3C6C8CBCDC9C2B5A7978A8C8D8D
6D737C81837D767677797C7F81828282848B9394
2F30302C2A2E34393C322A303836312D29282A2F332D27282A262223291E37475C809872
555CA5C9A6A19BA9B7B7B5BCC3C6C7C7C7C4C2C7C3986C6B74777977767A7F84888A8986
7F746651414550637476767F857A6D64637289A6BFC6C7CACCCFD1D1CDBFAE99888D8F9D
6B727A7E7E797374787A7C7D7E818384868B9091
36322C2A2A2D34465642282C3535332E29292B30342F29292B27242529273035445B9184
584986ACAB9E939EADB0B1B8BFC4C7C8C8C6C4C9C9B4997D686B7475777D82818081817D
75685841323A4A5D6F787B776E5E4E484850607A98B8CDCECED0D1D0CCC4B9A5928A8284
68717F7A727172767A79777B7F828587898E9394
3C322726292D36556F50292A3233332F2B2B2D3337322B2A2A2827282A2B2B2830397C90
63456B8AAC9F9097A1A7ADB3BAC0C5C7C8C7C6C4C3C9C69768666F73787F827D76767570
685A4A362935485968767B6B5544383333353D4F6A9ECAD0CED0D0CECAC8C2B29D846F65
67738275666B73787B767278808486888B919798
3830272528313A69774C342C2D2E2F2D2B2B2C3338312928292A2B292728282225316183
77575C799EB5A2A09C9C9FA6AFB6BDC3C7C9C9C6C4CACAB39679646973797B736A66635D
55483B302D394B5F6F75715C41424B58625547404D6BA9CFCFD3D0CFCCCDC9B79E795A57
627D746B61687174757474797E83868789919899
332E29262634417B754140302A282A2B2C2A2B3338312726282C2F2B252526222434486C
8771596E8AC5B6AE9C96959DA7AEB5BDC5C9CCC9C5C5C5CBC69565636B6F71695E57504A
43382F2E333E4E657670624B394D645C50565C463D3C82C9CED5D0D0CECFCAB5976B4752
62846363616971706F73777A7D82868788909799
302F2D282930528D5F344233292627292C2C2C3337312A27272D312E2A27272E383C4353
849070696EADC5BBA6A2A2A8AFB3B7BABEC6CDCBC8C7C7CDCBB1916C575F6962564B413C
37312D2E323D4B6374624E3C52575A4A3C49515B472B5CB5CBD2CACDCECAC3A5815B435C
777B59606A7073716F757C7F808487898B8F9394
2E2F312A2C2F659546284133292625282C2D2E3236332E2A282E3535332C293B4D443F3A
75A48A6C588CC7C3B3B0B0B4B8B9BAB7B7C2CCCDCACAC9C8C6C9C1795254615B51453934
322F2E2E3139455D6D523B31695B483223374A70542C48A4C8CEC4C8C9C0B28C654B4264
856C5260747877737179818384878A8C8E909191
2F2E2E273037787D392836312D2A282A2D2D2E2F3031322C2937464844382B221D212E2E
538F98895676A2B7C2B4A9ADB4B6B7B5B5BBC3C9CDCBC7C7C6C8BDBB71584D54554C423B
36302B2B2E343D505D463232564A392B251C38544F364497CFD3C4C2B9B58965453C3F55
6A584C617B7D7A76747A818486888B8E90929393
2F2E2E283344885E312B2C2E2F2E2C2C2D2D2E2F32373B342F3F50534E3C2A2829201B22
326D9BA3626778A5CBB8A2A5AEB1B3B3B4B5B9C5CFCBC4C3C3C8CCB7B66C474C59544D46
3D322A292C2F35424B3C2D363D362D252927634E415D83ACCFCEC0B5A0A05D412B2F3B42
47474A657F817C7A787B8184878A8C8F91949696
2C323E4330548C4D2D2B2F2E2D2C2A2A2B2927394E575B534C5C6752382F2B26221F1F20
29498CA0846C6290BDCAAAA9A9ACAFB2B4B6B9C4CDCBC6C4C3C4C4BFB7B46C424C4C4C47
3F362E2D2E2F31363A352F3434312C292B29493E3E58769CBEBBA99376693E30272A2F2F
3240536D8385827E7C7E8285898A8C8F92959697
293A4C5A2C608A412B29332F2A282828292628496B767671654F382B24272B2824242721
262A7390A37A587CA7D3B5AFA5A8ADB0B4B7BAC3CACBC9C6C3BEBBC5CCB6B64C49434A46
413A35323130302F2E31333331302E2D2D2F2F333B4B6186A39E8A6C4C3529282B282524
29426076858886827F8082868A8B8C8F93969798
2A4C45492F5B803A2A262F2B272525242A254D65797A705E49392C26242A2F2B25272822
221F4979A39462728CBEC1B4A5A9ACAFB2B5B8C0C7CACAC6C1BDBBC2C4BDB2AE66404642
433E3835333131303032333332312F2E2D2F2C2F353E4A6479715F4B382B27272926232D
3D587380878784817F8082878B8C8D909396999A
305838323254743529232926252323232E2E727A7B6F5D41272122252A2F322E28282924
211D235E92A87570749EC5BAA9ABADAFB1B3B6BDC4C8CAC6C1BEBDBAB8C0C1CAA6574C42
46413D3936353435363534343433312F2E2E2F2F3032374550483A332D2C2C2A2927293F
5A7184888785817F7E7F82878C8E8F9193989B9C
4B40332B2F5E682F282226262626272C375A797362503E312725262A2D30312C26272725
1E1C1E466DA68E7B6E7AACC5B8A1AEADB0B2B5BCC3C8CBC8C4BFBBB9B8BCBBD1BC874E42
42474946413E3A3532353937343332302F2F2F31323130343735312C2827272A2E2C3A5B
788289868282837F7D8085898C8E9094989A9C9D
5F262F292D685F2B29222526282A2E3944827361433023262E2E2E2F30302E2925262726
221F223045959F8A725D8DC7C39CB0ACAEB0B4BBC3C7CACAC8C1BAB9B9B5B3BFC4D2936C
494C54524E49433A3339403C36353534333232333433322F2D2F312E2A26252E3C355171
8C8D88817B7F837F7B80878A8C8F92979C9D9D9D
49272D2C345B612C2E252525272D36495877644C2F2726292E2E2F2F2F2F2E2B28262820
382C23212C70929F805676A8BAB8ADABAAACB0B8C0C5C8CBCBC4BDB9B5B1AFB5BDE2D097
59474D525956514D4B4C4D453D3C3D3F3F3B35312F363E4140362B30332F323F4A776060
7A8F7F7D797B7C7A787D83878B91969A9D9E9E9E
2D2D2C313B4D622E32282724263140586B61503723262F2E2D2E2E2E2D2D2D2C2C2B3121
4C3824181C4879AA905D6884A8CFACABA7A8ACB4BCC1C6CACCC7C1B8B1ADABAFB4BCC3BE
AE6C4E5262615F6265615B5149484A4E50493F322B3D525B5B453038423E415974728754
6087747876757473747980868D949A9D9E9FA0A0
2C2D2A2F375556342A262825263649616F5A3D2D23252A2B2C2F302D292A27292A23262C
4B341C181C3558919D7768728BBABCB4A6A7ABB0B6BDC2C6C8C7C3B9AEA8A6A9AFB6C3D1
D0C571645E60666A6D6B67646161626567645B3F2D476B88987653465F634B6072798362
627871706C6C6E6D6F77828C94999B9EA0A1A2A2
2F2C292D315D473923242926273B51656E522F28282626282B2F302C262828262A405653
402C1B1C2228386EA090736C739BC4BAA9A8AAADB1B8BFC2C4C6C5BBAEA6A1A3A9B1B9C2
C7B6B98B61616C6F7272727578797A7C7D7D7651365B879190857B5C798557616A747871
66676C66606267686B7887949E9E9D9FA2A3A4A5
292A2B2D2D563C3A2C2928252C4056636B413628272526282A2C2D2A2C243F3E436D744B
34333E21211B2551829290807487A5B3BAB0A4A8B0B4B9BDC1C6C7BFB4A69C9DA2ABB5BF
C6C5C5AE927C6C6F777A7D7E7F84898A8987826856759AA19E948975838A735E6C6C6A66
5E5A5C56525357606D7D8E9BA5A5A2A3A5A7A7A8
23282D2C28493238382F26252D42585E62323F2D252528282928282932275B5B5974521F
2D425E2523161B375C89A9977C787FA5C7B8A2A6AEB1B3B9BEC4C8C4BBA999979CA5B0B8
BFC5C7CAC39A747681838382838B9292908D887D788DA5A6A1988E89838387596A605B56
534F4B4948494F60758696A3ABAAA6A7A9A9AAAA
242428384670554736404B5A464C4E5C462F353C2425272728262529322745606C865624
2D4E57272E201D273F73A19C89716A8FB8B9B1AAA4AAB3B7BBC1C5C5C0AF9E97979FAAB2
B9C0C3C9C9B79E7F686E7D848B91959898948F8D8F9AA5A49F968C857B7574565A524D48
444242454A5564778A98A2A8ABABA9A9A9AAACAD
2626272828513C3E3A3A34492339475C2C2F2A4825272627282524283251686237665A30
345745283D2D221E28598A9895755D789DB4BFAF9DA6B2B6B8BDC1C5C4B6A69A949BA5AD
B4B9BDC1C4C7C4AD9480747F8F9293989C9793979D9E9D9B978E84796E6359534B474440
3D3F444C576B8092A1A9ADADAAABACAAA9ABADAE
2527292929403B44464138422F3E484C2B2E2C3E2E2C28292B272738466E6724254B5C2B
495B34254B341E1C264264899A8F5E66799CBBB3A5A8ADB1B5B9BCC3C5BCAFA196989FA6
AFB7BDC0C1C6C7BDAD95817D7F868E949B98939697928B88847C72675C4F454745444348
4F555D6B7C8A97A3ACAFAFAFAFB0B1AEACACADAE
24292E2A282C36454F4437343842493B2F2D2F3236302B2C2F2A29465A73434A35465C26
5D59262356391C1E292F3D7197A6695D5A82ABB3B0ADA9ADB2B4B7BFC5C0B6A79A979AA1
AAB4BDBEBEBFC1C7C7AD9181787B838A92918E8C89817874706A63584E433C4149494C5A
69727C8FA0A7ABB0B3B1AFB0B3B4B5B2B0AEADAD
222C362F282B353B3F3832333B3B3F332E2C2E323A332B2C324150485557383735376037
654F29285F3E201D23212B4A879E866C576B8AA6BAB4A9AAAEB0B3BBC1C0BAAA9B989A9D
A3AFBBBEBFC1C3C5C5CDC99E7065666E71767978746F6A6764636158504F525860646976
848D95A1ABB0B2B5B6B4B1B1B3B3B3B2B1AFACAC
212E3B332A2F35322E2D2E353A36332F2C2B2D343A332C31383536264F3D302C362C624B
67442F2B62452921211B23266F8A9D81615E6A93BAB8ADAAAAACAFB6BDBFBCAC9C9A9B9B
9DABB9BEC1C3C4C4C2BFBBBAB080505C555D636361616160606467605C6570757A818993
9CA3A8ACAFB2B4B6B7B5B3B2B2B1B0B1B2AFADAC
212B37332E363D3B3734313434402A2A2A29292D312F2D313635382955372B2530255F5A
654329235D593536362A231F476E95907F685B799EB4BFB4A6A7ACB2B7BAB9ADA09B9A99
9BA7B5BCC1C2C2C3C3C2BFBDB7A5904748444E565F6468696B717877777E85888C939AA0
A6AAADAFB1B2B4B6B7B5B3B1B0B0B0B1B1B0B0AF
20283231323B4443403E3B38324C272A2B282627292C2F323532352D5A3F2A232A225864
6442241B526C464B4839292225507E959B7958627DA7C9BBA5A4A8ADB2B5B5ADA49D9998
9BA5B1BAC0C0BEC1C4C0BBBCBCBDB49F68524753656E74787C838A8F93949597999FA5A8
AAACADAFB1B1B1B4B6B5B2B1AFB0B1B1B1B2B3B3
1F262F2E2D31354D635F554E454E3C39342D28282A2C2F3439333328545D262526264762
6F3D26203D5F392B3737322B24375380A188675E638BB3B8B3A8A3A8AFB1B1AEA8A29D9B
9EA7B1BAC0BFBCBEBFBEBCBAB8B9B8B9AB8D716C6F7780868B9094999C9E9FA0A2A5A8A9
AAACAFB0B0B1B1B3B4B4B4B2B1B1B1B2B3B5B6B6
21262C2B292A2A3443596B665B5250473E342B2A2C2D2F373C342F234B792827242C375C
79382C2327686534212C3A342B242B6398917A61526E93ADBEAFA0A4ACADADADABA6A09F
A0A8B2BAC0BEBBBABBBCBCB7B2B1B2AFADA9A28F7E838C93989A9B9EA0A3A5A6A7A7A8A8
A9ACAEAFAFB0B2B2B1B3B5B4B3B1B1B3B5B7B8B8
2E27272D3622373C454A5160686846433F362E2A292B2F363B30272842733C24272F3B5A
73393A2A274A72363922362E292022497383856B535E7494AEBDA3A4A4A6A9A9A7A39F9E
A1A8B1BAC0BFBCB9B7BABBB6B0B0B3B4B7B1AA9F969495989B9EA1A3A4A5A6A6A6A6A6A7
A9AAABADAEB0B2B1B0B1B3B3B2B2B1B1B1B4B8B8
3B2E252F40214341403531546F77393D423A312925282E35392D212E396552212A314356
663A45322F265C7E3E193129252021324A6E8A785F595F7B96C3A8A59EA1A4A4A3A09D9E
A1A8B0B9C0C0BDB9B5B8BAB4AEAEB0B3B5AFA9A9AAA39C9A9B9FA4A5A5A5A5A4A3A3A3A6
A8A8A7AAADB0B2B0AFAFB0B1B1B2B2B0AEB2B8B9
3F492D2F31343534322D2B2E3B696F644F40332A26282D353A2F242C34596124272F434E
51373B33332644736B3F2D23211E1F2331547B837F6F666F7FA9ACADA6A29FA0A1A09FA0
A2A9B0B8BFBFBCB9B7BABBB4ACA7A1ABBAB6AFACA9A6A29E9B9DA0A2A3A5A6A4A1A1A2A4
A7A6A6AAADAFB0AFAEAEAFB1B2B3B4B2B1B5B9BA
3C5E38302245252624262C3747525D615E4B362C28292C353B332A282F4D6A2A25304545
3D342E31362F2E618E62281E1E1D1E1D25436A879A8A776D6D89AAB0AEA59D9EA1A1A1A2
A4AAB1B8BDBDBBBABABBBBB3A99B91A3BBBBB5ADA5A5A6A19C9A9B9DA0A4A6A39F9FA1A3
A5A5A6AAADAEAEAEADAEAFB1B2B4B5B5B5B8BBBB
2F4B423625392925212A374F3E3E44535D503E32292A2F3438332D282A476536273C5637
323B242B313432587B56241E201D1C27315D677F899F8B796A768FA1AFA9A0A0A1A1A2A4
A7AEB5BABCBBB9BBBBBAB6AFA28286A8B3BDBEB7ADA9A6A19D9A999A9D9FA09E9C9EA1A2
A3A4A6A9ACADADACACAEB0B1B2B3B5B5B5B8BCBD
2232463A2B2A2E28253646663C2F253D565348382A2C313435332F2827435B432B45612B
2B40202931363A505E41211F231D1D354B7A646C6BA69B89706D738FA9ABA6A3A1A1A3A6
ABB2B8BBBCBAB8BBBCB8B0A79B6D7FAFABBCC4C0B7AEA6A29F9B99999A9A9B9A9A9DA1A1
A1A3A6A9ABACACABABAEB1B1B1B3B4B4B4B9BCBD
232B39332B282B2C3058594B362B2735475153412E2D303437353029273D4F512B3D4E2E
2B382B36452F3649593F221F221C2039757C5B404E869C948173708095A4AEA79FA1A6AA
AFB1B4BBC0BCB8BBBDB7AF979D6C83B2AAB9C0C2BFB7ADA8A49F9B9B9D9E9E9B989BA0A2
A3A3A3A7ABACACACADAEB0B1B1B1B2B4B7BABCBD
26282A2B2B2828334075642E342D3031374A5948332E2E343A37312B2939435A2E343733
2C2E39485929364556422922221D284398764E17335C8F97918175768099AFAAA0A3A9AD
B1B0B0BAC3BEB8BABCB5B088A0748AB3AAB4B9C1C6C0B7B0A9A39F9FA0A2A39D989A9EA1
A4A2A0A5AAABACADAEAEADAFB1B0B0B5B9BBBCBC
262728292A27294054685037423A342F2E3E4C42352F2E343A3834302E363E503D3A342E
262C3A5D5E34494A4942392D252B396A9467361325406986969C797474869AA7AFACA8AA
AEB0B3BAC0BDB9B7B6B4B4879E838BB3A2ACB3BEC6C5BFB6ABA6A2A1A2A3A4A19E99979C
A1A09FA3A7A9A9ABADADADAEAFB1B3B6B9BCBDBE
272728292A272B4C675238434D4438302B333C3B37312D323939383432353A424A413529
222C3A6B5D445D4F41474C392937498F875A231A1D293F6C90AF8178707583A0B9B4A9A7
A9B0B7BBBCBBB9B4B0B3B78B9A928DB09BA6AFBBC5C8C6BBAFA8A4A4A4A4A4A5A49A9296
9D9D9EA1A4A5A6A9ABACACADAEB2B7B8B9BCBFC0
2B2826282B282D4F714030353C3B39363332333A3F352B2F35393A363231333C473F332A
2735455E554D6047515558575B5C78AA8B60291F1C1D294D729B96897672778EA6B3B9AF
A5ADB8BAB9B8B6B2B0B4B696929597A99EA7AFBAC3C8C8C1B8AEA5A6A8A8A6A5A39E9997
96989C9FA3A3A3A7ABABABABABB1B6B8BABDC0C0
2F2A25282D2A2F5273342D25292F373C3E362F3B45392A2C32373B37322E2D37403B332E
2E3C4C4C4E566044676560524B39669C8D6733231D181D314F7BA1988377727C8EACC3B6
A4ACB7B8B7B4B1B0B0B3B29F8B94A2A2A5AAB0B9C1C5C7C5C0B2A6A8ACABA9A5A2A3A39B
9395999DA1A1A1A6AAAAA9A9AAAFB5B8BBBEC0C1
2E2A25282D2E33636B3D2824292D3340493D30373F372E2F32363939372F2A323B3B3835
33363D4655616C66775752434135699177432C201F1C1E24345983969D8978767E98B2B5
B1AFAEB3B7B2ADABABAEAD9C8895A7A7AAADB1B6BCC1C5C4BFB4A9A9ACAAA9A8A7A7A6A1
9C989697999DA0A5A9A9A9A9ABAFB4B8BBBEC0C1
302C282A2E323671634A26262D2C2E404F433434363432323234363A3C31282F383C3E3B
372F2D445F6972808244402E303169835C20231E2222231F213A5B89AB9B8377738399AD
BCB2A6AEB6B0A9A6A5A8A8968796A9AEAFAFAFB3B7BDC2C1BCB4ACAAAAA9A8ABADAAA8A8
A79E969394999FA4A7A8A9AAACAFB3B7BBBEC0C0
413D362F2C303967694F2A282D2B2B3843433F3A363635312E2F32383B3229303B3E3F3A
3432354E5F6C5B617E39362A303A7E854624272324242320202738638BA7958171737E99
B2B3AFAFAEAAA6A5A5A7A6938595A9AFAFAAA6AFBABEC0BFBBB5AEABA9A8A9ABADABAAAB
ACA8A29B9595989FA6A7A8AAACAEB1B4B8BBBEBF
4E493F332B2F3B586F53312B2B2A2A2E343F4740373738312B2B2F3439332E3640413F37
323842565E6A3F3A7233302A374B9185342E2C2826242324241D1D3C5FA59F8F776A6882
A0AFB7B1A8A6A5A6A6A7A5918393A8ADADA59EADBDC0BFBDB9B5B0ABA8A8A9AAABABAAAC
ADAFAEA69C96939AA3A5A7A9ACADAEB1B5B9BCBD
61625E452F2D37536E56373029282A2B2E39423A32373C352C2D313133383E4346433E38
363E4B485C612D345C39342648728F712C27262525232122231C1A273C778BA7907A6471
869DB1B7B5ACA2A4A7A7A390818E9FA7AAA5A2ABB6BDC0B9B1B3B5AEA8A8AAAAAAA8A7A8
A9ADAFAFACA096969BA0A6A9ACADAFB2B5B8BABA
3D3D3D383430335068583F3328282A2A2B333A332D363E372F30333030404F4F4A443E3B
3B434F3A5A582134464039265795885C2A2224252724212122201F1B21446DB1A58D6C68
7088A3B6C0B3A2A3A6A6A18F808A99A2A9A9A8ABB0BAC1B6ABB1B9B2A9A9AAA9A8A5A3A3
A4A8ACB5BAAD9D96959CA5A8ABADAFB2B6B7B8B8
5B5243372E2B3049615C4F2B2A272A2A2B3136312C3138342F3032363B49544C41414344
443F3E425B5A21323F3B33305296855A2A2A333535302A262422211C1D2C49879C9A8978
6B73849FB6B5AEA8A1A19D8C79889DAAB3B0ABACB1BBC2BBB3B6BAB2AAA8A8A7A5A3A2A0
A1A5AAB2B8B5AEA69F9D9DA2A8AAACAFB2B4B6B7
7861413127272E42565D5D262F282B2A2B3033302C2E31302F30333E4951534639404A4D
4A392D4B5C5F252F3C342E3E4E8E845E31384746413A312B26242321201F2954839BA38B
6F656682A1B0B6AC9F9D9886768AA5B4BDB6ADAFB4BCC3C1BDBCBBB3ACA9A7A5A3A1A09F
9FA2A8ADB2B9BDB6ACA0989DA4A7A8ABAEB2B5B6
766C583B2425303A45535C36332D2D2C2C2E2F2E2E30312E2D343D4B545048423F49534E
45342C3B5F612129332F2E486089886D4D4F5965694C2C2525242422211F2337577E9D97
846C5B668198ACB1AF9F93778093ACB6BEB7AFB2B7BCC0C1C0C0BEB8B1ACA7A5A4A2A09F
A0A3A7ABB0B6BAB8B2AAA2A1A2A4A7ABAEB2B4B5
75562F26272C33333447564A3933302E2D2C2C2D2F32332E2C3A4A565B4C3C4048535A4C
3B2F2F2C615F1E232D2E3655758389766164685E4E3A292525252423232325242D5A8898
96785955627C98AFBAA38E6C8F9CAFB6BCB6B0B4BABBBDBFC2C2C1BDB7B0AAA7A6A29FA0
A2A4A6A9ADB0B3B6B6B3AEA7A1A2A6AAAEB1B3B4
7358352E2A2F352E2A3E4F5D3E37302E2D2C2D2E3031312E2F44585852463D434E595E47
302C333A5B4F2421283E536B7F807B62473A312925292F2C2828282522232420233E5D7C
8F7C606757647795ABAA8C759F9FA0BCB6B6B3B5B8B9BABDBFC0C0BCB7B3AEA9A5A29FA0
A1A3A5A7A9ACAFB4B8B5B0A8A2A0A0A3A7ADB1B3
725B3E3733373A2F26384869443C312E2D2D2F2F2F2F2F2F334C615746424149525C5E42
272A3649543E29242B4F717F82796644252832343433322E2A2B2C28242324232428345A
7B7A6A7E5653567692AB8780AD9E8FBEB1B6B5B5B6B6B8BABCBDBDBAB7B5B3ACA5A2A0A0
A1A3A5A5A6A8ACB3B8B5AFAAA49E9B9DA2A9AFB1
70615041524F4C3D313B475F50473A34312F2F2E2D2E3033394C5B524543444C55595640
2B2D36495239262F44537B807A664D3625272D2F303132302D2C2C2C2C29262525242940
59676E8266574A5E7392777BB19D89AFB6B8B3B3B4B5B6B7B8BBBCBBB9B8B5B0AAA6A4A2
A2A4A7A8A8ABADB2B6B4B1AEABA29C9FA5A9ACAD
6F6660496E675D4A3B3E47515B50423B35312F2C2B2D31363D49534D4645474F56554E3F
323035465238223A5D537E7B7154372D2B2D3132323131302F2D2B30332F29282727282D
39577187755C434B587B6B76B19C879EBCB9B1B1B2B4B6B5B5B9BCBDBCBAB7B3AEAAA7A4
A3A6AAABACAEB0B2B3B3B2B2B1A79EA3AAABA9A9
6F67644B75695F5E5E50454C5D53443C36322F2C2B2D31373F49514C4645475057544C3F
333134465237213C6354807B6F50312A2B2D313131313030302D2B3035302A2828262629
324661518875605852614864B39E869BBDB9B0B0B2B4B6B5B5B8BCBDBCBAB7B3AFABA8A4
A3A6AAABACAEB0B2B3B3B2B3B2A89FA4ABABA9A9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5D6685BBB54029292428262D425238333932392F2F3835392F3A37434B513F3B382F2D26
2B283E6A66665A7165535C62676A736F76827D7C83837B837D81827E8385888989888887
8C8E928B8E8C908C88898A8B8E8A8A8D8E8A928E8F9292929293908D9195938F8E929295
9090999493969B979B9B9EA0ACB1C4CFCBD1CFBE
5A597093C19C3E282C29242A373630343837372B323B30322F4135444C4D4236372F2E30
2B2742696164607A644A5C62696D7575757C7C7E7A82847F7F7E807F8586868A8B88898B
8B9090888C8A8F8B8F87888B8D8B8F8E8D9191939595928F919292909698999195949492
9293979798969A9B9BA0A1A7AAAEC4CFD1CDCCC0
595A5F729AC2953A2A262A2D38342F364438322E3335332C343D384A413D422D2E34302C
292A416364675F7B59515E69766E6D7777787D7E818281818087837F8284838B8786898B
8F8C908C8B88898B928A8A8E908D8B8E8E9694939595949595979292979C9C9394979690
94919694959B9B999B9A9DA4ABB0C4D4D3CECDC5
60595D667CACC06E2F2A24282B2A2B3D4030333031312A2E363E2F4E443E3C312D362F27
262A466C65685C77585B63656F70717276797D7B7E818082847F82828088878B8889898E
8D888D8E8C888C90928D8C908E938D949196949499979593939998999899A09A99939392
96909797949699969A999DA5A5B0C2D2CFCECCC1
5F5A5B59708DBFB35B2C27242B2D32342E30292C32332B2D3133324B4339363031343228
27304C74606A676F565E636A6E7073787A7777817F7E7E858382827C7F85888B8787878E
8B8889908B8B918B8F8C8F8E8D8F8E95949796949598969794999898999F9B979593928F
94979A9A97909897979C96A3A5AABECED1CEC8BC
625A585F6176A0C8AA3F2824242934312D2C2C3135343032383C3D4C403D433A33322C30
302D4B77696E6169515E6169737273747D7A7C827D8080837F8182848288858B898D898D
8D8F8D8D8A8C8C8A8D8B8C918C9294989A97979997979A94979C9696979D999899949494
939598959294939797989A9EA4ABB8CACECDC7BB
5C6A595A62658AC3C791372C31262C322834312E31332E2D313731413D3C3B2E322F2C2B
28264A706F6E666654616C6C717170767F7A79827A7D7E7D7E797E83848582858C898991
898D8E8F8B888A8C8E8C8F918F949697999897979B9A9694989D999C9B9C9B979794929A
9895939294949491909497969CA9B6C6CDCAC1B7
4E6955515A6994B3C7C57E3927252C2B2A313238383B39403E43424C4142423C3A3A2F39
3A3A5C72746770625D636B6B6F72787B807F7F7D7F828584838386818588888A8F8A8F91
8A8B8A8C8C8B8E8D8C9090959099999A9A9A9C99999B98989B9F9E9C9F9D9B9B9897979A
98959795929493918E8E95989FA3B1BFC9C8C0B0
516063596276939CC1CBC374383537363641403E373733383A343D3F3836342C2E32272D
2C325A6F705D6E565660646A707476787B787D827A80807E7F8280848384888D8B898D8F
8A8E8D8A8C8F938F91919397969B979D979999999A9A9C9B9F9CA09D9D9C9D9A96949A98
999796949697929291918F959EA1ACBAC2C5BBA8
65586F6A63748789A4C2D0BA4B2F2E303030343431312D353433413638363632322F2C2C
30345C73735F695554646169717076777B7D7F807A7F807F7C817F8482848B8B898B898D
8F8D908F8F918E93948D8F919398999B979E999C9D9E9EA1A49F9D9D9D9C9E9B9A989A99
999693919691918F8F8D8D949499A5B3BABFB1A1
9E5B63705F6A777D8AABCFD4A13A322E2D34383635323A393E403E3A3833393435312F31
31386077815E6751545C656D6D7275787979797B7D7C7D7B787D828682828685868E8A8C
8A8D938E908E8F8E918F91958E94989A9B9A9A9C9A9F9E9D9EA29B9D9E9D9E9C9B9BA096
969896969690958F8A8D8A8B8D919DA4B2B6A59A
B48A60646A5E65757D8EC0D4CB7730292A292E2B2F2A3232332D4641343436313332292A
2D3164777957664E575B606E6D73737A79797F7C7D7C7E7A8181847E7D8381818A898588
908B919591908F92909095949495969F9A999C9C999B9B9EA09F9B9DA19C9E9A9C9E9A98
969396908F918F8A868785888D8F9798A6A49693
ADAC72647566636C7283A2D3D7C05225262A272426292D31383D41343031302F31272529
262E6776795E644B555B676A7374737576747B797D7E7D8081827C7F8386898689898789
8E8D938E8F918D91929394979893949B99999A9A9E9A96999E9E9FA29C989C999D9A979C
9592948F938D8C86838B828385878D8F968F8486
879794616A746B6C6F7384BBCFCF9D2D29252C23292A323A434E5A3435312A2730232A2B
2F35637D7563634F52596970716F717578787A7D7A7F81817F82847F828685878B8C868C
92918D918E949393909493959A94969E9D989A979DA09D9C9F9E9F9F9E9F9C9D98979195
94958F8D898E887F7D807F808280858788817679
606F7E6D6D7A7F84847A879BB5B4B7633127232324262A3B524B4B46452C2C2D2D27333B
342C577179685D53515C61696B70777674767E7E7F7E7B7E7F88818580868687868C878D
94928F9191989294909491959493989C9A9397989D9C9D9E9FA3989B9E9E9A9794969893
938D868686827D7A7A80828287848686827C7477
4C5E6470707B8B949694999FA8A4AE9E5F3727262023282E383C2C312F2B2A2B31262F2F
2A3163747368524A505E666C68746F717577807E817B7B7C807F82828188888A898A8B90
8E95939294939595939187969693969A97969C989B9E9CA19F9E9AA09E9A9C9594949592
9089827E7B7A7E7C8082848784868685847E7777
2C3B46698D899399A1ADADB1B6BEC0B9AE8129252627242A2F2B2C342E2C2E2F3228312C
3130606E6D644D4E506365666C75777175767D7D787E818083828385858A88868A8E9190
938C8F8F909597959795969D979A9C9D999A9C9A9B9F9EA09D9D9C9EA29B979891949490
90817B74787D7F7F837F807C7E837F817D776F6E
221F235192979EA2A2AFC2B9BEC0C7C6BCA23C2325232728292727272B2B2F2D2E2F2F29
24295F6B70664D4E535F66636A6C706F7875787A7A7D7D7E838283848389888A88909090
92909492919796989696939599979A9F9C9B9F9D9F9D9EA09D9F9F9E9C9B96949494938C
8B7C777A7E808278736C6560666D78746F696064
201C222F81A4A6AAB1B4C5B7BEBFC1BEBCAE6534232128282A2525262B2A3432342F2C27
272E5A6D7069474F555C626466696E7473797C79807D7D7F83828180858787888B8C8B93
93938E9493999796969598979494989D9C9FA09E9F9B9E9C9E9D9C9FA296969895948F8B
857B757A848384816957463B4751615D5C575559
25221F2158ADB1ADB3BAC4B4B7BDBCBEB7AEA27430292A232126262525262C382E2A2E2B
2B2D576A625F4B4951605E60626B70717579787A7A7B808182808282868A8988888B8A90
8F8D8E9A9696939999969B9C98959A9C9A9A9D9CA09F9E9F9F9EA09FA1989394918D8F8A
82777981848688836541323132404D59605A6371
201D1D1F37A2B4ACAFADBFB3B3B8BDB9B3AFA7A15B3C35272521222226292D2F2F252729
252E5E6E585B47504C565D62656A777379777D7C7A7D82807F7E8284878A8D8C8B8A9090
919090959B94929A94979A9C9598999D999F9C9E9C9E9C9E9D9D999F9D9C9692948A8A87
807478878485848A78563A38394959667273777E
2920211D258CAEA5A7A7B4B4A9B0B0B4B9B4B6B4997B4C2D292620222222302D2B262829
2534606F645C464D4C555C5D666D746F797A7D807C7D857F7D83838288868C8A918D8D8F
908D9295959697959A9895979597999C9C9F989D9E9E9EA09FA09D9B9E97968F948A8A84
716C71817F89878585837770757E7F8082847E7A
2A201B1B1D62A89DAAA8A6AFA9ACA7B1B5B5B8BDAD8C774F3729242626272C2931312F26
273258695B563E3A47555A60656E7473767D7C7F837D84807F83808586838B908E898D8D
978D8F988F96999397959797949B9C9CA09A979CA19F9F9E9E9C9B9A9B969192908B9480
746C747C7D878A8786878684868D89848B847E77
28261D1D1C3BA0A3A3A59F9FA6ACA19E9B9FA9BDBAAA8F5D412621201F2635282F282A29
28345B6A675A47443D53585F697072747676837B7F84817F7F8383868686878D8D8D908D
928D939091949C9796989B9C9C979C9D9E9B9E9D9EA59E9E9F9CA29D9A9794998F918F83
756B72787D858F8D8B89888A928D8F908C837E78
26312720212A78A9A1A6A49996928180757782A1ABBDB191653124242428263227232728
252C5D71635943454A4C5C5A696D6F74787B80787D7F8280818581838887898C8B928F90
908F8F9395979796999598A19B9D9F9C9F9F9F9F9FA29F9E9F9DA19E9A959292908B8C7E
786870767D86868D8D8E898C8D8C908E8A827C79
25302C212225478C989A968881766B6D6476838792A2AD9C6E372925262323272E242F46
252E57715B4E4643444E5957636B7672777A7B827E7C827F80828686868C888F8E91918D
8E8F939C9399969695979A9D9C9F9C9F9C9D9E9EA0A29E9F9D9F9F9D9A92938E8B8D8A7D
746B6D747D83878A8D8B888B908D8F888680807D
24243226221E224C7883787A7A67656C6C90B5ADA38D909A875A452D23222B252B282822
232E5A6D5A43404B4E51535F5F6A747176767D7F7D7C827D81838685878B8D8A8B8F9493
948F939B97979A98969A9A96999C9A9F99A29F9CA19FA2A4A3A1A19B999899928C8B8F7F
77726E737C8087868B888A898B8F8484817C7D7F
2323302F2B1E23285165677E856A6E727290B9C9C3A682977D3424231F1E232925222A25
292A5C6C5C413847484F565D67686C737575797D7F808482838287858886878C8B8D9091
9393959A9B99989897999A969A9D9E9DA2A39FA2A69EA2A4A4A3A19D9C98989691908E85
7C797572767C84858387868483827F84797B7B81
25312C372F1F1B212E4F4B6D877672807B7E9EC9CACAABA0A33C28221F25272B27262C25
252C596A5D3D42474D525958656A6D7574767B7E7D8080818585858C8782858A898D9492
979693999697979896949B9A9E9FA2A0A0A0A2A5A59EA3A5A29D9F9D9B9892958E8E908A
837C7772797D8286868B8783817E7B7C7A7C7B7E
2A24293A32212330212C285C898A7578787992BFCCCECABFC57F2F2222272B2922282727
283056645A4137484553575C6066717577777D8080808784848486868A878C8F86909092
96999397959894969A9D9B9C9C989EA3A2A0A5A4A4A0A4A4A3A4A19E9B9D9494928F8E88
857D7C7A7B7C7B82838C857D7F7B7D7E79757A7E
232532382F2C1F1F221E2244829A7B7176737FA8D0CFD0CCD0B94926232A26282C242425
22285360543C414A4B545D61676A71757779777F8080858181878386878B8C988A929090
969892999899989A9B9E9B9B9F9A9EA09FA3A7A7A4A3A09EA0A1A39F9E9D999591928988
87827E817F7E7C838387837E7C7B7F7F79757681
232E3D4E3523201B1E1C1F2F6B8F867370747690BFCDCBCECCCEA3382524262925262722
24254D664E3A4247454B5761676C7171797E807A7E80808382878889898A8E8E8F949390
91989B9796999A9EA29E9D9CA09F9F9FA2A6A8A2A6A4A5A2A0A4A5A2A69F9E9A93938C8E
85858484808181847D84827C7F7C7B797B797C7D
26324C734D2620211E1D1D25508395796F797678A5C7C8CECFCECE893125262527212329
2729495C48353C45494D5A62666C72747582837D7B8083867E8487898A8A8689909A9290
96969B9997A1A1A1A3A09E9FA0A2A3A2A5A8A5A3A8A9A8A4A5A8A2A6A69FA09B96919089
8A8883838382848481817B7C7D7978787A7B7C7D
333D5C857646241E1B1B1C233770A08B6D7E767591BEC3CACACCCFC3642821232526211F
272E4B5544353A444A515668696B706F7B7E7D7D81838185817F898B8B87888D92989196
97999A969BA19DA3A29A9E9EA2A4ABAAABAAA8A7A9A8AAA6A8A6A0A0A5A19E9B9598918C
8B8A86858083868785827D7E807C787A7B7C7B7D
345166887758241C1D1B1A1E2659929E716F6F7185A8C5C9CCCBCCCEB546272121232A25
232947563F3A383C45555569666C7076777D7D858182848082828487898D8B909093959D
979C9D98A09DA1A4A2A1A2A0AAA7AAA6A3ABACA8AAABA9A7A9A5A5A1A5A1999B9897928E
89868884838383878381817D827E7B787A7E7B7E
43627E937F60261D1F241D1E243B819C7F756E707EA0C6C7CACCCDCECCA53F2623232321
212B41573C37343C45505B64656C7074767C7981818083858687838689918F928E939397
959B9C9F9A9FA4A2A0A4A0A4AAACADA6A3ABADACA8A8ABAAA9AAA7A5A5A69E9D9D979488
878584868587868883828383817C77787D7B7E83
53749BAD9869261E2024231F20265B8C947C6E6B7490B6CEC6CDCFCDCDC98B3122272724
2B264455382F35394C565A65666F7173767E788385808385858586878B8B90938F959898
9898A09DA0A49C9DA0A3A8A4ADB1A9AAA7ACA8AEB0ABAAACACA5A7A0A5A69F9E98999491
8A85868686848886828580807F7B7A787B7C8282
5F80B6AD8A5129232328252028243B7A99836D6F6F81A0D1C7C9CBCCCDD1C15C27202623
2425404E3931383F4F545B62656C706F787C7D7E857F87848685848D8F8B8C9093989B99
999C9E9B9E9CA4A1A6A3AAACB2ADACACAFAEABACAEADA8A8ABA6A7A7A1A29F9995979591
8A88868984848787878A7E7B807F80797B7D8185
7993B2986E32212E22262B2B2827306090956D64707985C3CAC5C8CBCED1D4A72F222525
282F394837363C4751535E656E6D77747A807E83837E848286878A8D8D8D909794989697
989C9C9B9D9CA5A9A7ADABABB4AFADAFB1AFB2AFACA8A7ACACA7A9A7A4A1A29E9A999391
8A898588868587889186837F81817A7D7C7C8489
A49A9470492D2621222528242A2B2A4D80977964707B7DADCCBCC4C8CCD0D5C875352922
26273F43312F363D475164686C707779798080807F828084898C8D8B8D93929098919997
98999A9E9FA2A6A9A5ADA8ABB3AEAEAEB1B0B1B0B2AAA8ABADA8A8A8A4A39F9D9B979895
92908B8C8B89898B8B86847E817E7D817C838184
AC976C442C282B262126222320282833718F8E697074778FC7BCBDC4C7CBCFD1B3442A23
24282F3E2F343C434F5163686C707A7A7B7B7B7E8183888282868C8A8D8F909298959A99
9B96999D9DA0A5A5A5ADA7AEB1B0ACB1B5B1B2AFADABA9ABAAACAAA7A7A5A1A19D9A9293
938F8C888A8A90888F88858380827B7D79828283
907A452A222B2F29222122292622242A53859F787374777BB6C5B8BDC4C5C9D0CC973229
292935432C303C3D4B555F656E747F797678797F83828C84848589898F8F918E95969899
9C929B9B9AA2A7A3A7A9AAB2AFB3AFB1AFB1B8B1AEAEA9ABB0AEA5A6A5A49E9D9B9F9292
8C8E8F898B8C918B8A898984817C76847F808388
77582D252320232225242322221F212539729A8B737270749BC6B9BBBFC4C3C5CCC26A32
302A2D3A2D37343C4D59656C71757A7876787E83868487828585878C9094928E92919495
9C9D9BA2A2A2A8A6ACAFB0B1B0B8AEB2B4B5B7B0AFAFAFABB2ADA9A8A6A7A2A2A09A9695
8B8F918C8D94938E8A8B8586817F7E7D83808682
593E272524272C27232226322522221F295B8994766F6F7384C0C7BBBDC6BDBDC3CEAC3A
2F2B2D352E3236404F59656C727175757B7B82837E8289858886848B8F91909390909597
989DA2A7A9A5A8ABACB0B2B4B6B3B0AFB4B7B3ADAFAEA9AFB0AFABADA9A2A39E9B9B9796
918F93908D92948C91888886867E7F7C82848585
4331332C2827292A29252831252A201D223A769493707478759FCCBEB9C2C0BCBBCACA90
3523252C2B2E37454D596167757379757C7D7E83827A848186848589889296969593979A
9E9EA5A7A8AAADACB2ADB1B0B1B4B4B7BEB9B5AFADAEA8ABABA9ABA8AFA8A19FA09A9B9C
989393969095928C8D8C8A8486857B8081858489
542F2F383335242A2C2A29322B27282224335F90A48373777286BFCCB1BEC1BFBAC1D1C1
622827282C30344448555F6874747979787C80807F798083868A8C8E8D92989898979B98
9CA0A1A6ADADB0AEAEB3B5B3AEB6B3BABAB6B4ADB3ABABACB0ADACA8B0A6A4A59D9F9F98
96939495919495958C8E8C8A8587817E81838483
5F37302B23292B2F2C272632333026212A2C3C789794766D7D76A4CDB3B6BFBBBCBDCAD1
AF4229272D393637475761696D75787A787C7A7B7A7A8383868A8F918F91989899989D9C
9EA2A6A8AFAEAEADB1B1B4B3B4B4B2B4B2B0AFACB6ADAFB0B3AEB0AAACAEA7A6A29F9D9A
98929999929195948F8C8C8A848983817C818482
503A2E2E26322A30322A2D2E2F292726282A325C889B7F69797983B2B8ACBBBDC0BEC8D1
CD983524262F323B415461656E727A777B7C7C7F7D7C868187898B8F938E95969B9B9C9C
A5A4A7A8ACAAACACB1B3B4B4B3B3B0ADB0AEAEAEB3B0ADADB2B3B1ABAAA9A5A2A19E9B9B
9B9A909291908E928B8B8884848081847F7F8082
3738292E2F322E2D2B2C2D2F2A2F3329292A303A6C94977373787590BCA8B6C1C1C3C3CD
D2C97C2D21282D38475560626C6F777C7B7A7E80807F87818A888E9494919397979D9D9D
A5A5A7A7AAAEADACB0B1B3B0B5AFB0B4B2B7B4AEAEAFB4B3B0B3B2B2ADAAA8A6A1A19A9D
999A9092929490948A8D8A818587858382827B7F
3E352F2D2E2E2E2F2D2E302E2D2E2F31302B2C365389AA807372747DB5B5B3BCC0C3C3C6
CFCFBD5829242E34444D575F696F777577797C7D7E8682838D898D9493979897989A9EA1
A2A3A7A9ABAEADABAEB3B2B4B0ACAAB4B3B0B1B1B2B1B0ADAEB2AFB2AFADAAA9A7A49B9C
9493949498958E928A8D86828886847F84838285
4A302D3335342F3A2D2D2C30302D2B3029292926316F9E9470666F76A6C0ABB4BDBCC4C2
C9D0CCA83D2A2836414B545A66717574757A7D7E807E81868A8C8D9290949898959E9EA2
9FA4A7AEACADA9ADAFB6B5AEA8AAABB2B2B1AFB6B3B1B0B0ADAEAFB1B0B0A9AAA4A39F9A
93919595949193908C8C85858586877D81838285
532F272E32362D2C31302B3035302B2A2C2927282D5493A27D66677088BBB4AEB9BCC2BF
C2CBCEC8903430333F4C535F5F6F727579787A7B837F8384888A8B90929799959A9DA0A0
A2A7A8A8AEA7A7B1ACB4B0ADA8B1B6B6B1B1B0AFACABA5A9AEB2AEB2ABAEAAA8A3A09A98
9696908E8E90918F8C8B86817E87877C7F808084
4227252834333429262F2B2A292F2D2D2E2B29282D42779C986E616A76A4BEA7B1BCBFBB
BDC6CCCDC17A36343D474B56676D727075787C7B83818084878C908F94989C969B9D9FA0
A5A4A8A8ACA7ADADACB0ADAEADB0B2B2ADAFACAAACADA8A4ADB1B1B2AEB2ACA7A29B9B98
9593908A8E8D948F8B8884878182877C807A7F83
2F2C2D2D36332E2E2C2D2830312C3431372C2B322C29528BA57E6967708CC0B2ABB5BCBE
BDC2C6C9C9BB593637455152616B70716F797E7A8482828A8B8B8D8D92979D9AA19B9F9F
A2A9A9A4A5A5AAADA9B1ADADACABADABACADABAAACADA8A9A8A9A9B0B0ADA8ACA09C9A9A
95948D888E8E96898B8980838281817A867A7E87
3134313337362E2B302C282F322F35332D2E313127273A6F969B746C6982ACBEA0B3B8BF
C0BEC4C3C7CCB04C39434B575F647070767C7A797F7F7F8C8B8B8A93939698979E9D9F9F
A7AAA9A1A3A2AAACAEB4ACABA9A3A6A5A8A6A9ACAEAEADACA8A8AAA6A8ACA8AAA3A2A099
948E8A888D8D8D8A858387828183847F85807F89
333030333431262B2B2C282C31353136353234352A2E2C5082A37F67656E8EB9A3B1B6BC
BBBDC0C2C8CCCCA4403F47515C5F6C7074787B7C837D868D898C8E95969898989D9FA09E
A8A9A7A3A5A2AAACACB2ABA9A8A3A6AAA4A7A8AEB1B0AEACA5A9A6A6A6A7A7A6A1A69B9F
958D88898B8E92908A86878584867F8281818488
322B2F32302C302E27302E31323F30303030332B2A2A2C386B92956F626475A2B5AAB2B5
BABDBDC6C9CFCEC78A40404D59616A71717576777D858689858A8D979497969CA198A1A2
A4A7A4A6A0A4A7AAADACA6A6A0A5A7A5A8A3A7A9ABADA9A9B1AEA9A4A6ACB0A4A6AEA59E
938C8E8888908F8E8B8689868181838182807F8B
2C2C2D2F2D272C31282B293036372D33323130302627282D47829E8469656B87B4ADB1B4
B6BBBBC3C3CACFCDC1813F4554606671706F72787F878687838E8C9694979C9C9C9B9FA4
A1A1A2A49EA6A1A1A39F9A9F9BA2A29D9E9FA6A4ABAAA3A6B1ACAEA5A2ACACA0A2AAA4A4
958C8D8585888A8F8E888882827E847F7F807D8C
302D292C2E2E2D2C2B2F2934352F2F322A2F32292521252330668F9F7C64687BA4BBACB6
B1B3B7BAC0C6CBCCCEBB703C4E555E656E70767879828787868D8E989699979A97979A9B
A0A39EA39FA09C9A9A97949696989B96999E9B9C9CA5A0A2A4A5A7AAA5A7A5A29FA6A3A7
9C8E8B827F84868B8C8789807E8084828283878D
2B2F2C2F3231332C272E31383633302F2D2D2C2723242523243F799C8F736B6F96C1B2AB
A6AAB1B5BCBFC8CCCFCCB66047515C5F676E727B7A7C838B88909294999A9A989793969E
949B9B9F9A9D9A9597918E9291938F909093929298969C9DA0A1A8A8A7A3A4A49CA1A3A7
A0928683858484868A8B87847F817C837C81848E
272B342E2D2B2E2F302D2E362C2E2F2B2F2A3027282B262122286085A1826B677EA9C0A8
A1ABB2B6B7B5C1C7C9CACAA95F4A565D636D75757D7F838A888D939494959B999A9A9698
969497999594939095908B94928F908D8E908E8F8E969796979A9B9DA1A3A5A49A9DA1A3
A1988B81818188848A88868781837E827F82838C
342A2C343432312E282E3733332E3437342C3030271E212020233C76999B6E63708CB9AA
9FA7B0B3B3B0BBC2CAC9CBC8A25D4F535C63717679848386878B8C8F9392979A92969297
999193918B8F919495958C8A94908D8988898B8D8D94918C95959B999F9FA49E9A949699
9C9C8D837A7B81848689868285817F7F7D838590
2D2A2C312F3433292E33302E2F2C2F343532362D2627261C1E23265987A180636673A8B8
A3A3A8B3ADB2B5BDC5C8CBC6C49E595151606B6E7B807E8385878E92958D8D9090969497
92948B8F8C8F9396979084838C89827C7E847F88888585778C958E90A099999696969191
96958F83777A80818884857E8383807D80868991
2E31334429292B2F2F2E2D2E2A2C2C303236342D28252623222223326B8D956E626990BB
B7A2A1B0ADB6B8BCC4C4CBC9C5C59A59515F666E767C818289858C8D93858D8B91949392
8E928D9190909695948E837781817B716E867F888A8F7B6C868A8186A692929799979992
8E8E847F75797F838384847F81837E7F82888A91
282B2D262D292D2C2C3034342B2A2F39382F302C2327262323222126467C9980625C7FB3
C3AD9FA9AAB3B3B8C1C2C8CAC5C7C1965953696C747E7E8388858A8D8D8A8E8E908F8F91
8E8C91958F8C908D8E85816D77807A6E5C808089868B716E807B667DA698939CA5A2A399
978A837E7A777A7C8284847D838081807E8A9495
2C262A2D2E2B302F2B2D2E312F3030333239332E2B312426222320202A5E899C6F59679C
C0C2A2A4A8AFB0BBBDC2C8CEC6C5C6C2966060696E76787F8583868B848789898F8D9291
908F9292898684888A837A6D68777D6459768182847F696A8073657F9FA3A8A7B3AFAFA8
9E90887D777D787E7C81818283848782818A8F96
302A23292A2F2C362D2E2F30302B2A2B322C3A2D39282425242523222239779C875F6181
B7CAB9A6A7AAB1B6BABEC3CACBC9C2C2BF8A5E5F68757781827C828A81878285928E8F8F
8D8F8F8D8678767D7E7F7E6C6D6B7C6F607A858892969193A7A08D9FA2A4AFACACABAEAD
9F948C837E807C7F747B827B7E808383868D9295
2824252B252C2F343231303138322E3930312F2A382F27262D22211F232C52849F6D566C
9BC2CBAFA3A7ACB6B9BCBEC8C9CAC6C4C5BE94625C6C787B7C7B81867E817D8493939190
8F8D878881706D72696C78726F7485858F979B979EA9A7ACB2B2AAB1B4BBBDB1A09B9794
88888984837E79777973788083818079828D9497
2C2724272931342C312D303C403A362E2C3032443B2F342B232725222C293B6E91935F60
7CACCEBF9EA3A6AEB4BABBC5C8CAC8C6C4BFBC8F606277797B7B7F8181807E889093908D
8D8C827C746B6369534B717D878A92959D9D9FA8ADB0BBBBC1C4C1B9AFA7AA9B928E877C
75768280867E7D7877797B8082828580848E949A
322C27272429303938322E36433F2E2E36302C2E313727242825242120392A4D859B7C63
6688C2C59C959FADB1B9B5C0C7C7C6C7C5C1C1BC926669727F7C7B7A7C7E7B878E8B8D86
8685726A5F5B5D5F5E6E77828B8D83858A939EB6BBC1C5C7CBCED1CEC7B69E908991988B
73707C83827D797275797C8481828185848D8D99
2C2B362C2F2B363D3A362D283740312726292C2F303526252E2D2123212A363C58889663
5866A3C2AB969CACB5B2B4BDC3C3C7C9C5C7C1C4C19C6C6A73777A72767E7C838C838F88
7C766353434352637377777C84786C65667489A3BAC5C6CACDCFD1CFCAC6B09788908E94
716E79857E747179747C7B7C7F82828386869094
3C35282E2A2E34454F3D2A29313A322D2C282D2D36382827272421252A3032353F6E957C
53567EAFB99F98A9B0B3B4BCBEC3C7C9CAC4C5C5C5C4A06D68717576767F8284827C827C
756C56412F2F496371707578715F523F424B587F9EBCCACBCACACECCC6C3BCA3948A8478
6A747E7A7070737C7D78767B7A86848B8A8F949B
402E2C282C283A52744D2A2C3430352C2D2B2B3534302A302C27282B272E28252C407D8A
67516689A6A19097A3A8ABBBB9C1C6C5C8C7C5C4C2C7C3986C6370727A7E817D7475796D
64604A322B33445C69727D71593E39363D3A414D6BA0C6D0CED0CFD1CAC8C0B09E837261
667D7D74666F72777C75717B818286898A8E939B
38282627262D40657F4F352E3129352B29312D313D2D282D262C2B28232D2724262F5A78
73515C7D97B19E93979399A2AAB4BBC3C6C9CAC8C5C5C3C298676D6573787A756E64615F
564E372F3345535A6C7F73583B3C4F575A504D374171ADCFD3D2D3D3CDCECAB69E7B5D54
637E7666626B6F6F7572767A80808688899097A2
382E2B292B31457977463E2C292A2C2A2D2C2A303A2E2A2628292B2B25272325252E4A69
8472566C93BCBFA8A1999599A8ADB3BEC3CACACBC6C1C6C7C793696267746E695C54524E
423B2E2B2D454A5D757963433A546256565B534839427EC5D1CED0D2CDCEC8B6956C4C46
6C7E6A5C6070706D7076797A7D81858A888D959C
352A3026272E528854364430302324262F262E37382F2B29273439322B25282D35484A62
899D756074A9CDBFAAA4ADAAB2BBB6BDBCC8C9CBC6C6CDC9C8C28D5D616B656156534035
3330312D2F42475F736B47345C625A4842425A6C4A3557B1CFCCCCCECBC8BFAB80584658
7C785E5A6C7772707173787B818687888B8D9199
28352B2C2C34668D49313D35292729282E2E2F2C3A32322A2B2A343A342A292F494B393B
74988E675C8CC2C9B4A4AFB6B3B9B9B8B7C0CCCFCBC7C9C9C4C9BD7A505B5E5651443838
35332A2E3438465C675A32395E5D4C30292B45704D38429DCCCCC6C6C6C1AC906246445D
836E545B747A75747173888284898B89908C8F99
27382E272C3E7A7D3F2B352B2C282A2B2933302F312E2F2B2B2D404841383A2526272125
528DA17E606C9CC6BDA4ADAFB1B7B2B1B7B9C3CECBCAC7C1C8C5CBB76B515258554E4438
31352C2A2C3341525A51323C504F30262427385A413248A3CCCCC7C0C0B98B6B483C3E68
6C544B647B7C787A7779808782878B8B968D919A
2C302D2E304780652A2F2D31312E2B322F2B2D30323B3B2D333F505A55322A2722211F21
3272989C6B5F79B1C8B0A4A8ACB3B5AFB5B8B6CACEC9C7C1C5C5C5C4AF694C5057554C44
3C322A292A33353D4D432B2F3E3C2D2724285857415679AECACCBFB0A39A61452B2B3B4C
4A3F4F6D7B827C797679808A868C8B9290919499
31303840334F8D53282E2C2C2F2B282928252B344867604A5A536D5E2F292A2823252220
26538C9F85656592C3C6ABACA6AFB2AEB5B5B4C4C9CAC4C7C5C0BEC0C8AE614448504B4B
463A292F3130313035352F2B363132282E304C3E455E80A2C1C0AF9577623B2A2726272A
2C33516E8187817E7D807E8788858E8C93959899
2F3A5256355C8747252D34322C252B292B2A303E6E7A706D66523B2B27272D2922222621
21336A93A6715F7EACC9BDA7A9AAABAFB3B9B9C4C9CDCAC2C4BEBEC3C1C5A659434B493E
3B42333030342F30302F372F33302E2C2E2F2C3238465A8AA2968E684E382A29292B262A
2E436475848884817E8082888A8B8A8F92969499
2A3F553D2D5E82382C2C2A2826242429252A4169797972674828242926272D2F25292722
21234580A195646490B9C6AFA7A4ACB1B0B8B8C2C5CDCAC3C2C0BDBFBFBDC5A75E4A4141
43433935322F30353533353733352D2C2A2F2E2F304F4262776F5C46392E2A272E29262E
3C5673818B8787837D8282858D8D90979394999D
37563A2F3259732E26292724272525203035707971726040262624272B2F33342A20262A
1B1F265A90AD76677B9AC1C3A6A6ACB0ADB6B4B9C4C8CBC3C1C2BABCBEB9C2C6A2584640
3F4B3B36373935323534343A332F32342E302E2F2C33373F544737332E282E2727302837
586F8388898180837B7E83828C8F8B9294949C9D
4A472D303163672E2B262B242826272B305C7B7C6E4F322D2A2E282B292F2E2C25242C33
1D1F1F3978A098806D7DAACBB4A7ADB3AFB1B7BBC4C8CBC5C2BEB9B7BAB4BBC6C89D5041
47464744433F3A3533363433343431322F31302E323B30383936412C2E28262C292A385E
838A8D82827F847D7E83828F8C8E909197999C9E
582F2C2A2F5D652F282622232631303A497D7865412F28252B2B2C392F2F302826242427
1F2523284F91A0886E668DBCC0A6ACAAADB0B3BBC3C6CBC7C9C2BBB9BBB6B6BFC5C99F5A
484E564D5048473C343B4038363935323831323533353532312D2B2D2B29282C35444B6A
8A8C8880807A85837D7A8989899292979B9E9C9F
4027292D36595D2B27262624292E30435C76603A2A292C2F322D282F2D2E332930262423
283D2122276E8F9F77656FA2BFB9A8AAAAB0AEB6BFC4CBCCCBC7BCB9B5ACB1B7BFC6CDA6
5E4F514F5E574D454657544040433E393B3936322C32353C37382F2B2F303038537B6461
7888817C797A7B7C777A84898C8F969A9FA19A9D
31302D2D3C545E312F2D262429333E5F606C573425302B2B2C2E2D342A2E2B2B2A2E2727
443F1E1D223E81A28D6A697CB0C6B5A4AAA8ADB1BBC1C5C8C8CAC0B5B3A9AEADB7BDC6CA
AD6454555F6260646764604A4B49435249513B362F3851695E4B302E434540546F798057
6580777A75737474777A80868D93999C9DA2A09D
2C2C312A305B57342E29252324304D676C6234282B2528262B34322E2D262C2A25282D3B
55261C1E212C6194A173686B8CB9C1B0A4ACA7B2BBBDC2C4CBC8C3B9B1A8A8A6B2BABCC4
CCB275556460686C6B655E5F626666696D6B573E2F456F91847C5344657049676E7B7C6B
5F75746F6D7170666D79818A939B9F9A9EA3A3A2
302F292A3C5351322626282A30315565685B2D272828242A2A302F28282A28312D385262
3D2922262121357B9699716D779EBCC2A7A3ACAEAFB8C0C0C3C7C5BBACA3A1A2A6B7BAC2
C8C8B68264626C7171727875767D78757C816E58335A8195928B7460777D5B5971737C71
69646E635D6461686D7A85989C9D9C9DA1A6A4A5
28252C29344C40372B27263028385766664C352A23222C2D2C2A3128272A3335436C6E41
2B312F221E20214A7B9E8E7B7281A3BFB9A8A8A9ABB2B8BDC1C6C5BFB5A99AA19CB1B5BE
C4C7C7BD956C6F71787E7D7B7C8A8786848A83734F7B9B9D9B9D89718489765B6C656A64
5E575D5A515A5C626F778F9EA5A4A3A3A7AAA2A5
2429312634473B3E372E2A2C33395B5D613C3830242424292829272A3031595360855225
2B495C27201D1F32628EA796827182A8C3B7A1A8ACB1B3B8BBC7C6C4BBA7969A99A8ABBA
BFC1C5C7C09E6F6E7B828283858992938E928A757A90A5A3A09B8F7F818A7E5B685A5E55
544F4B4E484E4E60768796A6AAA9A6A8A7ABAAAD
26242F3345614C463C373D63463F5B5C4327353B2929282B272529232D334F5F66765426
2D5B592E2A1F1D2439759AA7886E688FB7C3ACA7AAADB4B4BEC2C6C7BFACA39696A1A9B3
BCBEC4C5C7C1AB7C74787A86898E97999A958E7B969D9FA3A09A8B857E7E736161565348
48443F3F414F5B798895A1A7ABA7ABA4A7ABABAD
25282727334D3F423A2B3D532A334A543429363E2A28232C29202829345066593D696125
335D3A2D3E2228272A5085A2907264739ABFBDA69EAAB0B2B8BBC1C6C4B3A69B949CA5A8
B2BBBDC0C5C3BDB1887679838B919198999998929DA29B96958F817A6D605D52464D4341
3F39464F59678196A0A9AFABAAADABA8ABAAABB0
212827262A3C4C424E4C3B35293B4F4835302B3C2D2727282A272A2E4A6D6033284E6328
4B5C2B364E28221D2F3A6E8D9E816562799BBFB1A1ABAFB0B7B9BAC3C7BDAF9B979A9CAB
ACBCBDBAC6C3C3C0B9927B7D84898F969C9696979794918C847D74685C4B433B463D3D44
4C585E71848D9BA7A9AFB0ADAFB5B1AEACAEAEB1
242B34232A34353C5642323B344746392F2A2C3A372F322B30302C4260684E46323C602E
5B53252D55311F2725233E75979F6E5B607BAAB9AEA6ADACB4B2B8C0C2C4B5A59A9C989F
A8B6BCBBBDC2C3C2C1BA9979767A8289908C8E8D897F79756E6B645B503F3F4447494B59
6A6F7A8D9EA5A8B0B3B0AFB1B3B4B3B4B0ACACAC
2828362E2730302F383738343F4A393329302F36392D2B272F48464F5A52323D3D345733
694E262F5C341D2727202A4C84A6836C5C6488B0BFAEA9AAACAFB5B8BEC2BBA9979A989E
9EB6BABEBEC2C4C2C1C2C19E7666686E76787977756C666067655B534D57555D656B727D
8592989FA7AEB0B9B5B5B0ADB1B3B2B1AFAFADAA
262B412C2C2E383433392A34353A302B2F2A2C353A372E323839352E4A462F2B2C386049
6C3E30325F422A25201D232B6D8B9982635D6C8FB5C1ACA5ACAEB3B2BFC0BBAD9A9D999C
9DADB8BDC0C3C4C6C5C0C0BFAA785555575861616066635B6068646456666E737A7C8690
9CA3A6ADAFB3B3B6B6B5B1B2B3B0B0AFB5ADAAAF
23263D3233393F39342F2F2F3340322831292A2B342C2E353335312C47372A2929306555
6C3929325B5B37322E291E233B798CA0785F647297C6BAA9ABA6A7B0B9B9B7ABA39A9B96
9BA4B3BDC3C1C0C2C5C0BEBBB9B0894F454755595D656A6E6874797D7E7D84878994989E
A6A6ACB1AFB5B4B4B7B5B5B4AEB3B3AFAFB2AFB4
262230373235484D463E3C323E432D282C28252A282D3132333A332F57472424262C5465
6C3C23234A6D4145503B27212A457D9D97745B657DAAC6B9A4A8A7ABB3B3B7ABA69A9C96
9DA6B2B8C0C0C0BEC6BFBEBFBBB6B8A36D4E4A5266756E797986898E93919498989EA4AB
AAAEAEAAB1B4B0B4B6B4B0B4AEAEB1B0B1B2AFB5
22292F33292A32405A615F5043463A3A312B272C292A2C3435382B315A582D2326263C69
633D25243A6A412C3440362E2F2B5883A689605D6187B4C2AFA3A6B0ACB3B2AEA5A69B9C
9EA7B3B7BFBEBEBABFBDB9B4B9B4B6B5A5896C64687C7B8A8A8E939499A0A3A3A5A5A8A9
A6AEB1AFB2AFB0B3B3B4B2B0B2B0B1AFB4B7B5B8
2621253725282F384853666E565056433E312C2C2D2D313E38332D2B476F2F2728263864
753D29252C5C662A2B30383226242E648E9A735F596994B4B9ACA0A9A6B0ABAEA9A59FA1
9EA7B0BDBFBEBABAB9BFBCB7B2B6B2B0B4ACA28C7C858B9397969E9FA2A1A3A4A7A4A6AF
A9A8AEB0AEB1B1B2B1B3B6B7AFB5B2AFB6B6B7B7
27292A34372334474B444E687857494F48353127282F28383D31252B4472332A282B3F5E
723E36292B417D3A29242D342E21223E768C906956597290B9B89FA0A7A7A5A8AAA59D9F
A1A9AFBEBEBEBDBAB5C0BAB7ADAFB2B8AFAEB2A89E959598A0A0A1A3A3A7A5A5A7A3A7A9
A7A9ABABAEAFB4B1B1AFB1B2B2B1B0B0B4B2B8B8
363424283D2C3A3F3B3B33476D71423946363425272E2C3C37292827376B4D272A2C3F5D
5D3A3B3B282A5D753E282C282520292B49788775635C66799ABBB0A1A0A4A3A5A29C9E9E
A3A6AFBCBEC2BCB7B4BCB7B8B2AAAEB9B5ACA9A6A6A79B989AA1A4A8A2A4A6A4A4A1A6A3
A9A7A7ACABB4B2ADB0B0B0B2B0B2B4AEAEB1B6BC
404F2B2433373D2F322D2E37426B686547363B2A25222B3B372E26293759642A252A4751
583940432F273C78714130231D1E2020325372767E6C636A839EB4AEA29DA1A1A09FA1A1
A0A6ADBCBBBEBEB5B7B9B7B4AC9CA2B6B9B6ACA3A7A6A49B9A9A9CA1A6A9A4A1A3A29EA4
A9A7A6A8ADB0ADAEADAEAFB1B2B4B4B1B2B4B8BE
3A6234292839282524272C363E4D6369623F3637282930393C2E2B2C2D52642D262D4A3C
3E392931322D2E638C61291F1F1D1F21283E6C8E97847C716E86A7BCAD9D9EA3A09FA2A1
A6ACAFBBBCBABBBCBBBBBBB2AE908FABB5BCB8A7A9A7A6A19E9A9B9CA0A5A6A39E9DA3A1
A6A1A8A8B0ABB0ADADB0B0AEB4B5B6B2B6B8B9BE
274A5432313C2A2525283452483E395A62533D322628293239372C292940663B273B5A31
343225263245344F7A532120231E1E203162678E8EA1887D6A7488A3B2A5A0A4A19CA2A2
A5AFB3C0BCBAB9BBB8BBB9AFA48A84ABB0B9C3B8AEA8A69F9C9E9C9B989EA09E9E9EA3A0
A2A6A5ACAAAEAFABACACB0AFAFB4B4B3B7B6BCBD
2931453327302C26293449613B2E293B55584A392E2B2F3831392A2C2A3C5F412B455D33
2D37272B2E3D364F653F241F2120202C4F7D675F729BA187746F7A84ABAFA3A4A29DA6A6
AAB4B5BDBBBAB6BFBBB8B1A098747DA9B0BCC3C0B6AFA6A2A199979B969B9A9B999BA0A4
A1A3A5A9AAADAAA9ACAFB1B1B4B0B7B5B7B5BDC1
2926363728292B2C3348684B3625322E3E574E35342D3C362F3B2A302A36594B323D4E2F
3137312E422D344E533F23231F20243373865A3156819F947D6F777A90B7A99DA2A5A5AB
AEB3B3BABEBAB9BBBBBAAE929A7681ACABB8C0C2BEB8AAABA19D999CA2A59A989B98A1A1
A0A3A2A8AAAEADACAEADB3AEB3B0B0B2B5B7BBBD
2328292E292A2A34476B5F3B312B2F30334D5C46362D2C35383A2D2C2E334A542F343B28
2F2E3451562A324D51412B2823202B45947B4B202C6687A0907A777F8095B1AA9DA7A7AE
B1AEB0BCC3BBB8BBB9B9AC8C9B7D88B0ADB1BAC0C5C1B6AFA9A4A09C9BA9A2939C9D9F9D
A99DA1A8A9A9ABAEAEADAEAEB3B0B0B9B8B8BAC3
2B282B2B292A2B335A6C4D3F3E3D342F3F41484B312F2A32394732312C303D523F38382F
282C3868612E4A514C482F2722242E6E91692E1D2336698AA28A787A727B96BAABA6A6AC
ADACB3BFC2BCBABAB4B9AF8998878BAAA6ADB4BCC5C9C0B2ACA7A2A19FA1AAA29C96999B
A1A09CA3A6A9AAABAEAAAEACB0ABB2BDBBB8BFC1
252729232D282F45685733474B4E352B2C2F3A423131313039383536333239484B3A3926
272C386A5B3C67434251473733344F9A88512A1F212041788BAA8579707781A2B6B3AAAA
AAADBBB8BBBEB4B4ADB6B2939A8F95A7A1A4B2B9C6C6C5BCAEAAA2A5A6A1A4A6A797939A
9A9E9BA5A2A9A5A8ABADAFABADB4B5B8B7BCBEC3
2B27252C2929314D6E492C3336383E332E2D353D47302D3337333A423131373B483D3526
242E4769594E643C4B59615D565677A68A5E271D1E202A46769A9B83787B7881AABEB6A5
AAACB9B3B8BBB6B5ACB5B399919298A7A0A3AEB6C3C9C7C3B6ADA5A7A8A9A49FA0A69493
989B9CA09FA3A2A6ADAAA9A8AEB3B7B4BABBBDBF
2D2926272E282B576E3E272B2E2A38403F2F353744342C2F34383D373132312E443C312E
313C4B5548595B4568655F52533E68A48C6F36231D1D20295285979B8079727B8EAFC0B7
A6ACB8B5BAB0B2B0B3B3B1A18D90A4A6A6AAB1B7C0C7C5CABEB0A8A6ADADABA4A2A3A49D
95929B9CA1A0A2A6AAABABAAA8ACB4B8BBBDC0C1
3A2729252E39345B693F2527272F3047513E303840422B292D383438362A2B2E3A483B2D
3938334649666C6F79594C3B3B2D5E986A41251F1C201D252E5983A196857C737B93B4BD
A9AAB0B8B9AEAEA9A8ABAE998A90A7A8A7A6B6BABDBFBFC4BFB3ABA5A9ACA7A7A9A7A2A5
9991969B9D9C9FA6A6A8A7A9ADAFB7B8BAC1C2BE
322B32262F3538696D41272A292F2E414C47382C363D302D333732423537292E36413C38
3734323F607269787E50402A35366889582920262024221E24365D91A994847B777D95B6
B9A9A8B6B3AEAAA6A3B0A3948B8FA9B5ADACAFAEB9BEC3BFBAB6ACA7ACABA7ABADA8A7AB
A5A0959394979DA5A6A9ABA8ADADB3B7B9BEBFBE
3F372E2A2C2C3C686D4D2E312C2B2B303E473F32333B353235313736442E2B2E3B3E4039
3232374E636E675C7A3F372D333B8089472524281F24232823292B6291A5958174727BA0
B5B9A5AEADA8A9A1A8A8AA96878EA9B6B1A9A8AFB9BCC0C6B9B8AFA7AAABA9AAACA9ABAE
AAAFA19693959CA3A6A5A9A7AEACB2B0BABDBFB9
4F5247332B2C35666D49342D2A2A2C2E3646463A3B3C392A2B2E2F2F3B353134433E4239
3634445A60633B436A372C2F3450908137292D2A27242123202124346B9BA08F786B6A7D
9BB5B5ACABA5A5A6A6A7A394848DA7B1ADA39FB1BAC1BEBDB8B7B1A7A7A7A8AAABABAAAB
ADAEACA79C9395A2A0A2A9AAADAFB0AEB6BABCBB
5C5C5A43392E3754685A322D292A2D262D4043372E413A322C2E342B303A3C414C3A3B41
353448545C4F3137613A2C2E406F8F712C2E292327262322211F2025367097A88E746772
83A0B3BFB1A9A4A5A4A5A08E8489A4A9A59E9FA9B6C1BBB5ADB6B4ABACACA9A9ACA6A8A4
AAA8B2B3AF9D8A939D9FA6A7A9ACAFAFB4B9BBB7
43424435342E2E5561623E2D2A272D292D343B2E2E383E33312F36313340514C4A413D44
39414D465950292B4B3B352D59888A5E272926242E282323211D1E1F264173A4AC887167
74879FB6BFADA6A4A6A5A38D86809BA7A4ACACA2B0C0BFB6ADACBDAEA7ADAAA9AAA1A7A0
A8A3AEB0B7B59E8F999FA6A5AAB2ADAFB4BBB4B9
50563F2F2E3233515E604D322B2A29272D3237332F313B3332352E333853544848454245
41433A4061562B2E3E40373C57928E5B28272C2D2B2A25242A211E1E21254A85A49C8970
6A7284A0BABDA7A4A5A4A386808399AFB5B6AEA4B2C1C0B8B9B3BBB3A9A7A6A0A8A0A4A1
A5A4AEAFB4BBB5A59B9C9BA4A7AEACADB5B6B3BD
7569472D272B2D3E575F562C2D292F262B2F36342D2B32302D3134384A564F453A3F494B
4540314562582B2D3C3C2C32518E8558313E404B433E2E29262423231F212956829AA088
716C68789FB8B5A0A7A298807B8EA0BBBAB1B4A6B7BCC3BCBCBEB8B5ADAAACA2A4A39FA1
9E9FA7B1B4B6BCB1B09F989CA4A8A8A7AFB0B4BA
786857302C262B363F5B5D362D2F2C2B352A2A2A2B2E30312B37434C54504E3B3F485655
45382838675324232D392B3B629187635651646F63593325212A22241F22282E50869FA2
81665D637C9EB5ABA1A48E7A7B86B0BEBAAEAFB4B5C0C1BFBFC1BFB5AEAAA6A2A5A29F9C
A19FA6AAADB5B9B6B2B0A29EA0A4A7ADADADB0BB
725D342D26292F3C33435847413330302B2D312D3132382F3134465C50533B3F4B4E594B
3D2C2E3A625325232A3731537288876B685E5F5D48352523262A242125242521325B839A
94755A53667696B4B6A589788D95ACBBBCB6B0B5BBBABCC0C2C1C1BDB6B3A7A9A5A5A1A1
A1A6A5AAAFACB4B7B6B2ADA7A4A1A6ABADACB1B8
76522E272B313B342B3C54503D39312C2B2D2F2F352F2E2B2F3E585F58423A415557604D
2B272F405750252A2C3A5C687D8D865C463F362F2E2A31292A26292322222428262F5F7E
937A6669605C7795B5AE8677A69EA7BCB6B4B4B5B6B5BABCC1BEBFBEB9B4B1A9A2A49B9C
A2A4A5A8ABACB0B5B6B3B1A6A29BA0A5ACAEB6B6
765D4335353D392E2B384E5F4A36342B2D333129312F3233394A62594A3E45475254613B
2B2F3648564127282E4776757E8162392A2A2D2F2E3031342B2F2C2E232222242629375F
767C6C755C4E5B7793A38B7AB19893B9B5B3B6B4B8B6B8BABCBBBDBBB6B5B3AAA5A5A1A0
A1A0A6A4A6ABACB3B9B4AFACA7999CA39EA5AEB5
6D5E56434A534433313249665949412E33342A2A302B2F343346614B3B454458555B5945
292D37485036222F3B5A76857C6F4B2A2B2C302E333A312B2929292C2D282A2324242736
5C696E7A6B4F4F5F6F89827DB19785B3B7B4B7B1B6B2B6BBB6BBBDBBB8B4B4AFA9A7A1A2
A3A5A7A6A6A5ABB1B6B6B0ACABA39A9DA5A7A9A7
6A66584F67625D4E463B44575A4F4233342E2F2D2E2B31353D4A55514655444855604C3D
3825384B4F3F282C5E597B806C5E35292D2F322D31323234302C2A31332B2F21272C2635
3C536F8A765649545D6C657CB19A86A7BDB7B7AFB3B7B6B6B7B9BDBFBCB9B6B6ADACA4A2
A0A9A8A9AEAEB0B3B1B8B0AEB1AB9D9DAAADA8A6
766F5C5B7C716A595553494A514D4C3D3E3B3230292A383A484D484E434145455551473E
3B27364C51382636715B79785F5832282C2B2F3A2F2C2D30303631303A2F292A2C292729
2C415F6C846B585559614F72A7A1839DB6B0AEA9B1B7B1B0B3B5B7BBBCBCB7B2ABADADA5
A3A6ABACAFACB3B3AFB2B4B3B0A9A7A0AFB3ACAD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{771.75, 367.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<30001Kb000`400?l00000o`00003oo`38h=So
0<SPf?l0b>3H1P38h=P00?l0b>3Ho`38h=So0<SPf0H0b>3H003o0<SPf?l0b>3Ho`38h=P60<SPf000
o`38h=So0<SPf?l0b>3H1P38h=P00?l0b>3Ho`38h=So0<SPf0H0b>3H003o0<SPf?l0b>3Ho`38h=P6
0<SPf000o`38h=So0<SPf?l0b>3H1P38h=P00?l0b>3Ho`38h=So0<SPf0H0b>3H003o0<SPf?l0b>3H
o`38h=P60<SPf000o`38h=So0<SPf?l0b>3H1P38h=P00?l0b>3Ho`38h=So0<SPf0H0b>3H003o0<SP
f?l0b>3Ho`38h=P60<SPf000o`38h=So0<SPf?l0b>3H1P38h=P00?l0b>3Ho`38h=So0<SPf0H0b>3H
003o0<SPf?l0b>3Ho`38h=P60<SPf000o`38h=So0<SPf?l0b>3H1P38h=P00?l0b>3Ho`38h=So0<SP
f0H0b>3H003o0<SPf?l0b>3Ho`38h=P60<SPf0006`38h=P305MGE`80J6QX0`23Ph<20:NWY`<0_;bl
0`0c<c<202TY:@<092@T0P0^;Rh302HV9P<08R8R0P0a<C430410@080?clo0`0j>SX203De=@<0<S8b
0`0d=3@203De=@<0<S8b0P0`<30303@d=0<0=cLg0P0e=CD303<c<`80=3@d0`0h>3P304E5A@80D51@
0`1;Bd/20492@P<0?Cdm0`0h>3P2034a<@<0;2`/1@0X:2P3030`<080>c/k0`1]KFd506=SH`<0FUYJ
0P1lO7`306MWI`80ATI61@1PH60306ATI0<0K6a/0P1cLg<307EeM@80MWIf0`1jNWX307inOPD0Ogmo
0P20P8030861P@<0Ogmo1@1nOWh207moO`<0PH610`23Ph<208J6QP<0R8R81@2:RXX308V9R@80R8R8
0`29RHT208^;R`<0SXj>0`2@T90208f=S@<0Rh^;0P2>SXh3092@T080SHf=0`29RHT308R8R080RHV9
0`2:RXX:08b<S0<0SHf=0P2>SXh308n?S`<0T92@0P2ATI4509:BTPH0TI6A1@2@T902096AT@<0TY:B
0`2CTi<209BDU0<0TI6A0P2?Shl3096AT@<0U9BD0P2BTY83092@T080U9BD0`2HV9P209JFUP<0U9BD
0`2FUYH209VIV@<0VYZJ0P2KVi/309fMW@<0X:2P0P2SXj<30:RXZ080]KFe0`33`l<30<[:bP80clo?
0`3@d=020=?Cd`<0/k>c=038h=P305eMG@80IVIV0`25QHD20;^k^`<0]KFe0`10@40502TY:@8092@T
0`0X:2P302HV9P80;Bd]0`12@T82059BDP<0>3Ph0P0c<c<303Ti>@<0<S8b0P0i>CT502l_;`<0>3Ph
0`0e=CD203Ti>@<0;bl_0P0j>SX303Lg=`<0@d=30P1;Bd/3055AD@80?clo0`0k>c/303Ph>080;bl_
0`0];Bd202HV9P<0:b/[0`0X:2P203hn?P<0JVYZ1@1VIVH305YJFP80LG5a0`1UIFD205=CD`<0G5aL
0P1RHV8306MWI`<0JVYZ0P1cLg<306m_K`80MWIf0`22PX8307emO@80O7al1@23Ph<307]kN`<0Ph>3
0P1mOGd30861P@80PX:20`1nOWh308>3P`80QHF50`28R8P508V9R@D0R8R80`27QhL208b<S0<0SXj>
0`2BTY8208^;R`<0SXj>0P2<S8`3092@T080S8b<0`28R8P308V9R@80RXZ:0`2;Rh/208j>SPH0RXZ:
0P2=SHd308j>SP80RXZ:0`2BTY8308j>SP80Shn?2`2BTY8209>CT`<0T92@0P2=SHd3096AT@<0UIFE
0P2CTi<308n?S`80SXj>1P2BTY8209FEU@D0T92@0`2IVIT209BDU0<0Ti>C0`2FUYH209^KV`<0UiNG
1@2KVi/309jNWP80X:2P0`2/[:`20;6a/@<0a<C40`3?cll20<_;b`<0dM7A0P3?cll30;jn_Q`0b>3H
000K0<SPf0<0EeMG0P1XJ6P308>3P`80YjNW0`2l_;`303<c<`80:BTY0`0T92@202h^;P<09RHV0`0R
8R82034a<@<0@4100P0o?cl303Xj>P80=CDe0`0b<S8303@d=080=CDe0`0b<S82030`<0<0=3@d0`0g
=cL203De=@<0<c<c0P0d=3@303Ph>0<0ADE50P1@D50304];B`80@T920`0m?Cd303Ph>080<C4a0`0/
;2`502PX:0<0<30`0P0k>c/306e]K@D0Hf=S0`1JFUX207alO0<0IfMW0P16ATH5061PH0<0I6AT0`1/
K6`207=cL`<0MGEe0P1fMWH307YjNP<0OWin1@1oOgl20820P0<0PH610`1oOgl507inOP80Ogmo0`21
PH4308>3P`80QXJ60`28R8P508Z:RP<0RHV90P28R8P308V9R@80Rh^;0`2>SXh3092@T080SHf=0`2;
Rh/208j>SP<0T92@0P2=SHd308V9R@<0R8R80P29RHT308Z:RPX0S8b<0`2=SHd208j>SP<0Shn?0`2@
T902096AT@D0TY:B1P2ATI45092@T080TI6A0`2BTY8309>CT`80U9BD0`2ATI4208n?S`<0TI6A0`2D
U9@209:BTP<0T92@0P2DU9@309RHV080UYJF0`2DU9@309JFUP80VIVI0`2JVYX209^KV`<0WIfM0`2P
X:020:>SX`<0Z:RX0P2e]KD30<?3``<0b/[:0P3?cll30=3@d080dm?C0`2c/k<d0<SPf0<0GEeM0P1V
IVH308F5Q@80^k^k0`2e]KD30410@0D0:BTY0P0T92@302PX:0<09RHV0P0];Bd30492@P80DU9B0`0h
>3P203<c<`<0>CTi0`0b<S8203Ti>@D0;bl_0`0h>3P303De=@80>CTi0`0_;bl203Xj>P<0=cLg0`13
@d<204];B`<0DE5A0P0o?cl303/k>`<0>3Ph0P0_;bl302d];@809RHV0`0[:b/302PX:080?Shn0`1Z
JVX506IVIP<0FUYJ0P1aLG4306EUI@80De=C0`1LG5`2069RHP<0IfMW0`1ZJVX207=cL`<0Kfm_0P1f
MWH308:2PP<0OGem0P1lO7`508>3P`<0Ng]k0`23Ph<207emO@<0PH610P22PX8307inOP<0Ph>30P25
QHD308R8R0D0RHV91@28R8P308N7Q`80S8b<0`2>SXh309:BTP80Rh^;0`2>SXh208b<S0<0T92@0P2<
S8`308R8R0<0RHV90P2:RXX308^;R`80SXj>1P2:RXX208f=S@<0SXj>0P2:RXX309:BTP<0SXj>0P2?
Shl;09:BTP80Ti>C0`2@T90208f=S@<0TI6A0`2EUID209>CT`<0Shn?0P2>SXh609:BTP80UIFE1@2@
T90309VIV@80U9BD0`2CTi<309JFUP80Vi^K0`2GUiL509^KV`<0WYjN0P2PX:030:b/[080/K6a0`34
a<@30<o?c`80bl_;0`3AdM420<o?c`<0_[jn7038h=P001/0b>3H0`1GEeL206QXJ0<0Ph>30P2WYjL3
0;bl_0<0<c<c0P0Y:BT302@T9080;Rh^0`0V9RH3028R8P80<C4a0`10@40203lo?`<0>SXj0P0e=CD3
038b<P<0=3@d0P0e=CD3038b<P80<30`0`0d=3@303Lg=`80=CDe0`0c<c<203@d=0<0>3Ph0`15ADD2
051@D0<0Bd];0P12@T8303dm?@<0>3Ph0P0a<C4302`/;0D0:2PX0`0`<30203/k>`<0KFe]1@1SHf<3
05YJFP80O7al0`1WIfL204I6APD0H61P0`1TI6@306a/K080Lg=c0`1eMGD207IfMP<0NWYj0`1nOWh5
07moO`80P8200`21PH4307moO`D0OWin0P1oOgl30861P@<0Ph>30P26QXH308R8R0D0RXZ:0`29RHT2
08R8R0<0RHV90P2;Rh/308j>SP<0T92@0P2=SHd308^;R`80SXj>0`2@T90208f=S@<0RHV90`28R8P2
08V9R@<0RXZ:2P2<S8`308f=S@80SXj>0`2?Shl3092@T080TI6A1@2BTY86096AT@D0T92@0P2ATI43
09:BTP<0Ti>C0P2DU9@3096AT@80Shn?0`2ATI4309BDU080TY:B0`2@T90209BDU0<0V9RH0P2FUYH3
09BDU0<0UYJF0P2IVIT309ZJVP80Vi^K0`2MWId30:2PX080Xj>S0`2XZ:P20;Fe]@<0`l?30`3:b/X2
0<o?c`<0d=3@0P3Cdm<30;>c/c@0b>3H0`1MGEd206IVIP<0QHF50P2k^k/30;Fe]@<0@4101@0Y:BT2
02@T90<0:2PX0`0V9RH202d];@<0@T920P1BDU8303Ph>080<c<c0`0i>CT3038b<P80>CTi1@0_;bl3
03Ph>0<0=CDe0P0i>CT302l_;`80>SXj0`0g=cL304=3@`80Bd];0`1ADE4203lo?`<0>c/k0`0h>3P2
02l_;`<0;Bd]0P0V9RH302/[:`<0:2PX0P0n?Sh306YZJPD0IVIV0`1JFUX2075aL@<0IFEU0P1CDe<3
05aLG080HV9R0`1WIfL306YZJP80Lg=c0`1_Kfl207IfMP<0PX:20`1mOGd207alO0D0Ph>30`1kNg/3
08>3P`80OGem0`21PH4208:2PP<0OWin0`23Ph<208F5Q@<0R8R81@29RHT508R8R0<0QhN70P2<S8`3
08j>SP<0TY:B0P2;Rh/308j>SP80S8b<0`2@T90208b<S0<0R8R80`29RHT208Z:RP<0Rh^;0P2>SXh6
08Z:RP80SHf=0`2>SXh208Z:RP<0TY:B0`2>SXh208n?S`/0TY:B0P2CTi<3092@T080SHf=0`2ATI43
09FEU@80Ti>C0`2?Shl208j>SPH0TY:B0P2EUID5092@T0<0VIVI0P2DU9@309>CT`<0UYJF0P2KVi/3
09NGU`D0Vi^K0`2NWYh20:2PX0<0[:b/0P2a/K430<C4a0<0clo?0P3;bl/30=7Ad@80clo?0`2n_[hL
0<SPf0006`38h=P305QHF080GemO0`1`L7020:6QX@<0_kno0`2VYZH204I6AP<08B4Q0P0Y:BT302DU
9@<09RHV0P0a<C4303/k>`80>3Ph0`0c<c<203Lg=`<0>SXj0`0g=cL203<c<`<0<S8b0P0a<C43038b
<PP0=3@d0P0f=SH303/k>`<0@T920P1<C4`304Q8B080@4100`0i>CT303<c<`80<30`0`0_;bl202TY
:@<09bLW0`0_;bl203Xj>P<0K6a/0P1RHV8306ATI0<0G5aL0P1kNg/3065QH@80Cdm?0`1MGEd2069R
HP<0Jf][0`1^KVh2075aL@<0M7Ad0P1fMWH307YjNPD0OWin0`1oOgl20820P0<0PX:20`21PH4207mo
O`D0P8200`21PH4308>3P`80QHF50`27QhL208V9R@<0RXZ:0`29RHT208R8R0<0RXZ:0P2<S8`308j>
SP<0Shn?0P2=SHd308Z:RP80Rh^;0`2<S8`508f=S@<0RXZ:0P29RHT308^;R`80SXj>0`2=SHd308b<
S080SHf=0`2>SXh2092@T0<0TY:B202CTi<509:BTP<0Ti>C0P2BTY83096AT@80TY:B0`2DU9@309JF
UP80UiNG0`2EUID209:BTP<0Ti>C0`2DU9@209>CT`<0TI6A0P2CTi<509JFUP<0UIFE0`2HV9P509ZJ
VP80Vi^K0`2MWId30:2PX080Xj>S0`2YZJT20;Jf]P<0a<C40`3<c<`20=7Ad@<0d=3@0P3?cll30;jn
_S@0b>3H0`1JFUX205UIF@<0L71`0P2CTi<30<71`@<0W9bL0P0n?Sh302PX:080;2`/0`0Y:BT302@T
9080:RXZ0`0g=cL203Hf=P<0<30`0P0d=3@303Ph>0D0=cLg0`0[:b/2038b<P<0>c/k0`0`<302038b
<P<0;bl_0P11@D4303De=@<0A4A40P1<C4`304e=C@80@T920`0f=SH303Lg=`80;bl_0`0^;Rh2030`
<0<0:b/[0`0W9bL20492@P<0JFUY0P1QHF4306ATI0<0H61P0P1jNWX306ATI080BTY:0`1LG5`2069R
HP<0JFUY0`1]KFd707EeM@H0O7al0P1nOWh307YjNP80PX:20`24Q8@507moO`<0OWin0P20P80307mo
O`<0QHF51@26QXH208Z:RP<0Rh^;0`28R8P208V9R@D0Rh^;1P2@T90208R8R0<0S8b<0P2:RXX308n?
S`80Rh^;0`2?Shl308N7Q`80R8R80`2;Rh/208f=S@<0Rh^;0`2?Shl208j>SP<0SHf=1@2ATI4309>C
T`D0UIFE0P2BTY8308n?S`<0TI6A1@2BTY82092@T0<0UYJF0`2HV9P209VIV@<0TI6A0P2EUID609BD
U0D0TY:B0P2CTi<509NGU`<0V9RH0`2FUYH209ZJVPD0Vi^K0`2PX:030:6QX@80YjNW0`2ZZZX20:j^
[P<0a<C40`3?cll20=7Ad@<0cLg=0P3<c<`30<30`1`0b>3H000K0<SPf0<0F5QH0P1OGel3071`L080
XJ6Q0`2o_kl30:JVYP80ATI60`0Q8B4202TY:@<09BDU0`0V9RH2034a<@<0>c/k0P0h>3P303<c<`80
=cLg0`0j>SX303Lg=`80<c<c0`0b<S82034a<@<0<S8b200d=3@203Hf=P<0>c/k0`12@T8204a<C0<0
B4Q80P10@40303Ti>@<0<c<c0P0`<30302l_;`80:BTY0`0W9bL302l_;`80>SXj0`1/K6`2069RHP<0
I6AT0`1LG5`207]kN`<0HF5Q0P1?Cdl305eMG@80HV9R0`1[Jf/306i^KP80LG5a0`1dM7@207IfMP<0
NWYj1@1nOWh307moO`80P8200`22PX830861P@80Ogmo1@20P8030861P@<0Ph>30P25QHD308N7Q`80
RHV90`2:RXX308V9R@80R8R80`2:RXX208b<S0<0SXj>0`2?Shl208f=S@<0RXZ:0P2;Rh/308b<S0D0
SHf=0`2:RXX208V9R@<0Rh^;0P2>SXh308f=S@<0S8b<0P2=SHd308j>SP80T92@0`2BTY8809>CT`D0
TY:B0`2CTi<209:BTP<0TI6A0P2BTY8309BDU0<0UYJF0P2GUiL309FEU@80TY:B0`2CTi<309BDU080
Ti>C0`2ATI4209>CT`D0UYJF0`2EUID309RHV0D0VYZJ0P2KVi/309fMW@<0X:2P0P2SXj<30:VYZ@80
][Jf0`34a<@30<c<c080dM7A0`3@d=020<o?c`<0_[jn=038h=P305YJFP80FEUI0`1`L70209>CT`<0
`L710`2LW9`203hn?P<0:2PX0P0/;2`302TY:@<092@T0P0Z:RX303Lg=`80=SHf0`0`<30203@d=0<0
>3Ph1@0g=cL302/[:`80<S8b0`0k>c/3030`<080<S8b0`0_;bl20451@@<0=CDe0`14A4@204a<C0<0
CDe=0P12@T8303Hf=P<0=cLg0P0_;bl302h^;P80<30`0`0[:b/302LW9`80@T920`1YJFT2065QH@<0
I6AT0`1PH60207YjNP<0I6AT0P1:BTX305aLG080HV9R0`1YJFT306e]K@L0MGEe1P1lO7`207inOP<0
NWYj0P22PX8308B4Q0D0Ogmo0`1nOWh20820P0<0Ogmo0`25QHD508J6QP80RXZ:0`2;Rh/308R8R080
RHV91@2;Rh/6092@T080R8R80`2<S8`208Z:RP<0Shn?0P2;Rh/308n?S`<0QhN70P28R8P308^;R`80
SHf=0`2;Rh/308n?S`80SXj>0`2=SHd5096AT@<0Ti>C1@2EUID209:BTP<0Shn?0`2ATI4509:BTP80
T92@0`2FUYH309RHV080VIVI0`2ATI4209FEU@H0U9BD1@2BTY8209>CT`D0UiNG0`2HV9P309JFUP80
VYZJ1@2KVi/30:2PX0<0XJ6Q0P2WYjL30:ZZZP80[Zj^0`34a<@30<o?c`80dM7A0`3=cLd20<c<c0<0
`<307038h=P001/0b>3H0`1KFe/205MGE`<0FUYJ0P1iNGT309JFUP<0];Bd0P2HV9P303lo?`80:2PX
0`0Q8B4302XZ:P80;bl_0`0c<c<202l_;`<0;2`/0P0h>3P30492@P<0>SXj1@0a<C4203<c<`<0<C4a
0`0_;bl2034a<@<0=CDe0P0i>CT303dm?@<0@D510P16ATH30492@P80?Cdm0`0d=3@302d];@80;bl_
0`0b<S8202/[:`<09RHV0`0_;bl203Xj>P<0Jf][0P1PH60306IVIP<0H61P0P1iNGT305MGE`D0FUYJ
0P1VIVH3079bLP<0LG5a0P1_Kfl3079bLP80MgMg0`1jNWX307alO080OWin0`1oOgl20861P@H0PX:2
1@21PH4808:2PP80Q8B40`26QXH208R8R0P0RHV90`2;Rh/208f=S@H0SXj>0P2<S8`308Z:RP80RHV9
0`28R8P208f=S@<0TI6A0`2=SHd208V9R@<0S8b<0P2@T90308n?S`<0SHf=0P2>SXh3092@T080TY:B
0`2DU9@509JFUP<0UIFE1@2DU9@309FEU@D0U9BD0P2EUID309NGU`<0VYZJ0P2LW9`309VIV@P0UIFE
0P2DU9@309:BTP80Ti>C0`2DU9@209FEU@<0UYJF0`2IVIT209^KV`D0VYZJ0`2LW9`309nOW`80Xj>S
0`2XZ:P20;Jf]P<0a<C40`3?cll20=CDe0<0d=3@0P39bLT30<[:bS@0b>3H0`1IFET205YJFP<0GemO
0P1bLW8309ZJVP<0`/;20P2EUID303Xj>P80:RXZ0`0V9RH302XZ:P80;Bd]0`0h>3P203@d=0<0;bl_
0P0f=SH304A4A0<0>3Ph0P0b<S8302h^;P80<c<c0`0e=CD303<c<`80;2`/0`0d=3@203dm?@<0>3Ph
0`1:BTX20451@@<0?Cdm0P12@T8302d];@<0;Rh^0P0d=3@3030`<080;2`/0`0Y:BT302XZ:P80@D51
0`1SHf<206ATI0<0IfMW0`1OGel207]kN`<0FEUI0P1ADE4305iNGP80JFUY0`1fMWH306i^KP80KFe]
1@1gMgL307QhN0<0OGem0P1nOWh30861P@80PX:21P21PH420820P0<0QhN70P23Ph<307moO`<0PX:2
0P24Q8@308>3P`80Rh^;0`27QhL308J6QP80RHV90`2;Rh/208n?S`<0S8b<0`2@T90208b<S0<0Rh^;
0P28R8P308V9R@80Rh^;0`2BTY8508Z:RP<0SXj>0P2@T90308f=S@<0Rh^;1@2>SXh209JFUP<0U9BD
0`2CTi<509FEU@80U9BD1P2EUID209NGU`D0TY:B0`2GUiL509bLW0<0Ti>C0P2DU9@309NGU`<0UYJF
0P2@T90309BDU080TI6A0`2FUYH209BDU0<0UIFE1@2KVi/309VIV@80Vi^K0`2JVYX309fMW@80Y:BT
0`2[Zj/20;2`/0<0a<C40`3De=@20=?Cd`<0c/k>0P3=cLd30<G5aA`0b>3H000K0<SPf0<0Fe]K0P1G
EeL305YJFP80NGUi0`2FUYH30;Bd]080V9RH0`0o?cl202PX:0<08B4Q0`0Z:RX202l_;`<0<c<c0P0_
;bl302`/;080>3Ph0`12@T8303Xj>PD0<C4a0P0c<c<3034a<@<0;bl_0P0a<C4303De=@80>CTi0`0m
?Cd30451@@80ATI60`12@T8203dm?@<0=3@d0`0];Bd202l_;`<0<S8b0P0[:b/302HV9P<0;bl_0P0j
>SX306][J`80H61P0`1VIVH3061PH080NGUi0`1GEeL505YJFP80IVIV0`1bLW83075aL@80Kfm_0`1b
LW8207MgM`<0NWYj0`1lO7`207inOP<0Ogmo0P21PH4608:2PPD0PH612022PX8208B4Q0<0QXJ60P28
R8P808V9R@<0Rh^;0P2=SHd608j>SP80S8b<0`2:RXX208V9R@<0R8R80P2=SHd3096AT@<0SHf=0P29
RHT308b<S080T92@0`2?Shl308f=S@80SXj>0`2@T90209:BTP<0U9BD1@2FUYH309FEU@D0U9BD0`2E
UID509BDU080UIFE0`2GUiL309ZJVP80W9bL0`2IVIT809FEU@80U9BD0`2BTY8209>CT`<0U9BD0P2E
UID309JFUP<0VIVI0P2KVi/509ZJVP<0W9bL0`2OWil20:>SX`<0Z:RX0P2f][H30<C4a0<0clo?0P3D
e=@30=3@d080bLW90`3:b/Xd0<SPf0<0FEUI0P1JFUX305mOG`80LW9b0`2JVYX30<;2`P80UIFE0`0j
>SX202XZ:P<09RHV0`0Z:RX202d];@<0>3Ph0P0d=3@302l_;`80=SHf0`14A4@303Ph>080<S8b0`0^
;Rh203<c<`<0=CDe0`0c<c<202`/;0<0=3@d0P0m?Cd303Ph>0<0BTY:0P11@D4303dm?@80@T920`0]
;Bd302h^;P80=3@d0`0`<30202`/;0<0:BTY0`0Z:RX20451@@<0Hf=S0P1TI6@306MWI`<0GemO0P1k
Ng/305UIF@80DE5A0`1NGUh206UYJ@<0MWIf0`1^KVh206e]K@D0MgMg0`1hN7P307emO@80OWin0`21
PH4208:2PPH0PH610P20P80308N7Q`80Ph>30`1oOgl308:2PP80Q8B40`23Ph<208^;R`<0QhN70`26
QXH208V9R@<0Rh^;0P2?Shl308b<S0<0T92@0P2<S8`308^;R`80R8R80`29RHT208^;R`<0TY:B1@2:
RXX308j>SP80T92@0`2=SHd308^;R`D0SXj>0P2FUYH309BDU0<0Ti>C1@2EUID209BDU0H0UIFE0P2G
UiL509:BTP<0UiNG1@2LW9`309>CT`80U9BD0`2GUiL309JFUP80T92@0`2DU9@2096AT@<0UYJF0P2D
U9@309FEU@D0Vi^K0`2IVIT209^KV`<0VYZJ0`2MWId20:BTY0<0Zj^[0P2`/;030<C4a0<0e=CD0P3C
dm<30<k>cP80cLg=0`35aLDL0<SPf0006`38h=P305]KF`80EeMG0`1JFUX207UiN@<0UYJF0`2d];@2
09RHV0<0?clo0P0X:2P3024Q8@<0:RXZ0P0_;bl303<c<`80;bl_0`0/;2`203Ph>0<0@T920`0j>SX5
034a<@80<c<c0`0a<C4302l_;`80<C4a0`0e=CD203Ti>@<0?Cdm0`11@D4204I6AP<0@T920P0m?Cd3
03@d=0<0;Bd]0P0_;bl3038b<P80:b/[0`0V9RH302l_;`80>SXj0`1[Jf/2061PH0<0IVIV0`1PH602
07UiN@<0EeMG1@1JFUX206IVIP<0LW9b0`1aLG4206m_K`<0LW9b0P1gMgL307YjNP<0O7al0P1nOWh3
07moO`80PH611P22PX850861P@P0PX:20P24Q8@308J6QP80R8R82029RHT308^;R`80SHf=1P2>SXh2
08b<S0<0RXZ:0P29RHT308R8R080SHf=0`2ATI4308f=S@80RHV90`2<S8`2092@T0<0Shn?0`2=SHd2
08j>SP<0T92@0P2BTY8309BDU0D0UYJF0`2EUID509BDU0<0UIFE1@2DU9@209FEU@<0UiNG0`2JVYX2
09bLW0<0VIVI202EUID209BDU0<0TY:B0P2CTi<309BDU080UIFE0`2FUYH309VIV@80Vi^K1@2JVYX3
09bLW0<0WinO0P2SXj<30:RXZ080][Jf0`34a<@30<o?c`80e=CD0`3@d=020<W9b@<0b/[:=038h=P3
05UIF@80FUYJ0`1OGel2079bLP<0VYZJ0`32`/8209FEU@<0>SXj0P0Z:RX302HV9P<0:RXZ0P0];Bd3
03Ph>080=3@d0`0_;bl203Hf=P<0A4A40`0h>3P2038b<P<0;Rh^0P0c<c<303De=@<0<c<c0P0/;2`3
03@d=080?Cdm0`0h>3P304Y:BP80@D510`0m?Cd20492@P<0;Bd]0`0^;Rh203@d=0<0<30`0P0/;2`3
02TY:@<0:RXZ0P11@D4306=SH`80I6AT0`1WIfL305mOG`80Ng]k0`1IFET2055AD@<0GUiN0P1YJFT3
07IfMP<0KVi^0P1]KFd507MgM`<0N7Qh0`1mOGd207inOP<0PH610P22PX860861P@80P8200`27QhL2
08>3P`<0Ogmo0`22PX8208B4Q0<0Ph>30P2;Rh/308N7Q`<0QXJ60P29RHT308^;R`80Shn?0`2<S8`3
092@T080S8b<0`2;Rh/208R8R0<0RHV90P2;Rh/309:BTPD0RXZ:0`2>SXh2092@T0<0SHf=0`2;Rh/5
08j>SP80UYJF0`2DU9@309>CT`D0UIFE0P2DU9@609FEU@80UiNG1@2BTY8309NGU`D0W9bL0`2CTi<2
09BDU0<0UiNG0`2FUYH2092@T0<0U9BD0P2ATI4309JFUP80U9BD0`2EUID509^KV`<0VIVI0P2KVi/3
09ZJVP<0WIfM0P2TY:@30:^[Z`80/;2`0`34a<@30=CDe080dm?C0`3>c/h20<g=c@<0aLG57038h=P0
01/0b>3H0`1LG5`505MGE`80JVYZ0`23Ph<30:JVYP80][Jf0`1lO7`203Xj>P<07AdM0`0W9bL202PX
:0D0;Bd]0`0_;bl203Hf=P<0>c/k0`0d=3@202d];@<0;bl_0P0c<c<3030`<0<0;Bd]0P0`<30303@d
=0D0=SHf0`1=CDd20410@0<0?clo0P0i>CT303<c<`<0;Rh^0P0`<303038b<P80:RXZ0`0U9BD303@d
=080@4100`1`L702065QH@<0IVIV0`1PH60207UiN@<0E5AD0P1KFe/305iNGP80J6QX201aLG4307Ad
M080MgMg0`1iNGT307]kN`80OGem0`1oOgl20820P0<0PH610`22PX8508>3P`80PX:21P21PH4208B4
Q0<0R8R80P29RHT308R8R0D0RHV90`2;Rh/508f=S@D0S8b<202;Rh/208j>SP<0T92@0`2>SXh208^;
R`<0SHf=202?Shl2096AT@<0Ti>C0P2DU9@309FEU@X0UYJF1P2EUID209JFUPD0UiNG0`2HV9P309^K
V`80WIfM0`2JVYX209JFUP<0U9BD0`2CTi<509:BTP80UIFE1@2GUiL309JFUP<0UiNG0P2HV9P309VI
V@80VYZJ0`2KVi/309fMW@80XJ6Q0`2WYjL20;Bd]0<0`L710`3=cLd20=CDe0<0clo?0P37alL30<W9
bC@0b>3H0`1PH60205UIF@<0GEeM0P1VIVH307alO0<0[:b/0P30`<0306i^KP80;bl_0`0Z:RX302@T
9080:2PX0`0[:b/202XZ:P<0:b/[0P0m?Cd30410@0<0<30`0P0c<c<3030`<0D0<C4a0`0Z:RX202h^
;P<0=SHf0P0n?Sh302l_;`<0CTi>0P14A4@303hn?P80?3`l0`0a<C4302d];@80=SHf0`0_;bl202LW
9`<09RHV0`0Z:RX204I6AP<0K6a/0P1UIFD306QXJ0<0G5aL0P1gMgL305QHF080Fe]K0`1SHf<206EU
I@<0Kfm_0`1`L702075aL@<0LW9b0P1fMWH307UiN@<0OGem0P1kNg/307inOP80PH610`20P80308:2
PP80Q8B40`1oOgl508:2PP<0P8200P28R8P308N7Q`80Rh^;0`28R8P508V9R@<0SXj>0P2=SHd308R8
R0<0SHf=0P2>SXh308b<S080R8R80`2<S8`2092@T0<0TY:B0`2=SHd208b<S0<0T92@0P2>SXh309>C
T`<0SHf=0P2DU9@3096AT@80UYJF1P2DU9@209VIV@<0UiNG0P2EUID609>CT`80VIVI0`2HV9P209VI
V@<0V9RH0`2IVIT20:2PX0<0VYZJ0P2IVIT609>CT`80TY:B0`2FUYH2092@T0D0UiNG0`2DU9@309JF
UP80VIVI0`2FUYH209ZJVP<0VIVI0`2MWId50:FUY@80/;2`0`32`/830=;BdP80clo?0`3>c/h20<c<
c0<0`L717038h=P001/0b>3H0`1LG5`505MGE`80JVYZ0`23Ph<30:JVYP80][Jf0`1lO7`203Xj>P<0
7AdM0`0W9bL202PX:0D0;Bd]0`0_;bl203Hf=P<0>c/k0`0d=3@202d];@<0;bl_0P0c<c<3030`<0<0
;Bd]0P0`<30303@d=0D0=SHf0`1=CDd20410@0<0?clo0P0i>CT303<c<`<0;Rh^0P0`<303038b<P80
:RXZ0`0U9BD303@d=080@4100`1`L702065QH@<0IVIV0`1PH60207UiN@<0E5AD0P1KFe/305iNGP80
J6QX201aLG4307AdM080MgMg0`1iNGT307]kN`80OGem0`1oOgl20820P0<0PH610`22PX8508>3P`80
PX:21P21PH4208B4Q0<0R8R80P29RHT308R8R0D0RHV90`2;Rh/508f=S@D0S8b<202;Rh/208j>SP<0
T92@0`2>SXh208^;R`<0SHf=202?Shl2096AT@<0Ti>C0P2DU9@309FEU@X0UYJF1P2EUID209JFUPD0
UiNG0`2HV9P309^KV`80WIfM0`2JVYX209JFUP<0U9BD0`2CTi<509:BTP80UIFE1@2GUiL309JFUP<0
UiNG0P2HV9P309VIV@80VYZJ0`2KVi/309fMW@80XJ6Q0`2WYjL20;Bd]0<0`L710`3=cLd20=CDe0<0
clo?0P37alL30<W9bC@0b>3H0`1PH60205UIF@<0GEeM0P1VIVH307alO0<0[:b/0P30`<0306i^KP80
;bl_0`0Z:RX302@T9080:2PX0`0[:b/202XZ:P<0:b/[0P0m?Cd30410@0<0<30`0P0c<c<3030`<0D0
<C4a0`0Z:RX202h^;P<0=SHf0P0n?Sh302l_;`<0CTi>0P14A4@303hn?P80?3`l0`0a<C4302d];@80
=SHf0`0_;bl202LW9`<09RHV0`0Z:RX204I6AP<0K6a/0P1UIFD306QXJ0<0G5aL0P1gMgL305QHF080
Fe]K0`1SHf<206EUI@<0Kfm_0`1`L702075aL@<0LW9b0P1fMWH307UiN@<0OGem0P1kNg/307inOP80
PH610`20P80308:2PP80Q8B40`1oOgl508:2PP<0P8200P28R8P308N7Q`80Rh^;0`28R8P508V9R@<0
SXj>0P2=SHd308R8R0<0SHf=0P2>SXh308b<S080R8R80`2<S8`2092@T0<0TY:B0`2=SHd208b<S0<0
T92@0P2>SXh309>CT`<0SHf=0P2DU9@3096AT@80UYJF1P2DU9@209VIV@<0UiNG0P2EUID609>CT`80
VIVI0`2HV9P209VIV@<0V9RH0`2IVIT20:2PX0<0VYZJ0P2IVIT609>CT`80TY:B0`2FUYH2092@T0D0
UiNG0`2DU9@309JFUP80VIVI0`2FUYH209ZJVP<0VIVI0`2MWId50:FUY@80/;2`0`32`/830=;BdP80
clo?0`3>c/h20<c<c0<0`L717038h=P001/0b>3H0`1NGUh505YJFP80GemO0`1`L70308:2PP80a<C4
0`2f][H205UIF@<0:RXZ0`0U9BD2028R8P<0:2PX0P0];Bd503<c<`<0<S8b0`0^;Rh202XZ:P<0;bl_
0P0c<c<302l_;`<0:b/[0P0`<30303@d=080<c<c0`0`<30305MGE`80?Cdm0`0l?3`203Lg=`<0=3@d
200a<C4202TY:@<09BDU0`0g=cL204Q8B0<0MGEe0P1SHf<306MWI`<0H61P0P1gMgL3059BDP80Fe]K
0`1SHf<206UYJ@<0KVi^0`1aLG4207=cL`<0MWIf0P1hN7P307UiN@<0NWYj0P1mOGd80820P0<0PX:2
0P24Q8@308>3P`80PH610`20P80307moO`80QHF51@2:RXX308R8R0D0RHV90`2;Rh/508b<S0D0Rh^;
0`2<S8`208f=S@D0SXj>0`2=SHd:08j>SP<0Shn?0`2ATI4209BDU0d0UYJF0`2GUiL209RHV0<0UYJF
0`2EUID209NGU`P0VIVI0`2KVi/209bLW0<0VYZJ0P2FUYH309>CT`D0TI6A0`2CTi<209NGU`<0VYZJ
0P2HV9P309FEU@<0U9BD0P2EUID309NGU`80VIVI0`2JVYX309^KV`80WinO0`2UYJD20;6a/@<0_[jn
0`3:b/X20=;BdP<0cLg=0P36a/H30<G5aC@0b>3H0`1OGel205YJFP<0Fe]K0P1IFET3071`L0<0SHf=
0P2o_kl30;>c/`80Fe]K0`0/;2`302LW9`8092@T0`0[:b/202d];@<0<S8b0P0d=3@302h^;P<0<30`
0P0Y:BT302`/;080<S8b0`0c<c<302/[:`80;Bd]0`0a<C4203<c<`<0<S8b0`1;Bd/204=3@`<0>CTi
0P0f=SH3030`<0<0<C4a0P0d=3@3038b<P80:2PX0`0W9bL3030`<080C4a<0`1dM7@2061PH0<0JVYZ
0`1WIfL206m_K`<0EUIF0P1NGUh306=SH`80JVYZ0`1^KVh3071`L080Lg=c0`1hN7P207YjNPH0MgMg
0P21PH4307moO`D0OWin0`25QHD208>3P`D0PX:20`1lO7`307moO`80QHF50`28R8P208^;R`P0QhN7
0`2>SXh208^;R`<0R8R80`29RHT2092@T0D0Rh^;0`2ATI4208^;R`<0Shn?0`2<S8`208n?S`<0SXj>
0P2=SHd308n?S`<0SXj>0P2EUID309BDU080UiNG0`2FUYH309BDU080UIFE0`2HV9P209JFUP<0UiNG
0`2DU9@209VIV@D0V9RH0`2IVIT309nOW`80Vi^K0`2GUiL209FEU@<0Ti>C0`2BTY8208n?S`<0U9BD
0P2GUiL509ZJVP<0UiNG0`2@T90209RHV0D0UiNG0`2LW9`309JFUP80Xj>S0`2UYJD20:ZZZP<0_[jn
0`3>c/h20=7Ad@<0c/k>0P38b<P30;bl_1`0b>3H000K0<SPf0<0GUiN1@1JFUX205mOG`<0L71`0`22
PX820<C4a0<0][Jf0P1IFET302XZ:P<09BDU0P0R8R8302PX:080;Bd]1@0c<c<3038b<P<0;Rh^0P0Z
:RX302l_;`80<c<c0`0_;bl302/[:`80<30`0`0d=3@203<c<`<0<30`0`1GEeL203dm?@<0?3`l0P0g
=cL303@d=0P0<C4a0P0Y:BT302DU9@<0=cLg0P18B4P307EeM@80Hf=S0`1WIfL3061PH080MgMg0`1B
DU8205]KF`<0Hf=S0P1YJFT306i^KP<0LG5a0P1cLg<307IfMP80N7Qh0`1iNGT307YjNP80OGem2020
P80308:2PP80Q8B40`23Ph<20861P@<0P8200`1oOgl208F5Q@D0RXZ:0`28R8P508V9R@<0Rh^;1@2<
S8`508^;R`<0S8b<0P2=SHd508j>SP<0SHf=2P2>SXh308n?S`<0TI6A0P2DU9@=09JFUP<0UiNG0P2H
V9P309JFUP<0UIFE0P2GUiL809VIV@<0Vi^K0P2LW9`309ZJVP80UYJF0`2CTi<5096AT@<0Ti>C0P2G
UiL309ZJVP80V9RH0`2EUID309BDU080UIFE0`2GUiL209VIV@<0VYZJ0`2KVi/209nOW`<0YJFU0P2a
/K430;jn_P<0b/[:0P3Bd]830<g=c@80a/K60`35aLDd0<SPf0<0GemO0P1JFUX305]KF`80FEUI0`1`
L70308f=S@80_kno0`2c/k<205]KF`<0;2`/0`0W9bL202@T90<0:b/[0P0];Bd3038b<P80=3@d0`0^
;Rh3030`<080:BTY0`0/;2`2038b<P<0<c<c0`0[:b/202d];@<0<C4a0P0c<c<3038b<P<0Bd];0P13
@d<303Ti>@80=SHf0`0`<303034a<@80=3@d0`0b<S8202PX:0<09bLW0`0`<30204a<C0<0M7Ad0P1P
H60306YZJP<0IfMW0P1_Kfl305IFEP80GUiN0`1SHf<206YZJP<0KVi^0`1`L70207=cL`<0N7Qh0P1j
NWX607MgM`80PH610`1oOgl507inOP<0QHF50P23Ph<508:2PP<0O7al0`1oOgl208F5Q@<0R8R80P2;
Rh/808N7Q`<0SXj>0P2;Rh/308R8R0<0RHV90P2@T90508^;R`<0TI6A0P2;Rh/308n?S`<0S8b<0P2?
Shl308j>SP80SHf=0`2?Shl308j>SP80UIFE0`2DU9@209NGU`<0UYJF0`2DU9@209FEU@<0V9RH0P2F
UYH309NGU`<0U9BD0P2IVIT509RHV0<0VIVI0`2OWil209^KV`<0UiNG0P2EUID309>CT`<0TY:B0P2?
Shl309BDU080UiNG1@2JVYX309NGU`<0T92@0P2HV9P509NGU`<0W9bL0`2FUYH20:>SX`<0YJFU0P2Z
ZZX30;jn_P<0c/k>0P3AdM430<k>cP80b<S80`2l_;`L0<SPf0006`38h=P305iNGPD0FUYJ0P1OGel3
071`L0<0PX:20P34a<@30;Jf]P80FEUI0`0Z:RX302DU9@808R8R0`0X:2P202d];@D0<c<c0`0b<S83
02h^;P80:RXZ0`0_;bl203<c<`<0;bl_0`0[:b/2030`<0<0=3@d0P0c<c<3030`<0<0EeMG0P0m?Cd3
03`l?080=cLg0`0d=3@8034a<@80:BTY0`0U9BD303Lg=`80B4Q80`1eMGD206=SH`<0IfMW0`1PH602
07MgM`<0DU9B0P1KFe/306=SH`80JFUY0`1^KVh3075aL@80Lg=c0`1fMWH207QhN0<0NGUi0`1jNWX2
07emO@P0P8200`22PX8208B4Q0<0Ph>30P21PH430820P0<0Ogmo0P25QHD508Z:RP<0R8R81@29RHT3
08^;R`D0S8b<1@2;Rh/308b<S080SHf=1@2>SXh308f=S@X0SXj>0`2?Shl3096AT@80U9BD3@2FUYH3
09NGU`80V9RH0`2FUYH309FEU@80UiNG202IVIT309^KV`80W9bL0`2JVYX209JFUP<0Ti>C1@2ATI43
09>CT`80UiNG0`2JVYX209RHV0<0UIFE0`2DU9@209FEU@<0UiNG0P2IVIT309ZJVP<0Vi^K0P2OWil3
0:FUY@80/K6a0`2n_[h30<[:bP80d];B0`3=cLd20<K6aP<0aLG5=038h=P305mOG`80FUYJ0`1KFe/2
05UIF@<0L71`0`2=SHd20;no_`<0/k>c0P1KFe/302`/;0<09bLW0P0T92@302/[:`80;Bd]0`0b<S82
03@d=0<0;Rh^0`0`<30202TY:@<0;2`/0P0b<S8303<c<`<0:b/[0P0];Bd3034a<@80<c<c0`0b<S83
04];B`80@d=30`0i>CT203Hf=P<0<30`0`0a<C4203@d=0<0<S8b0P0X:2P302LW9`<0<30`0P1<C4`3
07AdM080H61P0`1ZJVX306MWI`80Kfm_0`1FEUH205iNGP<0Hf=S0P1ZJVX306i^KP<0L71`0P1cLg<3
07QhN080NWYj1P1gMgL20861P@<0Ogmo1@1nOWh308F5Q@80Ph>31@22PX8307alO0<0Ogmo0P25QHD3
08R8R080Rh^;2027QhL308j>SP80Rh^;0`28R8P308V9R@80T92@1@2;Rh/3096AT@80Rh^;0`2?Shl3
08b<S080Shn?0`2>SXh208f=S@<0Shn?0`2>SXh209FEU@<0U9BD0P2GUiL309JFUP<0U9BD0P2EUID3
09RHV080UYJF0`2GUiL309BDU080VIVI1@2HV9P309VIV@<0WinO0P2KVi/309NGU`80UIFE0`2CTi<3
09:BTP80Shn?0`2DU9@209NGU`D0VYZJ0`2GUiL3092@T080V9RH1@2GUiL309bLW0<0UYJF0P2SXj<3
0:FUY@80ZZZZ0`2n_[h30<k>cP80dM7A0`3>c/h20<S8b0<0_;bl7038h=P001/0b>3H0`1SHf<205iN
GPD0FEUI0`1SHf<307EeM@80Z:RX0`34a<@20:JVYP<0>SXj0`0b<S8202@T90<09RHV0P0Z:RX302l_
;`80;Rh^0`0];Bd502`/;0<0<30`0P0c<c<3034a<@<0;Rh^0P0b<S8303De=@80=SHf0`0e=CD304a<
C0D0?clo0P0j>SX303Lg=`<0<c<c0P0a<C43030`<080:RXZ0`0Y:BT302/[:`80BTY:0`1iNGT206MW
I`<0KFe]0`1TI6@206][J`<0EUIF0P1NGUh306MWI`80K6a/0`1_Kfl3071`L080LW9b0`1gMgL207al
O0H0Ng]k0P1mOGd507moO`H0P8200P21PH450820P0<0PH610`23Ph<208F5Q@<0QhN70P28R8P608Z:
RPD0Rh^;5`2<S8`308f=S@80Shn?1@2>SXh3096AT@<0U9BD0P2GUiL509RHV0H0UiNG0P2HV9P;09NG
U`80V9RH202JVYX509^KV`<0VIVI0P2GUiL309BDU0<0Ti>C0P2DU9@309FEU@D0UiNG0P2EUID309>C
T`<0U9BD0P2EUID309BDU080UIFE0`2GUiL309VIV@80W9bL0`2QXJ420:f][@<0^[Zj0`38b<P20=7A
d@<0bl_;0P32`/830<C4a3@0b>3H0`1RHV8205YJFP<0F5QH0P1OGel3065QH@<0MWIf0P2PX:030<S8
b080ZZZZ0`0o?cl302PX:0D092@T0P0Y:BT303@d=080<C4a0`0];Bd502`/;0<0<C4a0P0e=CD303@d
=0<0<30`0P0b<S8303Ph>080?3`l0`0m?Cd304a<C080@4100`0m?Cd204=3@`<0>SXj0`0c<c<2038b
<P<0;2`/1@0`<30302d];@80Bd];0`1gMgL206UYJ@<0KVi^0`1QHF4206UYJ@<0DE5A0P1NGUh3065Q
H@80JFUY0`1cLg<3079bLP80Lg=c0`1dM7@207emO@<0NWYj0`1lO7`208:2PP<0OGem1@20P80308>3
P`80Ogmo0`21PH4208:2PP<0Q8B40`22PX8208R8R0<0QHF50P2;Rh/308V9R@<0SHf=0P29RHT508f=
S@<0Shn?1@2=SHd308Z:RPD0S8b<0P2:RXX308f=S@<0Rh^;0P2<S8`3096AT@80S8b<0`2BTY8309BD
U080V9RH0`2JVYX509NGU`<0VIVI1@2GUiL209ZJVP<0U9BD0`2GUiL209bLW0D0UYJF0`2GUiL309fM
W@80VIVI0`2HV9P209VIV@P0U9BD0`2CTi<209FEU@<0V9RH0P2EUID309:BTP<0U9BD0P2CTi<509NG
U`<0V9RH0`2JVYX209jNWP<0Y:BT0P2[Zj/30;Rh^0<0b/[:0P3>c/h30<g=c@80alO70`2k^k/L0<SP
f0006`38h=P306=SH`80GUiN1@1IFET306=SH`<0MGEe0P2XZ:P30<C4a080YZJV0`0j>SX3038b<P80
92@T0`0V9RH202XZ:P<0;bl_0P0^;Rh302d];@D0;2`/0`0`<30203<c<`<0<C4a0`0^;Rh2038b<P<0
=CDe0P0f=SH303De=@<0C4a<1@0o?cl203Xj>P<0=cLg0`0c<c<2034a<@<0<30`0P0Z:RX302TY:@<0
:b/[0P1:BTX307UiN@80IfMW0`1]KFd306ATI080Jf][0`1FEUH205iNGP<0IfMW0P1/K6`306m_K`<0
L71`0P1bLW8307MgM`80O7al1P1kNg/207emO@D0Ogmo1P20P8020861P@D0P8200`21PH4308>3P`80
QHF50`27QhL208R8R0H0RXZ:1@2;Rh/G08b<S0<0SHf=0P2?Shl508j>SP<0TI6A0`2DU9@209NGU`D0
V9RH1P2GUiL209RHV0/0UiNG0P2HV9P809ZJVPD0Vi^K0`2IVIT209NGU`<0U9BD0`2CTi<209BDU0<0
UIFE1@2GUiL209FEU@<0Ti>C0`2DU9@209FEU@<0U9BD0P2EUID309NGU`<0VIVI0P2LW9`30:6QX@80
[Jf]0`2j^[X30<S8b080dM7A0`3;bl/20<;2`P<0a<C4=038h=P3069RHP80FUYJ0`1HF5P205mOG`<0
HF5Q0`1fMWH20:2PX0<0b<S80P2ZZZX303lo?`<0:2PX1@0T92@202TY:@<0=3@d0P0a<C4302d];@D0
;2`/0`0a<C4203De=@<0=3@d0`0`<302038b<P<0>3Ph0P0l?3`303dm?@<0C4a<0P10@40303dm?@80
@d=30`0j>SX303<c<`80<S8b0`0/;2`5030`<0<0;Bd]0P1;Bd/307MgM`80JFUY0`1^KVh3065QH@80
JFUY0`1ADE4205iNGP<0HF5Q0P1YJFT307=cL`<0LW9b0P1cLg<307AdM080OGem0`1jNWX307alO080
PX:20`1mOGd50820P0<0Ph>30P1oOgl30861P@80PX:20`24Q8@308:2PP80R8R80`25QHD208^;R`<0
RHV90`2=SHd208V9R@D0SHf=0`2?Shl508f=S@<0RXZ:1@2<S8`208Z:RP<0SHf=0`2;Rh/208b<S0<0
TI6A0P2<S8`309:BTP<0U9BD0P2HV9P309ZJVPD0UiNG0`2IVIT509NGU`80VYZJ0`2DU9@309NGU`80
W9bL1@2FUYH309NGU`<0WIfM0P2IVIT309RHV080VIVI202DU9@309>CT`80UIFE0`2HV9P209FEU@<0
TY:B0`2DU9@209>CT`D0UiNG0`2HV9P309ZJVP80WYjN0`2TY:@20:^[Z`<0^;Rh0`3:b/X20<k>cP<0
cLg=0P37alL30;^k^a`0b>3H000K0<SPf0<0Hf=S0P1NGUh505UIF@<0Hf=S0`1eMGD20:RXZ0<0a<C4
0P2VYZH303Xj>P<0<S8b0P0T92@302HV9P80:RXZ0`0_;bl202h^;P<0;Bd]1@0/;2`3030`<080<c<c
0`0a<C4302h^;P80<S8b0`0e=CD203Hf=P<0=CDe0`1<C4`503lo?`80>SXj0`0g=cL303<c<`80<C4a
0`0`<30202XZ:P<0:BTY0`0[:b/204Y:BP<0NGUi0P1WIfL306e]K@<0I6AT0P1[Jf/305IFEP80GUiN
0`1WIfL206a/K0<0Kfm_0`1`L702079bLP<0MgMg0P1lO7`607]kN`80OGem1@1oOgl60820P080PH61
1@20P8030861P@<0Ph>30P25QHD308N7Q`80R8R81P2:RXX508^;RaL0S8b<0`2=SHd208n?S`D0SXj>
0`2ATI4309BDU080UiNG1@2HV9P609NGU`80V9RH2`2GUiL209RHV0P0VYZJ1@2KVi/309VIV@80UiNG
0`2DU9@309>CT`80U9BD0`2EUID509NGU`80UIFE0`2CTi<309BDU080UIFE0`2DU9@209FEU@<0UiNG
0`2IVIT209bLW0<0XJ6Q0P2][Jd30;Zj^P<0b<S80P3AdM430<_;b`80`/;20`34a<@d0<SPf0<0HV9R
0P1JFUX305QHF080GemO0`1QHF4307IfMP80X:2P0`38b<P20:ZZZP<0?clo0`0X:2P502@T9080:BTY
0`0d=3@2034a<@<0;Bd]1@0/;2`3034a<@80=CDe0`0d=3@3030`<080<S8b0`0h>3P203`l?0<0?Cdm
0`1<C4`20410@0<0?Cdm0P13@d<303Xj>P<0<c<c0P0b<S8302`/;0D0<30`0`0];Bd204];B`<0MgMg
0P1YJFT306i^KP<0HF5Q0P1YJFT3055AD@80GUiN0`1QHF4206UYJ@<0Lg=c0`1bLW8207=cL`<0M7Ad
0P1mOGd307YjNP<0O7al0P22PX8307emO@D0P8200`23Ph<207moO`<0PH610P22PX8308B4Q0<0PX:2
0P28R8P308F5Q@80Rh^;0`29RHT308f=S@80RHV91@2=SHd308n?S`D0SHf=0`2:RXX508b<S080RXZ:
0`2=SHd308^;R`80S8b<0`2ATI4208b<S0<0TY:B0`2DU9@209RHV0<0VYZJ1@2GUiL309VIV@D0UiNG
0P2JVYX309BDU0<0UiNG0P2LW9`509JFUP<0UiNG0`2MWId209VIV@<0V9RH0P2IVIT809BDU0<0Ti>C
0P2EUID309RHV080UIFE0`2BTY8309BDU080Ti>C1@2GUiL309RHV0<0VYZJ0P2NWYh30:BTY080Zj^[
0`2h^;P30<[:bP80c/k>0`3=cLd20<O7a`<0^k^k7038h=P001/0b>3H0`1UIFD2061PH0<0Fe]K0P1G
EeL305YJFP<0L71`0P2:RXX30;Rh^080c/k>0`2FUYH303<c<`809bLW1@0Z:RX802/[:`<0;Bd]0P0`
<303038b<PD0<c<c0`0b<S8203@d=0<0=cLg0P0j>SX303dm?@<0?Shn0P12@T830451@@80?Shn0`0i
>CT303@d=080<C4a0`0_;bl202TY:@<0:b/[0`0M7Ad204e=C@<0O7al0P1/K6`3071`L0<0JFUY0P1O
Gel305UIF@80H61P0`1ZJVX206i^KPP0LG5a0`1hN7P507inOP<0O7al0P1mOGd307inOP80Ogmo0`20
P80307moO`D0OWin0P20P80308>3P`<0QXJ60P24Q8@308>3P`80QhN70`2;Rh/:08b<S0H0SXj>0P2=
SHd308^;R`80RXZ:0`29RHT208^;R`<0S8b<0`2>SXh508n?S`80T92@0`2CTi<309NGU`80VIVI0`2J
VYX209VIV@<0V9RH0`2IVIT209ZJVP<0V9RH0P2FUYH309NGU`<0VIVI1@2JVYX209^KV`<0W9bL0`2K
Vi/209ZJVP<0VIVI0P2HV9P309JFUP<0UIFE0P2FUYH309RHV080UYJF0`2DU9@809>CT`80U9BD0`2B
TY82092@T0<0Ti>C0`2GUiL209VIV@<0WIfM0P2YZJT30;Jf]P<0aLG50P3?cll30<S8b0D0_kno=038
h=P305aLG080JVYZ0`1IFET205YJFP<0HV9R0`1UIFD208Z:RP<0`l?30P37alL3096AT@<0=cLg0P0/
;2`3034a<@809RHV0`0/;2`2038b<P<0:2PX0`0d=3@2034a<@<0;Rh^0P0a<C4303<c<`<0;Rh^0P0]
;Bd3034a<@80=cLg0`0a<C430451@@80?Cdm0`0l?3`203/k>`<0;Rh^0`0b<S8202l_;`<0;2`/0P0[
:b/302PX:0<09RHV0P1:BTX3071`L080Kfm_0`1^KVh506IVIP<0E5AD0P1QHF4506a/K0H0LG5a0P1`
L70307IfMP80Ogmo0`1jNWX307UiN@80PX:20`1jNWX207emO@<0OWin0`1mOGd207inOP<0NGUi0P1n
OWh308>3P`<0Q8B40P25QHD308:2PP80QHF50`2<S8`508V9R@<0TI6A0P29RHT308f=S@<0SXj>0P2?
Shl308^;R`80R8R80`2:RXX208b<S0<0SXj>0`2<S8`208n?S`<0TI6A0P2?Shl309BDU0<0UYJF0P2G
UiL309VIV@80V9RH1P2GUiL209^KV`<0VYZJ0P2FUYH309BDU0<0V9RH0P2MWId309VIV@80W9bL0`2K
Vi/309bLW080Vi^K1@2GUiL309BDU0<0TY:B0P2JVYX309RHV080UIFE0`2CTi<209:BTPP0U9BD0`2A
TI42092@T0<0U9BD0`2GUiL209JFUP<0W9bL0P2YZJT30;Jf]P<0a/K60P3=cLd30<[:bP80`L710`2g
]kLL0<SPf0006`38h=P306EUI@80H61P0`1KFe/205MGE`<0FUYJ0`1`L70208Z:RP<0^;Rh0P3>c/h3
09JFUP<0<c<c0P0W9bL502XZ:PP0:b/[0`0];Bd2030`<0<0<S8b1@0c<c<3038b<P80=3@d0`0g=cL2
03Xj>P<0?Cdm0`0n?Sh20492@P<0@D510P0n?Sh303Ti>@<0=3@d0P0a<C4302l_;`80:BTY0`0[:b/3
01dM7@80CDe=0`1lO7`206a/K0<0L71`0`1YJFT205mOG`<0FEUI0P1PH60306YZJP80KVi^201aLG43
07QhN0D0OWin0`1lO7`207emO@<0OWin0P1oOgl30820P0<0Ogmo1@1nOWh20820P0<0Ph>30`26QXH2
08B4Q0<0Ph>30P27QhL308^;R`X0S8b<1P2>SXh208f=S@<0Rh^;0P2:RXX308V9R@80Rh^;0`2<S8`3
08j>SPD0Shn?0P2@T90309>CT`<0UiNG0P2IVIT309ZJVP80VIVI0`2HV9P309VIV@80VYZJ0`2HV9P2
09JFUP<0UiNG0`2IVIT509ZJVP80Vi^K0`2LW9`309^KV`80VYZJ0`2IVIT209RHV0<0UYJF0`2EUID2
09JFUP<0V9RH0P2FUYH309BDU0P0Ti>C0P2DU9@309:BTP80T92@0`2CTi<309NGU`80VIVI0`2MWId2
0:VYZ@<0][Jf0`35aLD20<o?c`<0b<S81@2o_kld0<SPf0<0G5aL0P1ZJVX305UIF@80FUYJ0`1RHV83
06EUI@80RXZ:0`33`l<20<O7a`<0TI6A0`0g=cL202`/;0<0<C4a0P0V9RH302`/;080<S8b0`0X:2P3
03@d=080<C4a0`0^;Rh2034a<@<0<c<c0`0^;Rh202d];@<0<C4a0P0g=cL3034a<@<0@D510P0m?Cd3
03`l?080>c/k0`0^;Rh3038b<P80;bl_0`0/;2`202/[:`<0:2PX0`0V9RH204Y:BP<0L71`0P1_Kfl3
06i^KPD0IVIV0`1DE5@2065QH@D0K6a/1P1aLG42071`L0<0MWIf0P1oOgl307YjNP<0NGUi0P22PX83
07YjNP80OGem0`1nOWh307emO@80OWin0`1iNGT207inOP<0Ph>30`24Q8@208F5Q@<0PX:20P25QHD3
08b<S0D0RHV90`2ATI4208V9R@<0SHf=0`2>SXh208n?S`<0Rh^;0P28R8P308Z:RP80S8b<0`2>SXh3
08b<S080Shn?0`2ATI4208n?S`<0U9BD0`2FUYH209NGU`<0VIVI0P2HV9P609NGU`80Vi^K0`2JVYX2
09JFUP<0U9BD0`2HV9P209fMW@<0VIVI0P2LW9`309^KV`<0W9bL0P2KVi/509NGU`<0U9BD0`2BTY82
09ZJVP<0V9RH0P2EUID309>CT`80TY:B202DU9@3096AT@80T92@0`2DU9@309NGU`80UYJF0`2LW9`2
0:VYZ@<0][Jf0`36a/H20<g=c@<0b/[:0P31`L430;Ng]a`0b>3H000K0<SPf0<0EeMG0P1NGUh3061P
H080F5QH0`1KFe/307=cL`80T92@0`2WYjL20=CDe0<0^;Rh0`1nOWh204M7A`<09bLW0P0Y:BT3034a
<@80<30`0`0_;bl303<c<`D0=cLg0P0f=SH603@d=080=CDe0`0h>3P203/k>`<0?Shn0`0m?Cd203lo
?`<0?Cdm0P0j>SX303Hf=P<0<c<c0P0];Bd302`/;080>CTi0`1;Bd/3038b<P80EeMG1@1aLG4306AT
I0<0KFe]0P1NGUh305UIF@80GemO0`1XJ6P206e]K@<0L71`0`1bLW8207AdM0<0NGUi0P1mOGd607in
OPD0OGem0P20P80308:2PP<0PH610P1oOgl30820P080PH610`23Ph<308F5Q@80QXJ60`27QhL208V9
R@<0S8b<402=SHd208b<S0<0Rh^;0P2<S8`308f=S@D0SXj>0`2?Shl2096AT@<0TY:B0P2DU9@309NG
U`<0VIVI0P2JVYX809VIV@D0VYZJ1@2IVIT309ZJVP<0W9bL1`2MWId609bLW080Vi^K0`2IVIT209NG
U`<0UYJF0`2GUiL209RHV0<0VIVI0P2GUiL;09BDU080Ti>C0`2ATI42092@T0<0TI6A0`2DU9@209NG
U`<0WIfM0P2VYZH30;6a/@<0_kno0P3:b/X30<K6aP80`L710`2_[jld0<SPf0<0CTi>0P1YJFT305EE
E@80DE5A0`1JFUX306UYJ@80U9BD0`2c/k<20<O7a`<0aLG50`1nOWh203Ti>@<09bLW0P0U9BD302`/
;080:b/[0`0Z:RX3034a<@80<S8b1@0h>3P303/k>`<0>CTi0P10@40303hn?P80@d=30`12@T8304a<
C080@D511@12@T8303`l?0D0>SXj0`0_;bl203Ti>@H0>SXj0P1LG5`3079bLP80M7Ad0`1WIfL3071`
L080HV9R0`1MGEd206=SH`D0Jf][0`1_Kfl3079bLP80N7Qh0`1kNg/20820P0H0Ogmo0P1mOGd307mo
O`80PX:20`25QHD308B4Q0D0Ph>30P26QXH30861P@<0QHF51@28R8P208Z:RP<0Shn?0`2:RXX208n?
S`<0TI6A0P2:RXX308^;R`<0RXZ:1@2<S8`208^;R`<0SXj>0P2=SHd308b<S0D0T92@0`2EUID2092@
T0H0VIVI1`2JVYX309bLW0D0VIVI0`2KVi/509RHV0<0Vi^K0P2OWil309jNWP80W9bL0`2OWil309fM
W@D0Vi^K0P2HV9P609NGU`80VYZJ0`2HV9P209FEU@<0UiNG0P2EUID309:BTP<0U9BD0P2CTi<3096A
T@D0SXj>0`2EUID209RHV0<0WinO0P2SXj<30;6a/@<0_kno0P39bLT30<S8b080`<300`2`/;0L0<SP
f0006`38h=P305MGE`80GUiN0`1PH60205QHF0<0Fe]K0`1cLg<2092@T0<0YjNW0P3De=@30;Rh^0<0
OWin0P17AdL302LW9`80:BTY0`0a<C42030`<0<0;bl_0`0c<c<503Lg=`80=SHf1P0d=3@203De=@<0
>3Ph0P0k>c/303hn?P<0?Cdm0P0o?cl303dm?@80>SXj0`0f=SH303<c<`80;Bd]0`0/;2`203Ti>@<0
Bd];0`0b<S8205MGE`D0LG5a0`1TI6@306e]K@80GUiN0`1IFET205mOG`<0J6QX0P1]KFd3071`L0<0
LW9b0P1dM7@307UiN@80OGem1P1nOWh507emO@80P8200`22PX830861P@80Ogmo0`20P8020861P@<0
Ph>30`25QHD208J6QP<0QhN70P29RHT308b<S100SHf=0P2<S8`308^;R`80S8b<0`2=SHd508j>SP<0
Shn?0P2ATI4309:BTP80U9BD0`2GUiL309VIV@80VYZJ202IVIT509ZJVPD0VIVI0`2JVYX309bLW0L0
WIfM1P2LW9`209^KV`<0VIVI0P2GUiL309JFUP<0UiNG0P2HV9P309VIV@80UiNG2`2DU9@209>CT`<0
TI6A0P2@T903096AT@<0U9BD0P2GUiL309fMW@80YZJV0`2a/K430;no_`80b/[:0`36a/H20<71`@<0
[jn_=038h=P304i>CP80JFUY0`1EEED2055AD@<0FUYJ0`1YJFT209BDU0<0/k>c0P37alL30<G5a@<0
OWin0P0i>CT302LW9`809BDU0`0/;2`202/[:`<0:RXZ0`0a<C42038b<PD0>3Ph0`0k>c/303Ti>@80
@4100`0n?Sh204=3@`<0@T920`1<C4`20451@@D0@T920`0l?3`503Xj>P<0;bl_0P0i>CT603Xj>P80
G5aL0`1bLW8207AdM0<0IfMW0`1`L702069RHP<0GEeM0P1SHf<506][J`<0Kfm_0`1bLW8207QhN0<0
Ng]k0P20P80607moO`80OGem0`1oOgl208:2PP<0QHF50`24Q8@508>3P`80QXJ60`21PH4308F5Q@D0
R8R80P2:RXX308n?S`<0RXZ:0P2?Shl3096AT@80RXZ:0`2;Rh/308Z:RPD0S8b<0P2;Rh/308j>SP80
SHf=0`2<S8`5092@T0<0UIFE0P2@T90609VIV@L0VYZJ0`2LW9`509VIV@<0Vi^K1@2HV9P309^KV`80
WinO0`2NWYh209bLW0<0WinO0`2MWId509^KV`80V9RH1P2GUiL209ZJVP<0V9RH0P2EUID309NGU`80
UIFE0`2BTY8309BDU080Ti>C0`2ATI4508j>SP<0UIFE0P2HV9P309nOW`80Xj>S0`2a/K430;no_`80
bLW90`38b<P20<30`0<0/;2`7038h=P001/0b>3H0`1GEeL205iNGP<0H61P0P1HF5P305]KF`<0Lg=c
0P2@T9030:NWY`80e=CD0`2h^;P307inOP80AdM70`0W9bL202TY:@<0<C4a0P0`<30302l_;`<0<c<c
1@0g=cL203Hf=PH0=3@d0P0e=CD303Ph>080>c/k0`0n?Sh303dm?@80?clo0`0m?Cd203Xj>P<0=SHf
0`0c<c<202d];@<0;2`/0P0i>CT304];B`<0<S8b0P1GEeL5075aL@<0I6AT0`1]KFd205iNGP<0FEUI
0P1OGel306QXJ080KFe]0`1`L703079bLP80M7Ad0`1iNGT207emO@H0OWin1@1mOGd20820P0<0PX:2
0`21PH4207moO`<0P8200P21PH4308>3P`<0QHF50P26QXH308N7Q`80RHV90`2<S8`@08f=S@80S8b<
0`2;Rh/208b<S0<0SHf=1@2>SXh308n?S`80TI6A0`2BTY8209BDU0<0UiNG0`2IVIT209ZJVPP0VIVI
1@2JVYX509VIV@<0VYZJ0`2LW9`709fMW@H0W9bL0P2KVi/309VIV@80UiNG0`2FUYH309NGU`80V9RH
0`2IVIT209NGU`/0U9BD0P2CTi<3096AT@80T92@0`2ATI4309BDU080UiNG0`2MWId20:JVYP<0/K6a
0`2o_kl20<[:bP<0a/K60P31`L430:n_[c@0b>3H0`1>CTh206UYJ@<0EEEE0P1ADE4305YJFP<0JFUY
0P2DU9@30;>c/`80alO70`35aLD307inOP80>CTi0`0W9bL202DU9@<0;2`/0P0[:b/302XZ:P<0<C4a
0P0b<S8503Ph>0<0>c/k0`0i>CT20410@0<0?Shn0P13@d<30492@P<0C4a<0P11@D450492@P<0?3`l
1@0j>SX302l_;`80>CTi1P0j>SX205aLG0<0LW9b0P1dM7@306MWI`<0L71`0P1RHV8305eMG@80Hf=S
1@1[Jf/306m_K`<0LW9b0P1hN7P307]kN`80P8201P1oOgl207emO@<0Ogmo0P22PX8308F5Q@<0Q8B4
1@23Ph<208J6QP<0PH610`25QHD508R8R080RXZ:0`2?Shl308Z:RP80Shn?0`2ATI4208Z:RP<0Rh^;
0`2:RXX508b<S080Rh^;0`2>SXh208f=S@<0S8b<1@2@T90309FEU@80T92@1P2IVIT709ZJVP<0W9bL
1@2IVIT309^KV`D0V9RH0`2KVi/209nOW`<0WYjN0P2LW9`309nOW`<0WIfM1@2KVi/209RHV0H0UiNG
0P2JVYX309RHV080UIFE0`2GUiL209FEU@<0TY:B0`2DU9@209>CT`<0TI6A1@2>SXh309FEU@80V9RH
0`2OWil20:>SX`<0/K6a0`2o_kl20<W9b@<0b<S80P30`<030;2`/1`0b>3H000K0<SPf0<0D51@0P1K
Fe/306EUI@80GEeM0`1NGUh307MgM`80VIVI0`2BTY820<C4a0<0c/k>0`38b<P206e]K@<0<c<c0P0]
;Bd303Hf=PD0=3@d0`0h>3P203dm?@<0>c/k0P0g=cL303Hf=P<0=CDe0P0f=SH303Ti>@80?3`l0`0n
?Sh303dm?@80>c/k0`0h>3P203De=@<0<c<c0`0b<S8202l_;`<0;Bd]0P0W9bL302`/;0<0:BTY0P1S
Hf<306][J`80MWIf0`1FEUH306m_K`80H61P0`1GEeL205aLG0<0IVIV0P1[Jf/306m_K`<0Lg=c0P1g
MgL307UiN@80Ng]k0`1mOGd307moO`80OWin0`1mOGd20820P0H0PX:20P21PH4808:2PP<0Ph>30P27
QhL508^;R`H0S8b<1`2=SHd;08b<S080Shn?0`2BTY82096AT@<0T92@0`2ATI4209:BTP<0UIFE0P2G
UiL309VIV@D0VYZJ0`2IVIT:09ZJVPD0Vi^K0`2MWId809nOW`80WYjN202MWId309ZJVPD0UiNG0`2H
V9P509VIV@80UiNG1@2EUID309JFUP<0U9BD0P2BTY85096AT@H0T92@0P2EUID309fMW@80Xj>S0`2[
Zj/30;Vi^@80a<C40`32`/820<71`@<0X:2P=038h=P3055AD@80H61P0`1SHf<205UIF@<0HV9R0`1f
MWH209>CT`<0W9bL0P31`L430<_;b`<0`l?30P1dM7@303Ph>080=CDe0`0g=cL503Hf=P<0@D510P10
@40303hn?PD0=cLg0`0c<c<203Ph>0<0>SXj0P0d=3@303dm?@<0?clo0P0h>3P303Hf=P80=3@d0`0/
;2`302h^;P80<S8b0`0W9bL202d];@<0;2`/0`0b<S8205YJFP<0Kfm_0P1`L70305eMG@<0KVi^1@1F
EUH2061PH0<0I6AT0P1ZJVX3071`L0<0M7Ad0P1fMWH307QhN080Ng]k0`1hN7P307emO@80PX:20`1j
NWX50820P0<0OWin0P1oOgl308:2PP80P8200`24Q8@308>3P`80Q8B40`28R8P208f=S@<0Rh^;0`29
RHT208f=S@<0Shn?0P2:RXX308j>SP<0SHf=0P2:RXX308b<S080Shn?0`2CTi<208n?S`H0TI6A0P2C
Ti<309NGU`80UYJF0`2KVi/309NGU`80WIfM0`2GUiL809VIV@D0VYZJ0P2LW9`309^KV`<0WinO0P2L
W9`30:2PX0D0WIfM0`2LW9`209fMW@<0VYZJ0P2FUYH309BDU0<0VYZJ0P2HV9P309VIV@80UiNG0`2F
UYH209BDU0<0UYJF0`2GUiL509:BTPD0TI6A0`2?Shl209FEU@<0WYjN0P2QXJ430:b/[0<0^[Zj0P32
`/830<G5a@80^k^k0`2XZ:PL0<SPf0006`38h=P3051@D080Fe]K0`1UIFD205eMG@<0GUiN0`1gMgL2
09VIV@<0TY:B0P34a<@30<k>cP<0b<S80P1]KFd303<c<`80;Bd]0`0f=SH503@d=0<0>3Ph0P0m?Cd3
03/k>`80=cLg0`0f=SH303De=@80=SHf0`0i>CT203`l?0<0?Shn0`0m?Cd203/k>`<0>3Ph0P0e=CD3
03<c<`<0<S8b0P0_;bl302d];@809bLW0`0/;2`302TY:@80Hf=S0`1[Jf/207IfMP<0EUIF0`1_Kfl2
061PH0<0EeMG0P1LG5`306IVIP80Jf][0`1_Kfl307=cL`80MgMg0`1iNGT207]kN`<0OGem0`1oOgl2
07inOP<0OGem0P20P80608:2PP80PH612022PX8308>3P`80QhN71@2;Rh/608b<S0L0SHf=2`2<S8`2
08n?S`<0TY:B0P2ATI43092@T0<0TI6A0P2BTY8309FEU@80UiNG0`2IVIT509ZJVP<0VIVI2P2JVYX5
09^KV`<0WIfM202OWil209jNWPP0WIfM0`2JVYX509NGU`<0V9RH1@2IVIT209NGU`D0UIFE0`2FUYH3
09BDU080TY:B1@2ATI46092@T080UIFE0`2MWId20:>SX`<0Zj^[0`2i^KT20<C4a0<0`/;20P31`L43
0:2PX3@0b>3H0`1ADE42061PH0<0Hf=S0P1IFET3069RHP<0MWIf0P2CTi<309bLW080`L710`3;bl/3
0<?3``80M7Ad0`0h>3P203De=@<0=cLg1@0f=SH30451@@80@4100`0n?Sh503Lg=`<0<c<c0P0h>3P3
03Xj>P80=3@d0`0m?Cd303lo?`80>3Ph0`0f=SH203@d=0<0;2`/0`0^;Rh2038b<P<09bLW0P0];Bd3
02`/;0<0<S8b0P1JFUX306m_K`80L71`0`1MGEd306i^KPD0EUIF0P1PH60306ATI080JVYZ0`1`L703
07AdM080MWIf0`1hN7P207]kN`<0N7Qh0`1mOGd208:2PP<0NWYj1@20P80307inOP80Ogmo0`22PX82
0820P0<0Q8B40`23Ph<208B4Q0<0R8R80P2=SHd308^;R`<0RHV90P2=SHd308n?S`80RXZ:0`2>SXh3
08f=S@80RXZ:0`2<S8`208n?S`<0Ti>C0P2?Shl6096AT@80Ti>C0`2GUiL209JFUP<0Vi^K0`2GUiL2
09fMW@<0UiNG202IVIT509ZJVP80W9bL0`2KVi/309nOW`80W9bL0`2PX:0509fMW@<0W9bL0P2MWId3
09ZJVP80UYJF0`2DU9@309ZJVP80V9RH0`2IVIT209NGU`<0UYJF0P2DU9@309JFUP<0UiNG1@2BTY85
096AT@<0Shn?0P2EUID309jNWP80XJ6Q0`2/[:`30;Zj^P80`/;20`35aLD20;^k^`<0Z:RX7038h=P0
01/0b>3H0`1cLg<205QHF0<0HF5Q0P1^KVh305aLG0<0L71`1@29RHT20:RXZ0<0`L710`38b<P20<G5
a@<0E5AD0P0[:b/3030`<080;bl_0`0b<S8303Hf=P80>CTi0`0h>3P803De=@80=SHf0`0h>3P203`l
?0<0?Shn0`0l?3`203Ti>@<0=cLg0P0f=SH303@d=0<0<c<c0P0`<30302l_;`80;2`/0`0c<c<302d]
;@80I6AT0`1_Kfl207alO0<0EUIF0`1ZJVX205aLG0<0EEEE0P1KFe/306EUI@80JVYZ0`1^KVh307=c
L`80MWIf0`1iNGT207YjNP<0O7al0`1nOWh507emO@80OWin0`20P80307inOP80OGem0`20P80508>3
P`<0PX:20P25QHD308R8R080RHV90`2:RXX308^;R`L0S8b<0`2=SHd508n?S`<0SXj>0P2?Shl3092@
T0P0TI6A1@2BTY8209BDU0<0UiNG2P2JVYX809^KV`<0W9bL0P2NWYh309nOW`<0XJ6Q0P2OWil509fM
W@P0WYjN0`2KVi/209VIV@<0VYZJ0`2KVi/209ZJVP<0UiNG0P2FUYH809FEU@<0U9BD0P2BTY83092@
T080SXj>0`2=SHd308j>SP80TI6A0`2FUYH209bLW0<0Y:BT0`2b/[820;jn_P<0^[Zj0P2e]KD30:>S
Xc@0b>3H0`1UIFD205QHF0<0Kfm_0P1ZJVX306=SH`<0M7Ad0P27QhL308V9R@80Y:BT0`32`/830=3@
d080^[Zj0`1;Bd/202l_;`<0;Rh^200`<30503@d=0D0<C4a0`0];Bd203De=@<0=3@d0P0c<c<30451
@@<0=SHf0P0h>3P503Hf=PH0<S8b0P0_;bl502`/;0<0<30`0`0d=3@205aLG0D0Lg=c0`1OGel306UY
J@80EEEE0`1DE5@206ATI0<0HF5Q0P1YJFT3075aL@<0L71`0P1fMWH307MgM`80Ng]k0`1mOGd307mo
O`80P8200`1jNWX207moO`<0P8200`1oOgl207alO0<0PH610P1oOgl308B4Q0<0PX:20P24Q8@508^;
R`<0RHV90`2;Rh/208V9R@<0SHf=0P2?Shl308f=S@<0T92@1@2?Shl2096AT@<0SXj>0P2CTi<309BD
U0<0SHf=0P2?Shl3096AT@80Ti>C0`2HV9P309VIV@80Vi^K0`2GUiL209jNWP<0VIVI0`2LW9`209fM
W@D0WYjN0`2QXJ430:BTY080WinO202MWId309bLW080WYjN0`2KVi/209ZJVP<0V9RH0`2JVYX509VI
V@80UYJF0`2CTi<2096AT@<0UYJF1@2ATI4508n?S`H0SHf=1@2DU9@209VIV@<0YJFU0`2c/k<20;Zj
^P<0_kno0P2a/K430:6QXA`0b>3H000K0<SPf0<0Lg=c0P1HF5P3065QH@80KVi^0`1LG5`3071`L0D0
RHV90P2XZ:P30<71`@<0b<S80P35aLD305ADE080:b/[0`0`<30202l_;`<0<S8b0`0f=SH203Ti>@<0
>3Ph200e=CD203Hf=P<0>3Ph0P0l?3`303hn?P<0?3`l0P0i>CT303Lg=`80=SHf0`0d=3@303<c<`80
<30`0`0_;bl202`/;0<0<c<c0`0];Bd206ATI0<0Kfm_0P1lO7`305IFEP<0JVYZ0P1LG5`305EEE@80
Fe]K0`1UIFD206YZJP<0KVi^0`1cLg<207IfMP<0NGUi0P1jNWX307alO0<0OWin1@1mOGd207inOP<0
P8200`1nOWh207emO@<0P8201@23Ph<308:2PP80QHF50`28R8P208V9R@<0RXZ:0`2;Rh/708b<S0<0
SHf=1@2?Shl308j>SP80Shn?0`2@T908096AT@D0TY:B0P2DU9@309NGU`X0VYZJ202KVi/309bLW080
WYjN0`2OWil30:6QX@80WinO1@2MWId809jNWP<0Vi^K0P2IVIT309ZJVP<0Vi^K0P2JVYX309NGU`80
UYJF202EUID309BDU080TY:B0`2@T90208j>SP<0SHf=0`2>SXh2096AT@<0UYJF0P2LW9`30:BTY0<0
/[:b0P2n_[h30;Zj^P80]KFe0`2SXj<d0<SPf0<0IFEU0P1HF5P306m_K`80JVYZ0`1SHf<307AdM080
QhN70`29RHT20:BTY0<0`/;20`3@d=020;Zj^P<0Bd];0P0_;bl302h^;PP0<30`1@0d=3@5034a<@<0
;Bd]0P0e=CD303@d=080<c<c0`11@D4303Hf=P80>3Ph1@0f=SH6038b<P80;bl_1@0/;2`3030`<0<0
=3@d0P1LG5`507=cL`<0GemO0`1YJFT205EEE@<0E5AD0P1TI6@3065QH@80JFUY0`1aLG43071`L080
MWIf0`1gMgL207]kN`<0OGem0`1oOgl20820P0<0NWYj0P1oOgl30820P0<0Ogmo0P1lO7`30861P@80
Ogmo0`24Q8@308:2PP80Q8B41@2;Rh/308V9R@<0Rh^;0P29RHT308f=S@80Shn?0`2=SHd3092@T0D0
Shn?0P2ATI4308j>SP80Ti>C0`2DU9@308f=S@80Shn?0`2ATI4209>CT`<0V9RH0`2IVIT209^KV`<0
UiNG0P2NWYh309VIV@<0W9bL0P2MWId509jNWP<0XJ6Q0`2TY:@209nOW`P0WIfM0`2LW9`209jNWP<0
Vi^K0P2JVYX309RHV0<0VYZJ1@2IVIT209JFUP<0Ti>C0P2ATI4309JFUPD0TI6A1@2?Shl608f=S@D0
U9BD0P2IVIT30:FUY@<0/k>c0P2j^[X30;no_`80/K6a0`2QXJ4L0<SPf0006`38h=P307=cL`80F5QH
0`1QHF4206i^KP<0G5aL0`1`L70508V9R@80Z:RX0`31`L430<S8b080aLG50`1DE5@202/[:`<0<30`
0P0_;bl3038b<P<0=SHf0P0i>CT303Ph>0P0=CDe0P0f=SH303Ph>080?3`l0`0n?Sh303`l?080>CTi
0`0g=cL203Hf=P<0=3@d0`0c<c<2030`<0<0;bl_0P0/;2`303<c<`<0;Bd]0P1TI6@306m_K`80O7al
0`1FEUH306YZJP80G5aL0`1EEED205]KF`<0IFEU0P1ZJVX306i^KP<0Lg=c0P1fMWH307UiN@80NWYj
0`1lO7`307inOPD0OGem0P1nOWh30820P0<0OWin0P1mOGd30820P0D0Ph>30`22PX8208F5Q@<0R8R8
0P29RHT308Z:RP<0Rh^;1`2<S8`308f=S@D0Shn?0`2>SXh208n?S`<0T92@202ATI4509:BTP80U9BD
0`2GUiL:09ZJVPP0Vi^K0`2LW9`209jNWP<0WinO0`2QXJ4209nOW`D0WIfM202NWYh309^KV`80VIVI
0`2JVYX309^KV`80VYZJ0`2GUiL209JFUPP0UIFE0`2DU9@209:BTP<0T92@0P2>SXh308f=S@<0SXj>
0P2ATI4309JFUP80W9bL0`2TY:@30;:b/P80_[jn0`2j^[X20;Fe]@<0Xj>S=038h=P306EUI@80F5QH
0`1_Kfl206YZJP<0Hf=S0`1dM7@208N7Q`<0RHV90P2TY:@30<;2`P<0d=3@0P2j^[X304];B`80;bl_
0`0^;Rh8030`<0D0=3@d1@0a<C4302d];@80=CDe0`0d=3@203<c<`<0@D510`0f=SH203Ph>0D0=SHf
1P0b<S8202l_;`D0;2`/0`0`<30303@d=080G5aL1@1cLg<305mOG`<0JFUY0P1EEED305ADE080I6AT
0`1QHF4206UYJ@<0LG5a0`1`L70207IfMP<0MgMg0P1kNg/307emO@<0Ogmo0P20P80307YjNP80Ogmo
0`20P80307moO`80O7al0`21PH4207moO`<0Q8B40`22PX8208B4Q0D0Rh^;0`29RHT308^;R`80RHV9
0`2=SHd208n?S`<0SHf=0`2@T90508n?S`80TI6A0`2>SXh209>CT`<0U9BD0`2=SHd208n?S`<0TI6A
0P2CTi<309RHV0<0VIVI0P2KVi/309NGU`80WYjN0`2IVIT309bLW080WIfM1@2NWYh30:6QX@<0Y:BT
0P2OWil809fMW@<0W9bL0P2NWYh309^KV`80VYZJ0`2HV9P309ZJVPD0VIVI0P2FUYH309>CT`80TI6A
0`2FUYH5096AT@D0Shn?1P2=SHd509BDU080VIVI0`2UYJD30;>c/`80^[Zj0`2o_kl20;6a/@<0XJ6Q
7038h=P001/0b>3H0`2IVIT205eMG@<0GemO0P1iNGT305aLG0<0JFUY0P1eMGD307emO@80QhN70`2a
/K430=3@d080clo?0`2KVi/203lo?`<0;2`/0P0V9RH302l_;`<0<C4a0P0d=3@303<c<`80<C4a0`0b
<S8303@d=080=SHf0`0h>3P203/k>`<0?Shn0`0k>c/203Lg=`D0=SHf0`0e=CD303@d=080<C4a0`0_
;bl202h^;P<0=SHf0`0_;bl206ATI0<0M7Ad0P21PH4305UIF@<0IFEU0P1HF5P305=CD`80FUYJ0`1U
IFD206YZJP<0KVi^0`1bLW8207EeM@<0N7Qh0P1jNWX307]kN`P0O7al1@1mOGd307]kN`80NGUi0`1n
OWh508>3P`<0PH610P22PX8308B4Q080QXJ60`28R8P308V9R@80RXZ:0`2;Rh/208b<S0<0Shn?1@2A
TI43092@T0L0Shn?202ATI45092@T0<0U9BD0`2IVIT209ZJVP/0Vi^K0P2LW9`309fMW@80WinO0`2P
X:030:6QX@80WYjN0`2LW9`209fMW@P0WYjN0`2LW9`209^KV`<0W9bL0`2MWId209ZJVP<0UYJF1@2E
UID209BDU0H0Ti>C0P2BTY8308j>SP80Rh^;0`2:RXX308^;R`80S8b<0`2>SXh209>CT`<0Vi^K0`2Y
ZJT20;Bd]0<0[Zj^1@2UYJDd0<SPf0<0WYjN0P1KFe/306=SH`80L71`0`1OGel306YZJP80MgMg0`1m
OGd208Z:RP<0Zj^[0`3?cll20=CDe0<0XJ6Q0P0j>SX3038b<P80;Rh^0`0];Bd303@d=080>3Ph0`0f
=SH203De=@<0<S8b0`0j>SX203Ti>@<0?Shn0P10@40303hn?P<0>SXj0P0h>3P303<c<`80>CTi0`0d
=3@303De=@80<C4a0`0_;bl5034a<@<0>3Ph0P1PH60307MgM`80PH610`1NGUh306MWI`80DE5A0`1D
E5@205aLG0<0IFEU1@1]KFd3079bLP80MGEe0`1hN7P807UiN@80Ng]k0`1mOGd207alO0<0OGem0`1k
Ng/207QhN0<0OGem0P22PX8308J6QPD0PX:20`26QXH208F5Q@<0QXJ60`2>SXh208Z:RP<0S8b<0P2:
RXX308f=S@<0Ti>C0P2>SXh3092@T080SXj>0`2?Shl208j>SP<0TI6A0`2?Shl2096AT@<0UIFE0P2>
SXh309BDU0<0V9RH0P2JVYX309^KV`D0VYZJ0`2LW9`209ZJVP<0WinO0P2NWYh309fMW@<0WYjN0P2R
XZ8309^KV`80WIfM0`2NWYh309fMW@80WYjN0`2LW9`509^KV`<0X:2P1@2FUYH209RHV0P0UYJF0`2@
T90209FEU@<0Shn?0P2:RXX308f=S@<0RXZ:0P2;Rh/308f=S@80TI6A0`2MWId30:BTY080/[:b0`2f
][H20:FUY@<0VYZJ7038h=P001/0b>3H0`2IVIT205eMG@<0GemO0P1iNGT305aLG0<0JFUY0P1eMGD3
07emO@80QhN70`2a/K430=3@d080clo?0`2KVi/203lo?`<0;2`/0P0V9RH302l_;`<0<C4a0P0d=3@3
03<c<`80<C4a0`0b<S8303@d=080=SHf0`0h>3P203/k>`<0?Shn0`0k>c/203Lg=`D0=SHf0`0e=CD3
03@d=080<C4a0`0_;bl202h^;P<0=SHf0`0_;bl206ATI0<0M7Ad0P21PH4305UIF@<0IFEU0P1HF5P3
05=CD`80FUYJ0`1UIFD206YZJP<0KVi^0`1bLW8207EeM@<0N7Qh0P1jNWX307]kN`P0O7al1@1mOGd3
07]kN`80NGUi0`1nOWh508>3P`<0PH610P22PX8308B4Q080QXJ60`28R8P308V9R@80RXZ:0`2;Rh/2
08b<S0<0Shn?1@2ATI43092@T0L0Shn?202ATI45092@T0<0U9BD0`2IVIT209ZJVP/0Vi^K0P2LW9`3
09fMW@80WinO0`2PX:030:6QX@80WYjN0`2LW9`209fMW@P0WYjN0`2LW9`209^KV`<0W9bL0`2MWId2
09ZJVP<0UYJF1@2EUID209BDU0H0Ti>C0P2BTY8308j>SP80Rh^;0`2:RXX308^;R`80S8b<0`2>SXh2
09>CT`<0Vi^K0`2YZJT20;Bd]0<0[Zj^1@2UYJDd0<SPf0<0WYjN0P1KFe/306=SH`80L71`0`1OGel3
06YZJP80MgMg0`1mOGd208Z:RP<0Zj^[0`3?cll20=CDe0<0XJ6Q0P0j>SX3038b<P80;Rh^0`0];Bd3
03@d=080>3Ph0`0f=SH203De=@<0<S8b0`0j>SX203Ti>@<0?Shn0P10@40303hn?P<0>SXj0P0h>3P3
03<c<`80>CTi0`0d=3@303De=@80<C4a0`0_;bl5034a<@<0>3Ph0P1PH60307MgM`80PH610`1NGUh3
06MWI`80DE5A0`1DE5@205aLG0<0IFEU1@1]KFd3079bLP80MGEe0`1hN7P807UiN@80Ng]k0`1mOGd2
07alO0<0OGem0`1kNg/207QhN0<0OGem0P22PX8308J6QPD0PX:20`26QXH208F5Q@<0QXJ60`2>SXh2
08Z:RP<0S8b<0P2:RXX308f=S@<0Ti>C0P2>SXh3092@T080SXj>0`2?Shl208j>SP<0TI6A0`2?Shl2
096AT@<0UIFE0P2>SXh309BDU0<0V9RH0P2JVYX309^KV`D0VYZJ0`2LW9`209ZJVP<0WinO0P2NWYh3
09fMW@<0WYjN0P2RXZ8309^KV`80WIfM0`2NWYh309fMW@80WYjN0`2LW9`509^KV`<0X:2P1@2FUYH2
09RHV0P0UYJF0`2@T90209FEU@<0Shn?0P2:RXX308f=S@<0RXZ:0P2;Rh/308f=S@80TI6A0`2MWId3
0:BTY080/[:b0`2f][H20:FUY@<0VYZJ7038h=P001/0b>3H0`2IVIT205eMG@<0GemO0P1iNGT305aL
G0<0JFUY0P1eMGD307emO@80QhN70`2a/K430=3@d080clo?0`2KVi/203lo?`<0;2`/0P0V9RH302l_
;`<0<C4a0P0d=3@303<c<`80<C4a0`0b<S8303@d=080=SHf0`0h>3P203/k>`<0?Shn0`0k>c/203Lg
=`D0=SHf0`0e=CD303@d=080<C4a0`0_;bl202h^;P<0=SHf0`0_;bl206ATI0<0M7Ad0P21PH4305UI
F@<0IFEU0P1HF5P305=CD`80FUYJ0`1UIFD206YZJP<0KVi^0`1bLW8207EeM@<0N7Qh0P1jNWX307]k
N`P0O7al1@1mOGd307]kN`80NGUi0`1nOWh508>3P`<0PH610P22PX8308B4Q080QXJ60`28R8P308V9
R@80RXZ:0`2;Rh/208b<S0<0Shn?1@2ATI43092@T0L0Shn?202ATI45092@T0<0U9BD0`2IVIT209ZJ
VP/0Vi^K0P2LW9`309fMW@80WinO0`2PX:030:6QX@80WYjN0`2LW9`209fMW@P0WYjN0`2LW9`209^K
V`<0W9bL0`2MWId209ZJVP<0UYJF1@2EUID209BDU0H0Ti>C0P2BTY8308j>SP80Rh^;0`2:RXX308^;
R`80S8b<0`2>SXh209>CT`<0Vi^K0`2YZJT20;Bd]0<0[Zj^1@2UYJDd0<SPf0<0WYjN0P1KFe/306=S
H`80L71`0`1OGel306YZJP80MgMg0`1mOGd208Z:RP<0Zj^[0`3?cll20=CDe0<0XJ6Q0P0j>SX3038b
<P80;Rh^0`0];Bd303@d=080>3Ph0`0f=SH203De=@<0<S8b0`0j>SX203Ti>@<0?Shn0P10@40303hn
?P<0>SXj0P0h>3P303<c<`80>CTi0`0d=3@303De=@80<C4a0`0_;bl5034a<@<0>3Ph0P1PH60307Mg
M`80PH610`1NGUh306MWI`80DE5A0`1DE5@205aLG0<0IFEU1@1]KFd3079bLP80MGEe0`1hN7P807Ui
N@80Ng]k0`1mOGd207alO0<0OGem0`1kNg/207QhN0<0OGem0P22PX8308J6QPD0PX:20`26QXH208F5
Q@<0QXJ60`2>SXh208Z:RP<0S8b<0P2:RXX308f=S@<0Ti>C0P2>SXh3092@T080SXj>0`2?Shl208j>
SP<0TI6A0`2?Shl2096AT@<0UIFE0P2>SXh309BDU0<0V9RH0P2JVYX309^KV`D0VYZJ0`2LW9`209ZJ
VP<0WinO0P2NWYh309fMW@<0WYjN0P2RXZ8309^KV`80WIfM0`2NWYh309fMW@80WYjN0`2LW9`509^K
V`<0X:2P1@2FUYH209RHV0P0UYJF0`2@T90209FEU@<0Shn?0P2:RXX308f=S@<0RXZ:0P2;Rh/308f=
S@80TI6A0`2MWId30:BTY080/[:b0`2f][H20:FUY@<0VYZJ7038h=P001/0b>3H0`2YZJT208^;R`<0
IfMW0P1UIFD306YZJP<0J6QX0P1WIfL306i^KP80MgMg0`2JVYX30;Zj^P80f=SH0`35aLD208:2PP<0
>SXj0P0R8R8602/[:`80;Rh^0`0];Bd202/[:`<0;Rh^0`0a<C4203<c<`<0=3@d0P0l?3`30451@@<0
>SXj0P0a<C43038b<PD0<c<c0`0a<C4202d];@<0:RXZ0P0X:2P3030`<0<0;Rh^0P1XJ6P307EeM@80
P8200`1EEED306ATI080EUIF0`1ADE4205UIF@<0IFEU0P1/K6`3071`L0<0LW9b0P1dM7@307IfMP80
N7Qh0`1iNGT307YjNP80Ng]k0`1lO7`207emO@<0OWin1@1mOGd307moO`P0PH610P23Ph<308F5Q@80
QhN70`29RHT508R8R0<0RXZ:0P2<S8`308n?S`D0TI6A0`2@T90508n?S`80T92@0`2ATI4309:BTP80
Ti>C1@2DU9@309FEU@<0UiNG0P2IVIT;09^KV`D0W9bL0P2KVi/309fMW@D0WinO202NWYh309fMW@X0
W9bL0`2KVi/209RHV0<0UYJF1@2EUID209>CT`<0TY:B0`2ATI42092@T0<0S8b<0P28R8P808N7Q`<0
R8R80P2=SHd309:BTP<0WIfM0P2UYJD309jNWP80U9BD0`2EUIDd0<SPf0<0];Bd0P2:RXX3061PH080
I6AT0`1ZJVX305iNGP80IFEU0`1eMGD207emO@<0SXj>0`30`<020=CDe0<0bl_;0P1gMgL3030`<080
:BTY0`0Z:RX302TY:@80;Rh^0`0[:b/202l_;`<0:RXZ1@0b<S8303<c<`80;Bd]0`16ATH30451@@D0
=3@d0P0f=SH3034a<@<0<c<c0P0b<S8302TY:@80:RXZ0`0];Bd3034a<@80I6AT0`1gMgL207UiN@<0
EeMG0`1VIVH204i>CP<0EeMG0P1KFe/3061PH080KVi^0`1]KFd507=cL`<0NWYj1@1iNGT307moO`80
O7al0`1mOGd207alO0<0OWin0`1jNWX50861P@80Q8B40`1nOWh307emO@80Ph>31@21PH4308Z:RP<0
RHV90P25QHD308R8R080T92@0`2;Rh/3096AT@80UIFE0`2ATI42092@T0<0Shn?0P2BTY86092@T080
UIFE1@2DU9@309FEU@<0UYJF0P2OWil309ZJVP80VIVI1P2LW9`209VIV@D0Vi^K0`2NWYh30:2PX080
WinO0`2KVi/209fMW@<0XJ6Q0`2LW9`209jNWP<0VYZJ0P2LW9`309jNWP<0VYZJ0P2HV9P309JFUP80
Ti>C0`2FUYH2092@T0<0Shn?0`2ATI4208n?S`<0RXZ:0P26QXH308N7Q`<0QHF50P28R8P308f=S@80
Shn?0`2GUiL309RHV080YZJV0`2TY:@209JFUP<0Ti>C7038h=P001/0b>3H0`2YZJT208^;R`<0IfMW
0P1UIFD306YZJP<0J6QX0P1WIfL306i^KP80MgMg0`2JVYX30;Zj^P80f=SH0`35aLD208:2PP<0>SXj
0P0R8R8602/[:`80;Rh^0`0];Bd202/[:`<0;Rh^0`0a<C4203<c<`<0=3@d0P0l?3`30451@@<0>SXj
0P0a<C43038b<PD0<c<c0`0a<C4202d];@<0:RXZ0P0X:2P3030`<0<0;Rh^0P1XJ6P307EeM@80P820
0`1EEED306ATI080EUIF0`1ADE4205UIF@<0IFEU0P1/K6`3071`L0<0LW9b0P1dM7@307IfMP80N7Qh
0`1iNGT307YjNP80Ng]k0`1lO7`207emO@<0OWin1@1mOGd307moO`P0PH610P23Ph<308F5Q@80QhN7
0`29RHT508R8R0<0RXZ:0P2<S8`308n?S`D0TI6A0`2@T90508n?S`80T92@0`2ATI4309:BTP80Ti>C
1@2DU9@309FEU@<0UiNG0P2IVIT;09^KV`D0W9bL0P2KVi/309fMW@D0WinO202NWYh309fMW@X0W9bL
0`2KVi/209RHV0<0UYJF1@2EUID209>CT`<0TY:B0`2ATI42092@T0<0S8b<0P28R8P808N7Q`<0R8R8
0P2=SHd309:BTP<0WIfM0P2UYJD309jNWP80U9BD0`2EUIDd0<SPf0<0];Bd0P2:RXX3061PH080I6AT
0`1ZJVX305iNGP80IFEU0`1eMGD207emO@<0SXj>0`30`<020=CDe0<0bl_;0P1gMgL3030`<080:BTY
0`0Z:RX302TY:@80;Rh^0`0[:b/202l_;`<0:RXZ1@0b<S8303<c<`80;Bd]0`16ATH30451@@D0=3@d
0P0f=SH3034a<@<0<c<c0P0b<S8302TY:@80:RXZ0`0];Bd3034a<@80I6AT0`1gMgL207UiN@<0EeMG
0`1VIVH204i>CP<0EeMG0P1KFe/3061PH080KVi^0`1]KFd507=cL`<0NWYj1@1iNGT307moO`80O7al
0`1mOGd207alO0<0OWin0`1jNWX50861P@80Q8B40`1nOWh307emO@80Ph>31@21PH4308Z:RP<0RHV9
0P25QHD308R8R080T92@0`2;Rh/3096AT@80UIFE0`2ATI42092@T0<0Shn?0P2BTY86092@T080UIFE
1@2DU9@309FEU@<0UYJF0P2OWil309ZJVP80VIVI1P2LW9`209VIV@D0Vi^K0`2NWYh30:2PX080WinO
0`2KVi/209fMW@<0XJ6Q0`2LW9`209jNWP<0VYZJ0P2LW9`309jNWP<0VYZJ0P2HV9P309JFUP80Ti>C
0`2FUYH2092@T0<0Shn?0`2ATI4208n?S`<0RXZ:0P26QXH308N7Q`<0QHF50P28R8P308f=S@80Shn?
0`2GUiL309RHV080YZJV0`2TY:@209JFUP<0Ti>C7038h=P001/0b>3H0`2YZJT20;2`/0<0KFe]0P1@
D50307MgM`<0JVYZ0P1QHF4306ATI080L71`0`26QXH30:2PX080c<c<0`3Ph>020<71`@<0De=C0P0Y
:BT302LW9`<09BDU0P0Z:RX302LW9`809RHV0`0Z:RX302h^;P80<C4a0`0d=3@203hn?P<0A4A40`0j
>SX502h^;PD0<30`0`0_;bl202TY:@<09BDU0P0R8R8302XZ:P<0;Bd]0P1[Jf/307EeM@80O7al0`1C
De<306ATI080EUIF0`1@D50205UIF@<0IVIV0P1]KFd3079bLPD0Lg=c0`1dM7@207MgM`<0N7Qh0`1j
NWX207]kN`<0O7al0P1mOGd307moO`<0PH610P22PX830820P080Ogmo0`20P80308:2PP80Q8B40`26
QXH208R8R0<0RXZ:0`28R8P208J6QP<0RXZ:0P2>SXh308n?S`d0T92@0P2ATI4309:BTP<0Ti>C0P2E
UID309NGU`80V9RH0`2GUiL309FEU@80VIVI0`2LW9`209^KV`<0VYZJ0`2KVi/209fMW@<0VYZJ0P2H
V9P309ZJVP<0WYjN0P2OWil30:2PX080WinO0`2NWYh309bLW080Vi^K1@2LW9`309ZJVPD0UiNG0`2F
UYH209FEU@<0Ti>C0P2ATI43092@T0<0SXj>0P2<S8`308R8R080Q8B42023Ph<308F5Q@80QhN70`2;
Rh/3096AT@80UIFE0`2=SHd208F5Q@<0Ph>3=038h=P30:f][@80[:b/0`1bLW8206ATI0<0MGEe0`1V
IVH206=SH`<0K6a/0P1bLW8308>3P`<0XZ:R0P3Cdm<30=OGe`80`<300`1BDU8202DU9@<09RHV0`0Z
:RX202LW9`<092@T0P0V9RH302TY:@<0;Bd]0P0a<C4303Ph>080?Cdm0`11@D4303@d=080<30`0`0a
<C42030`<0<0;bl_0`0a<C4202LW9`<09BDU0P0Y:BT302HV9P<0;Rh^0P1WIfL307IfMP80NGUi0`1N
GUh306ATI080Bd];0`1EEED205]KF`<0IfMW0P1ZJVX307=cL`<0M7Ad0P1cLg<307EeM@80MWIf0`1d
M7@307]kN`80NGUi0`1mOGd207inOP<0OGem0`20P8020861P@<0PX:20P1lO7`307moO`<0Ph>30P26
QXH308V9R@80QXJ61P29RHT208N7Q`<0RHV90P2>SXh308f=S@<0Ti>C0P2>SXh308n?S`80TI6A0`2=
SHd2096AT@<0TY:B0`2CTi<209BDU0<0UiNG0P2HV9P309>CT`<0U9BD0P2KVi/509VIV@H0VYZJ0P2N
WYh309ZJVP80UYJF0`2IVIT509jNWP<0WinO0P2RXZ8309bLW0<0V9RH0P2LW9`309VIV@80WIfM0`2J
VYX309NGU`80W9bL0`2EUID209:BTP<0U9BD0P2?Shl309>CT`<0SHf=0P2<S8`308J6QP80Ph>30`2;
Rh/308:2PP80Ph>30`25QHD208N7Q`<0SHf=0`2?Shl209JFUP<0Shn?0P24Q8@308J6QQ`0b>3H000K
0<SPf0<0ZJVY0P2`/;0306e]K@80D51@0`1gMgL306YZJP80HF5Q0`1TI6@2071`L0<0QXJ60`2PX:02
0<c<c0<0h>3P0P31`L4305=CD`80:BTY0`0W9bL302DU9@80:RXZ0`0W9bL202HV9P<0:RXZ0`0^;Rh2
034a<@<0=3@d0P0n?Sh304A4A0<0>SXj1@0^;Rh5030`<0<0;bl_0P0Y:BT302DU9@808R8R0`0Z:RX3
02d];@80Jf][0`1eMGD207alO0<0De=C0`1TI6@205IFEP<0D51@0P1IFET306IVIP80KFe]0`1bLW85
07=cL`<0M7Ad0P1gMgL307QhN0<0NWYj0P1kNg/307alO080OGem0`1oOgl30861P@80PX:20`20P802
07moO`<0P8200`22PX8208B4Q0<0QXJ60P28R8P308Z:RP<0R8R80P26QXH308Z:RP80SXj>0`2?Shl=
092@T080TI6A0`2BTY8309>CT`80UIFE0`2GUiL209RHV0<0UiNG0`2EUID209VIV@<0W9bL0P2KVi/3
09ZJVP<0Vi^K0P2MWId309ZJVP80V9RH0`2JVYX309jNWP80WinO0`2PX:0209nOW`<0WYjN0`2LW9`2
09^KV`D0W9bL0`2JVYX509NGU`<0UYJF0P2EUID309>CT`80TI6A0`2@T90308j>SP80S8b<0`28R8P2
08B4Q0P0Ph>30`25QHD208N7Q`<0Rh^;0`2ATI4209FEU@<0SHf=0P25QHD308>3Pc@0b>3H0`2][Jd2
0:b/[0<0LW9b0P1TI6@307EeM@<0IVIV0P1SHf<306a/K080LW9b0`23Ph<30::RXP80dm?C0`3GemL2
0<30`0<0DU9B0P0U9BD302HV9P<0:RXZ0P0W9bL302@T90809RHV0`0Y:BT302d];@80<C4a0`0h>3P2
03dm?@<0@D510`0d=3@2030`<0<0<C4a0P0`<30302l_;`<0<C4a0P0W9bL302DU9@80:BTY0`0V9RH3
02h^;P80IfMW0`1fMWH207UiN@<0GUiN0`1TI6@204];B`<0EEEE0P1KFe/306MWI`80JVYZ0`1cLg<3
07AdM080Lg=c0`1eMGD207IfMP<0M7Ad0`1kNg/207UiN@<0OGem0P1nOWh307emO@<0P8200P21PH43
08:2PP80O7al0`1oOgl308>3P`80QXJ60`29RHT208J6QPH0RHV90P27QhL308V9R@80SXj>0`2=SHd3
09>CT`80SXj>0`2?Shl2096AT@<0SHf=0P2ATI4309:BTP<0Ti>C0P2DU9@309NGU`80V9RH0`2CTi<3
09BDU080Vi^K1@2IVIT609ZJVP80WYjN0`2JVYX209JFUP<0VIVI1@2NWYh309nOW`80XZ:R0`2LW9`3
09RHV080W9bL0`2IVIT209fMW@<0VYZJ0`2GUiL209bLW0<0UIFE0P2BTY8309BDU080Shn?0`2CTi<3
08f=S@80S8b<0`26QXH208>3P`<0Rh^;0`22PX8208>3P`<0QHF50P27QhL308f=S@<0Shn?0P2FUYH3
08n?S`80Q8B40`26QXHL0<SPf0006`38h=P30:VYZ@80/;2`0`1]KFd2051@D0<0MgMg0`1ZJVX2065Q
H@<0I6AT0P1`L70308J6QP<0X:2P0P3<c<`30>3Ph080`L710`1CDe<202TY:@<09bLW0`0U9BD202XZ
:P<09bLW0P0V9RH302XZ:P<0;Rh^0P0a<C4303@d=080?Shn0`14A4@303Xj>PD0;Rh^1@0`<30302l_
;`80:BTY0`0U9BD2028R8P<0:RXZ0`0];Bd206][J`<0MGEe0P1lO7`305=CD`<0I6AT0P1FEUH3051@
D080FEUI0`1VIVH206e]K@<0LW9b1@1cLg<307AdM080MgMg0`1hN7P307YjNP80Ng]k0`1lO7`207em
O@<0Ogmo0`21PH4208:2PP<0P8200P1oOgl30820P0<0PX:20P24Q8@308J6QP80R8R80`2:RXX308R8
R080QXJ60`2:RXX208j>SP<0Shn?3@2@T902096AT@<0TY:B0`2CTi<209FEU@<0UiNG0P2HV9P309NG
U`<0UIFE0P2IVIT309bLW080Vi^K0`2JVYX309^KV`80WIfM0`2JVYX209RHV0<0VYZJ0`2NWYh209nO
W`<0X:2P0P2OWil309jNWP<0W9bL0P2KVi/509bLW0<0VYZJ1@2GUiL309JFUP80UIFE0`2CTi<2096A
T@<0T92@0`2>SXh208b<S0<0R8R80P24Q8@808>3P`<0QHF50P27QhL308^;R`<0TI6A0P2EUID308f=
S@80QHF50`23Ph<d0<SPf0<0[Jf]0P2/[:`3079bLP80I6AT0`1eMGD306IVIP80Hf=S0`1/K6`2079b
LP<0Ph>30`2RXZ820=?Cd`<0emOG0P30`<03059BDP809BDU0`0V9RH302XZ:P809bLW0`0T92@202HV
9P<0:BTY0`0];Bd2034a<@<0>3Ph0P0m?Cd30451@@<0=3@d0P0`<303034a<@80<30`0`0_;bl3034a
<@809bLW0`0U9BD202TY:@<09RHV0`0^;Rh206MWI`<0MWIf0P1iNGT305iNGP<0I6AT0P1;Bd/305EE
E@80Fe]K0`1WIfL206YZJP<0Lg=c0`1dM7@207=cL`<0MGEe0P1fMWH307AdM0<0Ng]k0P1iNGT307em
O@80OWin0`1mOGd30820P080PH610`22PX8207alO0<0Ogmo0`23Ph<208J6QP<0RHV90P26QXH608V9
R@80QhN70`29RHT208j>SP<0SHf=0`2CTi<208j>SP<0Shn?0P2ATI4308f=S@80TI6A0`2BTY8309>C
T`80U9BD0`2GUiL209RHV0<0Ti>C0`2DU9@209^KV`D0VIVI1P2JVYX209jNWP<0VYZJ0P2FUYH309VI
V@D0WYjN0`2OWil20::RXP<0W9bL0`2HV9P209bLW0<0VIVI0P2MWId309ZJVP<0UiNG0P2LW9`309FE
U@80TY:B0`2DU9@208n?S`<0Ti>C0`2=SHd208b<S0<0QXJ60P23Ph<308^;R`<0PX:20P23Ph<308F5
Q@80QhN70`2=SHd308n?S`80UYJF0`2?Shl208B4Q0<0QXJ67038h=P001/0b>3H0`27QhL20:BTY0<0
UiNG0P1`L70306e]K@<0Jf][0P1`L703075aL@80MGEe0`1mOGd308b<S080/;2`0`3;bl/20<[:bP<0
UYJF0P0J6QX303<c<`<08B4Q0P0V9RH302<S8`8092@T0`0W9bL302d];@80>3Ph0`12@T8204Q8B0<0
BDU90`10@40203De=@<0;bl_1@0[:b/302`/;080:b/[0`0Z:RX202TY:@<0<C4a0`0];Bd206EUI@<0
LW9b0P1kNg/3065QH@<0GemO0P1DE5@3051@D080FEUI0`1VIVH206][J`<0Kfm_0`1bLW8207=cL`<0
M7Ad0P1eMGD307QhN0<0Ng]k0P1mOGd307inOPD0OGem0`1oOgl20861P@<0PX:22021PH4208B4Q0<0
QXJ60P28R8P308V9R@<0R8R80P27QhL308b<S0D0TI6A0`2@T905096AT@d0TY:B0P2CTi<309FEU@P0
UYJF0P2HV9P309^KV`80VIVI0`2GUiL309ZJVP80W9bL0`2KVi/209ZJVP<0WIfM1@2OWil309fMW@D0
WYjN0`2MWId209^KV`<0VYZJ0P2IVIT309NGU`D0UYJF0`2EUID209:BTP<0SXj>0P2<S8`308^;R`<0
R8R80P25QHD30861P@80OWin0`20P80308:2PP80Ph>30`24Q8@208F5Q@<0QhN70`29RHT208Z:RP<0
Ph>30P1lO7`307YjNS@0b>3H0`27QhL209NGU`<0U9BD0P1QHF4306YZJP<0M7Ad0P1[Jf/306a/K080
Kfm_0`1cLg<308B4Q080^k^k1@3?cll309fMW@80;Bd]0`0Y:BT302DU9@80;2`/0`0S8b<202TY:@<0
:RXZ0`0b<S8203Xj>P<0@d=30P1>CTh305YJFP<0=3@d0P0e=CD3034a<@80:RXZ0`0W9bL3030`<080
8b<S0`0Z:RX202/[:`<0;bl_0`0e=CD206=SH`<0OGem0P1eMGD606=SH`80Cdm?0`1BDU8205UIF@<0
JFUY0P1`L703075aL@<0Kfm_0P1aLG4307EeM@D0N7Qh0`1jNWX207emO@<0NWYj0P1oOgl60861P@80
Ogmo0`22PX8208B4Q0<0Ogmo0`22PX8208J6QP<0QHF50P27QhL308^;R`<0S8b<0P26QXH308b<S080
TY:B0`2ATI4308f=S@80TI6A0`2>SXh209BDU0D0Ti>C0`2@T90309BDU080Ti>C0`2EUID209ZJVP<0
U9BD0`2FUYH209jNWP<0WIfM0P2HV9P309ZJVP<0UiNG0P2MWId30:2PX080WIfM0`2LW9`309nOW`80
WYjN1@2OWil309jNWP<0WinO0P2LW9`309fMW@80V9RH0`2GUiL3096AT@80UIFE0`2DU9@209FEU@<0
Shn?0P2=SHd308V9R@<0SXj>0P28R8P307moO`80OGem0`20P80307moO`80P8200`22PX820820P0<0
QHF50`27QhL208R8R0<0PH610P1fMWH307UiNA`0b>3H000K0<SPf0<0QhN70P2TY:@309NGU`80L71`
0`1]KFd306][J`80L71`0`1aLG4207EeM@<0OGem0`2<S8`20;2`/0<0bl_;0P3:b/X309JFUP806QXJ
0`0c<c<3024Q8@809RHV0`0S8b<202@T90<09bLW0`0];Bd203Ph>0<0@T920P18B4P304U9B@<0@410
0P0e=CD302l_;`D0:b/[0`0/;2`202/[:`<0:RXZ0P0Y:BT3034a<@<0;Bd]0P1UIFD3079bLP80Ng]k
0`1QHF4305mOG`80E5AD0`1@D50205UIF@<0IVIV0P1[Jf/306m_K`<0LW9b0P1cLg<307AdM080MGEe
0`1hN7P307]kN`80OGem0`1nOWh507emO@<0Ogmo0P21PH4308:2PPP0PH610P24Q8@308J6QP80R8R8
0`29RHT308R8R080QhN70`2<S8`5096AT@<0T92@1@2ATI4=09:BTP80Ti>C0`2EUID809JFUP80V9RH
0`2KVi/209VIV@<0UiNG0`2JVYX209bLW0<0Vi^K0P2JVYX309fMW@D0WinO0`2MWId509jNWP<0WIfM
0P2KVi/309ZJVP80VIVI0`2GUiL509JFUP<0UIFE0P2BTY8308j>SP80S8b<0`2;Rh/308R8R080QHF5
0`21PH4207inOP<0P8200`22PX8208>3P`<0Q8B40P25QHD308N7Q`<0RHV90P2:RXX308>3P`80O7al
0`1jNWXd0<SPf0<0QhN70P2GUiL309BDU080HF5Q0`1ZJVX307AdM080Jf][0`1/K6`206m_K`<0Lg=c
0`24Q8@20;^k^`D0clo?0`2MWId202d];@<0:BTY0`0U9BD202`/;0<08b<S0P0Y:BT302XZ:P<0<S8b
0P0j>SX304=3@`80CTi>0`1JFUX303@d=080=CDe0`0a<C4202XZ:P<09bLW0`0`<30202<S8`<0:RXZ
0P0[:b/302l_;`<0=CDe0P1SHf<307emO@80MGEe1P1SHf<204m?C`<0DU9B0P1IFET306UYJ@80L71`
0`1aLG4306m_K`80LG5a0`1eMGD507QhN0<0NWYj0P1mOGd307YjNP80Ogmo1P21PH4207moO`<0PX:2
0P24Q8@307moO`<0PX:20P26QXH308F5Q@80QhN70`2;Rh/308b<S080QXJ60`2<S8`209:BTP<0TI6A
0`2=SHd2096AT@<0SXj>0P2DU9@509>CT`<0T92@0`2DU9@209>CT`<0UIFE0P2JVYX309BDU0<0UYJF
0P2NWYh309fMW@80V9RH0`2JVYX309NGU`80WIfM0`2PX:0209fMW@<0W9bL0`2OWil209jNWPD0WinO
0`2NWYh309nOW`80W9bL0`2MWId209RHV0<0UiNG0`2ATI4209FEU@<0U9BD0P2EUID308n?S`80SHf=
0`29RHT308j>SP80R8R80`1oOgl207emO@<0P8200`1oOgl20820P0<0PX:20P20P80308F5Q@<0QhN7
0P28R8P30861P@80MWIf0`1iNGTL0<SPf0006`38h=P306ATI080K6a/0`1hN7P2071`L0<0IVIV0`1c
Lg<208:2PP<0Ph>30P20P80307moO`<0PX:20P2IVIT30;2`/080_;bl0`2i^KT205QHF0<0<C4a0`0Q
8B4202LW9`<08b<S0P0T92@302DU9@<0:b/[0P0m?Cd304e=C@80CTi>0`19BDT304=3@`80>c/k0`0a
<C4502PX:0<0:b/[0P0];Bd3034a<@80<30`0`0g=cL302d];@80GemO0`1_Kfl207UiN@<0KFe]0`1J
FUX2059BDP<0D51@0P1JFUX306EUI@80JFUY0`1/K6`3071`L0D0M7Ad0P1eMGD307UiN@<0OGem1@1o
Ogl207emO@<0O7al0`1mOGd20820P0<0PX:20P24Q8@308>3P`<0PH610P24Q8@308N7Q`80R8R80`29
RHT508R8R0<0SXj>0P2CTi<309:BTP<0T92@0P2ATI4309>CT`80U9BD0`2EUID209>CT`<0TY:B1@2@
T90309:BTP80UIFE0`2FUYH309NGU`80VIVI0`2JVYX209RHV0<0UYJF0`2IVIT209bLW0<0WIfM0P2N
WYh30:2PX0<0XJ6Q0P2NWYh309^KV`80WIfM1P2NWYh209bLW0<0V9RH202EUID209BDU0<0TY:B0P2=
SHd308R8R080QXJ60`25QHD308:2PP80OWin0`1kNg/207YjNP<0OGem0`21PH4208>3P`/0Q8B40P23
Ph<307alO080MWIf0`1dM7@d0<SPf0<0H61P0P1_Kfl307inOPD0KFe]0`1jNWX207moO`D0Q8B40`1j
NWX308N7Q`80Vi^K0`2e]KD20;Bd]0<0]kNg0P1SHf<3034a<@<09bLW1@0S8b<202@T90<09RHV0`0Z
:RX203/k>`<0DU9B1@1;Bd/304I6AP80ADE51@0/;2`602d];@809bLW0`0c<c<203/k>`<0=3@d0`0/
;2`205MGE`<0LG5a0P1iNGT306QXJ0<0GEeM0P1CDe<3055AD@80G5aL0`1QHF4206UYJ@<0Jf][0`1`
L70207MgM`<0MWIf0P1dM7@307IfMPD0OWin0`1oOgl207inOP<0Ng]k0`1nOWh207moO`<0R8R80P21
PH4308F5Q@<0P8201@26QXH208N7Q`<0QXJ60`2<S8`208N7Q`<0SHf=0P2DU9@309:BTP<0Shn?1@2A
TI4209RHV0<0TY:B0P2DU9@3092@T0<0U9BD0P2ATI4309FEU@80U9BD0`2CTi<309RHV080W9bL0`2J
VYX209>CT`<0UiNG0`2HV9P209fMW@<0W9bL0P2MWId309jNWP<0WinO0P2SXj<309RHV080Vi^K1P2N
WYh209ZJVP<0UiNG0P2DU9@309JFUP<0V9RH1@2CTi<208f=S@P0QXJ60`22PX8207emO@D0NWYj0`20
P80508:2PP<0QhN70P24Q8@608J6QP80PX:20`1lO7`207AdM0<0MgMg7038h=P001/0b>3H0`1TI6@2
06a/K0<0N7Qh0P1`L70306IVIP<0Lg=c0P22PX8308>3P`80P8200`1oOgl308:2PP80VIVI0`2`/;02
0;bl_0<0^KVi0P1HF5P3034a<@<08B4Q0P0W9bL302<S8`8092@T0`0U9BD302/[:`80?Cdm0`1=CDd2
04i>CP<0BDU90`13@d<203/k>`<0<C4a1@0X:2P302/[:`80;Bd]0`0a<C42030`<0<0=cLg0`0];Bd2
05mOG`<0Kfm_0P1iNGT306e]K@<0FUYJ0P1BDU83051@D080FUYJ0`1UIFD206UYJ@<0K6a/0`1`L705
07AdM080MGEe0`1iNGT307emO@D0Ogmo0P1mOGd307alO0<0OGem0P20P80308:2PP80Q8B40`23Ph<3
0861P@80Q8B40`27QhL208R8R0<0RHV91@28R8P308j>SP80Ti>C0`2BTY83092@T080TI6A0`2CTi<2
09BDU0<0UIFE0P2CTi<309:BTPD0T92@0`2BTY8209FEU@<0UYJF0`2GUiL209VIV@<0VYZJ0P2HV9P3
09JFUP<0VIVI0P2LW9`309fMW@80WYjN0`2PX:030:6QX@80WYjN0`2KVi/209fMW@H0WYjN0P2LW9`3
09RHV0P0UIFE0P2DU9@309:BTP80SHf=0`28R8P208J6QP<0QHF50`22PX8207inOP<0Ng]k0P1jNWX3
07emO@<0PH610P23Ph<;08B4Q080Ph>30`1lO7`207IfMP<0M7Ad=038h=P3061PH080Kfm_0`1nOWh5
06e]K@<0NWYj0P1oOgl508B4Q0<0NWYj0`27QhL209^KV`<0]KFe0P2d];@30;Ng]`80Hf=S0`0a<C43
02LW9`D08b<S0P0T92@302HV9P<0:RXZ0P0k>c/3059BDPD0Bd];0`16ATH204E5A@D0;2`/1P0];Bd2
02LW9`<0<c<c0P0k>c/303@d=0<0;2`/0P1GEeL3075aL@80NGUi0`1XJ6P305eMG@80De=C0`1ADE42
05aLG0<0HF5Q0P1YJFT306][J`<0L71`0P1gMgL307IfMP80M7Ad0`1fMWH507inOP<0Ogmo0P1nOWh3
07]kN`<0OWin0P1oOgl308R8R080PH610`25QHD30820P0D0QXJ60P27QhL308J6QP<0S8b<0P27QhL3
08f=S@80U9BD0`2BTY8308n?S`D0TI6A0P2HV9P309:BTP80U9BD0`2@T90309BDU080TI6A0`2EUID2
09BDU0<0Ti>C0`2HV9P209bLW0<0VYZJ0P2CTi<309NGU`<0V9RH0P2MWId309bLW080WIfM0`2NWYh3
09nOW`80Xj>S0`2HV9P209^KV`H0WYjN0P2JVYX309NGU`80U9BD0`2FUYH309RHV0D0Ti>C0P2=SHd8
08J6QP<0PX:20P1mOGd507YjNP<0P8201@22PX8308N7Q`80Q8B41P26QXH208:2PP<0O7al0P1dM7@3
07MgMa`0b>3H000K0<SPf0<0I6AT0P1/K6`307QhN080L71`0`1VIVH307=cL`80PX:20`23Ph<20820
P0<0Ogmo0`22PX8209VIV@<0/;2`0P2l_;`30;Vi^@80F5QH0`0a<C43024Q8@809bLW0`0S8b<202@T
90<09BDU0`0[:b/203dm?@<0CDe=0P1>CTh304U9B@<0@d=30P0k>c/3034a<@D0:2PX0`0[:b/202d]
;@<0<C4a0P0`<30303Lg=`<0;Bd]0P1OGel306m_K`80NGUi0`1]KFd305YJFP80DU9B0`1@D50205YJ
FP<0IFEU0P1YJFT306a/K0<0L71`1@1dM7@207EeM@<0NGUi0`1mOGd507moO`80OGem0`1lO7`307em
O@80P8200`22PX8208B4Q0<0Ph>30`21PH4208B4Q0<0QhN70P28R8P308V9R@D0R8R80`2>SXh209>C
T`<0TY:B0`2@T902096AT@<0Ti>C0P2DU9@309FEU@80Ti>C0`2BTY85092@T0<0TY:B0P2EUID309JF
UP<0UiNG0P2IVIT309ZJVP80V9RH0`2FUYH309VIV@80W9bL0`2MWId209jNWP<0X:2P0`2QXJ4209jN
WP<0Vi^K0P2MWId609jNWP80W9bL0`2HV9P809FEU@80U9BD0`2BTY8208f=S@<0R8R80P26QXH308F5
Q@<0PX:20P1nOWh307]kN`80NWYj0`1mOGd30861P@80Ph>32`24Q8@208>3P`<0O7al0P1fMWH307Ad
M3@0b>3H0`1PH60206m_K`<0OWin1@1]KFd307YjNP80Ogmo1@24Q8@307YjNP<0QhN70P2KVi/30;Fe
]@80];Bd0`2g]kL206=SH`<0<C4a0`0W9bL502<S8`8092@T0`0V9RH302XZ:P80>c/k0`1BDU8504];
B`<0ATI60P15ADD502`/;0H0;Bd]0P0W9bL303<c<`80>c/k0`0d=3@302`/;080EeMG0`1aLG4207Ui
N@<0J6QX0`1MGEd205=CD`<0DE5A0P1LG5`3065QH@80JFUY0`1[Jf/3071`L080MgMg0`1fMWH207Ad
M0<0MWIf1@1nOWh307moO`80OWin0`1kNg/307inOP80Ogmo0`28R8P20861P@<0QHF50`20P80508J6
QP80QhN70`26QXH308b<S080QhN70`2=SHd209BDU0<0TY:B0`2?Shl5096AT@80V9RH0`2BTY8209BD
U0<0T92@0`2DU9@2096AT@<0UIFE0P2DU9@309>CT`<0V9RH0P2LW9`309ZJVP80Ti>C0`2GUiL309RH
V080WIfM0`2LW9`209fMW@<0WYjN0`2OWil20:>SX`<0V9RH0P2KVi/609jNWP80VYZJ0`2GUiL209BD
U0<0UYJF0`2HV9P509>CT`80SHf=2026QXH308:2PP80OGem1@1jNWX30820P0D0PX:20`27QhL208B4
Q0H0QXJ60P22PX8307alO080M7Ad0`1gMgLL0<SPf0006`38h=P304Q8B080D51@0`1SHf<2079bLP<0
MgMg0`21PH4208Z:RP<0SXj>0P2ATI4309>CT`<0UiNG0P2SXj<30:n_[`80]kNg0`2d];@20:NWY`<0
H61P0`1<C4`202<S8`<08R8R0P0V9RH302DU9@<09bLW0P0c<c<303hn?P80?Cdm0`0i>CT303Lg=`80
=CDe0`0_;bl502XZ:P<0;2`/0P0];Bd3030`<080;Bd]0`0c<c<302d];@80HV9R0`1^KVh207AdM0<0
J6QX0`1DE5@204m?C`<0DE5A0P1KFe/306MWI`80JVYZ0`1/K6`3071`L0L0M7Ad0`1hN7P=07emO@<0
Ogmo0P20P80308:2PPP0Q8B40P26QXH308R8R0D0RHV90`2;Rh/208f=S@<0T92@0P2BTY83096AT@<0
T92@0P2ATI4309:BTP80U9BD0`2FUYH209FEU@<0U9BD0`2BTY82096AT@<0U9BD0P2GUiL309RHV0d0
VIVI0`2JVYX209bLW0<0WIfM0P2OWil60:2PX080WYjN0`2LW9`209fMW@<0WinO0`2MWId209ZJVP<0
UYJF0P2CTi<309BDU0<0UIFE0P2CTi<3092@T080R8R80`21PH4207inOP/0OGem0P1nOWh30861P@<0
Q8B41@25QHD508J6QP<0QHF50P22PX8307]kN`80M7Ad0`1bLW8d0<SPf0<0C4a<0P1NGUh306ATI0D0
L71`0`1kNg/208^;R`<0U9BD0P2FUYH309BDU0<0VIVI0P2OWil30:RXZ080Y:BT0`2^[Zh209jNWP<0
GemO0`0g=cL202LW9`<09RHV0P0P820302<S8`<0:2PX0P0^;Rh303Ph>080?3`l0`0/;2`3034a<@80
;bl_0`0[:b/202XZ:P<0:b/[0`0a<C4202HV9PD0;bl_0`0Z:RX3034a<@80Hf=S0`1dM7@207=cL`<0
J6QX0`1BDU8204Y:BP<0D51@0P1NGUh306IVIP80K6a/0`1XJ6P307AdM080Kfm_0`1aLG4207EeM@<0
MgMg0`20P80207inOP<0PH611@1kNg/307alO080P8200`1oOgl508:2PP<0PH611@28R8P208Z:RP<0
RHV90`2:RXX208^;R`<0T92@0P2>SXh309FEU@<0Ti>C0P2BTY8309BDU080Ti>C1@2EUID309>CT`<0
TI6A0P27QhL509JFUP<0Ti>C0`2FUYH209ZJVP<0UiNG0P2FUYH309bLW0<0V9RH0P2KVi/309jNWP80
W9bL0`2QXJ4309nOW`80WYjN0`2JVYX20:2PX0<0WYjN0`2JVYX209bLW0<0UIFE1@2DU9@309FEU@80
TY:B0`2@T90208V9R@<0PX:20P1nOWh307]kN`<0NWYj0P1nOWh307alO080P8200`22PX8308B4Q080
QhN70`24Q8@508J6QP<0QHF50P24Q8@307inOPD0MgMg7038h=P001/0b>3H0`18B4P2051@D0<0Hf=S
0P1bLW8307MgM`<0PH610P2:RXX308j>SP80TI6A0`2CTi<309NGU`80Xj>S0`2_[jl20;Ng]`<0];Bd
0P2WYjL3061PH0<0C4a<0P0S8b<3028R8P809RHV0`0U9BD302LW9`80<c<c0`0n?Sh203dm?@<0>CTi
0`0g=cL203De=@<0;bl_1@0Z:RX302`/;080;Bd]0`0`<30202d];@<0<c<c0`0];Bd2069RHP<0KVi^
0P1dM7@306QXJ0<0E5AD0P1?Cdl3055AD@80Fe]K0`1WIfL206YZJP<0K6a/0`1`L70707AdM0<0N7Qh
3@1mOGd307moO`80P8200`22PX8808B4Q080QXJ60`28R8P508V9R@<0Rh^;0P2=SHd3092@T080TY:B
0`2ATI43092@T080TI6A0`2BTY8209BDU0<0UYJF0P2EUID309BDU0<0TY:B0P2ATI4309BDU080UiNG
0`2HV9P=09VIV@<0VYZJ0P2LW9`309fMW@80WinO1P2PX:0209jNWP<0W9bL0P2MWId309nOW`<0WIfM
0P2JVYX309JFUP80Ti>C0`2DU9@309FEU@80Ti>C0`2@T90208R8R0<0PH610P1nOWh;07emO@80OWin
0`21PH4308B4Q0D0QHF51@26QXH308F5Q@80PX:20`1kNg/207AdM0<0LW9b=038h=P304a<C080GUiN
0`1TI6@5071`L0<0Ng]k0P2;Rh/309BDU080UYJF0`2DU9@309VIV@80WinO0`2XZ:P20:BTY0<0[Zj^
0P2NWYh305mOG`<0=cLg0P0W9bL302HV9P80820P0`0S8b<302PX:080;Rh^0`0h>3P203`l?0<0;2`/
0`0a<C4202l_;`<0:b/[0P0Z:RX302/[:`<0<C4a0P0V9RH502l_;`<0:RXZ0`0a<C4206=SH`<0M7Ad
0P1cLg<306QXJ0<0DU9B0P1:BTX3051@D080GUiN0`1VIVH206a/K0<0J6QX0`1dM7@206m_K`<0LG5a
0P1eMGD307MgM`<0P8200P1nOWh30861P@D0Ng]k0`1lO7`20820P0<0Ogmo1@22PX830861P@D0R8R8
0P2:RXX308V9R@<0RXZ:0P2;Rh/3092@T080SXj>0`2EUID309>CT`80TY:B0`2DU9@209>CT`D0UIFE
0`2CTi<3096AT@80QhN71@2FUYH309>CT`<0UYJF0P2JVYX309NGU`80UYJF0`2LW9`309RHV080Vi^K
0`2NWYh209bLW0<0XJ6Q0`2OWil209jNWP<0VYZJ0P2PX:0309jNWP<0VYZJ0P2LW9`309FEU@D0U9BD
0`2EUID209:BTP<0T92@0P29RHT308:2PP80OWin0`1kNg/307YjNP80OWin0`1lO7`20820P0<0PX:2
0`24Q8@208N7Q`<0Q8B41@26QXH308F5Q@80Q8B40`1nOWh507MgMa`0b>3H000K0<SPf0<0B4Q80P1@
D50306=SH`80LW9b0`1gMgL30861P@80RXZ:0`2>SXh2096AT@<0Ti>C0`2GUiL20:>SX`<0[jn_0P2g
]kL30;Bd]080YjNW0`1PH60304a<C0808b<S0`0R8R8202HV9P<09BDU0`0W9bL203<c<`<0?Shn0P0m
?Cd303Ti>@<0=cLg0P0e=CD302l_;`D0:RXZ0`0/;2`202d];@<0<30`0P0];Bd303<c<`<0;Bd]0P1R
HV8306i^KP80M7Ad0`1XJ6P305ADE080Cdm?0`1ADE4205]KF`<0IfMW0P1ZJVX306a/K0<0L71`1`1d
M7@307QhN0d0OGem0`1oOgl20820P0<0PX:22024Q8@208J6QP<0R8R81@29RHT308^;R`80SHf=0`2@
T90209:BTP<0TI6A0`2@T902096AT@<0TY:B0P2DU9@309JFUP80UIFE0`2DU9@309:BTP80TI6A0`2D
U9@209NGU`<0V9RH3@2IVIT309ZJVP80W9bL0`2MWId209nOW`H0X:2P0P2NWYh309bLW080WIfM0`2O
Wil309fMW@80VYZJ0`2FUYH209>CT`<0U9BD0`2EUID209>CT`<0T92@0P28R8P30861P@80OWin2`1m
OGd207inOP<0PH610`24Q8@508F5Q@D0QXJ60`25QHD208:2PP<0Ng]k0P1dM7@3079bLS@0b>3H0`1<
C4`205iNGP<0I6AT1@1`L70307]kN`80Rh^;0`2DU9@209JFUP<0U9BD0`2IVIT209nOW`<0Z:RX0P2T
Y:@30:j^[P80WYjN0`1OGel303Lg=`809bLW0`0V9RH2020P80<08b<S0`0X:2P202h^;P<0>3Ph0P0l
?3`302`/;0<0<C4a0P0_;bl302/[:`80:RXZ0`0[:b/3034a<@809RHV1@0_;bl302XZ:P<0<C4a0P1S
Hf<307AdM080Lg=c0`1XJ6P3059BDP80BTY:0`1@D50205iNGP<0IVIV0P1/K6`306QXJ0<0M7Ad0P1_
Kfl3075aL@80MGEe0`1gMgL30820P080OWin0`21PH4507]kN`<0O7al0P20P80307moO`D0PX:20`21
PH4508R8R080RXZ:0`29RHT308Z:RP80Rh^;0`2@T90208j>SP<0UIFE0`2CTi<209:BTP<0U9BD0P2C
Ti<509FEU@<0Ti>C0`2ATI4208N7Q`D0UYJF0`2CTi<309JFUP80VYZJ0`2GUiL209JFUP<0W9bL0`2H
V9P209^KV`<0WYjN0P2LW9`30:6QX@<0WinO0P2NWYh309ZJVP80X:2P0`2NWYh309ZJVP80W9bL0`2E
UID509BDU0<0UIFE0P2BTY83092@T080RHV90`22PX8207inOP<0Ng]k0`1jNWX207inOP<0O7al0P20
P80308:2PP<0Q8B40P27QhL308B4Q0D0QXJ60`25QHD208B4Q0<0OWin1@1gMgLL0<SPf0006`38h=P3
03<c<`80=cLg0`15ADD206QXJ0<0R8R80`2?Shl2092@T0<0VIVI0P2RXZ830:ZZZP<0/K6a1@2b/[82
0;^k^`<0`L710P2a/K430:^[Z`<0QHF50P0U9BD3020P80809bLW0`0V9RH302DU9@80:2PX0`0/;2`2
02XZ:P<0:BTY0`0Z:RX702`/;0<0;Bd]200^;Rh202TY:@<0;Bd]0`0/;2`206EUI@<0KVi^0P1`L703
061PH0<0Cdm?0P1=CDd3059BDP80G5aL0`1WIfL206YZJP<0K6a/0`1`L70507AdM080Lg=c0`1hN7P3
07alO080Ng]k0`1jNWX207alO0<0Ogmo0`20P8020861P@<0PX:20P23Ph<308B4Q0<0QXJ60P28R8P8
08V9R@<0SHf=1@2ATI45092@T0<0TI6A0P2@T903096AT@80U9BD0`2FUYH209NGU`<0UYJF0`2EUID2
09>CT`<0UYJF0P2IVIT609^KV`80VYZJ0`2IVIT209^KV`H0W9bL0P2KVi/309fMW@D0WinO0`2NWYh5
09fMW@80WYjN0`2OWil309bLW080V9RH0`2EUID509>CT`<0U9BD0P2BTY8308f=S@80Ph>30`1jNWX2
07MgM`<0N7Qh0`1kNg/207inOP<0P8201@21PH480820P080PX:20`24Q8@308>3P`80P8200`1iNGT2
075aL@<0L71`=038h=P302`/;080>c/k0`16ATH206UYJ@<0SHf=0`29RHT209>CT`<0VIVI0P2QXJ46
0:f][@80/K6a0`2f][H20;jn_P<0`<300P2i^KT30:j^[P<0PH610P0Y:BT302DU9@809RHV0`0W9bL3
02@T9080:RXZ0`0_;bl202/[:`<0;2`/0`0d=3@202h^;P<0;2`/0P0^;Rh302l_;`<0<S8b0P0X:2P3
034a<@80;2`/0`0a<C43030`<080H61P0`1^KVh206e]K@<0I6AT0`1=CDd204i>CP<0D51@0P1SHf<3
06EUI@80IVIV0`1/K6`307EeM@80MgMg0`1aLG4207EeM@<0MWIf1@1mOGd307QhN080OWin0`21PH43
0820P080Ph>30`22PX8208>3P`H0QHF50P2:RXX308R8R080QXJ60`2:RXX308j>SP80TI6A0`2@T902
09>CT`<0S8b<1@2?Shl3092@T080UIFE0`2GUiL209FEU@<0UiNG0`2EUID209JFUP<0WIfM0P2GUiL3
09ZJVP<0W9bL0P2MWId309VIV@80VYZJ0`2LW9`309ZJVP80Vi^K0`2OWil209jNWP<0X:2P1@2MWId3
09bLW080WYjN0`2RXZ8309^KV`80UiNG0`2HV9P2096AT@H0U9BD1@2@T9020861P@<0Ng]k0P1dM7@3
07QhN0<0OGem1@1oOgl208>3P`<0Ogmo0`20P80207alO0<0OWin0P23Ph<307moO`<0PH610P1mOGd3
07MgM`80Kfm_0`1^KVhL0<SPf0006`38h=P303<c<`80=cLg0`15ADD206QXJ0<0R8R80`2?Shl2092@
T0<0VIVI0P2RXZ830:ZZZP<0/K6a1@2b/[820;^k^`<0`L710P2a/K430:^[Z`<0QHF50P0U9BD3020P
80809bLW0`0V9RH302DU9@80:2PX0`0/;2`202XZ:P<0:BTY0`0Z:RX702`/;0<0;Bd]200^;Rh202TY
:@<0;Bd]0`0/;2`206EUI@<0KVi^0P1`L703061PH0<0Cdm?0P1=CDd3059BDP80G5aL0`1WIfL206YZ
JP<0K6a/0`1`L70507AdM080Lg=c0`1hN7P307alO080Ng]k0`1jNWX207alO0<0Ogmo0`20P8020861
P@<0PX:20P23Ph<308B4Q0<0QXJ60P28R8P808V9R@<0SHf=1@2ATI45092@T0<0TI6A0P2@T903096A
T@80U9BD0`2FUYH209NGU`<0UYJF0`2EUID209>CT`<0UYJF0P2IVIT609^KV`80VYZJ0`2IVIT209^K
V`H0W9bL0P2KVi/309fMW@D0WinO0`2NWYh509fMW@80WYjN0`2OWil309bLW080V9RH0`2EUID509>C
T`<0U9BD0P2BTY8308f=S@80Ph>30`1jNWX207MgM`<0N7Qh0`1kNg/207inOP<0P8201@21PH480820
P080PX:20`24Q8@308>3P`80P8200`1iNGT2075aL@<0L71`=038h=P302`/;080>c/k0`16ATH206UY
J@<0SHf=0`29RHT209>CT`<0VIVI0P2QXJ460:f][@80/K6a0`2f][H20;jn_P<0`<300P2i^KT30:j^
[P<0PH610P0Y:BT302DU9@809RHV0`0W9bL302@T9080:RXZ0`0_;bl202/[:`<0;2`/0`0d=3@202h^
;P<0;2`/0P0^;Rh302l_;`<0<S8b0P0X:2P3034a<@80;2`/0`0a<C43030`<080H61P0`1^KVh206e]
K@<0I6AT0`1=CDd204i>CP<0D51@0P1SHf<306EUI@80IVIV0`1/K6`307EeM@80MgMg0`1aLG4207Ee
M@<0MWIf1@1mOGd307QhN080OWin0`21PH430820P080Ph>30`22PX8208>3P`H0QHF50P2:RXX308R8
R080QXJ60`2:RXX308j>SP80TI6A0`2@T90209>CT`<0S8b<1@2?Shl3092@T080UIFE0`2GUiL209FE
U@<0UiNG0`2EUID209JFUP<0WIfM0P2GUiL309ZJVP<0W9bL0P2MWId309VIV@80VYZJ0`2LW9`309ZJ
VP80Vi^K0`2OWil209jNWP<0X:2P1@2MWId309bLW080WYjN0`2RXZ8309^KV`80UiNG0`2HV9P2096A
T@H0U9BD1@2@T9020861P@<0Ng]k0P1dM7@307QhN0<0OGem1@1oOgl208>3P`<0Ogmo0`20P80207al
O0<0OWin0P23Ph<307moO`<0PH610P1mOGd307MgM`80Kfm_0`1^KVhL0<SPf0006`38h=P302LW9`80
92@T0`0_;bl204e=C@<0SXj>0`2EUID209nOW`<0Y:BT0P2YZJT30;>c/`<0_;bl0P2k^k/30;Rh^080
_Kfm0`31`L420<?3``<0^KVi0`2OWil203hn?P<09bLW0P0P8203024Q8@<09BDU0P0W9bL302PX:080
9bLW0`0U9BD302LW9`80:RXZ0`0/;2`202l_;`H0<30`0P0_;bl302h^;P80:2PX0`0[:b/302PX:080
H61P0`1]KFd2079bLP<0H61P1@1=CDd305ADE080GEeM0`1UIFD206MWI`<0J6QX0`1/K6`2071`L0<0
LW9b0P1dM7@307MgM`<0NWYj0P1kNg/507alO0<0OGem0`20P80708:2PP<0Ph>30`25QHD208N7Q`<0
R8R80P29RHT308Z:RP<0S8b<0P2?Shl=096AT@<0Ti>C0P2EUID509NGU`H0UYJF0P2EUID309JFUP80
UiNG0`2IVIT309ZJVPD0Vi^K0P2MWId609jNWP80WIfM402NWYh509nOW`<0Vi^K0P2FUYH309FEU@D0
U9BD0`2BTY8208n?S`<0RHV90P1oOgl307IfMP80N7Qh0`1lO7`30820P080PX:20`1lO7`207AdM0<0
JVYZ0`1RHV82061PH0<0HV9R0P1ZJVX3079bLP<0L71`0P1/K6`306IVIP80HF5Q0`1PH60d0<SPf0<0
8R8R0P0O7al302<S8`80DE5A0`2BTY8309NGU`80WYjN1@2RXZ830:n_[`<0`/;20P2i^KT30;jn_P80
`<300`37alL20<K6aP<0_;bl0`2RXZ8203`l?0<08b<S0P0U9BD302<S8`<09bLW0P0X:2P302TY:@P0
9bLW1@0[:b/202l_;`<0;Bd]0`0^;Rh502l_;`80:BTY0`0T92@302TY:@80GemO0`1[Jf/2071`L0<0
IVIV0`1=CDd204i>CP<0De=C0P1OGel306IVIP80Hf=S0`1ZJVX306a/K080L71`0`1_Kfl207QhN0<0
MGEe0`1hN7P507YjNPD0OGem0`1nOWh208>3P`<0PX:20P23Ph<308B4Q0<0Ph>30P29RHT308R8R080
RXZ:0`28R8P8092@T080TY:B0`2@T90309BDU080TY:B0`2ATI4209NGU`<0UYJF0P2HV9P609JFUP80
Ti>C0`2EUID209VIV@<0UiNG0`2JVYX209nOW`<0W9bL0P2KVi/309nOW`<0WIfM0P2OWil309fMW@80
WYjN0`2PX:0309fMW@D0WinO0P2NWYh309bLW0<0Vi^K0P2FUYH809BDU0<0Ti>C0P2<S8`308^;R`80
O7al0`1gMgL207YjNP<0OWin0`20P80208:2PP<0N7Qh0P1cLg<306a/K0<0IFEU0P1PH60306IVIP80
KFe]0`1hN7P307AdM080Kfm_0`1YJFT2061PH0<0I6AT7038h=P001/0b>3H0`0W9bL202@T90<0;bl_
0P1=CDd308j>SP<0UIFE0P2OWil30:BTY080ZJVY0`2c/k<30;bl_080^k^k0`2h^;P20;fm_@<0`L71
0P33`l<30;Vi^@<0WinO0P0n?Sh302LW9`80820P0`0Q8B4302DU9@809bLW0`0X:2P202LW9`<09BDU
0`0W9bL202XZ:P<0;2`/0P0_;bl6030`<080;bl_0`0^;Rh202PX:0<0:b/[0`0X:2P2061PH0<0KFe]
0P1bLW83061PH0D0CDe=0`1DE5@205eMG@<0IFEU0P1WIfL306QXJ0<0K6a/0P1`L703079bLP80M7Ad
0`1gMgL307YjNP80Ng]k1@1lO7`307emO@<0P8201`22PX8308>3P`<0QHF50P27QhL308R8R080RHV9
0`2:RXX308b<S080Shn?3@2ATI4309>CT`80UIFE1@2GUiL609JFUP80UIFE0`2FUYH209NGU`<0VIVI
0`2JVYX509^KV`80WIfM1P2NWYh209fMWA00WYjN1@2OWil309^KV`80UYJF0`2EUID509BDU0<0TY:B
0P2?Shl308V9R@80Ogmo0`1fMWH207QhN0<0O7al0`20P80208:2PP<0O7al0P1dM7@306YZJP<0HV9R
0P1PH603069RHP80JVYZ0`1bLW83071`L080K6a/0`1VIVH2065QH@<0H61P=038h=P3028R8P807alO
0`0S8b<2055AD@<0TY:B0`2GUiL209jNWPD0XZ:R0`2_[jl30<;2`P80^KVi0`2n_[h20<30`0<0alO7
0P36a/H30;bl_0<0XZ:R0P0l?3`302<S8`809BDU0`0S8b<302LW9`80:2PX0`0Y:BT802LW9`D0:b/[
0P0_;bl302d];@<0;Rh^1@0_;bl202TY:@<092@T0`0Y:BT205mOG`<0Jf][0P1`L70306IVIP<0CDe=
0P1>CTh305=CD`80GemO0`1VIVH206=SH`<0JVYZ0`1/K6`2071`L0<0Kfm_0P1hN7P307EeM@<0N7Qh
1@1jNWX507emO@<0OWin0P23Ph<308:2PP80Ph>30`24Q8@308>3P`80RHV90`28R8P208Z:RP<0R8R8
202@T90209:BTP<0T92@0`2DU9@209:BTP<0TI6A0P2GUiL309JFUP80V9RH1P2FUYH209>CT`<0UIFE
0P2IVIT309NGU`<0VYZJ0P2OWil309bLW080Vi^K0`2OWil309fMW@80WinO0`2MWId209jNWP<0X:2P
0`2MWId509nOW`80WYjN0`2LW9`309^KV`80UYJF202DU9@309>CT`80S8b<0`2;Rh/207alO0<0MgMg
0P1jNWX307inOP<0P8200P22PX8307QhN080Lg=c0`1/K6`306EUI@80H61P0`1VIVH206e]K@<0N7Qh
0`1dM7@206m_K`<0JFUY0P1PH60306ATI1`0b>3H000K0<SPf0<09bLW0P0T92@302l_;`80CDe=0`2>
SXh309FEU@80WinO0`2TY:@20:VYZ@<0/k>c0`2l_;`20;^k^`<0^;Rh0P2m_Kd30<71`@80`l?30`2i
^KT309nOW`80?Shn0`0W9bL2020P80<08B4Q0`0U9BD202LW9`<0:2PX0P0W9bL302DU9@<09bLW0P0Z
:RX302`/;080;bl_1P0`<30202l_;`<0;Rh^0P0X:2P302/[:`<0:2PX0P1PH60306e]K@80LW9b0`1P
H60504e=C@<0E5AD0P1MGEd306EUI@80IfMW0`1XJ6P306a/K080L71`0`1bLW8207AdM0<0MgMg0`1j
NWX207]kN`D0O7al0`1mOGd30820P0L0PX:20`23Ph<308F5Q@80QhN70`28R8P208V9R@<0RXZ:0`2<
S8`208n?S`d0TI6A0`2CTi<209FEU@D0UiNG1P2FUYH209FEU@<0UYJF0P2GUiL309VIV@<0VYZJ1@2K
Vi/209fMW@H0WYjN0P2MWId@09jNWPD0WinO0`2KVi/209JFUP<0UIFE1@2DU9@309:BTP80Shn?0`29
RHT207moO`<0MWIf0P1hN7P307alO0<0P8200P22PX8307alO080M7Ad0`1ZJVX3069RHP80H61P0`1R
HV8206YZJP<0LW9b0`1`L70206a/K0<0IVIV0P1QHF43061PH3@0b>3H0`0R8R8201lO7`<08b<S0P1A
DE4309:BTP<0UiNG0P2NWYh50::RXP<0[jn_0`32`/820;Vi^@<0_[jn0P30`<030<O7a`80a/K60`2l
_;`30::RXP80?3`l0`0S8b<202DU9@<08b<S0`0W9bL202PX:0<0:BTY200W9bL502/[:`80;bl_0`0]
;Bd302h^;PD0;bl_0P0Y:BT302@T90<0:BTY0P1OGel306][J`80L71`0`1VIVH304e=C@80CTi>0`1C
De<205mOG`<0IVIV0P1SHf<306YZJP<0K6a/0P1`L70306m_K`80N7Qh0`1eMGD307QhN0D0NWYj1@1m
OGd307inOP80Ph>30`22PX8208>3P`<0Q8B40`23Ph<208V9R@<0R8R80P2:RXX308R8R0P0T92@0P2B
TY83092@T0<0U9BD0P2BTY83096AT@80UiNG0`2FUYH209RHV0H0UYJF0P2CTi<309FEU@80VIVI0`2G
UiL309ZJVP80WinO0`2LW9`209^KV`<0WinO0`2MWId209nOW`<0WIfM0P2NWYh30:2PX0<0WIfM1@2O
Wil209jNWP<0W9bL0`2KVi/209JFUPP0U9BD0`2CTi<208b<S0<0Rh^;0P1lO7`307MgM`80NWYj0`1n
OWh30820P080PX:20`1hN7P207=cL`<0K6a/0`1UIFD2061PH0<0IVIV0P1]KFd307QhN0<0M7Ad0P1_
Kfl306UYJ@80H61P0`1TI6@L0<SPf0006`38h=P3028R8P806ATI0`0O7al2030`<0<0QhN70`2JVYX2
0:^[Z`D0[Jf]0`2h^;P30<;2`P80`<300`2l_;`20;no_`<0`L710P35aLD30;Vi^@<0[:b/0P1LG5`3
03Lg=`807alO0`0P820802PX:0809RHV0`0U9BD302HV9P80:2PX0`0/;2`2030`<0H0<S8b0P0`<303
02h^;P809bLW0`0Z:RX302DU9@80G5aL0`1[Jf/207=cL`<0H61P0`1<C4`204i>CP<0EEEE0P1LG5`3
069RHP80I6AT0`1UIFD306UYJ@80KVi^0`1bLW8207EeM@<0MgMg0`1iNGT207]kN`D0OGem0`1lO7`3
0820P080Ph>30`22PX820861P@<0PX:20`24Q8@208J6QP<0QhN70P29RHT308Z:RP<0Rh^;0P2<S8`3
092@T080Ti>C0`2BTY83096AT@80Ti>C0`2EUID209NGU`<0V9RH0P2GUiL309JFUPD0UiNG0`2FUYH2
09FEU@<0UiNG0`2IVIT209^KV`<0WIfM0P2NWYh809nOW`<0WYjN0P2MWId;09jNWPD0WinO0`2JVYX2
09BDU0D0UIFE0`2DU9@3096AT@80Rh^;0`25QHD207]kN`<0MGEe0P1kNg/308>3P`<0QhN70P26QXH3
07UiN@80IfMW0`1CDe<30492@P80?clo0`13@d<2055AD@H0GUiN0P1JFUX305QHF0D0EUIF=038h=P3
020P808071`L0`0R8R8202l_;`<0PH610`2TY:@20:JVYP<0ZZZZ0P2a/K430;Bd]0<0aLG50P2g]kL3
0;jn_P80_kno0`31`L420;jn_P<0_;bl0`2^[Zh206EUI@<0=3@d0P0S8b<3024Q8@D0:2PX0`0Z:RX5
02DU9@<09RHV0P0[:b/302XZ:P80=3@d0`0b<S8303@d=080;bl_0`0/;2`502LW9`<0;Rh^0P1JFUX3
06e]K@80L71`0`1YJFT304M7A`80Cdm?0`1EEED205aLG0<0HV9R0P1TI6@306IVIP<0JFUY0P1^KVh3
07AdM080Lg=c0`1iNGT307alO080NGUi0`20P80507emO@<0Ogmo0P23Ph<308:2PP80PH610`20P803
08F5Q@D0QhN70P28R8P308^;R`<0S8b<0P2;Rh/809>CT`<0SXj>0P2DU9@309>CT`80VIVI0`2GUiL5
09JFUP<0UIFE0P2HV9P309NGU`D0U9BD0`2HV9P209fMW@<0W9bL0P2OWil30:2PX0<0WYjN0P2OWil3
09^KV`80WYjN0`2LW9`309jNWP80WIfM0`2LW9`209nOW`<0XZ:R1@2FUYH309RHV080UIFE0`2DU9@3
08n?S`80Rh^;0`25QHD207]kN`<0MGEe0P1jNWX308B4Q0<0Ph>30P24Q8@30861P@80JFUY0`1GEeL3
04I6AP80>c/k0`17AdL2055AD@<0HF5Q0`1MGEd205aLG0<0EeMG0P1EEED305UIFA`0b>3H000K0<SP
f0<08R8R0P0I6AT301lO7`80<30`0`27QhL309ZJVP80Zj^[1@2][Jd30;Rh^0<0`/;20P30`<030;bl
_080_kno0`31`L420<G5a@<0^KVi0`2/[:`205aLG0<0=cLg0P0O7al3020P80P0:2PX0P0V9RH302DU
9@<09RHV0P0X:2P302`/;080<30`1P0b<S82030`<0<0;Rh^0P0W9bL302XZ:P<09BDU0P1LG5`306][
J`80Lg=c0`1PH60304a<C080CTi>0`1EEED205aLG0<0HV9R0P1TI6@306EUI@<0JFUY0P1^KVh3079b
LP80MGEe0`1gMgL307UiN@80Ng]k1@1mOGd307alO0<0P8200P23Ph<308:2PP80PH610`22PX8308B4
Q080QXJ60`27QhL208V9R@<0RXZ:0`2;Rh/208b<S0<0T92@0P2CTi<309:BTP<0TI6A0P2CTi<309FE
U@80UiNG0`2HV9P209NGU`<0UYJF1@2GUiL309JFUP80UIFE0`2GUiL309VIV@80Vi^K0`2MWId209jN
WPP0WinO0`2NWYh209fMW@/0WYjN1@2OWil309ZJVP80U9BD1@2EUID309BDU0<0TI6A0P2;Rh/308F5
Q@80Ng]k0`1eMGD207]kN`<0Ph>30`27QhL208J6QP<0NGUi0P1WIfL305=CD`<0@T920P0o?cl304=3
@`80DE5A1P1NGUh205YJFP<0F5QH1@1FEUHd0<SPf0<0820P0P0L71`3028R8P80;bl_0`21PH430:BT
Y080YZJV0`2ZZZX20;6a/@<0];Bd0`35aLD20;Ng]`<0_[jn0P2o_kl30<71`@80_[jn0`2l_;`30:j^
[P80IFEU0`0d=3@202<S8`<08B4Q1@0X:2P302XZ:PD09BDU0`0V9RH202/[:`<0:RXZ0P0d=3@3038b
<P<0=3@d0P0_;bl302`/;0D09bLW0`0^;Rh205YJFP<0KFe]0P1`L70306UYJ@<0AdM70P1?Cdl305EE
E@80G5aL0`1RHV8206ATI0<0IVIV0`1YJFT206i^KP<0M7Ad0P1cLg<307UiN@<0O7al0P1iNGT30820
P0D0OGem0`1oOgl208>3P`<0PX:20P21PH430820P0<0QHF51@27QhL208R8R0<0Rh^;0`2<S8`208^;
R`P0Ti>C0`2>SXh209BDU0<0Ti>C0P2IVIT309NGU`D0UYJF0`2EUID209RHV0<0UiNG1@2DU9@309RH
V080WIfM0`2LW9`209nOW`<0X:2P0`2NWYh209nOW`<0Vi^K0P2NWYh309bLW0<0WYjN0P2MWId309bL
W080WinO0`2RXZ8509JFUP<0V9RH0P2EUID309BDU0<0Shn?0P2;Rh/308F5Q@80Ng]k0`1eMGD207Yj
NP<0Q8B40`23Ph<208B4Q0<0PH610P1YJFT305MGE`<0ATI60P0k>c/304M7A`80DE5A0`1QHF4305eM
G@80G5aL0`1GEeL205EEE@<0FEUI7038h=P001/0b>3H0`0R8R8201XJ6P<071`L0P0W9bL305]KF`<0
ZJVY0P2][Jd30;Bd]080Zj^[0`2g]kL30<71`@80_Kfm0`2g]kL20;^k^`<0_kno0P2n_[h30;Fe]@<0
`<300P2RXZ8307]kN`80<c<c1P0Y:BT202HV9P<092@T1@0S8b<302@T90809BDU0`0Z:RX202l_;`<0
<30`0`0_;bl202`/;0<0:RXZ0P0V9RH302/[:`<09RHV0P1QHF4306QXJ080JVYZ0`1LG5`304e=C@80
CTi>0`1CDe<205UIF@<0H61P0P1RHV8306ATI0<0JVYZ0P1`L70307=cL`80MWIf0`1hN7P507YjNP<0
Ng]k0P1mOGd307moO`<0P8201`21PH4308>3P`<0QXJ60P28R8P808Z:RP<0Rh^;0P2=SHd3092@T0D0
TI6A0`2@T90209BDU0<0V9RH0P2GUiL309FEU@80UYJF0`2GUiL509VIV@<0V9RH0P2FUYH309NGU`<0
VIVI0P2KVi/309bLW080WIfM2`2NWYh209fMW@P0WYjN0`2MWId509nOW`<0VYZJ0P2EUID309BDU080
Ti>C0`2@T90308b<S080QhN70`21PH4207YjNP<0MgMg0P1mOGd308F5Q@<0R8R80P27QhL307emO@80
KVi^0`1@D50303Hf=P80<C4a0`0g=cL204E5A@<0EEEE0`1MGEd2069RHP<0I6AT0P1UIFD306IVIS@0
b>3H0`0U9BD2028R8P<07alO0P0Q8B4305QHF0<0[Jf]0P2a/K430:f][@80/k>c0`2j^[X30<C4a080
];Bd0`2g]kL20;fm_@<0_;bl0P2n_[h30;Ng]`<0[Zj^0P2RXZ8307AdM080<30`0`0Y:BT302XZ:P80
8b<S0`0Q8B4502HV9PD09BDU0`0V9RH202`/;0<0>3Ph0`0^;Rh202XZ:P<0;Rh^1@0[:b/302d];@80
EeMG0`1ZJVX2069RHP<0GemO0`1;Bd/204U9B@<0DE5A0P1PH60305iNGP80H61P0`1RHV8306][J`80
L71`0`1aLG4207EeM@<0NGUi0`1hN7P507YjNP80Ng]k0`20P8030861P@80PX:20`20P80508:2PP<0
QXJ60P2:RXX308V9R@D0R8R80`2;Rh/208Z:RP<0T92@0P2?Shl308f=S@<0SXj>0P2JVYX509JFUP<0
Ti>C1@2IVIT309JFUP80Vi^K0`2LW9`209RHV0<0UIFE0`2JVYX209bLW0D0VYZJ0`2MWId309bLW080
X:2P0`2OWil209jNWPH0WinO0P2NWYh30:2PX080WinO0`2QXJ4309RHV080Ti>C0`2DU9@2096AT@<0
SHf=0`2?Shl208Z:RP<0PX:20P1gMgL307UiN@80PH610`24Q8@308J6QP80R8R80`23Ph<206EUI@<0
@D510`0b<S82034a<@<0<S8b0P10@40304e=C@<0FEUI0P1PH60305YJFP80Hf=S0`1aLG4L0<SPf000
6`38h=P3028R8P806QXJ0`0L71`202LW9`<0Fe]K0`2YZJT20:f][@<0];Bd0P2[Zj/30;Ng]`<0`L71
0P2m_Kd30;Ng]`80^k^k0`2o_kl20;jn_P<0]KFe0`30`<020::RXP<0Ng]k0P0c<c<602TY:@809RHV
0`0T92@502<S8`<092@T0P0U9BD302XZ:P80;bl_0`0`<30302l_;`80;2`/0`0Z:RX202HV9P<0:b/[
0`0V9RH2065QH@<0J6QX0P1ZJVX305aLG0<0CDe=0P1>CTh305=CD`80FEUI0`1PH602069RHP<0I6AT
0`1ZJVX2071`L0<0Lg=c0P1fMWH307QhN0D0NWYj0`1kNg/207emO@<0Ogmo0`20P8070861P@<0Ph>3
0`26QXH208R8R0P0RXZ:0`2;Rh/208f=S@<0T92@1@2ATI43092@T080U9BD0`2HV9P209NGU`<0UIFE
0P2FUYH309NGU`D0VIVI0`2HV9P209JFUP<0UiNG0`2IVIT209^KV`<0W9bL0P2MWId;09jNWP80WIfM
202NWYh309fMW@D0WinO0`2JVYX209FEU@<0U9BD0P2CTi<3092@T0<0S8b<0P27QhL30861P@80NWYj
0`1gMgL207emO@<0QHF50`28R8P208N7Q`<0OGem0P1^KVh3051@D0<0=SHf0P0a<C4303Lg=`80ADE5
0`1EEED305eMG@80HV9R0`1TI6@206EUI@<0IVIV=038h=P302DU9@808R8R0`0O7al2024Q8@<0F5QH
0`2][Jd20;6a/@<0[Jf]0P2c/k<30;Zj^P<0a<C40P2d];@30;Ng]`80_Kfm0`2l_;`20;jn_P<0]kNg
0`2^[Zh20::RXP<0M7Ad0P0`<30302TY:@<0:RXZ0P0S8b<3024Q8@D09RHV1@0U9BD302HV9P80;2`/
0`0h>3P302h^;P80:RXZ0`0^;Rh502/[:`<0;Bd]0P1GEeL306YZJP80HV9R0`1OGel304];B`80BDU9
0`1ADE42061PH0<0GUiN0P1PH603069RHP<0Jf][0P1`L703075aL@80MGEe0`1iNGT307QhN0D0NWYj
0P1kNg/30820P0<0PH610P22PX830820P0D0PX:20`26QXH208Z:RP<0RHV91@28R8P308^;R`80RXZ:
0`2@T90208n?S`<0SHf=0`2>SXh209ZJVPD0UYJF0`2CTi<509VIV@<0UYJF0P2KVi/309bLW080V9RH
0`2EUID309ZJVP80W9bL1@2JVYX309fMW@<0W9bL0P2PX:0309nOW`80WYjN1P2OWil209jNWP<0X:2P
0P2OWil30:6QX@<0V9RH0P2CTi<309BDU080TI6A0`2=SHd308n?S`80RXZ:0`22PX8207MgM`<0NGUi
0P21PH4308B4Q0<0QXJ60P28R8P308>3P`80IFEU0`11@D43038b<P80<C4a0`0b<S820410@0<0CDe=
0`1IFET2061PH0<0FUYJ0P1SHf<3075aLA`0b>3H000K0<SPf0<08R8R0P0J6QX301`L70809bLW0`1K
Fe/30:VYZ@80[Jf]0`2d];@20:^[Z`<0]kNg0`31`L420;fm_@<0]kNg0P2k^k/30;no_`80_[jn0`2e
]KD30<30`080XZ:R0`1kNg/203<c<`H0:BTY0P0V9RH302@T90D08b<S0`0T92@202DU9@<0:RXZ0P0_
;bl3030`<0<0;bl_0P0/;2`302XZ:P809RHV0`0[:b/302HV9P80HF5Q0`1XJ6P206YZJP<0G5aL0`1=
CDd204i>CP<0De=C0P1IFET3061PH080HV9R0`1TI6@306YZJP80L71`0`1cLg<207IfMP<0N7Qh1@1j
NWX307]kN`80OGem0`1oOgl30820P0L0PH610`23Ph<308J6QP80R8R8202:RXX308^;R`80SHf=0`2@
T905096AT@<0T92@0P2DU9@309RHV080UiNG0`2EUID209JFUP<0UiNG1@2IVIT309RHV080UYJF0`2G
UiL309VIV@80Vi^K0`2LW9`209fMW@/0WYjN0P2MWId809jNWP<0WIfM1@2OWil309ZJVP80UIFE0`2D
U9@209>CT`<0T92@0`2<S8`208N7Q`<0PH610P1jNWX307MgM`80OGem0`25QHD308R8R080QhN70`1m
OGd206i^KP<0D51@0`0f=SH2034a<@<0=cLg0P15ADD305EEE@<0GEeM0P1RHV8306ATI080IFEU0`1V
IVHd0<SPf0<09BDU0P0R8R8301lO7`808B4Q0`1HF5P30:f][@80/K6a0`2][Jd20;>c/`<0^[Zj0`34
a<@20;Bd]0<0]kNg0P2m_Kd30;bl_080_[jn0`2g]kL30:j^[P80XZ:R0`1dM7@2030`<0<0:BTY0`0Z
:RX202<S8`<08B4Q1@0V9RH502DU9@<09RHV0P0/;2`303Ph>0<0;Rh^0P0Z:RX302h^;PD0:b/[0`0]
;Bd205MGE`<0JVYZ0P1RHV8305mOG`<0Bd];0P19BDT3055AD@80H61P0`1NGUh2061PH0<0HV9R0`1[
Jf/2071`L0<0LG5a0P1eMGD307UiN@<0N7Qh1@1jNWX207]kN`<0P8200`21PH4208:2PP<0P8201@22
PX8308J6QP80RXZ:0`29RHT508R8R0<0Rh^;0P2:RXX3092@T080Shn?0`2=SHd308j>SP80VYZJ1@2F
UYH309>CT`D0VIVI0`2FUYH209^KV`<0W9bL0P2HV9P309FEU@<0VYZJ0P2LW9`509ZJVP<0WIfM0`2L
W9`20:2PX0<0WinO0P2NWYh609nOW`80WYjN0`2PX:0209nOW`<0XJ6Q0`2HV9P209>CT`<0U9BD0P2A
TI4308f=S@<0Shn?0P2:RXX308:2PP80MgMg0`1iNGT20861P@<0Q8B40`26QXH208R8R0<0Ph>30P1U
IFD30451@@<0<S8b0P0a<C43038b<P80@4100`1=CDd305UIF@80H61P0`1JFUX206=SH`<0LG5a7038
h=P001/0b>3H0`0S8b<201lO7`<07AdM0P0S8b<302h^;P<0[Zj^0P2[Zj/30;Fe]@80Z:RX0`2c/k<3
0;bl_080][Jf0`2`/;020;Jf]P<0^k^k0P2h^;P30;:b/P<0[Zj^0P2RXZ8309^KV`80DU9B0`0o?cl3
034a<@80:2PX0`0R8R82024Q8@H08R8R0P0S8b<302PX:0D0;Bd]0`0/;2`202TY:@<09bLW0P0T92@3
02/[:`<0:RXZ0P1UIFD306IVIP80HF5Q0`1GEeL304e=C@80C4a<0`1@D50205IFEP<0GEeM0P1PH603
06ATI0<0K6a/0P1cLg<307EeM@80MWIf0`1iNGT307alO080NWYj0`1iNGT207inOP<0PX:20`21PH42
07inOP<0P8200P22PX8308B4Q0<0QhN70P2:RXX308b<S080Rh^;0`2:RXX308b<S080SXj>202?Shl3
092@T080UIFE0`2JVYX209NGU`<0Ti>C0P2EUID309RHV0D0VYZJ0`2IVIT209NGU`<0V9RH0`2JVYX5
09^KV`80W9bL2`2MWId509jNWP<0WinO0P2MWId309bLW080WYjN0`2OWil309ZJVP80UIFE0`2CTi<2
096AT@<0SHf=0`29RHT208>3P`<0OGem0P1iNGT307QhN080Ogmo0`26QXH308R8R080QhN70`24Q8@2
07UiN@<0EUIF0`0f=SH2034a<@<0=SHf0P12@T83055AD@<0HV9R0P1aLG4307IfMP80N7Qh0`1iNGTd
0<SPf0<0820P1@0M7Ad201lO7`<0=cLg0`2RXZ820;Bd]0<0[:b/0P2_[jl30:f][@<0_kno1@2c/k<2
0;Rh^0<0_Kfm0P2i^KT30;>c/`<0[jn_0P2WYjL30:6QX@80Fe]K0`0l?3`303De=@809bLW0`0U9BD2
024Q8@H08R8R0P0V9RH302TY:@80;Bd]1P0_;bl202DU9@<09bLW0P0Y:BT302DU9@<0;Rh^0P1NGUh3
06i^KP80F5QH0`1KFe/304M7A`80D51@0`1<C4`205IFEP<0GEeM0P1RHV8306EUI@<0JVYZ0P1gMgL3
07=cL`80NGUi0`1gMgL307emO@80O7al0`1jNWX207emO@<0PX:20`20P80207moO`<0OWin0P22PX83
08B4Q0<0QhN70P2:RXX308f=S@80S8b<0`2;Rh/308Z:RPD0T92@0P2ATI46092@T080UIFE0`2KVi/2
09BDU0<0TY:B0P2JVYX309BDU0<0UiNG0P2JVYX309bLW080UIFE0`2HV9P309VIV@80WIfM0`2IVIT2
09nOW`<0W9bL0`2NWYh209bLW0<0WYjN0P2LW9`309jNWPD0WIfM0`2IVIT209nOW`<0WIfM0`2LW9`2
09JFUP<0TY:B0P2DU9@608Z:RP80QhN70`20P80207AdM0<0N7Qh0P27QhL308B4Q0<0QHF50P24Q8@3
08Z:RP80N7Qh0`1FEUH303Xj>P80>3Ph0`0i>CT204U9B@<0FEUI0`1VIVH2079bLP<0Lg=c0P1gMgL3
07inOQ`0b>3H000K0<SPf0<08b<S0P0O7al301dM7@808b<S0`0^;Rh30:j^[P80Zj^[0`2e]KD20:RX
Z0<0/k>c0`2l_;`20;Jf]P<0/;2`0P2f][H30;^k^`80^;Rh0`2b/[830:j^[P80XZ:R0`2KVi/2059B
DP<0?clo0`0a<C4202PX:0<08R8R0P0Q8B46028R8P808b<S0`0X:2P502d];@<0;2`/0P0Y:BT302LW
9`8092@T0`0[:b/302XZ:P80IFEU0`1VIVH2065QH@<0EeMG0`1=CDd204a<C0<0D51@0P1FEUH305eM
G@80H61P0`1TI6@306a/K080Lg=c0`1eMGD207IfMP<0NGUi0`1lO7`207YjNP<0NGUi0P1nOWh308:2
PP<0PH610P1nOWh30820P080PX:20`24Q8@308N7Q`80RXZ:0`2<S8`208^;R`<0RXZ:0`2<S8`208j>
SPP0Shn?0`2@T90209FEU@<0VYZJ0P2GUiL309>CT`80UIFE0`2HV9P509ZJVP<0VIVI0P2GUiL309RH
V0<0VYZJ1@2KVi/209bLW0/0WIfM1@2NWYh309nOW`80WIfM0`2LW9`209jNWP<0WinO0`2JVYX209FE
U@<0Ti>C0P2ATI4308f=S@<0RHV90P23Ph<307emO@80NGUi0`1hN7P207moO`<0QXJ60`28R8P208N7
Q`<0Q8B40P1iNGT305IFEP<0=SHf0P0a<C4303Hf=P80@T920`1ADE43069RHP80LG5a0`1fMWH207Qh
N0<0NGUi=038h=P3020P80D07AdM0P0O7al303Lg=`<0XZ:R0P2d];@30:b/[080[jn_0`2][Jd30;no
_`D0/k>c0P2h^;P30;fm_@80^KVi0`2c/k<30:n_[`80YjNW0`2QXJ4205]KF`<0?3`l0`0e=CD202LW
9`<09BDU0P0Q8B46028R8P809RHV0`0Y:BT202d];@H0;bl_0P0U9BD302LW9`80:BTY0`0U9BD302h^
;P80GUiN0`1^KVh205QHF0<0Fe]K0`17AdL2051@D0<0C4a<0P1FEUH305eMG@80HV9R0`1UIFD306YZ
JP80MgMg0`1cLg<207UiN@<0MgMg0`1mOGd207alO0<0NWYj0P1mOGd308:2PP<0P8200P1oOgl307in
OP80PX:20`24Q8@308N7Q`80RXZ:0`2=SHd208b<S0<0Rh^;0`2:RXX5092@T080TI6A1P2@T90209FE
U@<0Vi^K0P2DU9@309:BTP80VYZJ0`2DU9@309NGU`80VYZJ0`2LW9`209FEU@<0V9RH0`2IVIT209fM
W@<0VIVI0P2OWil309bLW0<0WYjN0P2LW9`309jNWP80W9bL0`2NWYh509fMW@<0VIVI0P2OWil309fM
W@<0W9bL0P2FUYH309:BTP80U9BD1P2:RXX208N7Q`<0P8200P1dM7@307QhN080QhN70`24Q8@308F5
Q@80Q8B40`2:RXX207QhN0<0EUIF0`0j>SX203Ph>0<0>CTi0P19BDT305UIF@<0IVIV0P1bLW8307=c
L`80MgMg0`1nOWhL0<SPf0006`38h=P302DU9@808B4Q0`0L71`201/K6`<08B4Q0`2=SHd20;2`/0<0
Xj>S0P2ZZZX30:f][@<0/K6a0P2`/;030:n_[`80/[:b0`2e]KD20;Ng]`<0^;Rh0`2e]KD20;>c/`<0
`<300P2RXZ8307QhN0<0Bd];0P0d=3@302HV9P809BDU0`0S8b<5028R8P<09bLW1@0];Bd302`/;080
:b/[0`0Z:RX202DU9@<09RHV0`0f=SH205iNGP<0I6AT0P1RHV8305EEE@<0AdM70P16ATH304];B`80
De=C0`1LG5`2065QH@<0IFEU0`1]KFd207AdM0<0MGEe0P1fMWH307YjNPP0OGem0P20P80308:2PP<0
P8200P1nOWh30820P080PX:20`24Q8@308J6QP80RHV90`2;Rh/208b<S0P0SHf=0`2?Shl5096AT@<0
T92@0P2CTi<:09JFUP<0UiNG0`2HV9P209VIV@<0UiNG0P2FUYH309RHV0<0VYZJ0P2LW9`309fMW@80
Vi^K0`2JVYX309bLW0D0WinO0P2NWYh609nOW`80WIfM0`2LW9`509fMW@<0VIVI0P2DU9@309:BTP80
T92@0`2?Shl308f=S@80PH610`1fMWH207AdM0<0MWIf0P1lO7`308>3P`<0QhN70P29RHT308F5Q@80
Ogmo0`1lO7`307UiN@80N7Qh0`1iNGT20861P@<0R8R80`24Q8@207inOPD0OGem0`1lO7`d0<SPf0<0
:BTY0P0P8203024Q8@807AdM0`0U9BD308b<S080[Zj^0`2UYJD50:NWY`D0];Bd0`2YZJT50;2`/080
];Bd0`2i^KT30;Bd]080][Jf0`2d];@209VIV@<0Ng]k0`1<C4`202d];@<0:BTY0P0V9RH3020P80P0
8R8R0P0`<30302d];@<0:b/[0P0V9RH302PX:080:BTY0`0U9BD303@d=080H61P0`1_Kfl206ATI0<0
G5aL0`16ATH204e=C@<0C4a<0P1EEED305aLG080GEeM0`1VIVH306e]K@80M7Ad0`1_Kfl207UiN@<0
NWYj0`1mOGd20820P0<0O7al0P1mOGd308F5Q@<0Ogmo0P1mOGd508>3P`<0PX:20`28R8P208J6QP<0
S8b<0P2:RXX3096AT@D0SHf=0`2?Shl2092@T0<0SHf=0`2BTY8509FEU@80UYJF0`2GUiL209FEU@<0
VYZJ0`2HV9P209FEU@<0UiNG0P2EUID309NGU`<0VIVI1@2LW9`209nOW`<0V9RH0`2MWId709jNWP<0
X:2P0`2OWil20:2PX0<0WIfM0P2KVi/309jNWP<0UiNG0P2FUYH308n?S`80U9BD1P2:RXX208B4Q0<0
LG5a0P1/K6`3075aL@80PH610`1oOgl308V9R@80QhN71@25QHD308>3P`<0MgMg0P1`L70307EeM@80
OWin0`1oOgl30820P080PX:20`24Q8@207inOP<0NWYj7038h=P001/0b>3H0`0U9BD2024Q8@<071`L
0P0K6a/3024Q8@<0SHf=0P2`/;030:>SX`80ZZZZ0`2][Jd30;6a/@80/;2`0`2_[jl20;:b/P<0]KFe
0P2g]kL30;Rh^0<0]KFe0P2c/k<30<30`080XZ:R0`1hN7P304];B`80=3@d0`0V9RH202DU9@<08b<S
1@0R8R8302LW9`D0;Bd]0`0/;2`202/[:`<0:RXZ0P0U9BD302HV9P<0=SHf0P1NGUh306ATI080HV9R
0`1EEED304M7A`80ATI60`1;Bd/205=CD`<0G5aL0P1QHF4306EUI@<0KFe]0P1dM7@307EeM@80MWIf
0`1jNWX807emO@80P8200`22PX830820P080OWin0`20P80208:2PP<0Q8B40`26QXH208V9R@<0Rh^;
0P2<S8`808f=S@<0Shn?1@2ATI43092@T080Ti>C2P2FUYH309NGU`<0V9RH0P2IVIT309NGU`80UYJF
0`2HV9P309ZJVP80W9bL0`2MWId209^KV`<0VYZJ0`2LW9`509nOW`80WYjN1P2OWil209fMW@<0W9bL
1@2MWId309VIV@80U9BD0`2BTY82092@T0<0Shn?0`2=SHd20861P@<0MWIf0P1dM7@307IfMP80O7al
0`23Ph<308N7Q`80RHV90`25QHD207moO`<0O7al0`1iNGT207QhN0<0NGUi0P21PH4308R8R0<0Q8B4
0P1nOWh507emO@<0O7al=038h=P302TY:@80820P0`0Q8B4201dM7@<09BDU0`2<S8`20:j^[P<0YJFU
1@2WYjL50;Bd]0<0ZJVY1@2`/;020;Bd]0<0^KVi0`2d];@20;Jf]P<0];Bd0P2IVIT307]kN`<0C4a<
0P0];Bd302TY:@809RHV0`0P8208028R8P80<30`0`0];Bd302/[:`809RHV0`0X:2P202TY:@<09BDU
0`0d=3@2061PH0<0Kfm_0P1TI6@305aLG0<0ATI60P1=CDd304a<C080EEEE0`1LG5`205eMG@<0IVIV
0`1]KFd207AdM0<0Kfm_0P1iNGT307YjNP<0OGem0P20P80307alO080OGem0`25QHD307moO`80OGem
1@23Ph<308:2PP<0R8R80P26QXH308b<S080RXZ:0`2ATI4508f=S@<0Shn?0P2@T90308f=S@<0TY:B
1@2EUID209JFUP<0UiNG0P2EUID309ZJVP<0V9RH0P2EUID309NGU`80UIFE0`2GUiL309VIV@D0W9bL
0P2OWil309RHV0<0WIfM1`2NWYh30:2PX0<0WinO0P2PX:0309fMW@80Vi^K0`2NWYh309NGU`80UYJF
0`2?Shl209BDU0H0RXZ:0P24Q8@3075aL@80K6a/0`1aLG420861P@<0Ogmo0`29RHT208N7Q`D0QHF5
0`23Ph<307MgM`80L71`0`1eMGD207inOP<0Ogmo0`20P80208:2PP<0Q8B40P1nOWh307YjNQ`0b>3H
000K0<SPf0<09BDU0P0Q8B4301`L70806a/K0`0Q8B4308f=S@80/;2`0`2SXj<20:ZZZP<0[Jf]0`2a
/K420;2`/0<0[jn_0P2b/[830;Fe]@80]kNg0`2h^;P30;Fe]@80/k>c0`30`<020::RXP<0N7Qh0`1;
Bd/203@d=0<09RHV0P0U9BD302<S8`D08R8R0`0W9bL502d];@<0;2`/0P0[:b/302XZ:P809BDU0`0V
9RH303Hf=P80GUiN0`1TI6@2069RHP<0EEEE0`17AdL204I6AP<0Bd];0P1CDe<305aLG080HF5Q0`1U
IFD306e]K@80M7Ad0`1eMGD207IfMP<0NWYj201mOGd20820P0<0PX:20`20P80207inOP<0P8200P22
PX8308B4Q0<0QXJ60P29RHT308^;R`80S8b<202=SHd308n?S`D0TI6A0`2@T90209>CT`X0UYJF0`2G
UiL309RHV080VIVI0`2GUiL209JFUP<0V9RH0`2JVYX209bLW0<0WIfM0P2KVi/309ZJVP<0W9bL1@2O
Wil209jNWPH0WinO0P2MWId309bLW0D0WIfM0`2IVIT209BDU0<0TY:B0P2@T90308n?S`<0SHf=0P21
PH4307IfMP80M7Ad0`1fMWH207alO0<0Ph>30`27QhL208V9R@<0QHF50P1oOgl307alO0<0NGUi0P1h
N7P307UiN@80PH610`28R8P308B4Q080OWin1@1mOGd307alO3@0b>3H0`0Y:BT2020P80<08B4Q0P0M
7Ad302DU9@<0S8b<0P2^[Zh30:FUY@D0YjNW1@2d];@30:VYZ@D0/;2`0P2d];@30;Vi^@<0];Bd0P2f
][H30;Bd]080VIVI0`1kNg/304a<C080;Bd]0`0Y:BT202HV9P<0820P200R8R82030`<0<0;Bd]0`0[
:b/202HV9P<0:2PX0P0Y:BT302DU9@<0=3@d0P1PH60306m_K`80I6AT0`1LG5`304I6AP80CDe=0`1<
C4`205EEE@<0G5aL0P1MGEd306IVIP<0KFe]0P1dM7@306m_K`80NGUi0`1jNWX307emO@80P8200`1l
O7`207emO@<0QHF50`1oOgl207emO@D0Ph>30`22PX8308R8R080QXJ60`2<S8`208Z:RP<0TI6A1@2=
SHd308n?S`80T92@0`2=SHd309:BTPD0UIFE0P2FUYH309NGU`80UIFE0`2JVYX309RHV080UIFE0`2G
UiL209FEU@<0UiNG0`2IVIT509bLW080WinO0`2HV9P309fMW@L0WYjN0`2PX:0309nOW`80X:2P0`2M
WId209^KV`<0WYjN0`2GUiL209JFUP<0Shn?0P2DU9@608Z:RP80Q8B40`1aLG4206a/K0<0LG5a0P21
PH4307moO`<0RHV90P27QhL508F5Q@<0Ph>30`1gMgL2071`L0<0MGEe0P1nOWh307moO`<0P8200P22
PX8308B4Q080OWin0`1jNWXL0<SPf0006`38h=P302LW9`808R8R0`0M7Ad201DE5@<07alO0`1SHf<2
0:j^[P<0Ti>C0P2[Zj/30:NWY`<0YZJV0P2YZJT30:f][@D0[:b/0P2b/[860;Ng]`80];Bd0`2b/[82
0:f][@<0T92@0`1^KVh204a<C0<0<30`0P0X:2P302@T90<08R8R0P0S8b<302LW9`80;2`/1P0];Bd2
02h^;P<0;Bd]0P0U9BD3024Q8@<0?clo0P1GEeL306ATI080IFEU0`1DE5@30492@P80@D510`16ATH2
051@D0<0Fe]K0P1QHF4306IVIP<0KFe]0P1cLg<307EeM@80MWIf0`1jNWX307inOPD0P8200P21PH43
08:2PP<0P8200P1oOgl30861P@80Ph>30`24Q8@308F5Q@80QhN70`29RHT208f=S@<0Shn?0`2=SHd2
08^;R`<0Shn?1@2BTY85096AT@<0TY:B0P2FUYH309VIV@80V9RH1P2FUYH209NGU`D0UYJF0`2HV9P3
09^KV`80WIfM0`2OWil209^KV`<0V9RH0`2LW9`50:2PX0P0WinO0P2MWId509bLW0<0VYZJ0`2GUiL2
09BDU0<0TI6A0P2?Shl3096AT@<0T92@0P20P803071`L080Kfm_0`1cLg<207QhN0<0Ogmo0`26QXH5
08^;R`80R8R80`25QHD308:2PP80Q8B41@25QHD308B4Q0<0RHV90P2;Rh/308B4Q080OGem0`1kNg/d
0<SPf0<0:RXZ0P0P820501/K6`<07AdM0`1RHV820:RXZ0<0WIfM0P2ZZZX30:RXZ0<0YZJV0P2_[jl3
0:VYZ@80[:b/0`2WYjL20;6a/@H0]KFe0P2h^;P30;fm_@80[Jf]0`2<S8`307MgM`80Cdm?0`0g=cL2
02TY:@<092@T1@0V9RH302LW9`80;2`/0`0Y:BT5034a<@<0;bl_0P0V9RH302LW9`<0<S8b0P1HF5P3
06UYJ@80Fe]K0`1FEUH303hn?P80>SXj0`17AdL205EEE@<0FUYJ0P1PH60306EUI@<0KVi^0P1dM7@3
07=cL`80MWIf0`1mOGd307alO080Ogmo0`23Ph<207emO@<0Q8B40`20P80207moO`<0Ph>30P20P803
08F5Q@<0QXJ60P23Ph<308^;R`80T92@0`2>SXh308V9R@D0SHf=0P2GUiL308f=S@<0Shn?0P2HV9P3
08n?S`80UYJF0`2IVIT209>CT`<0UiNG0`2EUID509NGU`80U9BD0`2KVi/509bLW0<0X:2P0P2JVYX3
09NGU`<0W9bL0P2QXJ4509nOW`H0WYjN0P2LW9`309^KV`80VYZJ0`2KVi/309JFUP80TI6A0`2BTY82
092@T0<0Rh^;0`2DU9@20820P0<0M7Ad0P1/K6`307AdM080O7al0`1mOGd308N7Q`80RXZ:0`27QhL2
08J6QP<0QhN70`26QXH208B4Q0<0QXJ60P2=SHd308V9R@<0Q8B40P2;Rh/308B4Q080OWin0`1gMgLL
0<SPf0006`38h=P302LW9`808R8R0`0M7Ad201DE5@<07alO0`1SHf<20:j^[P<0Ti>C0P2[Zj/30:NW
Y`<0YZJV0P2YZJT30:f][@D0[:b/0P2b/[860;Ng]`80];Bd0`2b/[820:f][@<0T92@0`1^KVh204a<
C0<0<30`0P0X:2P302@T90<08R8R0P0S8b<302LW9`80;2`/1P0];Bd202h^;P<0;Bd]0P0U9BD3024Q
8@<0?clo0P1GEeL306ATI080IFEU0`1DE5@30492@P80@D510`16ATH2051@D0<0Fe]K0P1QHF4306IV
IP<0KFe]0P1cLg<307EeM@80MWIf0`1jNWX307inOPD0P8200P21PH4308:2PP<0P8200P1oOgl30861
P@80Ph>30`24Q8@308F5Q@80QhN70`29RHT208f=S@<0Shn?0`2=SHd208^;R`<0Shn?1@2BTY85096A
T@<0TY:B0P2FUYH309VIV@80V9RH1P2FUYH209NGU`D0UYJF0`2HV9P309^KV`80WIfM0`2OWil209^K
V`<0V9RH0`2LW9`50:2PX0P0WinO0P2MWId509bLW0<0VYZJ0`2GUiL209BDU0<0TI6A0P2?Shl3096A
T@<0T92@0P20P803071`L080Kfm_0`1cLg<207QhN0<0Ogmo0`26QXH508^;R`80R8R80`25QHD308:2
PP80Q8B41@25QHD308B4Q0<0RHV90P2;Rh/308B4Q080OGem0`1kNg/d0<SPf0<0:RXZ0P0P820501/K
6`<07AdM0`1RHV820:RXZ0<0WIfM0P2ZZZX30:RXZ0<0YZJV0P2_[jl30:VYZ@80[:b/0`2WYjL20;6a
/@H0]KFe0P2h^;P30;fm_@80[Jf]0`2<S8`307MgM`80Cdm?0`0g=cL202TY:@<092@T1@0V9RH302LW
9`80;2`/0`0Y:BT5034a<@<0;bl_0P0V9RH302LW9`<0<S8b0P1HF5P306UYJ@80Fe]K0`1FEUH303hn
?P80>SXj0`17AdL205EEE@<0FUYJ0P1PH60306EUI@<0KVi^0P1dM7@307=cL`80MWIf0`1mOGd307al
O080Ogmo0`23Ph<207emO@<0Q8B40`20P80207moO`<0Ph>30P20P80308F5Q@<0QXJ60P23Ph<308^;
R`80T92@0`2>SXh308V9R@D0SHf=0P2GUiL308f=S@<0Shn?0P2HV9P308n?S`80UYJF0`2IVIT209>C
T`<0UiNG0`2EUID509NGU`80U9BD0`2KVi/509bLW0<0X:2P0P2JVYX309NGU`<0W9bL0P2QXJ4509nO
W`H0WYjN0P2LW9`309^KV`80VYZJ0`2KVi/309JFUP80TI6A0`2BTY82092@T0<0Rh^;0`2DU9@20820
P0<0M7Ad0P1/K6`307AdM080O7al0`1mOGd308N7Q`80RXZ:0`27QhL208J6QP<0QhN70`26QXH208B4
Q0<0QXJ60P2=SHd308V9R@<0Q8B40P2;Rh/308B4Q080OWin0`1gMgLL0<SPf0006`38h=P302LW9`80
8R8R0`0M7Ad201DE5@<07alO0`1SHf<20:j^[P<0Ti>C0P2[Zj/30:NWY`<0YZJV0P2YZJT30:f][@D0
[:b/0P2b/[860;Ng]`80];Bd0`2b/[820:f][@<0T92@0`1^KVh204a<C0<0<30`0P0X:2P302@T90<0
8R8R0P0S8b<302LW9`80;2`/1P0];Bd202h^;P<0;Bd]0P0U9BD3024Q8@<0?clo0P1GEeL306ATI080
IFEU0`1DE5@30492@P80@D510`16ATH2051@D0<0Fe]K0P1QHF4306IVIP<0KFe]0P1cLg<307EeM@80
MWIf0`1jNWX307inOPD0P8200P21PH4308:2PP<0P8200P1oOgl30861P@80Ph>30`24Q8@308F5Q@80
QhN70`29RHT208f=S@<0Shn?0`2=SHd208^;R`<0Shn?1@2BTY85096AT@<0TY:B0P2FUYH309VIV@80
V9RH1P2FUYH209NGU`D0UYJF0`2HV9P309^KV`80WIfM0`2OWil209^KV`<0V9RH0`2LW9`50:2PX0P0
WinO0P2MWId509bLW0<0VYZJ0`2GUiL209BDU0<0TI6A0P2?Shl3096AT@<0T92@0P20P803071`L080
Kfm_0`1cLg<207QhN0<0Ogmo0`26QXH508^;R`80R8R80`25QHD308:2PP80Q8B41@25QHD308B4Q0<0
RHV90P2;Rh/308B4Q080OGem0`1kNg/d0<SPf0<0:RXZ0P0P820501/K6`<07AdM0`1RHV820:RXZ0<0
WIfM0P2ZZZX30:RXZ0<0YZJV0P2_[jl30:VYZ@80[:b/0`2WYjL20;6a/@H0]KFe0P2h^;P30;fm_@80
[Jf]0`2<S8`307MgM`80Cdm?0`0g=cL202TY:@<092@T1@0V9RH302LW9`80;2`/0`0Y:BT5034a<@<0
;bl_0P0V9RH302LW9`<0<S8b0P1HF5P306UYJ@80Fe]K0`1FEUH303hn?P80>SXj0`17AdL205EEE@<0
FUYJ0P1PH60306EUI@<0KVi^0P1dM7@307=cL`80MWIf0`1mOGd307alO080Ogmo0`23Ph<207emO@<0
Q8B40`20P80207moO`<0Ph>30P20P80308F5Q@<0QXJ60P23Ph<308^;R`80T92@0`2>SXh308V9R@D0
SHf=0P2GUiL308f=S@<0Shn?0P2HV9P308n?S`80UYJF0`2IVIT209>CT`<0UiNG0`2EUID509NGU`80
U9BD0`2KVi/509bLW0<0X:2P0P2JVYX309NGU`<0W9bL0P2QXJ4509nOW`H0WYjN0P2LW9`309^KV`80
VYZJ0`2KVi/309JFUP80TI6A0`2BTY82092@T0<0Rh^;0`2DU9@20820P0<0M7Ad0P1/K6`307AdM080
O7al0`1mOGd308N7Q`80RXZ:0`27QhL208J6QP<0QhN70`26QXH208B4Q0<0QXJ60P2=SHd308V9R@<0
Q8B40P2;Rh/308B4Q080OWin0`1gMgLL0<SPf0006`38h=P302/[:`809bLW0`0S8b<201PH60<07QhN
0`13@d<209NGU`<0YJFU0P2XZ:P30:NWY`<0YJFU0P2TY:@30:>SX`80WinO0`2KVi/509JFUP<0YZJV
0P2g]kL30;Rh^080][Jf0`2ZZZX309JFUP80K6a/0`19BDT2028R8P<08b<S0`0P820202@T90<09bLW
200[:b/202`/;0<0;Bd]0P0S8b<302PX:0<0=SHf0P1MGEd306ATI080J6QX0`1GEeL304A4A080@D51
0`14A4@204i>CP<0FEUI0P1PH60306MWI`<0KFe]0P1bLW8307AdM080MWIf0`1kNg/307inOP80Ogmo
0`1nOWh20820P0<0PX:20`21PH420820P0<0PH610P23Ph<308B4Q0<0QXJ60P27QhL308V9R@80S8b<
0`2?Shl508j>SP<0Shn?1@2@T905096AT@<0TY:B0P2FUYH309RHV080UiNG0`2FUYH309NGU`80VIVI
1@2JVYX309^KV`<0W9bL1@2NWYh209fMW@<0Vi^K0`2NWYh50:2PX080WinO0`2NWYh309fMW@D0WYjN
0P2MWId309ZJVP<0UYJF0P2CTi<3096AT@D0T92@0`2>SXh207moO`<0LG5a0P1^KVh306m_K`80MWIf
0`1nOWh308F5Q@80Rh^;0`2<S8`208f=S@<0S8b<0`2;Rh/208f=S@/0Shn?0P2=SHd308F5Q@80OGem
0`1kNg/d0<SPf0<0:2PX0P0V9RH501dM7@<071`L0`0k>c/20:2PX0D0Xj>S0`2UYJD509nOW`<0YZJV
0P2/[:`30:6QX@80WYjN0`2KVi/309nOW`80ZJVY0`2m_Kd20;Zj^P<0ZZZZ0`2?Shl205eMG@<0@D51
0P0V9RH3024Q8@<0820P0P0O7al302HV9P80=CDe0`0X:2P302l_;`80:2PX0`0Z:RX202TY:@<0:2PX
0`0d=3@205]KF`<0JVYZ0P1WIfL305YJFP<0AdM70P14A4@303dm?@80De=C0`1HF5P205mOG`<0JFUY
0`1`L702079bLP<0M7Ad1@1fMWH308>3P`80Ng]k0`1oOgl208B4Q0<0PH611@1oOgl508>3P`P0QXJ6
0`27QhL808f=S@80T92@0`2=SHd209:BTP<0SHf=0`2CTi<2092@T0<0TI6A0P2DU9@309bLW080UiNG
0`2FUYH309RHV080Vi^K1@2LW9`309NGU`<0W9bL0P2MWId309jNWP80Vi^K0`2NWYh309fMW@80WYjN
0`2UYJD509jNWP<0WinO0P2LW9`30::RXP80WIfM0`2JVYX309NGU`80U9BD0`2IVIT208n?S`<0TI6A
0`2?Shl208>3P`<0MGEe0P1[Jf/3079bLP80N7Qh0`1mOGd308F5Q@80Shn?0`2=SHd208^;R`<0RHV9
0`28R8P208Z:RP<0TY:B0P2=SHd308n?S`<0T92@0P2<S8`308>3P`80OWin0`1hN7PL0<SPf0006`38
h=P302/[:`809bLW0`0S8b<201PH60<07QhN0`13@d<209NGU`<0YJFU0P2XZ:P30:NWY`<0YJFU0P2T
Y:@30:>SX`80WinO0`2KVi/509JFUP<0YZJV0P2g]kL30;Rh^080][Jf0`2ZZZX309JFUP80K6a/0`19
BDT2028R8P<08b<S0`0P820202@T90<09bLW200[:b/202`/;0<0;Bd]0P0S8b<302PX:0<0=SHf0P1M
GEd306ATI080J6QX0`1GEeL304A4A080@D510`14A4@204i>CP<0FEUI0P1PH60306MWI`<0KFe]0P1b
LW8307AdM080MWIf0`1kNg/307inOP80Ogmo0`1nOWh20820P0<0PX:20`21PH420820P0<0PH610P23
Ph<308B4Q0<0QXJ60P27QhL308V9R@80S8b<0`2?Shl508j>SP<0Shn?1@2@T905096AT@<0TY:B0P2F
UYH309RHV080UiNG0`2FUYH309NGU`80VIVI1@2JVYX309^KV`<0W9bL1@2NWYh209fMW@<0Vi^K0`2N
WYh50:2PX080WinO0`2NWYh309fMW@D0WYjN0P2MWId309ZJVP<0UYJF0P2CTi<3096AT@D0T92@0`2>
SXh207moO`<0LG5a0P1^KVh306m_K`80MWIf0`1nOWh308F5Q@80Rh^;0`2<S8`208f=S@<0S8b<0`2;
Rh/208f=S@/0Shn?0P2=SHd308F5Q@80OGem0`1kNg/d0<SPf0<0:2PX0P0V9RH501dM7@<071`L0`0k
>c/20:2PX0D0Xj>S0`2UYJD509nOW`<0YZJV0P2/[:`30:6QX@80WYjN0`2KVi/309nOW`80ZJVY0`2m
_Kd20;Zj^P<0ZZZZ0`2?Shl205eMG@<0@D510P0V9RH3024Q8@<0820P0P0O7al302HV9P80=CDe0`0X
:2P302l_;`80:2PX0`0Z:RX202TY:@<0:2PX0`0d=3@205]KF`<0JVYZ0P1WIfL305YJFP<0AdM70P14
A4@303dm?@80De=C0`1HF5P205mOG`<0JFUY0`1`L702079bLP<0M7Ad1@1fMWH308>3P`80Ng]k0`1o
Ogl208B4Q0<0PH611@1oOgl508>3P`P0QXJ60`27QhL808f=S@80T92@0`2=SHd209:BTP<0SHf=0`2C
Ti<2092@T0<0TI6A0P2DU9@309bLW080UiNG0`2FUYH309RHV080Vi^K1@2LW9`309NGU`<0W9bL0P2M
WId309jNWP80Vi^K0`2NWYh309fMW@80WYjN0`2UYJD509jNWP<0WinO0P2LW9`30::RXP80WIfM0`2J
VYX309NGU`80U9BD0`2IVIT208n?S`<0TI6A0`2?Shl208>3P`<0MGEe0P1[Jf/3079bLP80N7Qh0`1m
OGd308F5Q@80Shn?0`2=SHd208^;R`<0RHV90`28R8P208Z:RP<0TY:B0P2=SHd308n?S`<0T92@0P2<
S8`308>3P`80OWin0`1hN7PL0<SPf0006`38h=P302`/;080:b/[0`0Y:BT201hN7P<0820P0`0Z:RX2
07MgM`<0/K6a0P2PX:030:FUY@<0XJ6Q0P2LW9`309JFUP80Shn?0`27QhL207emO@<0MGEe0`1gMgL2
0861P@<0W9bL0P2f][H30;bl_0<0/k>c0P2<S8`306ATI0808B4Q0`0U9BD301lO7`8092@T0`0W9bL2
02XZ:P<0:BTY0`0X:2P202XZ:P<0;bl_0P0M7Ad3034a<@<0:RXZ0P1RHV8306MWI`80J6QX0`1HF5P3
04M7A`80@d=30`15ADD204e=C@<0F5QH0P1OGel306IVIP<0K6a/0P1aLG4307AdM080MgMg0`1kNg/3
07inOP80OGem0`1lO7`207moO`P0PH610`22PX8208>3P`<0QHF50`27QhL208R8R0<0RHV90P2;Rh/3
08j>SPD0T92@0`2?Shl208j>SP<0Shn?0`2ATI4209>CT`<0U9BD0P2FUYH509NGU`<0UYJF0`2HV9P2
09^KV`<0WIfM202NWYh209fMW@D0WYjN0`2OWil:0:2PX0<0WYjN0`2MWId209nOW`<0XJ6Q0P2NWYh3
09ZJVP<0UYJF0P2BTY83096AT@80Shn?0`2>SXh308Z:RP80Ogmo0`1dM7@206i^KP<0KFe]0P1eMGD3
07inOP<0Q8B40P29RHT308f=S@80SXj>0`2;Rh/308R8R080RXZ:0`2=SHd508n?S`<0SXj>0P2:RXX3
08>3P`80O7al0`1kNg/d0<SPf0<09RHV0P0a<C4302LW9`80820P0`0Q8B4302XZ:P80N7Qh0`2YZJT2
0:6QX@<0YZJV0`2TY:@209VIV@<0UYJF0P2BTY830861P@80P8200`1eMGD307MgM`80PX:20`2QXJ42
0:^[Z`<0_Kfm0`2a/K42096AT@<0IFEU0P0a<C4802@T90<0:2PX0P0V9RH3038b<P<09bLW0P0S8b<3
02LW9`80:2PX0`0U9BD302`/;080GEeM0`1aLG4206=SH`<0FEUI0`13@d<204E5A@<0BTY:0P1<C4`3
05aLG080FUYJ0`1YJFT306e]K@80Kfm_0`1dM7@207QhN0<0Ng]k0`20P80207QhN0<0OGem0P1oOgl3
08:2PP<0P8200P21PH4308F5Q@80PH610`23Ph<308R8R080QhN70`29RHT208b<S0<0Rh^;0`2BTY82
08n?S`D0T92@1P2?Shl209>CT`<0UIFE1@2GUiL209JFUP<0VIVI0`2EUID209RHV0<0XJ6Q0P2KVi/3
09fMW@<0WinO0P2LW9`=09nOW`<0XZ:R0P2OWil309jNWP<0WinO0P2MWId30:6QX@80WYjN0`2JVYX3
09FEU@D0TY:B0P2@T90308^;R`<0S8b<0P1nOWh307QhN080J6QX0`1`L70207IfMP<0OGem1@26QXH5
08f=S@<0SXj>0`29RHT208b<S0<0SHf=0P2<S8`3092@T0<0SXj>0P2:RXX308:2PP80O7al0`1iNGTL
0<SPf0006`38h=P302`/;080:b/[0`0Y:BT201hN7P<0820P0`0Z:RX207MgM`<0/K6a0P2PX:030:FU
Y@<0XJ6Q0P2LW9`309JFUP80Shn?0`27QhL207emO@<0MGEe0`1gMgL20861P@<0W9bL0P2f][H30;bl
_0<0/k>c0P2<S8`306ATI0808B4Q0`0U9BD301lO7`8092@T0`0W9bL202XZ:P<0:BTY0`0X:2P202XZ
:P<0;bl_0P0M7Ad3034a<@<0:RXZ0P1RHV8306MWI`80J6QX0`1HF5P304M7A`80@d=30`15ADD204e=
C@<0F5QH0P1OGel306IVIP<0K6a/0P1aLG4307AdM080MgMg0`1kNg/307inOP80OGem0`1lO7`207mo
O`P0PH610`22PX8208>3P`<0QHF50`27QhL208R8R0<0RHV90P2;Rh/308j>SPD0T92@0`2?Shl208j>
SP<0Shn?0`2ATI4209>CT`<0U9BD0P2FUYH509NGU`<0UYJF0`2HV9P209^KV`<0WIfM202NWYh209fM
W@D0WYjN0`2OWil:0:2PX0<0WYjN0`2MWId209nOW`<0XJ6Q0P2NWYh309ZJVP<0UYJF0P2BTY83096A
T@80Shn?0`2>SXh308Z:RP80Ogmo0`1dM7@206i^KP<0KFe]0P1eMGD307inOP<0Q8B40P29RHT308f=
S@80SXj>0`2;Rh/308R8R080RXZ:0`2=SHd508n?S`<0SXj>0P2:RXX308>3P`80O7al0`1kNg/d0<SP
f0<09RHV0P0a<C4302LW9`80820P0`0Q8B4302XZ:P80N7Qh0`2YZJT20:6QX@<0YZJV0`2TY:@209VI
V@<0UYJF0P2BTY830861P@80P8200`1eMGD307MgM`80PX:20`2QXJ420:^[Z`<0_Kfm0`2a/K42096A
T@<0IFEU0P0a<C4802@T90<0:2PX0P0V9RH3038b<P<09bLW0P0S8b<302LW9`80:2PX0`0U9BD302`/
;080GEeM0`1aLG4206=SH`<0FEUI0`13@d<204E5A@<0BTY:0P1<C4`305aLG080FUYJ0`1YJFT306e]
K@80Kfm_0`1dM7@207QhN0<0Ng]k0`20P80207QhN0<0OGem0P1oOgl308:2PP<0P8200P21PH4308F5
Q@80PH610`23Ph<308R8R080QhN70`29RHT208b<S0<0Rh^;0`2BTY8208n?S`D0T92@1P2?Shl209>C
T`<0UIFE1@2GUiL209JFUP<0VIVI0`2EUID209RHV0<0XJ6Q0P2KVi/309fMW@<0WinO0P2LW9`=09nO
W`<0XZ:R0P2OWil309jNWP<0WinO0P2MWId30:6QX@80WYjN0`2JVYX309FEU@D0TY:B0P2@T90308^;
R`<0S8b<0P1nOWh307QhN080J6QX0`1`L70207IfMP<0OGem1@26QXH508f=S@<0SXj>0`29RHT208b<
S0<0SHf=0P2<S8`3092@T0<0SXj>0P2:RXX308:2PP80O7al0`1iNGTL0<SPf0006`38h=P302`/;080
:b/[0`0Y:BT201hN7P<0820P0`0Z:RX207MgM`<0/K6a0P2PX:030:FUY@<0XJ6Q0P2LW9`309JFUP80
Shn?0`27QhL207emO@<0MGEe0`1gMgL20861P@<0W9bL0P2f][H30;bl_0<0/k>c0P2<S8`306ATI080
8B4Q0`0U9BD301lO7`8092@T0`0W9bL202XZ:P<0:BTY0`0X:2P202XZ:P<0;bl_0P0M7Ad3034a<@<0
:RXZ0P1RHV8306MWI`80J6QX0`1HF5P304M7A`80@d=30`15ADD204e=C@<0F5QH0P1OGel306IVIP<0
K6a/0P1aLG4307AdM080MgMg0`1kNg/307inOP80OGem0`1lO7`207moO`P0PH610`22PX8208>3P`<0
QHF50`27QhL208R8R0<0RHV90P2;Rh/308j>SPD0T92@0`2?Shl208j>SP<0Shn?0`2ATI4209>CT`<0
U9BD0P2FUYH509NGU`<0UYJF0`2HV9P209^KV`<0WIfM202NWYh209fMW@D0WYjN0`2OWil:0:2PX0<0
WYjN0`2MWId209nOW`<0XJ6Q0P2NWYh309ZJVP<0UYJF0P2BTY83096AT@80Shn?0`2>SXh308Z:RP80
Ogmo0`1dM7@206i^KP<0KFe]0P1eMGD307inOP<0Q8B40P29RHT308f=S@80SXj>0`2;Rh/308R8R080
RXZ:0`2=SHd508n?S`<0SXj>0P2:RXX308>3P`80O7al0`1kNg/d0<SPf0<09RHV0P0a<C4302LW9`80
820P0`0Q8B4302XZ:P80N7Qh0`2YZJT20:6QX@<0YZJV0`2TY:@209VIV@<0UYJF0P2BTY830861P@80
P8200`1eMGD307MgM`80PX:20`2QXJ420:^[Z`<0_Kfm0`2a/K42096AT@<0IFEU0P0a<C4802@T90<0
:2PX0P0V9RH3038b<P<09bLW0P0S8b<302LW9`80:2PX0`0U9BD302`/;080GEeM0`1aLG4206=SH`<0
FEUI0`13@d<204E5A@<0BTY:0P1<C4`305aLG080FUYJ0`1YJFT306e]K@80Kfm_0`1dM7@207QhN0<0
Ng]k0`20P80207QhN0<0OGem0P1oOgl308:2PP<0P8200P21PH4308F5Q@80PH610`23Ph<308R8R080
QhN70`29RHT208b<S0<0Rh^;0`2BTY8208n?S`D0T92@1P2?Shl209>CT`<0UIFE1@2GUiL209JFUP<0
VIVI0`2EUID209RHV0<0XJ6Q0P2KVi/309fMW@<0WinO0P2LW9`=09nOW`<0XZ:R0P2OWil309jNWP<0
WinO0P2MWId30:6QX@80WYjN0`2JVYX309FEU@D0TY:B0P2@T90308^;R`<0S8b<0P1nOWh307QhN080
J6QX0`1`L70207IfMP<0OGem1@26QXH508f=S@<0SXj>0`29RHT208b<S0<0SHf=0P2<S8`3092@T0<0
SXj>0P2:RXX308:2PP80O7al0`1iNGTL0<SPf0006`38h=P302HV9P80:BTY0`0/;2`202<S8`H0820P
0P1:BTX308>3P`80TY:B0`2EUID309:BTP80S8b<0`24Q8@207]kN`<0Lg=c0P1^KVh306e]K@<0MGEe
0P1oOgl308B4Q080SXj>0`2LW9`30::RXP80X:2P0`1eMGD203Hf=P<0=cLg0`0X:2P502<S8`809bLW
1P0Y:BT202HV9P<0820P0P0n?Sh3028R8P<08b<S0P1NGUh3079bLP80G5aL0`1@D50304=3@`80A4A4
0`19BDT204m?C`<0EUIF0P1MGEd306ATI0<0Jf][0P1bLW8307AdM080MGEe0`1iNGT807emO@80Ogmo
0`21PH450820P0<0PX:20P24Q8@308J6QP<0QhN70P29RHT308^;R`80S8b<0`2=SHd3092@T080TY:B
0`2@T90208n?S`<0TI6A0`2CTi<209FEU@<0UiNG1@2HV9P509NGU`<0V9RH0P2JVYX309^KV`D0W9bL
202MWId209jNWP<0WinO402PX:050:6QX@80WIfM0`2IVIT309NGU`80UIFE0`2ATI4508f=S@<0Rh^;
0P20P80307AdM080Kfm_0`1]KFd207AdM0<0O7al0`23Ph<208R8R0<0Rh^;0P2<S8`308Z:RP<0RHV9
0P2;Rh/508j>SP<0SHf=0`29RHT208F5Q@<0PH610P1mOGd307alO3@0b>3H0`0U9BD2030`<0<0;2`/
0P0Q8B43028R8P<09BDU0P17AdL308b<S080V9RH0`2JVYX309JFUP80R8R80`21PH4207IfMP<0Jf][
0P1]KFd306ATI0<0MWIf0P23Ph<308N7Q`80TY:B0`2RXZ830:f][@80W9bL0`1^KVh203Lg=`<0:BTY
0`0U9BD202HV9PD08b<S0`0W9bL302h^;P8092@T0`0_;bl204I6AP<09BDU0`0^;Rh205MGE`<0LG5a
0P1KFe/304i>CP<0ATI60P13@d<304A4A080CTi>0`1IFET205MGE`<0Hf=S0`1[Jf/207IfMP<0LW9b
0P1gMgL307YjNP<0Ng]k0P22PX8307inOP80O7al0`22PX8307moO`80P8200`22PX8808J6QP80S8b<
0`28R8P208n?S`<0SXj>1@2ATI4308f=S@80SXj>0`2?Shl309>CT`80W9bL0`2CTi<209VIV@D0UYJF
0`2EUID309NGU`80VYZJ0`2MWId209bLW0<0WinO0`2LW9`209nOW`<0W9bL0P2MWId609jNWP80X:2P
0`2RXZ8209jNWP<0WinO0`2MWId509nOW`80WIfM0`2JVYX309:BTP80Ti>C0`2>SXh208^;R`<0SHf=
0`2:RXX207emO@<0M7Ad0P1[Jf/306e]K@80M7Ad0`1mOGd308>3P`80QhN70`2:RXX208f=S@<0Rh^;
0`28R8P208^;R`<0T92@0P2=SHd308n?S`<0R8R80P26QXH50820P0<0OGem7038h=P001/0b>3H0`0V
9RH202TY:@<0;2`/0P0S8b<6020P8080BTY:0`23Ph<209:BTP<0UIFE0`2BTY8208b<S0<0Q8B40P1k
Ng/307=cL`80KVi^0`1]KFd307EeM@80Ogmo0`24Q8@208j>SP<0W9bL0`2RXZ820:2PX0<0MGEe0P0f
=SH303Lg=`<0:2PX1@0S8b<202LW9`H0:BTY0P0V9RH3020P8080?Shn0`0R8R8302<S8`80GUiN0`1b
LW8205aLG0<0D51@0`13@d<204A4A0<0BDU90P1?Cdl305IFEP80GEeM0`1TI6@306][J`80LW9b0`1d
M7@207EeM@<0NGUi201mOGd207moO`<0PH611@20P80308:2PP80Q8B40`26QXH308N7Q`80RHV90`2;
Rh/208b<S0<0SHf=0`2@T90209:BTP<0T92@0P2?Shl3096AT@<0Ti>C0P2EUID309NGU`D0V9RH1@2G
UiL309RHV080VYZJ0`2KVi/509bLW0P0WIfM0P2NWYh309nOWa00X:2P1@2QXJ4209fMW@<0VIVI0`2G
UiL209FEU@<0TI6A1@2=SHd308^;R`80P8200`1dM7@206m_K`<0KFe]0P1dM7@307alO0<0Ph>30P28
R8P308^;R`80S8b<0`2:RXX308V9R@80Rh^;1@2>SXh308f=S@<0RHV90P25QHD30861P@80OGem0`1l
O7`d0<SPf0<09BDU0P0`<30302`/;0808B4Q0`0R8R8302DU9@80AdM70`2<S8`209RHV0<0VYZJ0`2F
UYH208R8R0<0PH610P1fMWH306][J`80KFe]0`1TI6@307IfMP80Ph>30`27QhL209:BTP<0XZ:R0`2]
[Jd209bLW0<0KVi^0P0g=cL302TY:@<09BDU0P0V9RH502<S8`<09bLW0`0^;Rh202@T90<0;bl_0P16
ATH302DU9@<0;Rh^0P1GEeL3075aL@80Fe]K0`1>CTh304I6AP80@d=30`14A4@204i>CP<0FEUI0P1G
EeL306=SH`<0Jf][0P1fMWH3079bLP80MgMg0`1jNWX307]kN`80PX:20`1nOWh207alO0<0PX:20`1o
Ogl20820P0<0PX:22026QXH208b<S0<0R8R80P2?Shl308j>SPD0TI6A0`2=SHd208j>SP<0Shn?0`2C
Ti<209bLW0<0Ti>C0P2IVIT509JFUP<0UIFE0`2GUiL209ZJVP<0WIfM0P2LW9`309nOW`<0W9bL0P2O
Wil309bLW080WIfM1P2NWYh20:2PX0<0XZ:R0P2NWYh309nOW`<0WIfM1@2OWil209fMW@<0VYZJ0`2B
TY8209>CT`<0SXj>0P2;Rh/308f=S@<0RXZ:0P1mOGd307AdM080Jf][0`1]KFd207AdM0<0OGem0`23
Ph<208N7Q`<0RXZ:0P2=SHd308^;R`<0R8R80P2;Rh/3092@T080SHf=0`2?Shl308R8R080QXJ61@20
P80307emOA`0b>3H000K0<SPf0<07alO0P0W9bL302h^;P80:2PX0`0R8R8301hN7P808b<S0`1>CTh2
07alO0<0P8200`1mOGd207alO0<0MgMg0P1/K6`306ATI080HV9R0`1[Jf/309BDU080^[Zj0`2d];@2
0:FUY@<0VYZJ0`2=SHd20:^[Z`<0QhN70P1?Cdl304Y:BP<0<30`0P0Q8B43020P80809BDU0`0V9RH3
02PX:080:b/[0`0_;bl201`L70<0;bl_0`0W9bL205MGE`<0MWIf0P1ADE4304Q8B0<0?Shn0P14A4@3
04e=C@80DE5A0`1EEED205]KF`<0HF5Q0`1ZJVX2079bLPD0M7Ad0`1hN7P307alO080OGem0`1nOWh2
07moO`H0P8200P1oOgl308>3P`D0QXJ60`27QhL208Z:RPP0S8b<0`2?Shl209:BTPD0TI6A0`2CTi<3
09FEU@80UiNG0`2IVIT209ZJVP<0VIVI0P2HV9P309NGU`<0V9RH0P2JVYX509VIV@<0VYZJ0`2LW9`2
09fMW@D0WYjN1P2OWil20:2PX0D0XJ6Q0`2RXZ830:>SX`80XZ:R0`2PX:0209bLW0<0VIVI1@2HV9P3
09:BTP80S8b<0`2=SHd308b<S080PH610`1fMWH2071`L0<0Kfm_0P1dM7@307YjNP<0P8200P25QHD;
08R8R080RXZ:0`2<S8`208Z:RP<0QhN70`23Ph<20820P0D0OWin0`1mOGdd0<SPf0D092@T0`0b<S82
02HV9P<08R8R0`0N7Qh2028R8P<0C4a<0P1hN7P308>3P`<0N7Qh1@1jNWX206MWI`<0IFEU1@1/K6`3
092@T080]KFe0`2][Jd20:>SX`<0SHf=0`2@T90209ZJVP<0QhN70P1JFUX304E5A@<0;Bd]0P0S8b<3
028R8P80:b/[0`0U9BD302/[:`D0:2PX0P0R8R8302<S8`<0;Rh^0P1JFUX306e]K@80FUYJ0`13@d<3
0410@080Bd];0`1>CTh2055AD@<0De=C1@1OGel306YZJP80M7Ad0`1aLG4507IfMP<0OGem0P1oOgl3
07emO@80O7al0`22PX8307emO@80PH610`23Ph<208J6QP<0QHF50`27QhL208^;R`<0SHf=0P2:RXX3
08^;R`<0Shn?0P2DU9@309>CT`80U9BD0`2?Shl309>CT`80Vi^K1@2GUiL309ZJVP80V9RH0`2FUYH5
09ZJVP<0UYJF0P2IVIT309bLW0<0VYZJ0P2OWil309VIV@80XZ:R0`2OWil309bLW080XJ6Q0`2OWil2
0::RXP<0Y:BT0`2SXj<50:6QX@80Vi^K0`2IVIT309RHV080VIVI0`2BTY8208b<S0<0Rh^;0`2?Shl2
07moO`<0MgMg0P1bLW8306i^KP80Lg=c0`1lO7`30820P080QhN70`26QXH208^;R`<0R8R80`2:RXX2
08V9R@<0Rh^;0P2?Shl608B4Q080PH610`1lO7`207emO@<0Ogmo7038h=P001/0b>3H0`0O7al202LW
9`<0;Rh^0P0X:2P3028R8P<07QhN0P0S8b<304i>CP80O7al0`20P80307emO@80O7al0`1gMgL206a/
K0<0I6AT0P1RHV8306][J`<0U9BD0P2j^[X30;Bd]080YJFU0`2JVYX308f=S@80Zj^[0`27QhL204m?
C`<0BTY:0`0`<302024Q8@<0820P0P0U9BD302HV9P<0:2PX0P0[:b/302l_;`8071`L0`0_;bl302LW
9`80EeMG0`1fMWH2055AD@<0B4Q80`0n?Sh204A4A0<0CDe=0P1ADE4305EEE@80Fe]K0`1QHF4306YZ
JP80LW9b1@1dM7@307QhN0<0O7al0P1mOGd307inOP80Ogmo1P20P80207moO`<0Ph>31@26QXH308N7
Q`80RXZ:202<S8`308n?S`80TY:B1@2ATI4309>CT`<0UIFE0P2GUiL309VIV@80VYZJ0`2IVIT209RH
V0<0UiNG0`2HV9P209ZJVPD0VIVI0`2JVYX309bLW080WIfM1@2NWYh609nOW`80X:2P1@2QXJ430::R
XP<0Xj>S0P2RXZ830:2PX080W9bL0`2IVIT509RHV0<0TY:B0P2<S8`308f=S@<0S8b<0P21PH4307If
MP80L71`0`1_Kfl207AdM0<0NWYj0`20P80208F5Q@/0R8R80P2:RXX308b<S080RXZ:0`27QhL308>3
P`80P8201@1nOWh307emOC@0b>3H1@0T92@3038b<P809RHV0`0R8R8301hN7P808R8R0`1<C4`207Qh
N0<0Ph>30`1hN7P507YjNP80IfMW0`1UIFD506a/K0<0T92@0P2e]KD30:f][@80Xj>S0`2=SHd3092@
T080VYZJ0`27QhL205YJFP<0ADE50`0];Bd202<S8`<08R8R0P0[:b/302DU9@<0:b/[1@0X:2P2028R
8P<08b<S0`0^;Rh205YJFP<0KFe]0P1JFUX304=3@`<0@4100P1;Bd/304i>CP80DE5A0`1CDe<505mO
G`<0JVYZ0P1dM7@3075aL@D0MWIf0`1mOGd207moO`<0OGem0P1lO7`308:2PP<0OGem0P21PH4308>3
P`80QXJ60`25QHD308N7Q`80Rh^;0`2=SHd208Z:RP<0Rh^;0`2?Shl209BDU0<0Ti>C0P2DU9@308n?
S`<0Ti>C0P2KVi/509NGU`<0VYZJ0P2HV9P309JFUPD0VYZJ0`2FUYH209VIV@<0W9bL0`2JVYX209nO
W`<0VIVI0P2RXZ8309nOW`<0W9bL0P2QXJ4309nOW`80XZ:R0`2TY:@30:>SX`D0XJ6Q0P2KVi/309VI
V@<0V9RH0P2IVIT309:BTP80S8b<0`2;Rh/308n?S`80Ogmo0`1gMgL2079bLP<0KVi^0P1cLg<307al
O0<0P8200P27QhL308J6QP80Rh^;0`28R8P308Z:RP80RHV90`2;Rh/208n?S`H0Q8B40P21PH4307al
O080OGem0`1oOglL0<SPf0006`38h=P301lO7`809bLW0`0^;Rh202PX:0<08R8R0`0N7Qh202<S8`<0
CTi>0P1lO7`30820P0<0OGem0P1lO7`307MgM`80K6a/0`1TI6@2069RHP<0Jf][0`2DU9@20;Zj^P<0
];Bd0P2UYJD309ZJVP<0SHf=0P2[Zj/308N7Q`80Cdm?0`1:BTX3030`<0808B4Q0`0P820202DU9@<0
9RHV0`0X:2P202/[:`<0;bl_0P0L71`302l_;`<09bLW0P1GEeL307IfMP80DE5A0`18B4P303hn?P80
A4A40`1=CDd2055AD@<0EEEE0P1KFe/3065QH@<0JVYZ0P1bLW8507AdM0<0N7Qh0`1lO7`207emO@<0
OWin0P1oOgl60820P080Ogmo0`23Ph<508J6QP<0QhN70P2:RXX808b<S0<0Shn?0P2BTY85096AT@<0
Ti>C0`2EUID209NGU`<0VIVI0P2JVYX309VIV@80V9RH0`2GUiL309RHV080VYZJ1@2IVIT309ZJVP<0
W9bL0P2MWId509jNWPH0WinO0P2PX:050:6QX@<0XZ:R0`2SXj<20::RXP<0X:2P0P2LW9`309VIV@D0
V9RH0`2BTY8208b<S0<0SHf=0`2<S8`20861P@<0MWIf0P1`L70306m_K`80M7Ad0`1jNWX30820P080
QHF52`28R8P208Z:RP<0S8b<0P2:RXX308N7Q`<0Ph>30P20P80507inOP<0OGem=038h=P502@T90<0
<S8b0P0V9RH3028R8P<07QhN0P0R8R8304a<C080N7Qh0`23Ph<307QhN0D0NWYj0P1WIfL306EUI@D0
K6a/0`2@T9020;Fe]@<0[Jf]0P2SXj<308f=S@<0T92@0P2JVYX308N7Q`80FUYJ0`15ADD302d];@80
8b<S0`0R8R8202/[:`<09BDU0`0[:b/502PX:0808R8R0`0S8b<302h^;P80FUYJ0`1]KFd205YJFP<0
@d=30`10@40204];B`<0CTi>0P1ADE4305=CD`D0GemO0`1ZJVX207AdM0<0LG5a1@1fMWH307emO@80
Ogmo0`1mOGd207alO0<0PX:20`1mOGd20861P@<0Ph>30P26QXH308F5Q@<0QhN70P2;Rh/308f=S@80
RXZ:0`2;Rh/308n?S`80U9BD0`2CTi<209BDU0<0Shn?0`2CTi<209^KV`D0UiNG0`2JVYX209RHV0<0
UYJF1@2JVYX309JFUP80VIVI0`2LW9`309ZJVP80WinO0`2IVIT20::RXP<0WinO0`2LW9`20:6QX@<0
WinO0P2RXZ830:BTY0<0Xj>S1@2QXJ4209^KV`<0VIVI0`2HV9P209VIV@<0TY:B0P2<S8`308^;R`<0
Shn?0P1oOgl307MgM`80LW9b0`1^KVh207=cL`<0O7al0`20P80208N7Q`<0QXJ60P2;Rh/308R8R0<0
RXZ:0P29RHT308^;R`80Shn?1P24Q8@20861P@<0O7al0P1mOGd307moOa`0b>3H000K0<SPf0<08b<S
0P0Y:BT302l_;`80;Bd]0`0Y:BT3024Q8@806QXJ0`0b<S82051@D0<0K6a/0`1RHV8207=cL`<0OWin
0P1bLW8506YZJP<0Lg=c0`2ATI420:f][@<0b/[:0P2g]kL309jNWP<0OWin0P2=SHd307UiN@80:2PX
0`0L71`301TI6@808b<S0`0T92@802HV9P80:BTY0`0/;2`202<S8`<0:b/[0`0X:2P205aLG0<0KFe]
0P1FEUH304Q8B0<0>c/k0P12@T8304e=C@80DE5A0`1EEED205]KF`<0HV9R0`1YJFT2071`L0<0LW9b
0P1dM7@307QhN0<0Ng]k0P1mOGd307inOP80P8201P21PH4208:2PP<0Q8B40P26QXH608N7Q`D0R8R8
0P29RHT308^;R`<0SXj>0P2BTY8509>CT`<0U9BD0`2EUID209NGU`D0VIVI0`2HV9P209NGU`<0UYJF
0`2HV9P209VIV@D0VYZJ0`2LW9`509nOW`P0X:2P0`2QXJ470::RXP<0Xj>S0`2TY:@20::RXP<0WinO
0P2MWId309ZJVP<0V9RH0P2FUYH309:BTP80SXj>0`2?Shl308j>SP80QXJ60`1lO7`207IfMP<0LW9b
0P1dM7@307QhN0<0OWin0P23Ph<308J6QP80QhN71P28R8P208N7Q`<0QXJ60P23Ph<30861P@<0OWin
1@1lO7`507emOC@0b>3H1@0S8b<3030`<080;bl_0`0[:b/301hN7P808b<S0`0X:2P2055AD@<0IFEU
0`1WIfL207inOP<0QHF50P1ZJVX306i^KPD0LW9b0`2@T9020;Vi^@<0bLW90P33`l<30:JVYP<0PX:2
0P2GUiL307emO@80=3@d0`0T92@302<S8`807alO0`0N7Qh202<S8`<0:BTY0`0U9BD2028R8P<0:RXZ
0P0U9BD302TY:@<0:RXZ0P1LG5`306a/K080G5aL0`11@D4303Ph>080AdM70`18B4P204m?C`<0EUIF
0P1MGEd306MWI`<0J6QX0P1/K6`307=cL`D0MGEe0`1iNGT207emO@<0Ogmo0P20P80308B4Q0<0PX:2
0P23Ph<308:2PP80QhN70`25QHD308R8R080QXJ60`27QhL208b<S0<0Rh^;0`2=SHd2092@T0<0TI6A
1@2CTi<309FEU@80VYZJ0`2KVi/209VIV@D0V9RH0`2GUiL309VIV@80VYZJ0`2FUYH209ZJVP<0WIfM
0`2NWYh209fMW@<0XZ:R0P2SXj<309nOW`<0XZ:R0P2VYZH309jNWP80XZ:R1P2TY:@20:>SX`<0XJ6Q
0P2MWId309bLW0D0V9RH0`2FUYH2096AT@<0T92@0`2>SXh208F5Q@<0O7al0P1iNGT307EeM@80LW9b
0`1fMWH307alO080Q8B40`25QHD208>3P`<0QhN70`26QXH208B4Q0<0Ph>30P22PX8307moO`<0Q8B4
0P1iNGT507]kN`<0PH617038h=P001/0b>3H0`0S8b<202TY:@<0;bl_0P0];Bd302TY:@<08B4Q0P0J
6QX3038b<P80D51@0`1/K6`3069RHP80Lg=c0`1nOWh2079bLPD0JVYZ0`1cLg<3096AT@80[Jf]0`3:
b/X20;Ng]`<0WYjN0`1nOWh208f=S@<0NGUi0P0X:2P301`L70<06ATI0P0S8b<302@T90P09RHV0P0Y
:BT302`/;0808b<S0`0[:b/302PX:080G5aL0`1]KFd205IFEP<0B4Q80`0k>c/20492@P<0CDe=0P1A
DE4305EEE@80Fe]K0`1RHV8306UYJ@80L71`0`1bLW8207AdM0<0N7Qh0`1kNg/207emO@<0OWin0P20
P8060861P@80PX:20`24Q8@208J6QPH0QhN71@28R8P208V9R@<0Rh^;0`2>SXh209:BTPD0Ti>C0`2D
U9@309FEU@80UiNG1@2IVIT309RHV080UiNG0`2FUYH309RHV080VIVI1@2JVYX309bLW0D0WinO202P
X:030:6QX@L0XZ:R0`2SXj<30:BTY080XZ:R0`2OWil209fMW@<0VYZJ0`2HV9P209JFUP<0TY:B0P2>
SXh308n?S`<0SXj>0P26QXH307alO080MWIf0`1bLW8207AdM0<0N7Qh0`1nOWh208>3P`<0QXJ60P27
QhL608R8R080QhN70`26QXH208>3P`<0PH610`1nOWh507alO0D0OGem=038h=P502<S8`<0<30`0P0_
;bl302/[:`<07QhN0P0S8b<302PX:080DE5A0`1UIFD306MWI`80OWin0`25QHD206YZJP<0KVi^1@1b
LW83092@T080^KVi0`39bLT20<?3``<0YZJV0`22PX8209NGU`<0OGem0P0d=3@302@T90<08b<S0P0O
7al301hN7P808b<S0`0Y:BT302DU9@808R8R0`0Z:RX202DU9@<0:BTY0`0Z:RX205aLG0<0K6a/0P1L
G5`30451@@<0>3Ph0P17AdL304Q8B080Cdm?0`1FEUH205eMG@<0IfMW0`1XJ6P206a/K0<0Lg=c1@1e
MGD307UiN@80OGem0`1oOgl20820P0<0Q8B40`22PX8208>3P`<0PX:20P27QhL308F5Q@<0R8R80P26
QXH308N7Q`80S8b<0`2;Rh/308f=S@80T92@0`2ATI4509>CT`<0UIFE0P2JVYX309^KV`80VIVI1@2H
V9P309NGU`<0VIVI0P2JVYX309JFUP80VYZJ0`2MWId309jNWP80WIfM0`2RXZ820:>SX`<0WinO0`2R
XZ820:JVYP<0WYjN0P2RXZ860:BTY080Xj>S0`2QXJ4209fMW@<0W9bL1@2HV9P309JFUP80TI6A0`2@
T90308j>SP80QHF50`1lO7`207UiN@<0MGEe0P1bLW8307IfMP<0O7al0P24Q8@308F5Q@80Ph>30`27
QhL308J6QP80Q8B40`23Ph<208:2PP<0Ogmo0`24Q8@207UiN@D0Ng]k0`21PH4L0<SPf0006`38h=P3
02<S8`80:BTY0`0_;bl202d];@<0:BTY0`0Q8B4201XJ6P<0<S8b0P1@D50306a/K0<0HV9R0P1cLg<3
07inOP80LW9b1@1ZJVX307=cL`<0TI6A0P2][Jd30<[:bP80]kNg0`2NWYh307inOP80SHf=0`1iNGT2
02PX:0<071`L0`0I6AT202<S8`<092@T200V9RH202TY:@<0;2`/0P0S8b<302/[:`<0:2PX0P1LG5`3
06e]K@80EUIF0`18B4P303/k>`80@T920`1=CDd2055AD@<0EEEE0P1KFe/3069RHP<0JFUY0P1`L703
079bLP80M7Ad0`1hN7P307]kN`80OGem0`1nOWh20820P0H0PH610P22PX8308B4Q080QXJ61P27QhL5
08R8R080RHV90`2;Rh/308j>SP80TY:B1@2CTi<309BDU0<0UIFE0P2GUiL509VIV@<0V9RH0P2GUiL3
09JFUP<0V9RH0P2IVIT509ZJVP<0W9bL1@2OWil80:2PX0<0XJ6Q1`2RXZ830:>SX`<0Y:BT0P2RXZ83
09nOW`80WIfM0`2JVYX309RHV080UYJF0`2BTY8208j>SP<0Shn?0`2>SXh208J6QP<0O7al0P1fMWH3
079bLP80M7Ad0`1hN7P307inOP80Ph>30`26QXH208N7Q`H0R8R80P27QhL308J6QP80Ph>30`21PH43
07inOPD0O7al1@1mOGdd0<SPf0D08b<S0`0`<30202l_;`<0:b/[0`0N7Qh202<S8`<0:2PX0P1ADE43
06EUI@<0IfMW0P1nOWh308F5Q@80JVYZ0`1^KVh5079bLP<0T92@0P2i^KT30<W9b@80`l?30`2VYZH3
08:2PP80UiNG0`1mOGd203@d=0<092@T0`0S8b<201lO7`<07QhN0P0S8b<302TY:@<09BDU0P0R8R83
02XZ:P809BDU0`0Y:BT302XZ:P80G5aL0`1/K6`205aLG0<0@D510`0h>3P204M7A`<0B4Q80P1?Cdl3
05IFEP80GEeM0`1WIfL306QXJ080K6a/0`1cLg<507EeM@<0NGUi0P1mOGd307moO`80P8200`24Q8@3
08:2PP80Ph>30`22PX8208N7Q`<0QHF50`28R8P208J6QP<0QhN70P2<S8`308^;R`<0SHf=0P2@T903
096AT@D0Ti>C0`2EUID209ZJVP<0Vi^K0P2IVIT509RHV0<0UiNG0`2IVIT209ZJVP<0UYJF0P2JVYX3
09fMW@<0WYjN0P2MWId30::RXP80Xj>S0`2OWil30::RXP80YZJV0`2NWYh20::RXPH0Y:BT0P2SXj<3
0:6QX@80WIfM0`2LW9`509RHV0<0UYJF0P2ATI43092@T0<0SXj>0P25QHD307alO080NGUi0`1eMGD2
079bLP<0MWIf0`1lO7`208B4Q0<0QHF50P23Ph<308N7Q`<0QXJ60P24Q8@308>3P`80PX:20`1oOgl3
08B4Q080NGUi1@1kNg/30861PA`0b>3H000K0<SPf0<0:2PX0P0[:b/302l_;`D0<C4a0`0V9RH201`L
70<08B4Q0P0Y:BT305EEE@<0ATI60P1[Jf/308N7Q`80Ogmo0`1dM7@207EeM@<0Ng]k0`2:RXX209ZJ
VP<0e]KF0P3;bl/30<G5a@<0/k>c0P2^[Zh30:BTY080B4Q80`0/;2`301lO7`808R8R0`0T92@202PX
:0<09RHV0`0U9BD202LW9`<0:BTY0P0V9RH302TY:@<0:2PX1@1PH60205eMG@<0BTY:0`0i>CT20410
@0<0C4a<0P1ADE4305IFEP80G5aL0`1SHf<306UYJ@80KVi^0`1bLW8207EeM@<0N7Qh0`1kNg/207em
O@<0OWin0P20P80308:2PP<0Ph>30P24Q8@308F5Q@80QXJ60`27QhL308R8R080QXJ60`25QHD208N7
Q`<0RXZ:0`2=SHd2096AT@<0U9BD1@2FUYH309FEU@80UiNG1@2HV9P309NGU`80UYJF0`2GUiL309RH
V080VYZJ0`2KVi/209bLW0<0WYjN202QXJ450::RXP<0Xj>S0P2TY:@30:>SX`80XZ:R0`2SXj<30:BT
Y080XJ6Q0`2OWil209fMW@<0W9bL0`2HV9P209FEU@<0TY:B1@2ATI4308n?S`80RXZ:0`23Ph<207al
O0<0MgMg0P1eMGD307IfMP<0O7al0P21PH4308F5Q@80QXJ61P27QhL208>3P`<0Ogmo0P1mOGd307al
O0<0Ng]k0P1jNWX307]kN`D0O7al=038h=P302DU9@80<C4a0`0/;2`203Lg=`<0;bl_0`0O7al201/K
6`<08B4Q0P0^;Rh304m?C`<0Bd];0P1]KFd308N7Q`80MWIf0`1bLW820820P0<0Ng]k0`1nOWh209jN
WP<0bLW91@3:b/X30:^[Z`80X:2P0`2SXj<203`l?0<0:2PX0`0R8R8201lO7`<09BDU0P0W9bL302/[
:`<09bLW0P0V9RH302`/;0D09BDU0`0/;2`205UIF@<0JVYZ0P1MGEd303dm?@<0@T920P17AdL304e=
C@80DU9B0`1IFET205QHF0<0IFEU0`1ZJVX206e]K@<0MGEe0P1dM7@307IfMP<0Ng]k0P1nOWh307em
O@D0P8200`21PH4708F5Q@<0S8b<0`27QhL208:2PP<0QHF50P2:RXX308V9R@<0SHf=0P2DU9@309:B
TP80UiNG0`2FUYH309>CT`80VIVI0`2FUYH509NGU`80V9RH0`2FUYH309BDU080Vi^K0`2JVYX209jN
WP<0WinO0`2RXZ870:2PX0<0XZ:R1@2UYJD309jNWP80Xj>S0`2UYJD30::RXP80WIfM0`2OWil209fM
W@<0Vi^K0`2HV9P209:BTP<0UIFE1@2>SXh3092@T080RXZ:0`23Ph<207alO0<0MgMg0P1bLW8307Ui
N@<0OGem0P22PX8508J6QP<0Rh^;0`27QhL208>3P`<0PH610P1nOWh307]kN`<0O7al0P1jNWX307al
O080Ng]k0`1nOWhL0<SPf0006`38h=P302PX:080:b/[0`0_;bl5034a<@<09RHV0P0L71`3024Q8@80
:BTY0`1EEED304I6AP80Jf][0`27QhL207moO`<0M7Ad0P1eMGD307]kN`<0RXZ:0P2JVYX30=KFeP80
bl_;0`35aLD30;>c/`80[Zj^0`2TY:@204Q8B0<0;2`/0`0O7al2028R8P<092@T0P0X:2P302HV9P<0
9BDU0P0W9bL302TY:@809RHV0`0Y:BT302PX:0D0H61P0P1MGEd304Y:BP<0>CTi0P10@40304a<C080
DE5A0`1FEUH205aLG0<0Hf=S0`1YJFT206i^KP<0LW9b0P1eMGD307QhN0<0Ng]k0P1mOGd307inOP80
P8200`22PX8308>3P`80Q8B40`25QHD208J6QP<0QhN70`28R8P208J6QP<0QHF50P27QhL308Z:RP<0
SHf=0P2ATI4309BDU0D0UYJF0`2EUID209NGU`D0V9RH0`2GUiL209JFUP<0UiNG0`2HV9P209ZJVP<0
Vi^K0P2LW9`309jNWPP0XJ6Q1@2RXZ830:>SX`80Y:BT0`2SXj<20::RXP<0Xj>S0`2TY:@20:6QX@<0
WinO0P2MWId309bLW0<0V9RH0P2EUID309:BTPD0TI6A0`2?Shl208Z:RP<0Ph>30P1lO7`307MgM`80
MGEe0`1fMWH307alO080PH610`25QHD208J6QPH0QhN70P23Ph<307moO`80OGem0`1lO7`307]kN`80
NWYj0`1kNg/507alO3@0b>3H0`0U9BD2034a<@<0;2`/0P0g=cL302l_;`<07alO0P0K6a/3024Q8@80
;Rh^0`1?Cdl304];B`80KFe]0`27QhL207IfMP<0LW9b0P20P80307]kN`<0OWin0P2NWYh30<W9b@D0
b/[:0`2[Zj/20:2PX0<0Xj>S0P0l?3`302PX:0<08R8R0P0O7al302DU9@809bLW0`0[:b/302LW9`80
9RHV0`0/;2`502DU9@<0;2`/0P1IFET306YZJP80GEeM0`0m?Cd30492@P80AdM70`1=CDd2059BDP<0
FEUI0P1HF5P306EUI@<0JVYZ0P1]KFd307EeM@80M7Ad0`1fMWH307]kN`80OWin0`1mOGd50820P0<0
PH611`25QHD308b<S0<0QhN70P22PX8308F5Q@80RXZ:0`29RHT308f=S@80U9BD0`2BTY8209NGU`<0
UYJF0`2CTi<209VIV@<0UYJF1@2GUiL209RHV0<0UYJF0`2DU9@209^KV`<0VYZJ0P2NWYh309nOW`<0
XZ:R1`2PX:030::RXPD0YJFU0`2NWYh20:>SX`<0YJFU0`2RXZ8209fMW@<0WinO0P2MWId309^KV`<0
V9RH0P2BTY8309FEU@D0SXj>0`2@T90208Z:RP<0Ph>30P1lO7`307MgM`80LW9b0`1iNGT307emO@80
PX:21@26QXH308^;R`<0QhN70P23Ph<30861P@80OWin0`1kNg/307alO080NWYj0`1lO7`207]kN`<0
OWin7038h=P001/0b>3H0`0T92@202TY:@<0;bl_0P0^;Rh3030`<0<0:BTY0P0N7Qh301lO7`808B4Q
0`0d=3@302h^;P80GEeM0`24Q8@209:BTP<0M7Ad0P1eMGD307QhN0<0Ogmo0P2;Rh/30<C4a080dM7A
0`3<c<`30<71`@80`/;20`2k^k/207YjNP<0=3@d0`0I6AT202<S8`<092@T0P0Y:BT302PX:0D09RHV
0`0W9bL202@T90<09bLW0`0V9RH205iNGPD0FUYJ0`19BDT303/k>`80@D510`1;Bd/2059BDP<0FEUI
0P1NGUh306=SH`<0JFUY0P1_Kfl307=cL`80MWIf0`1hN7P307YjNP80OGem0`1oOgl20861P@H0Ph>3
0P24Q8@308F5Q@D0QXJ60`27QhL208V9R@P0Rh^;0`2>SXh2096AT@<0U9BD1@2FUYH309FEU@80UiNG
0`2HV9P209NGU`<0UYJF0P2HV9P609ZJVP80Vi^K1@2LW9`309fMW@<0WYjN0P2OWil30:6QX@80Xj>S
1P2UYJD20:BTY0<0Xj>S1@2QXJ430::RXPD0XJ6Q0P2OWil309fMW@<0VYZJ0P2GUiL309BDU080TY:B
0`2@T90308f=S@80RHV90`25QHD207moO`<0Ng]k0P1jNWX307]kN`<0O7al0P1nOWh308:2PP80QHF5
1P26QXH20861P@D0O7al0`1mOGd307]kN`D0NGUi1@1jNWXd0<SPf0<0:RXZ0P0T92@302TY:@80>SXj
0`0b<S83024Q8@808b<S0`0`<302024Q8@<0;2`/0`0X:2P205aLG0<0RHV90P2:RXX307EeM@D0N7Qh
0`1iNGT209:BTP<0_kno0P3<c<`30<k>cP<0b/[:0P2o_kl30<G5a@80Ogmo0`0_;bl5028R8P<09bLW
0P0[:b/302TY:@<08R8R0P0X:2P502LW9`<0:2PX0`0`<30205IFEP<0I6AT0P1JFUX30451@@<0=cLg
0P18B4P304E5A@80De=C0`1GEeL205aLG0<0H61P0`1VIVH2075aL@<0MGEe1@1gMgL307emO@L0P820
0`27QhL808B4Q0D0QXJ60`2:RXX208N7Q`<0S8b<0P2?Shl308J6QPD0T92@0`2BTY8209JFUP<0VIVI
0`2CTi<209NGU`<0UIFE0P2HV9P309BDU080UYJF0`2JVYX309fMW@80Vi^K1@2LW9`309RHV0<0WYjN
0P2SXj<30::RXP80X:2P0`2UYJD50:BTY0<0X:2P1@2TY:@30:>SX`80Y:BT0`2QXJ4209jNWP<0Vi^K
0`2MWId509BDU080TY:B0`2?Shl308j>SP80R8R80`25QHD207emO@<0O7al0P1jNWX307]kN`<0O7al
0P1kNg/308:2PP80Ph>30`2<S8`308F5Q@80OGem0`1oOgl207]kN`<0OGem0`1nOWh207UiN@<0MGEe
0P1jNWX307inOQ`0b>3H000K0<SPf0<092@T0P0Y:BT302l_;`80;Rh^0`0`<30302TY:@807QhN0`0O
7al2024Q8@<0=3@d0`0^;Rh205eMG@<0Q8B40P2BTY8307AdM080MGEe0`1hN7P307moO`80Rh^;0`34
a<@20=7Ad@<0c<c<0`31`L420<;2`P<0^k^k0P1jNWX303@d=0<06ATI0P0S8b<302@T9080:BTY0`0X
:2P502HV9P<09bLW0P0T92@302LW9`<09RHV0P1NGUh505YJFP<0BDU90`0k>c/20451@@<0Bd];0P1B
DU8305UIF@80GUiN0`1SHf<306UYJ@80Kfm_0`1cLg<207IfMP<0N7Qh0`1jNWX207emO@<0Ogmo0P21
PH4608>3P`80Q8B40`25QHD508J6QP<0QhN70P29RHT808^;R`<0SXj>0P2ATI4309BDU0D0UYJF0`2E
UID209NGU`<0V9RH0P2GUiL309JFUP80V9RH1P2JVYX209^KV`D0W9bL0`2MWId309jNWP80WinO0`2Q
XJ420:>SX`H0YJFU0P2TY:@30:>SX`D0XJ6Q0`2RXZ850:6QX@80WinO0`2MWId309ZJVP80UiNG0`2D
U9@209:BTP<0T92@0`2=SHd208V9R@<0QHF50P1oOgl307]kN`80NWYj0`1kNg/307alO080OWin0`22
PX8208F5Q@H0QXJ60P21PH4507alO0<0OGem0`1kNg/507UiN@D0NWYj=038h=P302XZ:P8092@T0`0Y
:BT203Xj>P<0<S8b0`0Q8B4202<S8`<0<30`0P0Q8B4302`/;0<0:2PX0P1LG5`308V9R@80RXZ:0`1e
MGD507QhN0<0NGUi0P2BTY830;no_`80c<c<0`3>c/h30<[:bP80_kno0`35aLD207moO`<0;bl_1@0R
8R8302LW9`80:b/[0`0Y:BT3028R8P80:2PX1@0W9bL302PX:0<0<30`0P1FEUH306ATI080FUYJ0`11
@D4303Lg=`80B4Q80`15ADD205=CD`<0EeMG0P1LG5`3061PH0<0IVIV0P1aLG4307EeM@D0MgMg0`1m
OGd70820P0<0QhN72024Q8@508J6QP<0RXZ:0P27QhL308b<S080Shn?0`26QXH5092@T0<0TY:B0P2F
UYH309VIV@<0Ti>C0P2GUiL309FEU@80V9RH0`2DU9@209JFUP<0VYZJ0`2MWId209^KV`D0W9bL0`2H
V9P309jNWP80Xj>S0`2RXZ820:2PX0<0YJFU1@2TY:@30:2PX0D0Y:BT0`2SXj<20:BTY0<0XJ6Q0P2N
WYh309^KV`<0WIfM1@2DU9@209:BTP<0Shn?0`2>SXh208R8R0<0QHF50P1mOGd307alO080NWYj0`1k
Ng/307alO080Ng]k0`22PX8208>3P`<0S8b<0`25QHD207emO@<0Ogmo0P1kNg/307emO@<0OWin0P1i
NGT307EeM@80NWYj0`1nOWhL0<SPf0006`38h=P302@T9080:BTY0`0_;bl202h^;P<0<30`0`0Y:BT2
01hN7P<07alO0P0Q8B4303@d=0<0;Rh^0P1MGEd308B4Q080TY:B0`1dM7@207EeM@<0N7Qh0`1oOgl2
08^;R`<0a<C40P3AdM430<c<c0<0`L710P32`/830;^k^`80NWYj0`0d=3@301TI6@808b<S0`0T92@2
02TY:@<0:2PX1@0V9RH302LW9`8092@T0`0W9bL302HV9P80GUiN1@1JFUX304U9B@<0>c/k0P11@D43
04];B`80DU9B0`1IFET205iNGP<0Hf=S0`1YJFT206m_K`<0Lg=c0P1fMWH307QhN0<0NWYj0P1mOGd3
07moO`80PH611P23Ph<208B4Q0<0QHF51@26QXH308N7Q`80RHV9202;Rh/308j>SP80TI6A0`2DU9@5
09JFUP<0UIFE0P2GUiL309RHV080UiNG0`2FUYH209RHV0H0VYZJ0P2KVi/509bLW0<0WIfM0`2NWYh2
09nOW`<0XJ6Q0P2SXj<60:FUY@80Y:BT0`2SXj<50:6QX@<0XZ:R1@2QXJ4209nOW`<0WIfM0`2JVYX2
09NGU`<0U9BD0P2BTY83092@T0<0SHf=0P29RHT308F5Q@80Ogmo0`1kNg/207YjNP<0Ng]k0`1lO7`2
07inOP<0PX:20P25QHD608J6QP80PH611@1lO7`307emO@<0Ng]k1@1iNGT507YjNS@0b>3H0`0Z:RX2
02@T90<0:BTY0P0j>SX3038b<P<08B4Q0P0S8b<3030`<0808B4Q0`0/;2`302PX:080G5aL0`29RHT2
08Z:RP<0MGEe1@1hN7P307UiN@80TY:B0`2o_kl20<c<c0<0c/k>0`3:b/X20;no_`<0aLG50P1oOgl3
02l_;`D08R8R0`0W9bL202/[:`<0:BTY0`0R8R8202PX:0D09bLW0`0X:2P3030`<080EUIF0`1TI6@2
05YJFP<0@D510`0g=cL204Q8B0<0ADE50P1CDe<305MGE`80G5aL0`1PH60306IVIP80LG5a0`1eMGD5
07MgM`<0OGem1`20P80308N7Q`P0Q8B41@26QXH308Z:RP80QhN70`2<S8`208n?S`<0QXJ61@2@T903
09:BTP80UYJF0`2IVIT309>CT`80UiNG0`2EUID209RHV0<0U9BD0P2FUYH309ZJVP<0WIfM0P2KVi/5
09bLW0<0V9RH0`2NWYh20:>SX`<0XZ:R0P2PX:030:FUY@D0Y:BT0`2PX:050:BTY0<0Xj>S0P2TY:@3
0:6QX@80WYjN0`2KVi/309fMW@D0U9BD0P2BTY8308n?S`<0SXj>0P28R8P308F5Q@80OGem0`1lO7`2
07YjNP<0Ng]k0`1lO7`207]kN`<0PX:20P23Ph<308b<S0<0QHF50P1mOGd307moO`80Ng]k0`1mOGd3
07inOP80NGUi0`1eMGD207YjNP<0OWin7038h=P001/0b>3H0`0Q8B4202PX:0P0<C4a0`0Z:RX5024Q
8@808b<S0`0H61P301/K6`80CDe=0`1kNg/209jNWPD0MGEe0`1cLg<307AdM080Ogmo0`2WYjL20<k>
cP<0dM7A0`3=cLd20=SHf0<0dM7A0P2d];@3051@D0D09BDU0`0T92@202XZ:P<0:BTY0`0X:2P202HV
9P<09BDU0P0R8R8302LW9`<092@T0P1JFUX305QHF080E5AD0`18B4P303hn?P80@T920`1;Bd/205=C
D`<0Fe]K0P1PH60306ATI0<0Jf][0P1aLG4307EeM@80N7Qh0`1iNGT307YjNP80OGem0`20P80208:2
PPP0Ph>30`24Q8@508J6QP<0QhN70P2<S8`3096AT@80T92@0`2>SXh308n?S`80TI6A0`2CTi<209FE
U@H0UYJF0P2GUiL309RHV0D0UiNG0P2JVYX609fMW@D0W9bL202MWId209jNWP<0X:2P0P2TY:@30:NW
Y`<0YZJV0P2TY:@30::RXP80XJ6Q1P2PX:020::RXP<0Xj>S0P2QXJ4309nOW`<0W9bL0P2IVIT309JF
UP80Ti>C0`2?Shl308^;R`80R8R80`26QXH208:2PP<0P8200P1oOgl30820P0<0OWin0P1mOGd30820
P080Q8B40`25QHD308B4Q080P8200`1kNg/207emO@<0Ogmo0`1lO7`:07UiNC@0b>3H0`0S8b<202DU
9@<0<S8b0P0h>3P302l_;`<0;2`/1@0O7al2028R8P<07QhN0`0R8R8204A4A0<0PX:20P2JVYX307]k
N`80LG5a0`1fMWH307=cL`80Ogmo0`2XZ:P20=3@d0<0clo?0`3@d=020<c<c0<0d=3@0P2i^KT304U9
B@<09RHV0P0S8b<302XZ:P809RHV0`0X:2P302`/;0D092@T0P0U9BD3028R8P<0:2PX0P1CDe<3061P
H080E5AD0`0l?3`30451@@80BTY:0`1;Bd/205ADE0<0GEeM0P1QHF4306MWI`<0JVYZ0P1aLG4307Ee
M@80MgMg0`1iNGT307MgM`80Ogmo1@20P80308F5Q@D0PH610`27QhL208>3P`<0QXJ60`27QhL208^;
R`<0S8b<0P2HV9P308Z:RP<0TY:B1@2@T90209JFUP<0V9RH0`2BTY8209VIV@<0V9RH0P2IVIT309RH
V080VYZJ0`2KVi/309jNWPD0Vi^K0P2OWil309ZJVP<0WYjN0P2PX:0309nOW`80Xj>S1P2WYjL20:BT
Y0<0Xj>S0P2PX:0309jNWP<0X:2P0P2QXJ430:>SX`80WinO0`2NWYh309fMW@80VIVI0`2EUID2096A
T@<0TY:B0`29RHT208R8R0<0QhN70P22PX8307inOP80PH610`1oOgl307inOP80O7al1@23Ph<308N7
Q`<0Ph>30P1nOWh307alO080Ng]k1P1oOgl207UiN@<0MGEe0P1fMWH30861PA`0b>3H000K0<SPf0<0
8B4Q0P0X:2P8034a<@<0:RXZ1@0Q8B4202<S8`<061PH0`0K6a/204e=C@<0Ng]k0P2NWYh507EeM@<0
Lg=c0`1dM7@207moO`<0YjNW0P3>c/h30=7Ad@<0cLg=0P3Hf=P30=7Ad@80];Bd0`1@D50502DU9@<0
92@T0P0Z:RX302TY:@<0:2PX0P0V9RH302DU9@808R8R0`0W9bL302@T9080FUYJ0`1HF5P205ADE0<0
B4Q80`0n?Sh20492@P<0Bd];0P1CDe<305]KF`80H61P0`1TI6@306][J`80LG5a0`1eMGD207QhN0<0
NGUi0`1jNWX207emO@<0P8200P22PX8808>3P`<0Q8B41@26QXH308N7Q`80S8b<0`2ATI42092@T0<0
SXj>0`2?Shl2096AT@<0Ti>C0P2EUID609JFUP80UiNG0`2HV9P509NGU`80VYZJ1P2MWId509bLW0P0
WIfM0P2NWYh30:2PX080Y:BT0`2WYjL30:JVYP80Y:BT0`2RXZ820:6QX@H0X:2P0P2RXZ830:>SX`80
XJ6Q0`2OWil309bLW080VIVI0`2FUYH209>CT`<0Shn?0`2;Rh/208R8R0<0QXJ60P22PX830820P080
Ogmo0`20P80307inOP80OGem0`20P80208B4Q0<0QHF50`24Q8@20820P0<0Ng]k0P1mOGd307moO`<0
O7al2P1iNGTd0<SPf0<08b<S0P0U9BD3038b<P80>3Ph0`0_;bl302`/;0D07alO0P0R8R8301hN7P<0
8R8R0P14A4@308:2PP80VYZJ0`1kNg/2075aL@<0MWIf0`1cLg<207moO`<0Z:RX0P3@d=030<o?c`<0
d=3@0P3<c<`30=3@d080^KVi0`19BDT302HV9P808b<S0`0Z:RX202HV9P<0:2PX0`0/;2`502@T9080
9BDU0`0R8R8302PX:080De=C0`1PH60205ADE0<0?3`l0`11@D4204Y:BP<0Bd];0P1DE5@305eMG@80
HF5Q0`1WIfL306YZJP80LG5a0`1eMGD207MgM`<0NGUi0`1gMgL207moO`D0P8200`25QHD50861P@<0
QhN70P23Ph<308J6QP<0QhN70P2;Rh/308b<S080V9RH0`2:RXX309:BTPD0T92@0P2FUYH309RHV0<0
TY:B0P2IVIT309RHV080VIVI0`2HV9P209ZJVP<0Vi^K0`2NWYh509^KV`80WinO0`2JVYX309jNWP80
X:2P0`2OWil20:>SX`H0YjNW0P2TY:@30:>SX`80X:2P0`2NWYh30:2PX080XJ6Q0`2SXj<209nOW`<0
WYjN0`2MWId209VIV@<0UIFE0P2ATI4309:BTP<0RHV90P28R8P308N7Q`80PX:20`1nOWh20861P@<0
Ogmo0`1nOWh207alO0D0Ph>30`27QhL308>3P`80OWin0`1lO7`207]kN`H0Ogmo0P1iNGT307EeM@80
MWIf0`21PH4L0<SPf0006`38h=P3020P8080;Rh^0`0m?Cd204i>CP<0?Shn0`0P820202<S8`<0820P
0P0Q8B4301DE5@<061PH0P0n?Sh306MWI`80SHf=0`26QXH207YjNP<0L71`0`1aLG4207inOP<0RXZ:
0P2k^k/30=GEe@<0bLW90P3AdM430<o?c`80d=3@0`2QXJ4302l_;`80<30`200V9RH302LW9`809BDU
0`0T92@202<S8`<0:RXZ0`0P8202059BDP<0GUiN0P1:BTX304=3@`<0?3`l0P11@D4304Y:BP80DE5A
0`1IFET2061PH0<0IVIV0`1/K6`2071`L0<0M7Ad0P1hN7P307alO0D0OWin0`1mOGd20820P0<0Q8B4
0`23Ph<208:2PP<0Q8B40P27QhL308R8R0<0RHV90P2:RXX308b<S080SXj>0`2ATI4509:BTP<0Ti>C
0P2DU9@309JFUPP0V9RH0P2JVYX309bLW080WYjN0`2PX:0309jNWP80W9bL0`2MWId209jNWPH0WinO
0P2QXJ430:BTY080YJFU1P2VYZH50:FUY@80Y:BT0`2SXj<30::RXPL0Xj>S0`2RXZ830:2PX080WIfM
0`2IVIT209BDU0<0T92@0`2=SHd208Z:RP<0R8R80P25QHD308>3P`80PX:22021PH4308:2PP80Ph>3
0`22PX830820P080OWin0`1lO7`507]kN`<0NWYj0P1iNGT307YjNPD0Ng]k=038h=P302<S8`80;Rh^
0`0m?Cd204i>CP<0=CDe0`0S8b<2020P80<06a/K0P0N7Qh301`L70<07alO0P0_;bl306][J`80Shn?
0`26QXH207=cL`<0L71`0`1dM7@207IfMP<0T92@0P2o_kl30<g=c@<0bl_;0P3>c/h30<c<c080c/k>
0`2SXj<303Ph>0809BDU0`0T92@202HV9P<0:BTY0`0U9BD202HV9P<09bLW0P0R8R8302@T90<09BDU
0P1=CDd306IVIP80CTi>0`0j>SX30492@P80AdM70`15ADD204];B`<0EeMG0P1QHF4306MWI`<0K6a/
1@1aLG4207UiN@<0OWin0`20P80207YjNP<0OWin1@20P80308>3P`80PX:20`27QhL208R8R0H0RHV9
0P2:RXX508j>SP<0Shn?0`2DU9@209>CT`<0T92@0P2ATI4309RHV0<0Vi^K0P2GUiL309JFUP80VIVI
0`2JVYX209jNWP<0XZ:R0`2NWYh209fMW@<0W9bL0P2PX:0809nOW`<0XZ:R0P2VYZH30:RXZ0<0XZ:R
0P2VYZH30:BTY080YJFU0`2RXZ830:2PX080Y:BT0`2UYJD20::RXP<0YZJV0`2OWil209jNWP<0VYZJ
1@2CTi<308b<S080SXj>1@25QHD508B4Q0<0P8201@21PH4308B4Q080OGem0`24Q8@308:2PP80O7al
0`1oOgl207alO0<0Ng]k0`1iNGT207]kN`<0NGUi0P1lO7`307emOA`0b>3H000K0<SPf0<0820P0P0^
;Rh303dm?@80CTi>0`0n?Sh3020P80808b<S0`0P8202024Q8@<05ADE0`0H61P203hn?P<0IfMW0P2=
SHd308J6QP80NWYj0`1`L703075aL@80OWin0`2:RXX20;^k^`<0eMGE0`39bLT20=7Ad@<0clo?0P3@
d=030:6QX@<0;bl_0P0`<30802HV9P<09bLW0P0U9BD302@T90808b<S0`0Z:RX3020P8080DU9B0`1N
GUh204Y:BP<0@d=30`0l?3`20451@@<0BTY:0P1ADE4305UIF@80H61P0`1VIVH306a/K080L71`0`1d
M7@207QhN0<0O7al1@1nOWh307emO@80P8200`24Q8@308>3P`80PX:20`24Q8@208N7Q`<0R8R80`29
RHT208Z:RP<0S8b<0P2>SXh3096AT@D0TY:B0`2CTi<209BDU0<0UYJF202HV9P209ZJVP<0W9bL0P2N
WYh30:2PX0<0WYjN0P2LW9`309fMW@80WYjN1P2OWil20:6QX@<0Y:BT0P2UYJD60:JVYPD0YJFU0P2T
Y:@30:>SX`<0XZ:R1`2SXj<30::RXP<0X:2P0P2MWId309VIV@80U9BD0`2@T90308f=S@80RXZ:0`28
R8P208F5Q@<0Ph>30P22PX880861P@<0PX:20P23Ph<308:2PP<0P8200P1nOWh307alO0D0Ng]k0`1j
NWX207UiN@<0NWYj1@1kNg/d0<SPf0<08b<S0P0^;Rh303dm?@80CTi>0`0e=CD302<S8`80820P0`0K
6a/201hN7P<071`L0`0O7al202l_;`<0Jf][0P2?Shl308J6QP80Lg=c0`1`L70307AdM080MWIf0`2@
T9020;no_`<0cLg=0`3;bl/20<k>cP<0c<c<0P3>c/h30:>SX`<0>3Ph0P0U9BD302@T90809RHV0`0Y
:BT302DU9@809RHV0`0W9bL2028R8P<092@T0`0U9BD204e=C@<0IVIV0P1>CTh303Xj>P<0@T920P17
AdL304E5A@80Bd];0`1GEeL2065QH@<0IfMW0`1/K6`5075aL@80NGUi0`1nOWh30820P080NWYj0`1n
OWh50820P0<0Ph>30P22PX8308N7Q`80R8R81P29RHT208Z:RPD0SXj>0`2?Shl309BDU080Ti>C0`2@
T902096AT@<0V9RH0`2KVi/209NGU`<0UYJF0P2IVIT309ZJVP80WYjN0`2RXZ8309jNWP80WIfM0`2L
W9`20:2PX0P0WinO0`2RXZ820:JVYP<0Z:RX0`2RXZ820:JVYP<0Y:BT0P2UYJD30::RXP<0X:2P0P2T
Y:@30:FUY@80XZ:R0`2VYZH309nOW`80WYjN0`2JVYX509>CT`<0S8b<0P2>SXh508F5Q@D0Q8B40`20
P8050861P@<0Q8B40P1mOGd308B4Q0<0PX:20P1lO7`307moO`80O7al0`1kNg/307UiN@80Ng]k0`1i
NGT207alO0<0OGem7038h=P001/0b>3H0`0P820202h^;P<0?Cdm0P1>CTh303hn?P<0820P0P0S8b<3
020P80808B4Q0`0E5AD301PH6080?Shn0`1WIfL208f=S@<0QXJ60P1jNWX3071`L0<0LG5a0P1nOWh3
08Z:RP80^k^k0`3EeMD30<W9b@80dM7A0`3?cll20=3@d0<0XJ6Q0`0_;bl2030`<0P09RHV0`0W9bL2
02DU9@<092@T0P0S8b<302XZ:P<0820P0P1BDU8305iNGP80BTY:0`13@d<303`l?080@D510`1:BTX2
055AD@<0FEUI0P1PH60306IVIP<0K6a/0P1`L70307AdM080N7Qh0`1lO7`507inOP<0OGem0P20P803
08B4Q0<0Ph>30P22PX8308B4Q080QhN70`28R8P308V9R@80RXZ:0`2<S8`208j>SP<0TI6A1@2BTY83
09>CT`80U9BD0`2FUYH809RHV080VYZJ0`2LW9`209jNWP<0X:2P0`2NWYh209bLW0<0WIfM0P2NWYh6
09nOW`80XJ6Q0`2TY:@20:FUY@H0YZJV1@2UYJD20:BTY0<0Xj>S0`2RXZ870:>SX`<0XZ:R0`2PX:02
09fMW@<0VIVI0P2DU9@3092@T0<0SHf=0P2:RXX308R8R080QHF50`23Ph<208:2PPP0PH610`22PX82
08>3P`<0PX:20`20P80207inOP<0O7al1@1kNg/307YjNP80NGUi0`1jNWX507]kNc@0b>3H0`0S8b<2
02h^;P<0?Cdm0P1>CTh303De=@<08b<S0P0P820301/K6`807QhN0`0L71`301lO7`80;bl_0`1[Jf/2
08n?S`<0QXJ60P1cLg<3071`L0<0M7Ad0P1fMWH3092@T080_kno0`3=cLd30<_;b`80c/k>0`3<c<`2
0<k>cP<0Xj>S0`0h>3P202DU9@<092@T0P0V9RH302TY:@<09BDU0P0V9RH302LW9`808R8R0`0T92@3
02DU9@80CDe=0`1VIVH204i>CP<0>SXj0`12@T8204M7A`<0ADE50P1;Bd/305MGE`80HF5Q0`1WIfL3
06a/K0D0LG5a0P1iNGT307inOP<0P8200P1jNWX307inOPD0P8200`23Ph<208:2PP<0QhN70P28R8P6
08V9R@80RXZ:1@2>SXh308n?S`<0U9BD0P2CTi<3092@T080TI6A0`2HV9P309^KV`80UiNG0`2FUYH2
09VIV@<0VYZJ0P2NWYh30::RXP<0WYjN0P2MWId309bLW080X:2P202OWil30::RXP80YZJV0`2XZ:P3
0::RXP80YZJV0`2TY:@20:FUY@<0XZ:R0`2PX:020:BTY0<0YJFU0P2RXZ830:JVYP<0WinO0P2NWYh3
09ZJVPD0Ti>C0`2<S8`208j>SPD0QHF51@24Q8@30820P0D0PH610`24Q8@207emO@<0Q8B40`22PX82
07alO0<0Ogmo0P1lO7`307]kN`<0NGUi0P1kNg/307UiN@80O7al0`1mOGdL0<SPf0006`38h=P302<S
8`80=cLg0`1<C4`206e]K@<0C4a<0`0J6QX202DU9@<07QhN0P0O7al301TI6@<06QXJ0P0`<30304m?
C`80MWIf0`2FUYH208B4Q0<0Kfm_0`1aLG4207moO`<0LW9b0P2TY:@30=?Cd`<0`/;20P39bLT30<[:
bP80e]KF0`3AdM4308:2PP80;Rh^0`0T92@202HV9P<09BDU0`0V9RH502<S8`8092@T0`0/;2`3020P
8080Bd];0`1TI6@20410@0<0?Cdm0`0k>c/20451@@<0BDU90P1@D50305MGE`80H61P0`1XJ6P306e]
K@80L71`0`1dM7@207QhN0<0OWin0`22PX8207moO`<0Ng]k0P1oOgl308B4Q0<0PX:20P21PH4308B4
Q080R8R80`2:RXX308^;R`80R8R80`26QXH208b<S0<0Ti>C1@2DU9@509>CT`<0UiNG0`2KVi/209VI
V@<0V9RH0P2LW9`30:6QX@D0XZ:R0`2PX:0209fMW@<0WYjN0P2PX:030::RXP<0Xj>S0P2VYZH30:NW
Y`80YZJV0`2UYJD30:JVYP80YjNW1@2XZ:P30:NWY`<0YJFU0P2TY:@30:>SX`D0YJFU0`2SXj<209nO
W`<0Vi^K0P2FUYH309:BTP<0T92@0P2<S8`308Z:RP80QhN70`25QHD208>3P`<0PX:20`23Ph<208F5
Q@<0Q8B40P22PX8307moO`P0OGem0P1jNWX307MgM`<0N7Qh0P1jNWX507alO0<0OGem=038h=P302HV
9P80<S8b0`1<C4`207=cL`<0CDe=0`0V9RH2020P80<08B4Q0P0N7Qh601dM7@809BDU0`1@D50208>3
P`<0UIFE0P1iNGT306m_K`<0NGUi0P1fMWH307QhN080YJFU0`37alL30<S8b080c/k>0`3?cll50<k>
cP<0RHV90P0a<C4302DU9@809RHV0`0U9BD302LW9`808B4Q0`0S8b<202TY:@<09bLW0`0Y:BT204U9
B@<0G5aL0P18B4P303De=@<0?3`l0P15ADD304U9B@80CDe=0`1JFUX2069RHP<0IVIV0`1/K6`2079b
LP<0M7Ad0P1eMGD308:2PP<0Ph>30P1mOGd307]kN`80P8200`23Ph<308J6QP80OWin0`24Q8@208N7
Q`<0RHV91@2:RXX308J6QP80RHV90`2@T90309ZJVP80TY:B0`2@T90509JFUP<0Vi^K0P2IVIT309NG
U`L0XJ6Q0`2SXj<30:2PX080WYjN0`2OWil20:2PX0<0XZ:R0`2SXj<20::RXP<0YJFU0P2XZ:P30:FU
Y@<0Xj>S0P2XZ:P30:VYZ@80Z:RX0`2TY:@30:FUY@80Z:RX0`2RXZ850:JVYP<0WinO0P2PX:0309^K
V`80UYJF0`2ATI43092@T080RHV90`2:RXX208R8R0P0Ph>30`22PX8508B4Q0D0PH610`1kNg/207al
O0<0OGem0P1iNGT607QhN080NWYj0`1kNg/207alO0<0OGem7038h=P001/0b>3H0`0S8b<203Lg=`<0
C4a<0P1]KFd304a<C0<06QXJ0P0U9BD301hN7P807alO0`0I6AT301XJ6P80<30`0`1?Cdl207IfMP<0
UYJF0P24Q8@306m_K`<0LG5a0P1oOgl3079bLP80Y:BT0`3Cdm<30<;2`P80bLW90`3:b/X20=KFeP<0
dM7A0`22PX8202h^;P<092@T0P0V9RH302DU9@<09RHV1@0S8b<202@T90<0;2`/0`0P820204];B`<0
I6AT0P10@40303dm?@<0>c/k0P11@D4304U9B@80D51@0`1GEeL2061PH0<0J6QX0`1]KFd2071`L0<0
M7Ad0P1hN7P307inOP<0PX:20P1oOgl307]kN`80Ogmo0`24Q8@308:2PP80PH610`24Q8@208R8R0<0
RXZ:0`2;Rh/208R8R0<0QXJ60P2<S8`309>CT`D0U9BD1@2CTi<309NGU`<0Vi^K0P2IVIT309RHV080
W9bL0`2QXJ450::RXP<0X:2P0P2MWId309jNWP80X:2P0`2RXZ830:>SX`80YZJV0`2WYjL20:JVYP<0
YJFU0`2VYZH20:NWY`D0Z:RX0`2WYjL30:FUY@80Y:BT0`2SXj<50:FUY@<0Xj>S0P2OWil309^KV`80
UYJF0`2BTY83092@T080S8b<0`2:RXX208N7Q`<0QHF50P23Ph<308:2PP<0Ph>30P25QHD308B4Q080
PX:20`1oOgl807emO@80NWYj0`1gMgL307QhN080NWYj1@1lO7`307emOC@0b>3H0`0V9RH2038b<P<0
C4a<0P1cLg<304e=C@<09RHV0P0P8203024Q8@807QhN1P0M7Ad202DU9@<0D51@0P23Ph<309FEU@80
NGUi0`1_Kfl307UiN@80MWIf0`1hN7P20:FUY@<0alO70`38b<P20<k>cP<0clo?1@3>c/h308V9R@80
<C4a0`0U9BD202HV9P<09BDU0`0W9bL2024Q8@<08b<S0P0Y:BT302LW9`<0:BTY0P19BDT305aLG080
B4Q80`0e=CD303`l?080ADE50`19BDT204e=C@<0FUYJ0P1RHV8306IVIP<0K6a/0P1bLW8307AdM080
MGEe0`22PX8308>3P`80OGem0`1kNg/20820P0<0Ph>30`26QXH207inOP<0Q8B40P27QhL308V9R@D0
RXZ:0`26QXH208V9R@<0T92@0`2JVYX209:BTP<0T92@1@2FUYH309^KV`80VIVI0`2GUiL70:6QX@<0
Xj>S0`2PX:0209jNWP<0WinO0P2PX:030::RXP<0Xj>S0P2RXZ830:FUY@80Z:RX0`2UYJD30:>SX`80
Z:RX0`2YZJT20:RXZ0<0Y:BT0`2UYJD20:RXZ0<0XZ:R1@2VYZH309nOW`80X:2P0`2KVi/209JFUP<0
TI6A0`2@T90208V9R@<0RXZ:0P28R8P808>3P`<0PX:21@24Q8@50861P@<0Ng]k0P1lO7`307emO@80
NGUi1P1hN7P207YjNP<0Ng]k0P1lO7`307emOA`0b>3H000K0<SPf0<08b<S0P0g=cL304a<C080KFe]
0`1<C4`301XJ6P809BDU0`0N7Qh201lO7`<06ATI0`0J6QX2030`<0<0Cdm?0P1fMWH309JFUP80Q8B4
0`1_Kfl3075aL@80Ogmo0`1bLW820:BTY0<0dm?C0`32`/820<W9b@<0b/[:0P3Fe]H30=7Ad@<0PX:2
0P0^;Rh302@T90809RHV0`0U9BD302HV9PD08b<S0P0T92@302`/;0<0820P0P1;Bd/306ATI080@410
0`0m?Cd303/k>`80@D510`19BDT2051@D0<0EeMG0P1PH60306QXJ0<0KFe]0P1`L70307AdM080N7Qh
0`1nOWh308:2PP80Ogmo0`1kNg/207moO`<0Q8B40`22PX820861P@<0Q8B40P28R8P308Z:RP<0Rh^;
0P28R8P308J6QP80S8b<0`2CTi<509BDU0D0Ti>C0`2GUiL309^KV`80VIVI0`2HV9P209bLW0<0XJ6Q
1@2RXZ830:2PX080WIfM0`2NWYh20:2PX0<0XZ:R0`2SXj<20:JVYP<0YjNW0P2VYZH30:FUY@<0YZJV
0P2WYjL50:RXZ0<0YjNW0`2UYJD20:BTY0<0Xj>S1@2UYJD30:>SX`80WinO0`2KVi/209JFUP<0TY:B
0`2@T90208b<S0<0RXZ:0P27QhL308F5Q@80Ph>30`22PX8308>3P`80QHF50`24Q8@208:2PP<0Ogmo
201mOGd207YjNP<0MgMg0`1hN7P207YjNPD0O7al0`1mOGdd0<SPf0<09RHV0P0b<S8304a<C080Lg=c
0`1=CDd302HV9P80820P0`0Q8B4201hN7PH07AdM0P0U9BD3051@D080Ph>30`2EUID207UiN@<0Kfm_
0`1iNGT207IfMP<0N7Qh0P2UYJD30<O7a`<0b<S80P3>c/h30<o?c`D0c/k>0`29RHT2034a<@<09BDU
0P0V9RH302DU9@<09bLW0P0Q8B4302<S8`80:BTY0`0W9bL302TY:@80BDU90`1LG5`204Q8B0<0=CDe
0`0l?3`204E5A@<0BDU90P1=CDd305YJFP80HV9R0`1VIVH306a/K080LW9b0`1dM7@207EeM@<0PX:2
0`23Ph<207emO@<0Ng]k0P20P80308>3P`<0QXJ60P1nOWh308B4Q080QhN70`29RHT508Z:RP<0QXJ6
0P29RHT3092@T0<0VYZJ0P2BTY83092@T0D0UYJF0`2KVi/209VIV@<0UiNG1`2QXJ430:>SX`<0X:2P
0P2NWYh309nOW`80X:2P0`2RXZ830:>SX`80XZ:R0`2UYJD20:RXZ0<0YJFU0`2SXj<20:RXZ0<0ZJVY
0P2XZ:P30:BTY0<0YJFU0P2XZ:P30::RXPD0YZJV0`2OWil20:2PX0<0Vi^K0P2FUYH3096AT@<0T92@
0P29RHT308Z:RP80R8R82023Ph<308:2PPD0Q8B41@21PH4307]kN`80O7al0`1mOGd207UiN@H0N7Qh
0P1jNWX307]kN`80O7al0`1mOGdL0<SPf0006`38h=P302d];@80?Shn0`1DE5@2092@T0<0O7al0`13
@d<202@T90<06a/K0P0M7Ad301TI6@<06a/K0P0S8b<303Lg=`80KFe]0`2HV9P209JFUP<0KFe]0`1^
KVh207MgM`<0Lg=c0P2CTi<30;fm_@<0a<C40P3;bl/30<[:bP80d=3@0`3;bl/30<K6aP80J6QX0`0Y
:BT2024Q8@<0820P0`0U9BD502@T90808R8R0`0U9BD302XZ:P80@d=30`1QHF4203dm?@<0>c/k0`0i
>CT203lo?`<0B4Q80P1@D50305UIF@80HF5Q0`1YJFT306e]K@80L71`0`1dM7@207QhN0<0OGem1@20
P80307inOP80PH610`23Ph<308:2PP80PH610`23Ph<208N7Q`<0RHV90`2:RXX508V9R@80SHf=0`2B
TY8509BDU0<0UIFE0P2FUYH309VIV@<0Vi^K1@2JVYX209jNWP<0XZ:R1@2SXj<30:2PX080WYjN0`2P
X:020:>SX`<0YZJV1@2WYjL30:JVYP80Z:RX0`2YZJT30:RXZ080YjNW0`2XZ:P20:VYZ@<0Z:RX0`2W
YjL20:FUY@<0Xj>S0P2TY:@30:FUY@<0XZ:R0P2NWYh309^KV`80V9RH0`2EUID3096AT@80SHf=0`29
RHT208N7Q`<0QXJ60P24Q8@308:2PP<0Q8B41@25QHD208>3P`<0P8200`1nOWh207moO`<0P8200P1l
O7`307QhN0<0NGUi0P1kNg/507alO0<0OGem=038h=P303<c<`80?Cdm0`1LG5`208F5Q@<0MWIf0`16
ATH202@T90<07QhN1@0K6a/301`L70808b<S0`0g=cL2071`L0<0X:2P0P2;Rh/306e]K@<0OWin0P1f
MWH307EeM@80TI6A0`2n_[h30<?3``D0b/[:0P3<c<`30<o?c`<0`l?30P1TI6@302PX:0808B4Q0`0S
8b<302DU9@809RHV0`0Q8B4201lO7`<09bLW0`0^;Rh204];B`<0EEEE0P14A4@303De=@<0>SXj0P14
A4@304Y:BP80DE5A0`1FEUH206QXJ0<0JFUY0`1[Jf/2071`L0<0Kfm_0P1kNg/307inOPD0OGem0`21
PH4208>3P`<0PH610`25QHD20861P@<0Ogmo0P29RHT608^;R`80QhN70`28R8P208f=S@<0TY:B0`2H
V9P2096AT@<0UYJF0P2GUiL309VIV@<0VYZJ0P2FUYH309^KV`80XJ6Q0`2MWId20:>SX`<0XZ:R0`2J
VYX509jNWP80XZ:R0`2TY:@30:^[Z`80ZZZZ0`2[Zj/20:ZZZP<0Z:RX0`2WYjL20:VYZ@<0Z:RX0P2Z
ZZX30:JVYP<0Z:RX0P2VYZH50:2PX0<0YJFU0`2QXJ4209jNWP<0Vi^K0P2EUID309RHV0<0TI6A0P2<
S8`308^;R`80RXZ:0`26QXH208F5Q@<0P8200`23Ph<208J6QP<0QhN70P25QHD308:2PP<0OGem0P1n
OWh30820P080O7al0`1hN7P307YjNP80Ng]k0`1lO7`207]kN`<0OGem7038h=P001/0b>3H0`0];Bd2
03hn?P<0E5AD0P2@T90307alO0<0@d=30P0T92@301/K6`807AdM0`0I6AT301/K6`808b<S0`0g=cL2
06e]K@<0V9RH0P2FUYH306e]K@<0KVi^0P1gMgL307=cL`80Ti>C0`2m_Kd30<C4a080bl_;0`3:b/X2
0=3@d0<0bl_;0`36a/H206QXJ0<0:BTY0P0Q8B43020P80<09BDU1@0T92@2028R8P<09BDU0`0Z:RX2
04=3@`<0HF5Q0P0m?Cd303/k>`<0>CTi0P0o?cl304Q8B080D51@0`1IFET2065QH@<0JFUY0`1]KFd2
071`L0<0M7Ad0P1hN7P307emO@D0P8200`1nOWh20861P@<0Ph>30`22PX820861P@<0Ph>30P27QhL3
08V9R@<0RXZ:1@29RHT208f=S@<0TY:B1@2DU9@309FEU@80UYJF0`2IVIT309^KV`D0VYZJ0P2NWYh3
0::RXPD0Xj>S0`2PX:0209jNWP<0X:2P0P2SXj<30:JVYPD0YjNW0`2VYZH20:RXZ0<0ZJVY0`2XZ:P2
0:NWY`<0Z:RX0P2YZJT30:RXZ0<0YjNW0P2UYJD30:>SX`80Y:BT0`2UYJD30::RXP80WYjN0`2KVi/2
09RHV0<0UIFE0`2ATI4208f=S@<0RHV90P27QhL308J6QP80Q8B40`22PX8308B4Q0D0QHF50P23Ph<3
0820P0<0OWin0P1oOgl30820P080O7al0`1hN7P307UiN@80Ng]k1@1lO7`307emOC@0b>3H0`0c<c<2
03dm?@<0G5aL0P25QHD307IfMP<0ATI60P0T92@301hN7PD06a/K0`0L71`202<S8`<0=cLg0P1`L703
0:2PX080Rh^;0`1]KFd307inOP80MWIf0`1eMGD2096AT@<0_[jn0`33`l<50<[:bP80c<c<0`3?cll3
0<?3``80I6AT0`0X:2P2024Q8@<08b<S0`0U9BD202HV9P<08B4Q0P0O7al302LW9`<0;Rh^0P1;Bd/3
05EEE@80A4A40`0e=CD303Xj>P80A4A40`1:BTX2055AD@<0EUIF0P1XJ6P306UYJ@<0Jf][0P1`L703
06m_K`80Ng]k0`1nOWh507emO@<0PH610P23Ph<30861P@<0QHF50P21PH4307moO`80RHV91P2;Rh/2
08N7Q`<0R8R80P2=SHd309:BTP<0V9RH0P2ATI4309JFUP80UiNG0`2IVIT309ZJVP80UYJF0`2KVi/2
0:6QX@<0WIfM0P2SXj<30::RXP<0VYZJ1@2NWYh20::RXP<0Y:BT0`2[Zj/20:ZZZP<0Zj^[0P2ZZZX3
0:RXZ0<0YjNW0P2YZJT30:RXZ080ZZZZ0`2VYZH30:RXZ080YZJV1@2PX:030:FUY@<0XJ6Q0P2NWYh3
09^KV`80UIFE0`2HV9P3096AT@80S8b<0`2;Rh/208Z:RP<0QXJ60P25QHD30820P0<0Ph>30P26QXH3
08N7Q`80QHF50`22PX8307emO@80OWin0`20P80207alO0<0N7Qh0`1jNWX207]kN`<0O7al0P1kNg/3
07emOA`0b>3H000K0<SPf0<0>CTi0P1=CDd306=SH`80SHf=0`1]KFd304i>CP809bLW0`0N7Qh201dM
7@<06a/K0`0L71`201/K6`<09BDU0P1PH603092@T080Y:BT0`1_Kfl306i^KP80L71`0`1hN7P208F5
Q@<0YJFU0`36a/H20<_;b`<0bLW90P3>c/h30=;BdP<0`<300P31`L430492@P80:BTY0`0M7Ad302@T
90809BDU0`0V9RH2024Q8@<07QhN0`0c<c<203lo?`<0G5aL0P0k>c/303Xj>P<0=cLg0P0n?Sh304M7
A`80DE5A0`1JFUX206=SH`<0JFUY0`1]KFd206m_K`<0M7Ad0P1iNGT307]kN`<0OGem0P20P80308:2
PP80Ph>32022PX8308>3P`80Q8B40`27QhL308Z:RP80S8b<0`2=SHd208n?S`<0TI6A0`2CTi<209FE
U@<0V9RH1@2JVYX509^KV`<0W9bL0P2OWil30::RXPD0Xj>S0`2PX:0209nOW`<0XZ:R0P2VYZH30:VY
Z@<0Zj^[0P2XZ:P30:FUY@80ZJVY0`2][Jd30:^[Z`80Z:RX202YZJT30:RXZ080YZJV0`2SXj<50:BT
Y0<0X:2P0P2LW9`309^KV`80VYZJ0`2GUiL309:BTP80SHf=0`28R8P508N7Q`80Q8B40`23Ph<308B4
Q0L0QHF50`22PX830820P0D0PH610P1mOGd307UiN@<0NWYj0P1kNg/307alO0D0OGem=038h=P303@d
=080DE5A0`1VIVH208R8R0<0MgMg0`1HF5P202@T90<071`L0P0M7Ad301/K6`<06QXJ0P0N7Qh302HV
9P80FEUI0`2BTY8209jNWP<0LG5a1@1_Kfl3075aL@80QHF50`2XZ:P30<G5a@80bLW90`3<c<`20<_;
b`<0c<c<0`3>c/h20;Fe]@<0ATI60P0W9bL6024Q8@808b<S0`0Z:RX202DU9@<08b<S0`0Y:BT204M7
A`<0EUIF0P0o?cl303Xj>P<0>3Ph0P0l?3`304E5A@D0EEEE0P1YJFT306IVIP<0K6a/0P1`L70307If
MP80MgMg1P1mOGd208F5Q@<0PH610P22PX8308B4Q0<0P8201@22PX8208B4Q0<0QhN70`29RHT208f=
S@<0Rh^;1@2@T90309>CT`80UIFE0`2MWId209NGU`<0W9bL0`2MWId209RHV0<0X:2P0P2MWId30:6Q
X@80Y:BT0`2RXZ830:6QX@80XZ:R0`2PX:020:ZZZP<0YjNW0`2ZZZX20:JVYP<0Xj>S0P2[Zj/30:b/
[0<0Z:RX0P2ZZZX30:^[Z`80ZJVY0`2WYjL30:VYZ@D0YJFU0P2QXJ430:FUY@<0XJ6Q0P2IVIT309^K
V`80V9RH0`2GUiL309:BTP80SXj>0`29RHT208J6QP<0R8R80P24Q8@808>3P`<0QhN70P23Ph<60861
P@80OGem0`22PX8207inOP<0Ng]k0`1hN7P207YjNP<0OWin0P1kNg/307inOQ`0b>3H000K0<SPf0<0
>CTi0P1=CDd306=SH`80SHf=0`1]KFd304i>CP809bLW0`0N7Qh201dM7@<06a/K0`0L71`201/K6`<0
9BDU0P1PH603092@T080Y:BT0`1_Kfl306i^KP80L71`0`1hN7P208F5Q@<0YJFU0`36a/H20<_;b`<0
bLW90P3>c/h30=;BdP<0`<300P31`L430492@P80:BTY0`0M7Ad302@T90809BDU0`0V9RH2024Q8@<0
7QhN0`0c<c<203lo?`<0G5aL0P0k>c/303Xj>P<0=cLg0P0n?Sh304M7A`80DE5A0`1JFUX206=SH`<0
JFUY0`1]KFd206m_K`<0M7Ad0P1iNGT307]kN`<0OGem0P20P80308:2PP80Ph>32022PX8308>3P`80
Q8B40`27QhL308Z:RP80S8b<0`2=SHd208n?S`<0TI6A0`2CTi<209FEU@<0V9RH1@2JVYX509^KV`<0
W9bL0P2OWil30::RXPD0Xj>S0`2PX:0209nOW`<0XZ:R0P2VYZH30:VYZ@<0Zj^[0P2XZ:P30:FUY@80
ZJVY0`2][Jd30:^[Z`80Z:RX202YZJT30:RXZ080YZJV0`2SXj<50:BTY0<0X:2P0P2LW9`309^KV`80
VYZJ0`2GUiL309:BTP80SHf=0`28R8P508N7Q`80Q8B40`23Ph<308B4Q0L0QHF50`22PX830820P0D0
PH610P1mOGd307UiN@<0NWYj0P1kNg/307alO0D0OGem=038h=P303@d=080DE5A0`1VIVH208R8R0<0
MgMg0`1HF5P202@T90<071`L0P0M7Ad301/K6`<06QXJ0P0N7Qh302HV9P80FEUI0`2BTY8209jNWP<0
LG5a1@1_Kfl3075aL@80QHF50`2XZ:P30<G5a@80bLW90`3<c<`20<_;b`<0c<c<0`3>c/h20;Fe]@<0
ATI60P0W9bL6024Q8@808b<S0`0Z:RX202DU9@<08b<S0`0Y:BT204M7A`<0EUIF0P0o?cl303Xj>P<0
>3Ph0P0l?3`304E5A@D0EEEE0P1YJFT306IVIP<0K6a/0P1`L70307IfMP80MgMg1P1mOGd208F5Q@<0
PH610P22PX8308B4Q0<0P8201@22PX8208B4Q0<0QhN70`29RHT208f=S@<0Rh^;1@2@T90309>CT`80
UIFE0`2MWId209NGU`<0W9bL0`2MWId209RHV0<0X:2P0P2MWId30:6QX@80Y:BT0`2RXZ830:6QX@80
XZ:R0`2PX:020:ZZZP<0YjNW0`2ZZZX20:JVYP<0Xj>S0P2[Zj/30:b/[0<0Z:RX0P2ZZZX30:^[Z`80
ZJVY0`2WYjL30:VYZ@D0YJFU0P2QXJ430:FUY@<0XJ6Q0P2IVIT309^KV`80V9RH0`2GUiL309:BTP80
SXj>0`29RHT208J6QP<0R8R80P24Q8@808>3P`<0QhN70P23Ph<60861P@80OGem0`22PX8207inOP<0
Ng]k0`1hN7P207YjNP<0OWin0P1kNg/307inOQ`0b>3H000K0<SPf0<0>CTi0P1=CDd306=SH`80SHf=
0`1]KFd304i>CP809bLW0`0N7Qh201dM7@<06a/K0`0L71`201/K6`<09BDU0P1PH603092@T080Y:BT
0`1_Kfl306i^KP80L71`0`1hN7P208F5Q@<0YJFU0`36a/H20<_;b`<0bLW90P3>c/h30=;BdP<0`<30
0P31`L430492@P80:BTY0`0M7Ad302@T90809BDU0`0V9RH2024Q8@<07QhN0`0c<c<203lo?`<0G5aL
0P0k>c/303Xj>P<0=cLg0P0n?Sh304M7A`80DE5A0`1JFUX206=SH`<0JFUY0`1]KFd206m_K`<0M7Ad
0P1iNGT307]kN`<0OGem0P20P80308:2PP80Ph>32022PX8308>3P`80Q8B40`27QhL308Z:RP80S8b<
0`2=SHd208n?S`<0TI6A0`2CTi<209FEU@<0V9RH1@2JVYX509^KV`<0W9bL0P2OWil30::RXPD0Xj>S
0`2PX:0209nOW`<0XZ:R0P2VYZH30:VYZ@<0Zj^[0P2XZ:P30:FUY@80ZJVY0`2][Jd30:^[Z`80Z:RX
202YZJT30:RXZ080YZJV0`2SXj<50:BTY0<0X:2P0P2LW9`309^KV`80VYZJ0`2GUiL309:BTP80SHf=
0`28R8P508N7Q`80Q8B40`23Ph<308B4Q0L0QHF50`22PX830820P0D0PH610P1mOGd307UiN@<0NWYj
0P1kNg/307alO0D0OGem=038h=P303@d=080DE5A0`1VIVH208R8R0<0MgMg0`1HF5P202@T90<071`L
0P0M7Ad301/K6`<06QXJ0P0N7Qh302HV9P80FEUI0`2BTY8209jNWP<0LG5a1@1_Kfl3075aL@80QHF5
0`2XZ:P30<G5a@80bLW90`3<c<`20<_;b`<0c<c<0`3>c/h20;Fe]@<0ATI60P0W9bL6024Q8@808b<S
0`0Z:RX202DU9@<08b<S0`0Y:BT204M7A`<0EUIF0P0o?cl303Xj>P<0>3Ph0P0l?3`304E5A@D0EEEE
0P1YJFT306IVIP<0K6a/0P1`L70307IfMP80MgMg1P1mOGd208F5Q@<0PH610P22PX8308B4Q0<0P820
1@22PX8208B4Q0<0QhN70`29RHT208f=S@<0Rh^;1@2@T90309>CT`80UIFE0`2MWId209NGU`<0W9bL
0`2MWId209RHV0<0X:2P0P2MWId30:6QX@80Y:BT0`2RXZ830:6QX@80XZ:R0`2PX:020:ZZZP<0YjNW
0`2ZZZX20:JVYP<0Xj>S0P2[Zj/30:b/[0<0Z:RX0P2ZZZX30:^[Z`80ZJVY0`2WYjL30:VYZ@D0YJFU
0P2QXJ430:FUY@<0XJ6Q0P2IVIT309^KV`80V9RH0`2GUiL309:BTP80SXj>0`29RHT208J6QP<0R8R8
0P24Q8@808>3P`<0QhN70P23Ph<60861P@80OGem0`22PX8207inOP<0Ng]k0`1hN7P207YjNP<0OWin
0P1kNg/307inOQ`0b>3H000K0<SPf0<0@d=30P1PH6030861P@80WIfM0`29RHT3061PH080:2PX0`0N
7Qh201lO7`<07QhN0`0O7al201/K6`<08R8R0P0m?Cd307MgM`80XZ:R0`1nOWh307EeM@80KVi^0`1b
LW8207]kN`<0WIfM0`34a<@20<S8b0<0b/[:0P3>c/h30=3@d0<0bl_;0P31`L430:NWY`80AdM70`0L
71`302@T90808R8R0`0W9bL202<S8`<092@T0`0V9RH20451@@<0GEeM0P0g=cL303De=@<0=3@d0P0m
?Cd304Q8B080DU9B0`1KFe/2069RHP<0J6QX0`1/K6`206m_K`<0M7Ad0P1hN7P307YjNP<0O7al0P20
P80;08>3P`L0Q8B40`27QhL308Z:RP80SHf=1@2?Shl3092@T0<0U9BD0P2GUiL509RHV0<0Vi^K1@2M
WId309jNWP80WinO0`2PX:080:6QX@80XZ:R0`2VYZH20:ZZZP<0Zj^[0`2/[:`20:VYZ@<0YjNW0P2Y
ZJT60:b/[0D0Zj^[202ZZZX20:NWY`<0Y:BT1@2UYJD30::RXP80WYjN0`2LW9`209ZJVP<0UiNG0`2D
U9@208j>SP<0R8R80P27QhL308J6QP80QHF50`24Q8@308F5Q@80QXJ60`25QHD208B4Q0<0PX:21@21
PH430820P080OGem1P1iNGT207YjNP<0OGem1@1oOgld0<SPf0<0@d=30P1RHV8307inOP80Ti>C0`1o
Ogl3061PH0809RHV0`0M7Ad201lO7`<092@T0`0M7Ad201hN7P<092@T0P0k>c/30861P@80W9bL0`1o
Ogl307EeM@80KVi^0`1`L70207inOP<0X:2P0`36a/H20<O7a`<0b/[:0P3<c<`30<g=c@<0c/k>0P3<
c<`30:FUY@80?clo0`0V9RH802<S8`D08B4Q0`0[:b/20451@@<0EeMG0P0l?3`303Lg=`<0=3@d0P0l
?3`304E5A@80D51@0`1KFe/206ATI0<0IFEU0`1/K6`2071`L0<0M7Ad0P1fMWH307alO0<0NGUi1@21
PH420820P0<0Ph>30`25QHD208J6QP<0QhN70P23Ph<308J6QP<0RHV90P2ATI4308n?S`80TY:B0`2>
SXh509>CT`<0UiNG0P2EUID309^KV`<0W9bL0P2OWil309ZJVP80WinO0`2TY:@20::RXP<0X:2P0`2T
Y:@20:2PX0<0Y:BT0P2ZZZX30:b/[0<0[Jf]0P2VYZH30:>SX`80Zj^[0`2][Jd30:b/[0D0Z:RX0P2[
Zj/30:ZZZP<0ZJVY0P2ZZZX30:NWY`D0YJFU0`2VYZH209jNWPD0WIfM0`2GUiL309BDU080R8R80`27
QhL208F5Q@<0Q8B40P26QXH308F5Q@<0QhN70P26QXH308R8R080Ph>30`22PX8508>3P`<0PH610P1l
O7`307MgM`<0N7Qh0P1mOGd307]kN`80OWin0`23Ph<L0<SPf0006`38h=P304=3@`80H61P0`21PH42
09fMW@<0RHV90`1PH60202PX:0<07QhN0P0O7al301hN7P<07alO0P0K6a/3028R8P80?Cdm0`1gMgL2
0::RXP<0OWin0`1eMGD206i^KP<0LW9b0P1kNg/309fMW@<0a<C40P38b<P30<[:bP80c/k>0`3@d=03
0<_;b`80`L710`2WYjL204M7A`<071`L0`0T92@2028R8P<09bLW0P0S8b<302@T90<09RHV0P11@D43
05eMG@80=cLg0`0e=CD303@d=080?Cdm0`18B4P2059BDP<0Fe]K0P1RHV8306QXJ0<0K6a/0P1_Kfl3
07AdM080N7Qh0`1jNWX307alO080P8202`23Ph<708B4Q0<0QhN70`2:RXX208f=S@D0Shn?0`2@T903
09BDU080UiNG1@2HV9P309^KV`D0WIfM0`2NWYh209nOW`<0X:2P202QXJ420::RXP<0YZJV0P2ZZZX3
0:^[Z`<0[:b/0P2YZJT30:NWY`80ZJVY1P2/[:`50:^[Z`P0ZZZZ0P2WYjL30:BTY0D0YJFU0`2RXZ82
09jNWP<0W9bL0P2JVYX309NGU`<0U9BD0P2>SXh308R8R080QhN70`26QXH208F5Q@<0Q8B40`25QHD2
08J6QP<0QHF50P24Q8@308:2PPD0PH610`20P80207emO@H0NGUi0P1jNWX307emO@D0Ogmo=038h=P3
04=3@`80HV9R0`1nOWh209>CT`<0Ogmo0`1PH60202HV9P<07AdM0P0O7al302@T90<07AdM0P0N7Qh3
02@T9080>c/k0`21PH4209bLW0<0Ogmo0`1eMGD206i^KP<0L71`0P1nOWh30:2PX0<0a/K60P37alL3
0<[:bP80c<c<0`3=cLd30<k>cP80c<c<0`2UYJD203lo?`<09RHV200S8b<5024Q8@<0:b/[0P11@D43
05MGE`80?3`l0`0g=cL303@d=080?3`l0`15ADD2051@D0<0Fe]K0P1TI6@306EUI@<0K6a/0P1`L703
07AdM080MWIf0`1lO7`307UiN@D0PH610P20P80308>3P`<0QHF50P26QXH308N7Q`80Ph>30`26QXH3
08V9R@80TI6A0`2?Shl209:BTP<0SXj>1@2CTi<309NGU`80UIFE0`2KVi/309bLW080WinO0`2JVYX2
09nOW`<0Y:BT0P2RXZ830:2PX0<0Y:BT0P2PX:030:BTY080ZZZZ0`2/[:`30:f][@80YZJV0`2SXj<2
0:^[Z`<0[Jf]0`2/[:`50:RXZ080Zj^[0`2ZZZX30:VYZ@80ZZZZ0`2WYjL50:FUY@<0YZJV0P2NWYh5
09fMW@<0UiNG0`2DU9@208R8R0<0QhN70P25QHD308B4Q080QXJ60`25QHD308N7Q`80QXJ60`28R8P2
08>3P`<0PX:21@23Ph<30861P@80O7al0`1gMgL307QhN080OGem0`1kNg/207inOP<0Ph>37038h=P0
01/0b>3H0`1@D50207=cL`<0WinO0P2UYJD309ZJVP<0Hf=S0P0Y:BT301lO7`808R8R0`0Q8B4302<S
8`807alO0`0U9BD201hN7P<0FUYJ0P2EUID308f=S@<0Ogmo0P1]KFd306YZJP80Lg=c0`2FUYH30;^k
^`80aLG50`3;bl/20<c<c0<0bl_;0`3De=@20=3@d0<0a<C40P2;Rh/303<c<`<09BDU0P0N7Qh302LW
9`809RHV0`0[:b/301XJ6P80ADE50`1KFe/203@d=0<0<S8b0`0a<C4203`l?0<0BTY:0P1DE5@305aL
G080HF5Q0`1VIVH306][J`80L71`0`1dM7@207MgM`<0NGUi0`1kNg/207moO`P0Ph>30`25QHD208J6
QPD0QHF50`27QhL308^;R`80SXj>0`2?Shl2092@T0<0TI6A0`2EUID209VIV@<0V9RH0P2GUiL309ZJ
VP<0WYjN302OWil30:2PX0<0XZ:R0P2UYJD30:ZZZPD0[Jf]0`2[Zj/20:ZZZPD0ZJVY0`2ZZZX30:f]
[@80[Zj^0`2/[:`50:ZZZP<0Zj^[0P2XZ:P80:FUY@<0Xj>S0P2QXJ4309fMW@80VIVI0`2GUiL309FE
U@80Shn?0`29RHT208J6QPP0QHF50`27QhL208R8R0<0QXJ60P24Q8@308>3P`<0PH610P20P80307mo
O`80O7al1P1iNGT207YjNP<0OGem0P21PH4308:2PS@0b>3H0`1CDe<207AdM0<0Vi^K0P2][Jd309RH
V0<0JFUY0P0V9RH301hN7P80820P0`0T92@302<S8`807alO0`0P820202HV9P<0Fe]K0P2<S8`309BD
U0<0O7al0P1^KVh306][J`80M7Ad0`2@T9030;Jf]P80c/k>0`36a/H20<g=c@<0clo?1@3=cLd30<W9
b@80Rh^;0`0a<C43028R8PD09bLW0P0T92@302/[:`<09RHV0P14A4@305EEE@80>3Ph0`0_;bl303De
=@80>CTi0`1<C4`205IFEP<0FUYJ0P1UIFD306IVIP<0Kfm_0P1aLG4307=cL`80MWIf0`1nOWh307Qh
N080Ph>30`25QHD20820P0<0Ph>32025QHD208J6QP<0QhN71@2;Rh/3092@T080Ti>C0`2?Shl309FE
U@X0V9RH0`2PX:0209fMW@<0X:2P0P2TY:@309bLW080WIfM0`2PX:030:>SX`80Z:RX0`2TY:@20:f]
[@<0/K6a0`2YZJT20:ZZZP<0YjNW0P2/[:`30:RXZ0<0[Zj^0P2`/;030:^[Z`80ZZZZ1P2/[:`20:FU
Y@<0YjNW0P2PX:030:FUY@<0YZJV0P2OWil309jNWP80V9RH0`2IVIT309BDU080TI6A0`2:RXX208F5
Q@P0QXJ60`24Q8@208R8R0<0QXJ60P22PX8308F5Q@D0P8200`1oOgl207]kN`<0NWYj0`1hN7P207]k
N`<0O7al1@22PX8L0<SPf0006`38h=P3051@D080Lg=c0`2OWil20:FUY@<0VYZJ0`1SHf<202TY:@<0
7alO0P0R8R83024Q8@<08b<S0P0O7al302DU9@807QhN0`1JFUX209FEU@<0SHf=0`1oOgl206e]K@<0
JVYZ0P1cLg<309JFUP<0^k^k0P35aLD30<_;b`80c<c<0`3;bl/30=CDe080d=3@0`34a<@208^;R`<0
<c<c0`0U9BD201hN7P<09bLW0P0V9RH302/[:`<06QXJ0P15ADD305]KF`80=3@d0`0b<S83034a<@80
?3`l0`1:BTX205ADE0<0G5aL0P1QHF4306IVIP<0Jf][0P1`L70307AdM080MgMg0`1iNGT307]kN`80
Ogmo2023Ph<308F5Q@80QXJ61@25QHD308N7Q`<0Rh^;0P2>SXh308n?S`80T92@0`2ATI4309FEU@80
VIVI0`2HV9P209NGU`<0VYZJ0`2NWYh<09nOW`<0X:2P0`2RXZ820:FUY@<0ZZZZ1@2][Jd30:^[Z`80
ZZZZ1@2YZJT30:ZZZP<0[Jf]0P2^[Zh30:b/[0D0ZZZZ0`2[Zj/20:RXZ0P0YJFU0`2SXj<20:6QX@<0
WIfM0P2IVIT309NGU`<0UIFE0P2?Shl308V9R@80QXJ62025QHD308N7Q`80R8R80`26QXH208B4Q0<0
Ph>30`21PH420820P0<0Ogmo0P1lO7`607UiN@80NWYj0`1mOGd20861P@<0PX:2=038h=P305=CD`80
M7Ad0`2KVi/20:f][@<0V9RH0`1YJFT202HV9P<07QhN0P0P820302@T90<08b<S0P0O7al3020P8080
9RHV0`1KFe/208b<S0<0U9BD0`1lO7`206i^KP<0Jf][0P1dM7@3092@T0<0][Jf0P3>c/h30<K6aP80
cLg=0`3?cll50<g=c@<0bLW90P2;Rh/3034a<@<08R8R1@0W9bL202@T90<0:b/[0`0V9RH204A4A0<0
EEEE0P0h>3P302l_;`<0=CDe0P0i>CT304a<C080EUIF0`1JFUX206EUI@<0IVIV0`1_Kfl2075aL@<0
Lg=c0P1fMWH307inOP<0N7Qh0P23Ph<308F5Q@80P8200`23Ph<808F5Q@80QXJ60`27QhL508^;R`<0
T92@0P2CTi<308n?S`<0UIFE2P2HV9P30:2PX080WIfM0`2PX:020:BTY0<0W9bL0P2MWId30:2PX0<0
Xj>S0P2XZ:P30:BTY080[Jf]0`2a/K430:VYZ@80ZZZZ0`2WYjL20:b/[0<0Z:RX0`2^[Zh20;2`/0<0
Zj^[0P2ZZZX60:b/[080YJFU0`2WYjL20:2PX0<0YJFU0`2VYZH209nOW`<0WYjN0P2HV9P309VIV@<0
U9BD0P2ATI4308Z:RP80QHF52026QXH308B4Q080R8R80`26QXH208:2PP<0QHF51@20P80307moO`80
Ng]k0`1jNWX307QhN080Ng]k0`1lO7`508:2PQ`0b>3H000K0<SPf0<0D51@0P1cLg<309nOW`80YJFU
0`2JVYX306=SH`80:BTY0`0O7al2028R8P<08B4Q0`0S8b<201lO7`<09BDU0P0N7Qh305YJFP80UIFE
0`2=SHd307moO`80KFe]0`1ZJVX207=cL`<0UYJF0`2k^k/20<G5a@<0bl_;0P3<c<`30<_;b`<0e=CD
0P3@d=030<C4a080Rh^;0`0c<c<302DU9@807QhN0`0W9bL202HV9P<0:b/[0`0J6QX204E5A@<0Fe]K
0P0d=3@3038b<P<0<C4a0P0l?3`304Y:BP80E5AD0`1LG5`2065QH@<0IVIV0`1[Jf/2071`L0<0M7Ad
0P1gMgL307UiN@<0Ng]k0P1oOgl808>3P`<0QHF50P26QXH508F5Q@<0QhN70`2;Rh/208j>SP<0Shn?
0P2@T903096AT@<0UIFE0P2IVIT309RHV080UiNG0`2JVYX309jNWP`0WinO0`2PX:030::RXP80YJFU
0`2ZZZX50:f][@<0Zj^[0P2ZZZX50:VYZ@<0ZZZZ0`2][Jd20:j^[P<0[:b/1@2ZZZX30:^[Z`80Z:RX
202UYJD30:>SX`80XJ6Q0`2MWId209VIV@<0UiNG0`2EUID208n?S`<0RHV90P26QXH808F5Q@<0QhN7
0P28R8P308J6QP80Q8B40`23Ph<30861P@80P8200`1oOgl207alO0H0NGUi0P1jNWX307emO@80PH61
0`22PX8d0<SPf0<0De=C0P1dM7@309^KV`80[Jf]0`2HV9P306UYJ@809RHV0`0N7Qh2020P80<092@T
0`0S8b<201lO7`<0820P0P0V9RH305]KF`80S8b<0`2DU9@307alO080KVi^0`1[Jf/207AdM0<0T92@
0`2f][H20<k>cP<0a/K60P3=cLd30<o?c`D0cLg=0`39bLT208^;R`<0<C4a0`0R8R8502LW9`8092@T
0`0[:b/302HV9P80A4A40`1EEED203Ph>0<0;bl_0`0e=CD203Ti>@<0C4a<0P1FEUH305YJFP80IFEU
0`1VIVH306m_K`80LG5a0`1cLg<207IfMP<0OWin0`1hN7P208>3P`<0QHF50P20P80308>3P`P0QHF5
0P26QXH308N7Q`D0Rh^;0`2@T90209>CT`<0Shn?0`2EUID:09RHV0<0X:2P0P2MWId30:2PX080Y:BT
0`2LW9`209fMW@<0X:2P0`2SXj<20:RXZ0<0Y:BT0P2][Jd30;6a/@<0ZJVY0P2ZZZX30:NWY`80[:b/
0`2XZ:P30:j^[P80/;2`0`2[Zj/20:ZZZPH0[:b/0P2UYJD30:NWY`80X:2P0`2UYJD30:JVYP80WinO
0`2NWYh209RHV0<0VIVI0`2DU9@2096AT@<0RXZ:0P25QHD808J6QP<0Q8B40P28R8P308J6QP80PX:2
0`25QHD50820P0<0Ogmo0P1kNg/307YjNP<0N7Qh0P1kNg/307alO0D0PX:27038h=P001/0b>3H0`1Q
HF4208N7Q`<0/K6a0P2UYJD308f=S@<0BDU90P0Z:RX3020P808092@T0`0U9BD302LW9`8092@T0`0W
9bL201lO7`<0@D510P1mOGd3092@T0<0TI6A0P1VIVH306UYJ@80Kfm_0`27QhL30:2PX080b/[:0`38
b<P20<c<c0<0bLW90`3@d=020<g=c@<0fMWI0P2d];@306][J`<08R8R0P0P820302HV9P809BDU0`0X
:2P302HV9P80@d=30`1:BTX203Ph>0H0=CDe0P0o?cl304a<C080EEEE0`1LG5`206=SH`<0J6QX0`1]
KFd2075aL@<0MGEe0P1hN7P307]kN`<0OWin0P21PH4308>3P`D0PX:20`24Q8@708N7Q`<0RXZ:0`2=
SHd208j>SP<0T92@0P2ATI4309>CT`<0UYJF1`2HV9P309^KV`P0WYjN0P2PX:030::RXP80Xj>S0`2U
YJD30:JVYP80Z:RX0`2][Jd20;2`/0<0[Zj^1@2/[:`80:f][@D0[Zj^0`2[Zj/20:VYZ@<0ZZZZ0`2[
Zj/20:VYZ@<0YjNW0P2UYJD30:BTY0<0Xj>S0P2QXJ4309fMW@80VIVI0`2GUiL309JFUP80T92@0`2:
RXX208R8R0d0QXJ60`28R8P208V9R@<0QHF50`21PH420820P0<0Ogmo0P1nOWh307alO0D0Ng]k0`1o
Ogl208:2PP<0Ph>3=038h=P305mOG`80P8200`2f][H20:f][@<0RXZ:0`1ADE4202TY:@D08b<S0`0X
:2P302DU9@80820P0`0X:2P202@T90<0>c/k0P1jNWX309VIV@<0Ph>30P1]KFd506m_K`<0PH610`2P
X:020=7Ad@<0alO70P39bLT30<_;b`<0c<c<0P3=cLd30=7Ad@80`L710`1LG5`302LW9`80820P0`0V
9RH202<S8`<092@T0`0U9BD20410@0<0CTi>0P0i>CT3034a<@<0>3Ph0P0o?cl304m?C`80E5AD0`1K
Fe/2069RHP<0IFEU0`1/K6`2071`L0<0Kfm_0P1hN7P307alO0<0OGem0P1nOWh308F5Q@80Ogmo0`27
QhL308B4Q080QXJ60`25QHD208B4Q0<0SHf=0`2?Shl208^;R`<0S8b<0P2@T90309>CT`<0V9RH0P2K
Vi/509VIV@<0W9bL0`2NWYh209^KV`<0WYjN0P2LW9`30:BTY080XJ6Q0`2VYZH30:>SX`80ZZZZ0`2/
[:`20;:b/P<0[Jf]1@2/[:`30:n_[`80[Zj^0`2[Zj/30:b/[080[Zj^0`2][Jd50:RXZ0<0Zj^[0P2V
YZH50:NWY`<0XJ6Q0`2RXZ8209nOW`<0VIVI0P2EUID309NGU`<0UIFE0P2ATI4308Z:RP80R8R80`26
QXH208V9R@H0Q8B41`27QhL308Z:RP<0OWin0P1kNg/30820P080Ogmo0`20P80307UiN@80Ng]k0`1m
OGd20861P@<0QHF57038h=P001/0b>3H0`1QHF4208N7Q`<0/K6a0P2UYJD308f=S@<0BDU90P0Z:RX3
020P808092@T0`0U9BD302LW9`8092@T0`0W9bL201lO7`<0@D510P1mOGd3092@T0<0TI6A0P1VIVH3
06UYJ@80Kfm_0`27QhL30:2PX080b/[:0`38b<P20<c<c0<0bLW90`3@d=020<g=c@<0fMWI0P2d];@3
06][J`<08R8R0P0P820302HV9P809BDU0`0X:2P302HV9P80@d=30`1:BTX203Ph>0H0=CDe0P0o?cl3
04a<C080EEEE0`1LG5`206=SH`<0J6QX0`1]KFd2075aL@<0MGEe0P1hN7P307]kN`<0OWin0P21PH43
08>3P`D0PX:20`24Q8@708N7Q`<0RXZ:0`2=SHd208j>SP<0T92@0P2ATI4309>CT`<0UYJF1`2HV9P3
09^KV`P0WYjN0P2PX:030::RXP80Xj>S0`2UYJD30:JVYP80Z:RX0`2][Jd20;2`/0<0[Zj^1@2/[:`8
0:f][@D0[Zj^0`2[Zj/20:VYZ@<0ZZZZ0`2[Zj/20:VYZ@<0YjNW0P2UYJD30:BTY0<0Xj>S0P2QXJ43
09fMW@80VIVI0`2GUiL309JFUP80T92@0`2:RXX208R8R0d0QXJ60`28R8P208V9R@<0QHF50`21PH42
0820P0<0Ogmo0P1nOWh307alO0D0Ng]k0`1oOgl208:2PP<0Ph>3=038h=P305mOG`80P8200`2f][H2
0:f][@<0RXZ:0`1ADE4202TY:@D08b<S0`0X:2P302DU9@80820P0`0X:2P202@T90<0>c/k0P1jNWX3
09VIV@<0Ph>30P1]KFd506m_K`<0PH610`2PX:020=7Ad@<0alO70P39bLT30<_;b`<0c<c<0P3=cLd3
0=7Ad@80`L710`1LG5`302LW9`80820P0`0V9RH202<S8`<092@T0`0U9BD20410@0<0CTi>0P0i>CT3
034a<@<0>3Ph0P0o?cl304m?C`80E5AD0`1KFe/2069RHP<0IFEU0`1/K6`2071`L0<0Kfm_0P1hN7P3
07alO0<0OGem0P1nOWh308F5Q@80Ogmo0`27QhL308B4Q080QXJ60`25QHD208B4Q0<0SHf=0`2?Shl2
08^;R`<0S8b<0P2@T90309>CT`<0V9RH0P2KVi/509VIV@<0W9bL0`2NWYh209^KV`<0WYjN0P2LW9`3
0:BTY080XJ6Q0`2VYZH30:>SX`80ZZZZ0`2/[:`20;:b/P<0[Jf]1@2/[:`30:n_[`80[Zj^0`2[Zj/3
0:b/[080[Zj^0`2][Jd50:RXZ0<0Zj^[0P2VYZH50:NWY`<0XJ6Q0`2RXZ8209nOW`<0VIVI0P2EUID3
09NGU`<0UIFE0P2ATI4308Z:RP80R8R80`26QXH208V9R@H0Q8B41`27QhL308Z:RP<0OWin0P1kNg/3
0820P080Ogmo0`20P80307UiN@80Ng]k0`1mOGd20861P@<0QHF57038h=P001/0b>3H0`1QHF4208N7
Q`<0/K6a0P2UYJD308f=S@<0BDU90P0Z:RX3020P808092@T0`0U9BD302LW9`8092@T0`0W9bL201lO
7`<0@D510P1mOGd3092@T0<0TI6A0P1VIVH306UYJ@80Kfm_0`27QhL30:2PX080b/[:0`38b<P20<c<
c0<0bLW90`3@d=020<g=c@<0fMWI0P2d];@306][J`<08R8R0P0P820302HV9P809BDU0`0X:2P302HV
9P80@d=30`1:BTX203Ph>0H0=CDe0P0o?cl304a<C080EEEE0`1LG5`206=SH`<0J6QX0`1]KFd2075a
L@<0MGEe0P1hN7P307]kN`<0OWin0P21PH4308>3P`D0PX:20`24Q8@708N7Q`<0RXZ:0`2=SHd208j>
SP<0T92@0P2ATI4309>CT`<0UYJF1`2HV9P309^KV`P0WYjN0P2PX:030::RXP80Xj>S0`2UYJD30:JV
YP80Z:RX0`2][Jd20;2`/0<0[Zj^1@2/[:`80:f][@D0[Zj^0`2[Zj/20:VYZ@<0ZZZZ0`2[Zj/20:VY
Z@<0YjNW0P2UYJD30:BTY0<0Xj>S0P2QXJ4309fMW@80VIVI0`2GUiL309JFUP80T92@0`2:RXX208R8
R0d0QXJ60`28R8P208V9R@<0QHF50`21PH420820P0<0Ogmo0P1nOWh307alO0D0Ng]k0`1oOgl208:2
PP<0Ph>3=038h=P305mOG`80P8200`2f][H20:f][@<0RXZ:0`1ADE4202TY:@D08b<S0`0X:2P302DU
9@80820P0`0X:2P202@T90<0>c/k0P1jNWX309VIV@<0Ph>30P1]KFd506m_K`<0PH610`2PX:020=7A
d@<0alO70P39bLT30<_;b`<0c<c<0P3=cLd30=7Ad@80`L710`1LG5`302LW9`80820P0`0V9RH202<S
8`<092@T0`0U9BD20410@0<0CTi>0P0i>CT3034a<@<0>3Ph0P0o?cl304m?C`80E5AD0`1KFe/2069R
HP<0IFEU0`1/K6`2071`L0<0Kfm_0P1hN7P307alO0<0OGem0P1nOWh308F5Q@80Ogmo0`27QhL308B4
Q080QXJ60`25QHD208B4Q0<0SHf=0`2?Shl208^;R`<0S8b<0P2@T90309>CT`<0V9RH0P2KVi/509VI
V@<0W9bL0`2NWYh209^KV`<0WYjN0P2LW9`30:BTY080XJ6Q0`2VYZH30:>SX`80ZZZZ0`2/[:`20;:b
/P<0[Jf]1@2/[:`30:n_[`80[Zj^0`2[Zj/30:b/[080[Zj^0`2][Jd50:RXZ0<0Zj^[0P2VYZH50:NW
Y`<0XJ6Q0`2RXZ8209nOW`<0VIVI0P2EUID309NGU`<0UIFE0P2ATI4308Z:RP80R8R80`26QXH208V9
R@H0Q8B41`27QhL308Z:RP<0OWin0P1kNg/30820P080Ogmo0`20P80307UiN@80Ng]k0`1mOGd20861
P@<0QHF57038h=P001/0b>3H0`1fMWH209FEU@<0/k>c0P2IVIT307=cL`<0:b/[0P0Z:RX3028R8P80
9RHV0`0W9bL802TY:@80:2PX0`0^;Rh2065QH@<0S8b<0`2NWYh206EUI@<0JVYZ0P1^KVh307QhN0<0
QHF50P39bLT30<G5a@80bl_;0`36a/H30<W9b@80b/[:0`3IfMT20=?Cd`<0Y:BT0`0`<30502HV9P80
8b<S0`0T92@303<c<`80?clo1@0k>c/303Ph>0<0>CTi0P12@T8304i>CP80EUIF0`1MGEd206EUI@<0
Jf][0`1_Kfl207=cL`<0MWIf0P1iNGT307emO@<0PH610P22PX880861P@<0Q8B40P27QhL308R8R080
RXZ:0`2<S8`308j>SP80Shn?0`2@T90209>CT`<0UYJF1@2GUiL309RHV080VIVI0`2KVi/309fMW@D0
W9bL0P2PX:030:FUY@80Z:RX0`2YZJT30:ZZZP80Zj^[0`2_[jl20;:b/P<0/;2`0`2][Jd20:n_[`D0
/K6a0`2`/;030:n_[`80[Jf]0`2ZZZX20:RXZ0<0ZJVY0`2[Zj/20:ZZZP<0Z:RX0P2VYZH30:>SX`<0
XZ:R0P2PX:0309bLW080VIVI0`2GUiL309JFUP80TI6A0`2<S8`208Z:RP<0R8R81@27QhL308J6QP80
QHF50`2:RXX208j>SP<0QhN72020P80207moO`<0OWin1@1lO7`30820P080Ph>30`24Q8@d0<SPf0<0
NGUi0P2CTi<30;:b/P80V9RH0`1^KVh3038b<P808B4Q0`0^;Rh2028R8P<09RHV1@0[:b/302PX:080
9bLW0`0`<302061PH0<0T92@0`2EUID206e]K@<0I6AT0P1`L70307UiN@<0QHF50P33`l<30<[:bP80
aLG50`38b<P30<_;b`80c/k>0`3AdM420=CDe0<0YjNW0`0_;bl2028R8PD09BDU0`0X:2P302l_;`80
>CTi0`18B4P203Lg=`<0=SHf0`0l?3`204M7A`<0DE5A0P1CDe<305iNGP80IFEU0`1^KVh306e]K@80
MgMg0`1dM7@207YjNP<0P8200`1nOWh508>3P`80OWin0`24Q8@308:2PP80QXJ60`27QhL208Z:RPP0
SHf=0`2@T90209NGU`<0U9BD0`2HV9P209JFUP<0UiNG0P2HV9P609bLW080Vi^K0`2MWId209bLW0<0
YJFU0P2YZJT30:NWY`<0[Jf]1@2[Zj/20;Bd]0<0[jn_0`2][Jd20:n_[`<0/K6a0P2_[jl30;:b/P<0
[jn_0P2/[:`30:RXZ080YjNW1P2/[:`20:NWY`<0ZJVY0P2WYjL30:BTY0<0XJ6Q0P2RXZ8309jNWP80
VYZJ0`2IVIT309>CT`80TI6A0`2:RXX208V9R@<0QHF50P28R8P308J6QP<0QHF50P27QhL308R8R080
TI6A0`26QXH308>3P`80Ogmo1@21PH4307YjNP<0OGem1@1lO7`208B4Q0<0RHV97038h=P001/0b>3H
0`1fMWH209FEU@<0/k>c0P2IVIT307=cL`<0:b/[0P0Z:RX3028R8P809RHV0`0W9bL802TY:@80:2PX
0`0^;Rh2065QH@<0S8b<0`2NWYh206EUI@<0JVYZ0P1^KVh307QhN0<0QHF50P39bLT30<G5a@80bl_;
0`36a/H30<W9b@80b/[:0`3IfMT20=?Cd`<0Y:BT0`0`<30502HV9P808b<S0`0T92@303<c<`80?clo
1@0k>c/303Ph>0<0>CTi0P12@T8304i>CP80EUIF0`1MGEd206EUI@<0Jf][0`1_Kfl207=cL`<0MWIf
0P1iNGT307emO@<0PH610P22PX880861P@<0Q8B40P27QhL308R8R080RXZ:0`2<S8`308j>SP80Shn?
0`2@T90209>CT`<0UYJF1@2GUiL309RHV080VIVI0`2KVi/309fMW@D0W9bL0P2PX:030:FUY@80Z:RX
0`2YZJT30:ZZZP80Zj^[0`2_[jl20;:b/P<0/;2`0`2][Jd20:n_[`D0/K6a0`2`/;030:n_[`80[Jf]
0`2ZZZX20:RXZ0<0ZJVY0`2[Zj/20:ZZZP<0Z:RX0P2VYZH30:>SX`<0XZ:R0P2PX:0309bLW080VIVI
0`2GUiL309JFUP80TI6A0`2<S8`208Z:RP<0R8R81@27QhL308J6QP80QHF50`2:RXX208j>SP<0QhN7
2020P80207moO`<0OWin1@1lO7`30820P080Ph>30`24Q8@d0<SPf0<0NGUi0P2CTi<30;:b/P80V9RH
0`1^KVh3038b<P808B4Q0`0^;Rh2028R8P<09RHV1@0[:b/302PX:0809bLW0`0`<302061PH0<0T92@
0`2EUID206e]K@<0I6AT0P1`L70307UiN@<0QHF50P33`l<30<[:bP80aLG50`38b<P30<_;b`80c/k>
0`3AdM420=CDe0<0YjNW0`0_;bl2028R8PD09BDU0`0X:2P302l_;`80>CTi0`18B4P203Lg=`<0=SHf
0`0l?3`204M7A`<0DE5A0P1CDe<305iNGP80IFEU0`1^KVh306e]K@80MgMg0`1dM7@207YjNP<0P820
0`1nOWh508>3P`80OWin0`24Q8@308:2PP80QXJ60`27QhL208Z:RPP0SHf=0`2@T90209NGU`<0U9BD
0`2HV9P209JFUP<0UiNG0P2HV9P609bLW080Vi^K0`2MWId209bLW0<0YJFU0P2YZJT30:NWY`<0[Jf]
1@2[Zj/20;Bd]0<0[jn_0`2][Jd20:n_[`<0/K6a0P2_[jl30;:b/P<0[jn_0P2/[:`30:RXZ080YjNW
1P2/[:`20:NWY`<0ZJVY0P2WYjL30:BTY0<0XJ6Q0P2RXZ8309jNWP80VYZJ0`2IVIT309>CT`80TI6A
0`2:RXX208V9R@<0QHF50P28R8P308J6QP<0QHF50P27QhL308R8R080TI6A0`26QXH308>3P`80Ogmo
1@21PH4307YjNP<0OGem1@1lO7`208B4Q0<0RHV97038h=P001/0b>3H0`2IVIT209^KV`<0U9BD0P1a
LG4304e=C@<09bLW0P0[:b/802@T90D09bLW0`0X:2P202HV9P<0:b/[0P16ATH308F5Q@<0UIFE0P1l
O7`306EUI@80LW9b0`1cLg<30820P080ZJVY0`3:b/X20<K6aP<0`L710`34a<@20<W9b@<0e]KF0P3G
emL30;jn_P<0MWIf0P0a<C4302DU9@807alO0`0T92@3030`<080=CDe0`12@T82034a<@<0=CDe0`0j
>SX20492@P<0Bd];0P1EEED305mOG`80IFEU0`1[Jf/3075aL@80MgMg0`1iNGT207YjNP<0O7al0`1n
OWh207moO`<0P8200P22PX8608B4Q080QHF50`28R8P208^;R`<0S8b<0`2=SHd208j>SP<0T92@0P2C
Ti<309JFUPD0V9RH202IVIT309ZJVP80Vi^K0`2LW9`20:6QX@<0YJFU0P2WYjL30:RXZ0<0ZJVY0P2Z
ZZX30:j^[P80/[:b0`2`/;030:f][@80[jn_1@2b/[830;6a/@<0/;2`0P2^[Zh30:^[Z`80Z:RX0`2Z
ZZX30:b/[080ZZZZ0`2XZ:P20:NWY`<0YJFU0`2SXj<20:2PX0<0WYjN0P2KVi/309RHV0<0UIFE0P2C
Ti<3092@T080SHf=0`2:RXX208V9R@H0R8R80P29RHT308^;R`80SHf=0`28R8P308>3P`D0PH610P1o
Ogl307emO@D0O7al0`20P80208>3P`<0Q8B4=038h=P30:BTY080VYZJ0`2DU9@2071`L0<0BDU90`0]
;Bd202HV9P<08B4Q0P0R8R8302DU9@<0:2PX0P0T92@302XZ:P80:b/[0`0Z:RX204e=C@<0P8200`2G
UiL207UiN@<0I6AT0P1`L70307]kN`<0OGem0P2][Jd30<c<c080_;bl0`34a<@30<S8b080c<c<0`3@
d=020=GEe@<0b<S80`1eMGD203De=@<0:BTY0P0R8R8302HV9P<09bLW0P0o?cl304=3@`80<C4a0`0_
;bl303Hf=P80?Cdm0`17AdL2055AD@<0I6AT0P1XJ6P306a/K0<0L71`0P1gMgL507UiN@P0P8200`1o
Ogl208:2PP<0P8200`24Q8@208V9R@<0S8b<0P2=SHd308^;R`<0SHf=0P2CTi<309:BTP80T92@0`2H
V9P3096AT@80VIVI0`2GUiL209RHV0<0VIVI0`2JVYX209jNWP<0WinO0P2RXZ830:JVYP80ZJVY0`2U
YJD30:f][@80Z:RX0`2[Zj/20;>c/`P0[Zj^0`2a/K420;2`/0<0/K6a0`2`/;020;:b/P<0ZZZZ0P2X
Z:P30:^[Z`<0[Jf]1`2XZ:P30:BTY0<0Xj>S0P2OWil309fMW@80Vi^K0`2GUiL309RHV080UIFE0`2B
TY82092@T0<0Rh^;0P2<S8`308^;R`D0RHV91@2;Rh/308J6QP<0Q8B40P1nOWh30861P@80OWin0`1m
OGd30861P@80O7al0`23Ph<20861P@<0Q8B47038h=P001/0b>3H0`2IVIT209^KV`<0U9BD0P1aLG43
04e=C@<09bLW0P0[:b/802@T90D09bLW0`0X:2P202HV9P<0:b/[0P16ATH308F5Q@<0UIFE0P1lO7`3
06EUI@80LW9b0`1cLg<30820P080ZJVY0`3:b/X20<K6aP<0`L710`34a<@20<W9b@<0e]KF0P3GemL3
0;jn_P<0MWIf0P0a<C4302DU9@807alO0`0T92@3030`<080=CDe0`12@T82034a<@<0=CDe0`0j>SX2
0492@P<0Bd];0P1EEED305mOG`80IFEU0`1[Jf/3075aL@80MgMg0`1iNGT207YjNP<0O7al0`1nOWh2
07moO`<0P8200P22PX8608B4Q080QHF50`28R8P208^;R`<0S8b<0`2=SHd208j>SP<0T92@0P2CTi<3
09JFUPD0V9RH202IVIT309ZJVP80Vi^K0`2LW9`20:6QX@<0YJFU0P2WYjL30:RXZ0<0ZJVY0P2ZZZX3
0:j^[P80/[:b0`2`/;030:f][@80[jn_1@2b/[830;6a/@<0/;2`0P2^[Zh30:^[Z`80Z:RX0`2ZZZX3
0:b/[080ZZZZ0`2XZ:P20:NWY`<0YJFU0`2SXj<20:2PX0<0WYjN0P2KVi/309RHV0<0UIFE0P2CTi<3
092@T080SHf=0`2:RXX208V9R@H0R8R80P29RHT308^;R`80SHf=0`28R8P308>3P`D0PH610P1oOgl3
07emO@D0O7al0`20P80208>3P`<0Q8B4=038h=P30:BTY080VYZJ0`2DU9@2071`L0<0BDU90`0];Bd2
02HV9P<08B4Q0P0R8R8302DU9@<0:2PX0P0T92@302XZ:P80:b/[0`0Z:RX204e=C@<0P8200`2GUiL2
07UiN@<0I6AT0P1`L70307]kN`<0OGem0P2][Jd30<c<c080_;bl0`34a<@30<S8b080c<c<0`3@d=02
0=GEe@<0b<S80`1eMGD203De=@<0:BTY0P0R8R8302HV9P<09bLW0P0o?cl304=3@`80<C4a0`0_;bl3
03Hf=P80?Cdm0`17AdL2055AD@<0I6AT0P1XJ6P306a/K0<0L71`0P1gMgL507UiN@P0P8200`1oOgl2
08:2PP<0P8200`24Q8@208V9R@<0S8b<0P2=SHd308^;R`<0SHf=0P2CTi<309:BTP80T92@0`2HV9P3
096AT@80VIVI0`2GUiL209RHV0<0VIVI0`2JVYX209jNWP<0WinO0P2RXZ830:JVYP80ZJVY0`2UYJD3
0:f][@80Z:RX0`2[Zj/20;>c/`P0[Zj^0`2a/K420;2`/0<0/K6a0`2`/;020;:b/P<0ZZZZ0P2XZ:P3
0:^[Z`<0[Jf]1`2XZ:P30:BTY0<0Xj>S0P2OWil309fMW@80Vi^K0`2GUiL309RHV080UIFE0`2BTY82
092@T0<0Rh^;0P2<S8`308^;R`D0RHV91@2;Rh/308J6QP<0Q8B40P1nOWh30861P@80OWin0`1mOGd3
0861P@80O7al0`23Ph<20861P@<0Q8B47038h=P001/0b>3H0`2IVIT209^KV`<0U9BD0P1aLG4304e=
C@<09bLW0P0[:b/802@T90D09bLW0`0X:2P202HV9P<0:b/[0P16ATH308F5Q@<0UIFE0P1lO7`306EU
I@80LW9b0`1cLg<30820P080ZJVY0`3:b/X20<K6aP<0`L710`34a<@20<W9b@<0e]KF0P3GemL30;jn
_P<0MWIf0P0a<C4302DU9@807alO0`0T92@3030`<080=CDe0`12@T82034a<@<0=CDe0`0j>SX20492
@P<0Bd];0P1EEED305mOG`80IFEU0`1[Jf/3075aL@80MgMg0`1iNGT207YjNP<0O7al0`1nOWh207mo
O`<0P8200P22PX8608B4Q080QHF50`28R8P208^;R`<0S8b<0`2=SHd208j>SP<0T92@0P2CTi<309JF
UPD0V9RH202IVIT309ZJVP80Vi^K0`2LW9`20:6QX@<0YJFU0P2WYjL30:RXZ0<0ZJVY0P2ZZZX30:j^
[P80/[:b0`2`/;030:f][@80[jn_1@2b/[830;6a/@<0/;2`0P2^[Zh30:^[Z`80Z:RX0`2ZZZX30:b/
[080ZZZZ0`2XZ:P20:NWY`<0YJFU0`2SXj<20:2PX0<0WYjN0P2KVi/309RHV0<0UIFE0P2CTi<3092@
T080SHf=0`2:RXX208V9R@H0R8R80P29RHT308^;R`80SHf=0`28R8P308>3P`D0PH610P1oOgl307em
O@D0O7al0`20P80208>3P`<0Q8B4=038h=P30:BTY080VYZJ0`2DU9@2071`L0<0BDU90`0];Bd202HV
9P<08B4Q0P0R8R8302DU9@<0:2PX0P0T92@302XZ:P80:b/[0`0Z:RX204e=C@<0P8200`2GUiL207Ui
N@<0I6AT0P1`L70307]kN`<0OGem0P2][Jd30<c<c080_;bl0`34a<@30<S8b080c<c<0`3@d=020=GE
e@<0b<S80`1eMGD203De=@<0:BTY0P0R8R8302HV9P<09bLW0P0o?cl304=3@`80<C4a0`0_;bl303Hf
=P80?Cdm0`17AdL2055AD@<0I6AT0P1XJ6P306a/K0<0L71`0P1gMgL507UiN@P0P8200`1oOgl208:2
PP<0P8200`24Q8@208V9R@<0S8b<0P2=SHd308^;R`<0SHf=0P2CTi<309:BTP80T92@0`2HV9P3096A
T@80VIVI0`2GUiL209RHV0<0VIVI0`2JVYX209jNWP<0WinO0P2RXZ830:JVYP80ZJVY0`2UYJD30:f]
[@80Z:RX0`2[Zj/20;>c/`P0[Zj^0`2a/K420;2`/0<0/K6a0`2`/;020;:b/P<0ZZZZ0P2XZ:P30:^[
Z`<0[Jf]1`2XZ:P30:BTY0<0Xj>S0P2OWil309fMW@80Vi^K0`2GUiL309RHV080UIFE0`2BTY82092@
T0<0Rh^;0P2<S8`308^;R`D0RHV91@2;Rh/308J6QP<0Q8B40P1nOWh30861P@80OWin0`1mOGd30861
P@80O7al0`23Ph<20861P@<0Q8B47038h=P001/0b>3H0`2`/;0209FEU@<0JVYZ0P16ATH602TY:@80
;2`/0`0V9RH5024Q8@<08b<S0P0T92@302DU9@808b<S0`0];Bd2030`<0<0MWIf0`27QhL209FEU@<0
IVIV0P1eMGD3075aL@<0P8200P25QHD30<[:bP80`l?30`2k^k/30<30`080b<S80`3>c/h20=7Ad@<0
c<c<0`2n_[h204=3@`<0;Bd]0P0O7al302DU9@<0:RXZ0P0];Bd304Y:BP80:2PX0`0a<C4303Xj>P80
@D510`19BDT205EEE@<0H61P0P1VIVH306][J`<0Lg=c0P1jNWX307]kN`80NWYj1P1kNg/207emO@<0
P8200P23Ph<308J6QP<0Q8B40P23Ph<308N7Q`80Rh^;1P2<S8`208j>SP<0T92@0P2CTi<309JFUP<0
V9RH1`2IVIT609RHV080VYZJ0`2MWId20::RXP<0YJFU1@2VYZH30:NWY`80ZJVY0`2][Jd20;6a/@<0
/;2`0`2^[Zh20;2`/0<0/[:b0P2c/k<30;:b/P<0/;2`0P2_[jl30:^[Z`80ZJVY0`2ZZZX30:b/[080
Zj^[1@2XZ:P30:NWY`<0Y:BT0P2PX:0309nOW`80WIfM0`2IVIT509BDU0<0Ti>C0P2@T90308b<S0D0
RXZ:0`2;Rh/208f=S@<0S8b<0P2;Rh/308R8R0<0QHF50P23Ph<30861P@80OWin1P1lO7`207emO@<0
P8200P23Ph<308B4Q3@0b>3H0`2/[:`209NGU`<0K6a/0P14A4@302`/;0<0:2PX0P0[:b/302HV9P80
8B4Q0`0V9RH3028R8P808b<S0`0P820502PX:080<c<c0`1aLG4308n?S`80SXj>0`1YJFT2071`L0<0
M7Ad0`1gMgL208n?S`<0alO70P2l_;`30;fm_@<0a<C40P37alL30<_;b`80clo?0`3AdM430;>c/`80
A4A40`0Z:RX202<S8`<092@T0`0X:2P202l_;`<0?Shn0P0_;bl303@d=0<0?3`l0P13@d<304m?C`80
DE5A0`1SHf<206QXJ0<0K6a/0`1`L70507YjNPP0Ng]k0P1nOWh30861P@80Ph>30`28R8P508:2PP<0
QXJ60P2<S8`308Z:RP<0SHf=0P2?Shl3092@T080TY:B0`2HV9P309FEU@80VYZJ0`2IVIT209^KV`<0
UYJF0`2IVIT509fMW@80X:2P202UYJD30:f][@80YjNW0`2^[Zh20;6a/@<0/;2`0`2/[:`20;6a/@<0
]KFe0P2a/K430;:b/P<0[jn_0P2][Jd30:^[Z`80ZJVY0`2[Zj/30:ZZZP80[:b/0`2ZZZX50:NWY`<0
YJFU1@2QXJ4209fMW@<0VYZJ0`2BTY8509>CT`80Shn?0`2<S8`208R8R0H0RXZ:0P2@T90308R8R080
Shn?0`28R8P308F5Q@80Ph>30`20P80208:2PP<0Ng]k0`1mOGd207UiN@D0PX:20`23Ph<L0<SPf000
6`38h=P30;2`/080UIFE0`1ZJVX204I6APH0:BTY0P0/;2`302HV9PD08B4Q0`0S8b<202@T90<09BDU
0P0S8b<302d];@80<30`0`1fMWH308N7Q`80UIFE0`1VIVH207EeM@<0LG5a0`20P80208F5Q@<0b/[:
0P33`l<30;^k^`<0`<300P38b<P30<k>cP80dM7A0`3<c<`30;jn_P80@d=30`0];Bd201lO7`<09BDU
0`0Z:RX202d];@<0BTY:0P0X:2P3034a<@<0>SXj0P11@D4304U9B@80EEEE0`1PH60206IVIP<0Jf][
0`1cLg<207YjNP<0Ng]k0P1jNWX607]kN`80OGem0`20P80208>3P`<0QXJ60`24Q8@208>3P`<0QhN7
0P2;Rh/608b<S080SXj>0`2@T90209>CT`<0UYJF0`2HV9P709VIV@H0V9RH0P2JVYX309fMW@80XZ:R
0`2UYJD50:JVYP<0YjNW0P2YZJT30:f][@80/K6a0`2`/;030:j^[P80/;2`0`2b/[820;>c/`<0/[:b
0`2`/;020:n_[`<0Zj^[0P2YZJT30:ZZZP<0[:b/0P2[Zj/50:RXZ0<0YjNW0`2TY:@20:2PX0<0WinO
0P2MWId309VIV@D0U9BD0`2CTi<2092@T0<0S8b<1@2:RXX308^;R`80SHf=0`2<S8`208^;R`<0R8R8
0`25QHD208>3P`<0PH610P1nOWh607alO080OGem0`20P80208>3P`<0Q8B4=038h=P30:b/[080UiNG
0`1/K6`204A4A0<0;2`/0`0X:2P202/[:`<09RHV0P0Q8B4302HV9P<08R8R0P0S8b<3020P80D0:2PX
0P0c<c<3075aL@<0Shn?0P2>SXh306UYJ@80L71`0`1dM7@307MgM`80Shn?0`37alL20;bl_0<0_Kfm
0`34a<@20<O7a`<0bl_;0P3?cll30=7Ad@<0/k>c0P14A4@302XZ:P808b<S0`0T92@302PX:080;bl_
0`0n?Sh202l_;`<0=3@d0`0l?3`204=3@`<0Cdm?0P1ADE4306=SH`80J6QX0`1/K6`3071`L0D0NWYj
201kNg/207inOP<0PH610P23Ph<308R8R0D0PX:20`26QXH208b<S0<0RXZ:0`2=SHd208n?S`<0T92@
0P2BTY8309RHV0<0UIFE0P2JVYX309VIV@80Vi^K0`2FUYH309VIV@D0WIfM0P2PX:080:FUY@<0[Jf]
0P2WYjL30:j^[P80/K6a0`2`/;030:b/[080/K6a0`2e]KD20;6a/@<0/[:b0`2_[jl20:f][@<0Zj^[
0P2YZJT30:^[Z`<0ZZZZ0P2/[:`30:ZZZPD0YjNW0`2UYJD50:6QX@80WIfM0`2JVYX309:BTPD0Ti>C
0P2?Shl308b<S080R8R81P2:RXX2092@T0<0R8R80P2?Shl308R8R0<0QHF50P23Ph<30820P080PX:2
0`1kNg/307emO@80NGUi1@22PX8308>3Pa`0b>3H000K0<SPf0<0VYZJ0P1gMgL304M7A`80;bl_0`0Q
8B4302HV9P80:BTY0`0V9RH2024Q8@<08R8R1@0S8b<302@T90808B4Q0`0U9BD202XZ:P<0F5QH0`1l
O7`209jNWP<0NGUi0P1aLG43071`L0<0NWYj0P1eMGD30;Ng]`80bLW90`2g]kL30;jn_P80a<C40`38
b<P20<W9b@<0c<c<0`31`L4209nOW`<0>3Ph0P0N7Qh302TY:@<0;2`/0P0`<30303lo?`80;Bd]0`0b
<S8303Lg=`80@4100`1:BTX205MGE`<0Hf=S0P1YJFT306e]K@<0MGEe0P1jNWX307UiN@80MgMg0`1i
NGT307alO080Ogmo0`22PX8208F5Q@<0QhN70`25QHD208B4Q0<0QXJ60P29RHT308b<S0<0Shn?1@2@
T902096AT@<0Ti>C0`2DU9@209JFUP<0V9RH0P2IVIT609ZJVP80W9bL0`2OWil20::RXP<0YJFU0P2W
YjL30:RXZ0<0ZZZZ0P2][Jd30;2`/080/k>c0`2a/K430:n_[`80/;2`0`2a/K420;>c/`<0];Bd0`2b
/[820:n_[`<0[:b/0P2[Zj/30:f][@<0[jn_0P2][Jd30:VYZ@80Z:RX0`2VYZH30:BTY080XJ6Q0`2P
X:0209jNWP<0VYZJ0`2EUID209:BTPD0Shn?0`2>SXh208b<S0<0Rh^;0`2>SXh2092@T0<0SXj>0P2:
RXX308V9R@<0QhN70P24Q8@30861P@80OWin0`1lO7`307emO@80Ogmo0`22PX8208>3P`<0Q8B4=038
h=P3092@T080NWYj0`15ADD202XZ:P<08R8R0`0[:b/202l_;`<0:BTY0P0R8R83024Q8@<08R8R0P0Y
:BT302HV9P808R8R0`0T92@202XZ:P<0De=C0`25QHD209nOW`<0N7Qh0P1cLg<307AdM0<0MgMg0P1k
Ng/30;Jf]P80aLG50`2h^;P30;fm_@80a<C40`35aLD20<W9b@<0d=3@0`3<c<`209NGU`<0<S8b200Y
:BT203De=@<0@d=30P0/;2`3030`<0<0?3`l0P0m?Cd304];B`80EEEE0`1OGel206EUI@<0KVi^0`1d
M7@207moO`<0NGUi0P1fMWH307QhN0<0NGUi0P1oOgl308>3P`80PX:20`2<S8`508B4Q0<0QHF51@29
RHT508n?S`<0TI6A0P2>SXh309FEU@<0UYJF0P2HV9P309VIV@80W9bL0`2BTY8509^KV`<0VYZJ0P2R
XZ830:NWY`80Xj>S0`2WYjL30:VYZ@80ZZZZ0`2b/[820:n_[`<0/k>c0`2_[jl20;6a/@<0[jn_0P2a
/K430;Rh^0<0/K6a1@2^[Zh20:VYZ@<0Zj^[0`2`/;020:j^[P<0YJFU0P2VYZH30:FUY@<0Y:BT0P2N
WYh309fMW@80Vi^K0`2OWil509:BTP<0S8b<0P2>SXh308n?S`80RHV90`2;Rh/308b<S080TI6A0`2;
Rh/208Z:RPH0RHV90P24Q8@30861P@80O7al0`1fMWH308B4Q080Ogmo0`20P80208>3P`<0R8R87038
h=P001/0b>3H0`2JVYX207MgM`<0AdM70P0_;bl3024Q8@<09RHV0P0Y:BT302HV9P808B4Q0`0R8R85
02<S8`<092@T0P0Q8B4302DU9@80:RXZ0`1HF5P307alO080WYjN0`1iNGT2075aL@<0L71`0`1jNWX2
07EeM@<0]kNg0P39bLT30;Ng]`<0_[jn0P34a<@30<S8b080bLW90`3<c<`30<71`@80WinO0`0h>3P2
01hN7P<0:BTY0`0/;2`2030`<0<0?clo0P0];Bd3038b<P<0=cLg0P10@40304Y:BP80EeMG0`1SHf<2
06UYJ@<0KFe]0`1eMGD207YjNP<0NGUi0P1gMgL307UiN@<0O7al0P1oOgl308:2PP80QHF50`27QhL3
08F5Q@80Q8B40`26QXH208V9R@<0S8b<0`2?Shl5092@T080TI6A0`2CTi<309BDU080UYJF0`2HV9P2
09VIV@H0VYZJ0P2LW9`309nOW`80XZ:R0`2UYJD20:NWY`<0Z:RX0`2ZZZX20:f][@<0/;2`0P2c/k<3
0;6a/@<0[jn_0P2`/;030;6a/@80/k>c0`2d];@30;:b/P80[jn_0`2/[:`20:^[Z`<0[Jf]0`2_[jl2
0:f][@<0ZJVY0P2XZ:P30:JVYP<0Y:BT0P2QXJ430:2PX080WYjN0`2JVYX309FEU@80TY:B1@2?Shl3
08j>SP80S8b<0`2;Rh/308j>SP80T92@0`2>SXh208Z:RP<0RHV90`27QhL208B4Q0<0PH610P1nOWh3
07alO0<0OGem0P1oOgl308:2PP80Ph>30`24Q8@d0<SPf0<0T92@0P1jNWX304E5A@80:RXZ0`0R8R83
02/[:`80;bl_0`0Y:BT2028R8P<08B4Q0`0R8R8202TY:@<09RHV0P0R8R8302@T9080:RXZ0`1CDe<3
08F5Q@80WinO0`1hN7P207=cL`<0M7Ad0`1gMgL207]kN`<0][Jf0P35aLD30;Rh^0<0_Kfm0P34a<@3
0<G5a@80bLW90`3@d=030<c<c080UiNG0`0b<S8802TY:@80=CDe0`13@d<202`/;0<0<30`0`0l?3`2
03dm?@<0Bd];0P1EEED305mOG`80IFEU0`1^KVh307AdM080Ogmo0`1iNGT207IfMP<0N7Qh0`1iNGT2
07moO`<0Ph>30P22PX8308b<S0D0Q8B40`25QHD508V9R@D0Shn?0`2ATI4208j>SP<0UIFE0`2FUYH2
09RHV0<0VIVI0P2LW9`309:BTPD0Vi^K0`2JVYX20::RXP<0YjNW0P2SXj<30:NWY`<0ZJVY0P2ZZZX3
0;:b/P80[jn_0`2c/k<30:n_[`80/K6a0`2_[jl20;6a/@<0^;Rh0`2a/K450:j^[P80ZJVY0`2[Zj/3
0;2`/080[Zj^0`2UYJD20:JVYP<0YJFU0`2TY:@209jNWP<0WIfM0P2KVi/309nOW`D0TY:B0`2<S8`2
08j>SP<0Shn?0P29RHT308^;R`<0S8b<0P2ATI4308^;R`80RXZ:1P29RHT208B4Q0<0PH610P1lO7`3
07IfMP<0Q8B40P1oOgl30820P080Ph>30`28R8PL0<SPf0006`38h=P309ZJVP80MgMg0`17AdL202l_
;`<08B4Q0`0V9RH202TY:@<09RHV0P0Q8B43028R8PD08b<S0`0T92@2024Q8@<09BDU0P0Z:RX305QH
F0<0O7al0P2NWYh307UiN@80LG5a0`1`L70307YjNP80MGEe0`2g]kL20<W9b@<0]kNg0`2n_[h20<C4
a0<0b<S80P39bLT30<c<c0<0`L710P2OWil303Ph>0807QhN0`0Y:BT302`/;080<30`0`0o?cl202d]
;@<0<S8b0`0g=cL20410@0<0BTY:0P1GEeL306=SH`80JFUY0`1]KFd307EeM@80NWYj0`1iNGT207Mg
M`<0NGUi0`1lO7`207moO`<0PX:20P25QHD308N7Q`<0QHF50P24Q8@308J6QP80RHV90`2<S8`308n?
S`D0T92@0P2ATI4309>CT`<0U9BD0P2FUYH309RHV080VIVI1P2JVYX209bLW0<0WinO0P2RXZ830:FU
Y@80YjNW0`2XZ:P30:ZZZP80[Jf]0`2`/;020;>c/`<0/K6a0`2_[jl20;2`/0<0/K6a0P2c/k<30;Bd
]0<0/[:b0P2_[jl30:b/[080Zj^[0`2][Jd30:n_[`80[Jf]0`2YZJT20:RXZ0<0YZJV0`2TY:@20:6Q
X@<0X:2P0P2NWYh309ZJVP<0UIFE0P2BTY8508n?S`<0SXj>0P2<S8`308^;R`<0SXj>0P2@T90308j>
SP80RXZ:0`29RHT308N7Q`80Q8B40`21PH4207inOP<0O7al0`1mOGd207moO`<0PX:20P23Ph<308B4
Q3@0b>3H0`2@T90207YjNP<0ADE50P0Z:RX3028R8P<0:b/[0P0_;bl302TY:@808R8R0`0Q8B43028R
8P80:BTY0`0V9RH2028R8P<092@T0P0Z:RX305=CD`<0QHF50P2OWil307QhN080Lg=c0`1dM7@307Mg
M`80Ng]k0`2f][H20<G5a@<0^;Rh0`2m_Kd20<C4a0<0aLG50P39bLT30=3@d0<0c<c<0P2GUiL3038b
<PP0:BTY0P0e=CD304=3@`80;2`/0`0`<30303`l?080?Cdm0`1;Bd/205EEE@<0GemO0P1UIFD306i^
KP<0M7Ad0P1oOgl307UiN@80MWIf0`1hN7P307UiN@80Ogmo0`23Ph<208:2PP<0S8b<1@24Q8@308F5
Q@D0RHV91@2?Shl3096AT@80SXj>0`2EUID309JFUP80V9RH0`2IVIT209bLW0<0TY:B1@2KVi/309ZJ
VP80XZ:R0`2WYjL20:>SX`<0YjNW0`2YZJT20:ZZZP<0/[:b0P2_[jl30;>c/`<0[jn_0P2a/K430:n_
[`80/K6a0`2h^;P30;6a/@D0[Zj^0P2YZJT30:^[Z`<0/;2`0P2^[Zh30:FUY@80YZJV0`2UYJD30:BT
Y080WYjN0`2MWId209^KV`<0WinO1@2BTY8308b<S080SXj>0`2?Shl208V9R@<0Rh^;0`2<S8`2096A
T@<0Rh^;0P2:RXX608V9R@80Q8B40`21PH4207alO0<0MWIf0`24Q8@207moO`<0P8200P23Ph<308R8
R1`0b>3H000K0<SPf0<0MWIf0P1EEED302/[:`D08R8R0`0T92@202HV9P<09BDU200S8b<502@T9080
820P0`0O7al202PX:0<0>CTi0`1_Kfl209bLW0<0SHf=0P1`L70306m_K`<0MGEe0P1/K6`309jNWP80
bl_;0`2g]kL30;jn_PL0`<300`3?cll30=7Ad@80];Bd0`1[Jf/203De=@H0:b/[0P0d=3@3038b<PD0
<c<c0`0e=CD203lo?`<0Bd];0P1HF5P306ATI080Jf][0`1`L70307IfMP80NGUi0`1gMgL207EeM@<0
NGUi0`1nOWh20861P@<0Q8B40P26QXH308N7Q`<0QXJ61@25QHD208J6QP<0S8b<1@2ATI48092@T0<0
TY:B0P2DU9@309NGU`80VYZJ0`2LW9`309fMW@80WinO0`2RXZ820:BTY0<0YZJV0P2XZ:P30:ZZZP<0
[Zj^0P2a/K430;>c/`80];Bd0`2b/[880;6a/@80];Bd0`2f][H30;>c/`80[jn_1@2][Jd30;2`/0<0
/[:b0P2^[Zh30:VYZ@80Z:RX0`2WYjL30:BTY080XZ:R0`2PX:0209jNWP<0Vi^K0`2GUiL2096AT@<0
S8b<0P2>SXh3092@T080SXj>0`2<S8`3092@T080Ti>C0`2@T90208^;R`<0RHV90`27QhL208F5Q@<0
PX:20P1nOWh307alO0<0OWin0P21PH4308>3P`D0Q8B4=038h=P307MgM`80F5QH0`0];Bd202DU9@<0
8b<S0`0P820202<S8`<08R8R0P0U9BD302@T90<08b<S1@0R8R8201lO7`<08B4Q0P0U9BD303Ti>@<0
LW9b0P2JVYX308^;R`80Lg=c0`1bLW83071`L080M7Ad0`2KVi/20<K6aP<0^KVi0`2k^k/20;no_`<0
a<C40P33`l<30<G5a@<0c<c<0P32`/8306YZJP80<S8b0`0`<30302XZ:P80;Bd]0`0j>SX202d];@<0
=cLg0`0d=3@203`l?0<0CDe=0P1IFET306EUI@80K6a/0`1aLG4307EeM@80NWYj0`1hN7P207IfMP<0
N7Qh0`1nOWh208>3P`<0QXJ60P24Q8@308N7Q`<0PX:21@25QHD208N7Q`<0S8b<0`2@T90209BDU0<0
TY:B0P2>SXh309:BTP<0TI6A0P2DU9@309FEU@80W9bL0`2MWId309^KV`L0XZ:R0`2XZ:P20:JVYP<0
[:b/0`2_[jl20;2`/0<0/K6a0P2`/;030;Rh^0<0[Zj^0P2b/[830;Bd]080]KFe0`2g]kL30;2`/0L0
[jn_0`2[Zj/30;:b/P80[Jf]0`2YZJT20:RXZ0<0YZJV0`2WYjL50::RXP80X:2P0`2JVYX309JFUP80
UIFE0`2;Rh/208n?S`<0TI6A0P2<S8`308f=S@<0U9BD0P2CTi<308j>SP80RXZ:0`2;Rh/308F5Q@80
QXJ60`21PH4207moO`<0OWin0`1mOGd208>3P`<0P8200P26QXH308:2PQ`0b>3H000K0<SPf0<0MWIf
0P1EEED302/[:`D08R8R0`0T92@202HV9P<09BDU200S8b<502@T9080820P0`0O7al202PX:0<0>CTi
0`1_Kfl209bLW0<0SHf=0P1`L70306m_K`<0MGEe0P1/K6`309jNWP80bl_;0`2g]kL30;jn_PL0`<30
0`3?cll30=7Ad@80];Bd0`1[Jf/203De=@H0:b/[0P0d=3@3038b<PD0<c<c0`0e=CD203lo?`<0Bd];
0P1HF5P306ATI080Jf][0`1`L70307IfMP80NGUi0`1gMgL207EeM@<0NGUi0`1nOWh20861P@<0Q8B4
0P26QXH308N7Q`<0QXJ61@25QHD208J6QP<0S8b<1@2ATI48092@T0<0TY:B0P2DU9@309NGU`80VYZJ
0`2LW9`309fMW@80WinO0`2RXZ820:BTY0<0YZJV0P2XZ:P30:ZZZP<0[Zj^0P2a/K430;>c/`80];Bd
0`2b/[880;6a/@80];Bd0`2f][H30;>c/`80[jn_1@2][Jd30;2`/0<0/[:b0P2^[Zh30:VYZ@80Z:RX
0`2WYjL30:BTY080XZ:R0`2PX:0209jNWP<0Vi^K0`2GUiL2096AT@<0S8b<0P2>SXh3092@T080SXj>
0`2<S8`3092@T080Ti>C0`2@T90208^;R`<0RHV90`27QhL208F5Q@<0PX:20P1nOWh307alO0<0OWin
0P21PH4308>3P`D0Q8B4=038h=P307MgM`80F5QH0`0];Bd202DU9@<08b<S0`0P820202<S8`<08R8R
0P0U9BD302@T90<08b<S1@0R8R8201lO7`<08B4Q0P0U9BD303Ti>@<0LW9b0P2JVYX308^;R`80Lg=c
0`1bLW83071`L080M7Ad0`2KVi/20<K6aP<0^KVi0`2k^k/20;no_`<0a<C40P33`l<30<G5a@<0c<c<
0P32`/8306YZJP80<S8b0`0`<30302XZ:P80;Bd]0`0j>SX202d];@<0=cLg0`0d=3@203`l?0<0CDe=
0P1IFET306EUI@80K6a/0`1aLG4307EeM@80NWYj0`1hN7P207IfMP<0N7Qh0`1nOWh208>3P`<0QXJ6
0P24Q8@308N7Q`<0PX:21@25QHD208N7Q`<0S8b<0`2@T90209BDU0<0TY:B0P2>SXh309:BTP<0TI6A
0P2DU9@309FEU@80W9bL0`2MWId309^KV`L0XZ:R0`2XZ:P20:JVYP<0[:b/0`2_[jl20;2`/0<0/K6a
0P2`/;030;Rh^0<0[Zj^0P2b/[830;Bd]080]KFe0`2g]kL30;2`/0L0[jn_0`2[Zj/30;:b/P80[Jf]
0`2YZJT20:RXZ0<0YZJV0`2WYjL50::RXP80X:2P0`2JVYX309JFUP80UIFE0`2;Rh/208n?S`<0TI6A
0P2<S8`308f=S@<0U9BD0P2CTi<308j>SP80RXZ:0`2;Rh/308F5Q@80QXJ60`21PH4207moO`<0OWin
0`1mOGd208>3P`<0P8200P26QXH308:2PQ`0b>3H000K0<SPf0<0MWIf0P1EEED302/[:`D08R8R0`0T
92@202HV9P<09BDU200S8b<502@T9080820P0`0O7al202PX:0<0>CTi0`1_Kfl209bLW0<0SHf=0P1`
L70306m_K`<0MGEe0P1/K6`309jNWP80bl_;0`2g]kL30;jn_PL0`<300`3?cll30=7Ad@80];Bd0`1[
Jf/203De=@H0:b/[0P0d=3@3038b<PD0<c<c0`0e=CD203lo?`<0Bd];0P1HF5P306ATI080Jf][0`1`
L70307IfMP80NGUi0`1gMgL207EeM@<0NGUi0`1nOWh20861P@<0Q8B40P26QXH308N7Q`<0QXJ61@25
QHD208J6QP<0S8b<1@2ATI48092@T0<0TY:B0P2DU9@309NGU`80VYZJ0`2LW9`309fMW@80WinO0`2R
XZ820:BTY0<0YZJV0P2XZ:P30:ZZZP<0[Zj^0P2a/K430;>c/`80];Bd0`2b/[880;6a/@80];Bd0`2f
][H30;>c/`80[jn_1@2][Jd30;2`/0<0/[:b0P2^[Zh30:VYZ@80Z:RX0`2WYjL30:BTY080XZ:R0`2P
X:0209jNWP<0Vi^K0`2GUiL2096AT@<0S8b<0P2>SXh3092@T080SXj>0`2<S8`3092@T080Ti>C0`2@
T90208^;R`<0RHV90`27QhL208F5Q@<0PX:20P1nOWh307alO0<0OWin0P21PH4308>3P`D0Q8B4=038
h=P307MgM`80F5QH0`0];Bd202DU9@<08b<S0`0P820202<S8`<08R8R0P0U9BD302@T90<08b<S1@0R
8R8201lO7`<08B4Q0P0U9BD303Ti>@<0LW9b0P2JVYX308^;R`80Lg=c0`1bLW83071`L080M7Ad0`2K
Vi/20<K6aP<0^KVi0`2k^k/20;no_`<0a<C40P33`l<30<G5a@<0c<c<0P32`/8306YZJP80<S8b0`0`
<30302XZ:P80;Bd]0`0j>SX202d];@<0=cLg0`0d=3@203`l?0<0CDe=0P1IFET306EUI@80K6a/0`1a
LG4307EeM@80NWYj0`1hN7P207IfMP<0N7Qh0`1nOWh208>3P`<0QXJ60P24Q8@308N7Q`<0PX:21@25
QHD208N7Q`<0S8b<0`2@T90209BDU0<0TY:B0P2>SXh309:BTP<0TI6A0P2DU9@309FEU@80W9bL0`2M
WId309^KV`L0XZ:R0`2XZ:P20:JVYP<0[:b/0`2_[jl20;2`/0<0/K6a0P2`/;030;Rh^0<0[Zj^0P2b
/[830;Bd]080]KFe0`2g]kL30;2`/0L0[jn_0`2[Zj/30;:b/P80[Jf]0`2YZJT20:RXZ0<0YZJV0`2W
YjL50::RXP80X:2P0`2JVYX309JFUP80UIFE0`2;Rh/208n?S`<0TI6A0P2<S8`308f=S@<0U9BD0P2C
Ti<308j>SP80RXZ:0`2;Rh/308F5Q@80QXJ60`21PH4207moO`<0OWin0`1mOGd208>3P`<0P8200P26
QXH308:2PQ`0b>3H000K0<SPf0<0E5AD0P13@d<302PX:0D092@T0`0U9BD202PX:0<09RHV0P0T92@3
02HV9PD09bLW0`0V9RH202<S8`D0820P0`0W9bL305]KF`80SHf=0`2ATI4208B4Q0<0Jf][0`1gMgL2
06e]K@<0R8R80P2j^[X30<?3``<0`L710P2l_;`30;jn_P80`<301P35aLD20<g=c@<0[Zj^0P0k>c/3
03De=@<0:b/[0P0];Bd302/[:`80<30`0`0a<C4303Hf=P80@D510`1>CTh205QHF0<0HV9R0P1[Jf/3
079bLP<0MGEe1@1gMgL207QhN0<0O7al0`20P8020861P@<0PX:20P23Ph<308B4Q0P0QHF50P26QXH3
08Z:RP<0SXj>0P2ATI4509>CT`<0TY:B0`2CTi<209FEU@<0UiNG0P2KVi/309jNWP<0XJ6Q0P2SXj<3
0:JVYP80YjNW0`2YZJT20:^[Z`<0[Jf]0`2_[jl20;6a/@<0/[:b1@2c/k<30;:b/P80]KFe1@2g]kL3
0;Fe]@<0/[:b0P2^[Zh30:b/[080Zj^[0`2][Jd30:n_[`80[:b/0`2YZJT50:ZZZP<0YZJV0P2QXJ43
09nOW`80WYjN0`2LW9`309VIV@80UIFE1@2ATI4309:BTP80T92@0`2?Shl309:BTP80Ti>C0`2@T902
08b<S0<0RXZ:0`28R8P208N7Q`<0Q8B40P20P80307alO0<0Ogmo0P22PX8308B4Q0D0QHF5=038h=P3
05UIF@80?Shn0`0W9bL202DU9@<092@T0`0W9bL202`/;0<09bLW0P0S8b<3028R8P<09RHV0P0b<S83
02DU9@D08R8R0P0O7al302TY:@<0Fe]K0P29RHT309BDU080MWIf1P1_Kfl207=cL`<0Q8B40P30`<03
0<O7a`<0^k^k0P2m_Kd30<K6aPD0_Kfm0`33`l<20<k>cP<0[:b/0P0j>SX302l_;`<0:b/[0P0];Bd3
03De=@80;Rh^0`0b<S8303Hf=P80@4100`1?Cdl205UIF@<0IFEU0P1/K6`3079bLP<0LG5a1@1eMGD5
07]kN`<0PX:20P23Ph<307inOP80PX:20`29RHT308F5Q@80R8R80`26QXH208B4Q0<0Rh^;0`2?Shl2
096AT@<0T92@0P2CTi<6092@T080UIFE0`2GUiL209RHV0<0WIfM0`2RXZ820:NWY`<0ZJVY0P2UYJD3
0:RXZ080Zj^[0`2/[:`30;2`/080/[:b0`2d];@20;Jf]P<0/k>c0`2`/;020:n_[`<0];Bd0P2g]kL3
0;>c/`<0[Jf]0P2_[jl30:j^[P80ZJVY0`2_[jl30;2`/080[jn_0`2[Zj/20:f][@<0ZJVY0`2RXZ82
0:>SX`<0WYjN1@2KVi/309NGU`80UYJF0`2ATI4208n?S`<0Ti>C0P2@T90308f=S@<0TY:B0P2DU9@3
08b<S080TI6A1P28R8P508J6QP80OWin0`1oOgl307alO080PX:20`24Q8@508F5QA`0b>3H000K0<SP
f0<0E5AD0P13@d<302PX:0D092@T0`0U9BD202PX:0<09RHV0P0T92@302HV9PD09bLW0`0V9RH202<S
8`D0820P0`0W9bL305]KF`80SHf=0`2ATI4208B4Q0<0Jf][0`1gMgL206e]K@<0R8R80P2j^[X30<?3
``<0`L710P2l_;`30;jn_P80`<301P35aLD20<g=c@<0[Zj^0P0k>c/303De=@<0:b/[0P0];Bd302/[
:`80<30`0`0a<C4303Hf=P80@D510`1>CTh205QHF0<0HV9R0P1[Jf/3079bLP<0MGEe1@1gMgL207Qh
N0<0O7al0`20P8020861P@<0PX:20P23Ph<308B4Q0P0QHF50P26QXH308Z:RP<0SXj>0P2ATI4509>C
T`<0TY:B0`2CTi<209FEU@<0UiNG0P2KVi/309jNWP<0XJ6Q0P2SXj<30:JVYP80YjNW0`2YZJT20:^[
Z`<0[Jf]0`2_[jl20;6a/@<0/[:b1@2c/k<30;:b/P80]KFe1@2g]kL30;Fe]@<0/[:b0P2^[Zh30:b/
[080Zj^[0`2][Jd30:n_[`80[:b/0`2YZJT50:ZZZP<0YZJV0P2QXJ4309nOW`80WYjN0`2LW9`309VI
V@80UIFE1@2ATI4309:BTP80T92@0`2?Shl309:BTP80Ti>C0`2@T90208b<S0<0RXZ:0`28R8P208N7
Q`<0Q8B40P20P80307alO0<0Ogmo0P22PX8308B4Q0D0QHF5=038h=P305UIF@80?Shn0`0W9bL202DU
9@<092@T0`0W9bL202`/;0<09bLW0P0S8b<3028R8P<09RHV0P0b<S8302DU9@D08R8R0P0O7al302TY
:@<0Fe]K0P29RHT309BDU080MWIf1P1_Kfl207=cL`<0Q8B40P30`<030<O7a`<0^k^k0P2m_Kd30<K6
aPD0_Kfm0`33`l<20<k>cP<0[:b/0P0j>SX302l_;`<0:b/[0P0];Bd303De=@80;Rh^0`0b<S8303Hf
=P80@4100`1?Cdl205UIF@<0IFEU0P1/K6`3079bLP<0LG5a1@1eMGD507]kN`<0PX:20P23Ph<307in
OP80PX:20`29RHT308F5Q@80R8R80`26QXH208B4Q0<0Rh^;0`2?Shl2096AT@<0T92@0P2CTi<6092@
T080UIFE0`2GUiL209RHV0<0WIfM0`2RXZ820:NWY`<0ZJVY0P2UYJD30:RXZ080Zj^[0`2/[:`30;2`
/080/[:b0`2d];@20;Jf]P<0/k>c0`2`/;020:n_[`<0];Bd0P2g]kL30;>c/`<0[Jf]0P2_[jl30:j^
[P80ZJVY0`2_[jl30;2`/080[jn_0`2[Zj/20:f][@<0ZJVY0`2RXZ820:>SX`<0WYjN1@2KVi/309NG
U`80UYJF0`2ATI4208n?S`<0Ti>C0P2@T90308f=S@<0TY:B0P2DU9@308b<S080TI6A1P28R8P508J6
QP80OWin0`1oOgl307alO080PX:20`24Q8@508F5QA`0b>3H000K0<SPf0<0?3`l0P0h>3P302h^;P80
9bLW0`0S8b<302HV9P80:RXZ0`0X:2P202LW9`<0:BTY1@0[:b/302TY:@809bLW0`0T92@201/K6`<0
7AdM0`17AdL207IfMP<0SHf=0P2IVIT306][J`<0NWYj0P1bLW8307IfMP80XZ:R0`3;bl/30<G5a@80
^KVi0`2m_Kd20<;2`P<0_[jn0`2i^KT20<_;b`<0c<c<0P2>SXh302h^;P<09RHV0P0X:2P302TY:@80
:b/[0`0`<30303Hf=P80@T920`1?Cdl205QHF0<0H61P0P1ZJVX307=cL`D0MGEe0`1hN7P207YjNP<0
OWin1@21PH4307moO`80P8200`21PH4308>3P`L0QXJ60`28R8P308^;R`80TI6A1@2FUYH309BDU0<0
UIFE0P2GUiL309VIV@80W9bL0`2PX:030:BTY080YjNW0`2ZZZX20:^[Z`<0[:b/0P2^[Zh30:n_[`<0
/;2`0P2a/K480;:b/P<0];Bd0P2i^KT30;fm_@80^KVi0`2d];@30;6a/@80[Zj^0`2[Zj/20:ZZZP<0
Zj^[0`2/[:`20:^[Z`<0ZZZZ0P2/[:`30:f][@<0YjNW0P2QXJ4309nOW`80WIfM0`2LW9`309^KV`80
VIVI0`2GUiL209FEU@<0Ti>C1@2BTY8509>CT`<0T92@0P2=SHd308^;R`<0RHV90P28R8P308J6QP80
PX:20`1nOWh307moO`80PX:20`24Q8@208F5Q@<0QXJ6=038h=P304=3@`80<C4a0`0c<c<202`/;0<0
:2PX0`0W9bL202TY:@<0:RXZ0P0Y:BT302DU9@<0:2PX0P0a<C4302DU9@80:RXZ0`0P820201dM7@<0
8R8R0`0j>SX207IfMP<0U9BD0P2CTi<3071`L0<0M7Ad0P1hN7P307EeM@80WinO0`3<c<`30;jn_P80
^KVi0`32`/820<30`0<0_;bl0`2k^k/50<[:bP80T92@0`0e=CD302<S8`809BDU0`0/;2`202/[:`<0
;Rh^0`0g=cL204E5A@<0CDe=0P1IFET3065QH@80IfMW0`1eMGD307=cL`80NGUi0`1eMGD207alO0<0
OGem0`1nOWh208>3P`<0PX:20P1jNWX308B4Q0<0PH610P26QXH308B4Q080QHF50`29RHT308R8R080
TY:B1@2FUYH309FEU@<0Ti>C0P2GUiL309ZJVPD0WYjN0`2UYJD20:NWY`<0Z:RX0P2ZZZX30:f][@80
[:b/0`2b/[830:f][@80/K6a0`2`/;020;6a/@H0];Bd0P2g]kL30;jn_P80^KVi0`2e]KD30:n_[`80
[Jf]0`2^[Zh20:RXZ0H0Zj^[0P2YZJT30:^[Z`80Z:RX0`2_[jl30:RXZ080XJ6Q0`2OWil20:2PX0<0
VYZJ0`2KVi/209bLW0<0V9RH1@2CTi<209JFUP<0T92@0`2EUID209:BTP<0S8b<0P2=SHd308b<S0<0
RXZ:0P24Q8@308J6QP80QHF50`1kNg/30820P080PH610`25QHD208B4Q0<0RHV97038h=P001/0b>3H
0`0l?3`203Ph>0<0;Rh^0P0W9bL302<S8`<09RHV0P0Z:RX302PX:0809bLW0`0Y:BT502/[:`<0:BTY
0P0W9bL302@T90806a/K0`0M7Ad304M7A`80MWIf0`2=SHd209VIV@<0Jf][0`1jNWX2079bLP<0MWIf
0P2RXZ830<_;b`<0aLG50P2i^KT30;fm_@80`/;20`2n_[h30;Vi^@80bl_;0`3<c<`208j>SP<0;Rh^
0`0V9RH202PX:0<0:BTY0P0[:b/3030`<0<0=SHf0P12@T8304m?C`80F5QH0`1PH60206YZJP<0Lg=c
1@1eMGD307QhN080NWYj0`1nOWh50861P@<0Ogmo0P20P8030861P@<0Ph>31`26QXH308R8R0<0Rh^;
0P2ATI4509JFUP<0U9BD0`2EUID209NGU`<0VIVI0P2LW9`30:2PX0<0Y:BT0P2WYjL30:ZZZP80Zj^[
0`2/[:`20:j^[P<0[jn_0`2`/;020;6a/@P0/[:b0`2d];@20;Vi^@<0_Kfm0P2i^KT30;Bd]0<0/K6a
0P2^[Zh30:^[Z`80ZZZZ0`2[Zj/30:b/[080Zj^[0`2ZZZX20:b/[0<0[Jf]0`2WYjL20:6QX@<0WinO
0P2MWId309bLW0<0Vi^K0P2IVIT309NGU`80UIFE0`2CTi<509:BTPD0Ti>C0`2@T90208f=S@<0Rh^;
0`29RHT208R8R0<0QXJ60P22PX8307inOP<0Ogmo0P22PX8308B4Q080QHF50`26QXHd0<SPf0<0@d=3
0P0a<C4303<c<`80;2`/0`0X:2P302LW9`80:BTY0`0Z:RX202TY:@<09BDU0`0X:2P2034a<@<09BDU
0P0Z:RX3020P80807AdM0`0R8R8303Xj>P80MWIf0`2DU9@209>CT`<0L71`0`1dM7@207QhN0<0MGEe
0P2OWil30<c<c0<0_[jn0P2i^KT30<;2`P80`<300`2l_;`30;^k^`D0b/[:0P2@T90303De=@<08b<S
0P0U9BD302`/;080:b/[0`0^;Rh303Lg=`80ADE50`1=CDd205UIF@<0HF5Q0P1WIfL307EeM@<0Lg=c
0P1iNGT307EeM@80O7al0`1mOGd307inOP80Ph>30`22PX8207YjNP<0Q8B40`21PH4208J6QP<0Q8B4
0P25QHD308V9R@<0R8R80P2BTY8509JFUP<0UIFE0`2CTi<209NGU`<0VYZJ1@2NWYh30:FUY@80YjNW
0`2XZ:P20:ZZZP<0[Jf]0P2/[:`30;:b/P<0[Jf]0P2a/K430;2`/080/K6a1P2d];@20;Ng]`<0_[jn
0P2i^KT30;Fe]@<0[jn_0P2][Jd30:j^[P80Z:RX1P2[Zj/20:VYZ@<0Zj^[0P2XZ:P30:n_[`<0Z:RX
0P2QXJ4309nOW`80X:2P0`2JVYX309^KV`80W9bL0`2HV9P509>CT`80UYJF0`2@T90309FEU@80TY:B
0`2<S8`208f=S@<0S8b<0`2:RXX208B4Q0<0QXJ60P25QHD307]kN`<0P8200P21PH4308F5Q@80Q8B4
0`29RHTL0<SPf0006`38h=P303`l?080>3Ph0`0^;Rh202LW9`<08b<S0`0V9RH202XZ:P<0:2PX0P0W
9bL302TY:@D0:b/[0`0Y:BT202LW9`<092@T0P0K6a/301dM7@<0AdM70P1fMWH308f=S@80VIVI0`1[
Jf/307YjNP80LW9b0`1fMWH20::RXP<0bl_;0`35aLD20;Vi^@<0_Kfm0P32`/830;jn_P<0^KVi0P3;
bl/30<c<c080SXj>0`0^;Rh302HV9P80:2PX0`0Y:BT202/[:`<0<30`0`0f=SH20492@P<0Cdm?0P1H
F5P3061PH080JVYZ0`1cLg<507EeM@<0N7Qh0P1jNWX307inOPD0PH610`1oOgl20820P0<0PH610`23
Ph<708J6QP<0R8R80`2;Rh/2096AT@D0UYJF0`2DU9@309FEU@80UiNG0`2IVIT209bLW0<0X:2P0`2T
Y:@20:NWY`<0ZZZZ0P2[Zj/30:b/[080[Zj^0`2_[jl30;2`/080/K6a202b/[830;Bd]080^KVi0`2m
_Kd20;Vi^@<0];Bd0`2a/K420:j^[P<0Zj^[0P2ZZZX30:^[Z`<0[:b/0P2[Zj/30:ZZZP80[:b/0`2]
[Jd30:NWY`80XJ6Q0`2OWil209fMW@<0W9bL0`2KVi/209VIV@<0UiNG0P2EUID309>CT`D0TY:B1@2C
Ti<3092@T080SHf=0`2;Rh/308V9R@80R8R80`26QXH208:2PP<0OWin0`1oOgl208:2PP<0Q8B40P25
QHD308J6QS@0b>3H0`13@d<2034a<@<0<c<c0P0/;2`302PX:0<09bLW0P0Y:BT302XZ:P80:BTY0`0U
9BD302PX:080<C4a0`0U9BD202XZ:P<0820P0P0M7Ad3028R8P<0>SXj0P1fMWH309BDU080Ti>C0`1`
L70307AdM080N7Qh0`1eMGD209nOW`<0c<c<0`2n_[h20;Vi^@<0`/;20P30`<030;bl_0<0^k^k1@3:
b/X2092@T0<0=CDe0`0S8b<202DU9@<0;2`/0P0[:b/302h^;P<0=cLg0P15ADD304e=C@80FEUI0`1Q
HF4206MWI`<0MGEe0`1cLg<207UiN@<0MGEe0P1lO7`307emO@<0OWin0P23Ph<308:2PP80NWYj0`24
Q8@30861P@80QXJ60`24Q8@208F5Q@<0RHV90`28R8P209:BTPD0UYJF0`2EUID309>CT`80UiNG0`2J
VYX509jNWP<0YJFU0P2WYjL30:RXZ080ZZZZ0`2][Jd20:b/[0<0/[:b0`2][Jd20;6a/@<0/;2`0P2a
/K460;Bd]080]kNg0`2n_[h20;Vi^@<0]KFe0`2_[jl20:f][@<0[Zj^0P2XZ:P60:^[Z`80ZJVY0`2[
Zj/20:RXZ0<0[jn_0`2XZ:P20:6QX@<0WinO0P2PX:0309ZJVP<0Vi^K0P2LW9`309RHV0D0Ti>C0P2F
UYH3092@T0<0UIFE0P2BTY8308b<S080SHf=0`2<S8`308Z:RP80Q8B40`26QXH208F5Q@<0Ng]k0`20
P8020861P@<0QHF50P24Q8@308V9RA`0b>3H000K0<SPf0<0DE5A1@0`<30203Ph>0<0@D510`0f=SH5
02TY:@80:b/[0`0Z:RX302TY:@80;Bd]0`0_;bl202XZ:P<092@T0P0N7Qh3020P80<0>CTi0P1JFUX3
08>3P`80Xj>S0`1lO7`307EeM@80Lg=c0`1fMWH208N7Q`<0_Kfm0`3<c<`20;Bd]0<0_Kfm0P30`<03
0;^k^`<0]kNg0P38b<P30<k>cP80^KVi0`1/K6`302XZ:P808b<S0`0T92@202l_;`<0<S8b0`0g=cL2
03lo?`<0BTY:0P1EEED3065QH@80JVYZ0`1aLG4307EeM@80MgMg0`1hN7P207YjNP<0OGem0`1oOgl2
07emO@<0O7al0P1nOWh30820P0<0Ph>30P26QXH308R8R0D0Rh^;0`2<S8`209:BTPP0UiNG0`2HV9P2
09VIV@<0Vi^K0P2MWId30:2PX0<0Y:BT0P2YZJT30:b/[0D0[Jf]0P2^[Zh30;2`/0<0/[:b1@2c/k<2
0;:b/P<0/k>c0`2d];@20;Ng]`<0^;Rh0P2d];@60;2`/080/K6a0`2][Jd20:ZZZP<0[Jf]0`2_[jl2
0:f][@<0Zj^[0P2/[:`30:f][@<0ZJVY0P2TY:@30::RXP80WinO0`2NWYh309fMW@80VYZJ0`2GUiL2
09JFUP<0UIFE0P2DU9@309:BTP<0Ti>C0P2DU9@3096AT@80SXj>0`2<S8`308^;R`80RHV90`26QXH2
08>3P`<0PH610`20P80207moO`<0PX:21@25QHDd0<SPf0<0E5AD1@0_;bl203Ph>0<0<c<c0`0e=CD2
02@T90<0:RXZ0P0/;2`302XZ:P<0:BTY0P0b<S8302/[:`809bLW0`0X:2P2028R8P<092@T0`0c<c<2
05mOG`<0T92@0P2TY:@308>3P`<0Lg=c0P1gMgL3079bLP80QXJ60`2o_kl30<c<c080/K6a0`2n_[h2
0<71`@<0_kno0`2j^[X20<71`@<0dM7A0P31`L43069RHP<0:2PX0P0W9bL302PX:080;2`/0`0`<303
03@d=080A4A40`18B4P205EEE@<0GemO0P1XJ6P607AdM0D0NGUi0P1hN7P307alO0D0P8200`1oOgl2
07UiN@<0P8200`23Ph<208J6QP<0RXZ:0P2<S8`308j>SP<0SHf=0P2BTY8809RHV0<0UiNG0P2KVi/3
09RHV080W9bL0`2PX:030:6QX@80YZJV1@2][Jd30;2`/0D0[Zj^0`2c/k<20;Fe]@<0/k>c0P2^[Zh3
0;Jf]P<0/k>c1@2j^[X20;Jf]P<0];Bd0`2][Jd20;>c/`D0Zj^[0`2/[:`30;2`/080[Jf]0`2/[:`2
0:RXZ0<0/;2`0`2VYZH20:BTY0<0YJFU0P2MWId609nOW`80V9RH0`2FUYH209>CT`<0U9BD0P2EUID3
096AT@<0U9BD1@2EUID208b<S0<0SXj>0`2<S8`208Z:RP<0QHF50P27QhL30861P@<0OWin0P21PH43
08>3P`80Q8B40`23Ph<L0<SPf0006`38h=P3055AD@D0<30`0P0h>3P30451@@<0=SHf1@0Y:BT202/[
:`<0:RXZ0`0Y:BT202d];@<0;bl_0P0Z:RX302@T90807QhN0`0P820303Ti>@80FUYJ0`23Ph<20:>S
X`<0O7al0`1eMGD207=cL`<0MWIf0P27QhL30;fm_@<0c<c<0P2d];@30;fm_@80`<300`2k^k/30;Ng
]`80b<S80`3>c/h20;Vi^@<0K6a/0`0Z:RX202<S8`<092@T0P0_;bl3038b<P<0=cLg0P0o?cl304Y:
BP80EEEE0`1QHF4206YZJP<0LG5a0`1eMGD207MgM`<0N7Qh0P1jNWX307emO@<0Ogmo0P1mOGd307al
O080OWin0`20P80308>3P`80QXJ60`28R8P508^;R`<0S8b<0P2BTY8809NGU`<0V9RH0P2IVIT309^K
V`80WIfM0`2PX:030:BTY080ZJVY0`2/[:`50:f][@80[Zj^0`2`/;030;:b/PD0/k>c0P2b/[830;>c
/`<0];Bd0P2g]kL30;Rh^080];Bd1P2`/;020;6a/@<0[Jf]0P2ZZZX30:f][@<0[jn_0P2][Jd30:^[
Z`80[:b/0`2][Jd30:VYZ@80Y:BT0`2RXZ8209nOW`<0WYjN0`2MWId209ZJVP<0UiNG0P2FUYH309FE
U@80U9BD0`2BTY8309>CT`80U9BD0`2ATI4208j>SP<0S8b<0`2;Rh/208V9R@<0QXJ60P23Ph<30861
P@<0P8200P1oOgl308:2PPD0QHF5=038h=P305ADE0D0;bl_0P0h>3P303<c<`<0=CDe0P0T92@302XZ
:P80;2`/0`0Z:RX302TY:@80<S8b0`0[:b/202LW9`<0:2PX0P0R8R8302@T90<0<c<c0P1OGel3092@
T080Y:BT0`23Ph<307=cL`80MgMg0`1bLW8208J6QP<0_kno0`3<c<`20;6a/@<0_[jn0P31`L430;no
_`<0^[Zj0P31`L430=7Ad@80`L710`1RHV8302PX:0809bLW0`0X:2P202`/;0<0<30`0`0d=3@204A4
A0<0B4Q80P1EEED305mOG`80J6QX1P1dM7@507UiN@80N7Qh0`1lO7`50820P0<0Ogmo0P1iNGT30820
P0<0Ph>30P26QXH308Z:RP80S8b<0`2>SXh308f=S@80TY:B202HV9P309NGU`80Vi^K0`2HV9P209bL
W0<0X:2P0`2QXJ420:JVYPD0[Jf]0`2`/;050:j^[P<0/k>c0P2e]KD30;>c/`80[Zj^0`2f][H30;>c
/`D0^[Zj0P2f][H30;Bd]0<0[Jf]0P2c/k<50:^[Z`<0[:b/0`2`/;020:f][@<0[:b/0P2XZ:P30;2`
/0<0YZJV0P2TY:@30:FUY@80WIfM1P2OWil209RHV0<0UYJF0P2CTi<309BDU080UIFE0`2ATI4309BD
U0D0UIFE0P2<S8`308j>SP<0S8b<0P2:RXX308F5Q@80QhN70`21PH4307inOP80PH610`23Ph<208B4
Q0<0Ph>37038h=P001/0b>3H0`1XJ6P2034a<@<0=CDe0P0V9RH3024Q8@<09BDU0P0[:b/302d];@80
;Rh^0`0Z:RX302LW9`80;Rh^0`0c<c<202`/;0<092@T0P0S8b<302LW9`<0;Rh^0P10@40307AdM080
XJ6Q0`2?Shl307AdM080Lg=c0`1kNg/2079bLP<0YZJV0`3<c<`20;6a/@<0^k^k0P2m_Kd30;bl_0<0
^KVi0P31`L430<?3``80gMgM0`2^[Zh303/k>`80:RXZ0`0T92@2034a<@<0<S8b0`0f=SH203`l?0<0
A4A40P1CDe<3065QH@80JFUY0`1^KVh307EeM@L0NGUi0`1kNg/307alO080Ng]k0`1jNWX207emO@<0
PH610`23Ph<208J6QP<0Rh^;202?Shl209>CT`<0UiNG0P2HV9P309VIV@<0VYZJ0P2KVi/309fMW@80
WYjN0`2QXJ430:FUY@80ZZZZ1@2^[Zh30:f][@80[Zj^0`2`/;030;>c/`80]KFe0`2d];@=0;>c/`80
[jn_0`2][Jd30;2`/080/k>c0`2`/;020:b/[0<0[jn_0`2b/[820;2`/0<0[Jf]0P2/[:`30:^[Z`<0
ZZZZ0P2XZ:P30:FUY@80XJ6Q0`2OWil309fMW@80VYZJ1@2FUYH309NGU`80U9BD0`2BTY8309>CT`80
U9BD0`2BTY8208n?S`<0SHf=0`2<S8`208V9R@D0QHF50`24Q8@30820P080OGem0`20P80208>3P`<0
Q8B4=038h=P305mOG`80=cLg0`0`<30202/[:`<08b<S0`0Y:BT202/[:`<0;bl_0P0/;2`302LW9`<0
9RHV0P0b<S8303<c<`80<30`0`0V9RH2024Q8@<0:RXZ0`0/;2`203`l?0<0N7Qh0P2GUiL309BDU0<0
MWIf0P1]KFd307emO@80MWIf0`2TY:@30<g=c@80/k>c0`2f][H20;no_`<0^k^k0`2l_;`20;fm_@<0
b/[:0P3AdM430:n_[`<0@T920P0Y:BT302LW9`80;Bd]0`0i>CT303Hf=P80=cLg0`17AdL205MGE`<0
HF5Q0P1YJFT306e]K@<0MGEe0P1hN7P307YjNP80N7Qh0`1lO7`307YjNP80Ng]k1@1jNWX608>3P`80
QXJ60`2:RXX208n?S`<0TI6A0`2?Shl2096AT@D0V9RH0`2IVIT309RHV080WIfM0`2LW9`209jNWP<0
XZ:R0`2VYZH20:RXZ0<0[jn_1@2^[Zh20:f][@H0/K6a0P2d];@30;>c/`D0];Bd0`2b/[820;Bd]0<0
/[:b0P2`/;030:n_[`<0[:b/0P2f][H30:f][@80[jn_0`2`/;030;>c/`80[Zj^0`2`/;020:ZZZP<0
[:b/0`2^[Zh20:NWY`<0YZJV0P2RXZ8309nOW`<0WIfM0P2JVYX309RHV080TY:B1@2IVIT309:BTP<0
TI6A0P2EUID309BDU080Shn?1P2<S8`208Z:RP<0Q8B40P29RHT308>3P`<0PH610P1lO7`30861P@80
Q8B40`22PX8L0<SPf0006`38h=P306QXJ080<C4a0`0e=CD202HV9P<08B4Q0`0U9BD202/[:`<0;Bd]
0P0^;Rh302XZ:P<09bLW0P0^;Rh303<c<`80;2`/0`0T92@202<S8`<09bLW0`0^;Rh20410@0<0M7Ad
0P2QXJ4308n?S`<0M7Ad0P1cLg<307]kN`80LW9b0`2VYZH30<c<c080/K6a0`2k^k/20;fm_@<0_;bl
0`2i^KT20<71`@<0`l?30P3MgMd30:j^[P<0>c/k0P0Z:RX302@T9080<C4a0`0b<S8303Hf=P80?3`l
0`14A4@205=CD`<0HF5Q0P1YJFT306i^KP<0MGEe1`1iNGT307]kN`<0O7al0P1kNg/307YjNP80OGem
0`21PH4308>3P`80QXJ60`2;Rh/808n?S`80Ti>C0`2GUiL209RHV0<0VIVI0`2JVYX209^KV`<0WIfM
0P2NWYh30:6QX@<0YJFU0P2ZZZX50:j^[P<0[Jf]0P2^[Zh30;2`/0<0/k>c0P2e]KD30;Bd]0d0/k>c
0P2_[jl30:f][@<0/;2`0P2c/k<30;2`/080[:b/0`2_[jl30;:b/P80/;2`0`2][Jd20:b/[0<0Zj^[
0`2ZZZX20:RXZ0<0YJFU0P2QXJ4309nOW`<0WIfM0P2JVYX509JFUP<0UiNG0P2DU9@309:BTP<0Ti>C
0P2DU9@309:BTP80Shn?0`2=SHd308b<S080RHV91@25QHD308B4Q0<0P8200P1mOGd30820P080Ph>3
0`24Q8@d0<SPf0<0GemO0P0g=cL3030`<080:b/[0`0S8b<302TY:@80:b/[0`0_;bl202`/;0<09bLW
0`0V9RH2038b<P<0<c<c0P0`<30302HV9P808B4Q0`0Z:RX302`/;080?3`l0`1hN7P209NGU`<0U9BD
0`1fMWH206e]K@<0OGem0P1fMWH30:BTY0<0cLg=0P2c/k<30;Jf]P80_kno0`2k^k/30;bl_080_Kfm
0`3:b/X20=7Ad@<0[jn_0`12@T8202TY:@<09bLW0P0];Bd303Ti>@<0=SHf0P0g=cL304M7A`80EeMG
0`1QHF4206UYJ@<0KFe]0`1eMGD207QhN0<0NWYj0P1hN7P307alO0<0NWYj0P1kNg/507YjNPH0Ph>3
0P26QXH308Z:RP80Shn?0`2ATI4308n?S`80TI6A1@2HV9P309VIV@<0V9RH0P2MWId309bLW080WYjN
0`2RXZ830:JVYP80Z:RX0`2_[jl50:j^[P80[Jf]1P2a/K420;Bd]0<0/k>c1@2d];@30;:b/P80];Bd
0`2b/[820;2`/0<0[jn_0`2/[:`20;Jf]P<0[Jf]0P2_[jl30;2`/0<0/k>c0P2^[Zh30;2`/080ZZZZ
0`2/[:`30:j^[P80YjNW0`2VYZH20::RXP<0WinO0`2MWId209ZJVP<0V9RH0P2BTY8509VIV@<0TY:B
0`2ATI4209FEU@<0U9BD0P2?Shl608b<S080RXZ:0`24Q8@208V9R@<0Ph>30`21PH4207alO0<0PH61
0P24Q8@308:2PQ`0b>3H000K0<SPf0<0J6QX0P0a<C4303De=@809RHV0`0Q8B4302DU9@80:b/[0`0]
;Bd202h^;P<0:RXZ0`0W9bL202h^;P<0<c<c0P0/;2`302@T90808b<S0`0W9bL302h^;P80@4100`1d
M7@20:6QX@<0Shn?0`1dM7@207=cL`<0Ng]k0P1bLW830:JVYP<0c<c<0P2a/K430;^k^`80_Kfm0`2l
_;`30;Vi^@80`L710`33`l<20=gMg@<0[Zj^0`0k>c/202XZ:P<092@T0P0a<C43038b<P<0=SHf0P0l
?3`304A4A080De=C0`1QHF4206UYJ@<0KVi^0`1eMGD707UiN@<0Ng]k0`1lO7`207]kN`<0NWYj0P1m
OGd30861P@<0Ph>30P26QXH308^;R`P0Shn?0P2CTi<309NGU`80V9RH0`2IVIT309ZJVP80Vi^K0`2M
WId209jNWP<0XJ6Q0`2UYJD20:ZZZPD0[Zj^0`2][Jd20:j^[P<0/;2`0`2c/k<20;Fe]@<0];Bd3@2c
/k<20:n_[`<0[Jf]0`2`/;020;>c/`<0/;2`0P2/[:`30:n_[`<0/[:b0P2`/;030:f][@80[:b/0`2[
Zj/30:ZZZP80Z:RX0`2UYJD20:6QX@<0WinO0`2MWId209ZJVPD0UYJF0`2GUiL209BDU0<0TY:B0`2C
Ti<209BDU0<0TY:B0P2?Shl308f=S@<0S8b<0P29RHT508F5Q@<0Q8B40`20P80207emO@<0P8200P23
Ph<308B4Q3@0b>3H0`1OGel203Lg=`<0<30`0P0[:b/302<S8`<0:BTY0P0[:b/302l_;`80;2`/0`0W
9bL302HV9P80<S8b0`0c<c<2030`<0<09RHV0P0Q8B4302XZ:P<0;2`/0P0l?3`307QhN080UiNG0`2D
U9@307IfMP80KFe]0`1mOGd207IfMP<0Y:BT0`3=cLd20;>c/`<0][Jf0P2o_kl30;^k^`<0_;bl0P2m
_Kd30<[:bP80dM7A0`2_[jl30492@P80:BTY0`0W9bL202d];@<0>CTi0`0f=SH203Lg=`<0AdM70P1G
EeL3065QH@80JFUY0`1]KFd307EeM@80N7Qh0`1jNWX207QhN0<0O7al0`1jNWX207]kN`D0NWYj1P23
Ph<208J6QP<0RXZ:0P2?Shl3096AT@<0Shn?0P2ATI4509RHV0<0VIVI0`2HV9P209fMW@<0W9bL0P2N
WYh30::RXP<0YZJV0P2XZ:P30:n_[`D0[Zj^0P2][Jd60;6a/@80];Bd0`2c/k<50;Bd]0<0/[:b0P2d
];@30;:b/P80/;2`0`2_[jl30:b/[080][Jf0`2][Jd20:n_[`<0/;2`0`2c/k<20:j^[P<0/;2`0P2Z
ZZX30:b/[0<0[Zj^0P2WYjL30:JVYP80XZ:R0`2OWil309fMW@80VYZJ0`2HV9P209:BTPD0VIVI0`2B
TY83096AT@80UIFE0`2DU9@208n?S`H0S8b<0P2:RXX308B4Q080RHV90`23Ph<30861P@80O7al0`21
PH4208B4Q0<0PX:27038h=P001/0b>3H0`1CDe<2038b<P<0<C4a0P0Z:RX302TY:@<0:RXZ1`0];Bd3
02`/;0<0:b/[0P0];Bd302l_;`80;Bd]0`0Z:RX802TY:@80<c<c0`1NGUh208J6QP<0WIfM0`23Ph<2
06i^KP<0Ng]k0P1_Kfl308^;R`<0];Bd0P2h^;P30:^[Z`D0_[jn0`2o_kl20<?3``<0a<C40P3Hf=P3
0;^k^`<0XJ6Q0P0o?cl301lO7`80:BTY0`0Z:RX303@d=080>c/k0`14A4@2059BDP<0H61P0P1WIfL3
06a/K0<0Lg=c0P1hN7P507YjNP<0Ng]k0`1mOGd507alO080Ogmo0`22PX8308B4Q080QXJ60`2:RXX2
08j>SP<0TI6A0`2BTY8209>CT`<0UIFE0P2GUiL309ZJVP<0Vi^K0P2LW9`309nOW`80XZ:R0`2TY:@3
0:FUY@80ZJVY0`2/[:`50:f][@80[Zj^0`2`/;030;:b/PL0];Bd0`2b/[830;6a/@D0/[:b0P2a/K43
0:n_[`<0/;2`0P2a/K430;2`/080[jn_0`2a/K450;:b/P<0/K6a0P2^[Zh30:b/[0<0ZZZZ0P2XZ:P3
0:FUY@80XZ:R0`2OWil309bLW080Vi^K0`2JVYX209NGU`<0U9BD2P2CTi<3092@T080SXj>0`2<S8`3
08Z:RP80QhN70`25QHD508B4Q0<0PX:22P20P80d0<SPf0<0D51@0P0j>SX502h^;P<09RHV0`0b<S82
02XZ:P<0<30`0P0b<S8302XZ:P<0;Bd]0P0^;Rh302l_;`80:BTY0`0W9bL202HV9P<0:2PX0`0Z:RX2
038b<P<0G5aL0P28R8P309^KV`<0Ogmo0P1YJFT507UiN@<0Ph>30`2b/[820;Rh^0<0[:b/0P2k^k/3
0;fm_@<0`<300P2n_[h30<S8b080dM7A0`3=cLd309RHV080=CDe0`0T92@202HV9P<0;bl_0`0b<S82
03/k>`<0@D510P1DE5@3065QH@80IFEU0`1^KVh3079bLP80NWYj0`1gMgL207]kN`H0O7al0P1oOgl3
07emO@80O7al0`26QXH30861P@80QhN70`29RHT208^;R`<0Shn?0`2CTi<208j>SP<0UIFE0P2FUYH6
09^KV`D0W9bL0P2UYJD30:BTY0<0YjNW0P2XZ:P30:b/[080ZZZZ1@2/[:`30;6a/@<0/k>c1@2d];@5
0;>c/`<0/;2`0P2][Jd30;2`/0P0[Zj^0P2c/k<30;2`/0D0[Jf]0`2b/[820;>c/`<0/K6a0P2[Zj/3
0:ZZZP<0ZJVY0P2UYJD30::RXP80XJ6Q0`2NWYh809^KV`80VYZJ0`2@T90209:BTP<0TI6A0`2@T902
08j>SP<0TY:B1@2;Rh/308R8R0D0Q8B40P20P8030861P@<0Q8B41@1oOgl20820P0<0PX:27038h=P0
01/0b>3H0`1CDe<2038b<P<0<C4a0P0Z:RX302TY:@<0:RXZ1`0];Bd302`/;0<0:b/[0P0];Bd302l_
;`80;Bd]0`0Z:RX802TY:@80<c<c0`1NGUh208J6QP<0WIfM0`23Ph<206i^KP<0Ng]k0P1_Kfl308^;
R`<0];Bd0P2h^;P30:^[Z`D0_[jn0`2o_kl20<?3``<0a<C40P3Hf=P30;^k^`<0XJ6Q0P0o?cl301lO
7`80:BTY0`0Z:RX303@d=080>c/k0`14A4@2059BDP<0H61P0P1WIfL306a/K0<0Lg=c0P1hN7P507Yj
NP<0Ng]k0`1mOGd507alO080Ogmo0`22PX8308B4Q080QXJ60`2:RXX208j>SP<0TI6A0`2BTY8209>C
T`<0UIFE0P2GUiL309ZJVP<0Vi^K0P2LW9`309nOW`80XZ:R0`2TY:@30:FUY@80ZJVY0`2/[:`50:f]
[@80[Zj^0`2`/;030;:b/PL0];Bd0`2b/[830;6a/@D0/[:b0P2a/K430:n_[`<0/;2`0P2a/K430;2`
/080[jn_0`2a/K450;:b/P<0/K6a0P2^[Zh30:b/[0<0ZZZZ0P2XZ:P30:FUY@80XZ:R0`2OWil309bL
W080Vi^K0`2JVYX209NGU`<0U9BD2P2CTi<3092@T080SXj>0`2<S8`308Z:RP80QhN70`25QHD508B4
Q0<0PX:22P20P80d0<SPf0<0D51@0P0j>SX502h^;P<09RHV0`0b<S8202XZ:P<0<30`0P0b<S8302XZ
:P<0;Bd]0P0^;Rh302l_;`80:BTY0`0W9bL202HV9P<0:2PX0`0Z:RX2038b<P<0G5aL0P28R8P309^K
V`<0Ogmo0P1YJFT507UiN@<0Ph>30`2b/[820;Rh^0<0[:b/0P2k^k/30;fm_@<0`<300P2n_[h30<S8
b080dM7A0`3=cLd309RHV080=CDe0`0T92@202HV9P<0;bl_0`0b<S8203/k>`<0@D510P1DE5@3065Q
H@80IFEU0`1^KVh3079bLP80NWYj0`1gMgL207]kN`H0O7al0P1oOgl307emO@80O7al0`26QXH30861
P@80QhN70`29RHT208^;R`<0Shn?0`2CTi<208j>SP<0UIFE0P2FUYH609^KV`D0W9bL0P2UYJD30:BT
Y0<0YjNW0P2XZ:P30:b/[080ZZZZ1@2/[:`30;6a/@<0/k>c1@2d];@50;>c/`<0/;2`0P2][Jd30;2`
/0P0[Zj^0P2c/k<30;2`/0D0[Jf]0`2b/[820;>c/`<0/K6a0P2[Zj/30:ZZZP<0ZJVY0P2UYJD30::R
XP80XJ6Q0`2NWYh809^KV`80VYZJ0`2@T90209:BTP<0TI6A0`2@T90208j>SP<0TY:B1@2;Rh/308R8
R0D0Q8B40P20P8030861P@<0Q8B41@1oOgl20820P0<0PX:27038h=P001/0b>3H0`1CDe<2038b<P<0
<C4a0P0Z:RX302TY:@<0:RXZ1`0];Bd302`/;0<0:b/[0P0];Bd302l_;`80;Bd]0`0Z:RX802TY:@80
<c<c0`1NGUh208J6QP<0WIfM0`23Ph<206i^KP<0Ng]k0P1_Kfl308^;R`<0];Bd0P2h^;P30:^[Z`D0
_[jn0`2o_kl20<?3``<0a<C40P3Hf=P30;^k^`<0XJ6Q0P0o?cl301lO7`80:BTY0`0Z:RX303@d=080
>c/k0`14A4@2059BDP<0H61P0P1WIfL306a/K0<0Lg=c0P1hN7P507YjNP<0Ng]k0`1mOGd507alO080
Ogmo0`22PX8308B4Q080QXJ60`2:RXX208j>SP<0TI6A0`2BTY8209>CT`<0UIFE0P2GUiL309ZJVP<0
Vi^K0P2LW9`309nOW`80XZ:R0`2TY:@30:FUY@80ZJVY0`2/[:`50:f][@80[Zj^0`2`/;030;:b/PL0
];Bd0`2b/[830;6a/@D0/[:b0P2a/K430:n_[`<0/;2`0P2a/K430;2`/080[jn_0`2a/K450;:b/P<0
/K6a0P2^[Zh30:b/[0<0ZZZZ0P2XZ:P30:FUY@80XZ:R0`2OWil309bLW080Vi^K0`2JVYX209NGU`<0
U9BD2P2CTi<3092@T080SXj>0`2<S8`308Z:RP80QhN70`25QHD508B4Q0<0PX:22P20P80d0<SPf0<0
D51@0P0j>SX502h^;P<09RHV0`0b<S8202XZ:P<0<30`0P0b<S8302XZ:P<0;Bd]0P0^;Rh302l_;`80
:BTY0`0W9bL202HV9P<0:2PX0`0Z:RX2038b<P<0G5aL0P28R8P309^KV`<0Ogmo0P1YJFT507UiN@<0
Ph>30`2b/[820;Rh^0<0[:b/0P2k^k/30;fm_@<0`<300P2n_[h30<S8b080dM7A0`3=cLd309RHV080
=CDe0`0T92@202HV9P<0;bl_0`0b<S8203/k>`<0@D510P1DE5@3065QH@80IFEU0`1^KVh3079bLP80
NWYj0`1gMgL207]kN`H0O7al0P1oOgl307emO@80O7al0`26QXH30861P@80QhN70`29RHT208^;R`<0
Shn?0`2CTi<208j>SP<0UIFE0P2FUYH609^KV`D0W9bL0P2UYJD30:BTY0<0YjNW0P2XZ:P30:b/[080
ZZZZ1@2/[:`30;6a/@<0/k>c1@2d];@50;>c/`<0/;2`0P2][Jd30;2`/0P0[Zj^0P2c/k<30;2`/0D0
[Jf]0`2b/[820;>c/`<0/K6a0P2[Zj/30:ZZZP<0ZJVY0P2UYJD30::RXP80XJ6Q0`2NWYh809^KV`80
VYZJ0`2@T90209:BTP<0TI6A0`2@T90208j>SP<0TY:B1@2;Rh/308R8R0D0Q8B40P20P8030861P@<0
Q8B41@1oOgl20820P0<0PX:27038h=P001/0b>3H0`0j>SX203De=@<0;2`/0P0];Bd802h^;P<0;Bd]
0P0/;2`302d];@<0;bl_0P0/;2`302XZ:P80;Bd]0`0_;bl202d];@<0:RXZ0`0W9bL202/[:`<0AdM7
0P1TI6@30:2PX0<0UIFE0P1/K6`307]kN`80LW9b0`1dM7@309NGU`80_Kfm0`2OWil20;fm_@<0_kno
0`34a<@50<;2`P80dM7A0`3GemL30<30`080NWYj0`0e=CD201lO7`<0820P0`0a<C4203Xj>P<0ADE5
0P1BDU8305iNGP80IFEU0`1ZJVX3075aL@80MgMg0`1iNGT207YjNP<0O7al0`1mOGd207inOP<0P820
0P22PX8308B4Q0<0QHF50P27QhL308Z:RP80SHf=0`2ATI4509BDU0<0Ti>C0P2FUYH309VIV@<0Vi^K
0P2LW9`30:2PX080Y:BT1P2VYZH20:RXZ0<0ZZZZ0P2/[:`30:f][@80[Zj^0`2_[jl30;6a/@80/[:b
0`2c/k<20;Bd]0<0/K6a0`2_[jl20;6a/@D0/k>c0`2b/[830;2`/080[Zj^0`2`/;020;:b/PH0/K6a
0P2b/[830;>c/`80/K6a0`2][Jd30:ZZZP80YjNW0`2UYJD20:>SX`<0WinO0`2KVi/509bLW080UYJF
0`2ATI4209:BTP<0U9BD0`2CTi<2096AT@<0Shn?0P2=SHd308Z:RP<0QhN70P25QHD308B4Q080Ph>3
1P24Q8@208>3P`<0PH611@1nOWhd0<SPf0<0=cLg0P0h>3P302TY:@80;Rh^0`0_;bl3038b<P80;Rh^
0`0];Bd202/[:`<0;2`/0`0];Bd202l_;`<0:RXZ0P0_;bl303<c<`D0:BTY0`0Z:RX2030`<0<0>SXj
0P1/K6`309BDU0<0UiNG1@1cLg<207QhN0<0MGEe0`2@T9020;bl_0<0Z:RX0P2f][H60<71`@D0`l?3
0P3=cLd30=;BdP<0bLW90P1lO7`302d];@808B4Q0`0X:2P302d];@80>3Ph0`17AdL205EEE@<0H61P
0P1RHV8306a/K0<0Kfm_0P1gMgL307alO080Ng]k0`1jNWX307inOPD0P8200P1oOgl308N7Q`<0PH61
0P2:RXX308R8R080SXj>1P2DU9@2096AT@<0Ti>C1@2GUiL809fMW@D0YJFU1@2WYjL30:ZZZP80[Zj^
0`2][Jd20:b/[0<0/;2`0`2a/K420;>c/`<0/;2`0P2e]KD30:n_[`<0/;2`0P2d];@30;:b/P80]kNg
0`2d];@50:j^[P<0[jn_0P2d];@30;>c/`<0/;2`0P2c/k<50;:b/P<0[Jf]0`2ZZZX20:RXZ0<0YZJV
1@2QXJ4309ZJVP80WIfM0`2IVIT209ZJVP<0T92@1@2BTY8309BDU080T92@0`2DU9@208Z:RP<0SHf=
0`2:RXX20861P@<0QHF50P27QhL308F5Q@<0Ph>31@22PX8207]kN`<0Ogmo7038h=P001/0b>3H0`0j
>SX203De=@<0;2`/0P0];Bd802h^;P<0;Bd]0P0/;2`302d];@<0;bl_0P0/;2`302XZ:P80;Bd]0`0_
;bl202d];@<0:RXZ0`0W9bL202/[:`<0AdM70P1TI6@30:2PX0<0UIFE0P1/K6`307]kN`80LW9b0`1d
M7@309NGU`80_Kfm0`2OWil20;fm_@<0_kno0`34a<@50<;2`P80dM7A0`3GemL30<30`080NWYj0`0e
=CD201lO7`<0820P0`0a<C4203Xj>P<0ADE50P1BDU8305iNGP80IFEU0`1ZJVX3075aL@80MgMg0`1i
NGT207YjNP<0O7al0`1mOGd207inOP<0P8200P22PX8308B4Q0<0QHF50P27QhL308Z:RP80SHf=0`2A
TI4509BDU0<0Ti>C0P2FUYH309VIV@<0Vi^K0P2LW9`30:2PX080Y:BT1P2VYZH20:RXZ0<0ZZZZ0P2/
[:`30:f][@80[Zj^0`2_[jl30;6a/@80/[:b0`2c/k<20;Bd]0<0/K6a0`2_[jl20;6a/@D0/k>c0`2b
/[830;2`/080[Zj^0`2`/;020;:b/PH0/K6a0P2b/[830;>c/`80/K6a0`2][Jd30:ZZZP80YjNW0`2U
YJD20:>SX`<0WinO0`2KVi/509bLW080UYJF0`2ATI4209:BTP<0U9BD0`2CTi<2096AT@<0Shn?0P2=
SHd308Z:RP<0QhN70P25QHD308B4Q080Ph>31P24Q8@208>3P`<0PH611@1nOWhd0<SPf0<0=cLg0P0h
>3P302TY:@80;Rh^0`0_;bl3038b<P80;Rh^0`0];Bd202/[:`<0;2`/0`0];Bd202l_;`<0:RXZ0P0_
;bl303<c<`D0:BTY0`0Z:RX2030`<0<0>SXj0P1/K6`309BDU0<0UiNG1@1cLg<207QhN0<0MGEe0`2@
T9020;bl_0<0Z:RX0P2f][H60<71`@D0`l?30P3=cLd30=;BdP<0bLW90P1lO7`302d];@808B4Q0`0X
:2P302d];@80>3Ph0`17AdL205EEE@<0H61P0P1RHV8306a/K0<0Kfm_0P1gMgL307alO080Ng]k0`1j
NWX307inOPD0P8200P1oOgl308N7Q`<0PH610P2:RXX308R8R080SXj>1P2DU9@2096AT@<0Ti>C1@2G
UiL809fMW@D0YJFU1@2WYjL30:ZZZP80[Zj^0`2][Jd20:b/[0<0/;2`0`2a/K420;>c/`<0/;2`0P2e
]KD30:n_[`<0/;2`0P2d];@30;:b/P80]kNg0`2d];@50:j^[P<0[jn_0P2d];@30;>c/`<0/;2`0P2c
/k<50;:b/P<0[Jf]0`2ZZZX20:RXZ0<0YZJV1@2QXJ4309ZJVP80WIfM0`2IVIT209ZJVP<0T92@1@2B
TY8309BDU080T92@0`2DU9@208Z:RP<0SHf=0`2:RXX20861P@<0QHF50P27QhL308F5Q@<0Ph>31@22
PX8207]kN`<0Ogmo7038h=P001/0b>3H0`0n?Sh203Ph>0<0:b/[0P0^;Rh3038b<P<0<C4a1`0_;bl@
02h^;P80;Bd]0`0[:b/302PX:080:BTY0`0e=CD204Q8B0<0S8b<0`2RXZ8207emO@<0Lg=c0P1_Kfl3
075aL@<0Ogmo1@2e]KD20;6a/@<0^k^k0`31`L450<;2`P80bLW90`3@d=030=SHf080]KFe0`1?Cdl2
030`<0<0:2PX0`0Y:BT203De=@<0A4A40P1?Cdl305UIF@80HF5Q0`1WIfL306m_K`80MWIf1@1hN7P3
07YjNP<0OGem0P1nOWh30820P080PH610`23Ph<308J6QP80RHV90`2;Rh/208f=S@<0T92@0`2CTi<5
09FEU@80UYJF0`2HV9P309^KV`80WYjN0`2QXJ420::RXP<0YJFU0`2WYjL20:ZZZPD0[:b/0`2[Zj/2
0:f][@<0/;2`0`2c/k<20;Bd]0<0/K6a0P2^[Zh30:f][@<0[Zj^0P2a/K450;>c/`<0/[:b2P2a/K43
0;2`/0<0[jn_0P2`/;030;6a/@80/;2`0`2_[jl30:b/[080ZJVY0`2WYjL20:FUY@<0XJ6Q0`2MWId2
09ZJVP<0UiNG0P2EUID509>CT`<0UIFE0`2CTi<2096AT@<0Shn?0P2=SHd308Z:RP<0QhN70P25QHD8
08B4Q0<0Ph>30P22PX880861PC@0b>3H0`0n?Sh203De=@<0;bl_0P0];Bd802h^;P<0;bl_0P0];Bd3
02h^;P<0<30`0P0^;Rh302d];@80;Rh^0`0_;bl2034a<@<0<30`0`0[:b/202`/;0<0=SHf0P1CDe<3
08V9R@<0ZZZZ0P20P80307=cL`80LW9b0`1dM7@307emO@D0]KFe0P2c/k<30;bl_0<0`<301@33`l<2
0<K6aPH0clo?0P2m_Kd305QHF080:BTY0`0T92@302h^;P80=3@d0`14A4@204e=C@<0EeMG0P1OGel3
06UYJ@<0Kfm_0P1gMgL307EeM@80MgMg0`1iNGT307alO080OGem0`1nOWh208J6QP<0PX:20`23Ph<2
08f=S@<0RHV90P2=SHd309BDU0<0Ti>C0P2GUiL309RHV080UiNG0`2HV9P309ZJVP80WYjN0`2QXJ42
0::RXP<0Xj>S0`2WYjL20:VYZ@<0Zj^[0P2^[Zh30:f][@80Zj^[0`2^[Zh30;>c/`80/[:b0`2d];@2
0;2`/0<0[:b/0`2ZZZX20;Bd]0<0/k>c0P2`/;060;6a/@80/[:b0`2a/K420;2`/0<0[Jf]0`2^[Zh2
0;:b/P<0[jn_0P2b/[830:n_[`<0[Jf]0P2ZZZX30:VYZ@80YjNW0`2TY:@309^KV`80W9bL0`2DU9@2
09>CT`D0U9BD0`2HV9P309FEU@80SXj>0`2BTY8208Z:RP<0SHf=0`26QXH208:2PP<0R8R80P26QXH3
08B4Q0<0Ogmo0P24Q8@308>3P`80PX:20`25QHDL0<SPf0006`38h=P303hn?P80>3Ph0`0[:b/202h^
;P<0<S8b0`0a<C4702l_;a00;Rh^0P0];Bd302/[:`<0:2PX0P0Y:BT303De=@80B4Q80`2<S8`30::R
XP80OGem0`1cLg<206m_K`<0LG5a0`1oOgl50;Fe]@80/K6a0`2k^k/30<71`@D0`/;20P39bLT30=3@
d0<0f=SH0P2e]KD304m?C`80<30`0`0X:2P302TY:@80=CDe0`14A4@204m?C`<0FEUI0P1QHF4306MW
I`<0Kfm_0P1fMWH507QhN0<0NWYj0`1mOGd207inOP<0P8200P21PH4308>3P`<0QXJ60P29RHT308^;
R`80SHf=0`2@T90309>CT`D0UIFE0P2FUYH309RHV0<0Vi^K0P2NWYh30:6QX@80XZ:R0`2UYJD30:NW
Y`80ZZZZ1@2/[:`30:^[Z`80[Jf]0`2`/;030;>c/`80];Bd0`2a/K420:j^[P<0[Jf]0`2^[Zh20;6a
/@D0/k>c0`2b/[8:0;6a/@<0/;2`0`2_[jl20;2`/0<0/K6a0P2`/;030:n_[`<0[:b/0P2YZJT30:NW
Y`80YJFU0`2QXJ4309fMW@80VYZJ0`2GUiL209FEU@D0Ti>C0`2EUID309>CT`80TI6A0`2?Shl208f=
S@<0RXZ:0`27QhL208F5Q@P0Q8B40`23Ph<208:2PPP0PH61=038h=P303hn?P80=CDe0`0_;bl202d]
;@P0;Rh^0`0_;bl202d];@<0;Rh^0`0`<30202h^;P<0;Bd]0P0^;Rh302l_;`80<C4a0`0`<30302/[
:`80;2`/0`0f=SH205=CD`<0RHV90`2ZZZX20820P0<0Lg=c0P1bLW8307AdM0<0OGem1@2e]KD20;>c
/`<0_;bl0`30`<050<?3``80a/K61P3?cll20;fm_@<0F5QH0P0Y:BT302@T90<0;Rh^0P0d=3@304A4
A080CDe=0`1GEeL205mOG`<0JFUY0`1_Kfl207MgM`<0MGEe0P1gMgL307UiN@<0O7al0P1mOGd307in
OP80QXJ60`22PX8308>3P`80SHf=0`29RHT208f=S@<0U9BD0`2CTi<209NGU`<0V9RH0P2GUiL309RH
V0<0VYZJ0P2NWYh30:6QX@80XZ:R0`2SXj<30:NWY`80ZJVY0`2[Zj/20:j^[P<0[Jf]0P2[Zj/30:j^
[P<0/k>c0P2b/[830;Bd]080/;2`0`2/[:`30:ZZZP80];Bd0`2c/k<20;2`/0H0/K6a0P2b/[830;6a
/@80/;2`0`2][Jd30:j^[P80/[:b0`2_[jl20;:b/P<0[jn_0`2][Jd20:ZZZP<0ZJVY0P2WYjL30:BT
Y0<0Vi^K0P2LW9`309BDU080Ti>C1@2DU9@309RHV0<0UIFE0P2>SXh309:BTP80RXZ:0`2=SHd308J6
QP80PX:20`28R8P208J6QP<0Q8B40`1oOgl208B4Q0<0Ph>30P22PX8308F5QA`0b>3H000K0<SPf0<0
?Shn0P0h>3P302/[:`80;Rh^0`0b<S83034a<@L0;bl_400^;Rh202d];@<0:b/[0`0X:2P202TY:@<0
=CDe0P18B4P308b<S0<0XZ:R0P1mOGd307=cL`80Kfm_0`1aLG4307moO`D0]KFe0P2a/K430;^k^`<0
`L711@32`/820<W9b@<0d=3@0`3Hf=P20;Fe]@<0Cdm?0P0`<30302PX:0<0:BTY0P0e=CD304A4A080
Cdm?0`1IFET2065QH@<0IfMW0`1_Kfl207IfMPD0N7Qh0`1jNWX307emO@80OWin0`20P8020861P@<0
Ph>30`26QXH208V9R@<0Rh^;0P2=SHd3092@T0<0Ti>C1@2EUID209JFUP<0V9RH0`2KVi/209jNWP<0
XJ6Q0P2RXZ830:FUY@<0YjNW0P2ZZZX50:b/[0<0Zj^[0P2][Jd30;2`/0<0/k>c0P2d];@30;6a/@80
[Zj^0`2][Jd30:j^[P80/K6a1@2c/k<30;:b/PX0/K6a0`2`/;030:n_[`80/;2`0`2a/K420;2`/0<0
[jn_0`2/[:`20:VYZ@<0YjNW0P2UYJD30:6QX@<0WIfM0P2JVYX309NGU`80UIFE1@2CTi<309FEU@<0
Ti>C0P2ATI4308n?S`80SHf=0`2:RXX308N7Q`80QHF52024Q8@308>3P`80PX:22021PH4d0<SPf0<0
?Shn0P0e=CD302l_;`80;Bd]200^;Rh302l_;`80;Bd]0`0^;Rh3030`<080;Rh^0`0];Bd202h^;P<0
;bl_0P0a<C43030`<0<0:b/[0P0/;2`303Hf=P80De=C0`29RHT30:ZZZP80P8200`1cLg<2079bLP<0
M7Ad0`1mOGd50;Fe]@80/k>c0`2l_;`30<30`0D0`l?30P36a/H60<o?c`80_Kfm0`1HF5P202TY:@<0
92@T0`0^;Rh203@d=0<0A4A40P1=CDd305MGE`80GemO0`1YJFT306m_K`80MgMg0`1eMGD207MgM`<0
NGUi0`1lO7`207emO@<0OWin0P26QXH308:2PP<0Ph>30P2=SHd308V9R@80SHf=0`2DU9@309>CT`80
UiNG0`2HV9P209NGU`<0V9RH0`2JVYX209jNWP<0XJ6Q0P2RXZ830:>SX`<0YjNW0P2YZJT30:^[Z`80
[Zj^0`2][Jd20:^[Z`<0[Zj^0`2c/k<20;:b/P<0];Bd0P2`/;030:b/[0<0ZZZZ0P2d];@30;>c/`80
/;2`1P2a/K420;:b/P<0/K6a0P2`/;030:f][@<0[Zj^0P2b/[830:n_[`80/[:b0`2_[jl30:f][@80
ZZZZ0`2YZJT20:NWY`<0Y:BT0`2KVi/209bLW0<0U9BD0P2CTi<509BDU0<0V9RH0`2EUID208j>SP<0
TY:B0P2:RXX308f=S@<0QXJ60P22PX8308R8R080QXJ60`24Q8@307moO`80Q8B40`23Ph<208:2PP<0
QHF57038h=P001/0b>3H0`15ADD203Ti>@<0:b/[0P0^;Rh303@d=0<0<c<c0P0`<305034a<@<0;Rh^
0`0/;2`202l_;`<0<S8b0P0_;bl802`/;0<0:RXZ0P0Y:BT302PX:080<c<c0`1`L7030:FUY@80T92@
0`1_Kfl206][J`<0LW9b0`1]KFd20:FUY@<0bLW90P2XZ:P30;Fe]@<0_;bl0P30`<030<;2`P80a<C4
0`35aLD30=;BdP80bLW90`2a/K42038b<P<0=3@d0`0T92@2038b<P<0@T920P1<C4`305ADE080GEeM
0`1UIFD306i^KP80MGEe1@1fMWH307UiN@<0O7al0P1nOWh307moO`80P8200`21PH4308J6QP80RXZ:
0`2<S8`208f=S@<0Shn?0`2BTY8209JFUP<0V9RH1@2GUiL309^KV`L0X:2P0`2TY:@30:RXZ080Zj^[
0`2^[Zh20:b/[0<0ZZZZ0P2][Jd30;2`/0<0];Bd0P2e]KD30:n_[`80ZJVY0`2ZZZX30:j^[P80/K6a
0`2c/k<20;:b/P<0/;2`0`2b/[820;Bd]0<0/K6a202^[Zh50:n_[`D0/;2`0`2^[Zh20:^[Z`<0ZJVY
0P2WYjL30:>SX`<0WinO0P2HV9P509>CT`P0U9BD0`2CTi<2096AT@<0T92@0P2=SHd308Z:RP<0QXJ6
2P25QHD308:2PP80P8200`22PX8208B4Q0<0QHF5=038h=P304Y:BP80<30`0`0];Bd203<c<`<0=CDe
0`0d=3@202l_;`<0>SXj1@0];Bd302`/;0D0<30`0P0];Bd302/[:`80<30`200Y:BT302HV9P80<C4a
0`1_Kfl309jNWP80U9BD0`1`L70206IVIP<0Kfm_0`1fMWH20:JVYP<0`<300P2[Zj/30;Bd]0<0_Kfm
0P2l_;`30<C4a080`/;20`39bLT30=3@d080c<c<0`2XZ:P203dm?@<0:RXZ0`0X:2P203Hf=P<0@D51
0P1;Bd/305ADE080FUYJ0`1VIVH3075aL@80MGEe0`1dM7@207EeM@<0NWYj0`1mOGd207inOP<0P820
0P1nOWh30861P@<0QXJ60P2:RXX308b<S080SHf=0`2BTY83092@T080U9BD1@2HV9P309FEU@D0WYjN
0`2RXZ8209nOW`<0Y:BT0`2WYjL20:j^[P<0[:b/0P2][Jd30:VYZ@80[Jf]0`2_[jl30;Jf]P80]KFe
0`2^[Zh20:RXZ0<0ZZZZ0`2[Zj/50;:b/P80/K6a0`2_[jl30;Jf]P80/k>c0`2a/K450;2`/0<0[Jf]
0P2^[Zh30:n_[`80/K6a1P2`/;020:VYZ@<0ZZZZ0P2TY:@30:>SX`<0WinO0P2JVYX309>CT`80TI6A
1@2EUID309BDU0<0TI6A0P2CTi<3092@T0D0S8b<2025QHD208J6QP<0QhN70`1mOGd20861P@<0Ph>3
0P22PX8308F5QA`0b>3H000K0<SPf0<0ADE50P0i>CT302/[:`80;Rh^0`0d=3@303<c<`80<30`1@0a
<C4302h^;P<0;2`/0P0_;bl3038b<P80;bl_200/;2`302XZ:P80:BTY0`0X:2P203<c<`<0L71`0`2U
YJD2092@T0<0Kfm_0P1[Jf/3079bLP<0KFe]0P2UYJD30<W9b@80Z:RX0`2e]KD30;bl_080`<300`32
`/820<C4a0<0aLG50`3Bd]820<W9b@<0/K6a0P0b<S8303@d=0<092@T0P0b<S830492@P80C4a<0`1D
E5@205eMG@<0IFEU0`1^KVh207EeM@D0MWIf0`1iNGT307alO080OWin0`1oOgl20820P0<0PH610`26
QXH208Z:RP<0S8b<0P2=SHd308n?S`<0TY:B0P2FUYH309RHV0D0UiNG0`2KVi/70:2PX0<0Y:BT0`2X
Z:P20:^[Z`<0[Zj^0P2/[:`30:ZZZP80[Jf]0`2`/;030;Bd]080]KFe0`2_[jl20:VYZ@<0ZZZZ0`2^
[Zh20;6a/@<0/k>c0P2b/[830;2`/0<0/[:b0P2d];@30;6a/@P0[Zj^1@2_[jl50;2`/0<0[Zj^0P2[
Zj/30:VYZ@80YjNW0`2SXj<309nOW`80V9RH1@2CTi<809BDU0<0Ti>C0P2ATI43092@T080SHf=0`2:
RXX308J6QPX0QHF50`22PX820820P0<0PX:20P24Q8@308F5QC@0b>3H0`1:BTX2030`<0<0;Bd]0P0c
<c<303De=@<0=3@d0P0_;bl303Xj>PD0;Bd]0`0/;2`5030`<080;Bd]0`0[:b/2030`<0P0:BTY0`0V
9RH2034a<@<0Kfm_0`2NWYh209BDU0<0L71`0P1VIVH306m_K`<0MWIf0P2VYZH30<30`080Zj^[0`2d
];@30;fm_@80_;bl0`34a<@20<;2`P<0bLW90`3@d=020<c<c0<0Z:RX0P0m?Cd302XZ:P<0:2PX0P0f
=SH30451@@80Bd];0`1DE5@205YJFP<0IVIV0`1aLG4207EeM@<0M7Ad0P1eMGD307YjNP<0OGem0P1n
OWh30820P080OWin0`21PH4308J6QP80RXZ:0`2<S8`208f=S@<0TY:B0`2@T90209BDU0D0V9RH0`2E
UID509jNWP<0XZ:R0P2OWil30:BTY0<0YjNW0P2^[Zh30:b/[080[Jf]0`2YZJT20:f][@<0[jn_0`2f
][H20;Fe]@<0[Zj^0P2XZ:P30:ZZZP<0Zj^[1@2b/[820;6a/@<0[jn_0`2f][H20;>c/`<0/K6a1@2`
/;030:f][@80[Zj^0`2_[jl20;6a/@H0/;2`0P2YZJT30:ZZZP80Y:BT0`2SXj<309nOW`80VYZJ0`2C
Ti<2096AT@D0UIFE0`2DU9@3096AT@80Ti>C0`2@T90508b<S0P0QHF50P26QXH308N7Q`<0OGem0P21
PH4308>3P`80PX:20`25QHDL0<SPf0006`38h=P30451@@80=3@d0`0U9BD202/[:`<0=3@d0`0c<c<2
034a<@<0;bl_0P0];Bd602`/;080;Rh^0`0`<30202h^;P<0;2`/1@0];Bd302XZ:P80:2PX0`0V9RH2
034a<@<0D51@0`2BTY820:>SX`<0Ph>30P1SHf<306][J`<0J6QX0P2?Shl30;Ng]`80^;Rh0`2YZJT3
0;^k^`80_Kfm0`31`L450<30`0<0c<c<0P3?cll30<[:bP80SHf=0`0b<S83034a<@80=3@d0`10@402
04M7A`<0D51@0P1JFUX306EUI@<0KFe]0P1cLg<507AdM0<0MgMg0`1kNg/207inOPP0PH610`25QHD2
08V9R@<0Rh^;0P2>SXh3092@T0<0TY:B0P2FUYH309ZJVPD0VIVI0`2LW9`20:2PX0<0XJ6Q0P2RXZ83
0:FUY@<0Z:RX0P2ZZZX30:b/[080Zj^[0`2ZZZX20:b/[0<0[jn_0`2a/K420;:b/P<0[Zj^0P2ZZZX3
0:j^[P<0/[:b0P2c/k<30;:b/P80/;2`1P2_[jl20;2`/0<0[:b/0P2YZJT30:^[Z`<0[Jf]0P2_[jl8
0;6a/@<0[jn_0P2/[:`30:RXZ080Y:BT0`2PX:0309bLW080V9RH0`2EUID209>CT`<0TY:B0P2ATI43
092@T0<0TI6A0P2BTY83092@T080SHf=0`29RHT308J6QP80Q8B40`23Ph<508B4Q0<0PH610P1mOGd3
07moO`D0PX:2=038h=P305=CD`80;bl_0`0W9bL202h^;P<0<S8b0`0f=SH202d];@<0;2`/0P0a<C43
030`<0<0:b/[0P0`<30303De=@80<30`0`0[:b/202XZ:P<0;2`/0`0Y:BT202LW9`<0:2PX0P0];Bd3
05ADE0<0Ti>C0P2RXZ8307emO@80IVIV0`1WIfL3071`L080R8R80`2k^k/20;Bd]0<0[Zj^0`2i^KT2
0;bl_0<0`/;20P2o_kl30<;2`P<0bl_;0P3>c/h30<S8b080T92@0`0d=3@3030`<080<c<c0`0o?cl2
04a<C0<0De=C1@1OGel306m_K`80LW9b0`1eMGD207UiN@<0N7Qh0`1jNWX207]kN`<0Ph>30P1oOgl3
08>3P`<0Q8B40P28R8P308Z:RP80Rh^;0`2@T90309:BTP80UiNG0`2IVIT209FEU@<0VYZJ0`2MWId5
0:2PX080XZ:R0`2WYjL50:RXZ0<0[Zj^1@2WYjL20;6a/@<0[:b/0`2d];@20;2`/0<0[Jf]0P2XZ:P3
0;6a/@D0][Jf1@2a/K430;2`/0<0[jn_0P2/[:`30:^[Z`80YJFU0`2YZJT30:j^[P80/[:b0`2^[Zh2
0;:b/P<0Zj^[0`2^[Zh20:ZZZP<0Z:RX0P2SXj<30:2PX0<0VYZJ0P2HV9P509JFUP<0T92@1@2>SXh3
092@T080TI6A0`2?Shl208b<S0<0Rh^;0`26QXH20861P@<0OWin1@27QhL307alO080Ogmo1@20P803
08B4Q1`0b>3H000K0<SPf0<0@D510P0d=3@302DU9@80:b/[0`0d=3@303<c<`80<C4a0`0_;bl202d]
;@H0;2`/0P0^;Rh3030`<080;Rh^0`0/;2`502d];@<0:RXZ0P0X:2P302HV9P80<C4a0`1@D50309:B
TP80Xj>S0`23Ph<206=SH`<0Jf][0`1XJ6P208n?S`<0]kNg0P2h^;P30:VYZ@<0^k^k0P2m_Kd30<71
`@D0`<300`3<c<`20<o?c`<0b/[:0P2=SHd3038b<P<0<C4a0P0d=3@30410@080AdM70`1@D50205YJ
FP<0IFEU0`1]KFd207=cL`D0M7Ad0`1gMgL307]kN`80OWin2021PH4308F5Q@80RHV90`2;Rh/208j>
SP<0T92@0`2BTY8209JFUP<0VYZJ1@2IVIT309bLW080X:2P0`2QXJ420::RXP<0YJFU0`2XZ:P20:ZZ
ZP<0[:b/0P2[Zj/30:ZZZP80[:b/0`2_[jl30;6a/@80/[:b0`2^[Zh20:ZZZP<0[Zj^0`2b/[820;>c
/`<0/[:b0P2`/;060:n_[`80/;2`0`2/[:`20:VYZ@<0Zj^[0`2][Jd20:n_[`P0/K6a0`2_[jl20:b/
[0<0Z:RX0P2TY:@30:2PX0<0W9bL0P2HV9P309FEU@80Ti>C0`2BTY82096AT@<0T92@0`2ATI4209:B
TP<0T92@0P2=SHd308V9R@<0QXJ60P24Q8@308>3P`D0Q8B40`21PH4207emO@<0Ogmo1@22PX8d0<SP
f0<0De=C0P0_;bl302LW9`80;Rh^0`0b<S8303Hf=P80;Bd]0`0/;2`2034a<@<0<30`0`0[:b/2030`
<0<0=CDe0P0`<30302/[:`80:RXZ0`0/;2`302TY:@809bLW0`0X:2P202d];@<0E5AD0`2CTi<20::R
XP<0OGem0P1VIVH306MWI`<0L71`0P28R8P30;^k^`80];Bd0`2^[Zh30;Vi^@80_;bl0`32`/820;no
_`<0`/;20`3;bl/20<k>cP<0b<S80P2@T90303@d=0<0<30`0P0c<c<303lo?`80C4a<0`1CDe<505mO
G`<0Kfm_0P1bLW8307EeM@80NGUi0`1hN7P307YjNP80Ng]k0`23Ph<207moO`<0Ph>30`24Q8@208R8
R0<0RXZ:0P2;Rh/3092@T0<0TY:B0P2GUiL309VIV@80UIFE0`2JVYX309fMW@D0X:2P0P2RXZ830:NW
Y`D0Z:RX0`2^[Zh50:NWY`80/K6a0`2/[:`30;Bd]080/;2`0`2][Jd20:RXZ0<0/K6a1@2f][H50;6a
/@<0/;2`0`2_[jl20:b/[0<0Zj^[0P2UYJD30:VYZ@<0[Zj^0P2b/[830:j^[P80/[:b0`2[Zj/30:j^
[P80ZZZZ0`2XZ:P20:>SX`<0X:2P0`2JVYX209RHV0D0UYJF0`2@T90508j>SP<0T92@0P2ATI4308n?
S`80S8b<0`2;Rh/308J6QP80PH610`1nOWh508N7Q`<0O7al0P1oOgl50820P0<0Q8B47038h=P001/0
b>3H0`11@D4203@d=0<09BDU0P0[:b/303@d=0<0<c<c0P0a<C4302l_;`80;Bd]1P0/;2`202h^;P<0
<30`0P0^;Rh302`/;0D0;Bd]0`0Z:RX202PX:0<09RHV0P0a<C43051@D0<0TY:B0P2SXj<308>3P`80
Hf=S0`1[Jf/306QXJ080Shn?0`2g]kL20;Rh^0<0ZJVY0`2k^k/20;fm_@<0`L711@30`<030<c<c080
clo?0`3:b/X208f=S@<0<S8b0`0a<C4203@d=0<0@4100P17AdL3051@D080FUYJ0`1UIFD306e]K@80
Lg=c1@1dM7@307MgM`<0Ng]k0P1nOWh80861P@<0QHF50P29RHT308^;R`80SXj>0`2@T90309:BTP80
UYJF0`2JVYX509VIV@<0W9bL0P2PX:030:6QX@80XZ:R0`2UYJD30:RXZ080ZZZZ0`2/[:`20:^[Z`<0
ZZZZ0P2/[:`30:n_[`<0/K6a0P2b/[830:j^[P80ZZZZ0`2^[Zh30;:b/P80/k>c0`2b/[820;2`/0H0
[jn_0P2`/;030:b/[080ZJVY0`2[Zj/30:f][@80[jn_202a/K430:n_[`80[:b/0`2XZ:P20:BTY0<0
X:2P0`2LW9`209RHV0<0UIFE0P2CTi<309:BTP80TI6A0`2@T903096AT@80TY:B0`2@T90208f=S@<0
RHV90`26QXH208B4Q0<0Ph>31@24Q8@30861P@80OGem0`1oOgl508:2PS@0b>3H0`1CDe<202l_;`<0
9bLW0P0^;Rh3038b<P<0=SHf0P0];Bd302`/;080<C4a0`0`<30302/[:`80<30`0`0e=CD2030`<0<0
:b/[0P0Z:RX302`/;0<0:BTY0P0W9bL302PX:080;Bd]0`1DE5@309>CT`80XZ:R0`1mOGd206IVIP<0
IfMW0`1`L70208R8R0<0^k^k0P2d];@30:j^[P<0^KVi0P2l_;`30<;2`P80_kno0`32`/830<_;b`80
c/k>0`38b<P2092@T0<0=3@d0`0`<30203<c<`<0?clo0P1<C4`305=CD`D0GemO0`1_Kfl2079bLP<0
MGEe0P1iNGT307QhN0<0NWYj0P1kNg/308>3P`80Ogmo0`23Ph<308B4Q080R8R80`2:RXX208^;R`<0
T92@0`2BTY8209NGU`<0VIVI0P2EUID309ZJVP<0WIfM1@2PX:020::RXP<0YjNW1@2XZ:P30:j^[PD0
YjNW0P2a/K430:b/[0<0];Bd0P2`/;030:f][@80Z:RX0`2a/K450;Jf]PD0/K6a0`2`/;030:n_[`80
[:b/0`2[Zj/20:FUY@<0ZJVY0`2^[Zh20;:b/P<0[Zj^0P2b/[830:^[Z`<0[Zj^0P2ZZZX30:RXZ080
Xj>S0`2PX:0309ZJVP80V9RH1@2FUYH3092@T0D0SXj>0`2@T902096AT@<0Shn?0P2<S8`308^;R`<0
QXJ60P21PH4307inOPD0QhN70`1lO7`207moO`D0P8200`24Q8@L0<SPf0006`38h=P303/k>`80;Rh^
0`0Q8B4202TY:@H0<c<c0P0`<30302`/;080:BTY0`0Z:RX302`/;0X0;Bd]1@0^;Rh302/[:`80:BTY
0`0X:2P203<c<`<0=3@d0`1fMWH20:ZZZP<0V9RH0P1QHF4306MWI`<0JFUY0P1iNGT309jNWP80a/K6
0`2QXJ430;Ng]`80^KVi0`2o_kl20;jn_P<0_Kfm0`34a<@20<_;b`<0clo?0P35aLD307QhN0D0<C4a
0`0o?cl204I6AP<0CTi>0P1IFET306ATI0<0K6a/0P1aLG4307=cL`80M7Ad0`1gMgL307YjNP80OWin
1@22PX830861P@<0Q8B40P28R8P308^;R`80SXj>0`2@T90309>CT`80UiNG202KVi/309fMW@80WinO
0`2QXJ420:>SX`<0YZJV0`2XZ:P50:VYZ@80ZZZZ0`2[Zj/20:b/[0<0[Jf]1@2^[Zh50:f][@<0/K6a
0`2e]KD20;>c/`<0[jn_0P2^[Zh30:f][@<0[:b/0P2[Zj/30:RXZ080YZJV0`2XZ:P30:b/[080[jn_
1@2a/K430;2`/0<0[jn_0P2][Jd30:NWY`80XJ6Q0`2MWId309VIV@80V9RH0`2GUiL209>CT`<0Shn?
0P2<S8`308^;R`<0Shn?0P2CTi<3092@T080S8b<0`28R8P308F5Q@80Ph>30`21PH4208:2PP<0Ph>3
0`20P80207alO0<0OGem1@1oOgld0<SPf0<0@T920P0W9bL302DU9@80:2PX0`0d=3@303<c<`80=3@d
0`0Y:BT202HV9P<0;bl_0`0[:b/202XZ:P<0:BTY0P0_;bl502d];@<0;Rh^0`0[:b/202TY:@<0:2PX
0P0];Bd30492@P<0MgMg0P2LW9`309RHV080KVi^0`1QHF4306YZJP80MWIf0`2TY:@20;jn_P<0YjNW
0`2a/K420;bl_0<0_kno0P2k^k/30;fm_@<0a/K60P3<c<`30<g=c@80`L710`1jNWX303Hf=P80=3@d
0`0m?Cd204M7A`<0Bd];0P1FEUH306MWI`<0KFe]0P1bLW83071`L080MGEe0`1hN7P307alO080Ng]k
0`23Ph<20861P@<0P8200`24Q8@208N7Q`<0S8b<0P2@T90308n?S`<0U9BD0P2HV9P309bLW080UYJF
0`2KVi/309fMW@80WinO0`2PX:020:FUY@<0Y:BT1@2XZ:P30:b/[080YjNW1@2][Jd30:b/[0<0/;2`
0P2][Jd30:j^[P80[Jf]0`2`/;050;:b/P<0[Jf]0P2_[jl30:b/[0<0ZZZZ0P2/[:`30:f][@80Z:RX
0`2TY:@30:f][@D0/K6a0P2b/[830:j^[P<0/[:b0P2/[:`30:NWY`80XZ:R1P2KVi/209RHV0<0UIFE
0P2CTi<3092@T080RXZ:0`2>SXh308f=S@80U9BD0`2?Shl208^;R`<0R8R80`24Q8@208N7Q`<0PH61
0P22PX8308N7Q`<0O7al0P20P80307YjNP80Ogmo0`23Ph<L0<SPf0006`38h=P303/k>`80;Rh^0`0Q
8B4202TY:@H0<c<c0P0`<30302`/;080:BTY0`0Z:RX302`/;0X0;Bd]1@0^;Rh302/[:`80:BTY0`0X
:2P203<c<`<0=3@d0`1fMWH20:ZZZP<0V9RH0P1QHF4306MWI`<0JFUY0P1iNGT309jNWP80a/K60`2Q
XJ430;Ng]`80^KVi0`2o_kl20;jn_P<0_Kfm0`34a<@20<_;b`<0clo?0P35aLD307QhN0D0<C4a0`0o
?cl204I6AP<0CTi>0P1IFET306ATI0<0K6a/0P1aLG4307=cL`80M7Ad0`1gMgL307YjNP80OWin1@22
PX830861P@<0Q8B40P28R8P308^;R`80SXj>0`2@T90309>CT`80UiNG202KVi/309fMW@80WinO0`2Q
XJ420:>SX`<0YZJV0`2XZ:P50:VYZ@80ZZZZ0`2[Zj/20:b/[0<0[Jf]1@2^[Zh50:f][@<0/K6a0`2e
]KD20;>c/`<0[jn_0P2^[Zh30:f][@<0[:b/0P2[Zj/30:RXZ080YZJV0`2XZ:P30:b/[080[jn_1@2a
/K430;2`/0<0[jn_0P2][Jd30:NWY`80XJ6Q0`2MWId309VIV@80V9RH0`2GUiL209>CT`<0Shn?0P2<
S8`308^;R`<0Shn?0P2CTi<3092@T080S8b<0`28R8P308F5Q@80Ph>30`21PH4208:2PP<0Ph>30`20
P80207alO0<0OGem1@1oOgld0<SPf0<0@T920P0W9bL302DU9@80:2PX0`0d=3@303<c<`80=3@d0`0Y
:BT202HV9P<0;bl_0`0[:b/202XZ:P<0:BTY0P0_;bl502d];@<0;Rh^0`0[:b/202TY:@<0:2PX0P0]
;Bd30492@P<0MgMg0P2LW9`309RHV080KVi^0`1QHF4306YZJP80MWIf0`2TY:@20;jn_P<0YjNW0`2a
/K420;bl_0<0_kno0P2k^k/30;fm_@<0a/K60P3<c<`30<g=c@80`L710`1jNWX303Hf=P80=3@d0`0m
?Cd204M7A`<0Bd];0P1FEUH306MWI`<0KFe]0P1bLW83071`L080MGEe0`1hN7P307alO080Ng]k0`23
Ph<20861P@<0P8200`24Q8@208N7Q`<0S8b<0P2@T90308n?S`<0U9BD0P2HV9P309bLW080UYJF0`2K
Vi/309fMW@80WinO0`2PX:020:FUY@<0Y:BT1@2XZ:P30:b/[080YjNW1@2][Jd30:b/[0<0/;2`0P2]
[Jd30:j^[P80[Jf]0`2`/;050;:b/P<0[Jf]0P2_[jl30:b/[0<0ZZZZ0P2/[:`30:f][@80Z:RX0`2T
Y:@30:f][@D0/K6a0P2b/[830:j^[P<0/[:b0P2/[:`30:NWY`80XZ:R1P2KVi/209RHV0<0UIFE0P2C
Ti<3092@T080RXZ:0`2>SXh308f=S@80U9BD0`2?Shl208^;R`<0R8R80`24Q8@208N7Q`<0PH610P22
PX8308N7Q`<0O7al0P20P80307YjNP80Ogmo0`23Ph<L0<SPf0006`38h=P303De=@80;bl_0`0Y:BT2
02l_;`<0=SHf0`0b<S8202h^;P<0;Bd]0P0/;2`602XZ:P80;2`/0`0^;Rh7030`<0<0;bl_1@0^;Rh3
02XZ:P80;Bd]0`0/;2`305=CD`80TI6A0`2PX:0207QhN0<0K6a/0`1ZJVX206e]K@<0TY:B0P2j^[X3
0;Fe]@<0ZJVY0P2c/k<30;jn_P80_kno0`2n_[h30<?3``80alO70`38b<P20;no_`<0bLW90`1QHF42
034a<@<0>3Ph0P12@T83051@D080F5QH0`1PH60306QXJ080Kfm_0`1bLW8207AdM0<0N7Qh0`1kNg/2
07inOP<0P8200P21PH4308:2PP<0QXJ60P2;Rh/308b<S080SHf=0`2@T90309BDU080UiNG0`2IVIT2
09^KV`<0W9bL0`2MWId209jNWP<0XJ6Q0P2UYJD30:NWY`<0Z:RX0P2VYZH30:FUY@80YjNW0`2ZZZX2
0:b/[0<0[Zj^1@2_[jl30:f][@80Zj^[0`2/[:`30:f][@80[:b/202[Zj/30:b/[080[Jf]0`2[Zj/2
0:ZZZPH0ZJVY0P2ZZZX30:b/[0D0[Jf]0`2/[:`20:^[Z`<0YjNW0P2RXZ8309jNWP<0Vi^K0P2IVIT3
09NGU`80TI6A0`2<S8`208Z:RP<0Rh^;0`2?Shl2096AT@<0SHf=0P28R8P308J6QP<0QHF50P23Ph<8
08:2PP<0PH610P1oOgl80820P3@0b>3H0`0_;bl202`/;0D0;Bd]0`0f=SH303<c<`D0;Rh^0P0/;2`3
02d];@<0:2PX0P0`<303034a<@80;2`/0`0d=3@2034a<@<0=cLg0`0/;2`202/[:`<0<S8b0P0/;2`3
02TY:@<0DU9B0P2;Rh/30:FUY@80OWin0`1YJFT306MWI`80L71`0`2<S8`20<30`0<0/[:b0`2[Zj/2
0;Fe]@<0_;bl0P2n_[h30;fm_@<0`/;20P36a/H50<W9b@<0^k^k0`1IFET203Hf=P<0=cLg0P15ADD3
055AD@80DU9B0`1QHF4306][J`80L71`0`1aLG4206m_K`<0NGUi0`1nOWh207YjNP<0Q8B41@22PX83
08Z:RPD0Rh^;1@2=SHd309:BTP80UiNG0`2MWId209ZJVP<0XJ6Q0`2KVi/509nOW`80XZ:R1P2YZJT2
0:BTY0D0YJFU0`2ZZZX20:f][@<0ZJVY0`2a/K450:f][@80[:b/0`2[Zj/30:f][@80Zj^[0`2/[:`2
0:f][@<0Zj^[0`2ZZZX20:b/[0<0[Jf]0P2XZ:P30:VYZ@<0Z:RX1@2YZJT50;2`/0<0[Jf]0P2XZ:P3
0:b/[080X:2P0`2LW9`509ZJVP<0UIFE0P2DU9@308f=S@80R8R81P2>SXh209JFUP<0RHV90P2;Rh/3
08V9R@<0P8200P23Ph<308:2PPD0PH610`1jNWX208J6QP<0NWYj0P1nOWh308N7Qa`0b>3H000K0<SP
f0<0=CDe0P0_;bl302TY:@80;bl_0`0f=SH3038b<P80;Rh^0`0];Bd202`/;0H0:RXZ0P0/;2`302h^
;PL0<30`0`0_;bl502h^;P<0:RXZ0P0];Bd302`/;0<0De=C0P2ATI430:2PX080N7Qh0`1/K6`306YZ
JP80KFe]0`2BTY820;Zj^P<0]KFe0`2YZJT20;>c/`<0_[jn0P2o_kl30;jn_P<0`l?30P37alL30<S8
b080_kno0`39bLT3065QH@80<C4a0`0h>3P20492@P<0D51@0P1HF5P3061PH0<0J6QX0P1_Kfl3079b
LP80M7Ad0`1hN7P307]kN`80OWin0`20P8020861P@<0PX:20`26QXH208^;R`<0S8b<0P2=SHd3092@
T0<0U9BD0P2GUiL309VIV@80Vi^K0`2LW9`309fMW@80WYjN0`2QXJ420:FUY@<0YjNW0`2XZ:P20:JV
YP<0YJFU0P2WYjL30:ZZZP80[:b/0`2^[Zh50:n_[`<0[Jf]0P2[Zj/30:b/[0<0[Jf]0P2/[:`80:^[
Z`<0[:b/0P2][Jd30:^[Z`80ZZZZ1P2YZJT20:ZZZP<0[:b/1@2][Jd30:b/[080Zj^[0`2WYjL20::R
XP<0WYjN0`2KVi/209VIV@<0UiNG0P2ATI4308b<S080RXZ:0`2;Rh/308n?S`80TI6A0`2=SHd208R8
R0<0QXJ60`25QHD208>3P`P0PX:20`21PH4207moO`P0P820=038h=P302l_;`80;2`/1@0];Bd303Hf
=P<0<c<c1@0^;Rh202`/;0<0;Bd]0`0X:2P2030`<0<0<C4a0P0/;2`303@d=080<C4a0`0g=cL302`/
;080:b/[0`0b<S8202`/;0<0:BTY0`1BDU8208^;R`<0YJFU0P1nOWh306UYJ@<0IfMW0P1`L70308b<
S080`<300`2b/[830:^[Z`80]KFe0`2l_;`20;jn_P<0_Kfm0`32`/820<K6aPD0bLW90`2k^k/305UI
F@80=SHf0`0g=cL204E5A@<0DE5A0P1BDU83065QH@<0Jf][0P1`L703075aL@80Kfm_0`1iNGT307in
OP80NWYj0`24Q8@508:2PP<0RXZ:1@2;Rh/508f=S@<0TY:B0P2GUiL309fMW@80VYZJ0`2QXJ4309^K
V`D0WinO0P2RXZ860:VYZ@80Y:BT1@2UYJD30:ZZZP80[Jf]0`2YZJT30;6a/@D0[Jf]0P2/[:`30:^[
Z`<0[Jf]0P2[Zj/30:b/[080[Jf]0`2[Zj/30:ZZZP80[:b/0`2][Jd20:RXZ0<0ZJVY0`2XZ:P50:VY
Z@D0/;2`0`2][Jd20:RXZ0<0[:b/0P2PX:0309bLW0D0VYZJ0`2EUID209BDU0<0SHf=0P28R8P608j>
SP80UYJF0`29RHT208^;R`<0RHV90`20P80208>3P`<0PX:21@21PH4307YjNP80QXJ60`1jNWX207in
OP<0QhN77038h=P001/0b>3H0`0e=CD202l_;`<0:BTY0P0_;bl303Hf=P<0<S8b0P0^;Rh302d];@80
;2`/1P0Z:RX202`/;0<0;Rh^1`0`<30302l_;`D0;Rh^0`0Z:RX202d];@<0;2`/0`1CDe<2096AT@<0
X:2P0P1hN7P306a/K0<0JVYZ0P1]KFd309:BTP80^[Zj0`2e]KD30:VYZ@80/k>c0`2n_[h20;no_`<0
_[jn0`33`l<20<O7a`<0b<S80P2o_kl30<W9b@<0HF5Q0P0a<C4303Ph>080@T920`1@D50205QHF0<0
H61P0`1XJ6P206m_K`<0LW9b0P1dM7@307QhN0<0Ng]k0P1nOWh30820P080PH610`22PX8308J6QP80
Rh^;0`2<S8`208f=S@<0T92@0`2DU9@209NGU`<0VIVI0P2KVi/309bLW0<0WIfM0P2NWYh30:6QX@80
YJFU0`2WYjL30:RXZ080YZJV0`2UYJD20:NWY`<0ZZZZ0P2/[:`30:j^[PD0[jn_0`2][Jd20:^[Z`<0
[:b/0`2][Jd20:b/[0P0Zj^[0`2/[:`20:f][@<0Zj^[0P2ZZZX60:VYZ@80ZZZZ0`2/[:`50:f][@<0
[:b/0P2[Zj/30:NWY`80XZ:R0`2NWYh309^KV`80VIVI0`2GUiL2096AT@<0S8b<0P2:RXX308^;R`<0
Shn?0P2ATI4308f=S@80R8R80`26QXH308F5Q@80Ph>32022PX830861P@80Ogmo2020P80d0<SPf0<0
;bl_0P0/;2`502d];@<0=SHf0`0c<c<502h^;P80;2`/0`0];Bd302PX:080<30`0`0a<C4202`/;0<0
=3@d0P0a<C4303Lg=`<0;2`/0P0[:b/3038b<P80;2`/0`0Y:BT3059BDP80Rh^;0`2UYJD207inOP<0
JFUY0`1WIfL2071`L0<0S8b<0P30`<030;:b/P<0Zj^[0P2e]KD30;bl_080_[jn0`2m_Kd30<;2`P80
a/K61@39bLT30;^k^`<0FEUI0P0f=SH303Lg=`80ADE50`1ADE42059BDP<0HF5Q0`1[Jf/2071`L0<0
LG5a0P1_Kfl307UiN@<0OWin0P1jNWX308B4Q0D0PX:20`2:RXX508^;R`D0SHf=0`2BTY8209NGU`<0
WIfM0P2JVYX30:6QX@<0Vi^K1@2OWil20::RXPH0ZJVY0P2TY:@50:FUY@<0ZZZZ0P2][Jd30:VYZ@<0
/K6a1@2][Jd20:b/[0<0Zj^[0`2][Jd20:^[Z`<0[:b/0P2][Jd30:^[Z`<0ZZZZ0P2/[:`30:f][@80
Z:RX0`2YZJT30:RXZ0D0ZJVY1@2`/;030:f][@80Z:RX0`2/[:`20:2PX0<0W9bL1@2JVYX309FEU@80
U9BD0`2=SHd208R8R0H0SXj>0P2FUYH308V9R@80Rh^;0`29RHT30820P080Ph>30`22PX850861P@<0
NWYj0P26QXH307YjNP80OWin0`27QhLL0<SPf0006`38h=P8034a<@80=CDe0`0g=cL3038b<P80;2`/
0`0];Bd202l_;`<0:b/[0`0X:2P202`/;0<0<C4a1@0c<c<2038b<P<0<30`1@0b<S8302d];@80:BTY
0`0[:b/303Hf=P80KFe]0`2NWYh2096AT@<0MgMg0`1[Jf/206IVIP<0QhN70P2VYZH30<K6aP<0WYjN
0P2^[Zh30;bl_0D0_kno0`30`<020<71`@D0aLG50`3@d=030;>c/`80A4A40`0k>c/203hn?P<0DE5A
0P1FEUH305aLG0<0IFEU0P1]KFd3075aL@80MGEe0`1hN7P307alO080OGem0`1oOgl20820P0<0PX:2
0`28R8P208j>SP<0SHf=0P2<S8`3092@T0<0UIFE0P2FUYH309RHV080Vi^K202MWId30::RXP80YZJV
0`2XZ:P30:VYZ@80Y:BT0`2QXJ420:BTY0<0ZJVY0P2/[:`80:n_[`<0[:b/0P2XZ:P30:JVYP<0YJFU
0P2VYZH30:NWY`80Z:RX0`2YZJT30:b/[0D0[jn_0P2^[Zh30:ZZZPD0YZJV0`2WYjL20:VYZ@H0ZZZZ
0P2YZJT30:JVYP80Y:BT0`2QXJ4309jNWP80VYZJ0`2EUID208j>SP<0RHV90P2:RXX308b<S0<0SXj>
0P2?Shl308^;R`80QXJ60`25QHD308B4Q0D0Ph>30P22PX830861P@<0PX:20P23Ph<808:2PS@0b>3H
0`0a<C4203@d=0<0<C4a0P0c<c<303Lg=`<0=SHf0P0^;Rh302/[:`80<30`0`0/;2`302PX:080;bl_
0`0b<S8202l_;`<0=CDe0P0c<c<302d];@<0;Rh^1@0a<C4502LW9`<0>SXj0P1_Kfl309JFUP80Vi^K
0`1dM7@306a/K080JFUY0`22PX820:b/[0<0_[jn0`2PX:020;>c/`<0^;Rh0P2o_kl30<30`0<0_[jn
0P34a<@30<?3``80alO70`3<c<`30;2`/080C4a<0`0i>CT204=3@`<0Bd];0P1GEeL305mOG`<0I6AT
1@1`L70207IfMP<0O7al0`1jNWX207UiN@P0Ogmo0`2<S8`508^;R`80RXZ:1P2CTi<209JFUP<0V9RH
0P2GUiL309jNWP<0WIfM1@2OWil20:NWY`<0ZZZZ0`2YZJT20:6QX@<0Xj>S0P2RXZ830:ZZZP80[:b/
0`2^[Zh30;Bd]080[:b/0`2[Zj/20:VYZ@<0Xj>S0`2VYZH20:FUY@<0Z:RX0P2VYZH30:VYZ@<0[:b/
1@2^[Zh20:f][@<0[:b/1@2XZ:P30:ZZZP80YZJV0`2XZ:P30:b/[080Z:RX0`2ZZZX20:>SX`<0XZ:R
0`2PX:0209VIV@<0U9BD0P2>SXh308Z:RP80R8R8202=SHd308Z:RP80QHF50`23Ph<308N7Q`80PX:2
0`21PH4208>3P`<0Q8B40`1oOgl208F5Q@<0P8200P1oOgl308V9RA`0b>3H000K0<SPf0P0<C4a0P0e
=CD303Lg=`<0<S8b0P0/;2`302d];@80;bl_0`0[:b/302PX:080;2`/0`0a<C4503<c<`80<S8b0`0`
<305038b<P<0;Bd]0P0Y:BT302/[:`<0=SHf0P1]KFd309jNWP80TI6A0`1gMgL306][J`80IVIV0`27
QhL20:JVYP<0a/K60`2NWYh20:j^[P<0_;bl1@2o_kl30<30`080`L711@35aLD30=3@d0<0/k>c0P14
A4@303/k>`80?Shn0`1ADE4205IFEP<0G5aL0`1UIFD206e]K@<0LG5a0P1eMGD307QhN0<0O7al0P1m
OGd307moO`80P8200`22PX8308R8R080SXj>0`2=SHd208b<S0<0T92@0`2EUID209JFUP<0V9RH0P2K
Vi/809fMW@<0XZ:R0P2VYZH30:RXZ0<0ZJVY0P2TY:@30:6QX@80Y:BT0`2YZJT20:b/[0P0[jn_0`2/
[:`20:RXZ0<0YZJV0`2UYJD20:JVYP<0YjNW0P2XZ:P30:VYZ@<0[:b/1@2_[jl20:j^[P<0ZZZZ1@2V
YZH30:NWY`80ZJVY1P2ZZZX20:VYZ@<0YZJV0P2TY:@30:6QX@<0WYjN0P2JVYX309FEU@80SXj>0`29
RHT208Z:RP<0S8b<0`2>SXh208n?S`<0Rh^;0P26QXH308F5Q@<0Q8B41@23Ph<208:2PP<0PH610`22
PX8208>3P`P0PX:2=038h=P3034a<@80=3@d0`0a<C4203<c<`<0=cLg0`0f=SH202h^;P<0:b/[0P0`
<30302`/;0<0:2PX0P0_;bl3038b<P80;bl_0`0e=CD203<c<`<0;Bd]0`0^;Rh5034a<@D09bLW0`0j
>SX206m_K`<0UYJF0P2KVi/307AdM0<0K6a/0P1YJFT308:2PP80[:b/0`2n_[h30:2PX080/k>c0`2h
^;P20;no_`<0`<300`2n_[h20<C4a0<0`l?30P37alL30<c<c0<0/;2`0P1<C4`303Ti>@80@d=30`1;
Bd/205MGE`<0GemO0`1TI6@5071`L080MWIf0`1lO7`307YjNP80NGUi201oOgl308b<S0D0Rh^;0P2:
RXX609>CT`80UYJF0`2HV9P209NGU`<0WYjN0`2MWId509nOW`80YjNW0`2ZZZX30:VYZ@80XJ6Q0`2S
Xj<20::RXP<0ZZZZ0P2/[:`30:j^[P<0];Bd0P2/[:`30:^[Z`80ZJVY0`2SXj<30:JVYP80YJFU0`2X
Z:P20:JVYP<0ZJVY0`2/[:`50:j^[P80[Jf]0`2/[:`50:RXZ0<0ZZZZ0P2VYZH30:RXZ0<0[:b/0P2X
Z:P30:ZZZP80Xj>S0`2RXZ830:2PX080VIVI0`2DU9@208j>SP<0RXZ:0P28R8P808f=S@<0RXZ:0P25
QHD308>3P`<0QhN70P22PX830861P@80Ph>30`24Q8@307moO`80QHF50`20P80207moO`<0RHV97038
h=P001/0b>3H200a<C4203De=@<0=cLg0`0b<S8202`/;0<0;Bd]0P0_;bl302/[:`<0:2PX0P0/;2`3
034a<@D0<c<c0P0b<S83030`<0D0<S8b0`0];Bd202TY:@<0:b/[0`0f=SH206e]K@<0WYjN0P2ATI43
07MgM`<0Jf][0P1VIVH308N7Q`80YZJV0`36a/H309jNWP80[Zj^0`2l_;`50;no_`<0`<300P31`L45
0<G5a@<0d=3@0`2c/k<204A4A0<0>c/k0P0n?Sh3055AD@80EUIF0`1LG5`306EUI@80KFe]0`1aLG42
07EeM@<0N7Qh0`1lO7`207emO@<0Ogmo0P20P80308:2PP<0R8R80P2>SXh308f=S@80S8b<0`2@T903
09FEU@80UYJF0`2HV9P209^KV`P0WIfM0`2RXZ820:JVYP<0Z:RX0`2YZJT20:BTY0<0XJ6Q0P2TY:@3
0:VYZ@80[:b/202_[jl30:b/[080Z:RX0`2VYZH30:FUY@80YZJV0`2WYjL20:RXZ0<0ZJVY0`2/[:`5
0:n_[`80[Zj^0`2ZZZX50:JVYP<0YjNW0P2YZJT60:ZZZP80ZJVY0`2VYZH20:BTY0<0XJ6Q0`2NWYh2
09ZJVP<0UIFE0P2>SXh308V9R@80RXZ:0`2<S8`308j>SP80Shn?0`2;Rh/208J6QP<0QHF50`24Q8@5
08>3P`80PX:20`21PH4308:2PP80Ph>32022PX8d0<SPf0<0<C4a0P0d=3@3034a<@80<c<c0`0g=cL3
03Hf=P80;Rh^0`0[:b/2030`<0<0;2`/0`0X:2P202l_;`<0<S8b0P0_;bl303De=@80<c<c0`0];Bd3
02h^;PD0<C4a1@0W9bL303Xj>P80Kfm_0`2FUYH209^KV`<0M7Ad0`1/K6`206UYJ@<0PX:20P2/[:`3
0;jn_P<0X:2P0P2c/k<30;Rh^080_kno0`30`<030;jn_P80a<C40`33`l<20<O7a`<0c<c<0`2`/;02
04a<C0<0>CTi0P13@d<304];B`80EeMG0`1OGel306ATI0D0L71`0P1fMWH307alO0<0NWYj0P1iNGT8
07moO`<0S8b<1@2;Rh/208Z:RPH0Ti>C0P2FUYH309RHV080UiNG0`2NWYh309fMW@D0WinO0P2WYjL3
0:ZZZP<0ZJVY0P2QXJ430:>SX`80XZ:R0`2ZZZX20:b/[0<0[Zj^0`2d];@20:b/[0<0Zj^[0P2YZJT3
0:>SX`<0YZJV0P2UYJD30:RXZ080YZJV0`2YZJT30:b/[0D0[Zj^0P2][Jd30:b/[0D0Z:RX0`2ZZZX2
0:JVYP<0Z:RX0`2/[:`20:RXZ0<0ZZZZ0P2SXj<30::RXP<0X:2P0P2IVIT309BDU080SXj>0`2:RXX2
08R8R0P0SHf=0`2:RXX208F5Q@<0Ph>30`27QhL208:2PP<0PH610P23Ph<308B4Q0<0Ogmo0P25QHD3
0820P080Ogmo0`29RHTL0<SPf0006`38h=P302l_;`80<30`0`0a<C4503<c<`<0<30`1@0/;2`202d]
;@<0:b/[0`0Z:RX202h^;P<0<c<c0P0d=3@303<c<`80<S8b0`0a<C43038b<P80<c<c0`0^;Rh502XZ
:P<0<C4a0P1:BTX308N7Q`80X:2P0`28R8P3065QH@80I6AT0`1fMWH208n?S`<0/K6a0`2YZJT20:n_
[`<0][Jf0P2j^[X30;fm_@<0_kno0P30`<030<G5a@80alO70`3De=@30;Zj^P80YjNW0`1@D502038b
<P<0ATI60P1ADE4305aLG0<0IFEU0P1/K6`3075aL@80M7Ad0`1fMWH307UiN@80O7al0`1oOgl208:2
PP<0QHF50`28R8P208Z:RP<0S8b<0P2=SHd3096AT@<0UIFE0P2GUiL309RHV080Vi^K1P2NWYh209nO
W`<0XZ:R0P2VYZH30:NWY`<0Z:RX0P2TY:@30:6QX@80Y:BT0`2YZJT20:b/[0<0[jn_0`2^[Zh20:b/
[0<0ZJVY2P2VYZH50:NWY`<0Z:RX0`2/[:`20;2`/0<0[jn_0P2][Jd30:b/[0<0Zj^[0P2YZJT30:RX
Z0D0YjNW0`2YZJT20:^[Z`<0Z:RX0P2UYJD30:BTY0<0Xj>S0P2LW9`309BDU080SXj>1@2:RXX308^;
R`<0SXj>0P2ATI4308f=S@80R8R80`27QhL308J6QP80Q8B40`23Ph<208:2PPH0PH612P22PX8d0<SP
f0<0<c<c1@0`<30203<c<`<0=3@d0`0a<C4202HV9PD0:b/[0`0/;2`302PX:080;2`/0`0a<C4203De
=@<0<C4a0P0f=SH303De=@<0<S8b0P0d=3@303De=@80:RXZ0`0^;Rh302`/;080D51@0`22PX820:>S
X`<0Ogmo0`1WIfL206EUI@<0KVi^0P2>SXh30;Vi^@<0Xj>S0P2a/K430;Jf]P80_;bl0`2k^k/30;fm
_@80`<300`32`/820<S8b0H0c<c<0P2TY:@30410@080?clo0`17AdL2055AD@<0G5aL0`1OGel206a/
K0<0L71`0P1dM7@307QhN0<0Ng]k0P1lO7`308>3P`80OGem0`26QXH308f=S@80RHV90`2<S8`208j>
SP<0UIFE0`2FUYH709RHV0<0WIfM0`2OWil20:2PX0<0WYjN0P2XZ:P30:VYZ@<0YjNW0P2SXj<30:FU
Y@80XZ:R0`2ZZZX50:b/[0<0/[:b0P2[Zj/30:VYZ@80Z:RX0`2SXj<30:JVYP80ZZZZ0`2TY:@20:NW
Y`<0Z:RX0`2^[Zh20;6a/@<0/;2`0P2^[Zh30:b/[0<0YJFU0P2YZJT80:JVYPD0YjNW0`2VYZH20:6Q
X@<0YZJV0`2KVi/209nOW`<0UIFE0P2=SHd308R8R080RHV90`2;Rh/308j>SP80TY:B0`2@T90208Z:
RP<0QXJ60`27QhL208F5Q@<0Q8B40P26QXH307moO`<0PX:21@21PH4208B4Q0<0R8R87038h=P001/0
b>3H0`0_;bl2030`<0<0<C4a1@0c<c<3030`<0D0;2`/0P0];Bd302/[:`<0:RXZ0P0^;Rh303<c<`80
=3@d0`0c<c<2038b<P<0<C4a0`0b<S8203<c<`<0;Rh^1@0Z:RX3034a<@80BTY:0`27QhL20:2PX0<0
R8R80`1QHF4206ATI0<0MWIf0P2?Shl30;6a/@<0ZJVY0P2_[jl30;Jf]P80^[Zj0`2m_Kd30;no_`80
`<300`35aLD20<O7a`<0e=CD0`2j^[X20:NWY`<0D51@0P0b<S8304I6AP80DE5A0`1LG5`306EUI@80
K6a/0`1aLG4207AdM0<0MWIf0`1iNGT207alO0<0Ogmo0P22PX8308F5Q@<0R8R80P2:RXX308b<S080
SHf=0`2ATI4309FEU@80UiNG0`2HV9P209^KV`H0WYjN0P2OWil30::RXP80YZJV0`2WYjL30:RXZ080
Y:BT0`2QXJ420:BTY0<0ZJVY0P2/[:`30:n_[`<0[Zj^0P2/[:`30:VYZ@X0YZJV1@2WYjL30:RXZ0<0
[:b/0P2`/;030:n_[`80[Jf]0`2/[:`30:^[Z`80ZJVY0`2XZ:P50:NWY`<0ZJVY0P2[Zj/30:RXZ080
YJFU0`2TY:@30:>SX`80W9bL0`2DU9@208j>SPD0RXZ:0`2;Rh/308j>SP80TI6A0`2=SHd208R8R0<0
QhN70`26QXH208B4Q0<0Ph>30P22PX860861P@X0PX:2=038h=P303<c<`D0<30`0P0c<c<303@d=0<0
<C4a0P0V9RH502/[:`<0;2`/0`0X:2P202`/;0<0<C4a0P0e=CD3034a<@80=SHf0`0e=CD3038b<P80
=3@d0`0e=CD202XZ:P<0;Rh^0`0/;2`2051@D0<0PX:20P2SXj<307moO`<0IfMW0P1UIFD306i^KP80
SXj>0`2i^KT30:>SX`80/K6a0`2f][H20;bl_0<0^k^k0`2m_Kd20<30`0<0`/;20P38b<P60<c<c080
Y:BT0`10@40203lo?`<0AdM70P1ADE4305aLG0<0GemO0P1/K6`3071`L080M7Ad0`1hN7P307]kN`80
O7al0`23Ph<207emO@<0QXJ60`2=SHd208V9R@<0S8b<0P2>SXh309FEU@<0UYJF1`2HV9P309fMW@<0
WinO0P2PX:0309jNWP80Z:RX0`2YZJT30:NWY`80Xj>S0`2UYJD20::RXP<0ZZZZ1@2/[:`30;:b/P80
Zj^[0`2YZJT20:RXZ0<0Xj>S0`2VYZH20:ZZZP<0Y:BT0P2WYjL30:RXZ0<0[Zj^0P2a/K430;2`/080
[Zj^0`2/[:`30:FUY@80ZJVY202VYZH50:NWY`<0YZJV0P2QXJ430:JVYP<0Vi^K0P2OWil309FEU@80
SHf=0`28R8P208V9R@<0Rh^;0`2>SXh209:BTP<0T92@0P2:RXX308J6QP<0QhN70P25QHD308B4Q080
QXJ60`1oOgl308:2PPD0PH610P24Q8@308R8R1`0b>3H000K0<SPf0P0;Rh^1@0_;bl302h^;P80;2`/
0`0[:b/202XZ:P<0:b/[0`0];Bd2034a<@<0=CDe0P0d=3@303<c<`X0<S8b0`0^;Rh202`/;0<0:RXZ
0`0b<S8202`/;0<0JFUY0P2RXZ8309JFUP<0GemO0P1VIVH306QXJ080NGUi0`2FUYH30;Fe]@80/k>c
0`2_[jl20;Bd]0<0^[Zj0`2m_Kd20<30`0<0`l?30P37alL60=;BdP80aLG50`2<S8`203lo?`<0@410
0P18B4P305aLG0<0I6AT0P1ZJVX306m_K`80Lg=c0`1dM7@307EeM@80NWYj0`1oOgl208B4Q0<0R8R8
0`27QhL208J6QP<0RXZ:0P2@T90309>CT`<0UYJF0P2GUiL309RHV080Vi^K0`2NWYh509nOW`<0XZ:R
0P2UYJD60:JVYP80Y:BT0`2RXZ820:BTY0<0YjNW0P2ZZZX30:f][@<0ZZZZ0P2WYjL30:BTY080Xj>S
0`2UYJD30:RXZ080YZJV1@2UYJD30:NWY`<0Zj^[0P2_[jl30:b/[080ZJVY0`2/[:`30:n_[`80[Jf]
0`2YZJT20:JVYP<0YJFU0`2YZJT20:f][@<0ZJVY0P2UYJD60:NWY`80WYjN0`2CTi<208j>SP<0Rh^;
1@29RHT308f=S@80TI6A0`2?Shl208^;R`<0RHV90`28R8P208F5Q@<0Ph>31@22PX830861P@80P820
0`21PH4508:2PS@0b>3H0`0b<S8202/[:`<0;bl_0P0b<S83030`<0<0;2`/0P0`<30302h^;P809bLW
0`0`<30302h^;P80<C4a0`0b<S8203lo?`/0<30`0P0c<c<302/[:`D0:RXZ0`0/;2`203Ph>0<0Jf][
0P2BTY8309FEU@<0Kfm_0P1RHV8306ATI080MGEe0`2RXZ830;Fe]@80ZZZZ0`2b/[820;Fe]@<0^[Zj
1@2m_Kd30<K6aP80bLW90`3?cll30<k>cP80alO70`2:RXX50410@080CDe=0`1IFET3065QH@80JVYZ
1@1aLG4307EeM@<0MWIf0P1gMgL307emO@80QHF50`26QXH308V9R@80QHF50`2:RXX208f=S@<0UiNG
0`2DU9@209NGU`<0UYJF0P2LW9`30:6QX@<0V9RH0P2QXJ430::RXP80Y:BT0`2WYjL30:BTY080YZJV
0`2PX:020:BTY0<0YjNW0P2ZZZX30:f][@<0[:b/1@2VYZH20:2PX0<0YJFU0`2WYjL20:FUY@<0Z:RX
0P2SXj<30:NWY`<0ZJVY0P2[Zj/30:f][@D0ZJVY0`2a/K420:j^[P<0ZJVY0P2TY:@30:JVYP<0[:b/
0P2`/;030:BTY080YZJV0`2^[Zh30:FUY@80WYjN0`2CTi<208b<S0<0SXj>1@28R8P3092@T080Shn?
0`2>SXh208^;R`<0QXJ60`29RHT208J6QPD0PH610`23Ph<30861P@80PX:20`20P80207moO`<0Rh^;
7038h=P001/0b>3H200^;Rh502l_;`<0;Rh^0P0/;2`302/[:`80:RXZ0`0[:b/302d];@80<C4a0`0e
=CD203@d=0<0<c<c2P0b<S8302h^;P80;2`/0`0Z:RX3038b<P80;2`/0`1YJFT20::RXP<0UYJF0`1O
Gel206IVIP<0J6QX0P1iNGT309JFUP<0]KFe0P2c/k<30:n_[`80];Bd0`2j^[X30;fm_@80`<300`33
`l<20<O7a`H0d];B0P35aLD308b<S080?clo0`10@40204Q8B0<0G5aL0`1TI6@206YZJP<0Kfm_0P1c
Lg<307AdM0<0MGEe0P1jNWX307moO`80Q8B40`28R8P308N7Q`80QXJ60`2:RXX2092@T0<0Ti>C0`2F
UYH209NGU`<0V9RH0P2KVi/309jNWPD0WinO0`2RXZ820:FUY@H0YZJV0P2TY:@30::RXP80Y:BT0`2W
YjL20:ZZZP<0[Jf]0`2ZZZX20:NWY`<0Y:BT0P2SXj<30:FUY@<0Z:RX0P2VYZH50:FUY@<0YjNW0`2[
Zj/20:n_[`<0[:b/0P2YZJT30:b/[0<0[jn_0P2][Jd30:VYZ@80YZJV0`2UYJD30:VYZ@80[Jf]0`2Y
ZJT20:FUY@H0YjNW0P2NWYh309>CT`80SXj>0`2;Rh/508V9R@<0SHf=0P2ATI4308n?S`80Rh^;0`29
RHT308R8R080QHF50`23Ph<508:2PP<0PH610P20P8030861P@D0PX:2=038h=P3038b<P80:b/[0`0_
;bl2038b<P<0<30`0`0/;2`2030`<0<0;Rh^0P0W9bL3030`<0<0;Rh^0P0a<C43038b<P80?clo2`0`
<30203<c<`<0:b/[1@0Z:RX302`/;080>3Ph0`1[Jf/209:BTP<0UIFE0`1_Kfl2069RHP<0I6AT0P1e
MGD30::RXP<0]KFe0P2ZZZX30;:b/P80]KFe0`2j^[X50;fm_@<0a/K60P39bLT30<o?c`<0c/k>0P37
alL308Z:RPD0@4100P1=CDd305UIF@<0HF5Q0P1ZJVX5075aL@<0MGEe0`1fMWH207MgM`<0OGem0P25
QHD308J6QP<0RHV90P25QHD308Z:RP80SHf=0`2GUiL309BDU080UiNG0`2FUYH209bLW0<0XJ6Q0`2H
V9P20:6QX@<0XZ:R0P2TY:@30:NWY`<0Y:BT0P2VYZH30:2PX080Y:BT0`2WYjL20:ZZZP<0[Jf]0`2/
[:`50:JVYP80X:2P0`2UYJD30:NWY`80YJFU0`2XZ:P20:>SX`<0YjNW0`2YZJT20:^[Z`<0[Jf]1@2Y
ZJT30;6a/@80[Zj^0`2YZJT20:BTY0<0YZJV0`2/[:`20;2`/0<0Y:BT0P2VYZH30:j^[P<0YJFU0P2N
WYh309>CT`80S8b<0`2>SXh508R8R0<0T92@0P2?Shl308j>SP80Rh^;0`26QXH308V9R@80QXJ61@21
PH4308>3P`<0PH610P22PX830820P080Ogmo0`2;Rh/L0<SPf0006`38h=P802h^;PD0;bl_0`0^;Rh2
02`/;0<0:b/[0P0Z:RX302/[:`<0;Bd]0P0a<C4303De=@80=3@d0`0c<c<:038b<P<0;Rh^0P0/;2`3
02XZ:P<0<S8b0P0/;2`306UYJ@80XZ:R0`2FUYH305mOG`80IVIV0`1XJ6P207UiN@<0UYJF0`2e]KD2
0;>c/`<0[jn_0P2d];@30;Zj^P<0_Kfm0P30`<030<?3``80alO71P3Bd]820<G5a@<0S8b<0P0o?cl3
0410@080B4Q80`1LG5`306ATI080JVYZ0`1_Kfl207=cL`<0M7Ad0`1eMGD207YjNP<0Ogmo0P24Q8@3
08R8R0<0QhN70P26QXH308Z:RP80T92@0`2CTi<309JFUP80UiNG0`2HV9P209^KV`<0WYjN1@2OWil3
0::RXP80YJFU1P2VYZH20:BTY0<0XZ:R0P2TY:@30:NWY`80ZZZZ0`2][Jd30:ZZZP80YjNW0`2TY:@2
0:>SX`<0YJFU0`2XZ:P20:JVYPD0YJFU0`2WYjL30:^[Z`80[jn_0`2/[:`20:VYZ@<0[:b/0`2_[jl2
0:f][@<0ZJVY0P2VYZH30:FUY@<0ZJVY0P2][Jd30:VYZ@80YJFU1P2WYjL209jNWP<0Ti>C0P2>SXh3
08^;R`D0RHV90`2=SHd2096AT@<0Shn?0P2;Rh/308V9R@<0R8R80P25QHD308>3P`D0PX:20`21PH42
0820P0<0PH611@22PX8d0<SPf0<0<S8b0P0[:b/302l_;`80<S8b0`0`<30302`/;080<30`0`0^;Rh2
02LW9`<0<30`0`0^;Rh2034a<@<0<S8b0P0o?cl;030`<080<c<c0`0[:b/502XZ:P<0;2`/0P0h>3P3
06][J`80TY:B0`2EUID306m_K`80HV9R0`1TI6@207EeM@<0XZ:R0`2e]KD20:ZZZP<0/[:b0P2e]KD3
0;Zj^PD0_Kfm0`36a/H20<W9b@<0clo?0`3>c/h20<O7a`<0RXZ:1@10@40204e=C@<0FEUI0`1QHF42
06YZJPD0LG5a0`1eMGD307IfMP80MgMg0`1mOGd208F5Q@<0QXJ60`29RHT208F5Q@<0RXZ:0P2=SHd3
09NGU`<0U9BD0P2GUiL309JFUP80W9bL0`2QXJ4309RHV080XJ6Q0`2RXZ820:BTY0<0YjNW0`2TY:@2
0:JVYP<0X:2P0P2TY:@30:NWY`80ZZZZ0`2][Jd30:b/[0D0YZJV0P2PX:030:FUY@<0YjNW0P2UYJD3
0:RXZ080Xj>S0`2WYjL30:VYZ@80Zj^[0`2][Jd50:VYZ@<0/K6a0P2^[Zh30:VYZ@80Y:BT0`2VYZH3
0:b/[080/;2`0`2TY:@20:JVYP<0[Zj^0`2UYJD209jNWP<0Ti>C0P2<S8`308j>SPD0R8R80`2@T902
08n?S`<0SXj>0P2;Rh/308J6QP<0RHV90P26QXH50861P@<0Ph>30`21PH4208:2PP<0P8200P1oOgl3
08^;Ra`0b>3H000K0<SPf0<0;bl_0P0];Bd302/[:`80;Bd]1P0^;Rh202d];@<0:b/[1@0Z:RX302`/
;080<S8b0`0f=SH203@d=0<0<C4a1@0`<305034a<@<0;2`/0P0W9bL302DU9@<0:RXZ0P0V9RH304U9
B@80QhN70`2FUYH308F5Q@80Jf][0`1UIFD206][J`<0RXZ:0`2/[:`20;no_`<0ZZZZ0P2b/[830;Ng
]`<0^KVi0P2k^k/30;no_`80aLG50`3<c<`30<o?c`80eMGE0`2a/K4207moO`<0DE5A0P0k>c/305AD
E0<0FUYJ0P1WIfL306a/K080L71`0`1bLW8307AdM080N7Qh0`1mOGd208>3P`<0R8R80`27QhL208J6
QP<0Rh^;0P2@T90309BDU0<0UiNG0P2HV9P309VIV@80VYZJ0`2KVi/309bLW080WIfM0`2PX:020::R
XPP0Xj>S1@2RXZ880:>SX`<0X:2P0P2MWId509bLW0<0WinO0`2QXJ420:2PX0<0WinO0P2PX:030::R
XP<0YJFU0P2XZ:P30:JVYP80YJFU0`2XZ:P50:b/[0<0Zj^[0P2XZ:P30:JVYP<0Z:RX0P2YZJT30:JV
YP80Xj>S0`2VYZH30:RXZ080X:2P0`2GUiL2092@T0<0RXZ:0P26QXH308F5Q@<0R8R80P2<S8`308f=
S@80S8b<0`2:RXX308N7Q`80Ph>30`20P8020861P@<0PX:20`21PH420820P0<0PX:21@25QHDd0<SP
f0D0;2`/0`0];Bd202l_;`<0;Bd]0`0W9bL202`/;0<0<C4a0P0X:2P302/[:`<0:BTY0P0`<30303Hf
=P80=cLg0`0];Bd203<c<`<0<S8b0`0a<C45030`<0809RHV0`0W9bL302PX:080;Bd]0`17AdL208:2
PP<0WYjN0`24Q8@206UYJ@<0IFEU0P1[Jf/308N7Q`<0];Bd0P2][Jd30;6a/@80];Bd0`2f][H50;^k
^`D0`l?30`3:b/X30<o?c`80cLg=0`31`L420861P@<0?clo0P15ADD305ADE0<0H61P0P1VIVH3075a
L@80L71`0`1_Kfl3079bLP80N7Qh0`1oOgl208N7Q`<0QXJ60`27QhL208>3P`<0SXj>0P2<S8`309JF
UP<0U9BD0P2GUiL809bLW0<0Vi^K0P2OWil30:BTY0D0XJ6Q0`2RXZ820:BTY0<0WYjN0P2VYZH50:6Q
X@<0Xj>S0`2OWil209ZJVP<0WinO0P2KVi/60::RXP80WIfM0`2NWYh209nOW`<0YZJV0`2TY:@20:^[
Z`<0ZZZZ0P2SXj<30:JVYP<0/K6a0P2/[:`30:j^[P80YJFU0`2RXZ850:b/[0<0X:2P0P2RXZ830:ZZ
ZPD0Y:BT0`2EUID208b<S0<0SHf=1@25QHD308R8R080RXZ:0`2?Shl208j>SPH0R8R81@22PX8207in
OP<0Q8B41@1oOgl30820P080OGem0`2<S8`L0<SPf0006`38h=P302l_;`80;Bd]0`0[:b/202d];@H0
;Rh^0P0];Bd302/[:`D0:RXZ0`0/;2`2038b<P<0=SHf0P0d=3@3034a<@D0<30`1@0a<C4302`/;080
9bLW0`0U9BD302XZ:P809RHV0`19BDT208N7Q`<0UYJF0`25QHD206][J`<0IFEU0P1[Jf/308Z:RP<0
[:b/0P2o_kl30:ZZZP80/[:b0`2g]kL30;Vi^@80^k^k0`2o_kl20<G5a@<0c<c<0`3?cll20=GEe@<0
/K6a0P1oOgl3055AD@80>c/k0`1DE5@305YJFP80IfMW0`1/K6`2071`L0<0LW9b0`1dM7@207QhN0<0
OGem0P23Ph<308R8R0<0QhN70P26QXH308^;R`80T92@0`2DU9@309NGU`80V9RH0`2IVIT209ZJVP<0
Vi^K0`2LW9`209fMW@<0X:2P0P2RXZ880:>SX`D0XZ:R202SXj<30:2PX080WIfM1@2LW9`309nOW`<0
XJ6Q0P2PX:0309nOW`80X:2P0`2RXZ830:FUY@80Z:RX0`2VYZH20:FUY@<0Z:RX1@2/[:`30:^[Z`80
Z:RX0`2VYZH30:RXZ080ZJVY0`2VYZH20:>SX`<0YZJV0`2XZ:P20:2PX0<0UiNG0P2@T90308Z:RP80
QXJ60`25QHD308R8R080S8b<0`2=SHd208b<S0<0RXZ:0`27QhL208>3P`<0P8200P21PH4308:2PP<0
PH610P20P80308:2PPD0QHF5=038h=P502`/;0<0;Bd]0P0_;bl302d];@<09bLW0P0/;2`3034a<@80
:2PX0`0[:b/302TY:@80<30`0`0f=SH203Lg=`<0;Bd]0P0c<c<3038b<P<0<C4a1@0`<30202HV9P<0
9bLW0`0X:2P202d];@<0AdM70P22PX8309jNWP<0Q8B40P1YJFT306EUI@80Jf][0`27QhL30;Bd]080
[Jf]0`2a/K420;Bd]0<0][Jf1@2k^k/50<?3``<0b/[:0`3?cll20<g=c@<0`L710P21PH4303lo?`80
ADE50`1DE5@3061PH080IVIV0`1aLG42071`L0<0Kfm_0`1bLW8207QhN0<0Ogmo0P27QhL308J6QP<0
QhN70P23Ph<308j>SP80S8b<0`2FUYH309BDU080UiNG202LW9`309^KV`80WinO0`2TY:@50:6QX@<0
XZ:R0P2TY:@309jNWP80YZJV1@2QXJ430:>SX`<0WinO0P2JVYX309nOW`80Vi^K1P2RXZ8209fMW@<0
WYjN0P2OWil30:JVYP<0Y:BT0P2[Zj/30:ZZZP80Xj>S0`2VYZH30;6a/@80[:b/0`2^[Zh20:FUY@<0
XZ:R1@2/[:`30:2PX080XZ:R0`2ZZZX50:BTY0<0UIFE0P2<S8`308f=S@D0QHF50`28R8P208Z:RP<0
Shn?0P2>SXh608R8R0D0PX:20P1nOWh308B4Q0D0Ogmo0`20P80207emO@<0S8b<7038h=P001/0b>3H
0`0_;bl202`/;0<0:RXZ0P0/;2`802h^;P<0;2`/1@0[:b/302`/;080<S8b0`0f=SH203<c<`<0;bl_
0P0^;Rh302d];@<0;bl_0P0`<30302TY:@808b<S0`0R8R8302@T90809RHV0`0^;Rh2069RHP<0SXj>
0`2YZJT207AdM0<0JFUY0P1SHf<30861P@<0WYjN0P37alL30:VYZ@80/;2`0`2b/[830;Bd]080][Jf
0`2k^k/20<30`0<0aLG50`38b<P20=;BdP<0c/k>0P31`L4306m_K`80>CTi0`1>CTh305=CD`80HV9R
0`1WIfL206a/K0<0L71`0`1dM7@207MgM`<0Ng]k0P21PH4308J6QPD0QhN70`2<S8`2096AT@<0UIFE
0`2HV9P509VIV@80V9RH0`2GUiL309RHV080VYZJ0`2MWId209nOW`H0X:2P1@2QXJ4209nOW`<0WIfM
0P2KVi/309VIV@<0UYJF0P2CTi<309BDU080UYJF202HV9P309NGU`80VIVI0`2LW9`309jNWP80WinO
1@2PX:030:>SX`<0YJFU0P2XZ:P30:ZZZP80ZJVY0`2WYjL30:JVYP80YJFU0`2RXZ820:2PX0<0Y:BT
0`2WYjL20:>SX`<0W9bL0P2ATI4308R8R080Ph>30`21PH4308>3P`80QXJ60`2:RXX208b<S0<0RXZ:
0`27QhL20861P@<0OGem0P20P80308>3P`<0PH610P20P80308>3P`80QhN70`28R8Pd0<SPf0<0<30`
0P0];Bd302TY:@80;2`/1P0^;Rh202d];@<0;2`/0P0[:b/302l_;`<0:BTY0P0d=3@303De=@D0;bl_
0P0b<S8302XZ:P<0;bl_0P0b<S8302TY:@809BDU0`0Q8B4302DU9@808b<S0`0`<30206IVIP<0Shn?
0`2OWil207alO0<0I6AT0P1XJ6P307]kN`<0Y:BT0P2k^k/30:b/[080][Jf0`2a/K430;>c/`80]kNg
0`2j^[X20<30`0<0a/K60`3;bl/20<c<c0<0c/k>0P2k^k/3071`L080?3`l0`1>CTh305EEE@80GUiN
0`1UIFD206i^KP<0L71`0`1fMWH207QhN0<0NGUi0P22PX8608N7Q`80QXJ60`2=SHd208j>SP<0V9RH
0`2FUYH209VIV@<0UiNG0P2JVYX609NGU`80VYZJ0`2KVi/20:2PX0<0Xj>S0`2NWYh20:>SX`<0WinO
0P2PX:0309bLW0D0VYZJ0`2GUiL209BDU0D0UYJF0`2HV9P309^KV`80UYJF0`2IVIT209jNWP<0Vi^K
1@2LW9`30:FUY@80X:2P0`2RXZ830:BTY080YJFU0`2WYjL20:ZZZP<0YJFU0`2WYjL20:FUY@<0XZ:R
0P2OWil30:JVYP<0Xj>S0P2WYjL309bLW080SXj>0`2;Rh/208:2PP<0Ogmo0`24Q8@208J6QP<0Rh^;
0P2<S8`308N7Q`<0RHV90P20P80307inOP80P8200`24Q8@508:2PP<0Ph>30P27QhL308f=SA`0b>3H
000K0<SPf0<0;bl_0P0/;2`302XZ:P80;2`/200^;Rh302`/;0D0:b/[0`0/;2`2038b<P<0=SHf0P0c
<c<302l_;`80;Rh^0`0];Bd302l_;`80<30`0`0Y:BT202<S8`<08R8R0`0T92@202HV9P<0;Rh^0P1R
HV8308j>SP<0ZJVY0P1dM7@306UYJ@80Hf=S0`21PH4309jNWP80alO70`2YZJT20;2`/0<0/[:b0`2d
];@20;Jf]P<0^k^k0P30`<030<G5a@<0b<S80P3Bd]830<k>cP80`L710`1_Kfl203Ti>@<0CTi>0`1C
De<2069RHP<0IfMW0P1/K6`3071`L0<0M7Ad0P1gMgL307]kN`80PH610`26QXH508N7Q`<0S8b<0P2A
TI4309FEU@<0V9RH1@2IVIT209RHV0<0UiNG0`2HV9P209ZJVP<0WIfM0P2OWil60:2PX0D0XJ6Q0P2O
Wil309fMW@80Vi^K0`2IVIT309JFUP80Ti>C0`2DU9@209JFUPP0V9RH0`2GUiL209VIV@<0W9bL0`2N
WYh209nOW`D0X:2P0`2SXj<30:FUY@80Z:RX0`2ZZZX20:VYZ@<0YjNW0`2VYZH20:FUY@<0XZ:R0P2P
X:030:BTY0<0YjNW0P2SXj<309bLW080TI6A0`28R8P208>3P`<0PH610`23Ph<208J6QP<0RXZ:0P2<
S8`308Z:RP<0QhN70P21PH4307emO@80P8200`23Ph<30861P@80P8200`23Ph<208N7Q`<0R8R8=038
h=P3030`<080;Bd]0`0Y:BT202`/;0H0;Rh^0P0];Bd302`/;080:b/[0`0_;bl302TY:@80=3@d0`0e
=CD502l_;`80<S8b0`0Z:RX302l_;`80<S8b0`0Y:BT202DU9@<08B4Q0`0U9BD202<S8`<0<30`0P1V
IVH308n?S`<0WinO0P1lO7`306ATI080J6QX0`1kNg/30:BTY080^k^k0`2/[:`20;Jf]P<0/K6a0`2c
/k<20;Ng]`<0^[Zj0P30`<030<K6aP<0bl_;0P3<c<`30<k>cP80^k^k0`1`L70203`l?0<0CTi>0`1E
EED205iNGP<0IFEU0P1^KVh3071`L0<0MWIf0P1hN7P307UiN@80PX:21P27QhL208J6QP<0SHf=0P2>
SXh309RHV0<0UYJF0P2IVIT309NGU`80VYZJ1P2GUiL209ZJVP<0Vi^K0P2PX:030:>SX`<0WYjN0P2S
Xj<309nOW`80X:2P0`2LW9`509ZJVP<0UiNG0P2DU9@509JFUP<0V9RH0`2KVi/209JFUP<0VIVI0P2N
WYh309^KV`D0W9bL0`2UYJD20:2PX0<0XZ:R0`2TY:@20:FUY@<0YjNW0P2ZZZX30:FUY@<0YjNW0P2U
YJD30::RXP80WinO0`2VYZH30:>SX`80YjNW0`2LW9`208j>SP<0Rh^;0P22PX8307moO`<0Q8B40P26
QXH308^;R`80S8b<0`27QhL308V9R@80P8200`1nOWh20820P0<0Q8B41@22PX8308>3P`80QhN70`2=
SHdL0<SPf0006`38h=P302l_;`80;2`/0`0Z:RX202`/;0P0;Rh^0`0/;2`502/[:`<0;2`/0P0b<S83
03Hf=P80<c<c0`0_;bl202h^;P<0;Bd]0`0_;bl2030`<0<0:BTY0P0S8b<3028R8P<092@T0P0V9RH3
02h^;P80HV9R0`2>SXh30:VYZ@80M7Ad0`1YJFT206=SH`<0PH610`2NWYh20<O7a`<0ZJVY0P2`/;03
0;:b/P<0];Bd0P2f][H30;^k^`80`<300`35aLD30<S8b080d];B0`3>c/h20<71`@<0Kfm_0P0i>CT3
04i>CP<0De=C0P1RHV8306MWI`80K6a/0`1`L70307AdM080MgMg0`1kNg/20861P@<0QXJ61@27QhL3
08b<S080TI6A0`2EUID309RHV0D0VIVI0P2HV9P309NGU`<0V9RH0P2JVYX309fMW@80WinO1P2PX:05
0:6QX@80WinO0`2MWId209^KV`<0VIVI0`2FUYH209>CT`<0U9BD0P2FUYH809RHV0<0UiNG0P2IVIT3
09bLW0<0WYjN0P2OWil50:2PX0<0Xj>S0`2UYJD20:RXZ0<0ZZZZ0P2YZJT30:NWY`<0YZJV0P2UYJD3
0::RXP80X:2P0`2TY:@30:NWY`80Xj>S0`2LW9`2096AT@<0R8R80P23Ph<30861P@<0Ph>30P26QXH3
08Z:RP80S8b<0`2:RXX308N7Q`80PH610`1mOGd20820P0<0Ph>30`21PH420820P0<0Ph>30P27QhL3
08R8R3@0b>3H0`0`<30202d];@<0:BTY0P0/;2`602h^;P80;Bd]0`0/;2`202/[:`<0;bl_0`0Y:BT2
03@d=0<0=CDe1@0_;bl2038b<P<0:RXZ0`0_;bl2038b<P<0:BTY0P0U9BD3024Q8@<09BDU0P0S8b<3
030`<080IVIV0`2?Shl309nOW`80O7al0`1TI6@206QXJ0<0Ng]k0`2TY:@20;^k^`<0[:b/0P2f][H3
0;6a/@<0/k>c0P2g]kL30;Zj^P80`<300`36a/H30<_;b`80c<c<0`3>c/h20;^k^`<0L71`0P0l?3`3
04i>CP<0EEEE0P1NGUh306EUI@80KVi^0`1`L70307IfMP80N7Qh0`1iNGT208:2PPH0QhN70P26QXH3
08f=S@80SXj>0`2HV9P309JFUP80VIVI0`2GUiL209ZJVPH0UiNG0P2JVYX309^KV`80X:2P0`2SXj<3
09jNWP80Xj>S0`2OWil20:2PX0<0W9bL1@2JVYX309NGU`80U9BD1@2FUYH309RHV0<0Vi^K0P2FUYH3
09VIV@80WYjN0`2KVi/509bLW0<0YJFU0P2PX:030::RXP<0Y:BT0P2UYJD30:NWY`80ZZZZ0`2UYJD3
0:NWY`80YJFU0`2RXZ8209nOW`<0YZJV0`2SXj<20:NWY`<0W9bL0P2>SXh308^;R`80PX:20`1oOgl3
08B4Q080QXJ60`2;Rh/208b<S0<0QhN70`29RHT20820P0<0OWin0P20P80308B4Q0D0PX:20`23Ph<2
08N7Q`<0SHf=7038h=P001/0b>3H1@0/;2`502d];@<0;Rh^1@0_;bl302`/;080:b/[0`0];Bd3030`
<080<S8b0`0d=3@2038b<P<0;bl_0P0^;Rh802d];@<0:BTY0P0T92@302<S8`<092@T0P0R8R8302LW
9`80?Shn0`1kNg/309jNWP80SHf=0`1eMGD206=SH`<0MWIf0`2@T9020;Vi^@<0];Bd0P2`/;030:NW
Y`<0[Jf]0P2e]KD30;Rh^080^k^k0`2o_kl30<C4a080cLg=0`3?cll20=7Ad@<0Y:BT0P1WIfL304m?
C`<0DE5A0P1GEeL305mOG`80JFUY0`1_Kfl307AdM080N7Qh0`1kNg/20820P0<0QXJ60`27QhL208V9
R@<0SHf=0P2BTY8309BDU0<0UYJF0P2IVIT309^KV`80VYZJ202HV9P309VIV@80VYZJ0`2KVi/509bL
W0<0Vi^K0P2IVIT309NGU`80UYJF0`2EUID309:BTP80T92@0`2BTY8809BDU080Ti>C0`2BTY8209BD
U0<0UIFE0`2FUYH209NGU`<0VYZJ0P2LW9`30:2PX0<0WYjN0P2QXJ430:BTY080YJFU0`2TY:@30:JV
YP80YjNW0`2RXZ8209jNWP<0XJ6Q1@2TY:@30:6QX@80UIFE0`28R8P208>3P`<0PH610`22PX8208F5
Q@<0R8R80P2:RXX308V9R@<0QhN70P23Ph<50820P0<0PH610`20P80207moO`<0Ph>30P26QXH308N7
Qc@0b>3H0`0[:b/202l_;`<0;2`/0P0_;bl3038b<P<0<C4a0P0c<c<302`/;0809bLW0`0^;Rh3034a
<@80>3Ph0`0f=SH203<c<`<0<30`0P0_;bl602d];@80;2`/0`0W9bL202<S8`<092@T0`0U9BD202<S
8`<092@T0P0o?cl307UiN@<0W9bL0P2?Shl307=cL`80Jf][0`1_Kfl309JFUP80`L710`2b/[820:^[
Z`<0YZJV0`2ZZZX20;6a/@<0]KFe0P2l_;`30;no_`<0b<S80P3<c<`30<o?c`80c<c<0`2f][H2061P
H0<0AdM70`1ADE4205aLG0<0GemO0P1WIfL306i^KP<0LW9b0P1kNg/307YjNP80O7al0`23Ph<308^;
R`80R8R80`2@T90209:BTP<0U9BD0`2IVIT509ZJVP80V9RH0`2GUiL309>CT`80UYJF0`2NWYh209BD
U0H0Vi^K0P2OWil309ZJVP80WIfM0`2JVYX209FEU@<0UiNG0`2ATI4208j>SP<0TY:B0P2ATI4309>C
T`<0Shn?1@2@T90209>CT`H0TY:B0P2HV9P309JFUP80W9bL0`2MWId30:2PX080XJ6Q1@2XZ:P30:NW
Y`<0Xj>S1@2TY:@209bLW0<0XJ6Q0`2SXj<20:NWY`<0X:2P0P2BTY8308J6QP80Ph>30`25QHD508B4
Q0<0QXJ60P2:RXX308^;R`<0QhN70P24Q8@307moO`80PH610`1lO7`308>3P`80O7al0`21PH4208B4
Q0<0SXj>7038h=P001/0b>3H1@0/;2`502d];@<0;Rh^1@0_;bl302`/;080:b/[0`0];Bd3030`<080
<S8b0`0d=3@2038b<P<0;bl_0P0^;Rh802d];@<0:BTY0P0T92@302<S8`<092@T0P0R8R8302LW9`80
?Shn0`1kNg/309jNWP80SHf=0`1eMGD206=SH`<0MWIf0`2@T9020;Vi^@<0];Bd0P2`/;030:NWY`<0
[Jf]0P2e]KD30;Rh^080^k^k0`2o_kl30<C4a080cLg=0`3?cll20=7Ad@<0Y:BT0P1WIfL304m?C`<0
DE5A0P1GEeL305mOG`80JFUY0`1_Kfl307AdM080N7Qh0`1kNg/20820P0<0QXJ60`27QhL208V9R@<0
SHf=0P2BTY8309BDU0<0UYJF0P2IVIT309^KV`80VYZJ202HV9P309VIV@80VYZJ0`2KVi/509bLW0<0
Vi^K0P2IVIT309NGU`80UYJF0`2EUID309:BTP80T92@0`2BTY8809BDU080Ti>C0`2BTY8209BDU0<0
UIFE0`2FUYH209NGU`<0VYZJ0P2LW9`30:2PX0<0WYjN0P2QXJ430:BTY080YJFU0`2TY:@30:JVYP80
YjNW0`2RXZ8209jNWP<0XJ6Q1@2TY:@30:6QX@80UIFE0`28R8P208>3P`<0PH610`22PX8208F5Q@<0
R8R80P2:RXX308V9R@<0QhN70P23Ph<50820P0<0PH610`20P80207moO`<0Ph>30P26QXH308N7Qc@0
b>3H0`0[:b/202l_;`<0;2`/0P0_;bl3038b<P<0<C4a0P0c<c<302`/;0809bLW0`0^;Rh3034a<@80
>3Ph0`0f=SH203<c<`<0<30`0P0_;bl602d];@80;2`/0`0W9bL202<S8`<092@T0`0U9BD202<S8`<0
92@T0P0o?cl307UiN@<0W9bL0P2?Shl307=cL`80Jf][0`1_Kfl309JFUP80`L710`2b/[820:^[Z`<0
YZJV0`2ZZZX20;6a/@<0]KFe0P2l_;`30;no_`<0b<S80P3<c<`30<o?c`80c<c<0`2f][H2061PH0<0
AdM70`1ADE4205aLG0<0GemO0P1WIfL306i^KP<0LW9b0P1kNg/307YjNP80O7al0`23Ph<308^;R`80
R8R80`2@T90209:BTP<0U9BD0`2IVIT509ZJVP80V9RH0`2GUiL309>CT`80UYJF0`2NWYh209BDU0H0
Vi^K0P2OWil309ZJVP80WIfM0`2JVYX209FEU@<0UiNG0`2ATI4208j>SP<0TY:B0P2ATI4309>CT`<0
Shn?1@2@T90209>CT`H0TY:B0P2HV9P309JFUP80W9bL0`2MWId30:2PX080XJ6Q1@2XZ:P30:NWY`<0
Xj>S1@2TY:@209bLW0<0XJ6Q0`2SXj<20:NWY`<0X:2P0P2BTY8308J6QP80Ph>30`25QHD508B4Q0<0
QXJ60P2:RXX308^;R`<0QhN70P24Q8@307moO`80PH610`1lO7`308>3P`80O7al0`21PH4208B4Q0<0
SXj>7038h=P001/0b>3H1@0/;2`502d];@<0;Rh^1@0_;bl302`/;080:b/[0`0];Bd3030`<080<S8b
0`0d=3@2038b<P<0;bl_0P0^;Rh802d];@<0:BTY0P0T92@302<S8`<092@T0P0R8R8302LW9`80?Shn
0`1kNg/309jNWP80SHf=0`1eMGD206=SH`<0MWIf0`2@T9020;Vi^@<0];Bd0P2`/;030:NWY`<0[Jf]
0P2e]KD30;Rh^080^k^k0`2o_kl30<C4a080cLg=0`3?cll20=7Ad@<0Y:BT0P1WIfL304m?C`<0DE5A
0P1GEeL305mOG`80JFUY0`1_Kfl307AdM080N7Qh0`1kNg/20820P0<0QXJ60`27QhL208V9R@<0SHf=
0P2BTY8309BDU0<0UYJF0P2IVIT309^KV`80VYZJ202HV9P309VIV@80VYZJ0`2KVi/509bLW0<0Vi^K
0P2IVIT309NGU`80UYJF0`2EUID309:BTP80T92@0`2BTY8809BDU080Ti>C0`2BTY8209BDU0<0UIFE
0`2FUYH209NGU`<0VYZJ0P2LW9`30:2PX0<0WYjN0P2QXJ430:BTY080YJFU0`2TY:@30:JVYP80YjNW
0`2RXZ8209jNWP<0XJ6Q1@2TY:@30:6QX@80UIFE0`28R8P208>3P`<0PH610`22PX8208F5Q@<0R8R8
0P2:RXX308V9R@<0QhN70P23Ph<50820P0<0PH610`20P80207moO`<0Ph>30P26QXH308N7Qc@0b>3H
0`0[:b/202l_;`<0;2`/0P0_;bl3038b<P<0<C4a0P0c<c<302`/;0809bLW0`0^;Rh3034a<@80>3Ph
0`0f=SH203<c<`<0<30`0P0_;bl602d];@80;2`/0`0W9bL202<S8`<092@T0`0U9BD202<S8`<092@T
0P0o?cl307UiN@<0W9bL0P2?Shl307=cL`80Jf][0`1_Kfl309JFUP80`L710`2b/[820:^[Z`<0YZJV
0`2ZZZX20;6a/@<0]KFe0P2l_;`30;no_`<0b<S80P3<c<`30<o?c`80c<c<0`2f][H2061PH0<0AdM7
0`1ADE4205aLG0<0GemO0P1WIfL306i^KP<0LW9b0P1kNg/307YjNP80O7al0`23Ph<308^;R`80R8R8
0`2@T90209:BTP<0U9BD0`2IVIT509ZJVP80V9RH0`2GUiL309>CT`80UYJF0`2NWYh209BDU0H0Vi^K
0P2OWil309ZJVP80WIfM0`2JVYX209FEU@<0UiNG0`2ATI4208j>SP<0TY:B0P2ATI4309>CT`<0Shn?
1@2@T90209>CT`H0TY:B0P2HV9P309JFUP80W9bL0`2MWId30:2PX080XJ6Q1@2XZ:P30:NWY`<0Xj>S
1@2TY:@209bLW0<0XJ6Q0`2SXj<20:NWY`<0X:2P0P2BTY8308J6QP80Ph>30`25QHD508B4Q0<0QXJ6
0P2:RXX308^;R`<0QhN70P24Q8@307moO`80PH610`1lO7`308>3P`80O7al0`21PH4208B4Q0<0SXj>
7038h=P001/0b>3H0`0Y:BT202`/;0D0<30`0`0^;Rh502l_;`<0;Bd]0P0[:b/302l_;`<0<c<c0P0b
<S83034a<@D0<30`0P0_;bl302d];@<0;2`/0P0[:b/302TY:@809bLW1P0V9RH2020P80<09BDU0P0P
820306=SH`<0QHF50P2QXJ4308F5Q@80IfMW0`1]KFd30861P@80Xj>S0`2o_kl20;2`/0<0WIfM0`2V
YZH20;>c/`D0]KFe0`2k^k/30<30`080a<C40`38b<P50=;BdP80Vi^K1P1LG5`204e=C@<0EeMG0P1U
IFD306e]K@<0M7Ad0P1hN7P307]kN`80P8200`24Q8@308N7Q`80RXZ:0`2>SXh209:BTP<0Ti>C0`2D
U9@209RHV0<0Vi^K0P2JVYX309VIV@<0UiNG1`2FUYH609NGU`80UYJF0`2EUID209>CT`<0TY:B0P2C
Ti<309BDU0<0TI6A0P2>SXh3092@T080Ti>C0`2ATI4308n?S`80SXj>0`2=SHd208j>SPH0Shn?0P2@
T90309BDU080V9RH0`2IVIT309NGU`80VYZJ0`2MWId209nOW`<0XJ6Q0`2UYJD20:NWY`<0XZ:R0P2L
W9`309fMW@<0X:2P1@2SXj<209NGU`<0RXZ:0P24Q8@30861P@<0PX:20P24Q8@308J6QPD0R8R80`27
QhL208J6QP<0Ph>30P21PH4307moO`<0OWin0P1oOgl308:2PP80QXJ60`27QhLd0<SPf0<09bLW0P0[
:b/303@d=080;Rh^0`0];Bd302/[:`80;Rh^0`0_;bl2030`<0<0;Bd]0`0^;Rh203Hf=P<0;2`/0P0^
;Rh302l_;`80:b/[0`0_;bl302XZ:P80<30`0`0W9bL202PX:0<0:b/[0`0V9RH2024Q8@<08R8R0P0X
:2P3061PH0<0QHF50P2QXJ4308:2PP80Jf][0`1WIfL307inOP80ZJVY0`30`<020:RXZ0<0XJ6Q0`2[
Zj/20;:b/P<0][Jf0P2g]kL30;Fe]@<0`L710P37alL30<W9b@D0b/[:0P2YZJT305mOG`<0BTY:0P1F
EUH305eMG@80Hf=S0`1]KFd507EeM@<0OGem0P1oOgl308>3P`<0RXZ:0P28R8P308f=S@80Ti>C1P2D
U9@209FEU@<0Vi^K0P2IVIT609ZJVP80UYJF0`2HV9P209JFUP<0U9BD0`2GUiL209VIV@<0UIFE0P2D
U9@309>CT`80T92@0`2EUID3092@T080Rh^;0`2DU9@209:BTP<0Shn?0`2@T90208f=S@<0SXj>0P2@
T90308j>SP<0Shn?0P2>SXh309JFUP80UiNG0`2FUYH309NGU`80VYZJ0`2KVi/209fMW@<0XJ6Q0`2S
Xj<20:FUY@<0Y:BT0P2JVYX309fMW@<0XJ6Q0P2SXj<30:6QX@80V9RH0`2;Rh/80861P@80R8R80`24
Q8@208Z:RP<0R8R80`26QXH208N7Q`<0PH610P23Ph<307inOP<0PX:20P1oOgl308:2PP80Ph>30`2<
S8`L0<SPf0006`38h=P302TY:@80;2`/1@0`<30302h^;PD0;bl_0`0];Bd202/[:`<0;bl_0`0c<c<2
038b<P<0<C4a1@0`<30202l_;`<0;Bd]0`0/;2`202/[:`<0:BTY0P0W9bL602HV9P80820P0`0U9BD2
020P80<0Hf=S0`25QHD20:6QX@<0QHF50P1WIfL306e]K@<0PH610P2SXj<30;no_`80/;2`0`2MWId3
0:JVYP80/k>c1@2e]KD30;^k^`<0`<300P34a<@30<S8b0D0d];B0P2KVi/605aLG080CDe=0`1GEeL2
06EUI@<0KFe]0`1dM7@207QhN0<0Ng]k0P20P80308B4Q0<0QhN70P2:RXX308j>SP80TY:B0`2CTi<3
09BDU080V9RH0`2KVi/209ZJVP<0VIVI0`2GUiL709JFUPH0UiNG0P2FUYH309FEU@80Ti>C0`2BTY82
09>CT`<0U9BD0`2ATI4208j>SP<0T92@0P2CTi<3096AT@<0Shn?0P2>SXh308f=S@80SXj>1P2?Shl2
092@T0<0U9BD0P2HV9P309VIV@<0UiNG0P2JVYX309fMW@80WinO0`2QXJ430:FUY@80YjNW0`2RXZ82
09bLW0<0WIfM0`2PX:050:>SX`80UiNG0`2:RXX208B4Q0<0PH610`22PX8208B4Q0<0QXJ61@28R8P3
08N7Q`80QXJ60`23Ph<20861P@<0Ogmo0`1nOWh207moO`<0PX:20P26QXH308N7Qc@0b>3H0`0W9bL2
02/[:`<0=3@d0P0^;Rh302d];@<0:b/[0P0^;Rh302l_;`80<30`0`0];Bd302h^;P80=SHf0`0/;2`2
02h^;P<0;bl_0P0[:b/302l_;`<0:RXZ0P0`<30302LW9`80:2PX0`0[:b/302HV9P808B4Q0`0R8R82
02PX:0<0H61P0`25QHD20:6QX@<0PX:20P1[Jf/306MWI`<0OWin0P2YZJT30<30`080Z:RX0`2QXJ43
0:^[Z`80/[:b0`2f][H20;Ng]`<0]KFe0`31`L420<O7a`<0bLW91@3:b/X20:VYZ@<0GemO0`1:BTX2
05IFEP<0GEeM0P1SHf<306e]K@D0MGEe0`1mOGd207moO`<0Ph>30`2:RXX208R8R0<0SHf=0P2CTi<6
09BDU080UIFE0`2KVi/209VIV@H0VYZJ0P2FUYH309RHV080UYJF0`2DU9@309NGU`80VIVI0`2EUID2
09BDU0<0Ti>C0P2@T90309FEU@<0T92@0P2;Rh/309BDU080TY:B0`2?Shl3092@T080SHf=0`2>SXh2
092@T0<0SXj>0`2?Shl208j>SP<0UYJF0P2GUiL309JFUP<0UiNG0P2JVYX309^KV`80WIfM0`2QXJ43
0:>SX`80YJFU0`2TY:@209ZJVP<0WIfM0`2QXJ420:>SX`<0XJ6Q0P2HV9P308^;R`P0PH610P28R8P3
08B4Q080RXZ:0`28R8P308J6QP80QhN70`21PH4208>3P`<0OWin0`22PX8207moO`<0PX:20P23Ph<3
08b<S1`0b>3H000K0<SPf0<0:b/[0P0];Bd3030`<0P0<C4a0P0`<30302d];@80;2`/0`0_;bl3038b
<P80<C4a200_;bl5030`<0<0<C4a0P0`<30302/[:`809bLW0`0U9BD302@T90807alO0`0Q8B4201`L
70<0@d=30`1`L70509VIV@80KVi^0`1ZJVX3079bLP80QHF50`2m_Kd20:j^[P<0X:2P0`2VYZH20:n_
[`<0/K6a0P2c/k<30;Jf]P<0^k^k0P31`L430<O7a`80cLg=0`3AdM420;jn_P<0XJ6Q0`1HF5P205YJ
FP<0EUIF0P1HF5P306=SH`<0L71`0P1fMWH307YjNP80Ogmo0`23Ph<308F5Q@80R8R80`2;Rh/208n?
S`<0TY:B0`2CTi<509BDU080UIFE2`2FUYH209FEU@<0U9BD0`2BTY85092@T080TI6A0`2BTY8209FE
U@<0UYJF0`2@T90208V9R@<0SHf=0P2@T90308f=S@P0R8R80P26QXH308V9R@<0Rh^;0P2>SXh308f=
S@80Ti>C0`23Ph<509JFUP<0V9RH0P2KVi/309jNWPD0X:2P0`2LW9`209RHV0H0UiNG0P2JVYX309bL
W080UYJF0`2>SXh208>3P`<0Ng]k0`1mOGd208:2PP<0QHF51@27QhL308F5Q@80Q8B40`23Ph<20861
P@<0Ogmo0`1nOWh207moO`<0Q8B40P28R8P308V9RC@0b>3H0`0d=3@202XZ:P<0;2`/1@0d=3@3038b
<P80<C4a0`0^;Rh202PX:0<0;Rh^0`0g=cL503<c<`80;Rh^0`0d=3@203Lg=`<0=3@d0`0/;2`5030`
<0809bLW0`0N7Qh3024Q8@D0820P0P0S8b<303`l?0<0MWIf0P2IVIT309^KV`80KVi^0`1SHf<3071`
L080S8b<0`2i^KT20:ZZZP<0WinO0`2WYjL20;2`/0D0/k>c0`2`/;030;^k^`80`/;20`3:b/X20<W9
b@<0bl_;0P38b<P30::RXP<0GEeM0P1?Cdl305=CD`80G5aL0`1SHf<3075aL@80MWIf0`1iNGT208B4
Q0<0Ph>30`26QXH208N7Q`<0Rh^;0P2<S8`308n?S`<0Ti>C0P2BTY8309NGU`80VYZJ0`2BTY8309JF
UP80TY:B0`2GUiL209VIV@<0TI6A0`2CTi<2096AT@<0Rh^;0P2?Shl3096AT@80U9BD1P2EUID208b<
S0<0RXZ:0P2DU9@3092@T0<0SHf=0P29RHT308R8R080RHV90`2;Rh/508f=S@<0U9BD0P2ATI4308b<
S0D0UIFE0`2KVi/209VIV@H0WinO0P2TY:@309jNWP80VYZJ0`2DU9@309JFUP80VIVI1@2LW9`308f=
S@80Ph>30`1jNWX307]kN`80PH610`24Q8@208J6QP<0RHV90`26QXH208:2PP<0QHF50P21PH4607mo
O`80OGem0`23Ph<208F5Q@<0T92@7038h=P001/0b>3H0`0[:b/202d];@<0<30`200a<C42030`<0<0
;Bd]0P0/;2`302l_;`<0<S8b0P0a<C4802l_;`D0<30`0`0a<C42030`<0<0:b/[0P0W9bL302DU9@<0
92@T0P0O7al3024Q8@8071`L0`13@d<3071`L0D0VIVI0P1^KVh306YZJP<0LW9b0P25QHD30;fm_@80
[Zj^0`2PX:030:JVYP80[jn_0`2a/K420;>c/`<0][Jf0`2k^k/20<71`@<0alO70P3=cLd30=7Ad@80
_[jn0`2QXJ4305QHF080FUYJ0`1FEUH205QHF0<0Hf=S0`1`L70207IfMP<0NWYj0P1oOgl308>3P`<0
QHF50P28R8P308^;R`80Shn?0`2BTY8309>CT`D0U9BD0P2EUID;09JFUP80UIFE0`2DU9@309:BTPD0
T92@0P2ATI4309:BTP80UIFE0`2FUYH3092@T080RHV90`2=SHd2092@T0<0SHf=2028R8P208J6QP<0
RHV90`2;Rh/208j>SP<0SHf=0P2CTi<308>3P`D0UYJF0`2HV9P209^KV`<0WYjN1@2PX:0309bLW080
V9RH1P2GUiL209ZJVP<0W9bL0P2FUYH308j>SP80Ph>30`1kNg/307emO@80PX:20`25QHD508N7Q`<0
QHF50P24Q8@308>3P`80PH610`1oOgl307inOP80Ogmo0`24Q8@208R8R0<0RHV9=038h=P303@d=080
:RXZ0`0/;2`503@d=0<0<S8b0P0a<C4302h^;P80:2PX0`0^;Rh303Lg=`D0<c<c0P0^;Rh303@d=080
=cLg0`0d=3@302`/;0D0<30`0P0W9bL301hN7P<08B4Q1@0P820202<S8`<0?3`l0`1fMWH209VIV@<0
Vi^K0P1^KVh306=SH`<0L71`0P2<S8`30;Vi^@80ZZZZ0`2OWil30:NWY`80/;2`1@2c/k<30;2`/0<0
^k^k0P32`/830<[:bP80bLW90`3;bl/20<S8b0<0XZ:R0`1MGEd204m?C`<0De=C0P1LG5`306=SH`<0
LG5a0P1fMWH307UiN@80Q8B40`23Ph<308J6QP80QhN70`2;Rh/208b<S0<0Shn?0`2CTi<209:BTP<0
UiNG0P2JVYX309:BTP<0UYJF0P2BTY8309NGU`80VIVI0`2ATI4309>CT`80TI6A0`2;Rh/208n?S`<0
TI6A0P2DU9@609FEU@80S8b<0`2:RXX209BDU0<0T92@0`2=SHd208V9R@<0R8R80P29RHT308^;R`D0
SHf=0`2DU9@2096AT@<0S8b<1@2EUID309^KV`80VIVI1P2OWil20:BTY0<0WYjN0P2JVYX309BDU0<0
UYJF0P2IVIT509bLW0<0SHf=0P23Ph<307YjNP<0Ng]k0P21PH4308B4Q080QXJ60`29RHT308J6QP80
PX:20`25QHD20861P@H0Ogmo0P1mOGd308>3P`80QHF50`2@T90L0<SPf0006`38h=P302/[:`80;Bd]
0`0`<308034a<@80<30`0`0];Bd202`/;0<0;bl_0`0b<S82034a<@P0;bl_1@0`<303034a<@80<30`
0`0[:b/202LW9`<09BDU0`0T92@201lO7`<08B4Q0P0L71`304=3@`<0L71`1@2IVIT206i^KP<0JVYZ
0`1bLW8208F5Q@<0_Kfm0P2^[Zh30:2PX0<0YZJV0P2_[jl30;6a/@80/k>c0`2f][H30;^k^`80`L71
0`37alL20<g=c@<0dM7A0P2n_[h30:6QX@<0F5QH0P1JFUX305IFEP80F5QH0`1SHf<3071`L080MWIf
0`1jNWX207moO`<0Ph>30`25QHD208R8R0<0Rh^;0P2?Shl309:BTP<0Ti>C1@2DU9@209FEU@/0UYJF
0P2EUID309BDU0<0TY:B1@2@T902096AT@<0TY:B0P2EUID309JFUP<0T92@0P29RHT308f=S@80T92@
0`2=SHd808R8R080QXJ60`29RHT308^;R`80SXj>0`2=SHd209>CT`<0Ph>31@2FUYH309RHV080Vi^K
0`2NWYh50:2PX0<0W9bL0P2HV9P609NGU`80VYZJ0`2LW9`209JFUP<0SXj>0P23Ph<307]kN`<0OGem
0P22PX8308F5Q@D0QhN70`25QHD208B4Q0<0Ph>30P21PH4307moO`<0OWin0P1oOgl308B4Q080R8R8
0`29RHTd0<SPf0<0=3@d0P0Z:RX302`/;0D0=3@d0`0b<S82034a<@<0;Rh^0P0X:2P302h^;P<0=cLg
1@0c<c<202h^;P<0=3@d0P0g=cL303@d=0<0;2`/1@0`<30202LW9`<07QhN0`0Q8B45020P80808b<S
0`0l?3`307IfMP80VIVI0`2KVi/206i^KP<0Hf=S0`1`L70208b<S0<0^KVi0P2ZZZX309nOW`<0YjNW
0P2`/;050;>c/`<0/;2`0`2k^k/20<;2`P<0b/[:0P39bLT30<_;b`80b<S80`2RXZ8305eMG@80Cdm?
0`1CDe<205aLG0<0Hf=S0`1aLG4207IfMP<0NGUi0P24Q8@308>3P`<0QXJ60P27QhL308^;R`80S8b<
0`2?Shl309>CT`80TY:B0`2GUiL209ZJVP<0TY:B0`2FUYH209:BTP<0UiNG0P2IVIT3096AT@<0Ti>C
0P2ATI4308^;R`80Shn?0`2ATI4209BDU0H0UIFE0P2<S8`308Z:RP80U9BD0`2@T90308f=S@80RHV9
0`28R8P208V9R@<0Rh^;1@2=SHd309BDU080TI6A0`2<S8`509FEU@<0Vi^K0P2IVIT609nOW`80Y:BT
0`2NWYh209ZJVP<0U9BD0`2FUYH209VIV@D0W9bL0`2=SHd208>3P`<0NWYj0`1kNg/20861P@<0Q8B4
0P26QXH308V9R@<0QXJ60P22PX8308F5Q@80PH611P1oOgl207emO@<0Ph>30P25QHD3092@T1`0b>3H
000K0<SPf0D0;Rh^0`0_;bl2034a<@<0<c<c0`0b<S82030`<0<0;Rh^0P0/;2`302h^;P<0<C4a0P0_
;bl302d];@80;Rh^0`0_;bl2034a<@<0=3@d0`0e=CD203@d=0<0;Rh^0P0W9bL302@T90<08R8R0P0P
820501lO7`<09bLW0`1IFET208F5Q@<0YJFU0P1iNGT306][J`<0IVIV0P1[Jf/30;6a/@80[Jf]0`2W
YjL30:RXZ080ZZZZ0`2][Jd20;6a/@<0/k>c0`2f][H20;jn_P<0a/K60P38b<P30<O7a`80c/k>0`35
aLD309fMW@80E5AD0`1IFET204i>CP<0G5aL0`1[Jf/207=cL`<0NGUi0P1nOWh30861P@<0Ph>30P25
QHD308R8R080S8b<0`2@T90309>CT`80T92@0`2=SHd208n?S`<0TY:B0`2DU9@209FEU@<0UYJF0P2E
UID3096AT@<0SXj>1@2<S8`208n?S`<0Ti>C0P2GUiL309RHV0<0Shn?0P25QHD308R8R080Rh^;0`27
QhL308:2PPL0P8200`24Q8@308R8R080S8b<0`28R8P208b<S0<0L71`0`2DU9@2096AT@<0TY:B0P2G
UiL309bLW0<0Vi^K0P2HV9P309NGU`80UYJF0`2CTi<3092@T080TY:B1@2DU9@308n?S`80PX:20`1f
MWH307UiN@80P8200`23Ph<208J6QP<0QHF50`23Ph<508:2PP80PH611P1oOgl20820P0<0QHF50P2;
Rh/308b<S3@0b>3H0`0];Bd202XZ:P<0;2`/0P0a<C4302l_;`<0=3@d0P0c<c<302TY:@80;Rh^0`0c
<c<3030`<080;Rh^0`0_;bl202`/;0<0;bl_0P0d=3@303De=@<0<S8b0P0f=SH302d];@809RHV0`0W
9bL302HV9P8071`L0`0N7Qh202<S8`<09RHV0`1IFET208N7Q`<0XJ6Q0P20P80306=SH`<0IVIV0P1c
Lg<30:RXZ080^;Rh1P2SXj<20:RXZ0<0/k>c0P2][Jd30;:b/P<0]KFe0P2m_Kd30<G5a@80b<S80`3;
bl/20<K6aP<0a<C40`2NWYh205UIF@D0DE5A0`1PH60306][J`80KVi^0`1kNg/20820P0<0OWin0`23
Ph<208F5Q@<0QhN70P2>SXh309:BTP<0UIFE1@2=SHd5092@T0<0UYJF0P2DU9@309NGU`80TY:B0`2D
U9@308^;R`80Shn?0`2<S8`208n?S`<0Ti>C0P2FUYH309NGU`<0T92@0P24Q8@308>3P`80S8b<0`29
RHT308:2PP80O7al0`1nOWh208B4Q0<0Ogmo1@28R8P508F5Q@<0MgMg0`2<S8`209FEU@<0SXj>0P2@
T9030:2PX0D0VIVI202FUYH5096AT@<0UYJF0P2EUID308n?S`80Ph>30`1gMgL307YjNP80P8200`21
PH4208R8R0<0Q8B40`25QHD207inOPD0Ph>30`20P80307emO@80P8200`26QXH208V9R@<0TI6A7038
h=P001/0b>3H1@0^;Rh302l_;`80<C4a0`0c<c<3038b<P80<30`0`0^;Rh202`/;0<0;Rh^0`0a<C42
02l_;`<0;Bd]0P0^;Rh302l_;`80<C4a0`0d=3@303De=@80=3@d0`0^;Rh202LW9`<092@T0`0R8R82
020P80D07alO0`0W9bL305UIF@80QHF50`2UYJD207UiN@<0Jf][0`1VIVH206][J`<0/K6a0P2][Jd3
0:NWY`<0Z:RX0P2ZZZX30:f][@80/K6a0`2c/k<30;Jf]P80_[jn0`36a/H20<S8b0<0alO70P3>c/h3
0<G5a@<0WIfM0P1DE5@305UIF@80CTi>0`1LG5`306][J`80Lg=c0`1iNGT207inOP<0PH610`23Ph<2
08F5Q@<0R8R80P2<S8`3092@T0<0Ti>C0P2@T90308f=S@80Shn?0`2BTY8309BDU080UIFE0`2FUYH2
09FEU@<0TI6A0`2>SXh508b<S080Shn?0`2CTi<209NGU`<0V9RH0`2?Shl208F5Q@<0R8R80P2;Rh/3
08N7Q`<0PX:21`20P80308B4Q0<0R8R80P2<S8`308R8R080S8b<0`1`L70309BDU080TI6A0`2BTY82
09NGU`<0W9bL0`2KVi/209RHV0<0UiNG0P2FUYH309>CT`<0T92@0P2BTY8509BDU0<0Shn?0P22PX83
07IfMP<0NGUi0P20P80308>3P`80QXJ60`25QHD308>3P`D0PX:20P21PH4607moO`80P8200`25QHD2
08^;R`<0S8b<=038h=P302d];@80:RXZ0`0/;2`2034a<@<0;bl_0`0d=3@203<c<`<0:BTY0P0^;Rh3
03<c<`<0<30`0P0^;Rh302l_;`80;2`/0`0_;bl203@d=0<0=CDe0`0b<S8203Hf=P<0;Bd]0P0V9RH3
02LW9`<09RHV0P0L71`301hN7P808b<S0`0V9RH305UIF@80QhN70`2QXJ420820P0<0Hf=S0`1VIVH2
07=cL`<0Z:RX0P2h^;P60:>SX`80Z:RX0`2c/k<20:f][@<0/[:b0`2e]KD20;fm_@<0aLG50P38b<P3
0<_;b`80a/K60`34a<@309jNWP80FEUI1@1ADE43061PH0<0Jf][0P1^KVh307]kN`80P8200`1nOWh3
08>3P`80QHF50`27QhL208j>SP<0TY:B0`2EUID508f=S@D0T92@0`2FUYH209BDU0<0UiNG0P2BTY83
09BDU0<0Rh^;0P2?Shl308b<S080Shn?0`2CTi<209JFUP<0UiNG0`2@T90208B4Q0<0Ph>30P2<S8`3
08V9R@<0PX:20P1lO7`307inOP80Q8B40`1oOgl508R8R0D0QHF50`1gMgL308b<S080UIFE0`2>SXh2
092@T0<0X:2P1@2IVIT809JFUPD0TI6A0`2FUYH209FEU@<0Shn?0P23Ph<307MgM`<0NWYj0P20P803
0861P@80R8R80`24Q8@308F5Q@80OWin1@23Ph<30820P0<0OGem0P20P80308J6QP80RHV90`2ATI4L
0<SPf0006`38h=P302/[:`80;Bd]200_;bl302h^;P80;Bd]1@0/;2`302l_;`<0<C4a0P0_;bl302`/
;080;Bd]0`0`<30203<c<`H0=CDe0P0c<c<302`/;0809RHV1P0U9BD202<S8`<08B4Q0P0N7Qh301lO
7`<0@4100P1TI6@309>CT`80Shn?0`1cLg<305iNGP80IVIV0`2CTi<20;Ng]`<0/k>c0`2/[:`20:6Q
X@<0YjNW0P2`/;030;>c/`<0]KFe0P2l_;`30<?3``80a/K60`38b<P20<g=c@<0b/[:0`2i^KT209bL
W0<0EEEE1@1JFUX306MWI`80Kfm_0`1hN7P207alO0<0P8200`23Ph<208J6QP<0R8R80P2;Rh/308j>
SP<0T92@0P2>SXh308b<S080SXj>0`2@T90309:BTP80Ti>C0`2BTY82096AT@<0T92@0`2?Shl508j>
SP80T92@0`2CTi<209FEU@<0U9BD0`2:RXX20820P0<0Ogmo0P20P8030861P@<0Ogmo0P1dM7@306YZ
JP80Q8B40`1oOgl308J6QP80QHF50`2>SXh207MgM`<0Kfm_0`28R8P20820P0<0Ng]k0P2<S8`309fM
W@<0VYZJ0P2CTi<309RHV080WIfM0`2KVi/309RHV080UIFE0`2CTi<208j>SP<0R8R80P1nOWh307If
MP<0N7Qh0P1lO7`30861P@D0Q8B40`23Ph<508:2PPD0PH610`1oOgl20820P0<0QhN70P2?Shl3092@
T3@0b>3H0`0^;Rh2034a<@<0<c<c0P14A4@602TY:@80:b/[1@0_;bl302h^;P<0;Bd]0P0^;Rh302XZ
:PD0;2`/0P0`<303038b<P<0=SHf0P0d=3@302d];@80:2PX0`0U9BD302HV9P808b<S1@0R8R8302<S
8`<0<S8b0P1[Jf/308f=S@80UIFE0`1^KVh3069RHP80JFUY0`2@T9020;^k^`<0]kNg0`2RXZ820:6Q
X@<0/;2`0P2][Jd30;Jf]P<0^;Rh0P2l_;`50<C4a0<0bl_;0P39bLT60<G5a@80VYZJ0`1IFET2055A
D@<0GemO0`1VIVH206i^KP<0MWIf0P1lO7`30861P@<0PX:20P29RHT308F5Q@80S8b<0`2=SHd309>C
T`80QHF50`2=SHd208^;R`<0TI6A0`2DU9@209>CT`<0TY:B0P2>SXh309:BTP<0SHf=0P2ATI45092@
T0<0UYJF0P2EUID309BDU0<0SXj>0P23Ph<307MgM`D0PH610`1kNg/2075aL@<0KVi^0P26QXH307mo
O`<0R8R80P2:RXX308n?S`80Ng]k0`1/K6`308J6QP80RXZ:0`21PH4208J6QP<0YZJV1@2BTY8309NG
U`80VIVI0`2GUiL309VIV@80TY:B1@2>SXh308B4Q080Ogmo0`1eMGD307UiN@80Ogmo1@23Ph<608B4
Q080Ogmo0`21PH4208>3P`<0OWin0`1oOgl208:2PP<0R8R80P2:RXX3096ATA`0b>3H000K0<SPf0<0
:b/[0P0];Bd802l_;`<0;Rh^0P0];Bd502`/;0<0;bl_0`0a<C4202l_;`<0;2`/0P0];Bd3030`<080
<c<c1P0e=CD203<c<`<0;2`/0P0V9RH602DU9@808b<S0`0Q8B4201hN7P<07alO0`10@40206ATI0<0
Ti>C0P2?Shl307=cL`<0GUiN0P1VIVH309>CT`80]kNg0`2c/k<30:b/[080XJ6Q0`2WYjL20;2`/0<0
/k>c0`2e]KD20;bl_0<0`l?30P36a/H30<S8b080cLg=0`3:b/X30;Vi^@80W9bL0`1EEED505YJFP<0
IfMW0P1_Kfl307QhN080O7al0`20P80308>3P`80QXJ60`28R8P208^;R`<0SXj>0`2@T90208j>SP<0
S8b<0P2>SXh3092@T0<0TY:B0P2CTi<309:BTP80TI6A0`2@T90308n?S`D0SXj>0P2@T90309>CT`80
UIFE0`2DU9@308Z:RP80P8200`1oOgl20820P0<0PH610`1oOgl207AdM0<0JVYZ0P24Q8@307moO`<0
QXJ60P25QHD308j>SP80MgMg0`1_Kfl308R8R080P8200`1kNg/208b<S0<0WIfM0`2JVYX209>CT`<0
V9RH0P2MWId309^KV`<0V9RH0P2EUID309>CT`80SXj>0`28R8P207inOP<0MWIf0`1hN7P207alO0<0
PH611@24Q8@308>3P`D0PX:21@21PH4307moO`80P8200`27QhL208n?S`<0T92@=038h=P302h^;P80
<C4a0`0c<c<204A4A0H0:BTY0P0[:b/502l_;`<0;Rh^0`0];Bd202h^;P<0:RXZ1@0/;2`2030`<0<0
<S8b0`0f=SH203@d=0<0;Bd]0P0X:2P302DU9@<09RHV0P0S8b<5028R8P<08b<S0`0b<S8206][J`<0
SHf=0P2EUID306i^KP<0HV9R0P1YJFT3092@T080^k^k0`2g]kL30::RXP80XJ6Q0`2`/;020:f][@<0
][Jf0`2h^;P20;bl_0D0a<C40`3;bl/20<W9b@H0aLG50P2JVYX305UIF@80DE5A0`1OGel306IVIP80
KVi^0`1fMWH207alO0<0PH610`22PX8208V9R@<0QHF50P2<S8`308f=S@<0Ti>C0P25QHD308f=S@80
Rh^;0`2ATI4309BDU080Ti>C0`2BTY8208j>SP<0TY:B0`2=SHd2096AT@D0T92@0`2FUYH209FEU@<0
U9BD0`2>SXh208>3P`<0MgMg1@21PH4307]kN`80LG5a0`1^KVh208J6QP<0Ogmo0`28R8P208Z:RP<0
Shn?0P1kNg/306a/K0<0QXJ60P2:RXX30861P@80QXJ60`2VYZH509:BTP<0UiNG0P2IVIT309NGU`<0
VIVI0P2BTY8508j>SP<0Q8B40P1oOgl307EeM@<0NGUi0P1oOgl508>3P`H0Q8B40P1oOgl30861P@80
Ph>30`1nOWh307moO`80PX:20`28R8P208Z:RP<0TI6A7038h=P001/0b>3H0`0[:b/202d];@P0;bl_
0`0^;Rh202d];@D0;2`/0`0_;bl3034a<@80;bl_0`0/;2`202d];@<0<30`0P0c<c<603De=@80<c<c
0`0/;2`202HV9PH09BDU0P0S8b<3024Q8@807QhN0`0O7al30410@080I6AT0`2CTi<208n?S`<0Lg=c
0`1NGUh206IVIP<0Ti>C0P2g]kL30;>c/`<0[:b/0P2QXJ430:NWY`80/;2`0`2c/k<30;Fe]@80_;bl
0`33`l<20<K6aP<0b<S80P3=cLd30<[:bP<0^KVi0P2LW9`305EEE@D0FUYJ0`1WIfL206m_K`<0N7Qh
0P1lO7`30820P0<0Ph>30P26QXH308R8R080Rh^;0`2>SXh3092@T080SXj>0`2<S8`208j>SP<0T92@
0`2BTY8209>CT`<0TY:B0P2ATI43092@T0<0Shn?1@2>SXh2092@T0<0Ti>C0P2EUID309BDU0<0RXZ:
0P20P80307moO`80P8200`21PH4307moO`80M7Ad0`1ZJVX208B4Q0<0Ogmo0`26QXH208F5Q@<0SXj>
0P1gMgL306m_K`<0R8R80P20P80307]kN`80S8b<0`2MWId309ZJVP80Ti>C0`2HV9P209fMW@<0Vi^K
0`2HV9P209FEU@<0Ti>C0P2>SXh308R8R080OWin0`1fMWH307QhN080O7al0`21PH4508B4Q0<0Ph>3
1@22PX850861P@<0Ogmo0P20P80308N7Q`80Shn?0`2@T90d0<SPf0<0;Rh^0P0a<C4303<c<`80A4A4
1P0Y:BT202/[:`D0;bl_0`0^;Rh302d];@80;Rh^0`0Z:RX502`/;080<30`0`0b<S8303Hf=P80=3@d
0`0];Bd202PX:0<09BDU0`0V9RH202<S8`D08R8R0`0S8b<3038b<P80Jf][0`2=SHd209FEU@<0KVi^
0`1RHV8206UYJ@<0T92@0P2k^k/30;Ng]`<0XZ:R0P2QXJ430;2`/080[Jf]0`2f][H30;Rh^080_;bl
1@34a<@30<_;b`80bLW91P35aLD209ZJVP<0FEUI0P1ADE4305mOG`<0IVIV0P1^KVh307IfMP80O7al
0`21PH4308:2PP80RHV90`25QHD208b<S0<0SHf=0`2CTi<208F5Q@<0SHf=0P2;Rh/3096AT@<0U9BD
0P2CTi<309:BTP80SXj>0`2BTY8308f=S@80TI6A1@2@T90309JFUP80UIFE0`2DU9@308j>SP80Ph>3
0`1gMgL50861P@<0Ng]k0P1aLG4306i^KP80QXJ60`1oOgl308R8R080RXZ:0`2?Shl207]kN`<0K6a/
0`26QXH208Z:RP<0PH610P26QXH30:JVYPD0TY:B0`2GUiL209VIV@<0UiNG0`2IVIT209:BTPD0SXj>
0`24Q8@207moO`<0MGEe0`1iNGT207moO`D0Ph>31P24Q8@207moO`<0PH610P23Ph<307inOP<0Ogmo
0P22PX8308R8R080RXZ:0`2ATI4L0<SPf0006`38h=P302PX:080;2`/0`0_;bl202d];@/0:b/[0P0/
;2`302l_;`<0<S8b0P0_;bl302`/;080;Bd]0`0`<30203<c<`<0=SHf0`0d=3@2034a<@<0:b/[1@0V
9RH302LW9`809BDU0`0S8b<501hN7P<0;2`/0P13@d<307IfMP80WYjN0`20P80305iNGP80IVIV0`1d
M7@20;bl_0<0_Kfm0`2b/[8209fMW@<0Y:BT0P2_[jl30;:b/P<0]KFe0P2j^[X30<30`080aLG50`39
bLT20<S8b0<0aLG50`39bLT20<;2`P<0Vi^K0P1FEUH305QHF0<0IVIV0P1]KFd307EeM@80NWYj0`1n
OWh308>3P`80QhN70`28R8P208V9R@<0Rh^;202<S8`208f=S@<0Shn?0`2@T902096AT@<0Shn?0P2>
SXh3092@T0<0TY:B0P2ATI45092@T0<0Shn?0P2@T90308j>SP<0QHF50P1kNg/307IfMP80M7Ad0`1j
NWX307emO@80Jf][0`1HF5P208R8R0<0O7al0`25QHD20861P@<0UYJF0P1/K6`307]kN`<0Ph>30P1g
MgL306e]K@80QXJ60`2OWil309^KV`80Ti>C0`2LW9`20:FUY@<0YZJV0`2RXZ8209bLW0<0U9BD0P2:
RXX308:2PP80O7al1P1hN7P207YjNP<0OWin0P22PX8608>3P`80PX:20`21PH4508:2PPD0P8200`29
RHT209:BTP<0U9BD=038h=P302PX:080:b/[0`0];Bd202HV9P<0;Bd]0`0Y:BT202d];@D0;2`/0`0`
<30503@d=0<0:b/[0P0Z:RX302l_;`80>CTi0`0h>3P302l_;`80<30`0`0/;2`202<S8`<09bLW0`0V
9RH502<S8`808R8R0`0Q8B4302HV9P80ATI60`1lO7`209VIV@<0P8200`1RHV8205aLG0<0Ogmo0P2c
/k<30<?3``<0[Jf]0P2OWil30:VYZ@80ZZZZ1P2c/k<20;Rh^0<0`L710P32`/830<S8b080b/[:0`35
aLD30<O7a`80`L710`2FUYH205UIF@<0De=C0`1YJFT206a/K0<0M7Ad1@1nOWh308>3P`80R8R80`25
QHD208Z:RPH0SHf=0P2:RXX508j>SP<0T92@1@2?Shl3096AT@80SXj>0`2<S8`3096AT@80UIFE0`2?
Shl208b<S0<0T92@0P2=SHd308j>SP<0QHF50P21PH4306e]K@80MgMg0`20P80307YjNP80KVi^0`1L
G5`50820P0<0RHV90P26QXH308^;R`80LG5a0`1^KVh30820P080Ng]k0`1VIVH207emO@<0YZJV0`2H
V9P209>CT`<0W9bL0P2UYJD30::RXP<0Xj>S0P2IVIT309NGU`80RXZ:0`23Ph<207inOP<0NWYj0`1g
MgL207YjNP<0O7al0P22PX8608B4Q080OGem0`23Ph<20820P0<0PH610`20P80207inOP<0RXZ:0P2D
U9@309FEUA`0b>3H000K0<SPf0<0:2PX0P0/;2`302l_;`80;Bd]2`0[:b/202`/;0<0;bl_0`0b<S82
02l_;`<0;2`/0P0];Bd3030`<080<c<c0`0f=SH303@d=080<C4a0`0[:b/502HV9P<09bLW0P0U9BD3
02<S8`D07QhN0`0/;2`204=3@`<0MWIf0P2NWYh30820P0<0GUiN0P1VIVH307AdM080_;bl0`2m_Kd3
0;:b/P80WIfM0`2TY:@20:n_[`<0/[:b0`2e]KD20;Zj^P<0`<300P35aLD30<W9b@80b<S80`35aLD3
0<W9b@80`/;20`2KVi/205IFEP<0F5QH0`1VIVH206e]K@<0MGEe0P1jNWX307inOP<0Ph>30P27QhL3
08R8R080RHV90`2;Rh/808b<S080SHf=0`2?Shl3092@T080TI6A0`2?Shl208j>SP<0T92@0`2BTY82
096AT@D0T92@0`2?Shl2092@T0<0SXj>0`25QHD207]kN`<0MWIf0P1dM7@307YjNP<0OGem0P1[Jf/3
05QHF080R8R80`1lO7`308F5Q@80PH610`2FUYH206a/K0<0Ng]k0`23Ph<207MgM`<0KFe]0P26QXH3
09nOW`<0Vi^K0P2CTi<309bLW080YJFU0`2VYZH30::RXP80W9bL0`2DU9@208Z:RP<0PX:20P1lO7`6
07QhN080NWYj0`1nOWh208:2PPH0Ph>30P22PX830861P@D0PX:21@20P80308V9R@80TY:B0`2DU9@d
0<SPf0<0:2PX0P0[:b/302d];@809RHV0`0];Bd302TY:@80;Bd]1@0/;2`3030`<0D0=3@d0`0[:b/2
02XZ:P<0;bl_0P0i>CT303Ph>0<0;bl_0P0`<30302`/;0808b<S0`0W9bL302HV9PD08b<S0P0R8R83
024Q8@<09RHV0P16ATH307alO080VIVI0`20P803069RHP80G5aL0`1oOgl20;>c/`<0`l?30`2][Jd2
09nOW`<0ZJVY0P2ZZZX60;>c/`80^;Rh0`31`L420<;2`P<0b<S80P3:b/X30<G5a@<0alO70P31`L43
09JFUP80FEUI0`1CDe<306UYJ@80K6a/0`1dM7@507inOP<0Ph>30P28R8P308F5Q@80RXZ:1P2=SHd2
08Z:RPD0SXj>0`2@T90508n?S`<0TI6A0P2>SXh308b<S0<0TI6A0P2EUID308n?S`80S8b<0`2@T902
08f=S@<0SXj>0`25QHD20861P@<0KFe]0P1gMgL30820P0<0NWYj0P1^KVh305aLG0D0P8200`29RHT2
08J6QP<0Rh^;0P1aLG4306i^KP<0P8200P1kNg/306IVIP80OGem0`2VYZH309RHV080Ti>C0`2LW9`2
0:FUY@<0XZ:R0`2SXj<209VIV@<0UiNG0P2:RXX308>3P`80OWin0`1jNWX307MgM`80NWYj0`1lO7`2
08:2PPH0Q8B40P1mOGd308>3P`80P8200`21PH430820P080OWin0`2:RXX209BDU0<0UIFE7038h=P0
01/0b>3H0`0X:2P202`/;0<0;bl_0P0];Bd;02/[:`80;2`/0`0_;bl3038b<P80;bl_0`0/;2`202d]
;@<0<30`0P0c<c<303Hf=P<0=3@d0P0a<C4302/[:`D09RHV0`0W9bL202DU9@<08b<S1@0N7Qh302`/
;080@d=30`1fMWH209jNWP<0P8200`1NGUh206IVIP<0M7Ad0P2l_;`30;fm_@<0/[:b0P2MWId30:BT
Y080[jn_0`2b/[830;Fe]@80^[Zj0`30`<020<G5a@<0bLW90P38b<P30<G5a@<0bLW90P32`/8309^K
V`80EUIF0`1HF5P306IVIP80KFe]0`1eMGD207YjNP<0OWin0`23Ph<208N7Q`<0R8R80P29RHT308^;
R`P0S8b<0P2=SHd308n?S`<0T92@0P2ATI4308n?S`80SXj>0`2@T90309:BTP80TI6A1@2@T90308n?
S`80T92@0`2>SXh308F5Q@80Ng]k0`1fMWH207AdM0<0NWYj0`1mOGd206][J`<0F5QH0P28R8P307al
O0<0QHF50P21PH4309JFUP80K6a/0`1kNg/308>3P`80MgMg0`1]KFd208J6QP<0WinO0`2KVi/209>C
T`<0W9bL0P2UYJD30:JVYP<0XZ:R0P2LW9`309BDU080RXZ:0`22PX8207alO0H0N7Qh0P1jNWX307in
OP80PX:21P23Ph<208:2PP<0PH611@22PX850820P0<0RHV90P2BTY8309BDU3@0b>3H0`0X:2P202/[
:`<0;Bd]0P0V9RH302d];@<0:BTY0P0];Bd502`/;0<0<30`1@0d=3@302/[:`80:RXZ0`0_;bl203Ti
>@<0>3Ph0`0_;bl2030`<0<0;2`/0P0S8b<302LW9`<09RHV1@0S8b<2028R8P<08B4Q0`0V9RH204I6
AP<0O7al0P2IVIT30820P0<0HV9R0P1LG5`307moO`80/k>c0`33`l<30:f][@80WinO0`2YZJT20:ZZ
ZPH0/k>c0P2h^;P30<71`@80`/;20`38b<P20<[:bP<0aLG50`37alL20<71`@<0UYJF0P1IFET305=C
D`<0JFUY0P1/K6`307AdM0D0OWin0`23Ph<208R8R0<0QHF50P2:RXX608f=S@80RXZ:1@2>SXh3092@
T0D0Shn?0`2ATI4208j>SP<0S8b<0`2ATI4209FEU@<0Shn?0P2<S8`3092@T080SHf=0`2>SXh308F5
Q@80PH610`1]KFd207MgM`<0P8200`1jNWX206i^KP<0G5aL1@20P80308V9R@80QXJ60`2;Rh/2075a
L@<0KVi^0`20P80207]kN`<0IVIV0P1mOGd30:JVYP<0V9RH0P2CTi<309bLW080YJFU0`2RXZ830:>S
X`80VIVI0`2GUiL208Z:RP<0Ph>30P1nOWh307YjNP<0MgMg0P1jNWX307alO080PX:21P24Q8@207em
O@<0Ph>30P20P8030861P@<0P8200P1nOWh308Z:RP80U9BD0`2EUIDL0<SPf0006`38h=P:02XZ:P<0
:b/[0`0/;2`502d];@80;Rh^0`0_;bl3030`<080;Rh^1@0/;2`302d];@80<30`1P0c<c<2034a<@<0
;bl_0P0/;2`302PX:0P09BDU0P0Q8B43020P80<08R8R0P0`<303055AD@80T92@0`2GUiL307=cL`80
EeMG0`1VIVH20:BTY0<0`<300`2j^[X20:VYZ@<0Z:RX0P2YZJT30:j^[P<0];Bd0P2i^KT30;fm_@80
`l?30`37alL20<W9b@<0b<S80`3;bl/20<W9b@<0/[:b0P2=SHd3071`L0<0G5aL0P1RHV8306m_K`80
MWIf0`1lO7`30820P080Ph>30`25QHD208J6QP<0QhN70`28R8P508N7Q`80Rh^;0`2?Shl5092@T0<0
Shn?0P2>SXh3092@T0<0TY:B0P2?Shl308b<S080QhN70`23Ph<208N7Q`<0RHV90`24Q8@207alO0<0
LG5a0P1YJFT3079bLP<0NWYj0P1YJFT305YJFP80O7al0`20P80308Z:RP80QhN70`23Ph<205eMG@<0
K6a/0`1fMWH206QXJ0<0GUiN0P20P8030:>SX`<0YJFU0P2QXJ430:JVYP80[:b/0`2][Jd30:^[Z`80
YJFU0`2LW9`2096AT@<0QhN70P1oOgl307]kN`<0NWYj1@1lO7`207emO@<0Ogmo0`21PH450820P080
PH610`23Ph<30861P@80PX:20`2:RXX209>CT`<0U9BD=038h=P302`/;0809RHV0`0Z:RX202d];@<0
;Rh^0`0[:b/2030`<0<0;bl_0P0[:b/302d];@<0;Rh^0P0a<C4302l_;`D0<30`0P0c<c<3038b<P<0
>CTi0P0c<c<302h^;P80:b/[0`0a<C4302@T90809RHV0`0R8R8202<S8`H0820P0P0Z:RX305iNGP80
RHV90`2LW9`306m_K`80FEUI0`1WIfL209bLW0<0`<300`32`/820::RXP<0Y:BT0P2XZ:P30:n_[`<0
/;2`0P2k^k/30;fm_@80`/;20`38b<P20<k>cP<0a/K60`35aLD20<K6aP<0`/;20P2FUYH6061PH080
JFUY0`1^KVh207IfMP<0N7Qh0`1oOgl208F5Q@<0Ph>30P26QXH308^;R`<0Q8B40P27QhL508V9R@<0
Shn?0`2=SHd209:BTP<0TI6A0P2@T90308n?S`D0TY:B0`29RHT208J6QP<0Q8B40P28R8P308Z:RP<0
Ph>30P1jNWX306e]K@80J6QX0`1gMgL307emO@80I6AT0`1IFET207IfMP<0PH610`22PX8208B4Q0<0
Ogmo0P1YJFT306YZJP<0P8200P1cLg<306EUI@80Ogmo0`2OWil30:>SX`80Z:RX0`2WYjL20;>c/`H0
[jn_0P2XZ:P309jNWP80T92@0`28R8P207emO@<0MgMg0`1mOGd207QhN0<0OWin0P1lO7`60861P@80
PX:20`23Ph<208B4Q0<0QhN70`22PX820861P@<0RXZ:0P2?Shl309JFUQ`0b>3H000K0<SPf0X0:RXZ
0`0[:b/302`/;0D0;Bd]0P0^;Rh302l_;`<0<30`0P0^;Rh502`/;0<0;Bd]0P0`<30603<c<`80<C4a
0`0_;bl202`/;0<0:2PX200U9BD2024Q8@<0820P0`0R8R82030`<0<0DE5A0P2@T90309NGU`<0Lg=c
0P1GEeL306IVIP80Y:BT0`30`<030;Zj^P80ZJVY0`2XZ:P20:VYZ@<0[Zj^0`2d];@20;Vi^@<0_Kfm
0P33`l<30<O7a`80bLW90`38b<P30<_;b`80bLW90`2b/[8208f=S@<0L71`0`1LG5`2069RHP<0Kfm_
0P1fMWH307alO0<0P8200P23Ph<308F5Q@80QXJ60`27QhL308R8R0D0QhN70P2;Rh/308n?S`D0T92@
0`2?Shl208j>SP<0T92@0`2BTY8208n?S`<0S8b<0P27QhL308>3P`80QhN70`29RHT308B4Q080O7al
0`1aLG4206UYJ@<0LW9b0`1jNWX206UYJ@<0FUYJ0P1lO7`30820P0<0RXZ:0P27QhL308>3P`80GEeM
0`1/K6`307IfMP80J6QX0`1NGUh20820P0<0Xj>S0`2UYJD20:6QX@<0YZJV0P2/[:`30:f][@<0Zj^[
0P2UYJD309bLW080TI6A0`27QhL207moO`<0Ng]k0`1jNWX507alO080OGem0`1oOgl30861P@D0P820
0P21PH4308>3P`<0PH610P22PX8308Z:RP80Ti>C0`2DU9@d0<SPf0<0;2`/0P0V9RH302XZ:P80;Bd]
0`0^;Rh302/[:`80<30`0`0_;bl202/[:`<0;Bd]0`0^;Rh2034a<@<0;bl_1@0`<30203<c<`<0<S8b
0`0i>CT203<c<`<0;Rh^0P0[:b/3034a<@<092@T0P0V9RH3028R8P808b<S1P0P820202XZ:P<0GUiN
0P29RHT309bLW0<0Kfm_0P1IFET306MWI`80W9bL0`30`<030<;2`P80XZ:R0`2TY:@20:RXZ0<0[jn_
0`2`/;020;^k^`<0_Kfm0P32`/830<S8b080c/k>0`36a/H30<G5a@80a/K60`32`/8209JFUPH0H61P
0P1YJFT306i^KP80MWIf0`1hN7P307moO`80QHF50`23Ph<208J6QP<0Rh^;0`24Q8@208N7Q`D0RHV9
0`2?Shl308f=S@80TY:B0`2ATI42092@T0<0Shn?1@2BTY8308V9R@80QXJ60`24Q8@208R8R0<0RXZ:
0`23Ph<207YjNP<0KFe]0P1XJ6P307MgM`<0OGem0P1TI6@305UIF@80MWIf0`21PH4308:2PP80Q8B4
0`1oOgl206UYJ@<0JVYZ0`20P80207=cL`<0IFEU0P1oOgl309nOW`<0Xj>S0P2XZ:P30:NWY`80/k>c
1P2_[jl20:RXZ0<0WYjN0P2@T90308R8R080OGem0`1gMgL307emO@80N7Qh0`1nOWh207alO0H0PH61
0P22PX8308>3P`80Q8B40`27QhL308:2PP80PH610`2:RXX208n?S`<0UYJF7038h=P001/0b>3H0`0/
;2`202PX:0<09BDU0P0W9bL302/[:`<0;Rh^1`0`<30302l_;`<0;Rh^1@0_;bl202d];@<0:b/[0P0]
;Bd3030`<0D0<C4a0`0c<c<2038b<P<0:b/[0`0S8b<202@T90<09RHV0P0T92@302<S8`<07QhN0P0V
9RH3030`<080MgMg0`2TY:@308^;R`80DE5A0`1OGel208N7Q`<0^[Zj0`2o_kl20;Vi^@<0[Zj^0P2T
Y:@30:VYZ@<0/[:b0P2g]kL30;^k^`80`<300`34a<@20<W9b@<0bl_;0`38b<P20<;2`P<0a/K60P31
`L4308n?S`<0GemO0P1MGEd306UYJ@80LG5a0`1jNWX307emO@80Ogmo0`21PH4208>3P`H0Q8B41@22
PX8208R8R0<0Shn?1@2@T90308n?S`80SXj>1P2?Shl208^;R`<0QHF50P1lO7`307IfMP80Ng]k0`21
PH430820P080Ng]k0`1^KVh206ATI0<0KVi^0`1iNGT206m_K`<0IVIV0P1cLg<308N7Q`<0SHf=1@2?
Shl209BDU0<0WinO0`2XZ:P209nOW`<0UYJF0P2LW9`30:JVYP<0ZJVY0P2[Zj/30:b/[080[Zj^1P2_
[jl20:VYZ@<0X:2P0P2FUYH308b<S080Q8B40`1nOWh507emO@<0NWYj0P1gMgL307YjNP<0OWin1@1o
Ogl20861P@H0Ph>30P24Q8@308^;R`80TY:B0`2DU9@d0<SPf0<0<30`0P0Z:RX302<S8`80:BTY0`0Z
:RX302l_;`80;2`/0`0f=SH202d];@<0;Rh^0`0_;bl5030`<080:b/[0`0Z:RX202/[:`<0<S8b0`0/
;2`203Xj>P<0;Bd]0P0i>CT302PX:0<092@T0P0U9BD302@T90809BDU0`0S8b<5028R8P<0>CTi0P1g
MgL309bLW0<0QhN70P1OGel3065QH@80PH610`2g]kL30<[:bP80^KVi0`2VYZH20:NWY`<0ZZZZ0`2a
/K420;Jf]P<0^[Zj0P2n_[h30<?3``80b/[:0`3;bl/30<W9b@D0`/;20P2o_kl308Z:RP<0GUiN0P1O
Gel306QXJ080MGEe0`1gMgL30861P@80PX:20`1lO7`208:2PP<0RXZ:0`21PH4208N7Q`<0PX:20P25
QHD309:BTP<0SXj>1@2?Shl208f=S@H0Shn?0P2=SHd308J6QP80N7Qh0`1fMWH207emO@<0OWin0`1o
Ogl207inOP<0K6a/0P1]KFd306][J`<0O7al0P1_Kfl3061PH080NWYj0`25QHD308R8R080TY:B0`2F
UYH2096AT@<0Ti>C0`2WYjL20:2PX0<0SHf=0P2OWil30::RXP<0Y:BT0P2_[jl50:b/[0<0Zj^[0`2^
[Zh20:f][@<0WinO0P2DU9@308b<S080Ph>30`1nOWh30820P080O7al0`1oOgl207AdM0<0Ng]k0`22
PX8207]kN`<0OWin0P20P80608>3P`80QXJ60`2=SHd209:BTP<0UIFE7038h=P001/0b>3H0`0/;2`2
02PX:0<09BDU0P0W9bL302/[:`<0;Rh^1`0`<30302l_;`<0;Rh^1@0_;bl202d];@<0:b/[0P0];Bd3
030`<0D0<C4a0`0c<c<2038b<P<0:b/[0`0S8b<202@T90<09RHV0P0T92@302<S8`<07QhN0P0V9RH3
030`<080MgMg0`2TY:@308^;R`80DE5A0`1OGel208N7Q`<0^[Zj0`2o_kl20;Vi^@<0[Zj^0P2TY:@3
0:VYZ@<0/[:b0P2g]kL30;^k^`80`<300`34a<@20<W9b@<0bl_;0`38b<P20<;2`P<0a/K60P31`L43
08n?S`<0GemO0P1MGEd306UYJ@80LG5a0`1jNWX307emO@80Ogmo0`21PH4208>3P`H0Q8B41@22PX82
08R8R0<0Shn?1@2@T90308n?S`80SXj>1P2?Shl208^;R`<0QHF50P1lO7`307IfMP80Ng]k0`21PH43
0820P080Ng]k0`1^KVh206ATI0<0KVi^0`1iNGT206m_K`<0IVIV0P1cLg<308N7Q`<0SHf=1@2?Shl2
09BDU0<0WinO0`2XZ:P209nOW`<0UYJF0P2LW9`30:JVYP<0ZJVY0P2[Zj/30:b/[080[Zj^1P2_[jl2
0:VYZ@<0X:2P0P2FUYH308b<S080Q8B40`1nOWh507emO@<0NWYj0P1gMgL307YjNP<0OWin1@1oOgl2
0861P@H0Ph>30P24Q8@308^;R`80TY:B0`2DU9@d0<SPf0<0<30`0P0Z:RX302<S8`80:BTY0`0Z:RX3
02l_;`80;2`/0`0f=SH202d];@<0;Rh^0`0_;bl5030`<080:b/[0`0Z:RX202/[:`<0<S8b0`0/;2`2
03Xj>P<0;Bd]0P0i>CT302PX:0<092@T0P0U9BD302@T90809BDU0`0S8b<5028R8P<0>CTi0P1gMgL3
09bLW0<0QhN70P1OGel3065QH@80PH610`2g]kL30<[:bP80^KVi0`2VYZH20:NWY`<0ZZZZ0`2a/K42
0;Jf]P<0^[Zj0P2n_[h30<?3``80b/[:0`3;bl/30<W9b@D0`/;20P2o_kl308Z:RP<0GUiN0P1OGel3
06QXJ080MGEe0`1gMgL30861P@80PX:20`1lO7`208:2PP<0RXZ:0`21PH4208N7Q`<0PX:20P25QHD3
09:BTP<0SXj>1@2?Shl208f=S@H0Shn?0P2=SHd308J6QP80N7Qh0`1fMWH207emO@<0OWin0`1oOgl2
07inOP<0K6a/0P1]KFd306][J`<0O7al0P1_Kfl3061PH080NWYj0`25QHD308R8R080TY:B0`2FUYH2
096AT@<0Ti>C0`2WYjL20:2PX0<0SHf=0P2OWil30::RXP<0Y:BT0P2_[jl50:b/[0<0Zj^[0`2^[Zh2
0:f][@<0WinO0P2DU9@308b<S080Ph>30`1nOWh30820P080O7al0`1oOgl207AdM0<0Ng]k0`22PX82
07]kN`<0OWin0P20P80608>3P`80QXJ60`2=SHd209:BTP<0UIFE7038h=P001/0b>3H0`0/;2`202PX
:0<09BDU0P0W9bL302/[:`<0;Rh^1`0`<30302l_;`<0;Rh^1@0_;bl202d];@<0:b/[0P0];Bd3030`
<0D0<C4a0`0c<c<2038b<P<0:b/[0`0S8b<202@T90<09RHV0P0T92@302<S8`<07QhN0P0V9RH3030`
<080MgMg0`2TY:@308^;R`80DE5A0`1OGel208N7Q`<0^[Zj0`2o_kl20;Vi^@<0[Zj^0P2TY:@30:VY
Z@<0/[:b0P2g]kL30;^k^`80`<300`34a<@20<W9b@<0bl_;0`38b<P20<;2`P<0a/K60P31`L4308n?
S`<0GemO0P1MGEd306UYJ@80LG5a0`1jNWX307emO@80Ogmo0`21PH4208>3P`H0Q8B41@22PX8208R8
R0<0Shn?1@2@T90308n?S`80SXj>1P2?Shl208^;R`<0QHF50P1lO7`307IfMP80Ng]k0`21PH430820
P080Ng]k0`1^KVh206ATI0<0KVi^0`1iNGT206m_K`<0IVIV0P1cLg<308N7Q`<0SHf=1@2?Shl209BD
U0<0WinO0`2XZ:P209nOW`<0UYJF0P2LW9`30:JVYP<0ZJVY0P2[Zj/30:b/[080[Zj^1P2_[jl20:VY
Z@<0X:2P0P2FUYH308b<S080Q8B40`1nOWh507emO@<0NWYj0P1gMgL307YjNP<0OWin1@1oOgl20861
P@H0Ph>30P24Q8@308^;R`80TY:B0`2DU9@d0<SPf0<0<30`0P0Z:RX302<S8`80:BTY0`0Z:RX302l_
;`80;2`/0`0f=SH202d];@<0;Rh^0`0_;bl5030`<080:b/[0`0Z:RX202/[:`<0<S8b0`0/;2`203Xj
>P<0;Bd]0P0i>CT302PX:0<092@T0P0U9BD302@T90809BDU0`0S8b<5028R8P<0>CTi0P1gMgL309bL
W0<0QhN70P1OGel3065QH@80PH610`2g]kL30<[:bP80^KVi0`2VYZH20:NWY`<0ZZZZ0`2a/K420;Jf
]P<0^[Zj0P2n_[h30<?3``80b/[:0`3;bl/30<W9b@D0`/;20P2o_kl308Z:RP<0GUiN0P1OGel306QX
J080MGEe0`1gMgL30861P@80PX:20`1lO7`208:2PP<0RXZ:0`21PH4208N7Q`<0PX:20P25QHD309:B
TP<0SXj>1@2?Shl208f=S@H0Shn?0P2=SHd308J6QP80N7Qh0`1fMWH207emO@<0OWin0`1oOgl207in
OP<0K6a/0P1]KFd306][J`<0O7al0P1_Kfl3061PH080NWYj0`25QHD308R8R080TY:B0`2FUYH2096A
T@<0Ti>C0`2WYjL20:2PX0<0SHf=0P2OWil30::RXP<0Y:BT0P2_[jl50:b/[0<0Zj^[0`2^[Zh20:f]
[@<0WinO0P2DU9@308b<S080Ph>30`1nOWh30820P080O7al0`1oOgl207AdM0<0Ng]k0`22PX8207]k
N`<0OWin0P20P80608>3P`80QXJ60`2=SHd209:BTP<0UIFE7038h=P001/0b>3H0`0[:b/202LW9`<0
8b<S0P0U9BD302TY:@<0;Bd]0P0`<303034a<@80<30`1P0_;bl203@d=0<0>CTi0P0d=3@502l_;`H0
<C4a0P0b<S8303De=@80=cLg0`0`<30302TY:@809bLW0`0V9RH202@T90<08b<S0`0Q8B4202LW9`<0
9RHV0P1FEUH308^;R`<0UIFE0P1fMWH305MGE`80LG5a0`2LW9`30;bl_080b/[:0`2e]KD20:2PX0<0
Xj>S0`2][Jd20;:b/P<0^;Rh0P2l_;`30<30`080alO70`3;bl/30<W9b@80a/K61@38b<P30:f][@<0
SXj>0P1aLG4305eMG@80IVIV0`1gMgL307]kN`80OWin0`1oOgl20820P0<0PX:20`23Ph<20820P0<0
Ogmo0P28R8P6096AT@D0T92@0P2?Shl308f=S@<0Rh^;0P26QXH307moO`80MgMg0`1_Kfl206UYJ@<0
IfMW0`1]KFd707AdM0<0OGem0`26QXH208N7Q`<0R8R80P2=SHd309RHV0<0Vi^K0P2OWil30:2PX080
YjNW0`2_[jl30;Bd]080/K6a0`2][Jd20:ZZZP<0Zj^[0`2k^k/20<K6aP<0];Bd0P2OWil609fMW@80
TY:B0`2;Rh/208R8R0<0QhN70P24Q8@308:2PP<0Ogmo0P1lO7`307UiN@80MWIf0`1hN7P307alO080
Ogmo2`22PX8208>3P`<0S8b<0P2DU9@309JFUS@0b>3H0`0X:2P202@T90<09BDU0P0[:b/302DU9@<0
;2`/0P0_;bl303@d=080<S8b0`0a<C43030`<080<C4a0`0h>3P2038b<P<0;Rh^0P0i>CT3030`<0<0
<C4a0P0_;bl302XZ:P80>3Ph0`0_;bl302LW9`809RHV0`0];Bd2028R8P<08B4Q0`0O7al202<S8`<0
;2`/0P1BDU8308B4Q0<0WinO0P1]KFd305IFEP80K6a/0`2KVi/30<;2`P80bl_;0`2_[jl20:>SX`<0
YjNW0`2/[:`20;Jf]P<0^KVi0P2l_;`30;jn_P80b<S80`39bLT30<[:bP80a/K60`34a<@20<G5a@<0
_[jn0`2DU9@2069RHP<0G5aL0P1/K6`307QhN0<0Ng]k0P1lO7`307]kN`80PH610`26QXH307inOP80
PH610`1mOGd208B4Q0H0Ti>C0P2ATI43092@T080Shn?0`2=SHd308N7Q`80R8R80`21PH42071`L0<0
KFe]0P1bLW8306UYJ@<0K6a/0P1hN7P3079bLP80Kfm_0`1dM7@508F5Q@<0Shn?0P2GUiL309^KV`<0
UiNG0P2NWYh30:VYZ@80YjNW0`2/[:`50;:b/P<0ZZZZ0P2a/K430;Bd]0<0^k^k0P2m_Kd30;6a/@80
X:2P0`2KVi/309NGU`80U9BD1@28R8P308V9R@80Q8B40`23Ph<307inOP80NGUi0`1gMgL207UiN@<0
Lg=c0`1hN7P20820P0<0Ph>30P21PH430820P0<0NGUi0P22PX8308f=S@80U9BD0`2GUiLL0<SPf000
6`38h=P302/[:`809bLW0`0S8b<202DU9@<0:BTY0`0];Bd2030`<0<0<C4a0P0`<30602l_;`80=3@d
0`0i>CT203@d=0D0;bl_1P0a<C42038b<P<0=CDe0P0g=cL3030`<0<0:BTY0P0W9bL302HV9P8092@T
0`0S8b<3024Q8@809bLW0`0V9RH205IFEP<0Rh^;0`2EUID207IfMP<0EeMG0P1aLG4309bLW0<0_;bl
0P3:b/X30;Fe]@80X:2P0`2SXj<30:f][@80/[:b0`2h^;P20;bl_0<0`<300P37alL30<_;b`<0bLW9
0P36a/H50<S8b0<0[Jf]0`2>SXh2075aL@<0GEeM0P1VIVH307MgM`<0Ng]k0P1nOWh307moO`80P820
0`22PX8308>3P`80P8200`1oOgl208R8R0H0TI6A1@2@T90208n?S`<0SHf=0`2;Rh/208J6QP<0Ogmo
0P1gMgL306m_K`80JFUY0`1WIfL306e]K@L0M7Ad0`1mOGd308J6QP80QhN70`28R8P208f=S@<0V9RH
0`2KVi/209nOW`<0X:2P0P2WYjL30:n_[`<0];Bd0P2a/K430:f][@80ZZZZ0`2[Zj/30;^k^`80a/K6
0`2d];@209nOW`H0WIfM0P2BTY8308^;R`80R8R80`27QhL208B4Q0<0PX:20`1oOgl207alO0<0NGUi
0P1fMWH307QhN0<0O7al0P1oOgl;08:2PP80Ph>30`2<S8`209BDU0<0UYJF=038h=P302PX:08092@T
0`0U9BD202/[:`<09BDU0`0/;2`202l_;`<0=3@d0P0b<S83034a<@<0<30`0P0a<C4303Ph>080<S8b
0`0^;Rh203Ti>@<0<30`0`0a<C4202l_;`<0:RXZ0P0h>3P302l_;`<09bLW0P0V9RH302d];@808R8R
0`0Q8B4301lO7`808b<S0`0/;2`2059BDP<0Q8B40`2OWil206e]K@<0EUIF0P1/K6`309^KV`<0`/;2
0P3;bl/30:n_[`80Xj>S0`2WYjL30:b/[080][Jf0`2i^KT20;bl_0<0_[jn0P38b<P30<W9b@<0b/[:
0P36a/H30<C4a080aLG50`2n_[h309BDU080HV9R0`1LG5`206a/K0<0N7Qh0`1kNg/207alO0<0Ng]k
0P21PH4308J6QP<0OWin0P21PH4307emO@80Q8B41P2CTi<2096AT@<0T92@0P2?Shl308f=S@<0QhN7
0P28R8P30861P@80L71`0`1]KFd2079bLP<0JFUY0`1/K6`207QhN0<0LW9b0P1_Kfl307AdM0D0QHF5
0`2?Shl209NGU`<0Vi^K0`2GUiL209jNWP<0ZJVY0P2WYjL30:b/[0D0/[:b0`2ZZZX20;6a/@<0];Bd
0`2k^k/20;fm_@<0/K6a0P2PX:0309^KV`<0UiNG0P2DU9@508R8R0<0RHV90P24Q8@308>3P`<0OWin
0P1iNGT307MgM`80NGUi0`1cLg<307QhN080P8200`23Ph<20861P@<0P8200`1iNGT208:2PP<0SHf=
0P2DU9@309NGUa`0b>3H000K0<SPf0<0:b/[0P0W9bL502@T90<09bLW0`0/;2`2034a<@<0<S8b0P0a
<C46030`<080>CTi0`11@D4203/k>`<0<c<c200a<C42038b<P<0=SHf0P0i>CT303@d=0<0;Rh^0P0Y
:BT302HV9PD08b<S0`0V9RH202d];@<08R8R0P0k>c/306][J`<0U9BD0P2JVYX305MGE`80Hf=S0`1k
Ng/30:f][@80d];B0`2k^k/209jNWP<0WinO0`2WYjL20:j^[P<0]KFe0P2h^;P30;bl_080`l?31P3:
b/X20<S8b0<0a/K60P33`l<30<G5a@<0_[jn0P2=SHd305iNGP80Hf=S0`1dM7@307UiN@80O7al0`1m
OGd207inOP<0P8200`21PH4207inOP<0OGem0P27QhL6096AT@D0Shn?0P2=SHd308V9R@<0Ph>30P1l
O7`307EeM@80Kfm_0`1XJ6P205]KF`<0De=C0`1NGUh206i^KP<0Ng]k0P25QHD308^;R`<0Shn?0P2I
VIT30:6QX@80Xj>S0`2TY:@30:RXZ080[Zj^0`2d];@20;^k^`<0_kno0`31`L450<C4a080_[jn0`2f
][H30:ZZZP80WinO0`2HV9P209:BTP<0SXj>0`2:RXX207alO0<0M7Ad0P1hN7P30820P080Ph>30`24
Q8@30820P080NWYj0`1gMgL207IfMP<0MgMg0`1jNWX207moO`<0Q8B40P23Ph<60861P@80Ph>30`2<
S8`209JFUP<0V9RH=038h=P302`/;0809bLW0`0T92@202LW9`<0:BTY0`0a<C4203@d=0<0;2`/0P0a
<C4302d];@<0<30`0P0l?3`30410@080>SXj0`0f=SH202h^;P<0;2`/0`0`<302038b<P<0A4A40P0k
>c/302l_;`<0=3@d0P0[:b/302<S8`809bLW0`0U9BD3028R8P80;2`/0`0Y:BT203/k>`<0KVi^0`2A
TI4209>CT`<0GemO0P1PH60307alO0<0[:b/0P3>c/h30;no_`80WYjN0`2SXj<30:JVYP80[Zj^0`2d
];@20;Zj^P<0^k^k0P35aLD30<S8b0<0b/[:0P38b<P30<K6aP80a<C40`2o_kl30;bl_080Shn?0`1P
H602069RHP<0MgMg0`1iNGT507]kN`80Ogmo1P21PH420820P0<0OWin0P28R8P3092@T0<0Ti>C0P2@
T90508f=S@<0S8b<0`22PX8207alO0<0M7Ad0P1[Jf/306=SH`80JFUY0`1CDe<304];B`80LG5a0`1m
OGd208N7Q`<0RXZ:0`2BTY8209FEU@D0WIfM0`2OWil30:RXZ080[Jf]0`2`/;050;^k^`<0`L710P34
a<@30<71`@80^KVi0`2_[jl30:NWY`80ZZZZ0`2KVi/209:BTP<0SXj>0`27QhL207alO0<0MGEe0P1f
MWH308:2PP80P8200`26QXH307inOP80OGem0`1hN7P207MgM`<0NGUi0`1kNg/20820P0D0PX:20`25
QHD30820P080Q8B40`2>SXh209BDU0<0VYZJ7038h=P001/0b>3H0`0[:b/202LW9`D092@T0`0W9bL3
02`/;080<C4a0`0b<S82034a<@H0<30`0P0i>CT30451@@80>c/k0`0c<c<8034a<@80<S8b0`0f=SH2
03Ti>@<0=3@d0`0^;Rh202TY:@<09RHV1@0S8b<302HV9P80;Bd]0`0R8R8203/k>`<0Jf][0`2DU9@2
09ZJVP<0EeMG0P1SHf<307]kN`<0[Jf]0P3Bd]830;^k^`80WYjN0`2OWil30:NWY`80[Zj^0`2e]KD2
0;Rh^0<0_;bl0P33`l<60<[:bP80b<S80`36a/H20<?3``<0aLG50`2n_[h208f=S@<0GUiN0P1SHf<3
07AdM0<0NGUi0P1lO7`307emO@80OWin0`20P8030861P@80OWin0`1mOGd208N7Q`H0TI6A1@2?Shl2
08f=S@<0RHV90`23Ph<207alO0<0MGEe0P1_Kfl306QXJ080Fe]K0`1CDe<305iNGP80KVi^0`1kNg/2
08F5Q@<0Rh^;0`2?Shl209VIV@<0XJ6Q0P2SXj<30:BTY0<0Z:RX0P2^[Zh30;Bd]080^k^k0`2o_kl3
0<71`@D0a<C40P2n_[h30;Jf]P<0ZZZZ0P2OWil309RHV080TY:B0`2>SXh308Z:RP80O7al0`1dM7@2
07QhN0<0P8200P23Ph<308B4Q0<0P8200P1jNWX307MgM`80MWIf0`1gMgL307YjNP80Ogmo0`24Q8@2
08>3P`H0PH610P23Ph<308b<S080UYJF0`2HV9Pd0<SPf0<0;2`/0P0W9bL302@T90809bLW0`0Y:BT3
034a<@80=3@d0`0/;2`2034a<@<0;Bd]0`0`<30203`l?0<0@4100P0j>SX303Hf=P80;Rh^0`0/;2`3
030`<080<S8b0`14A4@203/k>`<0;bl_0`0d=3@202/[:`<08b<S0P0W9bL302DU9@<08R8R0P0/;2`3
02TY:@80>c/k0`1^KVh3096AT@80Ti>C0`1OGel2061PH0<0O7al0`2/[:`20<k>cP<0_kno0P2NWYh3
0:>SX`<0YZJV0P2^[Zh30;Bd]080^[Zj0`2k^k/20<G5a@<0b<S80`3:b/X20<S8b0<0a/K60P34a<@3
0;no_`<0_;bl0P2?Shl3061PH080HV9R0`1gMgL307UiN@D0Ng]k0P1oOgl60861P@80P8200`1nOWh2
08R8R0<0T92@0`2CTi<2092@T0D0SHf=0`2<S8`308:2PP80O7al0`1dM7@206][J`<0Hf=S0P1YJFT3
05=CD`<0Bd];0P1aLG4307emO@80QhN70`2:RXX309:BTP80UIFE1@2MWId309nOW`<0Z:RX0P2][Jd3
0;2`/0D0^k^k0`31`L420<C4a0<0`L710P2i^KT30:n_[`<0YjNW0P2ZZZX309^KV`80TY:B0`2>SXh3
08N7Q`80O7al0`1eMGD207IfMP<0PX:20P20P80308J6QP<0OWin0P1mOGd307QhN080MgMg0`1iNGT3
07]kN`80P8201@22PX8308F5Q@<0P8200P24Q8@308j>SP80U9BD0`2JVYXL0<SPf0006`38h=P302/[
:`809bLW1@0T92@302LW9`<0;2`/0P0a<C43038b<P80<C4a1P0`<30203Ti>@<0@D510P0k>c/303<c
<`P0<C4a0P0b<S8303Hf=P80>CTi0`0d=3@302h^;P80:BTY0`0V9RH502<S8`<09RHV0P0];Bd3028R
8P80>c/k0`1[Jf/309BDU080VYZJ0`1GEeL206=SH`<0Ng]k0`2][Jd20=;BdP<0^k^k0P2NWYh309nO
W`<0YjNW0P2^[Zh30;Fe]@80^;Rh0`2l_;`20<?3``H0b/[:0P38b<P30<K6aP80`l?30`35aLD30;jn
_P80SHf=0`1NGUh206=SH`<0M7Ad0`1iNGT207alO0<0OGem0P1nOWh30820P0<0PH610P1nOWh307em
O@80QhN71P2ATI4508n?S`80SHf=0`29RHT308>3P`80O7al0`1eMGD206m_K`<0J6QX0P1KFe/305=C
D`<0GUiN0P1^KVh307]kN`80QHF50`2;Rh/308n?S`80VIVI0`2QXJ420:>SX`<0Y:BT0`2XZ:P20:j^
[P<0];Bd0P2k^k/30;no_`<0`L711@34a<@20;jn_P<0][Jf0`2ZZZX209nOW`<0V9RH0P2BTY8308j>
SP<0RXZ:0P1lO7`307AdM080N7Qh0`20P80208>3P`<0Q8B40`20P80207YjNP<0MgMg0P1fMWH307Mg
M`<0NWYj0P1oOgl308B4Q080Ph>31P21PH4208>3P`<0S8b<0P2FUYH309RHV3@0b>3H0`0/;2`202LW
9`<092@T0P0W9bL302TY:@<0<C4a0P0d=3@302`/;080<C4a0`0];Bd3030`<080?3`l0`10@40203Xj
>P<0=SHf0P0^;Rh302`/;0<0<30`0P0b<S8304A4A080>c/k0`0_;bl303@d=080:b/[0`0S8b<202LW
9`<09BDU0`0R8R8202`/;0<0:BTY0P0k>c/306i^KP<0TI6A0P2CTi<305mOG`80H61P0`1lO7`30:b/
[080c/k>0`2o_kl209jNWP<0Xj>S0`2VYZH20:j^[P<0];Bd0P2j^[X30;^k^`80aLG50`38b<P30<[:
bP80b<S80`36a/H20<C4a0<0_kno0`2l_;`208n?S`<0H61P0P1RHV8307MgM`<0NGUi1@1kNg/207mo
O`H0PH610P20P80307inOP80R8R80`2@T90309>CT`80T92@1@2=SHd308b<S0<0PX:20P1lO7`307Ad
M080Jf][0`1SHf<206UYJ@<0De=C0`1;Bd/2075aL@<0OGem0P27QhL308Z:RP<0TY:B0P2EUID509fM
W@<0WinO0`2XZ:P20:f][@<0/;2`1@2k^k/30<71`@80a<C40`31`L420;Vi^@<0[jn_0`2WYjL20:ZZ
ZP<0Vi^K0P2BTY8308j>SP<0QhN70P1lO7`307EeM@80MWIf0`22PX820820P0<0QXJ60`1nOWh207em
O@<0N7Qh0P1gMgL307UiN@<0Ng]k0P20P80508:2PP<0QHF50`20P80208B4Q0<0SXj>0P2DU9@309ZJ
VQ`0b>3H000K0<SPf0<0;2`/0P0[:b/302XZ:P80:BTY0`0X:2P302d];@80<c<c1@0d=3@3030`<0<0
;Bd]0P0f=SH303hn?P80>SXj0`0c<c<202l_;`<0;Bd]0`0/;2`202h^;P<0<c<c0P0f=SH3034a<@<0
:b/[0P0Y:BT302PX:0809RHV0`0S8b<3020P80806a/K0`11@D4202LW9`<0De=C0`1lO7`209NGU`<0
NGUi0P1WIfL306=SH`<0QHF50P30`<030<K6aP80XJ6Q0`2OWil30:6QX@80[:b/0`2g]kL50;Rh^080
`<300`37alL50<S8b0<0alO70P35aLD30<S8b0<0aLG50P2][Jd3092@T080NWYj0`1[Jf/306m_K`80
N7Qh0`1kNg/507alO0<0Ng]k0P1lO7`307inOP80QXJ60`2>SXh308n?S`80SHf=0`2;Rh/208N7Q`<0
Ogmo0`1eMGD206MWI`<0Fe]K0P1JFUX305aLG080GEeM0`1QHF4306QXJ080LG5a0`1oOgl208Z:RP<0
QhN70`22PX8208>3P`<0R8R80P2@T90309bLW0<0[Jf]0P2m_Kd30<;2`P80`l?30`36a/H30<S8b080
bl_;0`3=cLd20<W9b@<0`/;20`2e]KD20:NWY`<0UiNG0P2:RXX308b<S0D0SHf=0`1]KFd207=cL`<0
O7al0P21PH4308>3P`<0OGem1@1fMWH207MgM`<0NGUi0`1lO7`207moO`<0PH612022PX8208B4Q0<0
Rh^;0P2CTi<309BDU3@0b>3H0`0b<S8202`/;0D09bLW0`0T92@302TY:@80<30`0`0i>CT203Ph>0<0
<S8b0`0^;Rh203Hf=P<0@d=30P0o?cl502h^;P<0=SHf0`0`<30202`/;0<0;Rh^0P0a<C4303Lg=`<0
9bLW0P0T92@302PX:0809BDU0`0T92@3024Q8@80820P0`0i>CT202XZ:P<0CDe=0`25QHD209^KV`<0
O7al0P1SHf<306IVIP<0R8R80P32`/830<G5a@80W9bL0`2EUID309nOW`80[Jf]0`2a/K420;Vi^@<0
]KFe0P30`<060<O7a`80a/K60`37alL20<G5a@H0`L710P2l_;`309:BTP80IVIV0`1YJFT3079bLP80
Ogmo0`1lO7`207]kN`<0NWYj0`1lO7`207inOP<0Ng]k0P27QhL308j>SP<0Rh^;0P2=SHd508J6QP<0
QHF50`1bLW8206YZJP<0GemO0P1KFe/305eMG@80GemO0`1NGUh306i^KP80MgMg0`22PX8208^;R`<0
SHf=0`23Ph<208F5Q@<0RXZ:0P2CTi<309jNWP<0][Jf0P2k^k/30<71`@80aLG50`37alL30<_;b`80
c/k>0`3AdM420<k>cP<0alO70`2f][H209jNWP<0T92@0P29RHT3096AT@<0V9RH0P2;Rh/307=cL`80
L71`0`1lO7`208>3P`<0PX:20`1mOGd207UiN@<0LW9b0P1eMGD307UiN@<0O7al0P24Q8@30861P@80
PX:20`21PH4308F5Q@80Q8B41@2=SHd309VIVA`0b>3H000K0<SPf0<0;2`/0P0[:b/302XZ:P80:BTY
0`0X:2P302d];@80<c<c1@0d=3@3030`<0<0;Bd]0P0f=SH303hn?P80>SXj0`0c<c<202l_;`<0;Bd]
0`0/;2`202h^;P<0<c<c0P0f=SH3034a<@<0:b/[0P0Y:BT302PX:0809RHV0`0S8b<3020P80806a/K
0`11@D4202LW9`<0De=C0`1lO7`209NGU`<0NGUi0P1WIfL306=SH`<0QHF50P30`<030<K6aP80XJ6Q
0`2OWil30:6QX@80[:b/0`2g]kL50;Rh^080`<300`37alL50<S8b0<0alO70P35aLD30<S8b0<0aLG5
0P2][Jd3092@T080NWYj0`1[Jf/306m_K`80N7Qh0`1kNg/507alO0<0Ng]k0P1lO7`307inOP80QXJ6
0`2>SXh308n?S`80SHf=0`2;Rh/208N7Q`<0Ogmo0`1eMGD206MWI`<0Fe]K0P1JFUX305aLG080GEeM
0`1QHF4306QXJ080LG5a0`1oOgl208Z:RP<0QhN70`22PX8208>3P`<0R8R80P2@T90309bLW0<0[Jf]
0P2m_Kd30<;2`P80`l?30`36a/H30<S8b080bl_;0`3=cLd20<W9b@<0`/;20`2e]KD20:NWY`<0UiNG
0P2:RXX308b<S0D0SHf=0`1]KFd207=cL`<0O7al0P21PH4308>3P`<0OGem1@1fMWH207MgM`<0NGUi
0`1lO7`207moO`<0PH612022PX8208B4Q0<0Rh^;0P2CTi<309BDU3@0b>3H0`0b<S8202`/;0D09bLW
0`0T92@302TY:@80<30`0`0i>CT203Ph>0<0<S8b0`0^;Rh203Hf=P<0@d=30P0o?cl502h^;P<0=SHf
0`0`<30202`/;0<0;Rh^0P0a<C4303Lg=`<09bLW0P0T92@302PX:0809BDU0`0T92@3024Q8@80820P
0`0i>CT202XZ:P<0CDe=0`25QHD209^KV`<0O7al0P1SHf<306IVIP<0R8R80P32`/830<G5a@80W9bL
0`2EUID309nOW`80[Jf]0`2a/K420;Vi^@<0]KFe0P30`<060<O7a`80a/K60`37alL20<G5a@H0`L71
0P2l_;`309:BTP80IVIV0`1YJFT3079bLP80Ogmo0`1lO7`207]kN`<0NWYj0`1lO7`207inOP<0Ng]k
0P27QhL308j>SP<0Rh^;0P2=SHd508J6QP<0QHF50`1bLW8206YZJP<0GemO0P1KFe/305eMG@80GemO
0`1NGUh306i^KP80MgMg0`22PX8208^;R`<0SHf=0`23Ph<208F5Q@<0RXZ:0P2CTi<309jNWP<0][Jf
0P2k^k/30<71`@80aLG50`37alL30<_;b`80c/k>0`3AdM420<k>cP<0alO70`2f][H209jNWP<0T92@
0P29RHT3096AT@<0V9RH0P2;Rh/307=cL`80L71`0`1lO7`208>3P`<0PX:20`1mOGd207UiN@<0LW9b
0P1eMGD307UiN@<0O7al0P24Q8@30861P@80PX:20`21PH4308F5Q@80Q8B41@2=SHd309VIVA`0b>3H
000K0<SPf0<0;2`/0P0[:b/302XZ:P80:BTY0`0X:2P302d];@80<c<c1@0d=3@3030`<0<0;Bd]0P0f
=SH303hn?P80>SXj0`0c<c<202l_;`<0;Bd]0`0/;2`202h^;P<0<c<c0P0f=SH3034a<@<0:b/[0P0Y
:BT302PX:0809RHV0`0S8b<3020P80806a/K0`11@D4202LW9`<0De=C0`1lO7`209NGU`<0NGUi0P1W
IfL306=SH`<0QHF50P30`<030<K6aP80XJ6Q0`2OWil30:6QX@80[:b/0`2g]kL50;Rh^080`<300`37
alL50<S8b0<0alO70P35aLD30<S8b0<0aLG50P2][Jd3092@T080NWYj0`1[Jf/306m_K`80N7Qh0`1k
Ng/507alO0<0Ng]k0P1lO7`307inOP80QXJ60`2>SXh308n?S`80SHf=0`2;Rh/208N7Q`<0Ogmo0`1e
MGD206MWI`<0Fe]K0P1JFUX305aLG080GEeM0`1QHF4306QXJ080LG5a0`1oOgl208Z:RP<0QhN70`22
PX8208>3P`<0R8R80P2@T90309bLW0<0[Jf]0P2m_Kd30<;2`P80`l?30`36a/H30<S8b080bl_;0`3=
cLd20<W9b@<0`/;20`2e]KD20:NWY`<0UiNG0P2:RXX308b<S0D0SHf=0`1]KFd207=cL`<0O7al0P21
PH4308>3P`<0OGem1@1fMWH207MgM`<0NGUi0`1lO7`207moO`<0PH612022PX8208B4Q0<0Rh^;0P2C
Ti<309BDU3@0b>3H0`0b<S8202`/;0D09bLW0`0T92@302TY:@80<30`0`0i>CT203Ph>0<0<S8b0`0^
;Rh203Hf=P<0@d=30P0o?cl502h^;P<0=SHf0`0`<30202`/;0<0;Rh^0P0a<C4303Lg=`<09bLW0P0T
92@302PX:0809BDU0`0T92@3024Q8@80820P0`0i>CT202XZ:P<0CDe=0`25QHD209^KV`<0O7al0P1S
Hf<306IVIP<0R8R80P32`/830<G5a@80W9bL0`2EUID309nOW`80[Jf]0`2a/K420;Vi^@<0]KFe0P30
`<060<O7a`80a/K60`37alL20<G5a@H0`L710P2l_;`309:BTP80IVIV0`1YJFT3079bLP80Ogmo0`1l
O7`207]kN`<0NWYj0`1lO7`207inOP<0Ng]k0P27QhL308j>SP<0Rh^;0P2=SHd508J6QP<0QHF50`1b
LW8206YZJP<0GemO0P1KFe/305eMG@80GemO0`1NGUh306i^KP80MgMg0`22PX8208^;R`<0SHf=0`23
Ph<208F5Q@<0RXZ:0P2CTi<309jNWP<0][Jf0P2k^k/30<71`@80aLG50`37alL30<_;b`80c/k>0`3A
dM420<k>cP<0alO70`2f][H209jNWP<0T92@0P29RHT3096AT@<0V9RH0P2;Rh/307=cL`80L71`0`1l
O7`208>3P`<0PX:20`1mOGd207UiN@<0LW9b0P1eMGD307UiN@<0O7al0P24Q8@30861P@80PX:20`21
PH4308F5Q@80Q8B41@2=SHd309VIVA`0b>3H000K0<SPf0<0;bl_1@0`<30202`/;0<0:RXZ0`0^;Rh2
03@d=0<0>CTi0P0l?3`3038b<P<0:RXZ0P0`<30303Ph>080=SHf0`0a<C4202d];@<0:BTY0`0X:2P2
02XZ:P<0;bl_0P0c<c<302d];@<09bLW0P0X:2P302XZ:P809RHV0`0R8R8302<S8`80:BTY0`0N7Qh2
03Lg=`<0AdM70`1LG5`20820P0<0V9RH0P1bLW8305EEE@<0G5aL0P2UYJD30<W9b@80YZJV0`2QXJ43
09^KV`80ZJVY1@2g]kL30;Fe]@80_;bl0`33`l<30<K6aPL0alO70`34a<@30<;2`P80alO70`33`l<2
09RHV0<0K6a/0`1[Jf/207AdM0<0MgMg0P1iNGT307MgM`<0MWIf0P1jNWX307moO`80Q8B40`28R8P3
08Z:RP80RHV90`26QXH207moO`<0M7Ad0`1VIVH2055AD@<0@D510P15ADD3051@D080Hf=S0`1dM7@5
07IfMP<0Ogmo0P25QHD307YjNP<0KFe]0P1TI6@306=SH`80LW9b0`29RHT30:JVYP80_kno0`36a/H2
0<O7a`<0b/[:0`3<c<`20<o?c`D0dM7A0`3=cLd30;no_`80[Zj^0`2IVIT208R8R0<0SHf=0`2?Shl2
09fMW@<0Jf][0P1bLW8307YjNPD0OWin0`1iNGT207=cL`<0M7Ad0P1hN7P307YjNP<0O7al0P1mOGd3
07inOP80PH610`23Ph<308B4Q080QXJ60`2;Rh/2092@T0<0TI6A=038h=P302`/;080:b/[0`0f=SH2
02`/;0<0;bl_0`0[:b/203Hf=P<0?Cdm0P0j>SX303Hf=P<0;Bd]0P0X:2P303Lg=`80@4100`0a<C42
02LW9`<09RHV0`0Y:BT202`/;0<0;bl_0P0`<30303De=@<09RHV0P0U9BD302h^;P80;Bd]0`0Q8B43
02<S8`808B4Q0`0Z:RX203Hf=P<0?3`l0`1HF5P208R8R0<0UYJF0P1SHf<305QHF0<0IVIV0P2SXj<3
0<;2`P80Zj^[0`2FUYH309bLW080[:b/0`2e]KD20;:b/P<0];Bd0P2m_Kd60<?3``80alO70`39bLT2
0<G5a@<0alO70`31`L420<C4a0<0`L710P2LW9`306a/K0<0JVYZ0P1cLg<307MgM`80NWYj0`1bLW83
07IfMP80OWin0`1lO7`208>3P`<0S8b<0`23Ph<208n?S`<0R8R80P1lO7`307IfMP<0Hf=S0P1CDe<5
04=3@`<0DU9B0P1SHf<307=cL`D0MgMg0`1lO7`208B4Q0<0N7Qh0`1/K6`206EUI@<0IVIV0P1dM7@3
08V9R@<0Xj>S0P2j^[X30<G5a@80a/K60`3:b/X30<g=c@80clo?0`3AdM420<o?c`<0b/[:0`36a/H2
0;2`/0<0UiNG0P28R8P3092@T0<0SXj>0P2DU9@3075aL@80KVi^0`1iNGT208F5Q@<0OWin0`1dM7@2
075aL@<0NGUi0P1dM7@307alO0<0Ng]k0P1lO7`307moO`D0PX:20`23Ph<508J6QP80T92@0`2DU9@L
0<SPf0006`38h=P302l_;`D0<30`0P0/;2`302XZ:P<0;Rh^0P0d=3@303Ti>@80?3`l0`0b<S8302XZ
:P80<30`0`0h>3P203Hf=P<0<C4a0P0];Bd302TY:@<0:2PX0P0Z:RX302l_;`80<c<c0`0];Bd302LW
9`80:2PX0`0Z:RX202HV9P<08R8R0`0S8b<202TY:@<07QhN0P0g=cL304M7A`<0G5aL0P20P80309RH
V080LW9b0`1EEED305aLG080YJFU0`39bLT20:JVYP<0XJ6Q0`2KVi/20:VYZ@D0]kNg0`2e]KD20;bl
_0<0`l?30`36a/H70<O7a`<0a<C40`32`/820<O7a`<0`l?30P2HV9P306a/K0<0Jf][0P1dM7@307Mg
M`80NGUi0`1gMgL307IfMP80NWYj0`1oOgl208B4Q0<0R8R80`2:RXX208V9R@<0QXJ60P1oOgl307Ad
M0<0IVIV0P1ADE430451@@80ADE50`1@D50206=SH`<0M7Ad1@1fMWH307moO`80QHF50`1jNWX306e]
K@80I6AT0`1SHf<2079bLP<0RHV90`2VYZH20;no_`<0a/K60P37alL30<[:bP<0c<c<0P3?cll50=7A
d@<0cLg=0`2o_kl20:j^[P<0VIVI0P28R8P308f=S@<0Shn?0P2MWId306][J`80LW9b0`1jNWX507in
OP<0NGUi0P1cLg<307AdM080N7Qh0`1jNWX307alO080OGem0`1nOWh20861P@<0Ph>30`24Q8@208J6
QP<0Rh^;0P2@T903096ATC@0b>3H0`0/;2`202/[:`<0=SHf0P0/;2`302l_;`<0:b/[0P0f=SH303dm
?@80>SXj0`0f=SH302d];@80:2PX0`0g=cL20410@0<0<C4a0P0W9bL302HV9P<0:BTY0P0/;2`302l_
;`80<30`0`0e=CD302HV9P809BDU0`0^;Rh202d];@<08B4Q0`0S8b<2024Q8@<0:RXZ0P0f=SH303`l
?0<0F5QH0P28R8P309JFUP80Hf=S0`1HF5P306IVIP80Xj>S0`32`/820:^[Z`<0UYJF0`2LW9`20:b/
[0<0]KFe0P2b/[830;Bd]080_Kfm1P33`l<20<O7a`<0bLW90P35aLD30<O7a`<0`L710P34a<@30<71
`@80W9bL0`1/K6`306YZJP80Lg=c0`1gMgL207YjNP<0LW9b0`1fMWH207inOP<0O7al0P23Ph<308b<
S0<0Ph>30P2?Shl308R8R080O7al0`1fMWH306=SH`80De=C1@13@d<3059BDP80Hf=S0`1cLg<507Mg
M`<0O7al0P24Q8@307QhN0<0K6a/0P1UIFD306IVIP80M7Ad0`29RHT30:>SX`80^[Zj0`35aLD20<K6
aP<0b/[:0`3=cLd20<o?c`<0dM7A0P3?cll30<[:bP<0a/K60P2`/;0309NGU`80R8R80`2@T90308j>
SP80U9BD0`1aLG4206i^KP<0NGUi0P25QHD307inOP<0M7Ad0P1aLG4307UiN@80M7Ad0`1lO7`307]k
N`80O7al0`1oOgl508:2PP<0Ph>31@26QXH2092@T0<0U9BD7038h=P001/0b>3H0`0f=SH2038b<P<0
;2`/1@0Z:RX302d];@80=3@d0`16ATH205IFEP<0@T920`0X:2P202`/;0D0=CDe0`0c<c<202h^;PH0
:BTY0P0[:b/3030`<080=3@d0`0_;bl502TY:@<0:b/[0P0W9bL302@T90<09BDU0P0Y:BT302LW9`80
<30`0`0e=CD304A4A080Fe]K0`2ATI4208B4Q0<0F5QH0`19BDT208J6QP<0[:b/0P2[Zj/309jNWP<0
Ti>C0P2NWYh30:f][@80/;2`0`2a/K420;Rh^0<0_kno0`34a<@20<O7a`D0b<S80`36a/H30<C4a0D0
bLW90P2d];@309VIV@<0OGem0P1XJ6P306][J`80M7Ad0`1eMGD307MgM`80OGem0`22PX820861P@<0
P8201@21PH4307emO@80MGEe0`1XJ6P305QHF080@D510`0b<S8203Xj>P<0BTY:0P1MGEd306m_K`<0
N7Qh0P1kNg/307MgM`80KVi^0`1NGUh304i>CPD0B4Q80P1@D503061PH0<0NWYj0P2HV9P30;Rh^080
cLg=1P3>c/h20=3@d0<0dM7A0P3@d=030<c<c0<0a<C40P2i^KT30:FUY@80TY:B0`2:RXX308:2PP80
Q8B40`1XJ6P2075aL@<0Ogmo0P1jNWX3079bLP<0LG5a0P1bLW8307IfMP80NWYj0`1iNGT307MgM`80
Ng]k0`1oOgl208:2PP<0QHF50`27QhL208V9R@<0SXj>0P2CTi<309BDU3@0b>3H0`0l?3`203De=@<0
:2PX0P0^;Rh302XZ:P<0;Rh^0P0d=3@304E5A@80Cdm?0`0m?Cd302XZ:P80:BTY0`0a<C4203Xj>P<0
<S8b0P0];Bd302`/;0<0:2PX1@0];Bd203Hf=P<0>3Ph0`0X:2P502LW9`8092@T0`0Q8B4302DU9@80
:RXZ0`0`<302038b<P<0=CDe0`0o?cl206i^KP<0UIFE0P1lO7`305=CD`<0EUIF0P1nOWh30:n_[`80
^KVi0`2OWil309RHV080ZJVY0`2`/;020;>c/`<0];Bd0P2l_;`30;jn_P<0`l?30P37alL30<W9b@80
b/[:0`34a<@80<G5a@80a<C40`2PX:0306e]K@80J6QX0`1aLG4207EeM@H0MWIf0P1oOgl308:2PP80
Q8B40`22PX8307alO080PX:20`1lO7`207EeM@<0K6a/0`1FEUH20451@@D0;bl_0`19BDT206=SH`<0
LG5a0`1`L70207EeM@<0N7Qh0P1aLG4305mOG`<0DU9B0P0o?cl30492@P80Bd];0`1HF5P307moO`80
WYjN0`2l_;`20<[:bP<0bl_;1@3:b/X30<k>cP80c<c<0`36a/H30<?3``80_;bl0`2SXj<209BDU0<0
RXZ:0`24Q8@207QhN0<0JVYZ0P1dM7@307inOP80NWYj1P1`L70207=cL`<0O7al0P1mOGd307QhN0<0
MWIf0P1kNg/307YjNP80QXJ60`24Q8@308^;R`80RXZ:0`2?Shl209BDU0<0Vi^K7038h=P001/0b>3H
0`0f=SH2038b<P<0;2`/1@0Z:RX302d];@80=3@d0`16ATH205IFEP<0@T920`0X:2P202`/;0D0=CDe
0`0c<c<202h^;PH0:BTY0P0[:b/3030`<080=3@d0`0_;bl502TY:@<0:b/[0P0W9bL302@T90<09BDU
0P0Y:BT302LW9`80<30`0`0e=CD304A4A080Fe]K0`2ATI4208B4Q0<0F5QH0`19BDT208J6QP<0[:b/
0P2[Zj/309jNWP<0Ti>C0P2NWYh30:f][@80/;2`0`2a/K420;Rh^0<0_kno0`34a<@20<O7a`D0b<S8
0`36a/H30<C4a0D0bLW90P2d];@309VIV@<0OGem0P1XJ6P306][J`80M7Ad0`1eMGD307MgM`80OGem
0`22PX820861P@<0P8201@21PH4307emO@80MGEe0`1XJ6P305QHF080@D510`0b<S8203Xj>P<0BTY:
0P1MGEd306m_K`<0N7Qh0P1kNg/307MgM`80KVi^0`1NGUh304i>CPD0B4Q80P1@D503061PH0<0NWYj
0P2HV9P30;Rh^080cLg=1P3>c/h20=3@d0<0dM7A0P3@d=030<c<c0<0a<C40P2i^KT30:FUY@80TY:B
0`2:RXX308:2PP80Q8B40`1XJ6P2075aL@<0Ogmo0P1jNWX3079bLP<0LG5a0P1bLW8307IfMP80NWYj
0`1iNGT307MgM`80Ng]k0`1oOgl208:2PP<0QHF50`27QhL208V9R@<0SXj>0P2CTi<309BDU3@0b>3H
0`0l?3`203De=@<0:2PX0P0^;Rh302XZ:P<0;Rh^0P0d=3@304E5A@80Cdm?0`0m?Cd302XZ:P80:BTY
0`0a<C4203Xj>P<0<S8b0P0];Bd302`/;0<0:2PX1@0];Bd203Hf=P<0>3Ph0`0X:2P502LW9`8092@T
0`0Q8B4302DU9@80:RXZ0`0`<302038b<P<0=CDe0`0o?cl206i^KP<0UIFE0P1lO7`305=CD`<0EUIF
0P1nOWh30:n_[`80^KVi0`2OWil309RHV080ZJVY0`2`/;020;>c/`<0];Bd0P2l_;`30;jn_P<0`l?3
0P37alL30<W9b@80b/[:0`34a<@80<G5a@80a<C40`2PX:0306e]K@80J6QX0`1aLG4207EeM@H0MWIf
0P1oOgl308:2PP80Q8B40`22PX8307alO080PX:20`1lO7`207EeM@<0K6a/0`1FEUH20451@@D0;bl_
0`19BDT206=SH`<0LG5a0`1`L70207EeM@<0N7Qh0P1aLG4305mOG`<0DU9B0P0o?cl30492@P80Bd];
0`1HF5P307moO`80WYjN0`2l_;`20<[:bP<0bl_;1@3:b/X30<k>cP80c<c<0`36a/H30<?3``80_;bl
0`2SXj<209BDU0<0RXZ:0`24Q8@207QhN0<0JVYZ0P1dM7@307inOP80NWYj1P1`L70207=cL`<0O7al
0P1mOGd307QhN0<0MWIf0P1kNg/307YjNP80QXJ60`24Q8@308^;R`80RXZ:0`2?Shl209BDU0<0Vi^K
7038h=P001/0b>3H0`0f=SH2038b<P<0;2`/1@0Z:RX302d];@80=3@d0`16ATH205IFEP<0@T920`0X
:2P202`/;0D0=CDe0`0c<c<202h^;PH0:BTY0P0[:b/3030`<080=3@d0`0_;bl502TY:@<0:b/[0P0W
9bL302@T90<09BDU0P0Y:BT302LW9`80<30`0`0e=CD304A4A080Fe]K0`2ATI4208B4Q0<0F5QH0`19
BDT208J6QP<0[:b/0P2[Zj/309jNWP<0Ti>C0P2NWYh30:f][@80/;2`0`2a/K420;Rh^0<0_kno0`34
a<@20<O7a`D0b<S80`36a/H30<C4a0D0bLW90P2d];@309VIV@<0OGem0P1XJ6P306][J`80M7Ad0`1e
MGD307MgM`80OGem0`22PX820861P@<0P8201@21PH4307emO@80MGEe0`1XJ6P305QHF080@D510`0b
<S8203Xj>P<0BTY:0P1MGEd306m_K`<0N7Qh0P1kNg/307MgM`80KVi^0`1NGUh304i>CPD0B4Q80P1@
D503061PH0<0NWYj0P2HV9P30;Rh^080cLg=1P3>c/h20=3@d0<0dM7A0P3@d=030<c<c0<0a<C40P2i
^KT30:FUY@80TY:B0`2:RXX308:2PP80Q8B40`1XJ6P2075aL@<0Ogmo0P1jNWX3079bLP<0LG5a0P1b
LW8307IfMP80NWYj0`1iNGT307MgM`80Ng]k0`1oOgl208:2PP<0QHF50`27QhL208V9R@<0SXj>0P2C
Ti<309BDU3@0b>3H0`0l?3`203De=@<0:2PX0P0^;Rh302XZ:P<0;Rh^0P0d=3@304E5A@80Cdm?0`0m
?Cd302XZ:P80:BTY0`0a<C4203Xj>P<0<S8b0P0];Bd302`/;0<0:2PX1@0];Bd203Hf=P<0>3Ph0`0X
:2P502LW9`8092@T0`0Q8B4302DU9@80:RXZ0`0`<302038b<P<0=CDe0`0o?cl206i^KP<0UIFE0P1l
O7`305=CD`<0EUIF0P1nOWh30:n_[`80^KVi0`2OWil309RHV080ZJVY0`2`/;020;>c/`<0];Bd0P2l
_;`30;jn_P<0`l?30P37alL30<W9b@80b/[:0`34a<@80<G5a@80a<C40`2PX:0306e]K@80J6QX0`1a
LG4207EeM@H0MWIf0P1oOgl308:2PP80Q8B40`22PX8307alO080PX:20`1lO7`207EeM@<0K6a/0`1F
EUH20451@@D0;bl_0`19BDT206=SH`<0LG5a0`1`L70207EeM@<0N7Qh0P1aLG4305mOG`<0DU9B0P0o
?cl30492@P80Bd];0`1HF5P307moO`80WYjN0`2l_;`20<[:bP<0bl_;1@3:b/X30<k>cP80c<c<0`36
a/H30<?3``80_;bl0`2SXj<209BDU0<0RXZ:0`24Q8@207QhN0<0JVYZ0P1dM7@307inOP80NWYj1P1`
L70207=cL`<0O7al0P1mOGd307QhN0<0MWIf0P1kNg/307YjNP80QXJ60`24Q8@308^;R`80RXZ:0`2?
Shl209BDU0<0Vi^K7038h=P001/0b>3H0`0l?3`2038b<P<09bLW0P0V9RH302TY:@<0;Bd]0P0f=SH3
05EEE@80Kfm_0`1@D50302TY:@80:RXZ0`0b<S8503<c<`80;bl_1P0[:b/202d];@<0<c<c0P0g=cL3
038b<P<0:b/[1@0Z:RX202PX:0<09bLW0`0X:2P202XZ:PD0:b/[0`0X:2P3030`<080>CTi0`1lO7`2
092@T0<0Hf=S0`15ADD206][J`<0RXZ:0P2/[:`309nOW`<0T92@0P2GUiL30:6QX@80YjNW0`2][Jd2
0;>c/`<0^[Zj0`30`<020<G5a@<0alO70P38b<P30<O7a`<0a/K60P34a<@30<?3``80bLW90`36a/H3
09NGU`80J6QX0`1VIVH206m_K`<0Lg=c0`1hN7P207moO`<0PX:20P1mOGd607IfMP80MGEe0`1`L702
06QXJ0<0FUYJ0`1:BTX203Hf=P<0:BTY0P0e=CD304Q8B080FEUI0`1XJ6P307IfMP80Ng]k0`1[Jf/2
05EEE@<0A4A40`0h>3P503<c<`80=CDe0`0m?Cd304m?C`80JVYZ0`2NWYh20<[:bP<0d=3@0`3>c/h5
0=3@d080c/k>0`3:b/X30<S8b080`/;20`2b/[8209fMW@<0Q8B40`1_Kfl206EUI@<0IfMW0P1cLg<3
08:2PP80MGEe0`1VIVH306][J`80Lg=c0`1hN7P207]kN`<0MWIf0`1bLW8207QhN0<0P8200P24Q8@3
08J6QP<0R8R80P2;Rh/3096AT@80UiNG0`2HV9Pd0<SPf0<0@4100P0^;Rh302`/;080:2PX0`0/;2`3
02PX:080>SXj0`1BDU8207AdM0<0CDe=0`0Z:RX202`/;0<0=3@d0P0`<30303De=@80;2`/0`0];Bd5
02/[:`<0=CDe0P0d=3@3030`<0<0:RXZ0P0`<30302`/;0809bLW0`0X:2P302/[:`809bLW0`0^;Rh2
02PX:0<09BDU0`0/;2`20410@0<0OGem0P2:RXX306MWI`<0DE5A0P1VIVH308V9R@80YZJV0`2QXJ43
092@T080UiNG0`2SXj<20:RXZ0<0Zj^[0P2k^k/30;Vi^@<0`L710P36a/H30<G5a@80b<S80`37alL3
0<G5a@80a<C40`32`/820<O7a`<0`l?30`2HV9P206a/K0<0Hf=S0P1`L703079bLP<0NWYj0P1nOWh3
0861P@80OGem0`1dM7@307EeM@80NGUi0`1]KFd206ATI0<0H61P0`1:BTX2038b<P<0:b/[0P0c<c<3
04A4A080G5aL0`1YJFT3079bLP80OGem0`1aLG4205UIF@<0?Shn0`0i>CT203Hf=P<0?Cdm0P0j>SX3
0451@@<0CDe=0P1[Jf/30:2PX080a/K60`3@d=030<k>cP80d=3@0`3?cll20=7Ad@<0b/[:0`38b<P2
0<30`0<0/;2`0P2NWYh308>3P`<0LW9b0P1QHF4306IVIPD0OGem0P1dM7@306IVIP<0Kfm_0P1bLW83
07MgM`80O7al0`1eMGD3075aL@80Ng]k0`21PH4208:2PP<0QXJ60`29RHT208Z:RP<0SXj>0P2CTi<3
09^KVa`0b>3H000K0<SPf0<0?3`l0P0b<S8302LW9`809RHV0`0Y:BT302d];@80=SHf0`1EEED206m_
K`<0D51@0`0Y:BT202XZ:P<0<S8b1@0c<c<202l_;`H0:b/[0P0];Bd303<c<`80=cLg0`0b<S8302/[
:`D0:RXZ0P0X:2P302LW9`<0:2PX0P0Z:RX502/[:`<0:2PX0`0`<30203Ti>@<0O7al0P2@T90306=S
H`<0ADE50P1[Jf/308Z:RP80[:b/0`2OWil3092@T080UiNG0`2QXJ420:NWY`<0[Jf]0P2c/k<30;Zj
^P<0`<300P35aLD30<O7a`80b<S80`37alL30<K6aP80a<C40`33`l<20<W9b@<0a/K60`2GUiL206QX
J0<0IVIV0P1_Kfl307=cL`<0N7Qh0P1oOgl308:2PP80OGem1P1fMWH207EeM@<0L71`0P1XJ6P305YJ
FP<0BTY:0P0f=SH302TY:@80=CDe0`18B4P205UIF@<0J6QX0`1fMWH207]kN`<0Jf][0P1EEED304A4
A0<0>3Ph1@0c<c<203De=@<0?Cdm0`1?Cdl206YZJP<0WYjN0P3:b/X30=3@d0<0c/k>1@3@d=020<k>
cP<0b/[:0`38b<P20<;2`P<0/[:b0P2MWId308B4Q0<0Kfm_0P1UIFD306MWI`80Lg=c0`22PX8207Ee
M@<0IVIV0`1[Jf/207=cL`<0N7Qh0P1kNg/307IfMP<0LW9b0P1hN7P30820P080Q8B40`26QXH308R8
R080Rh^;0`2ATI4209NGU`<0V9RH=038h=P30410@080;Rh^0`0/;2`202PX:0<0;2`/0`0X:2P203Xj
>P<0DU9B0P1dM7@304e=C@<0:RXZ0P0/;2`303@d=080<30`0`0e=CD202`/;0<0;Bd]1@0[:b/303De
=@80=3@d0`0`<30302XZ:P80<30`0`0/;2`202LW9`<0:2PX0`0[:b/202LW9`<0;Rh^0P0X:2P302DU
9@<0;2`/0P10@40307emO@80RXZ:0`1WIfL3055AD@80IVIV0`29RHT20:JVYP<0XJ6Q0`2@T90209NG
U`<0Xj>S0P2XZ:P30:^[Z`80^k^k0`2i^KT30<71`@80a/K60`35aLD20<S8b0<0alO70`35aLD20<C4
a0<0`/;20P37alL30<?3``<0V9RH0P1/K6`306=SH`80L71`0`1bLW8307YjNP80OWin0`21PH4207em
O@<0M7Ad0`1eMGD207UiN@<0KFe]0P1TI6@3061PH0<0BTY:0P0b<S8302/[:`80<c<c0`14A4@205aL
G0<0JFUY0`1bLW8207emO@<0LG5a0P1IFET303hn?P<0>CTi0P0f=SH303dm?@80>SXj0`11@D4304e=
C@80Jf][0`2PX:020<K6aP<0d=3@0`3>c/h20=3@d0<0clo?0P3AdM430<[:bP<0b<S80P30`<030;2`
/080WYjN0`23Ph<3079bLP80HF5Q0`1VIVH507emO@80M7Ad0`1VIVH306m_K`80LW9b0`1gMgL207al
O0<0MGEe0`1aLG4207]kN`<0PH610P22PX8308J6QP<0RHV90P2:RXX308j>SP80Ti>C0`2KVi/L0<SP
f0006`38h=P303Ph>080<30`0`0W9bL202DU9@<0:2PX0`0a<C4203Xj>P<0JFUY0P1gMgL304a<C0<0
=3@d0P0/;2`302d];@80;Rh^0`0_;bl202d];@H0:b/[0P0/;2`303<c<`80>3Ph0`0a<C4302TY:@80
:2PX0`0Y:BT202XZ:P<0:b/[0`0Y:BT202LW9`D0:2PX0`0R8R8302DU9@80<C4a0`1QHF4208>3P`<0
MgMg0`1GEeL205aLG0<0NGUi0P2NWYh30;Fe]@<0XZ:R0P2PX:0509bLW0<0WinO0P2VYZH30:n_[`<0
][Jf0P2m_Kd30<?3``80alO71P39bLT20<K6aP<0a<C41@3:b/X30;>c/`80UYJF0`1iNGT206ATI0<0
JFUY0`1cLg<207UiN@<0Ng]k0P1cLg<306YZJP<0IVIV0P1SHf<305eMG@80EEEE0`18B4P303/k>`80
<30`0`0];Bd203Ti>@<0Bd];0P1OGel306m_K`<0MGEe0P1aLG4305aLG080@D510`12@T8304];B`80
F5QH0`1RHV8205EEE@<0AdM70`10@40204e=C@<0Jf][0P2YZJT60<o?c`80dm?C0`3@d=020<o?c`<0
c<c<0`3=cLd20<W9b@<0]kNg0P2NWYh307UiN@<0FUYJ0P1GEeL3069RHP80OGem0`1dM7@206][J`<0
HF5Q0`1XJ6P2075aL@<0M7Ad0P1eMGD607AdM080NGUi0`1nOWh208>3P`<0QXJ60`27QhL208V9R@<0
TI6A0P2HV9P309VIVC@0b>3H0`0h>3P202PX:0<09RHV0P0W9bL302HV9P<0;Bd]0P10@40306EUI@80
Ogmo0`1?Cdl303De=@80;Rh^0`0a<C4202TY:@<0=CDe0P0[:b/302TY:@<0<C4a0P0];Bd3034a<@80
?Cdm0`0];Bd302PX:080;Bd]0`0V9RH202`/;0<0:b/[0`0X:2P202<S8`<0;Bd]0P0W9bL302@T90<0
9RHV0P0_;bl305YJFP80N7Qh0`1cLg<3055AD@80G5aL0`1mOGd209NGU`<0/K6a0`2NWYh209>CT`<0
UiNG0P2CTi<309VIV@80XZ:R0`2ZZZX30;Bd]080^k^k0`33`l<20<K6aP<0bLW90`3:b/X20<S8b0D0
aLG50`33`l<30<;2`P80V9RH0`1WIfL206e]K@<0IFEU0`1cLg<207QhN0<0NWYj0P1eMGD306i^KP<0
I6AT0P1QHF4305mOG`80EUIF0`1>CTh303Lg=`80;bl_0`0c<c<204E5A@<0De=C0P1JFUX306a/K0<0
Ogmo0P1cLg<305QHF080>c/k0`0l?3`304m?C`80EeMG0`1JFUX2051@D0<0CDe=0`0g=cL20451@@<0
LG5a0P2][Jd30<o?c`<0dm?C0P3Bd]850=?Cd`<0cLg=0`3>c/h20<[:bP<0][Jf0P2NWYh307]kN`<0
GEeM0P1DE5@306=SH`80OWin0`1fMWH206IVIP<0HV9R0`1[Jf/506m_K`80MGEe0`1bLW8307IfMP80
NWYj1@20P80308J6QP<0R8R80P29RHT3092@T080UiNG0`2RXZ8L0<SPf0006`38h=P303Ph>080<30`
0`0W9bL202DU9@<0:2PX0`0a<C4203Xj>P<0JFUY0P1gMgL304a<C0<0=3@d0P0/;2`302d];@80;Rh^
0`0_;bl202d];@H0:b/[0P0/;2`303<c<`80>3Ph0`0a<C4302TY:@80:2PX0`0Y:BT202XZ:P<0:b/[
0`0Y:BT202LW9`D0:2PX0`0R8R8302DU9@80<C4a0`1QHF4208>3P`<0MgMg0`1GEeL205aLG0<0NGUi
0P2NWYh30;Fe]@<0XZ:R0P2PX:0509bLW0<0WinO0P2VYZH30:n_[`<0][Jf0P2m_Kd30<?3``80alO7
1P39bLT20<K6aP<0a<C41@3:b/X30;>c/`80UYJF0`1iNGT206ATI0<0JFUY0`1cLg<207UiN@<0Ng]k
0P1cLg<306YZJP<0IVIV0P1SHf<305eMG@80EEEE0`18B4P303/k>`80<30`0`0];Bd203Ti>@<0Bd];
0P1OGel306m_K`<0MGEe0P1aLG4305aLG080@D510`12@T8304];B`80F5QH0`1RHV8205EEE@<0AdM7
0`10@40204e=C@<0Jf][0P2YZJT60<o?c`80dm?C0`3@d=020<o?c`<0c<c<0`3=cLd20<W9b@<0]kNg
0P2NWYh307UiN@<0FUYJ0P1GEeL3069RHP80OGem0`1dM7@206][J`<0HF5Q0`1XJ6P2075aL@<0M7Ad
0P1eMGD607AdM080NGUi0`1nOWh208>3P`<0QXJ60`27QhL208V9R@<0TI6A0P2HV9P309VIVC@0b>3H
0`0h>3P202PX:0<09RHV0P0W9bL302HV9P<0;Bd]0P10@40306EUI@80Ogmo0`1?Cdl303De=@80;Rh^
0`0a<C4202TY:@<0=CDe0P0[:b/302TY:@<0<C4a0P0];Bd3034a<@80?Cdm0`0];Bd302PX:080;Bd]
0`0V9RH202`/;0<0:b/[0`0X:2P202<S8`<0;Bd]0P0W9bL302@T90<09RHV0P0_;bl305YJFP80N7Qh
0`1cLg<3055AD@80G5aL0`1mOGd209NGU`<0/K6a0`2NWYh209>CT`<0UiNG0P2CTi<309VIV@80XZ:R
0`2ZZZX30;Bd]080^k^k0`33`l<20<K6aP<0bLW90`3:b/X20<S8b0D0aLG50`33`l<30<;2`P80V9RH
0`1WIfL206e]K@<0IFEU0`1cLg<207QhN0<0NWYj0P1eMGD306i^KP<0I6AT0P1QHF4305mOG`80EUIF
0`1>CTh303Lg=`80;bl_0`0c<c<204E5A@<0De=C0P1JFUX306a/K0<0Ogmo0P1cLg<305QHF080>c/k
0`0l?3`304m?C`80EeMG0`1JFUX2051@D0<0CDe=0`0g=cL20451@@<0LG5a0P2][Jd30<o?c`<0dm?C
0P3Bd]850=?Cd`<0cLg=0`3>c/h20<[:bP<0][Jf0P2NWYh307]kN`<0GEeM0P1DE5@306=SH`80OWin
0`1fMWH206IVIP<0HV9R0`1[Jf/506m_K`80MGEe0`1bLW8307IfMP80NWYj1@20P80308J6QP<0R8R8
0P29RHT3092@T080UiNG0`2RXZ8L0<SPf0006`38h=P303Ph>080<30`0`0W9bL202DU9@<0:2PX0`0a
<C4203Xj>P<0JFUY0P1gMgL304a<C0<0=3@d0P0/;2`302d];@80;Rh^0`0_;bl202d];@H0:b/[0P0/
;2`303<c<`80>3Ph0`0a<C4302TY:@80:2PX0`0Y:BT202XZ:P<0:b/[0`0Y:BT202LW9`D0:2PX0`0R
8R8302DU9@80<C4a0`1QHF4208>3P`<0MgMg0`1GEeL205aLG0<0NGUi0P2NWYh30;Fe]@<0XZ:R0P2P
X:0509bLW0<0WinO0P2VYZH30:n_[`<0][Jf0P2m_Kd30<?3``80alO71P39bLT20<K6aP<0a<C41@3:
b/X30;>c/`80UYJF0`1iNGT206ATI0<0JFUY0`1cLg<207UiN@<0Ng]k0P1cLg<306YZJP<0IVIV0P1S
Hf<305eMG@80EEEE0`18B4P303/k>`80<30`0`0];Bd203Ti>@<0Bd];0P1OGel306m_K`<0MGEe0P1a
LG4305aLG080@D510`12@T8304];B`80F5QH0`1RHV8205EEE@<0AdM70`10@40204e=C@<0Jf][0P2Y
ZJT60<o?c`80dm?C0`3@d=020<o?c`<0c<c<0`3=cLd20<W9b@<0]kNg0P2NWYh307UiN@<0FUYJ0P1G
EeL3069RHP80OGem0`1dM7@206][J`<0HF5Q0`1XJ6P2075aL@<0M7Ad0P1eMGD607AdM080NGUi0`1n
OWh208>3P`<0QXJ60`27QhL208V9R@<0TI6A0P2HV9P309VIVC@0b>3H0`0h>3P202PX:0<09RHV0P0W
9bL302HV9P<0;Bd]0P10@40306EUI@80Ogmo0`1?Cdl303De=@80;Rh^0`0a<C4202TY:@<0=CDe0P0[
:b/302TY:@<0<C4a0P0];Bd3034a<@80?Cdm0`0];Bd302PX:080;Bd]0`0V9RH202`/;0<0:b/[0`0X
:2P202<S8`<0;Bd]0P0W9bL302@T90<09RHV0P0_;bl305YJFP80N7Qh0`1cLg<3055AD@80G5aL0`1m
OGd209NGU`<0/K6a0`2NWYh209>CT`<0UiNG0P2CTi<309VIV@80XZ:R0`2ZZZX30;Bd]080^k^k0`33
`l<20<K6aP<0bLW90`3:b/X20<S8b0D0aLG50`33`l<30<;2`P80V9RH0`1WIfL206e]K@<0IFEU0`1c
Lg<207QhN0<0NWYj0P1eMGD306i^KP<0I6AT0P1QHF4305mOG`80EUIF0`1>CTh303Lg=`80;bl_0`0c
<c<204E5A@<0De=C0P1JFUX306a/K0<0Ogmo0P1cLg<305QHF080>c/k0`0l?3`304m?C`80EeMG0`1J
FUX2051@D0<0CDe=0`0g=cL20451@@<0LG5a0P2][Jd30<o?c`<0dm?C0P3Bd]850=?Cd`<0cLg=0`3>
c/h20<[:bP<0][Jf0P2NWYh307]kN`<0GEeM0P1DE5@306=SH`80OWin0`1fMWH206IVIP<0HV9R0`1[
Jf/506m_K`80MGEe0`1bLW8307IfMP80NWYj1@20P80308J6QP<0R8R80P29RHT3092@T080UiNG0`2R
XZ8L0<SPf0006`38h=P303<c<`80;Rh^0`0Y:BT502HV9P<0=3@d0P11@D4307]kN`80MGEe0`11@D43
0410@080<30`0`0Z:RX202PX:0<0:RXZ0P0[:b/302`/;0<0:RXZ0P0[:b/303<c<`80>3Ph0`0a<C43
02LW9`809RHV0`0X:2P202`/;0<0;bl_0`0[:b/502DU9@809RHV0`0R8R8302@T9080=3@d0`18B4P2
06a/K0<0QhN70`1aLG4205UIF@<0KVi^0P2:RXX30<G5a@<0][Jf0P2^[Zh309bLW080UYJF0`2EUID2
09fMW@<0YjNW0`2^[Zh20;Fe]@<0_Kfm0P35aLD30<W9b@<0c<c<0P39bLT80<G5a@<0bl_;0P36a/H3
09FEU@80IFEU0`1SHf<306][J`80Kfm_0`1aLG4206UYJ@<0GUiN0`1GEeL2051@D0<0BTY:0P13@d<3
03Ph>0<0;bl_0P0^;Rh303<c<`80?Shn0`1>CTh206EUI@<0MWIf0`1`L702069RHP<0Bd];0P0i>CT3
04e=C@<0I6AT0P1LG5`3051@D080EUIF0`1LG5`304I6AP80?Cdm0`0l?3`208:2PP<0bLW90`3>c/h2
0=GEe@D0d=3@0`3>c/h30<o?c`80b/[:0`2e]KD209NGU`<0Jf][0`17AdL2059BDP<0HV9R0P24Q8@5
06=SH`<0HF5Q0`1YJFT2075aL@<0L71`0P1_Kfl307=cL`<0MgMg0P1jNWX307emO@80PX:20`26QXH3
08N7Q`80R8R80`2@T90209NGU`<0VIVI=038h=P303Ph>080;Rh^0`0[:b/202TY:@<0:b/[0`0a<C42
04E5A@<0NGUi0P1gMgL304I6AP<0?Shn0P0/;2`302TY:@80:RXZ0`0/;2`202XZ:P<0;Bd]0`0/;2`2
02XZ:P<0<30`0P0j>SX302h^;P<0:RXZ0P0V9RH302PX:080:BTY1P0[:b/202DU9@<09bLW0P0S8b<6
02DU9@80;Rh^0`1:BTX206UYJ@<0Q8B40`1bLW8205IFEP<0K6a/0P2CTi<30;bl_0<0_kno0P2XZ:P3
0:6QX@80VIVI0`2EUID209VIV@<0Z:RX0`2][Jd20;>c/`<0_[jn0P33`l<60<[:bP80bl_;0`36a/H2
0<71`@<0a/K61@37alL309>CT`80JFUY0`1RHV8306MWI`80M7Ad0`1^KVh206UYJ@<0G5aL0`1DE5@2
059BDP<0CTi>0P12@T8303/k>`<0;Rh^0P0[:b/302d];@80ADE50`1:BTX205eMG@<0MGEe0`1iNGT2
06=SH`<0@d=30P0j>SX305ADE0<0HV9R1@1FEUH205]KF`<0De=C0`18B4P203Ti>@<0@T920P1nOWh3
0<G5a@<0dM7A0P3>c/h30=3@d080d];B0`3=cLd30<k>cP80b<S80`2f][H209FEU@<0K6a/0`1<C4`2
04I6AP<0K6a/0P1nOWh306YZJP80G5aL0`1PH605071`L0<0KFe]0P1`L70307IfMP<0NGUi0P1jNWX3
07emO@80PH610`25QHD308Z:RP80R8R80`2=SHd209FEU@<0W9bL7038h=P001/0b>3H0`0c<c<202h^
;P<0:BTY1@0V9RH303@d=080@D510`1kNg/207EeM@<0@D510`10@402030`<0<0:RXZ0P0X:2P302XZ
:P80:b/[0`0/;2`302XZ:P80:b/[0`0c<c<203Ph>0<0<C4a0`0W9bL202HV9P<0:2PX0P0/;2`302l_
;`<0:b/[1@0U9BD202HV9P<08R8R0`0T92@203@d=0<0B4Q80P1/K6`308N7Q`<0LG5a0P1IFET306i^
KP80RXZ:0`35aLD30;Jf]P80[Zj^0`2LW9`209JFUP<0UIFE0P2MWId30:NWY`<0[Zj^0P2e]KD30;fm
_@80aLG50`39bLT30<c<c080bLW92035aLD30<_;b`80a/K60`2EUID206EUI@<0Hf=S0`1[Jf/206m_
K`<0LG5a0P1YJFT305iNGP<0EeMG0P1@D50304Y:BP80@d=30`0h>3P302l_;`80;Rh^0`0c<c<203hn
?P<0CTi>0P1UIFD307IfMP<0L71`0P1RHV8304];B`80>CTi0`1=CDd306ATI080G5aL0`1@D50205IF
EP<0G5aL0`16ATH203dm?@<0?3`l0P22PX830<W9b@<0c/k>0P3EeMD50=3@d0<0c/k>0`3?cll20<[:
bP<0]KFe0P2GUiL306][J`<0AdM70P1BDU83069RHP80Q8B41@1SHf<3065QH@<0JFUY0P1aLG43071`
L080Kfm_0`1cLg<307MgM`80NWYj0`1mOGd208:2PP<0QXJ60`27QhL208R8R0<0T92@0P2GUiL309VI
VC@0b>3H0`0h>3P202h^;P<0:b/[0P0Y:BT302/[:`<0<C4a0P15ADD307UiN@80MgMg0`16ATH303hn
?P80;2`/0`0Y:BT202XZ:P<0;2`/0P0Z:RX302d];@<0;2`/0P0Z:RX3030`<080>SXj0`0^;Rh302XZ
:P809RHV0`0X:2P202TY:@H0:b/[0P0U9BD302LW9`808b<S1P0U9BD202h^;P<0BTY:0P1YJFT308B4
Q0<0LW9b0P1FEUH306a/K080Ti>C0`2l_;`30;no_`80Z:RX0`2QXJ4209VIV@<0UIFE0P2IVIT30:RX
Z0<0[Jf]0P2c/k<30;jn_P80`l?31P3:b/X20<_;b`<0a/K60P31`L430<K6aPD0alO70`2CTi<206UY
J@<0HV9R0`1WIfL207AdM0<0KVi^0P1YJFT305aLG0<0E5AD0P1BDU8304i>CP80@T920`0k>c/302h^
;P80:b/[0`0];Bd204E5A@<0BTY:0P1MGEd307EeM@<0NGUi0P1SHf<304=3@`80>SXj0`1DE5@3069R
HPD0EUIF0P1KFe/305=CD`<0B4Q80P0i>CT30492@P80OWin0`35aLD30=7Ad@80c/k>0`3@d=020=;B
dP<0cLg=0`3>c/h20<S8b0<0][Jf0P2EUID306a/K0<0C4a<0P16ATH306a/K080OWin0`1ZJVX205aL
G0<0H61P1@1`L70306e]K@80L71`0`1fMWH307UiN@80NWYj0`1mOGd20861P@<0QHF50`2:RXX208R8
R0<0SHf=0P2EUID309bLW1`0b>3H000K0<SPf0<0<c<c0P0^;Rh302TY:@D09RHV0`0d=3@20451@@<0
Ng]k0P1eMGD30451@@<0@4100P0`<30302XZ:P80:2PX0`0Z:RX202/[:`<0;2`/0`0Z:RX202/[:`<0
<c<c0P0h>3P3034a<@<09bLW0P0V9RH302PX:080;2`/0`0_;bl302/[:`D09BDU0P0V9RH3028R8P<0
92@T0P0d=3@304Q8B080K6a/0`27QhL3075aL@80FEUI0`1^KVh208Z:RP<0aLG50`2f][H20:j^[P<0
W9bL0P2FUYH309FEU@80WIfM0`2WYjL30:j^[P80]KFe0`2m_Kd20<G5a@<0bLW90`3<c<`20<W9b@P0
aLG50`3;bl/20<K6aP<0UIFE0P1UIFD306=SH`<0Jf][0P1_Kfl3075aL@80JFUY0`1NGUh305MGE`80
D51@0`1:BTX204=3@`<0>3Ph0`0_;bl202h^;P<0<c<c0P0n?Sh304i>CP80IFEU0`1fMWH3071`L080
HV9R0`1;Bd/203Ti>@<0CDe=0`1TI6@205aLG0<0D51@0P1FEUH305aLG0<0ATI60P0m?Cd303`l?080
PX:20`39bLT30<k>cP80eMGE1@3@d=030<k>cP<0clo?0P3:b/X30;Fe]@80UiNG0`1[Jf/304M7A`80
DU9B0`1RHV8208B4Q0D0Hf=S0`1QHF4306UYJ@80LG5a0`1`L70206m_K`<0Lg=c0`1gMgL207YjNP<0
OGem0P22PX8308J6QP<0QhN70P28R8P3092@T080UiNG0`2IVITd0<SPf0<0>3Ph0P0^;Rh302/[:`80
:BTY0`0[:b/3034a<@80ADE50`1iNGT207MgM`<0ATI60`0n?Sh202`/;0<0:BTY0P0Z:RX302`/;080
:RXZ0`0];Bd302`/;080:RXZ0`0`<30203Xj>P<0;Rh^0`0Z:RX202HV9P<0:2PX0P0Y:BT602/[:`80
9BDU0`0W9bL202<S8`H09BDU0P0^;Rh304Y:BP80JFUY0`24Q8@3079bLP80EUIF0`1/K6`209>CT`<0
_;bl0`2o_kl20:RXZ0<0XJ6Q0P2IVIT309FEU@80VIVI0`2XZ:P30:f][@80/k>c0`2n_[h20<?3``H0
b/[:0P3;bl/30<K6aP80`L710`36a/H50<O7a`<0Ti>C0P1YJFT3069RHP<0IfMW0P1dM7@306i^KP80
JFUY0`1LG5`305ADE080DU9B0`1>CTh20492@P<0>c/k0`0^;Rh202/[:`<0;Bd]0P15ADD304Y:BP80
GEeM0`1eMGD307UiN@80Hf=S0`13@d<203Xj>P<0E5AD0`1RHV8505IFEP80Fe]K0`1CDe<304Q8B080
>CTi0`12@T8207inOP<0aLG50`3AdM420<k>cP<0d=3@0P3Bd]830<g=c@<0c/k>0P38b<P30;Jf]P80
UIFE0`1/K6`304a<C080ATI60`1/K6`207inOP<0JVYZ0P1LG5`3061PH0D0L71`0`1]KFd2071`L0<0
MWIf0`1iNGT207YjNP<0OGem0P21PH4308F5Q@<0RXZ:0P28R8P308f=S@80UIFE0`2LW9`L0<SPf000
6`38h=P3030`<080;bl_0`0];Bd202PX:0<0:BTY0`0`<302059BDP<0SHf=0P1OGel303@d=0<0@T92
0P0c<c<302TY:@809RHV0`0W9bL202TY:@P0;2`/0`0c<c<203Lg=`<0<C4a0`0Z:RX502LW9`80;Bd]
0`0a<C4302h^;P80:RXZ1@0W9bL302h^;P<0>3Ph0P0l?3`304=3@`80De=C0`24Q8@3092@T080L71`
0`1YJFT206i^KP<0[Jf]0`35aLD20;^k^`<0YZJV1@2RXZ820:RXZ0<0[jn_0`2c/k<20;Ng]`<0^[Zj
0P2n_[h30<K6aP<0cLg=0P3;bl/30<S8b0D0alO70`3=cLd20<_;b`<0/K6a0P2ATI4306a/K0<0EeMG
0P1OGel306UYJ@80HV9R0`1FEUH304];B`80@D510`0l?3`203Lg=`<0<C4a0`0];Bd202h^;P<0<S8b
0P0m?Cd304];B`80Hf=S0`1dM7@3069RHP80CTi>0`0l?3`2059BDP<0EeMG0`1JFUX204Y:BP<0?3`l
0P19BDT3055AD@<0Fe]K0P17AdL302/[:`80G5aL0`2e]KD30<_;b`80d];B0`3:b/X20<g=c@<0c/k>
0`3:b/X20<?3``<0YJFU0P21PH4305]KF`<0@d=30P1LG5`307MgM`80Ng]k0`1IFET2061PH0<0JVYZ
0`1`L70207=cL`<0LG5a0P1_Kfl307EeM@<0O7al0P1oOgl30820P080Q8B40`27QhL308V9R@80Rh^;
0`2?Shl209>CT`<0U9BD=038h=P303De=@80:RXZ0`0`<30202HV9P<09bLW0`0^;Rh2059BDP<0R8R8
0P1DE5@303Hf=P<0A4A41@0`<30202<S8`<092@T0P0V9RH302l_;`<09RHV0P0^;Rh303Lg=`80>3Ph
0`0_;bl302/[:`80:BTY0`0W9bL203@d=0<0>CTi0`0b<S8202/[:`<09BDU0P0X:2P302d];@<0=CDe
0P18B4P304Y:BP80HV9R0`29RHT309fMW@80MGEe0`1PH60207AdM0<0ZJVY0`3=cLd20;no_`<0ZZZZ
0P2TY:@30:f][@80ZZZZ0`2b/[830;^k^`80][Jf0`2m_Kd20;bl_0<0b<S80`39bLT20<_;b`D0a/K6
0`3=cLd30<W9b@80b<S80`32`/8208f=S@<0GEeM0`1QHF4206][J`<0IFEU0P1QHF4305IFEP<0De=C
0P10@40303De=@80<c<c0`0`<303034a<@80;Bd]0`0_;bl20492@P<0AdM70P1OGel307=cL`<0Jf][
0P17AdL303@d=080G5aL0`1RHV8305YJFP80B4Q81@12@T8305YJFP<0K6a/0P1:BTX303De=@80EeMG
0`2a/K430<o?c`D0c<c<0P3>c/h30<_;b`<0b<S80P2o_kl30:^[Z`80P8200`1HF5P304I6AP80F5QH
0`1lO7`207QhN0<0GUiN0P1JFUX306a/K0<0MgMg0P1bLW83071`L080LG5a0`1cLg<307QhN080Ng]k
0`21PH4208J6QP<0QhN70`28R8P208^;R`<0SHf=0P2ATI4309VIVA`0b>3H000K0<SPf0<0<30`0P0_
;bl302d];@80:2PX0`0Y:BT3030`<080DU9B0`2=SHd205mOG`<0=3@d0`12@T8203<c<`<0:BTY0P0V
9RH302LW9`80:BTY200/;2`303<c<`80=cLg0`0a<C4302XZ:PD09bLW0P0];Bd3034a<@<0;Rh^0P0Z
:RX502LW9`<0;Rh^0`0h>3P203`l?0<0@d=30P1CDe<308B4Q0<0T92@0P1`L70306UYJ@80KVi^0`2]
[Jd30<G5a@80^k^k0`2VYZH50::RXP80Z:RX0`2_[jl30;>c/`80]kNg0`2j^[X20;jn_P<0a/K60`3=
cLd20<_;b`<0b<S81@37alL30<g=c@80bl_;0`2a/K42096AT@<0K6a/0`1GEeL205mOG`<0JFUY0P1R
HV8305IFEP<0Bd];0P11@D4303`l?080=cLg0`0a<C4302d];@80;Rh^0`0b<S8203dm?@<0Bd];0P1S
Hf<307AdM0<0HV9R0P1>CTh303`l?080DU9B0`1GEeL305YJFP80BTY:0`0l?3`204U9B@<0DE5A0`1K
Fe/204M7A`<0:b/[0P1LG5`30;Fe]@<0bl_;0P3Bd]830<[:bP80cLg=0`3>c/h30<[:bP80`l?30`2U
YJD20861P@<0Fe]K0`13@d<205aLG0<0MgMg0P1kNg/305UIF@80H61P0`1ZJVX3071`L080Lg=c0`1a
LG4206m_K`<0MGEe0`1lO7`207moO`<0P8200P24Q8@308N7Q`<0RHV90P2;Rh/308n?S`80Ti>C0`2D
U9@d0<SPf0<0=CDe0P0Z:RX3030`<0809RHV0`0W9bL302h^;P80DU9B0`28R8P205ADE0<0=SHf0`14
A4@5030`<0808b<S0`0T92@202HV9P<0;bl_0`0V9RH202h^;P<0=cLg0P0h>3P302l_;`<0:b/[0P0Y
:BT302LW9`80=3@d0`0i>CT3038b<P80:b/[0`0U9BD202PX:0<0;Bd]0`0e=CD204Q8B0<0BTY:0P1R
HV8308V9R@<0WIfM0P1eMGD3061PH080M7Ad0`2YZJT30<g=c@80_kno0`2ZZZX20:BTY0<0[Jf]0P2Z
ZZX30;:b/P<0^k^k0P2f][H30;fm_@80_;bl0`38b<P30<W9b@80bl_;1@36a/H30<g=c@<0bLW90P38
b<P30<;2`P80SHf=0`1MGEd3065QH@80Jf][0`1UIFD2065QH@<0EUIF0`1CDe<20410@0<0=CDe0P0c
<c<3030`<0<0<C4a0P0];Bd302l_;`80@T920`17AdL205mOG`<0Lg=c0`1[Jf/204M7A`<0=3@d0P1L
G5`3069RHP<0FUYJ0P18B4P50492@P<0FUYJ0`1/K6`204Y:BP<0=CDe0P1GEeL30;6a/@<0clo?1@3<
c<`20<k>cP<0bl_;0`38b<P20;no_`<0Zj^[0P20P80305QHF0<0ATI60P1HF5P307alO080N7Qh0`1N
GUh205YJFP<0K6a/0`1gMgL2079bLP<0L71`0P1aLG4307=cL`<0N7Qh0P1kNg/30861P@80QXJ60`27
QhL308R8R080Rh^;0`2=SHd2096AT@<0VIVI7038h=P001/0b>3H0`0^;Rh202l_;`<0<C4a0P0Z:RX3
02`/;0<0;bl_0P1UIFD309FEU@80ATI60`0X:2P30451@@80<c<c0`0Y:BT202HV9P<09BDU0P0X:2P3
02`/;0<0;Bd]0P0^;Rh3038b<P80=SHf0`0c<c<302h^;P80:RXZ0`0X:2P202h^;PH0=CDe0P0c<c<3
02`/;080:BTY0`0k>c/304e=C@80A4A40`0o?cl203Xj>P<0MGEe0`2TY:@208Z:RP<0K6a/0P1HF5P3
08b<S0<0alO70P33`l<30;>c/`D0/;2`0P2d];@30;Rh^0<0^KVi0P2j^[X50;Ng]`<0`/;20`3<c<`2
0<g=c@D0b/[:0`39bLT30<S8b080a/K60`39bLT20<71`@<0NGUi0`1BDU8205ADE0<0HF5Q0P1KFe/3
055AD@<0ADE50P0i>CT303@d=080<S8b0`0_;bl502h^;P<0<C4a0P0i>CT304E5A@80GEeM0`1]KFd3
059BDP80>c/k0`0a<C4206UYJ@<0Fe]K0`18B4P2038b<P<08b<S0P0g=cL304Y:BP<0L71`0P1DE5@3
02`/;080B4Q80`2TY:@30<S8b080c/k>0`34a<@20<S8b0<0bLW90`30`<020;:b/P<0S8b<0P1UIFD3
04];B`<0@T920P1TI6@308F5Q@80K6a/0`1BDU82061PH0<0M7Ad0`1hN7P207MgM`<0Lg=c0P1aLG43
07UiN@<0PH610P23Ph<308B4Q080QhN70`2:RXX308b<S080SXj>0`2@T905096ATC@0b>3H0`0X:2P2
03De=@<0:b/[1@0/;2`303@d=080IVIV0`2=SHd204U9B@<0<C4a0`0m?Cd203De=@<0:BTY0P0W9bL3
02TY:@80:2PX1P0^;Rh202l_;`<0;2`/0P0j>SX6038b<P80:RXZ0`0[:b/202XZ:P<0=3@d0`0j>SX2
03@d=0<0:RXZ0P0Y:BT302l_;`<0BDU90P1;Bd/303Ti>@80>c/k0`1dM7@309RHV080SXj>0`1WIfL2
05aLG0<0S8b<0`32`/820<W9b@<0];Bd0P2TY:@30:n_[`80][Jf0`2c/k<50;Vi^@<0^;Rh0P2g]kL3
0<30`0<0c<c<0P3?cll30<_;b`80alO71P39bLT20<C4a0<0bLW90P2m_Kd307YjNP<0D51@0P1KFe/3
05iNGP80EUIF0`1ADE4304A4A0D0>3Ph0P0e=CD303<c<`<0:RXZ0P0^;Rh303@d=080>3Ph0`16ATH2
05aLG0<0IfMW0`1JFUX2038b<P<0>CTi0P1NGUh305eMG@<0C4a<0P0`<30302TY:@80:b/[0`15ADD3
071`L080CDe=0`0h>3P20492@P<0WIfM1@3<c<`80<K6aP<0`L710P2/[:`3092@T080HV9R0`16ATH3
04A4A080GEeM0`23Ph<206i^KP<0E5AD0P1KFe/307AdM0<0NWYj0P1eMGD307AdM080LG5a0`1cLg<3
08R8R080PX:20`24Q8@208V9R@<0Rh^;0`29RHT2092@T0<0S8b<0P2?Shl309VIVA`0b>3H000K0<SP
f0<0;Rh^0P0_;bl3034a<@80:RXZ0`0/;2`302l_;`80IFEU0`2EUID204I6AP<0:2PX0`11@D4203<c
<`<0:BTY0P0V9RH302DU9@80:2PX0`0/;2`302d];@80;Rh^0`0b<S8203Hf=P<0<c<c0`0^;Rh202XZ
:P<0:2PX0P0^;Rh603De=@80<c<c0`0/;2`202TY:@<0>c/k0`1=CDd204A4A0<0?clo0P0j>SX307Ee
M@<0Y:BT0P2:RXX306a/K080F5QH0`2<S8`30<O7a`80`l?30`2c/k<50;2`/080];Bd0`2h^;P30;Vi
^@80^[Zj1@2g]kL30<;2`P<0c<c<0P3=cLd50<[:bP<0bLW90`38b<P20<K6aP<0bLW90P31`L4307Ui
N@<0DU9B0P1DE5@3065QH@80Fe]K0`1ADE4304E5A@80>CTi0`0d=3@2038b<P<0;bl_1@0^;Rh3034a
<@80>CTi0`15ADD205eMG@<0KFe]0`1BDU8203/k>`<0<C4a0P1YJFT305]KF`<0B4Q80P0b<S8302<S
8`80=cLg0`1:BTX3071`L080E5AD0`0/;2`204Q8B0<0Y:BT0`38b<P20<k>cP<0a<C40P38b<P30<W9
b@<0`<300P2b/[8308b<S080IFEU0`1;Bd/30492@P80I6AT0`25QHD206a/K0<0DU9B0P1PH60307Ad
M0<0N7Qh0P1gMgL307=cL`80LG5a0`1iNGT30861P@80Ph>30`24Q8@208N7Q`<0RXZ:0`2<S8`208j>
SP<0T92@1@2ATI4d0<SPf0<0:2PX0P0e=CD302/[:`D0;2`/0`0d=3@206IVIP<0SHf=0P19BDT3034a
<@<0?Cdm0P0e=CD302TY:@809bLW0`0Y:BT202PX:0H0;Rh^0P0_;bl302`/;080>SXj1P0b<S8202XZ
:P<0:b/[0P0Z:RX303@d=0<0>SXj0P0d=3@302XZ:P80:BTY0`0_;bl304U9B@80Bd];0`0i>CT203/k
>`<0M7Ad0`2HV9P208j>SP<0IfMW0P1LG5`308b<S0<0`/;20P39bLT30;Bd]080Y:BT0`2_[jl20;Jf
]P<0/k>c1@2i^KT30;Rh^080]kNg0`30`<030<c<c080clo?0`3;bl/20<O7a`H0bLW90P34a<@30<W9
b@80_Kfm0`1jNWX3051@D080Fe]K0`1NGUh205IFEP<0DE5A0`14A4@503Ph>080=CDe0`0c<c<302XZ
:P80;Rh^0`0d=3@203Ph>0<0ATI60P1LG5`306MWI`<0FUYJ0P0b<S8303Ti>@80GUiN0`1MGEd304a<
C080<30`0`0Y:BT202/[:`<0ADE50`1`L70204e=C@<0>3Ph0P12@T8309fMW@D0c<c<2036a/H30<71
`@80[:b/0`2@T902069RHP<0ATI60`14A4@205eMG@<0Ph>30P1^KVh305ADE080Fe]K0`1dM7@307Yj
NP80MGEe0`1dM7@2075aL@<0Lg=c0`28R8P208:2PP<0Q8B40P29RHT308^;R`<0RHV90P2@T90308b<
S080Shn?0`2IVITL0<SPf0006`38h=P302h^;P80;bl_0`0a<C4202XZ:P<0;2`/0`0_;bl206EUI@<0
UIFE0P16ATH302PX:0<0@D510P0c<c<302TY:@809RHV0`0U9BD202PX:0<0;2`/0`0];Bd202h^;P<0
<S8b0P0f=SH303<c<`<0;Rh^0P0Z:RX302PX:080;Rh^1P0e=CD203<c<`<0;2`/0P0Y:BT303/k>`<0
CDe=0P14A4@303lo?`80>SXj0`1eMGD30:BTY080RXZ:0`1/K6`205QHF0<0S8b<0`37alL20<?3``<0
/k>c1@2`/;020;Bd]0<0^;Rh0`2i^KT20;Zj^PD0]kNg0`32`/830<c<c080cLg=1@3:b/X30<W9b@<0
b<S80P36a/H30<W9b@80`L710`1iNGT3059BDP80E5AD0`1QHF4205]KF`<0DE5A0`15ADD203Ti>@<0
=3@d0P0b<S8302l_;`D0;Rh^0`0a<C4203Ti>@<0ADE50P1MGEd306e]K@<0DU9B0P0k>c/3034a<@80
JFUY0`1KFe/304Q8B080<S8b0`0S8b<203Lg=`<0BTY:0`1`L70205ADE0<0;2`/0P18B4P30:BTY0<0
b<S80P3>c/h30<C4a080b<S80`39bLT30<30`080/[:b0`2<S8`206EUI@<0Bd];0`12@T8206ATI0<0
QHF50P1/K6`3059BDP80H61P0`1dM7@307QhN080MgMg0`1cLg<2075aL@<0NGUi0`21PH4208>3P`<0
Q8B40P27QhL308Z:RP<0S8b<0P2>SXh3092@T0D0TI6A=038h=P302PX:080=CDe0`0[:b/502`/;0<0
=3@d0P1VIVH308f=S@80BDU90`0a<C4303dm?@80=CDe0`0Y:BT202LW9`<0:BTY0P0X:2P602h^;P80
;bl_0`0/;2`203Xj>PH0<S8b0P0Z:RX302/[:`80:RXZ0`0d=3@303Xj>P80=3@d0`0Z:RX202TY:@<0
;bl_0`19BDT204];B`<0>CTi0P0k>c/307AdM0<0V9RH0P2>SXh306MWI`80G5aL0`2<S8`30<;2`P80
bLW90`2d];@20:BTY0<0[jn_0P2f][H30;>c/`D0^KVi0`2h^;P20;Ng]`<0`<300`3<c<`20<o?c`<0
bl_;0P37alL60<W9b@80a<C40`39bLT20;fm_@<0NWYj0`1@D50205]KF`<0GUiN0P1FEUH3055AD@<0
A4A41@0h>3P203De=@<0<c<c0`0Z:RX202h^;P<0=3@d0P0h>3P304I6AP80G5aL0`1WIfL305YJFP80
<S8b0`0i>CT205iNGP<0GEeM0`1<C4`2030`<0<0:BTY0P0[:b/304E5A@<0L71`0P1=CDd303Ph>080
@T920`2MWId50<c<c0P0a/K60`31`L420:b/[0<0T92@0P1RHV8304I6AP<0A4A40P1MGEd308>3P`80
KVi^0`1DE5@205]KF`<0M7Ad0`1jNWX207EeM@<0M7Ad0P1aLG4307=cL`<0R8R80P22PX8308B4Q080
RHV90`2;Rh/308V9R@80T92@0`2<S8`208n?S`<0VIVI7038h=P001/0b>3H0`0_;bl502h^;P809bLW
0`0`<30303Lg=`80N7Qh0`1mOGd203Ti>@<0:2PX0`0f=SH2034a<@<0;Bd]0P0Z:RX302PX:080:RXZ
1P0];Bd202h^;P<0;bl_0P0`<303034a<@<0<S8b0P0/;2`302TY:@80=cLg0`16ATH304Q8B080A4A4
0`0h>3P202/[:`<08R8R0`0M7Ad2024Q8@D0;Rh^0`1CDe<308n?S`80V9RH0`29RHT205IFEP<0MWIf
0`2RXZ820;Ng]`<0`/;20P2d];@30:VYZ@80[Jf]0`2d];@30;Jf]P80]kNg1@2e]KD30;^k^`<0`l?3
0P39bLT30<g=c@80bl_;1P37alL20<K6aP<0b<S80P2m_Kd30;^k^`<0LG5a0P1HF5P304e=C@80E5AD
0`1EEED304a<C080@T920`0k>c/203Hf=P<0<30`1@0[:b/302h^;P80=3@d0`0m?Cd2051@D0<0GEeM
0`16ATH5038b<P80EUIF0`1:BTX303Ti>@80:b/[0`0U9BD201`L70<0>3Ph0`1DE5@204m?C`<0=SHf
0P14A4@309NGU`<0clo?0P3Cdm<30<C4a080`/;20`2i^KT30;Fe]@80RHV90`1UIFD204E5A@<0?3`l
0`0o?cl205EEE@<0JVYZ0P1HF5P304a<C080HF5Q0`1kNg/307emO@80NWYj0`1fMWH207AdM0<0NWYj
0`21PH4208B4Q0<0QXJ60P28R8P308^;R`<0SXj>0P2@T90309:BTPD0Ti>C=038h=P302LW9`80>3Ph
0`0^;Rh202LW9`<0;2`/0`0n?Sh207YjNP<0OGem0P0o?cl302/[:`<0=CDe0P0[:b/302`/;080:2PX
0`0Z:RX202/[:`<0:BTY0`0c<c<2030`<0<0;bl_0P0a<C4302h^;P<0;bl_1@0[:b/202d];@<0@410
0`18B4P20451@@<0>3Ph0P0j>SX302DU9@<09RHV0P0W9bL3024Q8@809BDU0`1BDU8308f=S@80XJ6Q
0`1nOWh2061PH0<0K6a/0`2LW9`20<K6aP<0_Kfm0P2TY:@30:f][@80[jn_0`2a/K430;Ng]`80/[:b
0`2a/K420;Ng]`<0^KVi0`33`l<20<k>cP<0bl_;0P3:b/X30<O7a`<0`L710P38b<P30<G5a@80bl_;
0`2g]kL306][J`80DE5A0`1BDU8205QHF0<0EEEE0`1>CTh204A4A0<0>3Ph0P0a<C4303De=@<0;2`/
0P0Z:RX302`/;080<c<c0`11@D42059BDP<0FUYJ0`1ADE42038b<P<0?3`l0P1@D50304m?C`<0<30`
0P0V9RH302@T90809bLW0`0h>3P305YJFP80@D510`0b<S8204Q8B0<0Xj>S1@3<c<`30<O7a`D0`<30
0`2i^KT208^;R`<0Jf][0P18B4P303`l?0<0?Shn0P1XJ6P306a/K080E5AD0`1;Bd/206ATI0<0Ng]k
0`1lO7`207QhN0<0NWYj0P1gMgL307UiN@<0P8200P27QhL308:2PP80QhN71P2;Rh/209JFUP<0SHf=
0P2ATI4309ZJVQ`0b>3H000K0<SPf0<0;bl_1@0^;Rh202LW9`<0<30`0`0g=cL207QhN0<0OGem0P0i
>CT302PX:0<0=SHf0P0a<C4302d];@80:RXZ0`0X:2P202XZ:PH0;Bd]0P0^;Rh302l_;`80<30`0`0a
<C43038b<P80;2`/0`0Y:BT203Lg=`<0ATI60`18B4P204A4A0<0>3Ph0P0[:b/3028R8P<07AdM0P0Q
8B4502h^;P<0De=C0`2?Shl209RHV0<0RHV90P1FEUH307IfMP<0XZ:R0P2g]kL30<;2`P80];Bd0`2Y
ZJT20:f][@<0];Bd0`2f][H20;Ng]`D0]KFe0`2k^k/30<?3``80bLW90`3=cLd20<_;b`H0alO70P36
a/H30<S8b080_Kfm0`2k^k/3075aL@80F5QH0`1=CDd205ADE0<0EEEE0`1<C4`20492@P<0>c/k0P0f
=SH3030`<0D0:b/[0`0^;Rh203@d=0<0?Cdm0P1@D50305eMG@<0ATI61@0b<S8205IFEP<0BTY:0`0i
>CT202/[:`<09BDU0P0L71`303Ph>0<0E5AD0P1?Cdl303Hf=P80A4A40`2GUiL30<o?c`80dm?C0`34
a<@20<;2`P<0^KVi0`2e]KD208V9R@<0IFEU0P15ADD303`l?0<0?clo0P1EEED306YZJP80F5QH0`1<
C4`2065QH@<0Ng]k0`1mOGd207YjNP<0MWIf0P1dM7@307YjNP<0PH610P24Q8@308J6QP80R8R80`2;
Rh/308j>SP80T92@0`2BTY8509>CTc@0b>3H0`0W9bL203Ph>0<0;Rh^0P0W9bL302`/;0<0?Shn0P1j
NWX307emO@80?clo0`0[:b/303De=@80:b/[0`0/;2`202PX:0<0:RXZ0P0[:b/302TY:@<0<c<c0P0`
<30302l_;`80<C4a0`0^;Rh302l_;`D0:b/[0P0];Bd30410@0<0B4Q80P11@D4303Ph>080>SXj0`0U
9BD302HV9P809bLW0`0Q8B4202DU9@<0DU9B0`2=SHd20:6QX@<0OWin0P1PH60306a/K0<0W9bL0P36
a/H30;fm_@80Y:BT0`2][Jd20:n_[`<0/K6a0`2g]kL20;:b/P<0/K6a0P2g]kL30;Vi^@<0`l?30P3>
c/h30<_;b`80b/[:0`37alL30<71`@80b<S80`35aLD20<_;b`<0]kNg0`1[Jf/2055AD@<0DU9B0P1H
F5P305EEE@<0CTi>0P14A4@303Ph>080<C4a0`0e=CD302`/;080:RXZ0`0/;2`203<c<`<0@D510P1B
DU8305YJFP<0DE5A0P0b<S8303`l?080D51@0`1?Cdl3030`<0809RHV0`0T92@202LW9`<0>3Ph0`1J
FUX20451@@<0<S8b0P18B4P30:>SX`D0c<c<0`37alL50<30`0<0^KVi0P2;Rh/306][J`80B4Q80`0l
?3`303hn?P80J6QX0`1/K6`205ADE0<0Bd];0P1TI6@307]kN`<0O7al0P1hN7P307YjNP80MgMg0`1i
NGT30820P080QhN70`22PX8208N7Q`H0Rh^;0P2FUYH308f=S@80TI6A0`2JVYXL0<SPf0006`38h=P3
02l_;`D0;Rh^0P0X:2P303<c<`<0A4A40P28R8P305iNGP80<C4a0`0[:b/302`/;080;Rh^0`0_;bl2
02h^;PD0;2`/1P0];Bd202h^;P<0;bl_0P0b<S8303Lg=`<0>c/k0P0d=3@302l_;`80?clo0`1@D503
05=CD`80CTi>0`0l?3`202XZ:P<0:2PX0`0Y:BT2020P80<06a/K0P0R8R83038b<P<0KFe]0P2KVi/3
0:>SX`80HV9R0`1WIfL307QhN080YJFU0`3;bl/20;Rh^0<0XZ:R0P2UYJD30:j^[P<0/K6a1@2c/k<2
0;Bd]0<0]KFe0`2i^KT20<G5a@<0clo?0P3;bl/30<C4a0D0`l?30`38b<P20<c<c0<0]kNg0`2f][H2
06a/K0<0AdM70P1<C4`305UIF@<0E5AD0P1=CDd304I6AP80?Cdm0`0b<S8302XZ:P80:BTY0`0/;2`2
02l_;`<0=CDe0P12@T8304];B`<0?3`l0P0];Bd303Hf=P80?Cdm0`0f=SH302d];@809BDU0`0Y:BT2
02LW9`<0Hf=S0`1>CTh20451@@<0GEeM0P23Ph<30:b/[0<0clo?0P3>c/h30<30`080]KFe1P2PX:02
05eMG@<0@D510P0[:b/302l_;`<0>c/k0P12@T8504M7A`<0BTY:0P1UIFD307moO`<0PH610P1lO7`3
07YjNP80N7Qh0`1kNg/30861P@80Q8B40`27QhL208Z:RP<0S8b<0`2?Shl2096AT@<0U9BD1@2FUYHd
0<SPf0<0;2`/0P0`<30302d];@80;Rh^0`0`<30304M7A`80P8200`1UIFD202XZ:P<0;bl_0`0];Bd5
034a<@80;Rh^0`0[:b/2038b<P<0;bl_0`0[:b/202d];@<0<30`0P0b<S8603/k>`80;Bd]0`0c<c<2
03lo?`<0D51@0`1JFUX205EEE@<0<S8b0P0Z:RX302LW9`<08R8R0P0Q8B4301lO7`808B4Q0`0b<S83
079bLP80V9RH0`2LW9`206][J`<0GemO0`1iNGT20;6a/@<0b<S80P2`/;030:BTY080Z:RX0`2/[:`3
0;>c/`80]KFe0`2_[jl20;Fe]@<0^;Rh0`2f][H20<[:bP<0c/k>0P39bLT30<O7a`<0`L711`35aLD3
0<C4a0<0[jn_0P1YJFT304a<C080D51@0`1GEeL305EEE@80C4a<0`14A4@203`l?0<0<S8b0`0Z:RX2
02TY:@<0:RXZ0P0c<c<303De=@80?Cdm0`1=CDd304=3@`80:b/[0`0_;bl203hn?P<0?3`l0`0];Bd2
02LW9`<092@T0P0X:2P305QHF0<0EeMG0P11@D4305IFEP80NGUi0`2^[Zh30<[:bP80c<c<0`2o_kl2
0;2`/0<0Xj>S0`2JVYX2065QH@<0ADE51@0[:b/303/k>`80C4a<0`1:BTX203lo?`<0Cdm?0P1]KFd3
07]kN`<0PX:20P1lO7`307UiN@80MWIf0`1iNGT30820P080RXZ:0`26QXH208b<S0<0Rh^;0`2BTY82
092@T0<0TI6A0P2DU9@309VIVA`0b>3H000K0<SPf0<0;bl_1@0^;Rh202PX:0<0<c<c0`14A4@208R8
R0<0GUiN0P0a<C4302/[:`<0;2`/0P0^;Rh302l_;`80;Rh^1@0/;2`602d];@80;Rh^0`0_;bl2038b
<P<0=cLg0`0k>c/203@d=0<0;bl_0P0o?cl3051@D0<0De=C0P1>CTh303`l?080:RXZ0`0X:2P302TY
:@80820P0`0K6a/2028R8P<0<S8b0`1]KFd209^KV`<0Xj>S0P1RHV8306MWI`<0N7Qh0P2UYJD30<_;
b`80^;Rh0`2RXZ820:FUY@<0[Zj^0`2a/K450;>c/`80];Bd0`2e]KD30;Vi^@80aLG50`3?cll20<_;
b`<0a<C41@33`l<30<S8b080c<c<0`2g]kL30;Jf]P80K6a/0`17AdL204a<C0<0FEUI0`1DE5@204e=
C@<0ATI60P0m?Cd3038b<P<0:RXZ0P0Y:BT302`/;080;bl_0`0e=CD20492@P<0Bd];0`0l?3`202d]
;@<0=SHf0P0m?Cd303Hf=P<0;Bd]0P0U9BD302TY:@809bLW0`1SHf<304i>CP80@D510`1MGEd208>3
P`<0[:b/0`3?cll20<k>cP<0`<300P2e]KD60:2PX080GEeM0`11@D4202/[:`<0;bl_0`0k>c/20492
@PD0AdM70`1:BTX206EUI@<0Ogmo0`21PH4207alO0<0NWYj0P1hN7P307]kN`<0PH610P24Q8@308N7
Q`80RXZ:0`2<S8`308n?S`80TI6A0`2DU9@509JFUS@0b>3H0`0/;2`2030`<0<0;Bd]0P0^;Rh3030`
<0<0AdM70P20P80306EUI@80:RXZ0`0_;bl302d];@D0<C4a0P0^;Rh302/[:`80<S8b0`0_;bl302/[
:`80;Bd]0`0`<302038b<PH0>c/k0P0];Bd303<c<`80?clo0`1@D50305YJFP80EEEE0`0b<S8202XZ
:P<09bLW0`0R8R82024Q8@<07alO0P0Q8B43038b<P<0LW9b0P2HV9P309bLW080Jf][0`1OGel307Ui
N@80/K6a0`38b<P20;2`/0<0Y:BT0P2XZ:P30:b/[0<0/k>c0P2e]KD30:n_[`80]KFe0`2h^;P30;Jf
]P80b/[:0`3>c/h20<W9b@<0alO70`31`L470<G5a@<0a<C40`2_[jl206UYJ@<0C4a<0P1@D50305MG
E`<0EEEE0P1<C4`304A4A080?3`l0`0b<S8302XZ:P80:BTY0`0Z:RX203<c<`<0=CDe0P0m?Cd304e=
C@<0@d=30P0[:b/302l_;`80?Shn0`0l?3`302d];@809bLW0`0T92@202PX:0<0F5QH0`1GEeL20451
@@<0EUIF0P1iNGT30:j^[P<0b/[:0P3<c<`30;no_`80/;2`0`2SXj<309ZJVP80HF5Q0`15ADD502/[
:`<0>c/k0P1<C4`304Y:BP80?clo0`1?Cdl206e]K@<0Ng]k0`22PX8207alO0<0NGUi0P1fMWH307Ui
N@<0P8200P2:RXX308J6QP80S8b<0`2;Rh/309:BTP80T92@0`2ATI4209BDU0<0VIVI7038h=P001/0
b>3H0`0_;bl502h^;P80:2PX0`0c<c<304A4A080R8R80`1NGUh2034a<@<0:b/[0`0/;2`202h^;P<0
;bl_0P0^;Rh502`/;0H0;Bd]0P0^;Rh302l_;`80<S8b0`0g=cL303/k>`80=3@d0`0_;bl203lo?`<0
D51@0`1CDe<204i>CP<0?3`l0P0Z:RX302PX:0<0:BTY0P0P820301/K6`808R8R0`0b<S8306e]K@80
Vi^K0`2SXj<2069RHP<0IfMW0`1hN7P20:FUY@<0bl_;0P2h^;P30::RXP80YJFU0`2^[Zh30;6a/@D0
/k>c0P2d];@30;Fe]@<0^KVi0P35aLD30<o?c`80bl_;0`34a<@50<?3``<0b<S80P3<c<`30;Ng]`<0
][Jf0P1/K6`304M7A`80C4a<0`1IFET305ADE080CDe=0`16ATH203dm?@<0<S8b0`0Z:RX202TY:@<0
;2`/0P0_;bl303De=@80@T920`1;Bd/303`l?080;Bd]0`0f=SH203dm?@<0=SHf0`0];Bd202DU9@<0
:BTY0P0W9bL306=SH`<0CTi>0P11@D4305eMG@80Ph>30`2/[:`30<o?c`80c/k>0`30`<020;Fe]@H0
X:2P0P1MGEd30451@@80:b/[0`0_;bl303/k>`80@T921@17AdL304Y:BP80IFEU0`1oOgl30861P@80
O7al0`1jNWX207QhN0<0Ng]k0`21PH4208B4Q0<0QhN70P2:RXX308b<S0<0Shn?0P2ATI4309BDU0D0
UYJF=038h=P302`/;080<30`0`0];Bd202h^;P<0<30`0`17AdL20820P0<0IFEU0P0Z:RX302l_;`<0
;Bd]1@0a<C4202h^;P<0:b/[0P0b<S8302l_;`<0:b/[0P0];Bd3030`<080<S8b1P0k>c/202d];@<0
<c<c0P0o?cl3051@D0<0FUYJ0P1EEED3038b<P80:RXZ0`0W9bL3028R8P808B4Q0`0O7al2024Q8@<0
<S8b0`1bLW8209RHV0<0W9bL0P1[Jf/305mOG`<0NGUi0P2a/K430<S8b080/;2`0`2TY:@20:RXZ0<0
[:b/0`2c/k<20;Fe]@<0[jn_0P2e]KD30;Rh^0<0][Jf0P3:b/X30<k>cP80bLW90`37alL30<71`@L0
aLG50`34a<@30:n_[`80JFUY0`1<C4`2051@D0<0EeMG0`1EEED204a<C0<0A4A40P0l?3`3038b<P<0
:RXZ0P0Y:BT302XZ:P80<c<c0`0e=CD203dm?@<0CDe=0`13@d<202/[:`<0;bl_0P0n?Sh303`l?0<0
;Bd]0P0W9bL302@T9080:2PX0`1HF5P305MGE`80@D510`1FEUH207UiN@<0[Zj^0`3:b/X20<c<c0<0
_kno0P2`/;030:>SX`<0VYZJ0P1QHF4304E5A@D0:b/[0`0k>c/204a<C0<0BTY:0P0o?cl304m?C`80
KFe]0`1kNg/308:2PP80O7al0`1iNGT207IfMP<0NGUi0`20P80208Z:RP<0QXJ60P2<S8`308^;R`<0
TY:B0P2@T903096AT@80U9BD0`2IVITL0<SPf0006`38h=P302`/;080<S8b0`0n?Sh204=3@`<0<30`
0`1DE5@208b<S0<0CDe=0P0];Bd302/[:`<0;bl_0P0^;Rh302d];@80;2`/1@0Z:RX302/[:`<0:BTY
0P0W9bL303Ti>@80CTi>0`1GEeL305]KF`80De=C0`1<C4`205aLG0<0IfMW0`1BDU8203Ph>0<0;bl_
0P0[:b/302HV9P<08R8R1@0O7al2020P80<0:BTY0`19BDT208b<S0<0X:2P0P24Q8@306a/K0<0HV9R
0P2@T9030;fm_@80b/[:0`2ZZZX50:VYZ@<0[:b/0P2_[jl30;:b/P80];Bd0`2f][H30;Vi^@80a<C4
0`3=cLd20<_;b`<0a/K60`34a<@20<?3``D0a<C40`2o_kl30;Ng]`80];Bd0`1/K6`20492@PP0C4a<
0`17AdL203lo?`<0=SHf0`0^;Rh202d];@<0;Rh^0P0_;bl3034a<@80=SHf0`0j>SX303De=@80;bl_
1@0d=3@3034a<@<0;2`/0P0Y:BT302/[:`80:BTY0`19BDT503hn?P<0F5QH0P1fMWH309bLW0<0_[jn
0P2k^k/30:VYZ@80Ti>C0`1fMWH306UYJ@80?Shn0`0`<30202LW9`<0:RXZ1@0_;bl3038b<P80@410
0`1CDe<206e]K@<0Ph>30`25QHD208:2PP<0OWin0P1lO7`307inOP<0PX:20P25QHD308V9R@80RXZ:
0`2<S8`308n?S`80TY:B0`2EUID209JFUP<0UiNG=038h=P3034a<@80<30`0`0h>3P20410@0<0<c<c
0`1?Cdl208f=S@<0De=C0P0X:2P302h^;PD0;2`/0`0_;bl202/[:`<0:2PX0P0Y:BT302PX:0<09BDU
0P0[:b/303@d=080B4Q80`1WIfL3061PH080BTY:0`1JFUX205=CD`<0KFe]0`1NGUh202l_;`<0:BTY
0P0Z:RX302PX:0<08b<S0P0U9BD3028R8P80820P0`0V9RH305=CD`80S8b<0`2OWil208F5Q@H0IFEU
0P2BTY830<?3``80a/K60`2[Zj/20:b/[0<0YZJV0`2_[jl20;:b/P<0[Zj^1@2e]KD30;Bd]080a<C4
0`39bLT20<[:bP<0a<C40`37alL20<G5a@<0`<300P2n_[h30<30`0<0b<S80P2^[Zh3065QH@80A4A4
0`18B4P3051@D0D0Bd];0P16ATH303Xj>P<0:BTY0P0_;bl3034a<@80<30`0`0a<C42030`<0H0=CDe
0P0_;bl302/[:`80=SHf0`0a<C43038b<P80:2PX0`0^;Rh2030`<0<0C4a<0`0n?Sh204E5A@<0GUiN
0P20P8030::RXP<0`L710P30`<030:n_[`80UIFE0`1gMgL3069RHP80>c/k0`0Z:RX202LW9`<09RHV
0`0W9bL202XZ:P<0;2`/0P0c<c<3055AD@80KVi^0`21PH4308N7Q`80PH610`1nOWh207emO@<0P820
0`1nOWh208N7Q`<0R8R80P25QHD308j>SP<0S8b<0P2CTi<309FEU@80V9RH0`2IVITL0<SPf0006`38
h=P302`/;080<S8b0`0n?Sh204=3@`<0<30`0`1DE5@208b<S0<0CDe=0P0];Bd302/[:`<0;bl_0P0^
;Rh302d];@80;2`/1@0Z:RX302/[:`<0:BTY0P0W9bL303Ti>@80CTi>0`1GEeL305]KF`80De=C0`1<
C4`205aLG0<0IfMW0`1BDU8203Ph>0<0;bl_0P0[:b/302HV9P<08R8R1@0O7al2020P80<0:BTY0`19
BDT208b<S0<0X:2P0P24Q8@306a/K0<0HV9R0P2@T9030;fm_@80b/[:0`2ZZZX50:VYZ@<0[:b/0P2_
[jl30;:b/P80];Bd0`2f][H30;Vi^@80a<C40`3=cLd20<_;b`<0a/K60`34a<@20<?3``D0a<C40`2o
_kl30;Ng]`80];Bd0`1/K6`20492@PP0C4a<0`17AdL203lo?`<0=SHf0`0^;Rh202d];@<0;Rh^0P0_
;bl3034a<@80=SHf0`0j>SX303De=@80;bl_1@0d=3@3034a<@<0;2`/0P0Y:BT302/[:`80:BTY0`19
BDT503hn?P<0F5QH0P1fMWH309bLW0<0_[jn0P2k^k/30:VYZ@80Ti>C0`1fMWH306UYJ@80?Shn0`0`
<30202LW9`<0:RXZ1@0_;bl3038b<P80@4100`1CDe<206e]K@<0Ph>30`25QHD208:2PP<0OWin0P1l
O7`307inOP<0PX:20P25QHD308V9R@80RXZ:0`2<S8`308n?S`80TY:B0`2EUID209JFUP<0UiNG=038
h=P3034a<@80<30`0`0h>3P20410@0<0<c<c0`1?Cdl208f=S@<0De=C0P0X:2P302h^;PD0;2`/0`0_
;bl202/[:`<0:2PX0P0Y:BT302PX:0<09BDU0P0[:b/303@d=080B4Q80`1WIfL3061PH080BTY:0`1J
FUX205=CD`<0KFe]0`1NGUh202l_;`<0:BTY0P0Z:RX302PX:0<08b<S0P0U9BD3028R8P80820P0`0V
9RH305=CD`80S8b<0`2OWil208F5Q@H0IFEU0P2BTY830<?3``80a/K60`2[Zj/20:b/[0<0YZJV0`2_
[jl20;:b/P<0[Zj^1@2e]KD30;Bd]080a<C40`39bLT20<[:bP<0a<C40`37alL20<G5a@<0`<300P2n
_[h30<30`0<0b<S80P2^[Zh3065QH@80A4A40`18B4P3051@D0D0Bd];0P16ATH303Xj>P<0:BTY0P0_
;bl3034a<@80<30`0`0a<C42030`<0H0=CDe0P0_;bl302/[:`80=SHf0`0a<C43038b<P80:2PX0`0^
;Rh2030`<0<0C4a<0`0n?Sh204E5A@<0GUiN0P20P8030::RXP<0`L710P30`<030:n_[`80UIFE0`1g
MgL3069RHP80>c/k0`0Z:RX202LW9`<09RHV0`0W9bL202XZ:P<0;2`/0P0c<c<3055AD@80KVi^0`21
PH4308N7Q`80PH610`1nOWh207emO@<0P8200`1nOWh208N7Q`<0R8R80P25QHD308j>SP<0S8b<0P2C
Ti<309FEU@80V9RH0`2IVITL0<SPf0006`38h=P302`/;080<S8b0`0n?Sh204=3@`<0<30`0`1DE5@2
08b<S0<0CDe=0P0];Bd302/[:`<0;bl_0P0^;Rh302d];@80;2`/1@0Z:RX302/[:`<0:BTY0P0W9bL3
03Ti>@80CTi>0`1GEeL305]KF`80De=C0`1<C4`205aLG0<0IfMW0`1BDU8203Ph>0<0;bl_0P0[:b/3
02HV9P<08R8R1@0O7al2020P80<0:BTY0`19BDT208b<S0<0X:2P0P24Q8@306a/K0<0HV9R0P2@T903
0;fm_@80b/[:0`2ZZZX50:VYZ@<0[:b/0P2_[jl30;:b/P80];Bd0`2f][H30;Vi^@80a<C40`3=cLd2
0<_;b`<0a/K60`34a<@20<?3``D0a<C40`2o_kl30;Ng]`80];Bd0`1/K6`20492@PP0C4a<0`17AdL2
03lo?`<0=SHf0`0^;Rh202d];@<0;Rh^0P0_;bl3034a<@80=SHf0`0j>SX303De=@80;bl_1@0d=3@3
034a<@<0;2`/0P0Y:BT302/[:`80:BTY0`19BDT503hn?P<0F5QH0P1fMWH309bLW0<0_[jn0P2k^k/3
0:VYZ@80Ti>C0`1fMWH306UYJ@80?Shn0`0`<30202LW9`<0:RXZ1@0_;bl3038b<P80@4100`1CDe<2
06e]K@<0Ph>30`25QHD208:2PP<0OWin0P1lO7`307inOP<0PX:20P25QHD308V9R@80RXZ:0`2<S8`3
08n?S`80TY:B0`2EUID209JFUP<0UiNG=038h=P3034a<@80<30`0`0h>3P20410@0<0<c<c0`1?Cdl2
08f=S@<0De=C0P0X:2P302h^;PD0;2`/0`0_;bl202/[:`<0:2PX0P0Y:BT302PX:0<09BDU0P0[:b/3
03@d=080B4Q80`1WIfL3061PH080BTY:0`1JFUX205=CD`<0KFe]0`1NGUh202l_;`<0:BTY0P0Z:RX3
02PX:0<08b<S0P0U9BD3028R8P80820P0`0V9RH305=CD`80S8b<0`2OWil208F5Q@H0IFEU0P2BTY83
0<?3``80a/K60`2[Zj/20:b/[0<0YZJV0`2_[jl20;:b/P<0[Zj^1@2e]KD30;Bd]080a<C40`39bLT2
0<[:bP<0a<C40`37alL20<G5a@<0`<300P2n_[h30<30`0<0b<S80P2^[Zh3065QH@80A4A40`18B4P3
051@D0D0Bd];0P16ATH303Xj>P<0:BTY0P0_;bl3034a<@80<30`0`0a<C42030`<0H0=CDe0P0_;bl3
02/[:`80=SHf0`0a<C43038b<P80:2PX0`0^;Rh2030`<0<0C4a<0`0n?Sh204E5A@<0GUiN0P20P803
0::RXP<0`L710P30`<030:n_[`80UIFE0`1gMgL3069RHP80>c/k0`0Z:RX202LW9`<09RHV0`0W9bL2
02XZ:P<0;2`/0P0c<c<3055AD@80KVi^0`21PH4308N7Q`80PH610`1nOWh207emO@<0P8200`1nOWh2
08N7Q`<0R8R80P25QHD308j>SP<0S8b<0P2CTi<309FEU@80V9RH0`2IVITL0<SPf0006`38h=P302TY
:@80>SXj0`1<C4`205YJFP<0;2`/0`1PH60208Z:RP<0@D510P0[:b/302TY:@<0<c<c0P0_;bl302XZ
:PL0:2PX0`0Y:BT302HV9P80:2PX0`19BDT206][J`H0MWIf0P1aLG4306EUI@80Cdm?0`0h>3P302/[
:`8092@T0`0W9bL202/[:`<0:2PX1@0T92@302LW9`808B4Q0`0V9RH302XZ:P80Lg=c0`2@T9020:>S
X`<0NWYj0`1HF5P207alO0<0YjNW0P3Cdm<30;Fe]@80[jn_0`2UYJD30:RXZ080[Jf]0`2`/;020;Bd
]0<0]kNg0`2j^[X20<?3``<0b/[:0P3;bl/30<W9b@<0a/K60P33`l<30;jn_P80^k^k0`35aLD30<c<
c0D0][Jf0P1<C4`304U9B@<0@d=30P1:BTX304I6AP80@D510`0j>SX303De=@80<S8b0`0a<C45030`
<080;bl_0`0^;Rh3034a<@D0<c<c0P0a<C43030`<0<0;Rh^1@0];Bd502l_;`<0<c<c0P0k>c/304];
B`80HF5Q0`26QXH30:>SX`80WYjN0`2:RXX206a/K0<0C4a<0`0e=CD202TY:@<0:2PX0P0[:b/302PX
:0<09BDU0P0T92@302TY:@80@T920`1PH60207IfMP<0QHF50`28R8P208J6QP<0PX:20P1oOgl30820
P0<0PX:20P26QXH308Z:RP80Rh^;0`2<S8`308n?S`80Ti>C0`2FUYH209NGU`<0V9RH=038h=P302l_
;`80>SXj0`1BDU8205IFEP<0=CDe0`1LG5`208N7Q`<0AdM70P0U9BD302d];@<0=3@d0P0b<S8302`/
;0809BDU0`0[:b/202TY:@<0:b/[0`0Z:RX2030`<0<0?Shn0P1^KVh307YjNP<0L71`0P1]KFd306IV
IP80DU9B0`0k>c/302/[:`D09bLW0P0];Bd302TY:@D08R8R0`0V9RH5024Q8@<0<c<c0P1ZJVX309>C
T`80YZJV0`1aLG4305mOG`80OWin0`2/[:`20<W9b@<0_Kfm0P2WYjL30:VYZ@<0ZZZZ0P2[Zj/30:n_
[`80/k>c1P2i^KT20<C4a0<0bLW90P3=cLd30<[:bP<0`/;20P34a<@50;jn_P<0`l?30`31`L420<G5
a@<0YZJV0P1IFET304=3@`<0Bd];0P19BDT303hn?P80>c/k0`12@T8303<c<`D0<30`0P0d=3@302l_
;`D0<30`0`0_;bl203Lg=`<0;bl_0P0c<c<3030`<0<0;Rh^0P0/;2`302h^;P80;bl_0`0/;2`3038b
<P80>3Ph0`16ATH205YJFP<0RXZ:0`2RXZ8209JFUP<0SXj>0P1XJ6P304i>CP<0>3Ph0P0Z:RX502TY
:@<0:b/[0`0V9RH202XZ:P<0;Rh^0P13@d<306ATI080MGEe0`24Q8@308R8R080Q8B40`21PH4207in
OP<0P8200`22PX8208R8R0<0RXZ:0P2;Rh/308Z:RP<0Shn?0P2BTY8309JFUP80U9BD0`2IVITL0<SP
f0006`38h=P302TY:@80>SXj0`1<C4`205YJFP<0;2`/0`1PH60208Z:RP<0@D510P0[:b/302TY:@<0
<c<c0P0_;bl302XZ:PL0:2PX0`0Y:BT302HV9P80:2PX0`19BDT206][J`H0MWIf0P1aLG4306EUI@80
Cdm?0`0h>3P302/[:`8092@T0`0W9bL202/[:`<0:2PX1@0T92@302LW9`808B4Q0`0V9RH302XZ:P80
Lg=c0`2@T9020:>SX`<0NWYj0`1HF5P207alO0<0YjNW0P3Cdm<30;Fe]@80[jn_0`2UYJD30:RXZ080
[Jf]0`2`/;020;Bd]0<0]kNg0`2j^[X20<?3``<0b/[:0P3;bl/30<W9b@<0a/K60P33`l<30;jn_P80
^k^k0`35aLD30<c<c0D0][Jf0P1<C4`304U9B@<0@d=30P1:BTX304I6AP80@D510`0j>SX303De=@80
<S8b0`0a<C45030`<080;bl_0`0^;Rh3034a<@D0<c<c0P0a<C43030`<0<0;Rh^1@0];Bd502l_;`<0
<c<c0P0k>c/304];B`80HF5Q0`26QXH30:>SX`80WYjN0`2:RXX206a/K0<0C4a<0`0e=CD202TY:@<0
:2PX0P0[:b/302PX:0<09BDU0P0T92@302TY:@80@T920`1PH60207IfMP<0QHF50`28R8P208J6QP<0
PX:20P1oOgl30820P0<0PX:20P26QXH308Z:RP80Rh^;0`2<S8`308n?S`80Ti>C0`2FUYH209NGU`<0
V9RH=038h=P302l_;`80>SXj0`1BDU8205IFEP<0=CDe0`1LG5`208N7Q`<0AdM70P0U9BD302d];@<0
=3@d0P0b<S8302`/;0809BDU0`0[:b/202TY:@<0:b/[0`0Z:RX2030`<0<0?Shn0P1^KVh307YjNP<0
L71`0P1]KFd306IVIP80DU9B0`0k>c/302/[:`D09bLW0P0];Bd302TY:@D08R8R0`0V9RH5024Q8@<0
<c<c0P1ZJVX309>CT`80YZJV0`1aLG4305mOG`80OWin0`2/[:`20<W9b@<0_Kfm0P2WYjL30:VYZ@<0
ZZZZ0P2[Zj/30:n_[`80/k>c1P2i^KT20<C4a0<0bLW90P3=cLd30<[:bP<0`/;20P34a<@50;jn_P<0
`l?30`31`L420<G5a@<0YZJV0P1IFET304=3@`<0Bd];0P19BDT303hn?P80>c/k0`12@T8303<c<`D0
<30`0P0d=3@302l_;`D0<30`0`0_;bl203Lg=`<0;bl_0P0c<c<3030`<0<0;Rh^0P0/;2`302h^;P80
;bl_0`0/;2`3038b<P80>3Ph0`16ATH205YJFP<0RXZ:0`2RXZ8209JFUP<0SXj>0P1XJ6P304i>CP<0
>3Ph0P0Z:RX502TY:@<0:b/[0`0V9RH202XZ:P<0;Rh^0P13@d<306ATI080MGEe0`24Q8@308R8R080
Q8B40`21PH4207inOP<0P8200`22PX8208R8R0<0RXZ:0P2;Rh/308Z:RP<0Shn?0P2BTY8309JFUP80
U9BD0`2IVITL0<SPf0006`38h=P302XZ:P80C4a<0`15ADD204U9B@<0;bl_0`1KFe/20820P0<0>SXj
0P0Z:RX302HV9P<0;bl_0P0[:b/302LW9`D09BDU0P0T92@302XZ:P<09BDU0P1=CDd306EUI@80NGUi
0`1jNWX3071`L080GUiN0`19BDT203Ti>@<0;2`/0`0V9RH202@T90<0:RXZ0P0_;bl302/[:`<09BDU
0P0W9bL302PX:0D08R8R0`0O7al204U9B@<0NGUi0P2SXj<309BDU0<0HV9R0P1bLW8308b<S080_[jn
0`31`L420;Bd]0<0YJFU0`2YZJT20:b/[0<0[jn_0P2b/[830;Fe]@<0^;Rh0P30`<030<O7a`D0b/[:
0`36a/H20<71`@<0_Kfm0P2k^k/30<;2`P<0a<C40P2m_Kd30;:b/P80[Zj^0`1VIVH30410@080ATI6
0`12@T8204=3@`<0?Shn0`0h>3P203De=@<0<c<c1@0a<C45030`<0<0<S8b1@0c<c<2038b<P<0<C4a
0`0_;bl202h^;P<0;Bd]0P0_;bl302`/;0<0;bl_0P0e=CD303hn?P80BTY:0`1TI6@307UiN@80LG5a
0`1OGel204];B`<0>3Ph0`0[:b/502LW9`80:BTY0`0V9RH302<S8`80;Bd]0`0m?Cd205QHF0<0Lg=c
0P20P80608N7Q`80Q8B40`21PH4207moO`<0P8200`22PX8208N7Q`<0Rh^;0P2<S8`308f=S@<0T92@
0P2CTi<309JFUP80VIVI0`2JVYXd0<SPf0<0:RXZ0P0o?cl305EEE@80?Cdm0`0];Bd305iNGP80PX:2
0`0h>3P502`/;0<0:RXZ0P0X:2P302HV9PD092@T0P0Y:BT302DU9@<0:RXZ0P11@D4306UYJ@D0NGUi
0`1bLW8206MWI`<0B4Q80P0X:2P302@T90<0:BTY0P0V9RH302LW9`80;Bd]0`0_;bl302DU9@80:BTY
0`0W9bL2028R8P<08B4Q0`0S8b<204E5A@<0P8200P2QXJ4309FEU@D0I6AT0`2@T9020;Vi^@<0a/K6
0P2_[jl30:NWY`<0Y:BT0P2/[:`30;6a/@80/;2`1P2h^;P20<;2`P<0aLG50P3=cLd30<[:bP<0`l?3
0P32`/830<30`080_Kfm1P2o_kl20;fm_@<0aLG50P2WYjL305iNGP<0BTY:1@11@D4504=3@`<0>CTi
0P0e=CD3038b<P80;bl_0`0`<30503De=@<0<c<c0P0e=CD303Lg=`80<c<c0`0e=CD302d];@80;2`/
0`0Z:RX202l_;`<0;Rh^0`0_;bl2030`<0<0Cdm?0P12@T83069RHP<0MgMg0P1_Kfl305aLG080ATI6
0`0i>CT302h^;P80:RXZ0`0W9bL202h^;P<0:BTY0`0V9RH202h^;P<0?3`l0P1FEUH307=cL`80PH61
0`2;Rh/508N7Q`<0Ph>30P1mOGd608:2PP80QHF51@2=SHd3092@T0<0UiNG0P2CTi<309BDU080VIVI
0`2MWIdL0<SPf0006`38h=P302XZ:P80C4a<0`15ADD204U9B@<0;bl_0`1KFe/20820P0<0>SXj0P0Z
:RX302HV9P<0;bl_0P0[:b/302LW9`D09BDU0P0T92@302XZ:P<09BDU0P1=CDd306EUI@80NGUi0`1j
NWX3071`L080GUiN0`19BDT203Ti>@<0;2`/0`0V9RH202@T90<0:RXZ0P0_;bl302/[:`<09BDU0P0W
9bL302PX:0D08R8R0`0O7al204U9B@<0NGUi0P2SXj<309BDU0<0HV9R0P1bLW8308b<S080_[jn0`31
`L420;Bd]0<0YJFU0`2YZJT20:b/[0<0[jn_0P2b/[830;Fe]@<0^;Rh0P30`<030<O7a`D0b/[:0`36
a/H20<71`@<0_Kfm0P2k^k/30<;2`P<0a<C40P2m_Kd30;:b/P80[Zj^0`1VIVH30410@080ATI60`12
@T8204=3@`<0?Shn0`0h>3P203De=@<0<c<c1@0a<C45030`<0<0<S8b1@0c<c<2038b<P<0<C4a0`0_
;bl202h^;P<0;Bd]0P0_;bl302`/;0<0;bl_0P0e=CD303hn?P80BTY:0`1TI6@307UiN@80LG5a0`1O
Gel204];B`<0>3Ph0`0[:b/502LW9`80:BTY0`0V9RH302<S8`80;Bd]0`0m?Cd205QHF0<0Lg=c0P20
P80608N7Q`80Q8B40`21PH4207moO`<0P8200`22PX8208N7Q`<0Rh^;0P2<S8`308f=S@<0T92@0P2C
Ti<309JFUP80VIVI0`2JVYXd0<SPf0<0:RXZ0P0o?cl305EEE@80?Cdm0`0];Bd305iNGP80PX:20`0h
>3P502`/;0<0:RXZ0P0X:2P302HV9PD092@T0P0Y:BT302DU9@<0:RXZ0P11@D4306UYJ@D0NGUi0`1b
LW8206MWI`<0B4Q80P0X:2P302@T90<0:BTY0P0V9RH302LW9`80;Bd]0`0_;bl302DU9@80:BTY0`0W
9bL2028R8P<08B4Q0`0S8b<204E5A@<0P8200P2QXJ4309FEU@D0I6AT0`2@T9020;Vi^@<0a/K60P2_
[jl30:NWY`<0Y:BT0P2/[:`30;6a/@80/;2`1P2h^;P20<;2`P<0aLG50P3=cLd30<[:bP<0`l?30P32
`/830<30`080_Kfm1P2o_kl20;fm_@<0aLG50P2WYjL305iNGP<0BTY:1@11@D4504=3@`<0>CTi0P0e
=CD3038b<P80;bl_0`0`<30503De=@<0<c<c0P0e=CD303Lg=`80<c<c0`0e=CD302d];@80;2`/0`0Z
:RX202l_;`<0;Rh^0`0_;bl2030`<0<0Cdm?0P12@T83069RHP<0MgMg0P1_Kfl305aLG080ATI60`0i
>CT302h^;P80:RXZ0`0W9bL202h^;P<0:BTY0`0V9RH202h^;P<0?3`l0P1FEUH307=cL`80PH610`2;
Rh/508N7Q`<0Ph>30P1mOGd608:2PP80QHF51@2=SHd3092@T0<0UiNG0P2CTi<309BDU080VIVI0`2M
WIdL0<SPf0006`38h=P302XZ:P80C4a<0`15ADD204U9B@<0;bl_0`1KFe/20820P0<0>SXj0P0Z:RX3
02HV9P<0;bl_0P0[:b/302LW9`D09BDU0P0T92@302XZ:P<09BDU0P1=CDd306EUI@80NGUi0`1jNWX3
071`L080GUiN0`19BDT203Ti>@<0;2`/0`0V9RH202@T90<0:RXZ0P0_;bl302/[:`<09BDU0P0W9bL3
02PX:0D08R8R0`0O7al204U9B@<0NGUi0P2SXj<309BDU0<0HV9R0P1bLW8308b<S080_[jn0`31`L42
0;Bd]0<0YJFU0`2YZJT20:b/[0<0[jn_0P2b/[830;Fe]@<0^;Rh0P30`<030<O7a`D0b/[:0`36a/H2
0<71`@<0_Kfm0P2k^k/30<;2`P<0a<C40P2m_Kd30;:b/P80[Zj^0`1VIVH30410@080ATI60`12@T82
04=3@`<0?Shn0`0h>3P203De=@<0<c<c1@0a<C45030`<0<0<S8b1@0c<c<2038b<P<0<C4a0`0_;bl2
02h^;P<0;Bd]0P0_;bl302`/;0<0;bl_0P0e=CD303hn?P80BTY:0`1TI6@307UiN@80LG5a0`1OGel2
04];B`<0>3Ph0`0[:b/502LW9`80:BTY0`0V9RH302<S8`80;Bd]0`0m?Cd205QHF0<0Lg=c0P20P806
08N7Q`80Q8B40`21PH4207moO`<0P8200`22PX8208N7Q`<0Rh^;0P2<S8`308f=S@<0T92@0P2CTi<3
09JFUP80VIVI0`2JVYXd0<SPf0<0:RXZ0P0o?cl305EEE@80?Cdm0`0];Bd305iNGP80PX:20`0h>3P5
02`/;0<0:RXZ0P0X:2P302HV9PD092@T0P0Y:BT302DU9@<0:RXZ0P11@D4306UYJ@D0NGUi0`1bLW82
06MWI`<0B4Q80P0X:2P302@T90<0:BTY0P0V9RH302LW9`80;Bd]0`0_;bl302DU9@80:BTY0`0W9bL2
028R8P<08B4Q0`0S8b<204E5A@<0P8200P2QXJ4309FEU@D0I6AT0`2@T9020;Vi^@<0a/K60P2_[jl3
0:NWY`<0Y:BT0P2/[:`30;6a/@80/;2`1P2h^;P20<;2`P<0aLG50P3=cLd30<[:bP<0`l?30P32`/83
0<30`080_Kfm1P2o_kl20;fm_@<0aLG50P2WYjL305iNGP<0BTY:1@11@D4504=3@`<0>CTi0P0e=CD3
038b<P80;bl_0`0`<30503De=@<0<c<c0P0e=CD303Lg=`80<c<c0`0e=CD302d];@80;2`/0`0Z:RX2
02l_;`<0;Rh^0`0_;bl2030`<0<0Cdm?0P12@T83069RHP<0MgMg0P1_Kfl305aLG080ATI60`0i>CT3
02h^;P80:RXZ0`0W9bL202h^;P<0:BTY0`0V9RH202h^;P<0?3`l0P1FEUH307=cL`80PH610`2;Rh/5
08N7Q`<0Ph>30P1mOGd608:2PP80QHF51@2=SHd3092@T0<0UiNG0P2CTi<309BDU080VIVI0`2MWIdL
0<SPf0006`38h=P3030`<080F5QH0`0h>3P5038b<P<0E5AD0P1dM7@303De=@80:BTY0`0S8b<302TY
:@809RHV0`0U9BD702<S8`H0;Rh^0P1bLW8307YjNP80Ng]k0`1_Kfl305eMG@80@D510`0W9bL2024Q
8@<08R8R0`0U9BD202XZ:P<0;bl_0P0b<S8302h^;PD0:2PX0`0Y:BT202@T90<08B4Q0`0M7Ad202<S
8`<0GUiN0P2BTY830:RXZ0<0MGEe0P1`L70307AdM080WYjN0`35aLD20;Zj^P<0ZJVY0`2[Zj/20:f]
[@<0[jn_0P2a/K430;>c/`<0][Jf0P2m_Kd30<C4a080b<S80`3:b/X30<K6aP80`L710`2n_[h20;fm
_@<0^[Zj0`2h^;P20<30`0<0`L710P3:b/X30:JVYP<0EeMG0P1<C4`30492@P80ATI60`11@D4303dm
?@80>CTi0`0f=SH203De=@<0=3@d0P0e=CD303Hf=P<0=CDe1`0d=3@303<c<`<0<C4a0P0_;bl502h^
;PH0;bl_0P0`<303038b<P80=cLg0`15ADD3051@D080B4Q80`0j>SX203<c<`<0;Bd]1@0/;2`302XZ
:P80:BTY0`0W9bL302TY:@80?clo0`1JFUX2075aL@<0Q8B40P28R8P308N7Q`<0QHF50P21PH4307mo
O`80OWin0`1oOgl308:2PP80QhN70`2<S8`208j>SP<0Shn?0`2ATI4209>CT`<0V9RH0P2KVi/309bL
W3@0b>3H0`0g=cL205IFEP<0>SXj0P0_;bl3038b<P<0FEUI0P1cLg<302h^;P809RHV0`0Y:BT302LW
9`8092@T0`0W9bL502DU9@80820P0`0`<30303De=@80L71`0`1iNGT2075aL@<0LW9b0`1PH6020410
@0D09RHV0`0T92@302LW9`80:b/[0`0_;bl203<c<`<0=3@d0`0Z:RX2020P80<09RHV0P0Z:RX301/K
6`<07alO0P0V9RH305YJFP80T92@0`2][Jd307IfMP80IfMW0`1kNg/209ZJVP<0`L710P33`l<60:JV
YP80[:b/0`2`/;020:f][@<0][Jf0`2d];@20;Vi^@<0a<C40P38b<P30<_;b`<0`l?30P31`L430<;2
`P80^[Zj0`2l_;`30;jn_P80^KVi0`32`/820<K6aP<0XZ:R0`1HF5P204I6AP<0@4100P0o?cl304];
B`<0>c/k0P0f=SH303Lg=`80>CTi0`0e=CD2038b<P<0=CDe1@0d=3@303Xj>P80<c<c0`0_;bl3038b
<P80=3@d0`0^;Rh2030`<0<0;Rh^0`0_;bl202`/;0<0<c<c0P0g=cL303lo?`<0E5AD0P17AdL303Lg
=`80<c<c0`0^;Rh302PX:080;Rh^1@0W9bL3030`<0<0:2PX0P0g=cL305QHF080Kfm_0`23Ph<208R8
R0<0RHV90`21PH420820P0<0Ph>30P1kNg/307inOP<0Ph>30P22PX8308b<S080Shn?0`2;Rh/309:B
TPD0U9BD0P2LW9`309fMWA`0b>3H000K0<SPf0<0<30`0P1HF5P303Ph>0D0<S8b0`1DE5@207AdM0<0
=CDe0P0Y:BT302<S8`<0:BTY0P0V9RH302DU9@L08b<S1P0^;Rh2079bLP<0NWYj0P1kNg/306m_K`<0
GEeM0P11@D4302LW9`808B4Q0`0R8R8302DU9@80:RXZ0`0_;bl2038b<P<0;Rh^1@0X:2P302TY:@80
92@T0`0Q8B4301dM7@808b<S0`1NGUh209:BTP<0Z:RX0`1eMGD2071`L0<0M7Ad0P2NWYh30<G5a@80
^[Zj0`2YZJT30:^[Z`80[Jf]0`2_[jl20;6a/@<0/k>c0`2f][H20;fm_@<0a<C40P38b<P30<[:bP<0
a/K60P31`L430;jn_P80_Kfm0`2j^[X30;Rh^080`<300`31`L420<[:bP<0YZJV0`1GEeL204a<C0<0
@T920P16ATH30451@@<0?Cdm0P0i>CT303Hf=P80=CDe0`0d=3@203De=@<0=SHf0`0e=CD703@d=0<0
<c<c0`0a<C4202l_;`D0;Rh^1P0_;bl2030`<0<0<S8b0P0g=cL304E5A@<0D51@0P18B4P303Xj>P80
<c<c0`0];Bd502`/;0<0:RXZ0P0Y:BT302LW9`<0:BTY0P0o?cl305YJFP80LG5a0`24Q8@208R8R0<0
QhN70`25QHD20861P@<0Ogmo0P1nOWh307moO`<0PX:20P27QhL308b<S080SXj>0`2?Shl3096AT@80
Ti>C0`2HV9P209^KV`<0W9bL=038h=P303Lg=`80EUIF0`0j>SX202l_;`<0<S8b0`1IFET207=cL`<0
;Rh^0P0V9RH302TY:@<09bLW0P0T92@302LW9`D09BDU0P0P8203030`<0<0=CDe0P1`L70307UiN@80
LG5a0`1bLW83061PH080@4101@0V9RH302@T90<09bLW0P0[:b/302l_;`80<c<c0`0d=3@302XZ:P80
820P0`0V9RH202XZ:P<06a/K0`0O7al202HV9P<0FUYJ0P2@T9030:f][@<0MWIf0P1WIfL307]kN`80
VYZJ0`31`L420<?3``H0YZJV0P2/[:`30;2`/080[Jf]0`2f][H30;Bd]080^KVi0`34a<@20<S8b0<0
bl_;0`33`l<20<71`@<0`/;20P2j^[X30;bl_0<0_[jn0P2i^KT30<;2`P80a/K60`2RXZ8305QHF080
ATI60`10@40203lo?`<0Bd];0`0k>c/203Hf=P<0=cLg0P0i>CT303De=@80<S8b0`0e=CD503@d=0<0
>SXj0P0c<c<302l_;`<0<S8b0P0d=3@302h^;P80<30`0`0^;Rh302l_;`80;2`/0`0c<c<203Lg=`<0
?clo0`1DE5@204M7A`<0=cLg0P0c<c<302h^;P<0:2PX0P0^;Rh502LW9`<0<30`0`0X:2P203Lg=`<0
F5QH0P1_Kfl308>3P`80R8R80`29RHT30861P@80P8200`23Ph<207]kN`<0OWin0`23Ph<208:2PP<0
S8b<0P2?Shl308^;R`<0TY:B1@2DU9@209bLW0<0WIfM7038h=P001/0b>3H0`1;Bd/20410@0<0<c<c
0P0[:b/302l_;`<0GUiN0P1XJ6P302l_;`80:2PX0`0R8R8:02HV9P<09bLW0P0/;2`303Lg=`<0FUYJ
0P1iNGT307=cL`80HV9R0`1@D50303hn?P80<C4a0`0W9bL202DU9@<09RHV0`0Z:RX202d];@<0<30`
0P0a<C4302`/;0<09RHV1@0W9bL202DU9@<07QhN0`0L71`201hN7P<0ATI60P1]KFd30:JVYP<0SXj>
0P1kNg/306i^KP80NWYj0`2/[:`20<G5a@<0^;Rh0`2QXJ420:j^[P<0[Jf]0P2`/;030;:b/P<0]KFe
0P2l_;`30<?3``80b<S80`3;bl/30<S8b080a<C40`2o_kl20;^k^`<0^KVi0`2h^;P20;bl_0<0^k^k
0P3AdM430;bl_0<0QhN70P1>CTh50492@P<0AdM70`19BDT204I6AP<0@D510P0n?Sh303Xj>P80=CDe
0`0b<S8303De=@80>CTi0`0g=cL203@d=0<0<c<c0`0b<S82030`<0P0;bl_0`0a<C42038b<P<0<C4a
0P0`<30303@d=0<0=cLg0P0e=CD3034a<@80;2`/0`0X:2P502LW9`<0:RXZ0P0^;Rh302`/;0<0>SXj
0P1KFe/307QhN080PX:20`29RHT208J6QPH0PX:20P23Ph<307moO`80OGem0`20P80308F5Q@80RHV9
0`2<S8`208j>SP<0T92@0`2DU9@209RHV0<0VYZJ0P2LW9`309fMWC@0b>3H0`1:BTX204M7A`<0;Bd]
0P0`<303034a<@<0Hf=S0P1WIfL302h^;P80:b/[0`0V9RH302/[:`8092@T0`0X:2P202HV9P<09bLW
0P0[:b/3030`<0<0G5aL0P1kNg/307alO080KVi^0`1?Cdl3038b<P80;Bd]0`0Z:RX202h^;P<0:2PX
0`0[:b/202TY:@<0;bl_0P0^;Rh302`/;0<09BDU0P0T92@302`/;080<c<c0`0M7Ad501lO7`<0>CTi
0P1hN7P30:2PX0<0V9RH0P20P80306e]K@80OGem0`2ZZZX20<_;b`<0];Bd0`2WYjL20:f][@<0/k>c
0P2_[jl30;6a/@<0]kNg0P2k^k/30<C4a080b<S80`3;bl/30<G5a@80`/;20`2n_[h20;Vi^@<0]kNg
0`2j^[X20;Bd]0<0^k^k0P36a/H30<S8b0<0WIfM0P1@D5030451@@80AdM70`16ATH304M7A`80A4A4
0`13@d<203lo?`<0>SXj0P0e=CD303<c<`<0=SHf0P0d=3@303<c<`D0=3@d0`0a<C42038b<P<0;bl_
0P0a<C43030`<0<0;Rh^0P0b<S8303/k>`80<30`0`0h>3P303Ti>@80=SHf0`11@D4202`/;0<0;Rh^
0`0X:2P202HV9P<0;2`/0P0Y:BT302XZ:P<0>3Ph0P1NGUh308>3P`80RXZ:0`2=SHd508:2PP<0Ogmo
0P24Q8@307emO@80OWin0`23Ph<308:2PP80Shn?0`2<S8`208j>SP<0T92@0`2ATI4209NGU`<0VIVI
0P2LW9`309jNWQ`0b>3H000K0<SPf0<0Bd];0P10@40303<c<`80:b/[0`0_;bl305iNGP80J6QX0`0_
;bl202PX:0<08R8R2P0V9RH302LW9`80;2`/0`0g=cL305YJFP80NGUi0`1cLg<2069RHP<0D51@0`0n
?Sh2034a<@<09bLW0P0U9BD302HV9P<0:RXZ0P0];Bd3030`<080<C4a0`0/;2`302HV9PD09bLW0P0U
9BD301hN7P<071`L0P0N7Qh304I6AP80KFe]0`2VYZH308j>SP80Ng]k0`1^KVh207YjNP<0[:b/0P35
aLD30;Rh^0<0XJ6Q0P2^[Zh30:f][@80/;2`0`2b/[830;Fe]@80_;bl0`33`l<20<S8b0<0bl_;0`38
b<P20<C4a0<0_kno0P2k^k/30;Vi^@<0^;Rh0P2l_;`30;^k^`80dM7A0`2l_;`308N7Q`80CTi>1@12
@T8304M7A`<0BDU90P16ATH30451@@80?Shn0`0j>SX203De=@<0<S8b0`0e=CD203Ti>@<0=cLg0P0d
=3@303<c<`<0<S8b0P0`<30802l_;`<0<C4a0P0b<S83034a<@80<30`0`0d=3@303Lg=`80=CDe0`0a
<C4202`/;0<0:2PX1@0W9bL302XZ:P80;Rh^0`0/;2`303Xj>P80Fe]K0`1hN7P208:2PP<0RHV90P26
QXH608:2PP80Ph>30`1oOgl207emO@<0P8200`25QHD208V9R@<0S8b<0P2>SXh3092@T0<0U9BD0P2H
V9P309ZJVP80W9bL0`2MWIdd0<SPf0<0BTY:0P17AdL302d];@80<30`0`0a<C4306=SH`80IfMW0`0^
;Rh202/[:`<09RHV0`0[:b/202@T90<0:2PX0P0V9RH302LW9`80:b/[0`0`<30305aLG080Ng]k0`1l
O7`206i^KP<0Cdm?0`0b<S8202d];@<0:RXZ0P0^;Rh302PX:0<0:b/[0P0Y:BT302l_;`80;Rh^0`0/
;2`302DU9@8092@T0`0/;2`203<c<`<07AdM1@0O7al303Ti>@80N7Qh0`2PX:0309RHV080P8200`1]
KFd207emO@<0ZZZZ0P3;bl/30;Bd]0<0YjNW0P2][Jd30;>c/`80[jn_0`2a/K430;Ng]`80^k^k0`34
a<@20<S8b0<0bl_;0`35aLD20<;2`P<0_[jn0P2i^KT30;Ng]`<0^[Zj0P2d];@30;^k^`80a/K60`38
b<P309fMW@80D51@0`11@D4204M7A`<0ATI60`17AdL204A4A0<0@d=30P0o?cl303Xj>P80=CDe0`0c
<c<303Hf=P80=3@d0`0c<c<503@d=0<0<C4a0P0b<S8302l_;`80<C4a0`0`<30302h^;P80<S8b0`0k
>c/2030`<0<0>3Ph0`0i>CT203Hf=P<0@D510P0/;2`302h^;P<0:2PX0P0V9RH302`/;080:BTY0`0Z
:RX303Ph>080GUiN0`23Ph<208Z:RP<0SHf=1@22PX8307moO`80Q8B40`1mOGd207inOP<0Ph>30`22
PX8208n?S`<0S8b<0P2>SXh3092@T0<0TI6A0P2GUiL309VIV@80W9bL0`2NWYhL0<SPf0006`38h=P3
04];B`80@4100`0c<c<202/[:`<0;bl_0`1NGUh206QXJ0<0;bl_0P0X:2P3028R8PX09RHV0`0W9bL2
02`/;0<0=cLg0`1JFUX207UiN@<0Lg=c0P1RHV83051@D0<0?Shn0P0a<C4302LW9`809BDU0`0V9RH3
02XZ:P80;Bd]0`0`<302034a<@<0;2`/0`0V9RH502LW9`809BDU0`0N7Qh301`L70807QhN0`16ATH2
06e]K@<0YZJV0`2>SXh207]kN`<0KVi^0P1jNWX30:b/[080aLG50`2h^;P30:6QX@80[Zj^0`2][Jd2
0;2`/0<0/[:b0`2e]KD20;bl_0<0`l?30P38b<P30<_;b`<0b<S80P34a<@30;no_`80^k^k0`2i^KT3
0;Rh^080_;bl0`2k^k/20=7Ad@<0_;bl0`27QhL204i>CPD0@T920`17AdL304U9B@80ATI60`11@D42
03hn?P<0>SXj0P0e=CD3038b<P<0=CDe0P0i>CT303Lg=`80=3@d0`0c<c<3038b<P80<30`200_;bl3
034a<@80<S8b0`0a<C42030`<0<0=3@d0`0g=cL203De=@<0<C4a0P0/;2`302PX:0D09bLW0`0Z:RX2
02h^;P<0;2`/0`0j>SX205]KF`<0N7Qh0P22PX8308V9R@80QXJ61P22PX8208>3P`<0Ogmo0P1mOGd3
0820P0<0QHF50P29RHT308b<S080SXj>0`2@T90309BDU080V9RH0`2JVYX209bLW0<0WIfM=038h=P3
04Y:BP80AdM70`0];Bd2030`<0<0<C4a0`1SHf<206MWI`<0;Rh^0P0[:b/302HV9P<0:b/[0P0T92@3
02PX:0809RHV0`0W9bL202/[:`<0<30`0`1LG5`207]kN`<0O7al0P1^KVh304m?C`<0<S8b0P0];Bd3
02XZ:P80;Rh^0`0X:2P302/[:`80:BTY0`0_;bl202h^;P<0;2`/0`0U9BD202@T90<0;2`/0P0c<c<3
01dM7@D07alO0`0i>CT207QhN0<0X:2P0`2HV9P20820P0<0KFe]0P1mOGd30:ZZZP80bl_;0`2d];@3
0:NWY`80[Jf]0`2c/k<20:n_[`<0/K6a0`2g]kL20;^k^`<0a<C40P38b<P30<_;b`<0aLG50P32`/83
0;jn_P80^KVi0`2g]kL30;Zj^P80];Bd0`2k^k/20<K6aP<0b<S80`2MWId2051@D0<0@D510P17AdL3
04I6AP<0AdM70P14A4@304=3@`80?clo0`0j>SX203De=@<0<c<c0`0f=SH203@d=0<0<c<c1@0d=3@3
034a<@80<S8b0`0_;bl2034a<@<0<30`0`0^;Rh2038b<P<0>c/k0P0`<30303Ph>0<0>CTi0P0f=SH3
0451@@80;2`/0`0^;Rh302PX:0809RHV0`0/;2`202TY:@<0:RXZ0`0h>3P205iNGP<0Ph>30P2:RXX3
08f=S@D0PX:20`1oOgl208B4Q0<0OGem0P1nOWh308>3P`<0PX:20P2?Shl308b<S080SXj>0`2@T903
096AT@80UiNG0`2IVIT209bLW0<0WYjN7038h=P001/0b>3H0`1OGel202HV9P<0;bl_0P0Y:BT302d]
;@<0J6QX0P1OGel302/[:`80:BTY0`0R8R8302DU9@809RHV0`0X:2P202XZ:P<0;Rh^0P0i>CT304A4
A0<0PX:20P1cLg<3065QH@80@d=30`0`<30302<S8`809RHV200^;Rh302l_;`D0<30`0P0^;Rh302TY
:@<09BDU0P0V9RH302LW9`809RHV0`0R8R8301lO7`808R8R0`0`<30204E5A@<0UIFE0`2OWil208Z:
RP<0LW9b0P1MGEd308f=S@80alO70`33`l<309bLW080/;2`0`2/[:`20:j^[P<0/;2`0`2d];@20;^k
^`<0`l?30P37alL60<[:bP80b<S80`31`L420;Zj^PH0^KVi0P2e]KD30;>c/`80_kno0`34a<@30=;B
dP80Ti>C0`1/K6`204U9B@<0C4a<0`1DE5@2059BDP<0CTi>0P19BDT304=3@`80>SXj0`0c<c<303Ti
>@80@4100`0l?3`203Hf=PH0=CDe0P0d=3@303<c<`D0<S8b0`0c<c<203@d=0<0<c<c0P0b<S8302l_
;`<0;Bd]0P0_;bl3034a<@80;Rh^0`0Z:RX302HV9P809BDU0`0^;Rh203`l?0<0=CDe0`1ADE42075a
L@<0S8b<0P2=SHd308R8R080PH610`1kNg/307moO`80Ph>30`1oOgl207]kN`<0P8200`27QhL208Z:
RP<0S8b<0P2?Shl309:BTP<0UiNG0P2LW9`809fMWC@0b>3H0`1HF5P202l_;`<0;2`/0P0Z:RX302l_
;`<0GEeM0P1UIFD302l_;`80:2PX0`0V9RH3028R8P808b<S0`0V9RH2034a<@<0<30`0P0j>SX304U9
B@<0OGem0P1hN7P306EUI@80@D510`0_;bl302PX:0809BDU1@0[:b/302`/;0<0>CTi1@0_;bl2030`
<0<0:2PX0`0V9RH502@T90809bLW0`0O7al302DU9@808b<S0`0X:2P204m?C`<0TI6A0`2PX:0208R8
R0<0KVi^0P1VIVH308f=S@80_;bl0`30`<030:JVYP80[:b/0`2ZZZX20:f][@<0/;2`0`2c/k<20;^k
^`<0`l?30P36a/H30<_;b`<0alO70P39bLT30<;2`P80^k^k0`2i^KT30;^k^`D0][Jf0P2o_kl30<G5
a@<0bLW90P2OWil305YJFP80B4Q80`1>CTh305IFEP80CDe=0`1@D50204Q8B0<0AdM70P0l?3`303@d
=0<0>c/k0P10@40303Ph>080=SHf0`0i>CT303De=@80<S8b0`0h>3P2034a<@<0<S8b0`0e=CD203<c
<`D0=CDe0`0b<S83034a<@80;Bd]0`0[:b/202d];@<0:b/[0`0Y:BT202PX:0<0;2`/0P0e=CD304A4
A0<0Bd];0P1ZJVX308Z:RP80S8b<0`28R8P50820P0<0NWYj0P25QHD308>3P`80OGem0`1jNWX808V9
R@D0TY:B0`2GUiL209^KV`<0WYjN0P2LW9`309nOWa`0b>3H000K0<SPf0<0GemO0P0V9RH302l_;`80
:BTY0`0];Bd306QXJ080GemO0`0[:b/202TY:@<08R8R0`0U9BD202HV9P<0:2PX0P0Z:RX302h^;P80
>CTi0`14A4@308:2PP80Lg=c0`1QHF4204=3@`<0<30`0`0S8b<202HV9PP0;Rh^0`0_;bl5030`<080
;Rh^0`0Y:BT302DU9@809RHV0`0W9bL202HV9P<08R8R0`0O7al2028R8P<0<30`0P15ADD309FEU@<0
WinO0P2:RXX3079bLP80GEeM0`2=SHd20<O7a`<0`l?30`2LW9`20;2`/0<0[:b/0P2^[Zh30;2`/0<0
];Bd0P2k^k/30<?3``80alO71P3:b/X20<S8b0<0`L710P2j^[X60;Vi^@80]KFe0`2c/k<20;no_`<0
a<C40`3Bd]8209>CT`<0K6a/0P19BDT304a<C0<0E5AD0P1BDU8304i>CP80BDU90`13@d<203Xj>P<0
<c<c0`0i>CT20410@0<0?3`l0P0f=SH603De=@80=3@d0`0c<c<5038b<P<0<c<c0P0d=3@303<c<`80
<S8b0`0_;bl302d];@80;bl_0`0a<C4202h^;P<0:RXZ0`0V9RH202DU9@<0;Rh^0P0l?3`303De=@<0
DE5A0P1aLG4308b<S080SHf=0`28R8P20861P@<0Ng]k0`1oOgl208>3P`<0Ogmo0P1kNg/30820P0<0
QhN70P2:RXX308b<S080Shn?0`2BTY8309NGU`80W9bL202MWIdd0<SPf0<0F5QH0P0_;bl302`/;080
:RXZ0`0_;bl305eMG@80IFEU0`0_;bl202PX:0<09RHV0`0R8R8202<S8`<09RHV0P0a<C43030`<080
>SXj0`19BDT307emO@80N7Qh0`1UIFD20451@@<0;bl_0`0X:2P202DU9@D0:b/[0`0/;2`303Ti>@D0
;bl_0P0`<30302PX:0<09RHV1@0T92@202LW9`<07alO0`0U9BD202<S8`<0:2PX0P1?Cdl3096AT@<0
X:2P0P28R8P306i^KP80IVIV0`2=SHd20;bl_0<0`<300`2VYZH20:b/[0<0ZZZZ0P2][Jd30;2`/0<0
/k>c0P2k^k/30<?3``80a/K60`3;bl/30<O7a`80bLW90`32`/820;^k^`<0^KVi0`2k^k/50;Jf]P80
_kno0`35aLD30<W9b@80WinO0`1JFUX204Q8B0<0CTi>0`1FEUH204e=C@<0D51@0P18B4P304M7A`80
?3`l0`0d=3@303/k>`80@4100`0h>3P203Hf=P<0>CTi0`0e=CD2038b<P<0>3Ph0P0a<C43038b<P<0
=CDe0P0c<c<503De=@<0<S8b0`0a<C4202d];@<0:b/[0P0];Bd302/[:`<0:BTY0P0X:2P302`/;080
=CDe0`14A4@304];B`80JVYZ0`2:RXX208b<S0<0R8R81@20P80307YjNP80QHF50`23Ph<207emO@<0
NWYj2029RHT509:BTP<0UiNG0P2KVi/309jNWP80W9bL0`2OWilL0<SPf0006`38h=P304U9B@809bLW
0`0];Bd202`/;0<0=3@d0`1KFe/2065QH@<0;2`/0P0^;Rh802DU9@<09bLW0P0];Bd303Hf=P80BDU9
0`1HF5P307MgM`80I6AT0`1<C4`202l_;`<09bLW0`0V9RH202TY:@D0;Rh^2`0_;bl202h^;P<0:b/[
0`0X:2P202HV9P<0:2PX0P0P820303Ph>0<0;2`/0P0S8b<3024Q8@80;2`/0`1`L70309:BTP80WinO
0`20P80205IFEP<0MWIf0P2XZ:P30;Zj^P<0^;Rh0P2][Jd30:^[Z`80ZZZZ0`2/[:`30;2`/080^;Rh
0`30`<020<G5a@<0b<S81@3;bl/30<C4a080_Kfm0`2i^KT30;Fe]@80/K6a0`2_[jl20;Fe]@<0_Kfm
0`3Rh^820=3@d0<0UiNG0P1IFET304M7A`<0CDe=0P1BDU8305UIF@80EUIF0`1ADE4204e=C@<0Bd];
0`1<C4`204e=C@<0ADE50P0m?Cd303`l?0<0?Cdm1@0o?cl203/k>`<0=CDe0`0a<C4202l_;`<0=SHf
0P0n?Sh30451@@<0@4100P0f=SH302/[:`80<30`0`0c<c<302l_;`80<S8b0`0o?cl204Y:BP<0MgMg
1@1PH60307YjNP80Shn?0`1oOgl207emO@<0NGUi0`1kNg/207alO0<0NWYj0P1hN7P307emO@<0Ph>3
0P27QhL308^;R`80TI6A0`2FUYH309ZJVP80WIfM202NWYhd0<SPf0<0@4100P0W9bL302TY:@80;Bd]
0`0f=SH305UIF@80GEeM0`0[:b/202LW9`H09RHV0P0T92@302TY:@80;Rh^0`0`<30204=3@`<0G5aL
0`1fMWH2061PH0<0>SXj0P0Z:RX302TY:@<0;2`/0P0_;bl3038b<P80;Bd]0`0X:2P302l_;`80;Bd]
0`0^;Rh203<c<`<0:BTY0`0`<30202HV9P<092@T0P0S8b<302PX:0<0?Cdm0P0Q8B43028R8P809bLW
0`1^KVh308n?S`80WinO0`1gMgL206EUI@<0Kfm_0P2RXZ830;no_`<0^KVi0P2XZ:P50:ZZZP<0/;2`
0`2^[Zh20;Jf]P<0_kno0P34a<@30<_;b`<0c<c<0P3;bl/30<O7a`80_;bl0`2i^KT30;Fe]@80[:b/
0`2a/K420;Ng]`<0_kno0`36a/H20<g=c@<0YZJV0P1NGUh304m?C`<0DE5A0P1?Cdl305iNGP80EeMG
0`1=CDd204E5A@<0ATI60`1GEeL205ADE0D0@4100`13@d<303hn?P80>CTi0`0k>c/203Ti>@<0=SHf
0`0b<S8202`/;0<0<S8b0P0e=CD303`l?0<0=cLg0P0h>3P302l_;`80:b/[0`0_;bl5030`<0<0>3Ph
0P1CDe<307]kN`<0I6AT0P1QHF4307QhN080R8R80`21PH4207alO0<0NGUi0`1jNWX207]kN`<0O7al
0P1gMgL307YjNP<0Q8B40P29RHT308b<S080Shn?0`2FUYH309ZJVP80WinO0`2QXJ4209ZJVP<0WIfM
7038h=P001/0b>3H0`19BDT202LW9`<0;Bd]0P0/;2`303@d=0<0Fe]K0P1QHF4302`/;080;Rh^200U
9BD302LW9`80;Bd]0`0f=SH204U9B@<0F5QH0`1gMgL206ATI0<0C4a<0P0_;bl302LW9`<09RHV0P0Y
:BT502h^;P/0;bl_0P0^;Rh302/[:`<0:2PX0P0V9RH302PX:080820P0`0h>3P302`/;0808b<S0`0Q
8B4202`/;0<0L71`0`2BTY8209nOW`<0P8200P1FEUH307IfMP80Z:RX0`2j^[X30;Rh^080[Jf]0`2[
Zj/20:ZZZP<0[:b/0`2`/;020;Rh^0<0`<300P35aLD30<S8b0D0bl_;0`34a<@20;fm_@<0^KVi0`2e
]KD20;6a/@<0[jn_0P2e]KD30;fm_@<0h^;R0P3@d=0309NGU`80FEUI0`17AdL304e=C@80DU9B0`1I
FET205IFEP<0DE5A0P1=CDd304];B`<0C4a<0P1=CDd304E5A@80?Cdm0`0l?3`303dm?@D0?clo0P0k
>c/303De=@<0<C4a0P0_;bl303Hf=P80?Shn0`11@D430410@080=SHf0`0[:b/2030`<0<0<c<c0`0_
;bl2038b<P<0?clo0P1:BTX307MgM`D0H61P0`1jNWX208n?S`<0Ogmo0P1mOGd307UiN@<0Ng]k0P1l
O7`307YjNP80N7Qh0`1mOGd308>3P`80QhN70`2;Rh/2096AT@<0UYJF0`2JVYX209fMW@P0WYjN=038
h=P30410@0809bLW0`0Y:BT202d];@<0=SHf0`1IFET205eMG@<0:b/[0P0W9bL602HV9P8092@T0`0Y
:BT202h^;P<0<30`0P13@d<305aLG0<0MWIf0P1PH60303Xj>P80:RXZ0`0Y:BT302`/;080;bl_0`0b
<S8202d];@<0:2PX0`0_;bl202d];@<0;Rh^0P0c<c<302TY:@<0<30`0P0V9RH302@T90808b<S0`0X
:2P303dm?@808B4Q0`0R8R8202LW9`<0KVi^0`2?Shl209nOW`<0MgMg0P1UIFD306m_K`80XZ:R0`2o
_kl30;Vi^@80Z:RX1@2ZZZX30;2`/0<0[Zj^0P2f][H30;no_`80a<C40`3;bl/30<c<c080bl_;0`37
alL20;bl_0<0^KVi0`2e]KD20:b/[0<0/K6a0P2g]kL30;no_`<0a/K60P3=cLd30:JVYP80GUiN0`1?
Cdl3055AD@80Cdm?0`1NGUh205MGE`<0CDe=0P15ADD304I6AP<0EeMG0P1DE5@50410@0<0@d=30`0n
?Sh203Ti>@<0>c/k0P0i>CT303Hf=P<0<S8b0P0/;2`3038b<P80=CDe0`0l?3`303Lg=`80>3Ph0`0_
;bl202/[:`<0;bl_1@0`<30303Ph>080De=C0`1kNg/306ATI080HF5Q0`1hN7P208R8R0<0PH610P1l
O7`307UiN@<0NWYj0P1kNg/307alO080MgMg0`1jNWX308B4Q080RHV90`2<S8`208n?S`<0UYJF0`2J
VYX209nOW`<0XJ6Q0P2JVYX309fMWA`0b>3H000K0<SPf0<0BDU90P0W9bL302d];@80;2`/0`0d=3@3
05]KF`80HF5Q0`0/;2`202h^;PP09BDU0`0W9bL202d];@<0=SHf0P19BDT305QHF0<0MgMg0P1TI6@3
04a<C080;bl_0`0W9bL302HV9P80:BTY1@0^;Rh;02l_;`80;Rh^0`0[:b/302PX:0809RHV0`0X:2P2
020P80<0>3Ph0`0/;2`202<S8`<08B4Q0P0/;2`3071`L0<0TY:B0P2OWil30820P080EUIF0`1fMWH2
0:RXZ0<0^[Zj0`2h^;P20:f][@<0Zj^[0P2ZZZX30:b/[0<0/;2`0P2h^;P30<30`080aLG50`38b<P5
0<_;b`<0a<C40P2m_Kd30;Vi^@<0]KFe0P2a/K430:n_[`80]KFe0`2m_Kd30>;RhP80d=3@0`2GUiL2
05UIF@<0AdM70`1=CDd2059BDP<0FEUI0P1FEUH3055AD@80CDe=0`1;Bd/304a<C080CDe=0`15ADD2
03dm?@<0?3`l0`0m?Cd503lo?`80>c/k0`0e=CD3034a<@80;bl_0`0f=SH203hn?P<0@D510`10@402
03Hf=P<0:b/[0P0`<30303<c<`<0;bl_0P0b<S8303lo?`80BTY:0`1gMgL5061PH0<0NWYj0P2?Shl3
07moO`80OGem0`1iNGT307]kN`80O7al0`1jNWX207QhN0<0OGem0`23Ph<208N7Q`<0Rh^;0P2ATI43
09JFUP<0VYZJ0P2MWId809jNWS@0b>3H0`10@40202LW9`<0:BTY0P0];Bd303Hf=P<0FEUI0P1MGEd3
02/[:`809bLW1P0V9RH202@T90<0:BTY0P0^;Rh3030`<080@d=30`1LG5`307IfMP80H61P0`0j>SX2
02XZ:P<0:BTY0`0/;2`202l_;`<0<S8b0P0];Bd302PX:0<0;bl_0P0];Bd302h^;P80<c<c0`0Y:BT3
030`<0809RHV0`0T92@202<S8`<0:2PX0`0m?Cd2024Q8@<08R8R0P0W9bL306i^KP<0Shn?0P2OWil3
07MgM`80IFEU0`1_Kfl20::RXP<0_kno0`2i^KT20:RXZ0D0ZZZZ0`2`/;030:j^[P80][Jf0`2o_kl2
0<C4a0<0bl_;0`3<c<`20<_;b`<0alO70P2l_;`30;Vi^@<0]KFe0P2/[:`30;6a/@80]kNg0`2o_kl3
0<K6aP80cLg=0`2VYZH205iNGP<0Cdm?0`1ADE4204m?C`<0GUiN0P1GEeL304e=C@80ADE50`16ATH3
05MGE`80E5AD1@10@40304=3@`<0?Shn0P0i>CT303/k>`80>CTi0`0f=SH3038b<P80;2`/0`0b<S82
03De=@<0?3`l0`0g=cL203Ph>0<0;bl_0P0[:b/302l_;`D0<30`0`0h>3P205=CD`<0Ng]k0`1TI6@2
065QH@<0N7Qh0P28R8P30861P@80O7al0`1iNGT307YjNP80Ng]k0`1lO7`207MgM`<0NWYj0`24Q8@2
08V9R@<0S8b<0P2?Shl309JFUP<0VYZJ0P2OWil30:6QX@80VYZJ0`2MWIdL0<SPf0006`38h=P502d]
;@<0;2`/0P0a<C4303/k>`<0CDe=0P1RHV8302h^;P80<S8b0`0X:2P302LW9`8092@T0`0V9RH2034a
<@<0@4100P1HF5P306][J`<0HF5Q0P1@D50303Lg=`808b<S0`0V9RH302l_;`80;Rh^0`0];Bd802h^
;PL0;Bd]1P0/;2`202/[:`<0<C4a0P0Q8B4304a<C0<0>3Ph0P0T92@301PH608071`L0`18B4P307Ui
N@80ZZZZ0`2@T90205eMG@<0J6QX0P24Q8@30:RXZ0<0clo?0P2/[:`30:^[Z`80YjNW0`2XZ:P30:b/
[080];Bd0`2l_;`20<71`@<0a/K60`3:b/X20<c<c0<0alO70P31`L430;Rh^0<0/K6a0P2][Jd30:^[
Z`80[jn_0`2d];@30;bl_080`l?30`2n_[h20:j^[P<0K6a/0`1>CTh2059BDP<0HV9R0P1QHF4305mO
G`80HV9R0`1UIFD3065QH@80Fe]K0`1ADE4204U9B@<0B4Q80`1:BTX204i>CP<0D51@0P19BDT303lo
?`<0<S8b0P0[:b/303dm?@80DU9B1P1KFe/204E5A@<0<30`0P0h>3P30492@P<0?Shn0P11@D4305UI
F@80M7Ad0`1bLW8308N7Q`80E5AD0`1PH60208N7Q`<0M7Ad0P1hN7P307IfMP<0MGEe0P1dM7@307=c
L`80M7Ad0`1iNGT30820P080QXJ60`2=SHd209BDU0<0VYZJ0`2MWId209jNWP<0WinO1@2PX:0d0<SP
f0<0<C4a0P0`<30502d];@<0?3`l0`1DE5@205iNGP<0<C4a0P0_;bl302d];@<09RHV0P0T92@302TY
:@80<c<c0`0n?Sh205mOG`<0H61P0`1/K6`205MGE`<0=3@d0P0U9BD3030`<0D0:b/[0`0/;2`202h^
;P<0;Bd]0`0d=3@202XZ:P<0;Rh^1@0[:b/302XZ:P80;Rh^1@0W9bL304A4A0<0?clo0P0N7Qh301dM
7@808R8R0`0n?Sh30861P@80XZ:R0`2=SHd206YZJP<0JFUY0P1lO7`30;2`/0<0a/K60P2e]KD30:BT
Y080ZZZZ0`2XZ:P30:f][@80/K6a0`2k^k/20<71`@<0aLG51@38b<P30<[:bP80`<300`2e]KD30;>c
/`80ZJVY0`2^[Zh20:f][@<0]kNg0`2m_Kd20<K6aP<0b/[:0P2][Jd306ATI0<0E5AD0P1EEED305mO
G`80HV9R0`1PH60206ATI0<0IfMW0`1TI6@2061PH0<0BTY:0P1;Bd/304U9B@<0@d=30P1BDU8304U9
B@80DE5A0`0k>c/303Hf=P80;bl_0`0h>3P2055AD@<0JFUY0`1NGUh204];B`<0<30`0P0^;Rh304=3
@`<0ADE50P10@40305ADE080Kfm_0`1iNGT30820P080EeMG0`1UIFD20820P0<0MgMg0P1jNWX307Ee
M@<0Lg=c1@1dM7@207MgM`<0NWYj0`20P80208J6QP<0SHf=0P2CTi<309VIV@<0W9bL0P2MWId30::R
XP80X:2P0`2MWIdL0<SPf0006`38h=P502d];@<0;2`/0P0a<C4303/k>`<0CDe=0P1RHV8302h^;P80
<S8b0`0X:2P302LW9`8092@T0`0V9RH2034a<@<0@4100P1HF5P306][J`<0HF5Q0P1@D50303Lg=`80
8b<S0`0V9RH302l_;`80;Rh^0`0];Bd802h^;PL0;Bd]1P0/;2`202/[:`<0<C4a0P0Q8B4304a<C0<0
>3Ph0P0T92@301PH608071`L0`18B4P307UiN@80ZZZZ0`2@T90205eMG@<0J6QX0P24Q8@30:RXZ0<0
clo?0P2/[:`30:^[Z`80YjNW0`2XZ:P30:b/[080];Bd0`2l_;`20<71`@<0a/K60`3:b/X20<c<c0<0
alO70P31`L430;Rh^0<0/K6a0P2][Jd30:^[Z`80[jn_0`2d];@30;bl_080`l?30`2n_[h20:j^[P<0
K6a/0`1>CTh2059BDP<0HV9R0P1QHF4305mOG`80HV9R0`1UIFD3065QH@80Fe]K0`1ADE4204U9B@<0
B4Q80`1:BTX204i>CP<0D51@0P19BDT303lo?`<0<S8b0P0[:b/303dm?@80DU9B1P1KFe/204E5A@<0
<30`0P0h>3P30492@P<0?Shn0P11@D4305UIF@80M7Ad0`1bLW8308N7Q`80E5AD0`1PH60208N7Q`<0
M7Ad0P1hN7P307IfMP<0MGEe0P1dM7@307=cL`80M7Ad0`1iNGT30820P080QXJ60`2=SHd209BDU0<0
VYZJ0`2MWId209jNWP<0WinO1@2PX:0d0<SPf0<0<C4a0P0`<30502d];@<0?3`l0`1DE5@205iNGP<0
<C4a0P0_;bl302d];@<09RHV0P0T92@302TY:@80<c<c0`0n?Sh205mOG`<0H61P0`1/K6`205MGE`<0
=3@d0P0U9BD3030`<0D0:b/[0`0/;2`202h^;P<0;Bd]0`0d=3@202XZ:P<0;Rh^1@0[:b/302XZ:P80
;Rh^1@0W9bL304A4A0<0?clo0P0N7Qh301dM7@808R8R0`0n?Sh30861P@80XZ:R0`2=SHd206YZJP<0
JFUY0P1lO7`30;2`/0<0a/K60P2e]KD30:BTY080ZZZZ0`2XZ:P30:f][@80/K6a0`2k^k/20<71`@<0
aLG51@38b<P30<[:bP80`<300`2e]KD30;>c/`80ZJVY0`2^[Zh20:f][@<0]kNg0`2m_Kd20<K6aP<0
b/[:0P2][Jd306ATI0<0E5AD0P1EEED305mOG`80HV9R0`1PH60206ATI0<0IfMW0`1TI6@2061PH0<0
BTY:0P1;Bd/304U9B@<0@d=30P1BDU8304U9B@80DE5A0`0k>c/303Hf=P80;bl_0`0h>3P2055AD@<0
JFUY0`1NGUh204];B`<0<30`0P0^;Rh304=3@`<0ADE50P10@40305ADE080Kfm_0`1iNGT30820P080
EeMG0`1UIFD20820P0<0MgMg0P1jNWX307EeM@<0Lg=c1@1dM7@207MgM`<0NWYj0`20P80208J6QP<0
SHf=0P2CTi<309VIV@<0W9bL0P2MWId30::RXP80X:2P0`2MWIdL0<SPf0006`38h=P502d];@<0;2`/
0P0a<C4303/k>`<0CDe=0P1RHV8302h^;P80<S8b0`0X:2P302LW9`8092@T0`0V9RH2034a<@<0@410
0P1HF5P306][J`<0HF5Q0P1@D50303Lg=`808b<S0`0V9RH302l_;`80;Rh^0`0];Bd802h^;PL0;Bd]
1P0/;2`202/[:`<0<C4a0P0Q8B4304a<C0<0>3Ph0P0T92@301PH608071`L0`18B4P307UiN@80ZZZZ
0`2@T90205eMG@<0J6QX0P24Q8@30:RXZ0<0clo?0P2/[:`30:^[Z`80YjNW0`2XZ:P30:b/[080];Bd
0`2l_;`20<71`@<0a/K60`3:b/X20<c<c0<0alO70P31`L430;Rh^0<0/K6a0P2][Jd30:^[Z`80[jn_
0`2d];@30;bl_080`l?30`2n_[h20:j^[P<0K6a/0`1>CTh2059BDP<0HV9R0P1QHF4305mOG`80HV9R
0`1UIFD3065QH@80Fe]K0`1ADE4204U9B@<0B4Q80`1:BTX204i>CP<0D51@0P19BDT303lo?`<0<S8b
0P0[:b/303dm?@80DU9B1P1KFe/204E5A@<0<30`0P0h>3P30492@P<0?Shn0P11@D4305UIF@80M7Ad
0`1bLW8308N7Q`80E5AD0`1PH60208N7Q`<0M7Ad0P1hN7P307IfMP<0MGEe0P1dM7@307=cL`80M7Ad
0`1iNGT30820P080QXJ60`2=SHd209BDU0<0VYZJ0`2MWId209jNWP<0WinO1@2PX:0d0<SPf0<0<C4a
0P0`<30502d];@<0?3`l0`1DE5@205iNGP<0<C4a0P0_;bl302d];@<09RHV0P0T92@302TY:@80<c<c
0`0n?Sh205mOG`<0H61P0`1/K6`205MGE`<0=3@d0P0U9BD3030`<0D0:b/[0`0/;2`202h^;P<0;Bd]
0`0d=3@202XZ:P<0;Rh^1@0[:b/302XZ:P80;Rh^1@0W9bL304A4A0<0?clo0P0N7Qh301dM7@808R8R
0`0n?Sh30861P@80XZ:R0`2=SHd206YZJP<0JFUY0P1lO7`30;2`/0<0a/K60P2e]KD30:BTY080ZZZZ
0`2XZ:P30:f][@80/K6a0`2k^k/20<71`@<0aLG51@38b<P30<[:bP80`<300`2e]KD30;>c/`80ZJVY
0`2^[Zh20:f][@<0]kNg0`2m_Kd20<K6aP<0b/[:0P2][Jd306ATI0<0E5AD0P1EEED305mOG`80HV9R
0`1PH60206ATI0<0IfMW0`1TI6@2061PH0<0BTY:0P1;Bd/304U9B@<0@d=30P1BDU8304U9B@80DE5A
0`0k>c/303Hf=P80;bl_0`0h>3P2055AD@<0JFUY0`1NGUh204];B`<0<30`0P0^;Rh304=3@`<0ADE5
0P10@40305ADE080Kfm_0`1iNGT30820P080EeMG0`1UIFD20820P0<0MgMg0P1jNWX307EeM@<0Lg=c
1@1dM7@207MgM`<0NWYj0`20P80208J6QP<0SHf=0P2CTi<309VIV@<0W9bL0P2MWId30::RXP80X:2P
0`2MWIdL0<SPf0006`38h=P302`/;080;Bd]0`0Z:RX202l_;`<0=cLg0`1EEED205IFEP<0=3@d0P0Z
:RX302HV9P<0:2PX0P0U9BD302HV9P80=SHf0`19BDT2065QH@<0Kfm_0`1JFUX203dm?@<0;Bd]0P0S
8b<302DU9@<0:RXZ0P0[:b/302`/;080;bl_0`0`<30302d];@80:BTY0`0Z:RX202LW9`<0:BTY0`0Z
:RX202<S8`<09RHV0P0/;2`304];B`<0=3@d0P0L71`301PH608071`L0`0e=CD305QHF080TI6A0`2M
WId207MgM`<0J6QX0P1bLW8308^;R`<0^[Zj0P2l_;`30;Bd]080YZJV0`2WYjL30:^[Z`80/;2`0`2f
][H20;fm_@<0`/;20`36a/H20<S8b0<0alO70P33`l<30;Vi^@<0[Zj^0P2XZ:P30:JVYP80ZJVY0`2_
[jl30;Jf]P80`l?30`3AdM420=3@d0<0aLG50`1aLG4206ATI0<0GUiN0P1PH60306IVIP80JVYZ0`1]
KFd306][J`80IfMW0`1TI6@5065QH@<0HV9R0P1UIFD306MWI`80I6AT0`1KFe/303lo?`80;Bd]0`17
AdL206][J`<0R8R80`2HV9P207IfMP<0De=C0P16ATH305mOG`<0Hf=S0P1;Bd/3061PH080LW9b0`1i
NGT308>3P`D0HV9R0P1hN7P3075aL@80L71`1P1/K6`206i^KP<0KFe]0P1_Kfl307MgM`<0PX:20P2<
S8`309BDU080VIVI0`2KVi/309jNWP80X:2P0`2QXJ450::RXS@0b>3H1@0/;2`3034a<@80:RXZ0`0`
<30305]KF`80EeMG0`0d=3@202h^;P<0:BTY0`0U9BD202<S8`<092@T0P0`<30304e=C@80IfMW0`1/
K6`3069RHP80=3@d0`0X:2P202/[:`<09BDU0`0X:2P202HV9P<0:b/[0P0d=3@3038b<P<0;Rh^0P0]
;Bd302HV9P80;2`/0`0Z:RX302DU9@80:2PX0`0];Bd203/k>`<0EEEE0`0V9RH201`L70<07QhN0P0Q
8B4302`/;0<0HF5Q0P2DU9@30:6QX@80Lg=c0`1XJ6P206][J`<0S8b<0`2i^KT20<71`@<0/;2`0P2T
Y:@30:b/[0<0YjNW0P2b/[830;^k^`80_Kfm0`32`/830<C4a080bl_;0`38b<P20<?3``<0^KVi0`2a
/K450:RXZ080YZJV0`2b/[830;Zj^P80_;bl0`34a<@20<c<c0<0/[:b0`1eMGD205EEE@<0I6AT0P1P
H60306QXJ080K6a/0`1[Jf/306EUI@80GUiN0`1OGel2069RHPH0IVIV0P1YJFT306e]K@80Jf][0`1G
EeL303hn?P80;bl_0`15ADD206m_K`<0TI6A0`24Q8@207alO0<0De=C0P14A4@306EUI@<0L71`0P19
BDT306MWI`80KVi^0`1kNg/307alO080Jf][0`1OGel207EeM@<0M7Ad0P1_Kfl306e]K@<0LG5a0P1`
L70306IVIP80KFe]0`1iNGT30861P@80RXZ:0`2CTi<209^KV`<0WinO0`2JVYX209jNWPD0Xj>S0`2R
XZ8L0<SPf0006`38h=P302`/;080;Bd]0`0Z:RX202l_;`<0=cLg0`1EEED205IFEP<0=3@d0P0Z:RX3
02HV9P<0:2PX0P0U9BD302HV9P80=SHf0`19BDT2065QH@<0Kfm_0`1JFUX203dm?@<0;Bd]0P0S8b<3
02DU9@<0:RXZ0P0[:b/302`/;080;bl_0`0`<30302d];@80:BTY0`0Z:RX202LW9`<0:BTY0`0Z:RX2
02<S8`<09RHV0P0/;2`304];B`<0=3@d0P0L71`301PH608071`L0`0e=CD305QHF080TI6A0`2MWId2
07MgM`<0J6QX0P1bLW8308^;R`<0^[Zj0P2l_;`30;Bd]080YZJV0`2WYjL30:^[Z`80/;2`0`2f][H2
0;fm_@<0`/;20`36a/H20<S8b0<0alO70P33`l<30;Vi^@<0[Zj^0P2XZ:P30:JVYP80ZJVY0`2_[jl3
0;Jf]P80`l?30`3AdM420=3@d0<0aLG50`1aLG4206ATI0<0GUiN0P1PH60306IVIP80JVYZ0`1]KFd3
06][J`80IfMW0`1TI6@5065QH@<0HV9R0P1UIFD306MWI`80I6AT0`1KFe/303lo?`80;Bd]0`17AdL2
06][J`<0R8R80`2HV9P207IfMP<0De=C0P16ATH305mOG`<0Hf=S0P1;Bd/3061PH080LW9b0`1iNGT3
08>3P`D0HV9R0P1hN7P3075aL@80L71`1P1/K6`206i^KP<0KFe]0P1_Kfl307MgM`<0PX:20P2<S8`3
09BDU080VIVI0`2KVi/309jNWP80X:2P0`2QXJ450::RXS@0b>3H1@0/;2`3034a<@80:RXZ0`0`<303
05]KF`80EeMG0`0d=3@202h^;P<0:BTY0`0U9BD202<S8`<092@T0P0`<30304e=C@80IfMW0`1/K6`3
069RHP80=3@d0`0X:2P202/[:`<09BDU0`0X:2P202HV9P<0:b/[0P0d=3@3038b<P<0;Rh^0P0];Bd3
02HV9P80;2`/0`0Z:RX302DU9@80:2PX0`0];Bd203/k>`<0EEEE0`0V9RH201`L70<07QhN0P0Q8B43
02`/;0<0HF5Q0P2DU9@30:6QX@80Lg=c0`1XJ6P206][J`<0S8b<0`2i^KT20<71`@<0/;2`0P2TY:@3
0:b/[0<0YjNW0P2b/[830;^k^`80_Kfm0`32`/830<C4a080bl_;0`38b<P20<?3``<0^KVi0`2a/K45
0:RXZ080YZJV0`2b/[830;Zj^P80_;bl0`34a<@20<c<c0<0/[:b0`1eMGD205EEE@<0I6AT0P1PH603
06QXJ080K6a/0`1[Jf/306EUI@80GUiN0`1OGel2069RHPH0IVIV0P1YJFT306e]K@80Jf][0`1GEeL3
03hn?P80;bl_0`15ADD206m_K`<0TI6A0`24Q8@207alO0<0De=C0P14A4@306EUI@<0L71`0P19BDT3
06MWI`80KVi^0`1kNg/307alO080Jf][0`1OGel207EeM@<0M7Ad0P1_Kfl306e]K@<0LG5a0P1`L703
06IVIP80KFe]0`1iNGT30861P@80RXZ:0`2CTi<209^KV`<0WinO0`2JVYX209jNWPD0Xj>S0`2RXZ8L
0<SPf0006`38h=P302l_;`80;2`/0`0Y:BT202d];@<0<C4a0`1MGEd204M7A`<0>CTi0P0S8b<302@T
90<0:BTY0P0V9RH302LW9`80>c/k0`1ADE4206EUI@<0KVi^0`1BDU8202l_;`D0:2PX1P0V9RH202PX
:0<0:b/[0P0_;bl3030`<0<0;2`/0P0V9RH502PX:0<09RHV0`0Z:RX20410@0<0EUIF0P1CDe<30410
@0<0;2`/0P0K6a/301`L70808R8R0`0X:2P303Ph>080KVi^0`2PX:02092@T0<0Lg=c0P1/K6`307=c
L`<0Vi^K0P34a<@30;Zj^P80ZJVY0`2XZ:P30:ZZZP80[Jf]0`2a/K420;Rh^0<0_kno0`32`/820<C4
a0<0a/K60P35aLD30;^k^`<0[Zj^0P2VYZH30:6QX@80Xj>S0`2YZJT30;6a/@80^KVi0`32`/820<O7
a`<0][Jf0`2i^KT208^;R`D0HF5Q0`1/K6`206m_K`P0LW9b0`1eMGD207QhN0<0NGUi0`1jNWX207al
O0D0OGem0`1fMWH3055AD@80=SHf0`1KFe/208N7Q`<0TI6A0`2@T90208F5Q@<0Ng]k0P1LG5`307Ui
N@<0QHF50P1GEeL3065QH@80JVYZ0`1dM7@307QhN080LG5a0`1VIVH206MWI`<0K6a/0P1VIVH3061P
H0<0HV9R0P1WIfL306QXJ080Jf][0`1hN7P308N7Q`80U9BD1@2NWYh309fMW@<0WinO0P2RXZ830:>S
X`80Y:BT0`2UYJDd0<SPf0<0<30`0P0_;bl302TY:@80:RXZ0`0l?3`305=CD`80DE5A0`0b<S8502HV
9P<0:2PX0P0Z:RX3030`<080<C4a0`1EEED206EUI@<0J6QX0`1KFe/202d];@<09bLW1@0X:2P302@T
90D0:RXZ0P0`<30302l_;`D0:2PX0`0Z:RX202PX:0<0<C4a0`0];Bd203Ph>0<0DU9B0P1RHV8303dm
?@<0:BTY0P0R8R8302HV9PD08B4Q0`0e=CD207]kN`<0UYJF0P2IVIT3075aL@80KFe]0`1gMgL309jN
WP80_;bl0`32`/820:NWY`<0Xj>S0`2/[:`20:j^[P<0[jn_0P2h^;P60<30`080`l?30`37alL20<G5
a@<0^k^k0`2/[:`20:>SX`<0XJ6Q0P2RXZ830:JVYP<0]kNg0P2j^[X30<;2`PD0b<S80`2f][H208:2
PP<0I6AT0P1RHV8306a/K0D0LG5a0`1bLW8207QhN0<0MGEe0P1fMWH307emO@<0N7Qh0P1eMGD307al
O080PH610`1^KVh305QHF080<c<c0`1JFUX20861P@<0UIFE0`2BTY8208^;R`<0M7Ad0P1PH60307Mg
M`<0OGem0P1KFe/305UIF@80LG5a0`1cLg<307alO080LG5a0`1YJFT206ATI0<0KVi^0P1SHf<305eM
G@<0I6AT0P1QHF4306QXJ080KFe]0`1jNWX308F5Q@80V9RH0`2LW9`209fMW@<0W9bL0`2MWId20:6Q
X@<0YZJV0P2TY:@30:FUYA`0b>3H000K0<SPf0<0;bl_0P0/;2`302TY:@80;Bd]0`0a<C4305eMG@80
AdM70`0i>CT202<S8`<092@T0`0Y:BT202HV9P<09bLW0P0k>c/3055AD@80IFEU0`1^KVh3059BDP80
;bl_1@0X:2P602HV9P80:2PX0`0[:b/202l_;`<0<30`0`0/;2`202HV9PD0:2PX0`0V9RH302XZ:P80
@4100`1FEUH205=CD`<0@4100`0/;2`201/K6`<071`L0P0R8R8302PX:0<0>3Ph0P1^KVh30:2PX080
T92@0`1cLg<206a/K0<0Lg=c0`2KVi/20<C4a0<0^[Zj0P2YZJT30:RXZ0<0ZZZZ0P2][Jd30;6a/@80
^;Rh0`2o_kl30<;2`P80a<C40`36a/H20<G5a@<0^k^k0`2^[Zh20:JVYP<0XJ6Q0P2SXj<30:VYZ@<0
/K6a0P2i^KT30<;2`P80alO70`2f][H30;Vi^@80Rh^;1@1QHF4306a/K080Kfm_201bLW8307EeM@80
N7Qh0`1iNGT307YjNP80O7al1@1mOGd307IfMP<0DE5A0P0f=SH305]KF`80QhN70`2ATI43092@T080
QHF50`1kNg/205aLG0<0NGUi0`25QHD205MGE`<0HF5Q0P1ZJVX307AdM0<0N7Qh0P1aLG4306IVIP80
IfMW0`1/K6`206IVIP<0H61P0`1RHV8206MWI`<0J6QX0P1[Jf/307QhN0<0QhN70P2DU9@509jNWP<0
WIfM0`2OWil20::RXP<0Xj>S0P2TY:@30:FUYC@0b>3H0`0`<30202l_;`<0:BTY0P0Z:RX303`l?0<0
De=C0P1ADE43038b<PD09RHV0`0X:2P202XZ:P<0<30`0P0a<C4305EEE@80IFEU0`1XJ6P305]KF`80
;Bd]0`0W9bL502PX:0<092@T1@0Z:RX2030`<0<0;bl_1@0X:2P302XZ:P80:2PX0`0a<C4302d];@80
>3Ph0`1BDU82069RHP<0?Cdm0`0Y:BT2028R8P<09RHV1@0Q8B4303De=@80Ng]k0`2FUYH209VIV@<0
LG5a0P1]KFd307MgM`<0WYjN0P2l_;`30<;2`P80YjNW0`2SXj<30:b/[080[Zj^0`2_[jl20;Rh^0H0
`<300P33`l<30<O7a`80aLG50`2k^k/30:b/[080Xj>S0`2QXJ420::RXP<0YZJV0`2g]kL20;Zj^P<0
`/;21@38b<P30;Jf]P80PX:20`1TI6@2069RHP<0K6a/1@1aLG43079bLP80N7Qh0`1eMGD207IfMP<0
OGem0`1hN7P207EeM@<0O7al0P21PH4306i^KP<0F5QH0P0c<c<305YJFP80PH610`2EUID309:BTP80
Rh^;0`1dM7@2061PH0<0MgMg0`1mOGd205]KF`<0FEUI0P1aLG4307=cL`<0O7al0P1aLG4306UYJ@80
I6AT0`1^KVh206=SH`<0GEeM0`1TI6@2065QH@<0J6QX0P1]KFd307YjNP<0QHF50P2HV9P309bLW080
WIfM0`2LW9`309fMW@80XJ6Q0`2VYZH20:BTY0<0YJFU7038h=P001/0b>3H0`0_;bl202`/;0<0:BTY
0P0];Bd3034a<@<0GEeM0P17AdL303Ti>@808b<S0`0T92@302TY:@809RHV0`0W9bL203/k>`<0DE5A
0P1UIFD306i^KP<0DU9B0P0_;bl502PX:0H09RHV0P0X:2P302/[:`80;bl_0`0`<30302`/;0809RHV
1@0X:2P302HV9P<0:RXZ0P10@40305IFEP80De=C0`10@40302`/;0806a/K0`0L71`2028R8P<0:2PX
0`0h>3P206i^KP<0X:2P0P2@T90307=cL`80K6a/0`1cLg<309^KV`80a<C40`2j^[X20:VYZ@<0Z:RX
0`2ZZZX20:f][@<0/K6a0P2h^;P30;no_`<0`/;20P34a<@30<K6aP80aLG50`2k^k/30:j^[P80YZJV
0`2QXJ420:>SX`<0ZJVY0`2a/K420;Vi^@<0`/;20P37alL30;Jf]P<0^KVi0P2;Rh/5065QH@<0K6a/
0P1_Kfl8079bLP<0MGEe0P1hN7P307UiN@<0NWYj0P1lO7`507emO@<0MWIf0`1ADE4203Hf=P<0Fe]K
0P27QhL3096AT@<0T92@0P25QHD307]kN`80G5aL0`1iNGT308F5Q@80EeMG0`1QHF4206YZJP<0M7Ad
0`1hN7P2075aL@<0IVIV0P1WIfL306a/K080IVIV0`1PH603069RHP80IfMW0`1XJ6P206][J`<0N7Qh
0`27QhL209BDU0D0WYjN0`2MWId309nOW`80XZ:R0`2SXj<20:BTY0<0YJFU=038h=P3030`<080;bl_
0`0Y:BT202XZ:P<0?3`l0`1CDe<2055AD@<0<S8b1@0V9RH302PX:080:RXZ0`0`<302034a<@<0EEEE
0P1UIFD306QXJ0<0Fe]K0P0];Bd302LW9`D0:2PX0`0T92@502XZ:P80<30`0`0_;bl502PX:0<0:RXZ
0P0X:2P3034a<@<0;Bd]0P0h>3P3059BDP80HV9R0`0m?Cd302TY:@808R8R0`0V9RH5024Q8@<0=CDe
0P1kNg/309JFUP80VIVI0`1aLG4206e]K@<0MgMg0`2NWYh20;bl_0<0`/;20P2WYjL30:>SX`<0[:b/
0P2^[Zh30:n_[`80^;Rh1P30`<020<?3``<0alO70P35aLD30;^k^`<0[:b/0P2SXj<30:6QX@80XZ:R
0`2VYZH30;Ng]`80^[Zj0`32`/850<S8b0<0][Jf0P22PX8306ATI080HV9R0`1/K6`5075aL@<0LW9b
0P1hN7P307EeM@80MWIf0`1mOGd307QhN080MGEe0`1lO7`20861P@<0KVi^0`1HF5P203<c<`<0FUYJ
0P21PH4309FEU@<0TY:B0P2;Rh/307AdM080H61P0`1gMgL307emO@80Fe]K0`1IFET2075aL@<0Lg=c
0`1lO7`2075aL@<0JFUY0P1TI6@306i^KP80Hf=S0`1MGEd306ATI080HF5Q0`1XJ6P206e]K@<0NWYj
0`25QHD209RHV0<0W9bL0P2MWId309bLW0<0WIfM0P2QXJ430:JVYP80Y:BT0`2UYJDL0<SPf0006`38
h=P302TY:@80:RXZ0`0[:b/502d];@<0EUIF0P0l?3`303Xj>P80;2`/0`0Y:BT302PX:0809BDU0`0/
;2`20410@0<0EUIF0P1SHf<306][J`<0@D510P0f=SH302PX:0809bLW0`0U9BD302HV9P80:2PX0`0Z
:RX202`/;0<0;Bd]0`0Z:RX202`/;0<092@T0P0o?cl303hn?P<0@d=30P1]KFd307AdM080Bd];0`0d
=3@303<c<`80?Shn1@0Q8B4301/K6`<09BDU0P1ADE4308:2PP80TY:B0`2@T9020820P0<0M7Ad0`27
QhL20:FUY@<0/k>c0P2j^[X30;2`/0<0Y:BT0P2XZ:P30;2`/080];Bd0`2i^KT30;fm_@80`L710`36
a/H20<O7a`<0_kno0`2d];@20:JVYP<0W9bL0P2MWId30::RXP<0Zj^[0P2e]KD30;no_`80a/K61P35
aLD20:j^[P<0TY:B0P1lO7`306a/K080Kfm_0`1gMgL307YjNP80OGem0`1nOWh207moO`<0Q8B40`29
RHT208Z:RP<0RHV90P27QhL308:2PP<0J6QX0P1FEUH307EeM@80VYZJ0`2QXJ4309jNWP80U9BD0`29
RHT207EeM@<0Ph>30`2:RXX207=cL`<0GUiN1@1/K6`306YZJP80IVIV0`1NGUh205YJFP<0G5aL0P1F
EUH3059BDP<0De=C0P1GEeL3061PH080KFe]0`1mOGd308j>SP80Vi^K1@2UYJD30::RXP<0Xj>S0P2U
YJD50:NWY`<0Z:RX=038h=P302PX:0809BDU0`0/;2`202TY:@<0=3@d0`1<C4`20410@0<0=cLg0P0[
:b/302LW9`<09RHV0P0`<30302PX:080>3Ph0`1GEeL506IVIP<0C4a<0P0e=CD302XZ:P808b<S0`0R
8R8302`/;080;Bd]0`0/;2`202XZ:P<0<C4a0`0X:2P202LW9`<0:RXZ0P0c<c<303De=@<0@d=30P1/
K6`306i^KP80@D510`0[:b/3034a<@80;bl_0`0R8R8201hN7P<0820P0`0Q8B4204Y:BP<0Ng]k0P2N
WYh308j>SP80Ng]k0`1bLW830861P@80Xj>S0`2o_kl20;Vi^@H0Z:RX0P2YZJT30:^[Z`80/[:b0`2h
^;P30;fm_@80`L710`36a/H20<G5a@<0_kno0`2e]KD20:VYZ@<0VYZJ0P2QXJ4309bLW0<0/K6a0P2e
]KD30;jn_P80a<C41P37alL20;fm_@<0UIFE0P1/K6`306m_K`80LG5a0`1hN7P307inOP80OGem0`1k
Ng/207alO0<0RXZ:0`27QhL208J6QP<0Q8B40P2:RXX308>3P`<0Lg=c0P1?Cdl307]kN`80Vi^K0`2M
WId309^KV`80WIfM0`29RHT2075aL@<0Q8B40`29RHT207IfMP<0Fe]K0P1/K6`306EUI@<0JVYZ0P1T
I6@305iNGP80EeMG0`1MGEd205YJFP<0DE5A0`1JFUX205aLG0<0HV9R0P1_Kfl307MgM`<0Shn?0P2N
WYh30:FUY@80Y:BT1P2SXj<20:NWY`<0ZZZZ0P2RXZ830:FUYA`0b>3H000K0<SPf0<0:BTY0P0Z:RX3
02/[:`D0;Bd]0`1FEUH203`l?0<0>SXj0P0/;2`302TY:@<0:2PX0P0U9BD302`/;080@4100`1FEUH2
06=SH`<0Jf][0`11@D4203Hf=P<0:2PX0P0W9bL302DU9@<09RHV0P0X:2P302XZ:P80;2`/0`0];Bd3
02XZ:P80;2`/0`0T92@203lo?`<0?Shn0`13@d<206e]K@<0M7Ad0P1;Bd/303@d=0<0<c<c0P0n?Sh5
024Q8@<06a/K0`0U9BD2055AD@<0PX:20P2BTY83092@T080P8200`1dM7@308N7Q`80YJFU0`2c/k<2
0;Zj^P<0/;2`0`2TY:@20:RXZ0<0/;2`0P2d];@30;Vi^@<0_Kfm0P31`L430<K6aP80alO70`2o_kl3
0;Bd]080YZJV0`2LW9`209fMW@<0XZ:R0`2[Zj/20;Fe]@<0_kno0P36a/H60<G5a@80[Zj^0`2BTY82
07alO0<0K6a/0P1_Kfl307MgM`<0NWYj0P1mOGd307inOP80Ogmo0`24Q8@308V9R@80RXZ:0`29RHT2
08N7Q`<0PX:20`1XJ6P205IFEP<0MGEe0P2JVYX30:6QX@<0WYjN0P2DU9@308V9R@80MGEe0`23Ph<3
08Z:RP80Lg=c0`1NGUh506a/K0<0JVYZ0P1VIVH305iNGP80FUYJ0`1LG5`205IFEP<0DU9B0`1CDe<2
05MGE`<0H61P0P1]KFd307emO@<0SXj>0P2KVi/50:FUY@<0XZ:R0`2SXj<20:FUY@D0YjNW0`2XZ:Pd
0<SPf0<0:2PX0P0U9BD302`/;080:BTY0`0d=3@304a<C080@4100`0g=cL202/[:`<09bLW0`0V9RH2
030`<0<0:2PX0P0h>3P305MGE`D0IVIV0`1<C4`203De=@<0:RXZ0P0S8b<3028R8P<0;2`/0P0];Bd3
02`/;080:RXZ0`0a<C4302PX:0809bLW0`0Z:RX203<c<`<0=CDe0`13@d<206a/K0<0KVi^0P11@D43
02/[:`<0<C4a0P0_;bl3028R8P807QhN0`0P8203024Q8@80BTY:0`1kNg/209jNWP<0SXj>0P1kNg/3
079bLP<0PH610P2SXj<30;no_`80^KVi1P2XZ:P20:VYZ@<0Zj^[0P2b/[830;Rh^0<0_Kfm0P31`L43
0<K6aP80aLG50`2o_kl30;Fe]@80ZJVY0`2JVYX20:6QX@<0W9bL0`2a/K420;Fe]@<0_[jn0P34a<@6
0<O7a`80_Kfm0`2EUID206a/K0<0Kfm_0P1aLG4307QhN0<0OWin0P1mOGd307]kN`80O7al0`2:RXX3
08N7Q`80QXJ60`24Q8@208Z:RP<0Ph>30`1cLg<204m?C`<0Ng]k0P2KVi/309fMW@<0Vi^K0P2MWId3
08V9R@80LG5a0`24Q8@308V9R@80MWIf0`1KFe/206a/K0<0IFEU0`1ZJVX206ATI0<0GUiN0P1GEeL3
05eMG@80FUYJ0`1ADE4305YJFP80G5aL0`1RHV8206m_K`<0MgMg0`2?Shl209jNWP<0YJFU0P2TY:@6
0:>SX`80YjNW0`2ZZZX20::RXP<0YJFU7038h=P001/0b>3H0`0S8b<202PX:0<0;Bd]0P0/;2`302PX
:0<0BDU90P0b<S8503Ph>0<0;bl_0`0V9RH202DU9@<0;Bd]0P12@T8305QHF080GUiN0`1RHV83038b
<P80?clo0`0];Bd502DU9@D0:2PX0`0Y:BT502PX:0<0:BTY0P0b<S8302LW9`D0Fe]K0`1IFET207Ad
M0<0DU9B0P0O7al302d];@<0@T920P1NGUh302DU9@808b<S0`0F5QH301/K6`80=cLg0`1LG5`208V9
R@<0ZJVY0P2GUiL307alO0<0N7Qh0P1oOgl30:FUY@80alO70`2h^;P30::RXP80YZJV0`2^[Zh20;6a
/@<0/k>c0`2i^KT20;jn_P<0a<C40P38b<P30<C4a0<0^k^k0P2YZJT309VIV@80UiNG0`2LW9`30:FU
Y@80/;2`0`2h^;P20;no_`<0aLG50`37alL20<[:bP<0`l?30P2JVYX307AdM080MWIf0`21PH4508>3
P`<0PX:20P23Ph<308^;R`D0TY:B0`2@T90208f=S@<0R8R80`1mOGd207QhN0<0SHf=0P2UYJD30:JV
YP<0XJ6Q0P2HV9P308j>SP80RHV91P23Ph<208N7Q`<0FEUI0P1ZJVX3061PH0<0Fe]K0P1FEUH305=C
D`80Cdm?0`1;Bd/204U9B@<0B4Q80`19BDT204m?C`<0H61P0P1eMGD308J6QP<0UYJF0P2SXj<30:^[
Z`80ZZZZ0`2VYZH30:NWY`D0ZJVY1@2ZZZXd0<SPf0<092@T0P0Y:BT3034a<@809RHV0`0d=3@304M7
A`80>c/k0`0n?Sh203Lg=`<0;Rh^0`0Z:RX202`/;0<0<c<c0P0i>CT305]KF`80GEeM0`1QHF4303`l
?080>3Ph0`0`<30802@T9080:BTY0`0X:2P202TY:@<09bLW0`0Z:RX2030`<0<0<C4a0P1IFET305=C
D`<0H61P0P25QHD3059BDP809BDU0`0[:b/304U9B@80G5aL0`0W9bL2020P80<07AdM0`0O7al2038b
<P<0HV9R0P2>SXh30:NWY`80UYJF0`22PX83075aL@80PX:20`2XZ:P20<?3``<0]kNg0`2QXJ420:RX
Z0<0[:b/0P2a/K430;>c/`<0^;Rh0P2k^k/30<O7a`80a/K60`34a<@30;^k^`80YjNW0`2FUYH209ZJ
VP<0VIVI0`2XZ:P20:^[Z`<0^[Zj0P2o_kl30<71`@<0aLG50P37alL30<30`080WYjN0`1_Kfl206i^
KP<0Ng]k1@22PX8308>3P`80QHF50`29RHT309:BTP80Ti>C0`2>SXh209:BTP<0RXZ:0`1eMGD207Yj
NP<0T92@0P2UYJD30:>SX`<0X:2P0P2KVi/308n?S`80Ogmo0`21PH4308Z:RP80OWin0`1KFe/206QX
J0<0FUYJ0`1NGUh205EEE@<0E5AD0P1?Cdl304];B`80CTi>0`18B4P504i>CP<0H61P0P1fMWH308N7
Q`<0UYJF0P2VYZH30:ZZZP80ZJVY0`2VYZH30:RXZ080YjNW0`2[Zj/20:ZZZP<0[Jf]7038h=P001/0
b>3H0`0S8b<202PX:0<0;Bd]0P0/;2`302PX:0<0BDU90P0b<S8503Ph>0<0;bl_0`0V9RH202DU9@<0
;Bd]0P12@T8305QHF080GUiN0`1RHV83038b<P80?clo0`0];Bd502DU9@D0:2PX0`0Y:BT502PX:0<0
:BTY0P0b<S8302LW9`D0Fe]K0`1IFET207AdM0<0DU9B0P0O7al302d];@<0@T920P1NGUh302DU9@80
8b<S0`0F5QH301/K6`80=cLg0`1LG5`208V9R@<0ZJVY0P2GUiL307alO0<0N7Qh0P1oOgl30:FUY@80
alO70`2h^;P30::RXP80YZJV0`2^[Zh20;6a/@<0/k>c0`2i^KT20;jn_P<0a<C40P38b<P30<C4a0<0
^k^k0P2YZJT309VIV@80UiNG0`2LW9`30:FUY@80/;2`0`2h^;P20;no_`<0aLG50`37alL20<[:bP<0
`l?30P2JVYX307AdM080MWIf0`21PH4508>3P`<0PX:20P23Ph<308^;R`D0TY:B0`2@T90208f=S@<0
R8R80`1mOGd207QhN0<0SHf=0P2UYJD30:JVYP<0XJ6Q0P2HV9P308j>SP80RHV91P23Ph<208N7Q`<0
FEUI0P1ZJVX3061PH0<0Fe]K0P1FEUH305=CD`80Cdm?0`1;Bd/204U9B@<0B4Q80`19BDT204m?C`<0
H61P0P1eMGD308J6QP<0UYJF0P2SXj<30:^[Z`80ZZZZ0`2VYZH30:NWY`D0ZJVY1@2ZZZXd0<SPf0<0
92@T0P0Y:BT3034a<@809RHV0`0d=3@304M7A`80>c/k0`0n?Sh203Lg=`<0;Rh^0`0Z:RX202`/;0<0
<c<c0P0i>CT305]KF`80GEeM0`1QHF4303`l?080>3Ph0`0`<30802@T9080:BTY0`0X:2P202TY:@<0
9bLW0`0Z:RX2030`<0<0<C4a0P1IFET305=CD`<0H61P0P25QHD3059BDP809BDU0`0[:b/304U9B@80
G5aL0`0W9bL2020P80<07AdM0`0O7al2038b<P<0HV9R0P2>SXh30:NWY`80UYJF0`22PX83075aL@80
PX:20`2XZ:P20<?3``<0]kNg0`2QXJ420:RXZ0<0[:b/0P2a/K430;>c/`<0^;Rh0P2k^k/30<O7a`80
a/K60`34a<@30;^k^`80YjNW0`2FUYH209ZJVP<0VIVI0`2XZ:P20:^[Z`<0^[Zj0P2o_kl30<71`@<0
aLG50P37alL30<30`080WYjN0`1_Kfl206i^KP<0Ng]k1@22PX8308>3P`80QHF50`29RHT309:BTP80
Ti>C0`2>SXh209:BTP<0RXZ:0`1eMGD207YjNP<0T92@0P2UYJD30:>SX`<0X:2P0P2KVi/308n?S`80
Ogmo0`21PH4308Z:RP80OWin0`1KFe/206QXJ0<0FUYJ0`1NGUh205EEE@<0E5AD0P1?Cdl304];B`80
CTi>0`18B4P504i>CP<0H61P0P1fMWH308N7Q`<0UYJF0P2VYZH30:ZZZP80ZJVY0`2VYZH30:RXZ080
YjNW0`2[Zj/20:ZZZP<0[Jf]7038h=P001/0b>3H0`0S8b<202PX:0<0;Bd]0P0/;2`302PX:0<0BDU9
0P0b<S8503Ph>0<0;bl_0`0V9RH202DU9@<0;Bd]0P12@T8305QHF080GUiN0`1RHV83038b<P80?clo
0`0];Bd502DU9@D0:2PX0`0Y:BT502PX:0<0:BTY0P0b<S8302LW9`D0Fe]K0`1IFET207AdM0<0DU9B
0P0O7al302d];@<0@T920P1NGUh302DU9@808b<S0`0F5QH301/K6`80=cLg0`1LG5`208V9R@<0ZJVY
0P2GUiL307alO0<0N7Qh0P1oOgl30:FUY@80alO70`2h^;P30::RXP80YZJV0`2^[Zh20;6a/@<0/k>c
0`2i^KT20;jn_P<0a<C40P38b<P30<C4a0<0^k^k0P2YZJT309VIV@80UiNG0`2LW9`30:FUY@80/;2`
0`2h^;P20;no_`<0aLG50`37alL20<[:bP<0`l?30P2JVYX307AdM080MWIf0`21PH4508>3P`<0PX:2
0P23Ph<308^;R`D0TY:B0`2@T90208f=S@<0R8R80`1mOGd207QhN0<0SHf=0P2UYJD30:JVYP<0XJ6Q
0P2HV9P308j>SP80RHV91P23Ph<208N7Q`<0FEUI0P1ZJVX3061PH0<0Fe]K0P1FEUH305=CD`80Cdm?
0`1;Bd/204U9B@<0B4Q80`19BDT204m?C`<0H61P0P1eMGD308J6QP<0UYJF0P2SXj<30:^[Z`80ZZZZ
0`2VYZH30:NWY`D0ZJVY1@2ZZZXd0<SPf0<092@T0P0Y:BT3034a<@809RHV0`0d=3@304M7A`80>c/k
0`0n?Sh203Lg=`<0;Rh^0`0Z:RX202`/;0<0<c<c0P0i>CT305]KF`80GEeM0`1QHF4303`l?080>3Ph
0`0`<30802@T9080:BTY0`0X:2P202TY:@<09bLW0`0Z:RX2030`<0<0<C4a0P1IFET305=CD`<0H61P
0P25QHD3059BDP809BDU0`0[:b/304U9B@80G5aL0`0W9bL2020P80<07AdM0`0O7al2038b<P<0HV9R
0P2>SXh30:NWY`80UYJF0`22PX83075aL@80PX:20`2XZ:P20<?3``<0]kNg0`2QXJ420:RXZ0<0[:b/
0P2a/K430;>c/`<0^;Rh0P2k^k/30<O7a`80a/K60`34a<@30;^k^`80YjNW0`2FUYH209ZJVP<0VIVI
0`2XZ:P20:^[Z`<0^[Zj0P2o_kl30<71`@<0aLG50P37alL30<30`080WYjN0`1_Kfl206i^KP<0Ng]k
1@22PX8308>3P`80QHF50`29RHT309:BTP80Ti>C0`2>SXh209:BTP<0RXZ:0`1eMGD207YjNP<0T92@
0P2UYJD30:>SX`<0X:2P0P2KVi/308n?S`80Ogmo0`21PH4308Z:RP80OWin0`1KFe/206QXJ0<0FUYJ
0`1NGUh205EEE@<0E5AD0P1?Cdl304];B`80CTi>0`18B4P504i>CP<0H61P0P1fMWH308N7Q`<0UYJF
0P2VYZH30:ZZZP80ZJVY0`2VYZH30:RXZ080YjNW0`2[Zj/20:ZZZP<0[Jf]7038h=P001/0b>3H1@0T
92@302PX:080>3Ph0`16ATH3071`L080EEEE0`17AdL203Hf=P<0@4100`1;Bd/205YJFP<0ATI60P1<
C4`304i>CP80G5aL0`16ATH302l_;`80=CDe0`0l?3`202@T90<09BDU1@0W9bL302PX:0809RHV0`0U
9BD302TY:@80<S8b0`0W9bL204E5A@<0H61P0`1/K6`208J6QP<0EUIF0P0T92@302d];@<0CTi>0P1G
EeL302LW9`80;Rh^0`0P820301dM7@809bLW0`0o?cl207=cL`<0XJ6Q0P2LW9`308V9R@<0LG5a0P1Z
JVX308n?S`80^;Rh0`2i^KT30;6a/@80ZZZZ0`2TY:@20:ZZZP<0/k>c0`2g]kL20;^k^`<0`L711@35
aLD30<30`080[jn_0`2NWYh509NGU`<0WinO0P2ZZZX30;:b/P80^KVi0`30`<030<?3``D0bLW90P2g
]kL309jNWP80Ogmo0`1XJ6P306i^KP80OGem0`24Q8@208^;R`<0TI6A0`2EUID509RHV080U9BD0`2?
Shl308f=S@80Shn?0`2JVYX20:FUY@<0Y:BT0`2OWil209JFUP<0S8b<0P25QHD307]kN`<0MGEe0P1d
M7@305IFEP80FUYJ0`1BDU8304e=C@80B4Q80`14A4@50492@P80ADE50`1:BTX305EEE@80I6AT0`1g
MgL208Z:RP<0V9RH0`2RXZ820:RXZ0D0Zj^[202YZJT30:ZZZP80[:b/0`2][Jdd0<SPf0<09RHV0P0T
92@302l_;`80<c<c0`15ADD3065QH@80C4a<0`16ATH203`l?0<0=cLg0`0m?Cd206=SH`<0ATI60P0o
?cl305]KF`80G5aL0`13@d<302LW9`80=CDe0`0k>c/502TY:@<0:2PX0P0[:b/302LW9`809BDU0`0Y
:BT302<S8`80;Bd]0`0c<c<204m?C`<0GemO0`1VIVH207IfMP<0E5AD0P0V9RH302d];@<0Fe]K0P1I
FET302h^;P80:RXZ0`0O7al301dM7@8092@T0`0i>CT207EeM@<0VYZJ0P2WYjL308R8R0<0KVi^0P1X
J6P308n?S`80]kNg0`33`l<30:b/[080YjNW0`2ZZZX20:f][@H0];Bd0P2n_[h30<;2`P80a/K60`37
alL30;no_`80[:b/0`2SXj<509JFUP<0XJ6Q0P2YZJT30;>c/`80_;bl0`2n_[h30<C4a080aLG50`37
alL20<71`@<0Zj^[0P1lO7`307AdM0<0N7Qh0P1jNWX308J6QP80RHV90`2>SXh309NGU`80VIVI0`2J
VYX209FEU@<0SXj>0`1kNg/209JFUP<0WIfM0P2OWil30:>SX`<0X:2P0P2JVYX308^;R`80QHF51P1n
OWh207=cL`D0HF5Q0`1FEUH305=CD`D0B4Q80P14A4@503lo?`<0@D510`1?Cdl205]KF`<0NGUi0P28
R8P309FEU@<0XJ6Q0P2WYjL30:^[Z`80YjNW0`2[Zj/30:BTY080YjNW1@2[Zj/30:f][A`0b>3H000K
0<SPf0D092@T0`0X:2P203Ph>0<0ATI60`1`L70205EEE@<0AdM70P0f=SH30410@0<0Bd];0P1JFUX3
04I6AP80C4a<0`1>CTh205aLG0<0ATI60`0_;bl203De=@<0?3`l0P0T92@302DU9@D09bLW0`0X:2P2
02HV9P<09BDU0`0Y:BT2038b<P<09bLW0P15ADD3061PH0<0K6a/0P26QXH305IFEP8092@T0`0];Bd3
04i>CP80EeMG0`0W9bL202h^;P<0820P0`0M7Ad202LW9`<0?clo0P1cLg<30:6QX@80W9bL0`29RHT3
075aL@80JVYZ0`2?Shl20;Rh^0<0^KVi0`2a/K420:ZZZP<0Y:BT0P2ZZZX30;>c/`<0]kNg0P2k^k/3
0<71`@D0aLG50`30`<020:n_[`<0WYjN1@2GUiL309nOW`80ZZZZ0`2b/[820;Vi^@<0`<300`33`l<5
0<W9b@80]kNg0`2NWYh207moO`<0J6QX0`1^KVh207emO@<0Q8B40P2;Rh/3096AT@<0UIFE1@2HV9P2
09BDU0<0Shn?0`2=SHd208n?S`<0VYZJ0P2UYJD30:BTY0<0WinO0P2FUYH308b<S080QHF50`1kNg/3
07EeM@80M7Ad0`1FEUH205YJFP<0DU9B0`1=CDd204Q8B0<0A4A41@12@T8204E5A@<0BTY:0`1EEED2
06ATI0<0MgMg0P2:RXX309RHV0<0XZ:R0P2XZ:P50:^[Z`P0ZJVY0`2ZZZX20:b/[0<0[Jf]=038h=P3
02HV9P8092@T0`0_;bl203<c<`<0ADE50`1QHF4204a<C0<0ATI60P0l?3`303Lg=`<0?Cdm0P1SHf<3
04I6AP80?clo0`1KFe/205aLG0<0@d=30`0W9bL203De=@<0>c/k1@0Y:BT302PX:080:b/[0`0W9bL2
02DU9@<0:BTY0`0S8b<202d];@<0<c<c0P1?Cdl305mOG`<0IVIV0P1fMWH305ADE0809RHV0`0];Bd3
05]KF`80FEUI0`0^;Rh202XZ:P<07alO0`0M7Ad202@T90<0>CTi0P1eMGD309ZJVP80YjNW0`28R8P3
06i^KP80J6QX0`2?Shl20;Ng]`<0`l?30`2/[:`20:NWY`<0ZZZZ0P2][Jd60;Bd]080_[jn0`32`/82
0<K6aP<0alO70`2o_kl20:b/[0<0Xj>S1@2FUYH30:6QX@80ZJVY0`2c/k<20;bl_0<0_[jn0`34a<@2
0<G5a@<0alO70P31`L430:^[Z`80O7al0`1dM7@307QhN080NWYj0`26QXH208V9R@<0SXj>0`2GUiL2
09VIV@<0VYZJ0P2EUID308j>SP<0Ng]k0P2FUYH309fMW@80WinO0`2SXj<30:2PX080VYZJ0`2;Rh/2
08F5Q@H0OWin0P1cLg<5065QH@<0EUIF0`1CDe<504Q8B080A4A41@0o?cl30451@@<0Cdm?0P1KFe/3
07UiN@80R8R80`2EUID30:6QX@80YjNW0`2[Zj/20:NWY`<0Zj^[0`2TY:@20:NWY`D0Zj^[0`2][JdL
0<SPf0006`38h=P502@T90<0:2PX0P0h>3P304I6AP<0L71`0P1EEED304M7A`80=SHf0`10@40304];
B`80FUYJ0`16ATH204a<C0<0CTi>0P1LG5`304I6AP<0;bl_0P0e=CD303`l?08092@T0`0U9BD502LW
9`<0:2PX0P0V9RH302DU9@<0:BTY0P0b<S8302LW9`80ADE50`1PH60306a/K080QXJ60`1FEUH202@T
90<0;Bd]0`1>CTh205MGE`<09bLW0P0^;Rh3020P80<07AdM0P0W9bL303lo?`80Lg=c0`2QXJ4209bL
W0<0RHV90`1aLG4206YZJP<0Shn?0P2h^;P30;Vi^@<0/K6a0P2ZZZX30:BTY080ZZZZ0`2c/k<30;Ng
]`80^k^k0`31`L450<G5a@<0`<300P2_[jl309jNWPD0UiNG0`2OWil20:ZZZP<0/[:b0P2i^KT30<30
`0<0`l?31@39bLT20;Ng]`<0WYjN0P1oOgl306QXJ0<0KVi^0P1mOGd308B4Q080Rh^;0`2ATI4309FE
U@D0V9RH0P2DU9@308n?S`<0SHf=0P2?Shl309ZJVP80YJFU0`2TY:@309nOW`80UYJF0`2<S8`208F5
Q@<0Ng]k0`1eMGD207AdM0<0EUIF0P1JFUX3059BDP<0CDe=0P18B4P304A4A0D0@T920P15ADD304Y:
BP<0EEEE0P1TI6@307MgM`80RXZ:0`2HV9P30::RXP80Z:RX1@2[Zj/80:VYZ@<0ZZZZ0P2/[:`30:f]
[C@0b>3H0`0V9RH202@T90<0;bl_0P0c<c<304E5A@<0HF5Q0P1<C4`304I6AP80?3`l0`0g=cL303dm
?@80Hf=S0`16ATH203lo?`<0Fe]K0P1LG5`304=3@`<09bLW0P0e=CD303/k>`D0:BTY0`0X:2P202/[
:`<09bLW0P0U9BD302TY:@<08b<S0P0];Bd303<c<`80Cdm?0`1OGel306IVIP80MWIf0`1DE5@202HV
9P<0;Bd]0`1KFe/205UIF@<0;Rh^0P0Z:RX301lO7`<07AdM0P0T92@303Ti>@80MGEe0`2JVYX20:NW
Y`<0R8R80`1^KVh206QXJ0<0Shn?0P2g]kL30<?3``<0[:b/0P2WYjL30:ZZZP80[Jf]1P2d];@20;jn
_P<0`/;20P36a/H30<O7a`<0_kno0P2/[:`30:>SX`D0UYJF0`2QXJ420:VYZ@<0/k>c0P2l_;`30;jn
_P<0a<C40P35aLD30<O7a`80`L710`2[Zj/207alO0<0M7Ad0`1hN7P207YjNP<0QXJ60P29RHT308j>
SP<0UiNG0P2IVIT309ZJVP80UIFE0`2>SXh307]kN`80UYJF0`2MWId209nOW`<0Xj>S0`2PX:0209ZJ
VP<0Rh^;0P25QHD607inOP80Lg=c1@1QHF4305IFEP<0De=C1@18B4P204A4A0D0?clo0`11@D4304m?
C`80Fe]K0`1iNGT208R8R0<0UIFE0`2QXJ420:NWY`<0Zj^[0P2WYjL30:^[Z`<0Y:BT0P2WYjL50:^[
Z`<0[Jf]7038h=P001/0b>3H1@0V9RH302LW9`D0:2PX0`1ADE4203`l?0<0?Shn1@0j>SX303@d=080
BDU90`0S8b<203Ti>@<0AdM70P1LG5`302`/;0<0;bl_0P0Z:RX304Q8B0809BDU0`0W9bL302HV9P80
9bLW0`0X:2P202DU9@<092@T0`0X:2P2038b<P<0DE5A0P1XJ6P3069RHP<0=cLg0P1VIVH305YJFP80
<30`0`0d=3@305MGE`80ADE50`0X:2P203dm?@<0;Bd]0`0R8R8201hN7P<0:2PX0P1IFET308Z:RP80
V9RH0`2EUID307EeM@80GEeM0`1hN7P209fMW@<0];Bd0`2o_kl20:n_[`<0WIfM0P2VYZH30;:b/P<0
][Jf0P2h^;P30;fm_@80`L710`35aLD30<C4a080][Jf0`2VYZH209ZJVP<0U9BD0`2KVi/20:FUY@<0
[Jf]0P2d];@30;Vi^@<0_Kfm0P31`L430<C4a080alO70`34a<@20:f][@<0U9BD0`20P80207AdM0<0
Ogmo0P2?Shl309:BTP<0Ti>C0P2HV9P309bLW080UiNG0`2CTi<309NGU`80WIfM0`2NWYh209fMW@<0
Vi^K0`2GUiL208j>SP<0Q8B40P1iNGT306i^KP<0Hf=S0P1IFET305=CD`80Bd];0`17AdL304A4A080
@4100`0m?Cd203lo?`<0A4A40P1<C4`305MGE`<0Jf][0P20P80309:BTP80XJ6Q0`2YZJT50:f][@<0
ZZZZ0P2[Zj/30:b/[0<0ZZZZ0P2YZJT30:^[Z`80[Jf]0`2^[Zhd0<SPf0<09BDU0P0X:2P502LW9`<0
<c<c0`1=CDd203lo?`<0@T920P0j>SX302/[:`<0?Cdm0P1CDe<302XZ:P80<c<c0`1:BTX205ADE0<0
=3@d0`0Y:BT203Hf=P<0?Shn0P0Z:RX302PX:0<08b<S0P0/;2`302TY:@80820P0`0X:2P302TY:@80
=3@d0`1@D50206IVIP<0FEUI0`0m?Cd206UYJ@<0HF5Q0P0U9BD303<c<`<0GEeM0P0j>SX302d];@80
?Shn0`0R8R8302PX:0809bLW0`0Z:RX2051@D0<0QHF50P2RXZ83092@T0<0LW9b0P1TI6@307=cL`80
VYZJ0`2o_kl30;fm_@80YZJV0`2NWYh20:ZZZP<0/;2`0`2b/[820;Rh^0<0^k^k0P31`L430<K6aP<0
a<C40P2c/k<30:JVYP80Vi^K0`2DU9@309bLW080YJFU0`2XZ:P20;:b/P<0^k^k0`2m_Kd20<30`0<0
aLG50P33`l<30;fm_@80/K6a0`28R8P307IfMP80NGUi0`23Ph<208^;R`H0TI6A0P2HV9P509VIV@<0
V9RH0`2BTY8209fMW@<0XZ:R0P2KVi/309JFUP<0UIFE0P2?Shl30861P@80NWYj0`1]KFd3061PH080
GEeM0`1BDU8204I6AP<0CDe=0`13@d<20451@@<0?clo0P0i>CT304I6AP80Cdm?0`1IFET306MWI`80
PH610`2FUYH20:2PX0<0ZJVY0`2_[jl20:^[Z`<0ZZZZ0P2][Jd30:^[Z`<0Z:RX0P2[Zj/30:ZZZP80
Zj^[0`2`/;0L0<SPf0006`38h=P502HV9P<09bLW1@0X:2P3055AD@80?3`l0`0n?Sh503Xj>P<0=3@d
0P19BDT302<S8`80>CTi0`17AdL205aLG0<0;2`/0`0_;bl202XZ:P<0B4Q80P0U9BD302LW9`<09RHV
0P0W9bL302PX:0809BDU0`0T92@302PX:080<S8b0`1ADE4206QXJ0<0HV9R0`0g=cL206IVIP<0FUYJ
0P0`<30303@d=0<0EeMG0P15ADD302PX:080?Cdm0`0];Bd3028R8P807QhN0`0X:2P205UIF@<0RXZ:
0P2HV9P309FEU@<0MGEe0P1MGEd307QhN080WIfM0`2d];@30;no_`80[jn_0`2MWId20:JVYP<0/[:b
0`2f][H20;Rh^0<0_Kfm0P31`L430<G5a@<0a<C40P2f][H30:JVYP80VYZJ0`2DU9@309^KV`80YJFU
0`2][Jd20;Bd]0<0^KVi0`2m_Kd20<71`@<0a<C40P37alL30<C4a080[Jf]0`2DU9@30820P080M7Ad
0`1oOgl208n?S`<0TY:B0`2CTi<209RHV0<0W9bL0P2GUiL309>CT`<0UiNG0P2MWId309jNWP80WIfM
0`2KVi/309NGU`80SXj>0`24Q8@207UiN@<0KVi^0`1SHf<205UIF@<0De=C0P1;Bd/304M7A`<0A4A4
0P10@40303dm?@80?clo0`14A4@204a<C0<0EeMG0`1[Jf/20820P0<0TY:B0P2QXJ430:VYZ@D0[Jf]
0`2ZZZX20:^[Z`<0[:b/0`2ZZZX20:VYZ@<0Zj^[0P2][Jd30:j^[S@0b>3H0`0U9BD202PX:0D09bLW
0`0c<c<304e=C@80?clo0`12@T8203Xj>P<0:b/[0`0m?Cd205=CD`<0:RXZ0P0c<c<304Y:BP80E5AD
0`0d=3@302TY:@80=SHf0`0n?Sh202XZ:P<0:2PX0`0S8b<202`/;0<0:BTY0P0P820302PX:0<0:BTY
0P0d=3@3051@D080IVIV0`1IFET303dm?@80JFUY0`1QHF4202DU9@<0<c<c0`1MGEd203Xj>P<0;Bd]
0P0n?Sh3028R8P<0:2PX0P0W9bL302XZ:P80D51@0`25QHD20::RXP<0T92@0`1bLW8206ATI0<0Lg=c
0P2JVYX30;no_`<0_Kfm0P2VYZH309jNWP80ZZZZ0`2`/;030;:b/P80^;Rh0`2k^k/20<71`@<0a/K6
0`34a<@20;>c/`<0YZJV0P2KVi/309BDU0<0W9bL0P2UYJD30:RXZ080/[:b0`2k^k/30;fm_@80`<30
0`35aLD20<?3``<0_Kfm0P2a/K4308R8R0<0MWIf0P1iNGT308>3P`80Rh^;1P2ATI4209RHV0D0VIVI
0`2HV9P309:BTP80WIfM0`2RXZ8209^KV`<0UYJF0`2EUID208n?S`<0PH610P1jNWX306e]K@<0H61P
0P1MGEd3059BDP80ATI60`1=CDd304=3@`80@D510`0o?cl203Ti>@<0ATI60P1?Cdl305UIF@<0IfMW
0P21PH4309JFUP80X:2P0`2YZJT30:n_[`80Zj^[0`2ZZZX20:f][@<0Zj^[0`2XZ:P20:^[Z`<0ZZZZ
0P2[Zj/30;2`/1`0b>3H000K0<SPf0<09BDU0P0W9bL802TY:@<0@4100P0k>c/304A4A080ATI60`11
@D4303Ph>080@T920`0_;bl203hn?P<0B4Q80P1<C4`302/[:`<0;Rh^0P0/;2`303hn?P80;Rh^0`0/
;2`302PX:080:BTY0`0[:b/502LW9`<0>3Ph0P16ATH306i^KP80IfMW0`0T92@302DU9@80Bd];0`1L
G5`202/[:`<0BDU90`1KFe/203@d=0<09BDU0P1;Bd/303@d=0<07QhN0P0L71`302HV9P80@T920`1T
I6@208V9R@<0VYZJ0`2?Shl205iNGP<0IVIV0P1iNGT309bLW0<0^k^k0P2c/k<30:FUY@80Z:RX0`2]
[Jd30;6a/@80]KFe0`2i^KT20;bl_0<0`l?30`35aLD20;bl_0<0[jn_0P2QXJ4309JFUP<0V9RH0P2O
Wil30:JVYP80[jn_0`2g]kL30;fm_@80`<300`31`L420<K6aP<0alO70P2m_Kd30:f][@<0UIFE0P21
PH4307emO@80Ogmo0`26QXH308j>SP80U9BD0`2KVi/209RHV0<0Ti>C0`2FUYH209NGU`<0TY:B0P2;
Rh/308R8R0<0Q8B40P1lO7`3079bLP80IfMW0`1LG5`304m?C`80ADE50`17AdL204E5A@<0A4A40`13
@d<204Q8B0<0Cdm?0P1EEED305eMG@80Jf][0`1lO7`308Z:RP80UiNG0`2SXj<20:b/[0/0[jn_0P2`
/;030;6a/@<0[Zj^1@2/[:`20:f][@<0[Zj^=038h=P3024Q8@80:2PX0`0W9bL202HV9P<0:RXZ0`0l
?3`204a<C0<0@T920P1>CTh304a<C0<0>c/k0P0e=CD302TY:@80>c/k0`1?Cdl204Q8B0<0=CDe0`0`
<30202/[:`<0?3`l0P0];Bd602LW9`80:2PX0`0Z:RX202LW9`<0:RXZ0`0^;Rh204Y:BP<0KFe]0P1P
H60303<c<`<0:2PX0P1>CTh306=SH`80:2PX0`1;Bd/305aLG080:b/[0`0f=SH204i>CP<0:2PX0`0R
8R8201dM7@<0;bl_0P0j>SX306i^KP80SHf=0`2NWYh30861P@80IFEU0`1RHV8207UiN@<0Vi^K0`2o
_kl20;6a/@<0XJ6Q0P2[Zj/30:n_[`<0/;2`0P2g]kL30;Vi^@80^[Zj0`33`l<30<O7a`80_Kfm0`2_
[jl209^KV`<0UiNG0`2JVYX209bLW0<0Zj^[0P2/[:`30;bl_0<0_Kfm0P2j^[X30<K6aPD0`l?30P30
`<030;Vi^@<0TY:B0P1kNg/307emO@80Q8B40`29RHT308n?S`80UYJF0`2LW9`509JFUPD0UiNG0`2D
U9@2096AT@<0S8b<0`24Q8@207emO@<0M7Ad0P1XJ6P305aLG0<0Bd];0P13@d<303/k>`80ATI61P0m
?Cd204A4A0<0C4a<0P1HF5P305iNGP80LG5a0`24Q8@308f=S@80Vi^K0`2WYjL20:VYZ@<0[jn_0`2`
/;020:f][@<0[jn_0P2e]KD30;6a/@<0[Zj^0P2/[:`50:j^[P<0/K6a7038h=P001/0b>3H0`0U9BD2
02LW9`P0:BTY0`10@40203/k>`<0A4A40P16ATH30451@@<0>3Ph0P12@T8302l_;`80?Shn0`18B4P2
04a<C0<0:b/[0`0^;Rh202`/;0<0?Shn0P0^;Rh302`/;0<0:2PX0P0Y:BT302/[:`D09bLW0`0h>3P2
04I6AP<0KVi^0P1WIfL302@T90<09BDU0P1;Bd/305aLG080:b/[0`19BDT305]KF`80=3@d0`0U9BD2
04];B`<0=3@d0`0N7Qh201`L70<09RHV0P12@T8306ATI080RHV90`2JVYX308n?S`80GUiN0`1VIVH2
07UiN@<0W9bL0`2k^k/20;>c/`<0YJFU0P2XZ:P30:f][@<0/K6a0P2e]KD30;Vi^@80_;bl0`33`l<3
0<G5a@80_;bl0`2_[jl20:6QX@<0UYJF0`2HV9P209nOW`<0YZJV0P2_[jl30;Ng]`<0_Kfm0P30`<03
0<71`@80a/K60`37alL20;fm_@<0[Jf]0`2EUID20861P@<0OGem0P1oOgl308J6QP<0SXj>0P2DU9@3
09^KV`80V9RH0`2CTi<309JFUP80UiNG0`2BTY8208^;R`<0R8R80`24Q8@207alO0<0LW9b0P1WIfL3
05aLG0<0Cdm?0P15ADD304M7A`80ADE50`14A4@304=3@`80B4Q80`1?Cdl205EEE@<0GEeM0P1[Jf/3
07alO0<0RXZ:0P2GUiL30:>SX`80[:b/2`2_[jl20;2`/0<0/K6a0`2^[Zh50:b/[080[Jf]0`2^[Zhd
0<SPf0<08B4Q0P0X:2P302LW9`809RHV0`0Z:RX303`l?080C4a<0`12@T8204i>CP<0C4a<0`0k>c/2
03De=@<0:BTY0P0k>c/304m?C`80B4Q80`0e=CD3030`<080:b/[0`0l?3`202d];@H09bLW0P0X:2P3
02XZ:P809bLW0`0Z:RX302h^;P80BTY:0`1]KFd2061PH0<0<c<c0`0X:2P204i>CP<0Hf=S0P0X:2P3
04];B`<0G5aL0P0[:b/303Hf=P80CTi>0`0X:2P3028R8P807AdM0`0_;bl203Xj>P<0KVi^0P2=SHd3
09jNWP<0PH610P1UIFD3069RHP80NGUi0`2KVi/30;no_`80/K6a0`2QXJ420:^[Z`<0[jn_0`2`/;02
0;Ng]`<0^KVi0P2j^[X30<?3``<0alO70P2m_Kd30:n_[`80Vi^K0`2GUiL309ZJVP80W9bL0`2[Zj/2
0:b/[0<0_;bl0`2m_Kd20;Zj^P<0a/K61@33`l<20<30`0<0^KVi0`2BTY8207]kN`<0OGem0P24Q8@3
08V9R@<0Shn?0P2FUYH309bLW0D0UYJF1@2GUiL309BDU080TI6A0`2<S8`308B4Q080OGem0`1dM7@2
06QXJ0<0G5aL0`1;Bd/204=3@`<0>c/k0P16ATH603dm?@80A4A40`1<C4`205QHF0<0GUiN0P1aLG43
08B4Q0<0SHf=0P2KVi/30:NWY`80ZJVY0`2_[jl30;2`/080[Jf]0`2_[jl20;Fe]@<0/K6a0`2^[Zh2
0:b/[0D0[Zj^0`2a/K4L0<SPf0006`38h=P302DU9@809bLW200Y:BT30410@080>c/k0`14A4@204I6
AP<0@D510`0h>3P20492@P<0;bl_0P0n?Sh304Q8B080C4a<0`0[:b/302h^;P80;2`/0`0n?Sh202h^
;P<0;2`/0`0X:2P202TY:@<0:b/[1@0W9bL303Ph>080ATI60`1^KVh206MWI`<092@T0`0U9BD204];
B`<0G5aL0P0[:b/304U9B@<0Fe]K0P0d=3@302DU9@80Bd];0`0d=3@301hN7P8071`L0`0V9RH20492
@P<0I6AT0P29RHT309ZJVP<0Shn?0P1NGUh306IVIP80NGUi0`2LW9`30;^k^`80/k>c0`2UYJD20:RX
Z0<0[Jf]0`2a/K420;Fe]@<0^KVi0P2l_;`30<?3``<0aLG50P2l_;`30:n_[`80XJ6Q0`2FUYH309RH
V080WinO0`2VYZH20:n_[`<0]kNg0`2m_Kd20<30`0<0`L710P36a/H30<O7a`80_Kfm0`2][Jd309FE
U@80PH610`1mOGd207moO`<0QXJ60`2>SXh209BDU0<0Vi^K0P2HV9P309>CT`<0UYJF0P2GUiL309:B
TP80Rh^;0`28R8P308B4Q080O7al0`1bLW8206MWI`<0G5aL0`1?Cdl204E5A@<0AdM70P15ADD304A4
A0<0@d=30P18B4P304m?C`80EEEE0`1MGEd206][J`<0O7al0`2:RXX209NGU`<0Xj>S0P2/[:`;0:n_
[`80/;2`0`2a/K430:j^[PD0[:b/0P2][Jd30:j^[S@0b>3H0`0Q8B4202PX:0<09bLW0P0V9RH302XZ
:P<0?3`l0P1<C4`30492@P80CTi>0`1<C4`303/k>`80=CDe0`0Y:BT203/k>`<0Cdm?0P18B4P303De
=@<0<30`0P0[:b/303`l?080;Bd]1P0W9bL202PX:0<0:RXZ0P0W9bL302XZ:P<0;Rh^0P1:BTX306e]
K@80H61P0`0c<c<302PX:080CTi>0`1SHf<202PX:0<0Bd];0`1LG5`202/[:`<0=SHf0P1>CTh302PX
:0<08R8R0P0M7Ad302l_;`80>SXj0`1^KVh208f=S@<0WYjN0`21PH4206EUI@<0HV9R0P1iNGT309^K
V`<0_kno0P2a/K430:6QX@80Zj^[0`2_[jl30;2`/080]kNg0`2i^KT20;Zj^P<0`l?30`37alL20;fm
_@<0[jn_0P2KVi/309NGU`<0VYZJ0P2LW9`30:^[Z`80[:b/0`2l_;`30;fm_@80^[Zj0`36a/H50<?3
``80`<300`2i^KT309:BTP80Ng]k0`1mOGd208B4Q0<0RHV90`2?Shl209JFUP<0W9bL1@2FUYH509NG
U`<0U9BD0P2ATI4308b<S0<0Q8B40P1mOGd307AdM080J6QX0`1LG5`304];B`80@d=30`0k>c/204I6
APH0?Cdm0P14A4@304a<C080F5QH0`1NGUh2075aL@<0Q8B40`2=SHd209^KV`<0YjNW0P2YZJT30:n_
[`<0/;2`0P2][Jd30:n_[`80]KFe0`2a/K430:j^[P80[:b/1@2^[Zh30;6a/A`0b>3H000K0<SPf0<0
92@T0P0Y:BT302h^;P80:RXZ0`0X:2P302`/;080=SHf0`15ADD204m?C`<0A4A40`0g=cL203@d=0<0
>3Ph0P12@T8304U9B@80>c/k0`0_;bl302d];@80;bl_0`0b<S8203Hf=P<0<30`0`0[:b/202`/;0<0
;bl_0P0Z:RX302TY:@<0ATI60P1JFUX307=cL`80@d=30`1:BTX303De=@80ATI60`1LG5`202HV9P<0
GEeM0`1IFET202HV9P<08b<S0P1FEUH303Ti>@<071`L0P0N7Qh302TY:@80;bl_0`0m?Cd2075aL@<0
UiNG0`2VYZH206UYJ@<0GEeM0P1JFUX308:2PP<0Zj^[0P2c/k<30;2`/080[Jf]0`2YZJT30:f][@80
/[:b0`2d];@20;Ng]`<0_kno0`35aLD20<30`0<0][Jf0P2WYjL309ZJVP<0UiNG0P2JVYX30:6QX@80
ZZZZ0`2d];@30;fm_@D0_[jn0P2o_kl30<71`@D0alO70`2][Jd2096AT@<0PH610P1hN7P307]kN`<0
Ph>30P2:RXX309:BTP80TI6A0`2>SXh308b<S080RHV90`21PH4207QhN0<0M7Ad0`1`L70206YZJP<0
Hf=S0P1HF5P304i>CP<0@d=30P0l?3`30451@@D0BDU90`1<C4`205YJFP<0JFUY0P1bLW8307alO080
Shn?0`2PX:030:NWY`80Zj^[0`2`/;020;>c/`<0/K6a0`2_[jl20;2`/0<0/k>c0P2d];@30;Fe]@<0
/[:b0P2`/;030:j^[PD0[Jf]=038h=P302@T9080:b/[0`0d=3@202<S8`<0:RXZ0`0d=3@203De=@<0
?3`l0P1FEUH30492@P<0<S8b0P0k>c/303@d=080AdM70`16ATH203Ti>@<0;bl_0`0Z:RX202`/;0<0
>SXj0P0g=cL302l_;`<0<S8b0P0[:b/5030`<0<0;2`/0`12@T82061PH0<0J6QX0P1>CTh304I6AP<0
<S8b0P0l?3`3061PH080;Rh^0`1KFe/305=CD`809BDU0`0];Bd205EEE@<0<C4a0`0O7al202LW9`<0
9BDU0P0S8b<303hn?P80MGEe0`2GUiL309nOW`80KVi^0`1KFe/2061PH0<0Ng]k0`2ZZZX20;Vi^@<0
[Zj^0P2VYZH30:f][@<0[:b/0P2d];@30;:b/P80^;Rh0`30`<030<;2`P80a<C40`2e]KD20:FUY@<0
VYZJ0`2LW9`209RHV0<0WinO0P2XZ:P30;Jf]P<0_;bl0P2k^k/30;fm_@80`/;20`33`l<20<;2`P<0
`L710`2j^[X209VIV@<0NGUi0P1fMWH307YjNP<0PX:20P29RHT3092@T080S8b<0`2>SXh308f=S@80
RHV90`1oOgl207UiN@<0MGEe0`1^KVh206][J`<0I6AT0P1KFe/3051@D0D0?clo0`14A4@204M7A`<0
BDU90`1;Bd/205UIF@<0JVYZ0P1_Kfl307YjNP80SHf=0`2NWYh30:FUY@80Z:RX0`2`/;020;>c/`<0
/;2`0`2_[jl20;6a/@<0/k>c0P2d];@30;>c/`<0];Bd0P2`/;080:b/[1`0b>3H000K0<SPf0<092@T
0P0Y:BT302h^;P80:RXZ0`0X:2P302`/;080=SHf0`15ADD204m?C`<0A4A40`0g=cL203@d=0<0>3Ph
0P12@T8304U9B@80>c/k0`0_;bl302d];@80;bl_0`0b<S8203Hf=P<0<30`0`0[:b/202`/;0<0;bl_
0P0Z:RX302TY:@<0ATI60P1JFUX307=cL`80@d=30`1:BTX303De=@80ATI60`1LG5`202HV9P<0GEeM
0`1IFET202HV9P<08b<S0P1FEUH303Ti>@<071`L0P0N7Qh302TY:@80;bl_0`0m?Cd2075aL@<0UiNG
0`2VYZH206UYJ@<0GEeM0P1JFUX308:2PP<0Zj^[0P2c/k<30;2`/080[Jf]0`2YZJT30:f][@80/[:b
0`2d];@20;Ng]`<0_kno0`35aLD20<30`0<0][Jf0P2WYjL309ZJVP<0UiNG0P2JVYX30:6QX@80ZZZZ
0`2d];@30;fm_@D0_[jn0P2o_kl30<71`@D0alO70`2][Jd2096AT@<0PH610P1hN7P307]kN`<0Ph>3
0P2:RXX309:BTP80TI6A0`2>SXh308b<S080RHV90`21PH4207QhN0<0M7Ad0`1`L70206YZJP<0Hf=S
0P1HF5P304i>CP<0@d=30P0l?3`30451@@D0BDU90`1<C4`205YJFP<0JFUY0P1bLW8307alO080Shn?
0`2PX:030:NWY`80Zj^[0`2`/;020;>c/`<0/K6a0`2_[jl20;2`/0<0/k>c0P2d];@30;Fe]@<0/[:b
0P2`/;030:j^[PD0[Jf]=038h=P302@T9080:b/[0`0d=3@202<S8`<0:RXZ0`0d=3@203De=@<0?3`l
0P1FEUH30492@P<0<S8b0P0k>c/303@d=080AdM70`16ATH203Ti>@<0;bl_0`0Z:RX202`/;0<0>SXj
0P0g=cL302l_;`<0<S8b0P0[:b/5030`<0<0;2`/0`12@T82061PH0<0J6QX0P1>CTh304I6AP<0<S8b
0P0l?3`3061PH080;Rh^0`1KFe/305=CD`809BDU0`0];Bd205EEE@<0<C4a0`0O7al202LW9`<09BDU
0P0S8b<303hn?P80MGEe0`2GUiL309nOW`80KVi^0`1KFe/2061PH0<0Ng]k0`2ZZZX20;Vi^@<0[Zj^
0P2VYZH30:f][@<0[:b/0P2d];@30;:b/P80^;Rh0`30`<030<;2`P80a<C40`2e]KD20:FUY@<0VYZJ
0`2LW9`209RHV0<0WinO0P2XZ:P30;Jf]P<0_;bl0P2k^k/30;fm_@80`/;20`33`l<20<;2`P<0`L71
0`2j^[X209VIV@<0NGUi0P1fMWH307YjNP<0PX:20P29RHT3092@T080S8b<0`2>SXh308f=S@80RHV9
0`1oOgl207UiN@<0MGEe0`1^KVh206][J`<0I6AT0P1KFe/3051@D0D0?clo0`14A4@204M7A`<0BDU9
0`1;Bd/205UIF@<0JVYZ0P1_Kfl307YjNP80SHf=0`2NWYh30:FUY@80Z:RX0`2`/;020;>c/`<0/;2`
0`2_[jl20;6a/@<0/k>c0P2d];@30;>c/`<0];Bd0P2`/;080:b/[1`0b>3H000K0<SPf0<08R8R0P0/
;2`303Hf=P80;bl_0`0X:2P302/[:`80=CDe0`0k>c/203lo?`<0>3Ph0`0b<S8203<c<`D0>c/k0`0o
?cl203<c<`<0;Rh^0`0/;2`202h^;P<0<S8b0P0j>SX303<c<`<0:b/[0P0/;2`3038b<P80@D510`1@
D50304Q8B080EEEE0`1GEeL203Ph>0<0=cLg0`0e=CD203Lg=`<0H61P0P0g=cL306EUI@<0Cdm?0P0Y
:BT302PX:080GemO0`0n?Sh3020P80807AdM0`0S8b<2024Q8@<0:b/[0P1:BTX308N7Q`<0WYjN0P26
QXH306a/K080EeMG0`1[Jf/308Z:RP80YZJV0`2j^[X20;Bd]0<0ZJVY0`2ZZZX20:j^[P<0/;2`0P2c
/k<30;^k^`<0`L710P30`<030;Zj^P80ZZZZ0`2KVi/309RHV080VYZJ0`2MWId20:>SX`<0[jn_0`2k
^k/20;jn_P<0_kno0P31`L430<?3``D0aLG50`3=cLd20<W9b@<0WYjN0P1`L70306EUI@<0IVIV0P1^
KVh3075aL@80MWIf0`1iNGT307QhN080M7Ad0`1_Kfl206YZJP<0IfMW0`1TI6@206=SH`<0HF5Q0P1H
F5P3051@D0<0Cdm?0P1BDU8305QHF080H61P0`1TI6@306UYJ@80MWIf0`24Q8@208f=S@<0UIFE0P2Q
XJ430:^[Z`<0/;2`0P2b/[830;Fe]@80][Jf0`2d];@50;6a/@P0/k>c0`2b/[820;6a/@<0[jn_1@2/
[:`d0<SPf0D0:2PX0`0f=SH202h^;P<09bLW1@0`<30302l_;`80>3Ph0`0g=cL303Ph>080=3@d0`0o
?cl204Y:BP<0>CTi0P0c<c<302TY:@<0<30`0P0_;bl303Hf=P80>CTi0`0];Bd302/[:`809bLW0`0_
;bl204Q8B0<0ATI60`1?Cdl205YJFP<0DU9B0P0b<S8603dm?@80=3@d0`1GEeL203<c<`<0JFUY0`1>
CTh202HV9P<0;bl_0P1LG5`303@d=0<07AdM1@0W9bL2020P80<0:RXZ0P1<C4`308B4Q0<0YZJV0P23
Ph<306a/K080G5aL0`1TI6@308R8R080/;2`0`2o_kl20:j^[P<0ZJVY0`2ZZZX20:b/[0<0[jn_0P2e
]KD30;Rh^0<0_[jn0P32`/830;^k^`80ZJVY0`2GUiL309ZJVP80V9RH1@2NWYh30;Jf]P<0^[Zj1@2n
_[h20<;2`P<0a<C40P32`/830<71`@<0`/;20P31`L4309jNWP80MWIf0`1VIVH306QXJ080KVi^0`1f
MWH207QhN0<0NGUi0`1gMgL207EeM@<0K6a/0P1VIVH3061PH0<0IfMW0P1UIFD305]KF`80De=C0`1=
CDd305MGE`80EEEE0`1MGEd206EUI@<0Jf][0`1bLW8207emO@<0QHF50P2BTY8309RHV080WinO0`2W
YjL30:j^[P80/;2`0`2i^KT50;Fe]@<0/;2`0P2][Jd30;6a/@80/k>c0`2b/[830;6a/@D0[jn_0P2]
[Jd30:ZZZQ`0b>3H000K0<SPf0<08R8R0P0/;2`303Hf=P80;bl_0`0X:2P302/[:`80=CDe0`0k>c/2
03lo?`<0>3Ph0`0b<S8203<c<`D0>c/k0`0o?cl203<c<`<0;Rh^0`0/;2`202h^;P<0<S8b0P0j>SX3
03<c<`<0:b/[0P0/;2`3038b<P80@D510`1@D50304Q8B080EEEE0`1GEeL203Ph>0<0=cLg0`0e=CD2
03Lg=`<0H61P0P0g=cL306EUI@<0Cdm?0P0Y:BT302PX:080GemO0`0n?Sh3020P80807AdM0`0S8b<2
024Q8@<0:b/[0P1:BTX308N7Q`<0WYjN0P26QXH306a/K080EeMG0`1[Jf/308Z:RP80YZJV0`2j^[X2
0;Bd]0<0ZJVY0`2ZZZX20:j^[P<0/;2`0P2c/k<30;^k^`<0`L710P30`<030;Zj^P80ZZZZ0`2KVi/3
09RHV080VYZJ0`2MWId20:>SX`<0[jn_0`2k^k/20;jn_P<0_kno0P31`L430<?3``D0aLG50`3=cLd2
0<W9b@<0WYjN0P1`L70306EUI@<0IVIV0P1^KVh3075aL@80MWIf0`1iNGT307QhN080M7Ad0`1_Kfl2
06YZJP<0IfMW0`1TI6@206=SH`<0HF5Q0P1HF5P3051@D0<0Cdm?0P1BDU8305QHF080H61P0`1TI6@3
06UYJ@80MWIf0`24Q8@208f=S@<0UIFE0P2QXJ430:^[Z`<0/;2`0P2b/[830;Fe]@80][Jf0`2d];@5
0;6a/@P0/k>c0`2b/[820;6a/@<0[jn_1@2/[:`d0<SPf0D0:2PX0`0f=SH202h^;P<09bLW1@0`<303
02l_;`80>3Ph0`0g=cL303Ph>080=3@d0`0o?cl204Y:BP<0>CTi0P0c<c<302TY:@<0<30`0P0_;bl3
03Hf=P80>CTi0`0];Bd302/[:`809bLW0`0_;bl204Q8B0<0ATI60`1?Cdl205YJFP<0DU9B0P0b<S86
03dm?@80=3@d0`1GEeL203<c<`<0JFUY0`1>CTh202HV9P<0;bl_0P1LG5`303@d=0<07AdM1@0W9bL2
020P80<0:RXZ0P1<C4`308B4Q0<0YZJV0P23Ph<306a/K080G5aL0`1TI6@308R8R080/;2`0`2o_kl2
0:j^[P<0ZJVY0`2ZZZX20:b/[0<0[jn_0P2e]KD30;Rh^0<0_[jn0P32`/830;^k^`80ZJVY0`2GUiL3
09ZJVP80V9RH1@2NWYh30;Jf]P<0^[Zj1@2n_[h20<;2`P<0a<C40P32`/830<71`@<0`/;20P31`L43
09jNWP80MWIf0`1VIVH306QXJ080KVi^0`1fMWH207QhN0<0NGUi0`1gMgL207EeM@<0K6a/0P1VIVH3
061PH0<0IfMW0P1UIFD305]KF`80De=C0`1=CDd305MGE`80EEEE0`1MGEd206EUI@<0Jf][0`1bLW82
07emO@<0QHF50P2BTY8309RHV080WinO0`2WYjL30:j^[P80/;2`0`2i^KT50;Fe]@<0/;2`0P2][Jd3
0;6a/@80/k>c0`2b/[830;6a/@D0[jn_0P2][Jd30:ZZZQ`0b>3H000K0<SPf0<08R8R0P0/;2`303Hf
=P80;bl_0`0X:2P302/[:`80=CDe0`0k>c/203lo?`<0>3Ph0`0b<S8203<c<`D0>c/k0`0o?cl203<c
<`<0;Rh^0`0/;2`202h^;P<0<S8b0P0j>SX303<c<`<0:b/[0P0/;2`3038b<P80@D510`1@D50304Q8
B080EEEE0`1GEeL203Ph>0<0=cLg0`0e=CD203Lg=`<0H61P0P0g=cL306EUI@<0Cdm?0P0Y:BT302PX
:080GemO0`0n?Sh3020P80807AdM0`0S8b<2024Q8@<0:b/[0P1:BTX308N7Q`<0WYjN0P26QXH306a/
K080EeMG0`1[Jf/308Z:RP80YZJV0`2j^[X20;Bd]0<0ZJVY0`2ZZZX20:j^[P<0/;2`0P2c/k<30;^k
^`<0`L710P30`<030;Zj^P80ZZZZ0`2KVi/309RHV080VYZJ0`2MWId20:>SX`<0[jn_0`2k^k/20;jn
_P<0_kno0P31`L430<?3``D0aLG50`3=cLd20<W9b@<0WYjN0P1`L70306EUI@<0IVIV0P1^KVh3075a
L@80MWIf0`1iNGT307QhN080M7Ad0`1_Kfl206YZJP<0IfMW0`1TI6@206=SH`<0HF5Q0P1HF5P3051@
D0<0Cdm?0P1BDU8305QHF080H61P0`1TI6@306UYJ@80MWIf0`24Q8@208f=S@<0UIFE0P2QXJ430:^[
Z`<0/;2`0P2b/[830;Fe]@80][Jf0`2d];@50;6a/@P0/k>c0`2b/[820;6a/@<0[jn_1@2/[:`d0<SP
f0D0:2PX0`0f=SH202h^;P<09bLW1@0`<30302l_;`80>3Ph0`0g=cL303Ph>080=3@d0`0o?cl204Y:
BP<0>CTi0P0c<c<302TY:@<0<30`0P0_;bl303Hf=P80>CTi0`0];Bd302/[:`809bLW0`0_;bl204Q8
B0<0ATI60`1?Cdl205YJFP<0DU9B0P0b<S8603dm?@80=3@d0`1GEeL203<c<`<0JFUY0`1>CTh202HV
9P<0;bl_0P1LG5`303@d=0<07AdM1@0W9bL2020P80<0:RXZ0P1<C4`308B4Q0<0YZJV0P23Ph<306a/
K080G5aL0`1TI6@308R8R080/;2`0`2o_kl20:j^[P<0ZJVY0`2ZZZX20:b/[0<0[jn_0P2e]KD30;Rh
^0<0_[jn0P32`/830;^k^`80ZJVY0`2GUiL309ZJVP80V9RH1@2NWYh30;Jf]P<0^[Zj1@2n_[h20<;2
`P<0a<C40P32`/830<71`@<0`/;20P31`L4309jNWP80MWIf0`1VIVH306QXJ080KVi^0`1fMWH207Qh
N0<0NGUi0`1gMgL207EeM@<0K6a/0P1VIVH3061PH0<0IfMW0P1UIFD305]KF`80De=C0`1=CDd305MG
E`80EEEE0`1MGEd206EUI@<0Jf][0`1bLW8207emO@<0QHF50P2BTY8309RHV080WinO0`2WYjL30:j^
[P80/;2`0`2i^KT50;Fe]@<0/;2`0P2][Jd30;6a/@80/k>c0`2b/[830;6a/@D0[jn_0P2][Jd30:ZZ
ZQ`0b>3H000K0<SPf0<08B4Q0P0^;Rh303/k>`80<c<c0`0Z:RX302l_;`80=CDe0`0b<S8202h^;P<0
;Bd]0`0^;Rh203De=@<0>SXj0P0f=SH303<c<`80;bl_0`0/;2`302/[:`80;Bd]0`0d=3@203Xj>P<0
<c<c0`0/;2`2034a<@<0>3Ph0P0e=CD303Hf=P<09RHV0P1?Cdl303dm?@80<30`0`0/;2`303Hf=P80
;2`/0`1RHV8204];B`<0IfMW0`14A4@202l_;`<0:b/[0P1RHV8304E5A@<0:BTY1@0Q8B4201/K6`<0
8b<S0P0V9RH306m_K`<0RXZ:0P2MWId30861P@80HF5Q0`1NGUh306YZJP80Ti>C0`2j^[X20;Rh^0<0
[Jf]1@2ZZZX30:b/[080[jn_0`2f][H30;fm_@80_kno0`2l_;`20:b/[0<0W9bL0`2JVYX509^KV`80
WIfM0`2[Zj/30;Vi^@80_[jn0`31`L420<?3``D0a<C40`32`/830;no_`80^k^k0`2j^[X20;2`/0<0
P8200`1@D50205aLG0<0EEEE0P1MGEd606=SH`L0HF5Q1P1PH60206ATI0<0IfMW0P1PH60305aLG0<0
IFEU0P1`L70307EeM@80NWYj0`21PH4308V9R@80Ti>C0`2LW9`20:>SX`<0Z:RX0P2/[:`30:n_[`<0
/[:b0P2d];@30;Jf]P80]kNg0`2e]KD30;>c/`D0/[:b0P2a/K430;2`/0<0/K6a0P2b/[830:n_[`80
[Jf]0`2/[:`d0<SPf0<09RHV0P0[:b/30451@@D0;2`/0`0^;Rh203Ph>0<0=3@d0P0c<c<303Ti>@<0
:RXZ0P0d=3@303De=@80>SXj0`0`<30202/[:`<0;bl_0`0Z:RX202`/;0<0=CDe0P0j>SX303Lg=`<0
;Rh^0P0b<S8303Ph>080>CTi0`0e=CD302h^;P80BTY:0`16ATH202l_;`<0:b/[0`0/;2`203Ph>0<0
H61P0P19BDT306a/K0<0?Shn0P0`<303038b<P80GemO0`12@T8302XZ:P809BDU0`0P820201dM7@<0
8b<S0P0[:b/306e]K@<0Rh^;0P2IVIT308:2PP80Hf=S0`1MGEd306a/K080Shn?0`2e]KD20<71`@<0
[:b/0`2UYJD20:b/[0<0[Zj^0P2c/k<30;:b/P<0_kno0P30`<030;^k^`80[Jf]0`2JVYX309fMW@80
VIVI0`2LW9`209fMW@<0[Jf]0`2h^;P20;fm_@<0`<300P33`l<30<C4a080a/K60`35aLD50<30`0<0
_kno0P2ZZZX307QhN0D0EEEE0`1GEeL205QHF0H0HF5Q0P1PH60306IVIP80Hf=S0`1KFe/3061PH080
J6QX1@1TI6@305IFEP<0IVIV0P1^KVh307=cL`80NWYj0`1lO7`308J6QP80T92@0`2LW9`20:>SX`<0
YZJV0P2][Jd30:n_[`D0/k>c1@2f][H30;Fe]@<0/K6a0P2b/[830;>c/`D0/;2`0`2_[jl20;Fe]@<0
[Jf]0P2ZZZX30:n_[a`0b>3H000K0<SPf0<08B4Q0P0^;Rh303/k>`80<c<c0`0Z:RX302l_;`80=CDe
0`0b<S8202h^;P<0;Bd]0`0^;Rh203De=@<0>SXj0P0f=SH303<c<`80;bl_0`0/;2`302/[:`80;Bd]
0`0d=3@203Xj>P<0<c<c0`0/;2`2034a<@<0>3Ph0P0e=CD303Hf=P<09RHV0P1?Cdl303dm?@80<30`
0`0/;2`303Hf=P80;2`/0`1RHV8204];B`<0IfMW0`14A4@202l_;`<0:b/[0P1RHV8304E5A@<0:BTY
1@0Q8B4201/K6`<08b<S0P0V9RH306m_K`<0RXZ:0P2MWId30861P@80HF5Q0`1NGUh306YZJP80Ti>C
0`2j^[X20;Rh^0<0[Jf]1@2ZZZX30:b/[080[jn_0`2f][H30;fm_@80_kno0`2l_;`20:b/[0<0W9bL
0`2JVYX509^KV`80WIfM0`2[Zj/30;Vi^@80_[jn0`31`L420<?3``D0a<C40`32`/830;no_`80^k^k
0`2j^[X20;2`/0<0P8200`1@D50205aLG0<0EEEE0P1MGEd606=SH`L0HF5Q1P1PH60206ATI0<0IfMW
0P1PH60305aLG0<0IFEU0P1`L70307EeM@80NWYj0`21PH4308V9R@80Ti>C0`2LW9`20:>SX`<0Z:RX
0P2/[:`30:n_[`<0/[:b0P2d];@30;Jf]P80]kNg0`2e]KD30;>c/`D0/[:b0P2a/K430;2`/0<0/K6a
0P2b/[830:n_[`80[Jf]0`2/[:`d0<SPf0<09RHV0P0[:b/30451@@D0;2`/0`0^;Rh203Ph>0<0=3@d
0P0c<c<303Ti>@<0:RXZ0P0d=3@303De=@80>SXj0`0`<30202/[:`<0;bl_0`0Z:RX202`/;0<0=CDe
0P0j>SX303Lg=`<0;Rh^0P0b<S8303Ph>080>CTi0`0e=CD302h^;P80BTY:0`16ATH202l_;`<0:b/[
0`0/;2`203Ph>0<0H61P0P19BDT306a/K0<0?Shn0P0`<303038b<P80GemO0`12@T8302XZ:P809BDU
0`0P820201dM7@<08b<S0P0[:b/306e]K@<0Rh^;0P2IVIT308:2PP80Hf=S0`1MGEd306a/K080Shn?
0`2e]KD20<71`@<0[:b/0`2UYJD20:b/[0<0[Zj^0P2c/k<30;:b/P<0_kno0P30`<030;^k^`80[Jf]
0`2JVYX309fMW@80VIVI0`2LW9`209fMW@<0[Jf]0`2h^;P20;fm_@<0`<300P33`l<30<C4a080a/K6
0`35aLD50<30`0<0_kno0P2ZZZX307QhN0D0EEEE0`1GEeL205QHF0H0HF5Q0P1PH60306IVIP80Hf=S
0`1KFe/3061PH080J6QX1@1TI6@305IFEP<0IVIV0P1^KVh307=cL`80NWYj0`1lO7`308J6QP80T92@
0`2LW9`20:>SX`<0YZJV0P2][Jd30:n_[`D0/k>c1@2f][H30;Fe]@<0/K6a0P2b/[830;>c/`D0/;2`
0`2_[jl20;Fe]@<0[Jf]0P2ZZZX30:n_[a`0b>3H000K0<SPf0<08B4Q0P0^;Rh303/k>`80<c<c0`0Z
:RX302l_;`80=CDe0`0b<S8202h^;P<0;Bd]0`0^;Rh203De=@<0>SXj0P0f=SH303<c<`80;bl_0`0/
;2`302/[:`80;Bd]0`0d=3@203Xj>P<0<c<c0`0/;2`2034a<@<0>3Ph0P0e=CD303Hf=P<09RHV0P1?
Cdl303dm?@80<30`0`0/;2`303Hf=P80;2`/0`1RHV8204];B`<0IfMW0`14A4@202l_;`<0:b/[0P1R
HV8304E5A@<0:BTY1@0Q8B4201/K6`<08b<S0P0V9RH306m_K`<0RXZ:0P2MWId30861P@80HF5Q0`1N
GUh306YZJP80Ti>C0`2j^[X20;Rh^0<0[Jf]1@2ZZZX30:b/[080[jn_0`2f][H30;fm_@80_kno0`2l
_;`20:b/[0<0W9bL0`2JVYX509^KV`80WIfM0`2[Zj/30;Vi^@80_[jn0`31`L420<?3``D0a<C40`32
`/830;no_`80^k^k0`2j^[X20;2`/0<0P8200`1@D50205aLG0<0EEEE0P1MGEd606=SH`L0HF5Q1P1P
H60206ATI0<0IfMW0P1PH60305aLG0<0IFEU0P1`L70307EeM@80NWYj0`21PH4308V9R@80Ti>C0`2L
W9`20:>SX`<0Z:RX0P2/[:`30:n_[`<0/[:b0P2d];@30;Jf]P80]kNg0`2e]KD30;>c/`D0/[:b0P2a
/K430;2`/0<0/K6a0P2b/[830:n_[`80[Jf]0`2/[:`d0<SPf0<09RHV0P0[:b/30451@@D0;2`/0`0^
;Rh203Ph>0<0=3@d0P0c<c<303Ti>@<0:RXZ0P0d=3@303De=@80>SXj0`0`<30202/[:`<0;bl_0`0Z
:RX202`/;0<0=CDe0P0j>SX303Lg=`<0;Rh^0P0b<S8303Ph>080>CTi0`0e=CD302h^;P80BTY:0`16
ATH202l_;`<0:b/[0`0/;2`203Ph>0<0H61P0P19BDT306a/K0<0?Shn0P0`<303038b<P80GemO0`12
@T8302XZ:P809BDU0`0P820201dM7@<08b<S0P0[:b/306e]K@<0Rh^;0P2IVIT308:2PP80Hf=S0`1M
GEd306a/K080Shn?0`2e]KD20<71`@<0[:b/0`2UYJD20:b/[0<0[Zj^0P2c/k<30;:b/P<0_kno0P30
`<030;^k^`80[Jf]0`2JVYX309fMW@80VIVI0`2LW9`209fMW@<0[Jf]0`2h^;P20;fm_@<0`<300P33
`l<30<C4a080a/K60`35aLD50<30`0<0_kno0P2ZZZX307QhN0D0EEEE0`1GEeL205QHF0H0HF5Q0P1P
H60306IVIP80Hf=S0`1KFe/3061PH080J6QX1@1TI6@305IFEP<0IVIV0P1^KVh307=cL`80NWYj0`1l
O7`308J6QP80T92@0`2LW9`20:>SX`<0YZJV0P2][Jd30:n_[`D0/k>c1@2f][H30;Fe]@<0/K6a0P2b
/[830;>c/`D0/;2`0`2_[jl20;Fe]@<0[Jf]0P2ZZZX30:n_[a`0b>3H000K0<SPf0<08B4Q0P0[:b/3
03Lg=`80<c<c0`0^;Rh303Hf=P80?Cdm0`0k>c/203Lg=`<0=3@d0`0a<C4503@d=080@410200Z:RX5
02TY:@<0;Bd]0P0a<C4302l_;`<0;Bd]0P0a<C4303Hf=P80=CDe0`0h>3P302TY:@80EEEE0`0g=cL2
02/[:`<09BDU0`0`<30202DU9@<0GemO0P1JFUX306EUI@<0@d=30P0Y:BT302<S8`80GEeM0`1IFET3
03De=@D0=SHf0P0Z:RX302<S8`807alO0`17AdL306i^KP80UIFE0`2@T90207moO`<0J6QX0`1KFe/2
07UiN@<0WYjN0P2d];@30;no_`<0];Bd0P2VYZH30:NWY`80[:b/0`2b/[830;Ng]`80^[Zj0`2i^KT2
0:f][@<0X:2P0`2KVi/209ZJVP<0VIVI0P2KVi/30:NWY`<0]KFe0P2l_;`30<71`@D0`/;21@33`l<3
0<;2`P80_kno0`2m_Kd20;Ng]`<0YJFU0`2@T90204M7A`<0B4Q80P14A4@304i>CP<0EUIF0P1OGel3
06ATI080J6QX0`1YJFT306][J`80LG5a0`1hN7P507MgM`<0OWin0P25QHD308R8R080S8b<0`2CTi<3
09ZJVP80X:2P0`2VYZH20:ZZZP<0[Jf]0P2_[jl30;6a/@<0/[:b0P2d];@30;Jf]P80]kNg0`2e]KD3
0;>c/`80/K6a202`/;050;6a/@D0/;2`0`2_[jld0<SPf0<08b<S0P0V9RH303dm?@80<S8b0`0c<c<3
03Ti>@80?clo0`0i>CT203@d=0P0;bl_0`0c<c<20410@0<0<S8b0P0X:2P3034a<@<0:BTY0P0Z:RX3
02/[:`80=3@d0`0/;2`302h^;P80=CDe0`0c<c<203De=@<0<C4a0`0/;2`204M7A`<0=cLg0P0Z:RX6
02TY:@80<30`0`1UIFD205EEE@<0K6a/0`0i>CT202TY:@<0<S8b1@1KFe/303Lg=`80<S8b0`0^;Rh2
02TY:@<07QhN0P0S8b<303/k>`<0NGUi0P2<S8`30:2PX080N7Qh0`1OGel306ATI080LW9b0`2GUiL2
0<K6aP<0^[Zj0`2YZJT20:^[Z`<0YZJV0P2WYjL30;2`/0D0^KVi0`2g]kL20:^[Z`<0Xj>S0`2JVYX2
09^KV`<0UYJF0P2KVi/30:BTY0<0/k>c0P2m_Kd30<?3``80`L710`30`<020<;2`P<0aLG50`30`<02
0;jn_P<0^k^k0P2i^KT30;2`/0<0RHV90P1?Cdl304E5A@80AdM70`1EEED305UIF@80GEeM0`1UIFD2
06YZJP<0KVi^0`1XJ6P207AdM0<0NGUi0P1mOGd307inOP<0OGem0P24Q8@308N7Q`80RHV90`2DU9@3
09RHV080WYjN1@2VYZH30:b/[080/K6a0`2_[jl30;Fe]@D0];Bd0P2g]kL60;Fe]@80];Bd0`2^[Zh5
0;>c/`D0[jn_0`2b/[820:n_[`<0];Bd7038h=P001/0b>3H0`0Q8B4202/[:`<0=cLg0P0c<c<302h^
;P<0=SHf0P0m?Cd303/k>`80=cLg0`0d=3@3034a<@D0=3@d0P10@40802XZ:PD0:BTY0`0];Bd2034a
<@<0;bl_0`0];Bd2034a<@<0=SHf0P0e=CD303Ph>0<0:BTY0P1EEED303Lg=`80:b/[0`0U9BD3030`
<0809BDU0`1OGel205YJFP<0IFEU0`13@d<202TY:@<08b<S0P1MGEd305UIF@<0=CDe1@0f=SH202XZ
:P<08b<S0P0O7al304M7A`<0KVi^0P2EUID3092@T080Ogmo0`1XJ6P305]KF`80NGUi0`2NWYh20;Bd
]0<0_kno0`2d];@20:JVYP<0YjNW0P2/[:`30;:b/P<0]kNg0P2j^[X30;Vi^@80[Jf]0`2PX:0309^K
V`80VYZJ0`2IVIT209^KV`<0YjNW0`2e]KD20;bl_0<0`L711@32`/850<?3``<0`/;20P2o_kl30;fm
_@80]kNg0`2UYJD3092@T080AdM70`18B4P204A4A0<0CTi>0`1FEUH205mOG`<0I6AT0P1XJ6P306UY
J@<0Jf][0P1aLG4307QhN0D0MgMg0`1nOWh208F5Q@<0R8R80P2<S8`309>CT`<0VYZJ0P2PX:030:JV
YP80ZZZZ0`2][Jd20:n_[`<0/K6a0`2b/[820;Bd]0<0][Jf0P2g]kL30;Fe]@<0/k>c0P2a/K480;2`
/0D0/K6a1@2`/;030:n_[c@0b>3H0`0S8b<202HV9P<0?Cdm0P0b<S8303<c<`<0>CTi0P0o?cl303Ti
>@80=3@d200_;bl303<c<`80@4100`0b<S8202PX:0<0<C4a0`0Y:BT202XZ:P<0:b/[0P0d=3@302`/
;0<0;Rh^0P0e=CD303<c<`80=CDe0`0a<C4302`/;080AdM70`0g=cL202XZ:PH0:BTY0P0`<30306EU
I@80EEEE0`1/K6`303Ti>@80:BTY0`0b<S8505]KF`<0=cLg0P0b<S8302h^;P80:BTY0`0N7Qh202<S
8`<0>c/k0`1iNGT208b<S0<0X:2P0P1hN7P305mOG`<0I6AT0P1bLW8309NGU`80a/K60`2j^[X30:VY
Z@80Zj^[0`2VYZH20:NWY`<0/;2`1@2i^KT30;Ng]`80Zj^[0`2SXj<309ZJVP80Vi^K0`2FUYH209^K
V`<0Y:BT0`2c/k<20;fm_@<0`l?30P31`L430<30`080`/;20`35aLD30<30`080_[jn0`2k^k/20;Vi
^@<0/;2`0`29RHT204m?C`<0ADE50P17AdL305EEE@<0FEUI0P1MGEd306EUI@80JVYZ0`1^KVh306QX
J080M7Ad0`1iNGT207emO@<0OWin0`1mOGd208B4Q0<0QhN70P29RHT309BDU0<0V9RH0P2NWYh50:JV
YP<0[:b/0P2a/K430:n_[`<0]KFe1@2d];@20;Ng]`H0]KFe0P2d];@30:j^[PD0/k>c1@2_[jl30;:b
/P80[jn_0`2d];@L0<SPf0006`38h=P3020P8080:2PX0`0b<S82034a<@<0<S8b0`0k>c/204A4A0<0
@d=30P10@40303hn?P<0>c/k0P0h>3P3038b<P80C4a<0`0W9bL202XZ:P<0:b/[0`0X:2P202HV9P<0
9bLW0P0Y:BT302`/;0<0;bl_0P0b<S8303De=@80<S8b0`0e=CD302d];@80FUYJ0`0o?cl202XZ:P<0
8b<S0`0Z:RX2028R8P<0F5QH1@1TI6@30492@P8092@T0`0K6a/2059BDP<0K6a/0`16ATH204];B`<0
B4Q80P0i>CT302TY:@808R8R0`0U9BD3051@D080OWin0`2EUID209^KV`<0NGUi0`1HF5P2069RHP<0
OGem0P2WYjL30<W9b@<0^k^k0P2UYJD30:BTY080Z:RX0`2][Jd30;:b/PD0]KFe0P2][Jd30:BTY0<0
WIfM0P2IVIT309RHV080Vi^K0`2UYJD30;6a/@80^[Zj1@30`<030;jn_P80`L710`34a<@30<30`080
^k^k1@2l_;`30;fm_@<0];Bd0P2OWil306QXJ080DU9B0`17AdL305=CD`80IFEU0`1^KVh207AdM0<0
N7Qh0`1lO7`208>3P`<0RXZ:0P2?Shl309>CT`<0U9BD0P2EUID309NGU`80VIVI0`2OWil30:FUY@80
Z:RX0`2ZZZX20:b/[0<0[Jf]0P2_[jl80;6a/@<0];Bd0P2f][H30;Fe]@<0/[:b0P2a/K430:n_[`80
/;2`202a/K430;:b/PD0/k>c=038h=P302HV9P808R8R0`0`<30203Lg=`<0<S8b0`0e=CD204Q8B0<0
CDe=0P16ATH303hn?P<0?3`l0P0b<S8303hn?P80@d=30`0];Bd202PX:0<0;2`/0`0X:2P202DU9@<0
:RXZ0P0X:2P302d];@<0<C4a0P0b<S8303<c<`80>SXj0`0c<c<302l_;`80EeMG0`17AdL502@T90<0
9RHV0P0/;2`305ADE080IFEU0`1/K6`303`l?0D08b<S0P1:BTX306e]K@<0@D510P15ADD3051@D080
>c/k0`0W9bL2024Q8@<0:RXZ0`15ADD207emO@<0WIfM0P2GUiL307AdM0<0Fe]K0P1UIFD307emO@80
ZZZZ0`36a/H30;Vi^@80Y:BT0`2XZ:P20:NWY`<0Zj^[1@2c/k<30;Ng]`80Zj^[0`2VYZH309ZJVP80
W9bL0`2FUYH209fMW@<0YZJV0`2b/[820;Rh^0P0`<300P2n_[h30<K6aP<0_kno0P2n_[h30;no_`80
^k^k0`2f][H30;Rh^080Xj>S0`1]KFd204i>CP<0BTY:0`1BDU8206IVIP<0MGEe0P1^KVh607UiN@80
QXJ60`29RHT208j>SP<0Ti>C0`2ATI4209BDU0D0V9RH0`2NWYh30:BTY080Zj^[0`2ZZZX50:j^[P80
ZZZZ0`2a/K430;Bd]080/;2`0`2d];@20;Jf]P<0];Bd0`2`/;020;Bd]0D0[Zj^0`2a/K430;2`/080
/K6a0`2b/[820:n_[`<0]KFe7038h=P001/0b>3H0`0P820202PX:0<0<S8b0P0a<C43038b<P<0>c/k
0P14A4@304=3@`80@4100`0n?Sh303/k>`80>3Ph0`0b<S8204a<C0<09bLW0P0Z:RX302/[:`<0:2PX
0P0V9RH302LW9`80:BTY0`0/;2`302l_;`80<S8b0`0e=CD2038b<P<0=CDe0`0];Bd205YJFP<0?clo
0P0Z:RX302<S8`<0:RXZ0P0R8R8305QHF0D0I6AT0`12@T8202@T90<06a/K0P1BDU8306a/K0<0ATI6
0P1;Bd/304Q8B080>CTi0`0Y:BT2028R8P<09BDU0`1@D50207inOP<0UIFE0P2KVi/307UiN@<0F5QH
0P1RHV8307emO@80YjNW0`39bLT30;^k^`80YJFU0`2TY:@20:RXZ0<0[Jf]0`2b/[850;Fe]@80[Jf]
0`2TY:@309fMW@80VIVI0`2HV9P209^KV`<0YJFU0`2a/K420;Zj^PD0`<300`2n_[h20<71`@<0a<C4
0`30`<020;^k^`D0_;bl0`2m_Kd30;Bd]080WinO0`1XJ6P2059BDP<0AdM70`1CDe<206EUI@<0KVi^
0P1dM7@307QhN0<0O7al0P23Ph<308Z:RP80Shn?0`2CTi<309BDU080UIFE0`2GUiL209VIV@<0WinO
0`2UYJD20:RXZ0<0ZZZZ0P2/[:`30:f][@80[jn_202a/K430;Bd]080][Jf0`2e]KD30;:b/P80/K6a
0`2_[jl20;2`/0P0/K6a0`2b/[850;>c/c@0b>3H0`0V9RH2028R8P<0<30`0P0g=cL3038b<P<0=CDe
0P18B4P304e=C@80ATI60`0n?Sh303`l?080<S8b0`0n?Sh204=3@`<0;Bd]0P0X:2P302`/;0<0:2PX
0P0U9BD302XZ:P80:2PX0`0];Bd3034a<@80<S8b0`0c<c<203Xj>P<0<c<c0`0_;bl205MGE`<0AdM7
1@0T92@302HV9P80;2`/0`1DE5@206EUI@<0K6a/0`0l?3`502<S8`80BTY:0`1]KFd30451@@80ADE5
0`1@D50203/k>`<09bLW0P0Q8B4302XZ:P<0ADE50P1mOGd309fMW@80UiNG0`1dM7@305]KF`80IFEU
0`1mOGd20:ZZZP<0a/K60`2i^KT20:BTY0<0Z:RX0P2WYjL30:^[Z`D0/k>c0`2g]kL20:^[Z`<0YZJV
0`2JVYX209bLW0<0UYJF0P2MWId30:JVYP<0/[:b0P2h^;P80<30`080_[jn0`36a/H30;no_`80_[jn
0`2o_kl20;^k^`<0][Jf0`2h^;P20:>SX`<0KFe]0P1>CTh304Y:BP<0DU9B0P1VIVH307EeM@80KVi^
1P1iNGT208J6QP<0RHV90P2>SXh309>CT`<0TI6A0P2DU9@509RHV0<0WYjN0`2TY:@20:^[Z`<0ZZZZ
1@2^[Zh20:ZZZP<0/K6a0`2d];@20;2`/0<0];Bd0P2f][H30;Bd]0<0/;2`0P2d];@50:j^[P<0/K6a
0`2`/;020;6a/@<0/[:b0P2_[jl30;Fe]A`0b>3H000K0<SPf0<0820P0P0X:2P3038b<P80<C4a0`0b
<S8303/k>`80A4A40`13@d<20410@0<0?Shn0`0k>c/203Ph>0<0<S8b0P1<C4`302LW9`80:RXZ0`0[
:b/302PX:0809RHV0`0W9bL202TY:@<0;2`/0`0_;bl2038b<P<0=CDe0P0b<S8303De=@<0;Bd]0P1J
FUX303lo?`80:RXZ0`0S8b<302XZ:P808R8R0`1HF5P506ATI0<0@T920P0T92@301/K6`80DU9B0`1/
K6`304I6AP80Bd];0`18B4P203Ti>@<0:BTY0P0R8R8302DU9@<0D51@0P1nOWh309FEU@80Vi^K0`1i
NGT305QHF080HV9R0`1mOGd20:NWY`<0bLW90`2k^k/20:FUY@<0Y:BT0P2XZ:P30:f][@<0/[:b1@2e
]KD20:f][@<0Y:BT0`2MWId209VIV@<0V9RH0P2KVi/30:FUY@<0/K6a0P2j^[X50<30`0<0_[jn0P31
`L430<C4a0<0`<300P2k^k/50;bl_0<0_Kfm0`2d];@209nOW`<0J6QX0P1BDU8304M7A`<0De=C0P1U
IFD306i^KP80M7Ad0`1hN7P307alO080Ph>30`2:RXX208n?S`<0Ti>C0`2DU9@209FEU@<0UiNG0P2I
VIT309nOW`<0YJFU0P2XZ:P30:ZZZP80[:b/0`2][Jd20:n_[`P0/K6a0`2d];@20;Jf]P<0]KFe0`2b
/[820;6a/@<0[jn_0P2`/;080;6a/@<0/[:b1@2c/k<d0<SPf0<09RHV0P0R8R83030`<080=cLg0`0b
<S8303De=@80B4Q80`1=CDd204I6AP<0?Shn0`0l?3`2038b<P<0?Shn0P13@d<302d];@80:2PX0`0/
;2`302PX:0809BDU0`0Z:RX202PX:0<0;Bd]0`0a<C42038b<P<0<c<c0P0j>SX303<c<`<0;bl_0P1G
EeL304M7A`D092@T0`0V9RH202`/;0<0E5AD0P1UIFD306a/K0<0?3`l1@0S8b<204Y:BP<0KFe]0`11
@D4204E5A@<0D51@0P0k>c/302LW9`808B4Q0`0Z:RX304E5A@80OGem0`2MWId209NGU`<0M7Ad0`1K
Fe/206EUI@<0OGem0P2ZZZX30<K6aP<0^KVi0P2TY:@30:RXZ080YjNW0`2[Zj/50;>c/`<0]kNg0P2[
Zj/30:JVYP<0VYZJ0P2LW9`309JFUP80WIfM0`2VYZH30;:b/P80^;Rh2030`<020;jn_P<0a/K60`2o
_kl20;jn_P<0_kno0P2k^k/30;Jf]P<0^;Rh0P2SXj<306e]K@80CTi>0`1:BTX3059BDP80IVIV0`1e
MGD206i^KPH0NGUi0P26QXH308V9R@80SXj>0`2CTi<3096AT@80U9BD1@2HV9P309jNWP<0Y:BT0P2[
Zj/30:ZZZPD0[Zj^0P2ZZZX30;6a/@<0];Bd0P2`/;030;Bd]080][Jf0`2d];@30;2`/080];Bd1@2^
[Zh30;6a/@<0/;2`0P2a/K430;:b/P80[jn_0`2e]KDL0<SPf0006`38h=P301lO7`809RHV0`0_;bl2
02h^;P<0;Bd]0`0a<C4203De=@<0CDe=0P1SHf<305mOG`<0EEEE0P1>CTh304E5A@80CTi>0`0l?3`2
03Ti>@<0=3@d0`0];Bd502PX:080:RXZ0`0/;2`302l_;`80=3@d0`0i>CT503<c<`<0:2PX0P1DE5@3
05eMG@809RHV0`0U9BD502HV9P<0AdM70P1RHV8306m_K`<0?Cdm0P0V9RH3020P8080?Cdm0`1OGel3
03Ti>@80:b/[1@0g=cL3038b<P80:b/[0`0T92@303Lg=`80De=C0`20P8020:6QX@<0R8R80`1WIfL2
05iNGP<0Hf=S0P2;Rh/30;>c/`<0^;Rh0P2c/k<30:RXZ080Xj>S0`2XZ:P30:n_[`D0/K6a0P2^[Zh3
0:RXZ0<0XZ:R0P2MWId309^KV`80WYjN0`2WYjL30;6a/@80^[Zj0`30`<020;no_`<0_;bl0P2n_[h3
0;no_`<0_[jn0P2l_;`30;Zj^P80^;Rh0`2i^KT30;Rh^080^KVi0`2[Zj/208f=S@<0LG5a0`1/K6`2
06m_K`<0MgMg0P20P80308J6QP<0Rh^;0P2@T90309BDU080VIVI0`2LW9`309jNWP80WinO0`2PX:02
0::RXP<0YJFU0`2XZ:P20:VYZ@<0ZZZZ0P2/[:`30:n_[`D0/;2`1@2a/K430;>c/`P0];Bd0P2b/[88
0;6a/@<0/[:b0P2c/k<30;Fe]@D0][Jf=038h=P3028R8P80:BTY0`0_;bl203<c<`<0:BTY0`0Z:RX2
038b<P<0@4100P1JFUX3065QH@<0GemO0P1@D50304=3@`80ATI61@0j>SX3034a<@<0:b/[0P0W9bL3
02`/;080:BTY0`0Z:RX302`/;080=3@d0`0e=CD203Ph>0<0:b/[0`0a<C4205YJFP<0F5QH0P0];Bd3
02<S8`D09RHV0`0l?3`206UYJ@<0Hf=S0`0m?Cd202DU9@<092@T0P0j>SX306YZJP<0@D510P0/;2`3
03@d=080@4100`0f=SH202h^;P<0;bl_0`0[:b/205QHF0<0Ph>30P2VYZH308V9R@<0H61P0P1MGEd3
065QH@80QhN70`2d];@30<;2`P80[jn_0`2SXj<20:JVYP<0/;2`0`2/[:`20;>c/`<0/[:b0P2^[Zh3
0:FUY@<0YZJV0P2KVi/309bLW080WYjN0`2WYjL30;>c/`80]kNg0`2o_kl50;jn_P80^[Zj0`2o_kl3
0;fm_@80^KVi0`2d];@20;Vi^@<0];Bd0`2f][H20;Fe]@<0YJFU0P29RHT306a/K0<0I6AT0P1XJ6P3
07alO080Ng]k1P2:RXX208j>SP<0Ti>C0P2DU9@309VIV@<0X:2P1@2SXj<50:FUY@<0Z:RX0P2YZJT3
0:JVYP80[Zj^0`2a/K420:n_[`<0/[:b0`2_[jl20;2`/0D0/k>c0`2d];@30;:b/P80/;2`0`2b/[82
0;2`/0<0/K6a0`2_[jl20;Bd]0<0]kNg0P2e]KD30;Rh^1`0b>3H000K0<SPf0<07alO0P0V9RH302l_
;`80;Rh^0`0];Bd3034a<@80=CDe0`1=CDd206=SH`<0GemO0`1EEED204i>CP<0ADE50P1>CTh303`l
?080>CTi0`0d=3@302d];@D0:2PX0P0Z:RX302`/;0<0;bl_0P0d=3@303Ti>@D0<c<c0`0X:2P205AD
E0<0GEeM0P0V9RH302DU9@D09RHV0`17AdL2069RHP<0Kfm_0`0m?Cd202HV9P<0820P0P0m?Cd305mO
G`<0>CTi0P0[:b/503Lg=`<0<S8b0P0[:b/302@T90<0=cLg0P1CDe<30820P080XJ6Q0`28R8P306MW
I`80GUiN0`1SHf<208^;R`<0/k>c0`2h^;P20;>c/`<0Z:RX0P2SXj<30:RXZ0<0[jn_1@2a/K420:j^
[P<0Z:RX0`2RXZ8209fMW@<0Vi^K0P2NWYh30:NWY`<0/K6a0P2j^[X30<30`080_kno0`2l_;`20;jn
_P<0_kno0`2n_[h20;bl_0<0^[Zj0P2h^;P30;Vi^@<0^;Rh0P2i^KT30:^[Z`80SHf=0`1aLG4306a/
K080Kfm_0`1gMgL20820P0<0QXJ60`2;Rh/2092@T0<0U9BD0P2IVIT309bLW0<0WYjN0P2OWil30:2P
X080XZ:R0`2UYJD30:RXZ080ZJVY0`2ZZZX20:b/[0<0[jn_1@2`/;050;6a/@<0/k>c202d];@20;:b
/PP0/K6a0`2b/[820;>c/`<0]KFe1@2f][Hd0<SPf0<08R8R0P0Y:BT302l_;`80<c<c0`0Y:BT302XZ
:P80<S8b0`10@40205YJFP<0HF5Q0`1OGel2051@D0<0@d=30P16ATH503Xj>P<0<C4a0`0[:b/202LW
9`<0;2`/0P0Y:BT302XZ:P<0;2`/0P0d=3@303De=@80>3Ph0`0[:b/3034a<@80FUYJ0`1HF5P202d]
;@<08b<S1@0V9RH303`l?080JFUY0`1SHf<303dm?@809BDU0`0T92@203Xj>P<0JVYZ0`11@D4202`/
;0<0=3@d0P10@40303Hf=P80;Rh^0`0_;bl302/[:`80F5QH0`23Ph<20:JVYP<0RHV90`1PH60205eM
G@<0HF5Q0P27QhL30;Bd]0<0`/;20P2_[jl30:>SX`80YZJV0`2`/;030:b/[080/k>c0`2b/[820:j^
[P<0YJFU0`2VYZH209^KV`<0W9bL0P2NWYh30:NWY`<0/k>c0P2g]kL30;no_`D0_[jn0P2j^[X30;no
_`<0_Kfm0P2i^KT30;Bd]080^KVi0`2d];@30;Jf]P80]KFe0`2UYJD208V9R@<0K6a/0`1TI6@206QX
J0<0O7al0P1kNg/608Z:RP80SXj>0`2CTi<209BDU0<0VIVI0`2PX:050:>SX`D0YJFU0`2XZ:P20:VY
Z@<0YZJV0P2^[Zh30;6a/@80[jn_0`2b/[830:n_[`80/;2`1@2c/k<30;Bd]0<0/[:b0P2`/;030;:b
/P80/;2`0`2a/K430:n_[`80];Bd0`2g]kL20;Fe]@<0^;Rh7038h=P001/0b>3H0`0Q8B4202HV9P<0
;2`/0P0[:b/302TY:@D0:RXZ0`0d=3@204=3@`<0FEUI0`1[Jf/206IVIP<0Fe]K0P1BDU83051@D080
AdM70`0n?Sh303@d=080:b/[0`0Z:RX202`/;0<0;Bd]0`0_;bl203Lg=`<0?3`l0P0d=3@302l_;`<0
8b<S0P1;Bd/307UiN@80:2PX0`0W9bL302@T9080;2`/0`0g=cL205aLG0<0NGUi0`0h>3P202`/;0<0
8b<S0P0W9bL306QXJ0<0IFEU0P0d=3@3024Q8@80;2`/0`0j>SX203@d=0<0:b/[0`0T92@202/[:`<0
Hf=S0P2HV9P3096AT@<0NWYj0P1QHF43059BDP80KVi^0`2CTi<30:f][@80_[jn0`2_[jl20:2PX0<0
Y:BT0`2/[:`70:f][@<0Zj^[0`2VYZH20:2PX0<0WinO0P2PX:030:RXZ0<0/[:b0P2j^[X30<30`080
_[jn0`2k^k/20;Zj^P<0^k^k1@2l_;`30;Ng]`80/[:b0`2a/K430;:b/P80[jn_0`2][Jd20:VYZ@<0
XZ:R0`2?Shl207inOP<0Ph>30P2<S8`309>CT`<0V9RH0P2JVYX309^KV`80WYjN0`2PX:030:>SX`80
YJFU0`2VYZH50:NWY`D0Z:RX0`2YZJT20:b/[0<0[Zj^1@2_[jl30;2`/0D0/[:b0P2a/K430;>c/`<0
]KFe0P2d];@30;>c/`D0/K6a0`2c/k<20;Fe]@<0]kNg1@2h^;Pd0<SPf0<09RHV0P0Q8B4302DU9@80
=cLg0`0U9BD302PX:080;bl_0`0h>3P204Q8B0<0De=C0`1VIVH206i^KP<0EUIF0P1@D50305IFEP80
@d=30`0n?Sh3034a<@D0;2`/1@0];Bd3034a<@80?Shn0`0h>3P203<c<`<0;Bd]0`0[:b/204M7A`<0
Kfm_0P0_;bl302LW9`<0:2PX0P0V9RH303Ph>080I6AT0`1eMGD303dm?@80:BTY0`0U9BD202`/;0<0
G5aL0`1VIVH202XZ:P<0:b/[0P0`<30303Ph>080<S8b0`0V9RH302@T9080;Rh^0`1TI6@208j>SP<0
VYZJ0`1cLg<205mOG`<0FEUI0P1YJFT309BDU0<0];Bd0P2i^KT30:b/[080X:2P0`2YZJT30:JVYP80
/;2`0`2[Zj/20:j^[P<0ZJVY0`2UYJD209nOW`<0XJ6Q0P2NWYh30:NWY`<0/;2`0P2m_Kd30;no_`80
_[jn1@2j^[X30;Vi^@<0_kno0P2l_;`30;Ng]`80/[:b0`2f][H30;:b/P80/;2`0`2d];@20:b/[0<0
XZ:R0`2<S8`207alO0<0QHF50P2;Rh/309>CT`<0UiNG0P2FUYH309jNWP80WinO0`2RXZ830:6QX@80
Xj>S0`2TY:@20:NWY`<0Y:BT0`2VYZH20:n_[`<0ZJVY0P2XZ:P30:j^[P80/;2`0`2^[Zh50;6a/@<0
/[:b0P2a/K430;>c/`<0][Jf0P2g]kL30:n_[`80]KFe0`2b/[830:n_[`D0][Jf1@2g]kLL0<SPf000
6`38h=P3024Q8@809RHV0`0/;2`202/[:`<0:BTY1@0Z:RX303@d=080@d=30`1IFET306][J`80IVIV
0`1KFe/2059BDP<0D51@0P17AdL303hn?P<0=3@d0P0[:b/302XZ:P80;2`/0`0];Bd302l_;`80=cLg
0`0l?3`203@d=0<0;bl_0`0S8b<204];B`<0NGUi0P0X:2P302LW9`<092@T0P0/;2`303Lg=`80G5aL
0`1iNGT303Ph>080;2`/0`0S8b<202LW9`<0J6QX0`1UIFD203@d=0<08B4Q0P0/;2`303Xj>P80=3@d
0`0[:b/302@T9080:b/[0`1SHf<209RHV0<0TI6A0`1jNWX2065QH@<0DU9B0P1^KVh309>CT`<0[Jf]
0P2n_[h30:n_[`80X:2P0`2TY:@30:b/[0L0[Jf]0`2[Zj/30:JVYP80X:2P0`2OWil20:2PX0<0Z:RX
0`2b/[820;Zj^P<0`<300P2n_[h30;^k^`80^[Zj0`2k^k/50;bl_0<0]kNg0P2b/[830;6a/@<0/[:b
0P2_[jl30:f][@80ZJVY0`2RXZ8308n?S`80OWin0`23Ph<208b<S0<0Ti>C0`2HV9P209ZJVP<0Vi^K
0P2NWYh30:2PX0<0Xj>S0P2UYJD30:JVYPD0YjNW1@2XZ:P30:VYZ@80[:b/0`2^[Zh50:n_[`<0/;2`
1@2b/[820;6a/@<0/k>c0`2e]KD20;Bd]0<0/k>c1@2a/K430;>c/`80]KFe0`2g]kL50;Rh^3@0b>3H
0`0V9RH2024Q8@<09BDU0P0g=cL302DU9@<0:2PX0P0_;bl303Ph>080B4Q80`1CDe<306IVIP80KVi^
0`1FEUH2051@D0<0EUIF0P13@d<303hn?P<0<C4a1@0/;2`502d];@<0<C4a0P0n?Sh303Ph>080<c<c
0`0];Bd302/[:`80AdM70`1_Kfl202l_;`<09bLW0`0X:2P202HV9P<0>3Ph0P1TI6@307EeM@<0?Cdm
0P0Y:BT302DU9@80;2`/0`1LG5`306IVIP80:RXZ0`0[:b/2030`<0<0>3Ph0P0b<S8302HV9P<092@T
0P0^;Rh306ATI080SXj>0`2JVYX307=cL`80GemO0`1IFET206UYJ@<0U9BD0`2d];@20;Vi^@<0[:b/
0P2PX:030:VYZ@<0YZJV0P2`/;030:^[Z`80[Zj^0`2YZJT30:FUY@80WinO0`2QXJ4209jNWP<0YjNW
0`2`/;020;fm_@<0_kno0P2n_[h50;Zj^P<0^KVi0`2o_kl20;bl_0<0]kNg0P2b/[830;Jf]P<0/[:b
0P2`/;030;Bd]080[:b/0`2RXZ8308b<S080O7al0`25QHD208^;R`<0Ti>C0`2GUiL209JFUP<0WYjN
0P2OWil30::RXP<0XJ6Q0P2SXj<30:BTY080YjNW0`2TY:@30:JVYP80[jn_0`2YZJT20:RXZ0<0[Zj^
0P2`/;030:j^[PD0/K6a0`2b/[820;6a/@<0/k>c0`2f][H20;Ng]`<0[jn_0P2e]KD30;:b/P<0[jn_
1@2f][H50;Ng]a`0b>3H000K0<SPf0<08B4Q0P0V9RH302`/;080:b/[0`0Y:BT502XZ:P<0=3@d0P13
@d<305UIF@<0Jf][0P1VIVH305]KF`80DU9B0`1@D50204M7A`<0?Shn0`0d=3@202/[:`<0:RXZ0P0/
;2`302d];@<0;bl_0P0g=cL303`l?080=3@d0`0_;bl302<S8`80Bd];0`1iNGT202PX:0<09bLW0`0T
92@202`/;0<0=cLg0P1LG5`307UiN@<0>3Ph0P0/;2`302<S8`809bLW0`1XJ6P306EUI@80=3@d0`0Q
8B4202`/;0<0>SXj0P0d=3@302/[:`<092@T0P0[:b/306=SH`80V9RH0`2ATI4307YjNP80HF5Q0`1B
DU8206i^KP<0Ti>C0`2][Jd20;jn_P<0[jn_0P2PX:030:BTY0<0[:b/1`2][Jd30:^[Z`<0YZJV0P2P
X:0309nOW`80X:2P0`2XZ:P30;:b/P80^[Zj0`30`<020;jn_P<0^k^k0P2j^[X30;^k^`D0_;bl0`2g
]kL20;:b/P<0/K6a0`2b/[820:n_[`<0[Jf]0P2YZJT30::RXP<0Shn?0P1nOWh308>3P`80S8b<0`2C
Ti<309RHV080VYZJ0`2KVi/209jNWP<0X:2P0`2SXj<20:FUY@<0YZJV1@2WYjL50:RXZ0<0ZJVY0P2/
[:`30:j^[PD0[jn_0`2`/;050;:b/P80/K6a0`2c/k<30;Fe]@80];Bd0`2c/k<50;6a/@<0/k>c0P2e
]KD30;Ng]`D0^;Rh=038h=P302HV9P808B4Q0`0U9BD203Lg=`<09BDU0`0X:2P202l_;`<0>3Ph0P18
B4P305=CD`<0IVIV0P1^KVh305IFEP80D51@0`1FEUH204=3@`<0?Shn0`0a<C4502`/;0D0;Bd]0`0a
<C4203hn?P<0>3Ph0P0c<c<302d];@<0:b/[0P17AdL306m_K`80;bl_0`0W9bL302PX:0809RHV0`0h
>3P206ATI0<0MGEe0`0m?Cd202TY:@<09BDU0P0/;2`305aLG0<0IVIV0P0Z:RX302/[:`80<30`0`0h
>3P2038b<P<09RHV0`0T92@202h^;P<0I6AT0P2>SXh309ZJVP<0Lg=c0P1OGel305UIF@80JFUY0`2D
U9@30;Bd]080^KVi0`2/[:`20:2PX0<0ZJVY0`2VYZH20;2`/0<0Zj^[0P2^[Zh30:VYZ@<0YJFU0P2O
Wil30:6QX@80WYjN0`2WYjL30;2`/080_Kfm0`2o_kl20;jn_PD0^[Zj0`2i^KT30;no_`80_;bl0`2g
]kL20;:b/P<0][Jf0`2b/[820;2`/0<0];Bd0P2/[:`30::RXP<0S8b<0P1lO7`308F5Q@80Rh^;0`2C
Ti<309NGU`80UYJF0`2NWYh209nOW`<0XZ:R0`2QXJ420:>SX`<0Y:BT0P2WYjL30:BTY0<0YZJV0P2_
[jl30:VYZ@80Z:RX0`2^[Zh20;2`/0<0[Zj^1@2a/K430;:b/P80/K6a0`2c/k<30;Jf]P80]kNg0`2_
[jl20;Fe]@<0/[:b0`2_[jl50;Jf]PD0]kNg7038h=P001/0b>3H0`0^;Rh502LW9`80;Bd]0`0f=SH3
028R8P80=cLg0`0l?3`204E5A@<0BTY:0`1ADE42061PH0D0J6QX0`16ATH204=3@`<0?clo0`0f=SH2
02h^;P<0:RXZ0P0Y:BT302/[:`<0;bl_0P0f=SH303/k>`80<30`0`0W9bL302PX:080@T920`1cLg<2
03`l?0<092@T0`0W9bL202l_;`<0>c/k0P1JFUX307=cL`<0>CTi0P0j>SX302XZ:P809bLW0`1:BTX3
079bLP80=SHf0`0i>CT2028R8P<0=SHf0P0^;Rh302TY:@<0820P0P0R8R8304U9B@80Lg=c0`23Ph<3
08F5Q@80Jf][0`1CDe<205iNGP<0M7Ad0`2DU9@20:j^[P<0_Kfm0P2SXj<60:BTY080YZJV1@2YZJT3
0:NWY`<0Xj>S0P2OWil309jNWP80XJ6Q0`2XZ:P30;6a/@80^[Zj0`30`<020;no_`<0_;bl0P2i^KT3
0;Ng]`<0^[Zj0P2k^k/30;Jf]PD0/;2`0`2c/k<20;Bd]0<0]kNg0P2a/K430:ZZZP<0WinO0P2FUYH3
09BDU080UIFE0`2HV9P309^KV`80WYjN0`2QXJ420:>SX`<0Y:BT0`2UYJD=0:JVYP80YjNW0`2YZJT2
0:ZZZP<0Zj^[0P2][Jd30:j^[P<0/;2`0P2b/[830;6a/@80/;2`0`2a/K450;>c/`D0/[:b202a/K43
0;Bd]0D0^;Rh=038h=P302LW9`80:BTY0`0Z:RX203@d=0<0=cLg0`0S8b<203@d=0<0AdM70P1;Bd/3
04A4A0<0CTi>0P1XJ6P307QhN080EeMG0`19BDT204m?C`<0B4Q80`0e=CD2034a<@<09bLW0P0X:2P3
02l_;`<0:2PX0P0h>3P303dm?@80<C4a0`0U9BD302/[:`80A4A40`1bLW8203<c<`<0:RXZ0`0X:2P2
02/[:`<0?clo0P1NGUh3079bLP<0?Shn0P0f=SH302TY:@80:b/[0`11@D4307emO@80>SXj0`0Y:BT2
02@T90<0;Bd]0P0d=3@302h^;P<08B4Q0P0R8R8303hn?P80MWIf0`2<S8`3092@T080JFUY0`1FEUH2
05UIF@<0LW9b0`2@T9020;Vi^@<0^;Rh0P2OWil30:2PX0D0YjNW0`2UYJD20:RXZ0<0ZZZZ0`2UYJD2
09fMW@<0WinO0P2QXJ430:VYZ@<0[jn_1`2n_[h30;fm_@80^[Zj0`2e]KD30<30`080^[Zj0`2g]kL2
0:f][@<0[jn_0`2b/[820;Rh^0<0[jn_0P2^[Zh30;:b/P<0Z:RX0P2NWYh509FEU@<0V9RH1@2PX:03
0:6QX@D0Xj>S0`2WYjL50:FUY@80YjNW0`2SXj<30:NWY`80ZJVY0`2WYjL20:VYZ@D0Zj^[0`2^[Zh3
0:n_[`80];Bd1@2a/K430:n_[`<0/K6a1@2b/[820;6a/@H0/;2`0P2d];@30;:b/PD0^;Rh7038h=P0
01/0b>3H0`0^;Rh502LW9`80;Bd]0`0f=SH3028R8P80=cLg0`0l?3`204E5A@<0BTY:0`1ADE42061P
H0D0J6QX0`16ATH204=3@`<0?clo0`0f=SH202h^;P<0:RXZ0P0Y:BT302/[:`<0;bl_0P0f=SH303/k
>`80<30`0`0W9bL302PX:080@T920`1cLg<203`l?0<092@T0`0W9bL202l_;`<0>c/k0P1JFUX307=c
L`<0>CTi0P0j>SX302XZ:P809bLW0`1:BTX3079bLP80=SHf0`0i>CT2028R8P<0=SHf0P0^;Rh302TY
:@<0820P0P0R8R8304U9B@80Lg=c0`23Ph<308F5Q@80Jf][0`1CDe<205iNGP<0M7Ad0`2DU9@20:j^
[P<0_Kfm0P2SXj<60:BTY080YZJV1@2YZJT30:NWY`<0Xj>S0P2OWil309jNWP80XJ6Q0`2XZ:P30;6a
/@80^[Zj0`30`<020;no_`<0_;bl0P2i^KT30;Ng]`<0^[Zj0P2k^k/30;Jf]PD0/;2`0`2c/k<20;Bd
]0<0]kNg0P2a/K430:ZZZP<0WinO0P2FUYH309BDU080UIFE0`2HV9P309^KV`80WYjN0`2QXJ420:>S
X`<0Y:BT0`2UYJD=0:JVYP80YjNW0`2YZJT20:ZZZP<0Zj^[0P2][Jd30:j^[P<0/;2`0P2b/[830;6a
/@80/;2`0`2a/K450;>c/`D0/[:b202a/K430;Bd]0D0^;Rh=038h=P302LW9`80:BTY0`0Z:RX203@d
=0<0=cLg0`0S8b<203@d=0<0AdM70P1;Bd/304A4A0<0CTi>0P1XJ6P307QhN080EeMG0`19BDT204m?
C`<0B4Q80`0e=CD2034a<@<09bLW0P0X:2P302l_;`<0:2PX0P0h>3P303dm?@80<C4a0`0U9BD302/[
:`80A4A40`1bLW8203<c<`<0:RXZ0`0X:2P202/[:`<0?clo0P1NGUh3079bLP<0?Shn0P0f=SH302TY
:@80:b/[0`11@D4307emO@80>SXj0`0Y:BT202@T90<0;Bd]0P0d=3@302h^;P<08B4Q0P0R8R8303hn
?P80MWIf0`2<S8`3092@T080JFUY0`1FEUH205UIF@<0LW9b0`2@T9020;Vi^@<0^;Rh0P2OWil30:2P
X0D0YjNW0`2UYJD20:RXZ0<0ZZZZ0`2UYJD209fMW@<0WinO0P2QXJ430:VYZ@<0[jn_1`2n_[h30;fm
_@80^[Zj0`2e]KD30<30`080^[Zj0`2g]kL20:f][@<0[jn_0`2b/[820;Rh^0<0[jn_0P2^[Zh30;:b
/P<0Z:RX0P2NWYh509FEU@<0V9RH1@2PX:030:6QX@D0Xj>S0`2WYjL50:FUY@80YjNW0`2SXj<30:NW
Y`80ZJVY0`2WYjL20:VYZ@D0Zj^[0`2^[Zh30:n_[`80];Bd1@2a/K430:n_[`<0/K6a1@2b/[820;6a
/@H0/;2`0P2d];@30;:b/PD0^;Rh7038h=P001/0b>3H0`0^;Rh502LW9`80;Bd]0`0f=SH3028R8P80
=cLg0`0l?3`204E5A@<0BTY:0`1ADE42061PH0D0J6QX0`16ATH204=3@`<0?clo0`0f=SH202h^;P<0
:RXZ0P0Y:BT302/[:`<0;bl_0P0f=SH303/k>`80<30`0`0W9bL302PX:080@T920`1cLg<203`l?0<0
92@T0`0W9bL202l_;`<0>c/k0P1JFUX307=cL`<0>CTi0P0j>SX302XZ:P809bLW0`1:BTX3079bLP80
=SHf0`0i>CT2028R8P<0=SHf0P0^;Rh302TY:@<0820P0P0R8R8304U9B@80Lg=c0`23Ph<308F5Q@80
Jf][0`1CDe<205iNGP<0M7Ad0`2DU9@20:j^[P<0_Kfm0P2SXj<60:BTY080YZJV1@2YZJT30:NWY`<0
Xj>S0P2OWil309jNWP80XJ6Q0`2XZ:P30;6a/@80^[Zj0`30`<020;no_`<0_;bl0P2i^KT30;Ng]`<0
^[Zj0P2k^k/30;Jf]PD0/;2`0`2c/k<20;Bd]0<0]kNg0P2a/K430:ZZZP<0WinO0P2FUYH309BDU080
UIFE0`2HV9P309^KV`80WYjN0`2QXJ420:>SX`<0Y:BT0`2UYJD=0:JVYP80YjNW0`2YZJT20:ZZZP<0
Zj^[0P2][Jd30:j^[P<0/;2`0P2b/[830;6a/@80/;2`0`2a/K450;>c/`D0/[:b202a/K430;Bd]0D0
^;Rh=038h=P302LW9`80:BTY0`0Z:RX203@d=0<0=cLg0`0S8b<203@d=0<0AdM70P1;Bd/304A4A0<0
CTi>0P1XJ6P307QhN080EeMG0`19BDT204m?C`<0B4Q80`0e=CD2034a<@<09bLW0P0X:2P302l_;`<0
:2PX0P0h>3P303dm?@80<C4a0`0U9BD302/[:`80A4A40`1bLW8203<c<`<0:RXZ0`0X:2P202/[:`<0
?clo0P1NGUh3079bLP<0?Shn0P0f=SH302TY:@80:b/[0`11@D4307emO@80>SXj0`0Y:BT202@T90<0
;Bd]0P0d=3@302h^;P<08B4Q0P0R8R8303hn?P80MWIf0`2<S8`3092@T080JFUY0`1FEUH205UIF@<0
LW9b0`2@T9020;Vi^@<0^;Rh0P2OWil30:2PX0D0YjNW0`2UYJD20:RXZ0<0ZZZZ0`2UYJD209fMW@<0
WinO0P2QXJ430:VYZ@<0[jn_1`2n_[h30;fm_@80^[Zj0`2e]KD30<30`080^[Zj0`2g]kL20:f][@<0
[jn_0`2b/[820;Rh^0<0[jn_0P2^[Zh30;:b/P<0Z:RX0P2NWYh509FEU@<0V9RH1@2PX:030:6QX@D0
Xj>S0`2WYjL50:FUY@80YjNW0`2SXj<30:NWY`80ZJVY0`2WYjL20:VYZ@D0Zj^[0`2^[Zh30:n_[`80
];Bd1@2a/K430:n_[`<0/K6a1@2b/[820;6a/@H0/;2`0P2d];@30;:b/PD0^;Rh7038h=P001/0b>3H
0`0k>c/202h^;P<09BDU0P0_;bl30410@0<08B4Q0P13@d<30451@@80@4100`0e=CD3034a<@80E5AD
0`1_Kfl207MgM`<0>CTi0P0m?Cd30492@P<0>SXj0P0a<C4302TY:@809BDU0`0X:2P302h^;P80=CDe
0`0i>CT202d];@<08B4Q0`0^;Rh203Ti>@<0IFEU0P1BDU83024Q8@<0:RXZ0P0a<C4304=3@`80EUIF
0`1VIVH303Xj>P80ADE50`0b<S8202l_;`<09RHV0`1LG5`207inOP<0?Shn0P0I6AT3034a<@80:BTY
0`0U9BD3020P80808B4Q0`0b<S8204Y:BP<0KVi^0`2:RXX207QhN0<0GemO0P1IFET305mOG`<0Ng]k
0P2FUYH30<?3``80Z:RX0`2UYJD309jNWP80XJ6Q1@2TY:@30:>SX`<0X:2P0P2MWId309jNWP80XJ6Q
0`2XZ:P30;2`/080^KVi1@30`<030;fm_@80^KVi0`2e]KD30;Rh^080^[Zj0`2d];@50:j^[P<0/;2`
0P2c/k<30;Fe]@80[jn_1P2YZJT20:ZZZP<0Xj>S0P2LW9`309ZJVP<0Vi^K0P2OWil30:BTY0X0YJFU
0`2TY:@80:>SX`80YZJV1@2XZ:P30:NWY`80ZZZZ0`2][Jd30;2`/080/[:b0`2`/;050:n_[`<0/;2`
1@2a/K450;:b/P<0/;2`0P2^[Zh30;:b/P80^;Rh0`2i^KTd0<SPf0<0=SHf0P0d=3@302@T9080:2PX
0`0m?Cd302`/;080>SXj0`0o?cl503/k>`<0<c<c0P17AdL306e]K@80LG5a0`12@T8203Ti>@<0ATI6
0`0f=SH203@d=0<09BDU0P0W9bL302h^;P<0;2`/0P0l?3`303Lg=`80:BTY0`0X:2P302LW9`80=cLg
0`1[Jf/204e=C@<09bLW0`0Z:RX202`/;0<0?clo1@1MGEd303Xj>PD0>c/k0P0X:2P302XZ:P<0GEeM
0P1eMGD303hn?P80:2PX0`0/;2`202PX:0<09BDU0`0P820202TY:@<0:b/[0P19BDT307QhN0<0QhN7
0P1eMGD306=SH`80G5aL0`1VIVH307UiN@80VYZJ0`2k^k/20;2`/0<0XJ6Q0`2PX:020:BTY0<0Xj>S
0P2UYJD30::RXP<0W9bL1@2NWYh20:>SX`<0YZJV0`2_[jl20;bl_0<0_[jn0P32`/830;bl_080]kNg
0`2d];@30;bl_080]kNg0`2h^;P20;:b/P<0ZZZZ0`2^[Zh20;Vi^@<0]KFe0P2/[:`30:VYZ@D0YZJV
0`2WYjL209^KV`<0V9RH0`2JVYX20:6QX@<0Y:BT0P2XZ:P30::RXP<0Y:BT0P2VYZH50:BTY0<0XJ6Q
0`2VYZH20:>SX`<0ZJVY1@2WYjL20:b/[0<0Zj^[0`2d];@20;:b/P<0[Jf]202`/;020;:b/P<0/;2`
0P2b/[830;Bd]0D0[Zj^0`2a/K420;Jf]P<0_;bl7038h=P001/0b>3H0`0k>c/202h^;P<09BDU0P0_
;bl30410@0<08B4Q0P13@d<30451@@80@4100`0e=CD3034a<@80E5AD0`1_Kfl207MgM`<0>CTi0P0m
?Cd30492@P<0>SXj0P0a<C4302TY:@809BDU0`0X:2P302h^;P80=CDe0`0i>CT202d];@<08B4Q0`0^
;Rh203Ti>@<0IFEU0P1BDU83024Q8@<0:RXZ0P0a<C4304=3@`80EUIF0`1VIVH303Xj>P80ADE50`0b
<S8202l_;`<09RHV0`1LG5`207inOP<0?Shn0P0I6AT3034a<@80:BTY0`0U9BD3020P80808B4Q0`0b
<S8204Y:BP<0KVi^0`2:RXX207QhN0<0GemO0P1IFET305mOG`<0Ng]k0P2FUYH30<?3``80Z:RX0`2U
YJD309jNWP80XJ6Q1@2TY:@30:>SX`<0X:2P0P2MWId309jNWP80XJ6Q0`2XZ:P30;2`/080^KVi1@30
`<030;fm_@80^KVi0`2e]KD30;Rh^080^[Zj0`2d];@50:j^[P<0/;2`0P2c/k<30;Fe]@80[jn_1P2Y
ZJT20:ZZZP<0Xj>S0P2LW9`309ZJVP<0Vi^K0P2OWil30:BTY0X0YJFU0`2TY:@80:>SX`80YZJV1@2X
Z:P30:NWY`80ZZZZ0`2][Jd30;2`/080/[:b0`2`/;050:n_[`<0/;2`1@2a/K450;:b/P<0/;2`0P2^
[Zh30;:b/P80^;Rh0`2i^KTd0<SPf0<0=SHf0P0d=3@302@T9080:2PX0`0m?Cd302`/;080>SXj0`0o
?cl503/k>`<0<c<c0P17AdL306e]K@80LG5a0`12@T8203Ti>@<0ATI60`0f=SH203@d=0<09BDU0P0W
9bL302h^;P<0;2`/0P0l?3`303Lg=`80:BTY0`0X:2P302LW9`80=cLg0`1[Jf/204e=C@<09bLW0`0Z
:RX202`/;0<0?clo1@1MGEd303Xj>PD0>c/k0P0X:2P302XZ:P<0GEeM0P1eMGD303hn?P80:2PX0`0/
;2`202PX:0<09BDU0`0P820202TY:@<0:b/[0P19BDT307QhN0<0QhN70P1eMGD306=SH`80G5aL0`1V
IVH307UiN@80VYZJ0`2k^k/20;2`/0<0XJ6Q0`2PX:020:BTY0<0Xj>S0P2UYJD30::RXP<0W9bL1@2N
WYh20:>SX`<0YZJV0`2_[jl20;bl_0<0_[jn0P32`/830;bl_080]kNg0`2d];@30;bl_080]kNg0`2h
^;P20;:b/P<0ZZZZ0`2^[Zh20;Vi^@<0]KFe0P2/[:`30:VYZ@D0YZJV0`2WYjL209^KV`<0V9RH0`2J
VYX20:6QX@<0Y:BT0P2XZ:P30::RXP<0Y:BT0P2VYZH50:BTY0<0XJ6Q0`2VYZH20:>SX`<0ZJVY1@2W
YjL20:b/[0<0Zj^[0`2d];@20;:b/P<0[Jf]202`/;020;:b/P<0/;2`0P2b/[830;Bd]0D0[Zj^0`2a
/K420;Jf]P<0_;bl7038h=P001/0b>3H0`0o?cl204U9B@<0;Bd]0P0_;bl3034a<@<0=3@d0P0e=CD3
03@d=080<S8b0`0];Bd302/[:`80;Rh^0`0k>c/206UYJ@<0Kfm_0P1TI6@304m?C`<0@4100P0c<c<3
02XZ:P809RHV0`0X:2P302d];@80=CDe0`0j>SX202l_;`<092@T0`0/;2`203@d=0<0FEUI0P1QHF43
02@T90<09bLW0P0_;bl304=3@`80CTi>0`1ADE4303Lg=`80>c/k1@0c<c<302HV9P<0A4A40P1cLg<3
06][J`80?clo0`0];Bd202<S8`<08B4Q0`0N7Qh201lO7`<08b<S0P0a<C4305ADE0<0Ng]k0P23Ph<3
07moO`80Kfm_0`1VIVH306m_K`80Ogmo0`2YZJT20:b/[0<0[Jf]0`2VYZH20::RXP<0WinO0P2PX:03
0:6QX@<0X:2P0P2OWil30:2PX080XZ:R0`2YZJT30;2`/080^;Rh1@2o_kl30;bl_080^KVi0`2g]kL3
0;Zj^P80^k^k0`2d];@20:b/[0<0YjNW0`2QXJ420:^[Z`<0^[Zj0P2f][H30:n_[`<0[:b/0P2YZJT3
0:JVYP80XZ:R0`2NWYh309^KV`80WIfM0`2PX:020::RXP<0Xj>S0`2UYJD20:JVYP<0Y:BT1@2QXJ43
0::RXP80Y:BT0`2WYjL50:JVYP80ZZZZ0`2][Jd30:n_[`80/;2`0`2_[jl50:j^[P<0[jn_0P2a/K43
0;:b/P80/k>c0`2d];@30;:b/P80/K6a0`2e]KD20;Vi^@<0^[Zj=038h=P30410@080Cdm?0`0[:b/2
02@T90<0<c<c0`0g=cL203dm?@<0;bl_0P0b<S8302d];@<0;Rh^0P0g=cL30492@P80Jf][0`1XJ6P2
06EUI@<0AdM70`0f=SH203/k>`<0:RXZ0P0U9BD3028R8P<0:b/[0P0k>c/303Lg=`80;Rh^0`0V9RH3
02TY:@80=cLg0`1IFET206ATI0<0:RXZ0`0U9BD202XZ:P<0AdM70P1ADE4305QHF0<0>CTi0P10@403
04=3@`80;bl_0`0W9bL303`l?080N7Qh0`1aLG420451@@<0<30`0P0S8b<301dM7@<07QhN1@0P8202
038b<P<0De=C0`1bLW8207IfMP<0OWin0P1/K6`306=SH`<0JVYZ0P23Ph<309jNWP80];Bd0`2^[Zh3
0::RXP80WIfM1@2QXJ430:2PX0<0WinO1@2QXJ420:2PX0<0YZJV0`2][Jd20;bl_0<0^k^k1@2n_[h2
0;Fe]@<0]kNg0`2i^KT20;Ng]`<0];Bd0P2/[:`309bLW0<0XZ:R0P2f][H30;Vi^@80][Jf0`2/[:`3
0:>SX`80YjNW0`2VYZH20:BTY0<0Vi^K1@2JVYX309bLW080XJ6Q0`2VYZH30:VYZ@80Y:BT0`2QXJ42
0:>SX`<0XZ:R0`2NWYh20:BTY0<0ZJVY0P2WYjL30:JVYP80Z:RX0`2][Jd30;2`/080[Jf]0`2^[Zh2
0:f][@<0[Zj^0`2_[jl20;6a/@<0/[:b1@2d];@30;6a/@80/[:b0`2d];@20;Rh^0<0_[jn7038h=P0
01/0b>3H0`0o?cl204U9B@<0;Bd]0P0_;bl3034a<@<0=3@d0P0e=CD303@d=080<S8b0`0];Bd302/[
:`80;Rh^0`0k>c/206UYJ@<0Kfm_0P1TI6@304m?C`<0@4100P0c<c<302XZ:P809RHV0`0X:2P302d]
;@80=CDe0`0j>SX202l_;`<092@T0`0/;2`203@d=0<0FEUI0P1QHF4302@T90<09bLW0P0_;bl304=3
@`80CTi>0`1ADE4303Lg=`80>c/k1@0c<c<302HV9P<0A4A40P1cLg<306][J`80?clo0`0];Bd202<S
8`<08B4Q0`0N7Qh201lO7`<08b<S0P0a<C4305ADE0<0Ng]k0P23Ph<307moO`80Kfm_0`1VIVH306m_
K`80Ogmo0`2YZJT20:b/[0<0[Jf]0`2VYZH20::RXP<0WinO0P2PX:030:6QX@<0X:2P0P2OWil30:2P
X080XZ:R0`2YZJT30;2`/080^;Rh1@2o_kl30;bl_080^KVi0`2g]kL30;Zj^P80^k^k0`2d];@20:b/
[0<0YjNW0`2QXJ420:^[Z`<0^[Zj0P2f][H30:n_[`<0[:b/0P2YZJT30:JVYP80XZ:R0`2NWYh309^K
V`80WIfM0`2PX:020::RXP<0Xj>S0`2UYJD20:JVYP<0Y:BT1@2QXJ430::RXP80Y:BT0`2WYjL50:JV
YP80ZZZZ0`2][Jd30:n_[`80/;2`0`2_[jl50:j^[P<0[jn_0P2a/K430;:b/P80/k>c0`2d];@30;:b
/P80/K6a0`2e]KD20;Vi^@<0^[Zj=038h=P30410@080Cdm?0`0[:b/202@T90<0<c<c0`0g=cL203dm
?@<0;bl_0P0b<S8302d];@<0;Rh^0P0g=cL30492@P80Jf][0`1XJ6P206EUI@<0AdM70`0f=SH203/k
>`<0:RXZ0P0U9BD3028R8P<0:b/[0P0k>c/303Lg=`80;Rh^0`0V9RH302TY:@80=cLg0`1IFET206AT
I0<0:RXZ0`0U9BD202XZ:P<0AdM70P1ADE4305QHF0<0>CTi0P10@40304=3@`80;bl_0`0W9bL303`l
?080N7Qh0`1aLG420451@@<0<30`0P0S8b<301dM7@<07QhN1@0P8202038b<P<0De=C0`1bLW8207If
MP<0OWin0P1/K6`306=SH`<0JVYZ0P23Ph<309jNWP80];Bd0`2^[Zh30::RXP80WIfM1@2QXJ430:2P
X0<0WinO1@2QXJ420:2PX0<0YZJV0`2][Jd20;bl_0<0^k^k1@2n_[h20;Fe]@<0]kNg0`2i^KT20;Ng
]`<0];Bd0P2/[:`309bLW0<0XZ:R0P2f][H30;Vi^@80][Jf0`2/[:`30:>SX`80YjNW0`2VYZH20:BT
Y0<0Vi^K1@2JVYX309bLW080XJ6Q0`2VYZH30:VYZ@80Y:BT0`2QXJ420:>SX`<0XZ:R0`2NWYh20:BT
Y0<0ZJVY0P2WYjL30:JVYP80Z:RX0`2][Jd30;2`/080[Jf]0`2^[Zh20:f][@<0[Zj^0`2_[jl20;6a
/@<0/[:b1@2d];@30;6a/@80/[:b0`2d];@20;Rh^0<0_[jn7038h=P001/0b>3H0`0o?cl204U9B@<0
;Bd]0P0_;bl3034a<@<0=3@d0P0e=CD303@d=080<S8b0`0];Bd302/[:`80;Rh^0`0k>c/206UYJ@<0
Kfm_0P1TI6@304m?C`<0@4100P0c<c<302XZ:P809RHV0`0X:2P302d];@80=CDe0`0j>SX202l_;`<0
92@T0`0/;2`203@d=0<0FEUI0P1QHF4302@T90<09bLW0P0_;bl304=3@`80CTi>0`1ADE4303Lg=`80
>c/k1@0c<c<302HV9P<0A4A40P1cLg<306][J`80?clo0`0];Bd202<S8`<08B4Q0`0N7Qh201lO7`<0
8b<S0P0a<C4305ADE0<0Ng]k0P23Ph<307moO`80Kfm_0`1VIVH306m_K`80Ogmo0`2YZJT20:b/[0<0
[Jf]0`2VYZH20::RXP<0WinO0P2PX:030:6QX@<0X:2P0P2OWil30:2PX080XZ:R0`2YZJT30;2`/080
^;Rh1@2o_kl30;bl_080^KVi0`2g]kL30;Zj^P80^k^k0`2d];@20:b/[0<0YjNW0`2QXJ420:^[Z`<0
^[Zj0P2f][H30:n_[`<0[:b/0P2YZJT30:JVYP80XZ:R0`2NWYh309^KV`80WIfM0`2PX:020::RXP<0
Xj>S0`2UYJD20:JVYP<0Y:BT1@2QXJ430::RXP80Y:BT0`2WYjL50:JVYP80ZZZZ0`2][Jd30:n_[`80
/;2`0`2_[jl50:j^[P<0[jn_0P2a/K430;:b/P80/k>c0`2d];@30;:b/P80/K6a0`2e]KD20;Vi^@<0
^[Zj=038h=P30410@080Cdm?0`0[:b/202@T90<0<c<c0`0g=cL203dm?@<0;bl_0P0b<S8302d];@<0
;Rh^0P0g=cL30492@P80Jf][0`1XJ6P206EUI@<0AdM70`0f=SH203/k>`<0:RXZ0P0U9BD3028R8P<0
:b/[0P0k>c/303Lg=`80;Rh^0`0V9RH302TY:@80=cLg0`1IFET206ATI0<0:RXZ0`0U9BD202XZ:P<0
AdM70P1ADE4305QHF0<0>CTi0P10@40304=3@`80;bl_0`0W9bL303`l?080N7Qh0`1aLG420451@@<0
<30`0P0S8b<301dM7@<07QhN1@0P8202038b<P<0De=C0`1bLW8207IfMP<0OWin0P1/K6`306=SH`<0
JVYZ0P23Ph<309jNWP80];Bd0`2^[Zh30::RXP80WIfM1@2QXJ430:2PX0<0WinO1@2QXJ420:2PX0<0
YZJV0`2][Jd20;bl_0<0^k^k1@2n_[h20;Fe]@<0]kNg0`2i^KT20;Ng]`<0];Bd0P2/[:`309bLW0<0
XZ:R0P2f][H30;Vi^@80][Jf0`2/[:`30:>SX`80YjNW0`2VYZH20:BTY0<0Vi^K1@2JVYX309bLW080
XJ6Q0`2VYZH30:VYZ@80Y:BT0`2QXJ420:>SX`<0XZ:R0`2NWYh20:BTY0<0ZJVY0P2WYjL30:JVYP80
Z:RX0`2][Jd30;2`/080[Jf]0`2^[Zh20:f][@<0[Zj^0`2_[jl20;6a/@<0/[:b1@2d];@30;6a/@80
/[:b0`2d];@20;Rh^0<0_[jn7038h=P001/0b>3H0`0l?3`205iNGP<0>3Ph0P0`<303028R8P<0ADE5
0P0U9BD302HV9P8092@T0`0V9RH302`/;080=cLg0`17AdL2059BDP<0GEeM0P1QHF4305iNGP<0Bd];
0P0f=SH302`/;080:2PX0`0Y:BT302`/;080=CDe0`0k>c/203<c<`<0:RXZ0`0X:2P202l_;`<0CDe=
0P1ZJVX302XZ:P<09BDU0P0`<30504E5A@<0?Cdm0`0d=3@202h^;P<0<C4a0P0f=SH302l_;`<0;Rh^
0P1QHF4308j>SP80HV9R0`0X:2P501hN7P<07AdM0P0N7Qh301dM7@809BDU0`13@d<306YZJP80QhN7
0`2JVYX208Z:RP<0MgMg1@1]KFd308V9R@80ZZZZ0`2`/;030:j^[P80YJFU0`2MWId209jNWPP0XJ6Q
0`2RXZ820:BTY0<0ZZZZ0`2a/K420;Rh^0D0_Kfm0`2k^k/50;Zj^PD0^k^k0`2c/k<20:VYZ@<0Vi^K
0`2ATI420:>SX`D0^k^k0`2e]KD30:f][@D0YJFU0P2VYZH30:6QX@<0W9bL0P2JVYX309^KV`80WIfM
0`2PX:030:BTY080YZJV0`2SXj<509nOW`<0XJ6Q0P2SXj<50:FUY@<0YZJV0P2ZZZX30:f][@P0[Zj^
0P2][Jd30:j^[P<0[jn_0P2a/K430;:b/P80];Bd202e]KD30;Rh^0D0^k^k=038h=P303Xj>P80HV9R
0`0d=3@202TY:@<0:2PX0`0i>CT202PX:0<09BDU0P0T92@302LW9`<0;2`/0P0f=SH303hn?P80CDe=
0`1SHf<206UYJ@<0HV9R0`0o?cl203Hf=P<0=cLg0P0X:2P302TY:@<0<30`0P0i>CT303`l?080;Rh^
0`0[:b/302`/;080;Bd]0`1BDU8206ATI0<0;Bd]0`0V9RH202d];@<0BTY:0P0l?3`303hn?P<0>CTi
0P0Y:BT3034a<@80<S8b0`0];Bd302h^;P80Hf=S0`2<S8`2065QH@<0:BTY1@0O7al301dM7@807alO
0`0Q8B4202PX:0<0?Shn0`1/K6`208j>SP<0UiNG0P24Q8@307alO0<0LG5a0P1^KVh308J6QP80YjNW
0`2l_;`30:f][@80WIfM0`2NWYh20:>SX`<0X:2P0`2OWil20::RXP<0XJ6Q0P2VYZH30:b/[0<0[jn_
0P2k^k/30;bl_080^[Zj0`2k^k/20;bl_0P0^k^k0`2b/[820:j^[P<0T92@0`2?Shl20:^[Z`<0]KFe
0P2l_;`30;Rh^0<0YjNW0P2YZJT30:NWY`80YZJV0`2QXJ4309jNWP80VYZJ0`2KVi/209bLW0<0X:2P
0`2UYJD20:JVYP<0Xj>S0P2NWYh309fMW@<0Xj>S0P2QXJ430:JVYP80XJ6Q1@2XZ:P30;2`/0<0Zj^[
0P2`/;050:f][@H0/;2`0P2^[Zh30;Bd]080]KFe0`2f][H30;:b/P80][Jf0`2h^;P20;Vi^@<0_[jn
7038h=P001/0b>3H0`0l?3`205iNGP<0>3Ph0P0`<303028R8P<0ADE50P0U9BD302HV9P8092@T0`0V
9RH302`/;080=cLg0`17AdL2059BDP<0GEeM0P1QHF4305iNGP<0Bd];0P0f=SH302`/;080:2PX0`0Y
:BT302`/;080=CDe0`0k>c/203<c<`<0:RXZ0`0X:2P202l_;`<0CDe=0P1ZJVX302XZ:P<09BDU0P0`
<30504E5A@<0?Cdm0`0d=3@202h^;P<0<C4a0P0f=SH302l_;`<0;Rh^0P1QHF4308j>SP80HV9R0`0X
:2P501hN7P<07AdM0P0N7Qh301dM7@809BDU0`13@d<306YZJP80QhN70`2JVYX208Z:RP<0MgMg1@1]
KFd308V9R@80ZZZZ0`2`/;030:j^[P80YJFU0`2MWId209jNWPP0XJ6Q0`2RXZ820:BTY0<0ZZZZ0`2a
/K420;Rh^0D0_Kfm0`2k^k/50;Zj^PD0^k^k0`2c/k<20:VYZ@<0Vi^K0`2ATI420:>SX`D0^k^k0`2e
]KD30:f][@D0YJFU0P2VYZH30:6QX@<0W9bL0P2JVYX309^KV`80WIfM0`2PX:030:BTY080YZJV0`2S
Xj<509nOW`<0XJ6Q0P2SXj<50:FUY@<0YZJV0P2ZZZX30:f][@P0[Zj^0P2][Jd30:j^[P<0[jn_0P2a
/K430;:b/P80];Bd202e]KD30;Rh^0D0^k^k=038h=P303Xj>P80HV9R0`0d=3@202TY:@<0:2PX0`0i
>CT202PX:0<09BDU0P0T92@302LW9`<0;2`/0P0f=SH303hn?P80CDe=0`1SHf<206UYJ@<0HV9R0`0o
?cl203Hf=P<0=cLg0P0X:2P302TY:@<0<30`0P0i>CT303`l?080;Rh^0`0[:b/302`/;080;Bd]0`1B
DU8206ATI0<0;Bd]0`0V9RH202d];@<0BTY:0P0l?3`303hn?P<0>CTi0P0Y:BT3034a<@80<S8b0`0]
;Bd302h^;P80Hf=S0`2<S8`2065QH@<0:BTY1@0O7al301dM7@807alO0`0Q8B4202PX:0<0?Shn0`1/
K6`208j>SP<0UiNG0P24Q8@307alO0<0LG5a0P1^KVh308J6QP80YjNW0`2l_;`30:f][@80WIfM0`2N
WYh20:>SX`<0X:2P0`2OWil20::RXP<0XJ6Q0P2VYZH30:b/[0<0[jn_0P2k^k/30;bl_080^[Zj0`2k
^k/20;bl_0P0^k^k0`2b/[820:j^[P<0T92@0`2?Shl20:^[Z`<0]KFe0P2l_;`30;Rh^0<0YjNW0P2Y
ZJT30:NWY`80YZJV0`2QXJ4309jNWP80VYZJ0`2KVi/209bLW0<0X:2P0`2UYJD20:JVYP<0Xj>S0P2N
WYh309fMW@<0Xj>S0P2QXJ430:JVYP80XJ6Q1@2XZ:P30;2`/0<0Zj^[0P2`/;050:f][@H0/;2`0P2^
[Zh30;Bd]080]KFe0`2f][H30;:b/P80][Jf0`2h^;P20;Vi^@<0_[jn7038h=P001/0b>3H0`0_;bl2
04];B`<0@T920P0f=SH302DU9@<0>CTi0P0Y:BT302DU9@808B4Q0`0Z:RX303Lg=`80Cdm?1@0n?Sh3
04A4A080De=C0`1MGEd3051@D080?Shn0`0b<S8202TY:@<0:RXZ0`0_;bl203@d=0<0>3Ph0P0c<c<3
02d];@<0:2PX0P0Z:RX304M7A`80IFEU0`0f=SH302LW9`80?3`l0`1FEUH203Lg=`<0<S8b0`0k>c/2
02@T90<0:b/[0P0a<C4303@d=0<0<S8b0P1HF5P307]kN`80EUIF0`0T92@201hN7P<0820P0`0M7Ad2
01`L70<09bLW0P0a<C4305eMG@<0IfMW0P1oOgl308V9R@80WinO0`2;Rh/307UiN@80JVYZ0`1fMWH2
08n?S`<0XJ6Q0`2_[jl20:VYZ@D0X:2P1P2QXJ420::RXP<0Y:BT0P2WYjL30:j^[P<0]KFe0P2j^[X3
0;bl_080^k^k0`2i^KT50;^k^`<0^[Zj0P2f][H30:n_[`80XZ:R0`22PX8308J6QP80Z:RX0`2c/k<2
0;fm_@<0_[jn0`2g]kL20:f][@<0ZJVY0P2VYZH30:6QX@<0WIfM0P2JVYX309VIV@80VYZJ0`2MWId3
09nOW`80X:2P0`2NWYh209bLW0<0WYjN0`2QXJ420::RXP<0Xj>S0P2TY:@30:JVYP80ZJVY0`2/[:`5
0:f][@D0[:b/0`2^[Zh30;2`/080/K6a0`2b/[820;>c/`P0]KFe0`2h^;P20;bl_0<0_Kfm=038h=P3
02LW9`80BTY:0`1DE5@2038b<P<0<C4a0`0l?3`202XZ:PD09BDU0`0X:2P303@d=080DU9B0`18B4P2
03hn?P<0>CTi0P1JFUX3069RHP<0De=C0P0m?Cd3038b<P809RHV0`0X:2P302TY:@80<S8b0`0i>CT2
03Lg=`<0;2`/1@0Y:BT30410@080IVIV0`0k>c/302LW9`80>c/k0`1JFUX2034a<@<0=3@d0`0b<S82
02DU9@<09RHV0P0b<S8304E5A@<0=3@d0P1?Cdl307YjNP80De=C0`0Q8B42020P80<08b<S1@0N7Qh3
020P8080<C4a0`1RHV8306MWI`D0SXj>0P2QXJ4308R8R0<0OGem0P1ZJVX307AdM080R8R80`2SXj<3
0;:b/P80YJFU0`2PX:020:BTY0<0XJ6Q0`2LW9`50::RXP80YJFU0`2_[jl30;>c/`80`<300`2l_;`2
0;Zj^P<0^KVi0P2k^k/30;Rh^0<0^k^k0P2i^KT30:n_[`80Y:BT0`2:RXX308B4Q080Zj^[0`2`/;02
0;Vi^@<0`l?30`2h^;P20:j^[P<0Z:RX0P2VYZH309nOW`<0W9bL0P2NWYh309bLW080Vi^K0`2HV9P3
09jNWP80X:2P202NWYh30:>SX`80X:2P0`2RXZ820:JVYP<0YJFU0P2/[:`30:ZZZP<0[Zj^0P2_[jl3
0:^[Z`D0[:b/0`2`/;050:n_[`D0];Bd0`2c/k<20;Ng]`<0][Jf0P2l_;`30;fm_A`0b>3H000K0<SP
f0<0;bl_0P1;Bd/30492@P80=SHf0`0U9BD303Ti>@80:BTY0`0U9BD2024Q8@<0:RXZ0`0g=cL204m?
C`D0?Shn0`14A4@205=CD`<0GEeM0`1@D50203hn?P<0<S8b0P0Y:BT302XZ:P<0;bl_0P0d=3@303Ph
>080<c<c0`0];Bd302PX:080:RXZ0`17AdL206EUI@<0=SHf0`0W9bL203`l?0<0EUIF0P0g=cL3038b
<P<0>c/k0P0T92@302/[:`80<C4a0`0d=3@3038b<P80F5QH0`1kNg/205IFEP<092@T0P0N7Qh3020P
80<07AdM0P0L71`302LW9`80<C4a0`1MGEd306MWI`80Ogmo0`29RHT209nOW`<0Rh^;0`1iNGT206YZ
JP<0MWIf0P2?Shl30:6QX@<0[jn_0P2YZJT50:2PX0H0XJ6Q0P2RXZ830:BTY080YjNW0`2^[Zh30;Fe
]@80^[Zj0`2l_;`20;^k^`<0^KVi1@2k^k/30;Zj^P80][Jf0`2_[jl20::RXP<0PX:20`26QXH20:RX
Z0<0/k>c0P2m_Kd30;jn_P<0]kNg0P2][Jd30:VYZ@80YZJV0`2QXJ4309fMW@80VYZJ0`2IVIT209ZJ
VP<0WIfM0`2OWil20:2PX0<0WYjN0P2LW9`309jNWP<0XJ6Q0P2RXZ830:>SX`80Y:BT0`2VYZH20:VY
Z@<0[:b/1@2][Jd50:b/[0<0[Zj^0`2`/;020;6a/@<0/[:b0P2c/k<80;Fe]@<0^;Rh0P2l_;`30;fm
_C@0b>3H0`0W9bL204Y:BP<0E5AD0P0b<S83034a<@<0?3`l0P0Z:RX502DU9@<0:2PX0`0d=3@2059B
DP<0B4Q80P0n?Sh303Ti>@80FUYJ0`1RHV8305=CD`80?Cdm0`0b<S8202HV9P<0:2PX0`0Y:BT2038b
<P<0>CTi0P0g=cL302`/;0D0:BTY0`10@40206IVIP<0>c/k0`0W9bL203/k>`<0FUYJ0P0a<C4303@d
=0<0<S8b0P0U9BD302HV9P80<S8b0`15ADD303@d=080Cdm?0`1jNWX205=CD`<08B4Q0P0P820302<S
8`D07QhN0`0P8202034a<@<0HV9R0`1WIfL508j>SP80XJ6Q0`28R8P307emO@80JVYZ0`1dM7@208R8
R0<0Xj>S0`2b/[820:FUY@<0X:2P0P2TY:@30:6QX@<0W9bL1@2RXZ820:FUY@<0[jn_0`2c/k<20<30
`0<0_;bl0P2j^[X30;Vi^@80^k^k0`2h^;P30;^k^`80^KVi0`2_[jl20:BTY0<0RXZ:0`24Q8@20:^[
Z`<0/;2`0P2i^KT30<?3``<0^;Rh0P2^[Zh30:RXZ080YZJV0`2OWil309bLW080WYjN0`2LW9`209^K
V`<0V9RH0`2NWYh20:2PX0P0WYjN0`2SXj<20:2PX0<0XZ:R0P2VYZH30:FUY@80[:b/0`2ZZZX30:j^
[P80[jn_0`2[Zj/50:b/[0<0/;2`1@2_[jl50;Bd]0<0/k>c0P2g]kL30;Jf]P80_;bl0`2m_KdL0<SP
f0006`38h=P302l_;`80Bd];0`12@T8203Hf=P<09BDU0`0i>CT202TY:@<09BDU0P0Q8B4302XZ:P<0
=cLg0P1?Cdl503hn?P<0A4A40P1CDe<305eMG@<0D51@0P0n?Sh3038b<P80:BTY0`0Z:RX302l_;`80
=3@d0`0h>3P203<c<`<0;Bd]0`0X:2P202XZ:P<0AdM70P1UIFD303Hf=P<09bLW0P0l?3`305IFEP80
=cLg0`0b<S8303/k>`8092@T0`0[:b/2034a<@<0=3@d0`0b<S8205QHF0<0Ng]k0P1FEUH302@T9080
7QhN0`0P820301dM7@8071`L0`0W9bL2034a<@<0GEeM0`1WIfL207moO`<0RHV90P2OWil308^;R`<0
NGUi0P1ZJVX307IfMP80Shn?0`2QXJ430:n_[`80ZJVY1@2PX:060:6QX@80XZ:R0`2TY:@20:NWY`<0
[Zj^0`2e]KD20;Zj^P<0_;bl0P2k^k/30;Vi^@D0^k^k0`2j^[X20;Jf]P<0[jn_0P2RXZ8308:2PP<0
QXJ60P2XZ:P30;>c/`80_Kfm0`2n_[h30;Ng]`80[Jf]0`2YZJT20:JVYP<0XJ6Q0`2MWId209ZJVP<0
VIVI0P2JVYX309fMW@<0WinO0P2PX:0309jNWP80W9bL0`2NWYh30:6QX@80XZ:R0`2SXj<20:BTY0<0
YZJV0P2YZJT30:b/[0D0[Jf]1@2/[:`30:j^[P<0/;2`0P2a/K430;:b/P80/k>c202e]KD30;Rh^080
_;bl0`2m_Kdd0<SPf0<09bLW0P1:BTX305ADE080<S8b0`0a<C4303`l?080:RXZ1@0U9BD302PX:0<0
=3@d0P1BDU8304Q8B080?Shn0`0i>CT205YJFP<0HV9R0`1CDe<203dm?@<0<S8b0P0V9RH302PX:0<0
:BTY0P0b<S8303Ti>@80=cLg0`0/;2`502TY:@<0@4100P1VIVH303/k>`<09bLW0P0k>c/305YJFP80
<C4a0`0d=3@3038b<P809BDU0`0V9RH2038b<P<0ADE50`0d=3@204m?C`<0NWYj0P1CDe<3024Q8@80
820P0`0S8b<501hN7P<0820P0P0a<C43069RHP<0IfMW1@2>SXh20:6QX@<0R8R80`1mOGd206YZJP<0
M7Ad0P28R8P30:>SX`<0/[:b0P2UYJD30:2PX080Y:BT0`2QXJ4309bLW0D0XZ:R0P2UYJD30:n_[`<0
/k>c0P30`<030;bl_080^[Zj0`2i^KT20;^k^`<0^;Rh0`2k^k/20;Vi^@<0[jn_0P2TY:@308Z:RP<0
Q8B40P2[Zj/30;2`/080^KVi0`33`l<30;Rh^080[Zj^0`2XZ:P20:JVYP<0WinO0`2LW9`209jNWP<0
W9bL0P2KVi/309RHV0<0WYjN0P2PX:0809jNWP<0Xj>S0P2PX:030::RXP80YZJV0`2UYJD20:b/[0<0
ZZZZ0`2^[Zh20:n_[`<0Zj^[1@2/[:`30;2`/0D0[jn_1@2d];@30;>c/`80]kNg0`2f][H20;bl_0<0
_Kfm7038h=P001/0b>3H0`0R8R82038b<P<0ATI60P0j>SX302/[:`<0:RXZ0P0^;Rh302PX:0809BDU
0`0f=SH304I6AP80IVIV0`0l?3`202l_;`<09BDU0P0m?Cd305IFEP<0De=C0P18B4P303Ph>080:RXZ
0`0/;2`3034a<@80=3@d0`0e=CD203<c<`<0;bl_0`0X:2P202LW9`<0@d=30P1KFe/304=3@`<0:b/[
0P15ADD3065QH@D0:b/[0`10@402020P80<0:BTY0P0a<C4303Hf=P<0>SXj0P1@D50305iNGP80@D51
0`0Q8B4201lO7`<08b<S1@0M7Ad303De=@80Bd];0`1jNWX306ATI080K6a/0`1[Jf/20:JVYP<0Vi^K
0`29RHT2071`L0<0KFe]0P1cLg<308n?S`<0ZJVY0P2[Zj/30:JVYP80Xj>S1P2QXJ420:>SX`<0YZJV
0P2[Zj/30;:b/P<0^;Rh0P2k^k/30;bl_080^[Zj0`2h^;P20;^k^`<0_;bl0`2h^;P20;2`/0<0YjNW
0P2KVi/306e]K@<0Ogmo0P2_[jl30:^[Z`80_;bl0`34a<@30<30`080]kNg0`2^[Zh20:JVYP<0XZ:R
0`2OWil209^KV`D0VIVI1P2JVYX209^KV`D0VYZJ0`2MWId80:6QX@80Xj>S0`2VYZH20:VYZ@<0Zj^[
1@2/[:`50:^[Z`<0[Zj^202a/K420;>c/`P0];Bd0`2i^KT20;bl_0<0_Kfm=038h=P302TY:@80<C4a
0`15ADD203<c<`<09bLW0`0`<30202`/;0<09RHV0P0Y:BT303@d=0<0BDU90P1QHF4303/k>`80;Rh^
0`0Y:BT203/k>`<0EEEE0`1HF5P204Y:BP<0>CTi0P0^;Rh302/[:`<0;bl_0P0h>3P3034a<@80>CTi
0`0Z:RX302`/;080:RXZ0`0l?3`205mOG`<0@D510`0[:b/204E5A@<0GEeM0P0c<c<302d];@<0=cLg
0P0W9bL302/[:`80;Rh^0`0m?Cd303Hf=P80Cdm?0`1UIFD203lo?`<092@T0P0O7al3024Q8@D0820P
0`0/;2`204m?C`<0OGem0`1WIfL205mOG`<0LW9b0P2KVi/30:6QX@<0QhN70P1dM7@306m_K`80NWYj
0`24Q8@30:^[Z`80[jn_0`2SXj<20:BTY0<0XZ:R0`2MWId50:JVYP80ZZZZ0`2d];@30;Fe]@80_Kfm
0`2k^k/20;Zj^P<0][Jf0P2o_kl30;^k^`<0^;Rh0P2a/K430:2PX080V9RH0`1dM7@307emO@80ZJVY
0`2`/;020;bl_0<0`l?30`30`<020;Jf]P<0[jn_0P2VYZH30::RXP<0XJ6Q0P2IVIT309NGU`80Vi^K
0`2FUYH309^KV`80VYZJ0`2KVi/209VIV@<0Vi^K0`2PX:020:BTY0<0XJ6Q0P2SXj<30:FUY@80ZJVY
0`2ZZZX30:f][@80ZZZZ0`2YZJT20:b/[0<0[jn_1@2a/K430;Bd]080/;2`0`2g]kL30;Fe]@80]kNg
0`2e]KD20;fm_@<0`L717038h=P001/0b>3H0`0R8R82038b<P<0ATI60P0j>SX302/[:`<0:RXZ0P0^
;Rh302PX:0809BDU0`0f=SH304I6AP80IVIV0`0l?3`202l_;`<09BDU0P0m?Cd305IFEP<0De=C0P18
B4P303Ph>080:RXZ0`0/;2`3034a<@80=3@d0`0e=CD203<c<`<0;bl_0`0X:2P202LW9`<0@d=30P1K
Fe/304=3@`<0:b/[0P15ADD3065QH@D0:b/[0`10@402020P80<0:BTY0P0a<C4303Hf=P<0>SXj0P1@
D50305iNGP80@D510`0Q8B4201lO7`<08b<S1@0M7Ad303De=@80Bd];0`1jNWX306ATI080K6a/0`1[
Jf/20:JVYP<0Vi^K0`29RHT2071`L0<0KFe]0P1cLg<308n?S`<0ZJVY0P2[Zj/30:JVYP80Xj>S1P2Q
XJ420:>SX`<0YZJV0P2[Zj/30;:b/P<0^;Rh0P2k^k/30;bl_080^[Zj0`2h^;P20;^k^`<0_;bl0`2h
^;P20;2`/0<0YjNW0P2KVi/306e]K@<0Ogmo0P2_[jl30:^[Z`80_;bl0`34a<@30<30`080]kNg0`2^
[Zh20:JVYP<0XZ:R0`2OWil209^KV`D0VIVI1P2JVYX209^KV`D0VYZJ0`2MWId80:6QX@80Xj>S0`2V
YZH20:VYZ@<0Zj^[1@2/[:`50:^[Z`<0[Zj^202a/K420;>c/`P0];Bd0`2i^KT20;bl_0<0_Kfm=038
h=P302TY:@80<C4a0`15ADD203<c<`<09bLW0`0`<30202`/;0<09RHV0P0Y:BT303@d=0<0BDU90P1Q
HF4303/k>`80;Rh^0`0Y:BT203/k>`<0EEEE0`1HF5P204Y:BP<0>CTi0P0^;Rh302/[:`<0;bl_0P0h
>3P3034a<@80>CTi0`0Z:RX302`/;080:RXZ0`0l?3`205mOG`<0@D510`0[:b/204E5A@<0GEeM0P0c
<c<302d];@<0=cLg0P0W9bL302/[:`80;Rh^0`0m?Cd303Hf=P80Cdm?0`1UIFD203lo?`<092@T0P0O
7al3024Q8@D0820P0`0/;2`204m?C`<0OGem0`1WIfL205mOG`<0LW9b0P2KVi/30:6QX@<0QhN70P1d
M7@306m_K`80NWYj0`24Q8@30:^[Z`80[jn_0`2SXj<20:BTY0<0XZ:R0`2MWId50:JVYP80ZZZZ0`2d
];@30;Fe]@80_Kfm0`2k^k/20;Zj^P<0][Jf0P2o_kl30;^k^`<0^;Rh0P2a/K430:2PX080V9RH0`1d
M7@307emO@80ZJVY0`2`/;020;bl_0<0`l?30`30`<020;Jf]P<0[jn_0P2VYZH30::RXP<0XJ6Q0P2I
VIT309NGU`80Vi^K0`2FUYH309^KV`80VYZJ0`2KVi/209VIV@<0Vi^K0`2PX:020:BTY0<0XJ6Q0P2S
Xj<30:FUY@80ZJVY0`2ZZZX30:f][@80ZZZZ0`2YZJT20:b/[0<0[jn_1@2a/K430;Bd]080/;2`0`2g
]kL30;Fe]@80]kNg0`2e]KD20;fm_@<0`L717038h=P001/0b>3H0`0R8R82038b<P<0ATI60P0j>SX3
02/[:`<0:RXZ0P0^;Rh302PX:0809BDU0`0f=SH304I6AP80IVIV0`0l?3`202l_;`<09BDU0P0m?Cd3
05IFEP<0De=C0P18B4P303Ph>080:RXZ0`0/;2`3034a<@80=3@d0`0e=CD203<c<`<0;bl_0`0X:2P2
02LW9`<0@d=30P1KFe/304=3@`<0:b/[0P15ADD3065QH@D0:b/[0`10@402020P80<0:BTY0P0a<C43
03Hf=P<0>SXj0P1@D50305iNGP80@D510`0Q8B4201lO7`<08b<S1@0M7Ad303De=@80Bd];0`1jNWX3
06ATI080K6a/0`1[Jf/20:JVYP<0Vi^K0`29RHT2071`L0<0KFe]0P1cLg<308n?S`<0ZJVY0P2[Zj/3
0:JVYP80Xj>S1P2QXJ420:>SX`<0YZJV0P2[Zj/30;:b/P<0^;Rh0P2k^k/30;bl_080^[Zj0`2h^;P2
0;^k^`<0_;bl0`2h^;P20;2`/0<0YjNW0P2KVi/306e]K@<0Ogmo0P2_[jl30:^[Z`80_;bl0`34a<@3
0<30`080]kNg0`2^[Zh20:JVYP<0XZ:R0`2OWil209^KV`D0VIVI1P2JVYX209^KV`D0VYZJ0`2MWId8
0:6QX@80Xj>S0`2VYZH20:VYZ@<0Zj^[1@2/[:`50:^[Z`<0[Zj^202a/K420;>c/`P0];Bd0`2i^KT2
0;bl_0<0_Kfm=038h=P302TY:@80<C4a0`15ADD203<c<`<09bLW0`0`<30202`/;0<09RHV0P0Y:BT3
03@d=0<0BDU90P1QHF4303/k>`80;Rh^0`0Y:BT203/k>`<0EEEE0`1HF5P204Y:BP<0>CTi0P0^;Rh3
02/[:`<0;bl_0P0h>3P3034a<@80>CTi0`0Z:RX302`/;080:RXZ0`0l?3`205mOG`<0@D510`0[:b/2
04E5A@<0GEeM0P0c<c<302d];@<0=cLg0P0W9bL302/[:`80;Rh^0`0m?Cd303Hf=P80Cdm?0`1UIFD2
03lo?`<092@T0P0O7al3024Q8@D0820P0`0/;2`204m?C`<0OGem0`1WIfL205mOG`<0LW9b0P2KVi/3
0:6QX@<0QhN70P1dM7@306m_K`80NWYj0`24Q8@30:^[Z`80[jn_0`2SXj<20:BTY0<0XZ:R0`2MWId5
0:JVYP80ZZZZ0`2d];@30;Fe]@80_Kfm0`2k^k/20;Zj^P<0][Jf0P2o_kl30;^k^`<0^;Rh0P2a/K43
0:2PX080V9RH0`1dM7@307emO@80ZJVY0`2`/;020;bl_0<0`l?30`30`<020;Jf]P<0[jn_0P2VYZH3
0::RXP<0XJ6Q0P2IVIT309NGU`80Vi^K0`2FUYH309^KV`80VYZJ0`2KVi/209VIV@<0Vi^K0`2PX:02
0:BTY0<0XJ6Q0P2SXj<30:FUY@80ZJVY0`2ZZZX30:f][@80ZZZZ0`2YZJT20:b/[0<0[jn_1@2a/K43
0;Bd]080/;2`0`2g]kL30;Fe]@80]kNg0`2e]KD20;fm_@<0`L717038h=P001/0b>3H0`0S8b<202/[
:`<0>CTi0P0c<c<302/[:`<0:2PX0P0[:b/302`/;080<30`0`1HF5P305UIF@80Bd];0`0f=SH202/[
:`<09bLW0P0e=CD304M7A`<0DE5A0P1CDe<30451@@80;Rh^0`0];Bd3030`<080=3@d0`0g=cL203De
=@<0<30`0`0Y:BT202LW9`<0?Cdm0P1?Cdl3055AD@<0:b/[0P0m?Cd304i>CP80;Rh^0`0[:b/303Ph
>080:b/[0`0f=SH204E5A@<0;bl_0`0f=SH204U9B@<0FEUI0P0o?cl3028R8P807alO0`0R8R8301`L
7080820P0`0i>CT207EeM@<0O7al0`1KFe/20410@0<0CTi>0P26QXH309bLW0<0U9BD0P21PH4307=c
L`80L71`0`20P80309FEU@80Y:BT0`2^[Zh20:NWY`<0WinO0`2QXJ420:JVYP<0ZZZZ0P2_[jl30;6a
/@<0];Bd0P2k^k/30<30`080_;bl0`2h^;P20;^k^`<0_Kfm0`2g]kL20:n_[`<0UiNG0P2MWId306a/
K0<0Ph>30P2b/[830:ZZZP80^KVi0`30`<030<;2`P80_kno0`2g]kL20:f][@<0Z:RX0`2TY:@209nO
W`D0Vi^K0`2MWId509jNWP<0Vi^K0P2HV9P309^KV`<0X:2P0P2RXZ880:>SX`80YjNW0`2[Zj/80:b/
[080[Jf]0`2^[Zh30;2`/0L0/K6a0`2b/[830;Bd]080]kNg0`2j^[X20;bl_0<0_Kfm=038h=P302TY
:@809RHV0`0f=SH203Lg=`<0:2PX0`0Y:BT202/[:`<0;2`/0P0c<c<304Q8B0<0J6QX0P1;Bd/303Hf
=P809BDU0`0b<S8202h^;P<0?Shn0`1GEeL204i>CP<0=CDe0P0d=3@302d];@<0?3`l0P0f=SH302l_
;`80>c/k0`0Z:RX3030`<080:RXZ0`0f=SH205UIF@<0Bd];0`0b<S8203dm?@<0CTi>0P0_;bl3034a
<@<0=cLg0P0a<C4302h^;P80@T920`0];Bd303@d=080CTi>0`1CDe<203lo?`D08b<S0`0O7al3020P
808092@T0`0c<c<207=cL`<0QXJ60`1JFUX2034a<@<0EUIF0P21PH4309nOW`<0U9BD0P1mOGd306m_
K`80MgMg0`1jNWX3092@T080]kNg0`2YZJT209fMW@<0XZ:R1@2UYJD30:^[Z`80[Zj^1P2c/k<20;Zj
^P<0_[jn0P2j^[X30;Vi^@D0^k^k0`2j^[X20:j^[P<0TY:B0P2JVYX307IfMP<0PH610P2/[:`30:^[
Z`80^;Rh0`30`<030<;2`P80_[jn0`2h^;P20:ZZZP<0Zj^[0`2QXJ4209fMW@<0VIVI0P2LW9`30::R
XP<0YJFU0P2JVYX309RHV080Vi^K0`2HV9P50:6QX@<0X:2P0P2SXj<30::RXP80Z:RX0`2ZZZX30:j^
[P80[Jf]0`2/[:`20:j^[P<0[Jf]0`2c/k<20:j^[P<0/k>c1@2`/;030;:b/P80]KFe0`2g]kL20;^k
^`<0_Kfm7038h=P001/0b>3H0`0S8b<202/[:`<0>CTi0P0c<c<302/[:`<0:2PX0P0[:b/302`/;080
<30`0`1HF5P305UIF@80Bd];0`0f=SH202/[:`<09bLW0P0e=CD304M7A`<0DE5A0P1CDe<30451@@80
;Rh^0`0];Bd3030`<080=3@d0`0g=cL203De=@<0<30`0`0Y:BT202LW9`<0?Cdm0P1?Cdl3055AD@<0
:b/[0P0m?Cd304i>CP80;Rh^0`0[:b/303Ph>080:b/[0`0f=SH204E5A@<0;bl_0`0f=SH204U9B@<0
FEUI0P0o?cl3028R8P807alO0`0R8R8301`L7080820P0`0i>CT207EeM@<0O7al0`1KFe/20410@0<0
CTi>0P26QXH309bLW0<0U9BD0P21PH4307=cL`80L71`0`20P80309FEU@80Y:BT0`2^[Zh20:NWY`<0
WinO0`2QXJ420:JVYP<0ZZZZ0P2_[jl30;6a/@<0];Bd0P2k^k/30<30`080_;bl0`2h^;P20;^k^`<0
_Kfm0`2g]kL20:n_[`<0UiNG0P2MWId306a/K0<0Ph>30P2b/[830:ZZZP80^KVi0`30`<030<;2`P80
_kno0`2g]kL20:f][@<0Z:RX0`2TY:@209nOW`D0Vi^K0`2MWId509jNWP<0Vi^K0P2HV9P309^KV`<0
X:2P0P2RXZ880:>SX`80YjNW0`2[Zj/80:b/[080[Jf]0`2^[Zh30;2`/0L0/K6a0`2b/[830;Bd]080
]kNg0`2j^[X20;bl_0<0_Kfm=038h=P302TY:@809RHV0`0f=SH203Lg=`<0:2PX0`0Y:BT202/[:`<0
;2`/0P0c<c<304Q8B0<0J6QX0P1;Bd/303Hf=P809BDU0`0b<S8202h^;P<0?Shn0`1GEeL204i>CP<0
=CDe0P0d=3@302d];@<0?3`l0P0f=SH302l_;`80>c/k0`0Z:RX3030`<080:RXZ0`0f=SH205UIF@<0
Bd];0`0b<S8203dm?@<0CTi>0P0_;bl3034a<@<0=cLg0P0a<C4302h^;P80@T920`0];Bd303@d=080
CTi>0`1CDe<203lo?`D08b<S0`0O7al3020P808092@T0`0c<c<207=cL`<0QXJ60`1JFUX2034a<@<0
EUIF0P21PH4309nOW`<0U9BD0P1mOGd306m_K`80MgMg0`1jNWX3092@T080]kNg0`2YZJT209fMW@<0
XZ:R1@2UYJD30:^[Z`80[Zj^1P2c/k<20;Zj^P<0_[jn0P2j^[X30;Vi^@D0^k^k0`2j^[X20:j^[P<0
TY:B0P2JVYX307IfMP<0PH610P2/[:`30:^[Z`80^;Rh0`30`<030<;2`P80_[jn0`2h^;P20:ZZZP<0
Zj^[0`2QXJ4209fMW@<0VIVI0P2LW9`30::RXP<0YJFU0P2JVYX309RHV080Vi^K0`2HV9P50:6QX@<0
X:2P0P2SXj<30::RXP80Z:RX0`2ZZZX30:j^[P80[Jf]0`2/[:`20:j^[P<0[Jf]0`2c/k<20:j^[P<0
/k>c1@2`/;030;:b/P80]KFe0`2g]kL20;^k^`<0_Kfm7038h=P001/0b>3H0`0V9RH202PX:0<0:RXZ
1@0[:b/502PX:0<0<c<c0P10@40307EeM@<0I6AT0P0^;Rh303@d=080;Bd]0`0`<302034a<@<0=cLg
0`1:BTX205UIF@<0B4Q80P0c<c<602h^;P80=3@d0`0j>SX203Lg=`<0<C4a0`0[:b/202TY:@<0>CTi
0P13@d<305YJFP<0;Rh^0P0d=3@303Lg=`80<c<c0`0/;2`302h^;P80>CTi0`18B4P205UIF@<0:BTY
0`0f=SH204E5A@<0EUIF0P12@T8302TY:@D08R8R0`0M7Ad202PX:0<0@d=30P2HV9P307IfMP<0CTi>
0P0G5aL303<c<`80G5aL0`2?Shl309NGU`80TI6A0`21PH4207EeM@<0MWIf0`20P80209VIV@<0[jn_
0P2ZZZX30:2PX0<0Xj>S0P2YZJT30:f][@80/K6a1P2`/;020;Zj^P<0`l?30P2n_[h30;Rh^080^[Zj
0`2l_;`30;Fe]@80/;2`0`28R8P20:2PX0<0M7Ad0`2:RXX20;>c/`<0ZZZZ0P2d];@30;Vi^@<0`L71
0P36a/H30<30`080]kNg0`2`/;030:VYZ@80Xj>S1@2OWil30:2PX0<0XZ:R0P2SXj<309fMW@80V9RH
0`2JVYX309jNWP80XJ6Q0`2TY:@20::RXP<0X:2P0P2UYJD30:ZZZP<0Zj^[0P2/[:`30:f][@D0[Zj^
0`2][Jd20:n_[`<0/K6a1@2`/;030;Fe]@80^KVi0`2k^k/50;bl_3@0b>3H0`0S8b<202PX:0<0:BTY
0P0^;Rh302TY:@D0:RXZ0`0d=3@204M7A`<0Jf][0`1OGel203/k>`<0<C4a0P0[:b/302l_;`80<30`
0`0c<c<304e=C@80G5aL0`16ATH203Hf=P<0;Bd]0`0/;2`203De=@<0>3Ph0P0j>SX302d];@<0;2`/
0P0^;Rh303<c<`80BTY:0`1DE5@302l_;`80=3@d0`0k>c/202PX:0<0;bl_0`0^;Rh203@d=0<0DE5A
0P1FEUH302XZ:P<0<S8b0P1=CDd3055AD@80@D510`0[:b/202PX:0<08b<S0`0P820202/[:`<0ADE5
0P2DU9@307]kN`<0Bd];0P0P820302`/;080IVIV0`27QhL30:2PX080T92@0`1jNWX207MgM`<0Ogmo
0`20P80209FEU@<0/K6a0P2ZZZX309fMW@D0YjNW0`2^[Zh20;6a/@<0[Zj^0`2`/;020;bl_0<0`l?3
0P2k^k/30;Rh^080^k^k1P2i^KT20:b/[0<0S8b<0P2KVi/307emO@<0R8R80P2`/;030:f][@80/K6a
0`2j^[X30<30`080aLG50`31`L420;Jf]P<0[jn_0`2YZJT20:BTY0<0X:2P0P2LW9`309^KV`<0ZJVY
0P2RXZ8309>CT`80W9bL0`2MWId309nOW`80WIfM0`2YZJT209fMW@<0XJ6Q0P2XZ:P60:VYZ@80Zj^[
1@2^[Zh30:f][@D0[Zj^0`2c/k<50;2`/0<0^KVi1@2h^;P20;Zj^P<0`l?37038h=P001/0b>3H0`0V
9RH202PX:0<0:RXZ1@0[:b/502PX:0<0<c<c0P10@40307EeM@<0I6AT0P0^;Rh303@d=080;Bd]0`0`
<302034a<@<0=cLg0`1:BTX205UIF@<0B4Q80P0c<c<602h^;P80=3@d0`0j>SX203Lg=`<0<C4a0`0[
:b/202TY:@<0>CTi0P13@d<305YJFP<0;Rh^0P0d=3@303Lg=`80<c<c0`0/;2`302h^;P80>CTi0`18
B4P205UIF@<0:BTY0`0f=SH204E5A@<0EUIF0P12@T8302TY:@D08R8R0`0M7Ad202PX:0<0@d=30P2H
V9P307IfMP<0CTi>0P0G5aL303<c<`80G5aL0`2?Shl309NGU`80TI6A0`21PH4207EeM@<0MWIf0`20
P80209VIV@<0[jn_0P2ZZZX30:2PX0<0Xj>S0P2YZJT30:f][@80/K6a1P2`/;020;Zj^P<0`l?30P2n
_[h30;Rh^080^[Zj0`2l_;`30;Fe]@80/;2`0`28R8P20:2PX0<0M7Ad0`2:RXX20;>c/`<0ZZZZ0P2d
];@30;Vi^@<0`L710P36a/H30<30`080]kNg0`2`/;030:VYZ@80Xj>S1@2OWil30:2PX0<0XZ:R0P2S
Xj<309fMW@80V9RH0`2JVYX309jNWP80XJ6Q0`2TY:@20::RXP<0X:2P0P2UYJD30:ZZZP<0Zj^[0P2/
[:`30:f][@D0[Zj^0`2][Jd20:n_[`<0/K6a1@2`/;030;Fe]@80^KVi0`2k^k/50;bl_3@0b>3H0`0S
8b<202PX:0<0:BTY0P0^;Rh302TY:@D0:RXZ0`0d=3@204M7A`<0Jf][0`1OGel203/k>`<0<C4a0P0[
:b/302l_;`80<30`0`0c<c<304e=C@80G5aL0`16ATH203Hf=P<0;Bd]0`0/;2`203De=@<0>3Ph0P0j
>SX302d];@<0;2`/0P0^;Rh303<c<`80BTY:0`1DE5@302l_;`80=3@d0`0k>c/202PX:0<0;bl_0`0^
;Rh203@d=0<0DE5A0P1FEUH302XZ:P<0<S8b0P1=CDd3055AD@80@D510`0[:b/202PX:0<08b<S0`0P
820202/[:`<0ADE50P2DU9@307]kN`<0Bd];0P0P820302`/;080IVIV0`27QhL30:2PX080T92@0`1j
NWX207MgM`<0Ogmo0`20P80209FEU@<0/K6a0P2ZZZX309fMW@D0YjNW0`2^[Zh20;6a/@<0[Zj^0`2`
/;020;bl_0<0`l?30P2k^k/30;Rh^080^k^k1P2i^KT20:b/[0<0S8b<0P2KVi/307emO@<0R8R80P2`
/;030:f][@80/K6a0`2j^[X30<30`080aLG50`31`L420;Jf]P<0[jn_0`2YZJT20:BTY0<0X:2P0P2L
W9`309^KV`<0ZJVY0P2RXZ8309>CT`80W9bL0`2MWId309nOW`80WIfM0`2YZJT209fMW@<0XJ6Q0P2X
Z:P60:VYZ@80Zj^[1@2^[Zh30:f][@D0[Zj^0`2c/k<50;2`/0<0^KVi1@2h^;P20;Zj^P<0`l?37038
h=P001/0b>3H0`0V9RH202PX:0<0:RXZ1@0[:b/502PX:0<0<c<c0P10@40307EeM@<0I6AT0P0^;Rh3
03@d=080;Bd]0`0`<302034a<@<0=cLg0`1:BTX205UIF@<0B4Q80P0c<c<602h^;P80=3@d0`0j>SX2
03Lg=`<0<C4a0`0[:b/202TY:@<0>CTi0P13@d<305YJFP<0;Rh^0P0d=3@303Lg=`80<c<c0`0/;2`3
02h^;P80>CTi0`18B4P205UIF@<0:BTY0`0f=SH204E5A@<0EUIF0P12@T8302TY:@D08R8R0`0M7Ad2
02PX:0<0@d=30P2HV9P307IfMP<0CTi>0P0G5aL303<c<`80G5aL0`2?Shl309NGU`80TI6A0`21PH42
07EeM@<0MWIf0`20P80209VIV@<0[jn_0P2ZZZX30:2PX0<0Xj>S0P2YZJT30:f][@80/K6a1P2`/;02
0;Zj^P<0`l?30P2n_[h30;Rh^080^[Zj0`2l_;`30;Fe]@80/;2`0`28R8P20:2PX0<0M7Ad0`2:RXX2
0;>c/`<0ZZZZ0P2d];@30;Vi^@<0`L710P36a/H30<30`080]kNg0`2`/;030:VYZ@80Xj>S1@2OWil3
0:2PX0<0XZ:R0P2SXj<309fMW@80V9RH0`2JVYX309jNWP80XJ6Q0`2TY:@20::RXP<0X:2P0P2UYJD3
0:ZZZP<0Zj^[0P2/[:`30:f][@D0[Zj^0`2][Jd20:n_[`<0/K6a1@2`/;030;Fe]@80^KVi0`2k^k/5
0;bl_3@0b>3H0`0S8b<202PX:0<0:BTY0P0^;Rh302TY:@D0:RXZ0`0d=3@204M7A`<0Jf][0`1OGel2
03/k>`<0<C4a0P0[:b/302l_;`80<30`0`0c<c<304e=C@80G5aL0`16ATH203Hf=P<0;Bd]0`0/;2`2
03De=@<0>3Ph0P0j>SX302d];@<0;2`/0P0^;Rh303<c<`80BTY:0`1DE5@302l_;`80=3@d0`0k>c/2
02PX:0<0;bl_0`0^;Rh203@d=0<0DE5A0P1FEUH302XZ:P<0<S8b0P1=CDd3055AD@80@D510`0[:b/2
02PX:0<08b<S0`0P820202/[:`<0ADE50P2DU9@307]kN`<0Bd];0P0P820302`/;080IVIV0`27QhL3
0:2PX080T92@0`1jNWX207MgM`<0Ogmo0`20P80209FEU@<0/K6a0P2ZZZX309fMW@D0YjNW0`2^[Zh2
0;6a/@<0[Zj^0`2`/;020;bl_0<0`l?30P2k^k/30;Rh^080^k^k1P2i^KT20:b/[0<0S8b<0P2KVi/3
07emO@<0R8R80P2`/;030:f][@80/K6a0`2j^[X30<30`080aLG50`31`L420;Jf]P<0[jn_0`2YZJT2
0:BTY0<0X:2P0P2LW9`309^KV`<0ZJVY0P2RXZ8309>CT`80W9bL0`2MWId309nOW`80WIfM0`2YZJT2
09fMW@<0XJ6Q0P2XZ:P60:VYZ@80Zj^[1@2^[Zh30:f][@D0[Zj^0`2c/k<50;2`/0<0^KVi1@2h^;P2
0;Zj^P<0`l?37038h=P001/0b>3H0`0V9RH202LW9`<0:2PX0P0Y:BT302XZ:P<09bLW0P0Y:BT30410
@080E5AD0`1XJ6P3051@D080=cLg0`12@T8203Xj>P<0=3@d0P0_;bl302h^;P<0?Shn0P1<C4`30492
@P80=CDe0`0_;bl302h^;P80=3@d0`0j>SX203Ph>0<0=3@d0`0`<30202h^;P<0=SHf0P0n?Sh3051@
D0<0?Cdm0P0j>SX303@d=080;Rh^0`0V9RH302`/;080>SXj0`1MGEd205iNGP<0=3@d0`19BDT204Y:
BP<0BDU90P12@T8303Ti>@80;Bd]0`0U9BD302/[:`80>CTi0`1ZJVX209BDU0<0IfMW0`0f=SH201<C
4`<09BDU0P10@40306UYJ@<0QXJ60P2FUYH309bLW080NGUi1P1dM7@208J6QP<0VYZJ0P2WYjL30:n_
[`<0[:b/0P2XZ:P30:ZZZP80[Zj^0`2`/;030;>c/`80^[Zj0`30`<020;fm_@<0^KVi0P2g]kL30;Jf
]PD0];Bd0`27QhL209jNWP<0Ph>30`2;Rh/20;>c/`<0XZ:R0P2/[:`30;>c/`<0_[jn0P36a/H30<G5
a@80_kno0`2f][H30:^[Z`80YZJV0`2RXZ820:6QX@<0XZ:R0`2SXj<20:BTY0<0XJ6Q0P2NWYh309VI
V@<0UiNG0P2LW9`30:6QX@80X:2P0`2OWil20:>SX`<0YjNW1@2YZJT30:^[Z`P0[Jf]0P2^[Zh30:n_
[`80/K6a0`2c/k<30;Jf]P80^KVi0`2l_;`20;fm_@<0_[jn=038h=P302/[:`80:2PX1@0[:b/302TY
:@<0:RXZ0P0[:b/303<c<`80FUYJ0`1/K6`304e=C@80?clo0`0n?Sh203dm?@<0=3@d0P0_;bl303lo
?`<0@D510P18B4P304];B`80<C4a0`0_;bl302XZ:P80<S8b0`0i>CT204M7A`<0<S8b0`0a<C4202`/
;0<0<30`0P0m?Cd3059BDP<0?clo1@0h>3P202l_;`<0:2PX0`0/;2`203Ph>0<0J6QX0P1QHF4302h^
;P<0BTY:0P1ADE4304a<C080B4Q80`0_;bl202LW9`<08R8R0`0T92@202h^;P<0KVi^0P2ATI4306UY
J@<0;Rh^0P0M7Ad302<S8`80=SHf0`1YJFT308Z:RP80XZ:R0`2:RXX207QhN0<0NWYj0`1bLW8207]k
N`<0UYJF0P2j^[X30:^[Z`D0YZJV0`2/[:`20:f][@<0[:b/0`2c/k<20;no_`<0`/;20P2l_;`50;Zj
^P<0];Bd0`2i^KT20:n_[`<0RHV90P2HV9P308N7Q`<0Rh^;0P2ZZZX30:JVYP80[Jf]0`2d];@30;bl
_080aLG50`39bLT20<30`0<0/[:b0`2/[:`20:NWY`<0XZ:R0P2QXJ4309nOW`<0XJ6Q0P2ZZZX30::R
XP80W9bL0`2FUYH309VIV@80Vi^K0`2QXJ420:2PX0<0W9bL0P2SXj<30:JVYP<0ZJVY0P2ZZZX30:^[
Z`80[Zj^0`2ZZZX30:j^[P80[:b/0`2`/;020:^[Z`<0/[:b0`2m_Kd20;^k^`<0^;Rh0P2o_kl30<71
`A`0b>3H000K0<SPf0<09RHV0P0W9bL302PX:080:BTY0`0Z:RX302LW9`80:BTY0`10@40205ADE0<0
J6QX0`1@D50203Lg=`<0@T920P0j>SX303@d=080;bl_0`0^;Rh303hn?P80C4a<0`12@T8203De=@<0
;bl_0`0^;Rh203@d=0<0>SXj0P0h>3P303@d=0<0<30`0P0^;Rh303Hf=P80?Shn0`1@D50303dm?@80
>SXj0`0d=3@202h^;P<09RHV0`0/;2`203Xj>P<0GEeM0P1NGUh303@d=0<0BDU90P1:BTX304U9B@80
@T920`0i>CT202d];@<09BDU0`0[:b/203Ti>@<0JVYZ0P2DU9@306MWI`<0=SHf0P0C4a<302DU9@80
@4100`1YJFT308J6QP80UYJF0`2LW9`207UiN@H0M7Ad0P26QXH309ZJVP80YjNW0`2_[jl30:b/[080
Z:RX0`2ZZZX20:j^[P<0/;2`0`2c/k<20;Zj^P<0`<300P2m_Kd30;Vi^@80]kNg0`2f][H50;Bd]0<0
QhN70P2NWYh308>3P`<0Rh^;0P2c/k<30::RXP80[:b/0`2c/k<30;jn_P80a/K60`35aLD20;no_`<0
][Jf0`2[Zj/20:JVYP<0XZ:R0P2QXJ430::RXP<0Xj>S0P2TY:@30:6QX@80WYjN0`2IVIT309NGU`80
W9bL0`2QXJ420:2PX0<0WinO0P2SXj<30:NWY`D0ZJVY0`2[Zj/80:f][@80[Zj^0`2_[jl20;6a/@<0
/k>c0`2f][H20;Vi^@<0_;bl0P2m_Kd30;jn_S@0b>3H0`0[:b/202PX:0D0:b/[0`0Y:BT302XZ:P80
:b/[0`0c<c<205YJFP<0K6a/0`1=CDd203lo?`<0?Shn0P0m?Cd303@d=080;bl_0`0o?cl30451@@80
B4Q80`1;Bd/2034a<@<0;bl_0`0Z:RX2038b<P<0>CTi0P17AdL3038b<P<0<C4a0P0/;2`3030`<080
?Cdm0`1BDU8303lo?`D0>3Ph0P0_;bl302PX:0<0;2`/0P0h>3P306QXJ080HF5Q0`0^;Rh304Y:BP80
DE5A0`1<C4`204Q8B0<0;bl_0P0W9bL3028R8P<092@T0P0^;Rh306i^KP80TI6A0`1YJFT302h^;P80
7AdM0`0S8b<203Hf=P<0JFUY0`2:RXX20::RXP<0RXZ:0P1hN7P307YjNP<0LW9b0P1kNg/309JFUP80
^[Zj0`2[Zj/50:JVYP<0[:b/0P2][Jd30:b/[0<0/k>c0P2o_kl30<;2`P80_;bl1@2j^[X30;Bd]0<0
^KVi0P2_[jl308V9R@80V9RH0`27QhL308^;R`80ZZZZ0`2VYZH20:f][@<0];Bd0`2l_;`20<G5a@<0
bLW90P30`<030;:b/P<0[:b/0P2WYjL30::RXP80XJ6Q0`2OWil30:6QX@80ZZZZ0`2RXZ8209bLW0<0
UYJF0`2IVIT209^KV`<0XJ6Q0P2PX:0309bLW080Xj>S0`2VYZH30:VYZ@80ZZZZ0`2[Zj/20:j^[P<0
ZZZZ0`2^[Zh20:b/[0<0/;2`0P2[Zj/30;:b/P<0_Kfm0P2k^k/30;Rh^080_kno0`31`L4L0<SPf000
6`38h=P502LW9`<0:2PX0P0Y:BT302XZ:P<09bLW0P0[:b/304a<C080IfMW0`1BDU8303Ph>080@d=3
0`1=CDd204A4A0<0>3Ph0P0`<30302/[:`<0<c<c0P0l?3`303/k>`80=cLg0`0a<C4302d];@80<S8b
1@0i>CT303Ph>0<0=3@d0P0b<S8303De=@80>SXj0`12@T8304Y:BP80@D510`0e=CD202TY:@<08R8R
0`0/;2`203Xj>P<0Jf][0P1MGEd304A4A0<0GEeM0P1?Cdl30451@@80AdM70`1<C4`203Ti>@<0:BTY
0`0g=cL204U9B@<0Shn?0P27QhL305YJFP<08b<S0P0J6QX301dM7@80:BTY0`0o?cl306a/K080T92@
0`2_[jl20861P@<0N7Qh0`1`L70207EeM@<0Ph>30P2PX:030;Vi^@<0];Bd0P2YZJT30:NWY`80ZJVY
0`2`/;030;Ng]`80^k^k0`2l_;`20;^k^`<0^KVi0P2d];@30;2`/0<0/k>c0P2g]kL308^;R`80VYZJ
0`2BTY8308f=S@80/;2`0`2KVi/20:JVYP<0[jn_0`2k^k/20<G5a@<0b<S80P36a/H30;^k^`<0[jn_
0P2XZ:P=0:BTY0<0YJFU0P2TY:@309ZJVP<0TY:B0P2FUYH509fMW@<0WYjN0P2QXJ430:BTY0<0YJFU
0P2VYZH30:VYZ@80Zj^[1P2/[:`20:f][@<0[Zj^0P2b/[830;Ng]`<0^;Rh0P2i^KT30;bl_080_kno
0`30`<0d0<SPf0<09BDU0P0W9bL302TY:@808b<S0`0];Bd302PX:080;bl_0`15ADD206QXJ0<0EeMG
0`0c<c<204M7A`<0Bd];0P1>CTh303De=@80:b/[0`0/;2`302l_;`80>SXj0`12@T88034a<@80<30`
0`0i>CT203Ph>0<0=CDe0`0f=SH203<c<`<0<S8b0P0i>CT304Q8B0<0Bd];0P0j>SX303Ti>@809RHV
0`0W9bL302`/;080>3Ph0`1ZJVX205]KF`<0?3`l0`1WIfL204=3@`<0@T920P1ADE4304M7A`80=cLg
0`0c<c<303@d=080Cdm?0`2JVYX208R8R0<0DE5A0`0Z:RX201lO7`<08B4Q0P0P82030451@@<0N7Qh
0P2;Rh/30:ZZZP80QHF50`1iNGT3071`L080MgMg0`21PH420::RXP<0][Jf0`2c/k<70:ZZZP<0[Jf]
0`2k^k/20;Rh^0<0^k^k0P2n_[h50;Bd]0<0[Jf]0`2f][H20;:b/P<0Ti>C0P2JVYX308n?S`<0UIFE
0P2WYjL30:6QX@80Y:BT0`2b/[830;Vi^@D0a/K60P35aLD30;bl_0<0[Zj^0P2ZZZX30::RXP80YJFU
0`2VYZH30:6QX@80Y:BT0`2VYZH20:NWY`<0UiNG0`2CTi<509ZJVP80WYjN0`2KVi/20:FUY@<0XZ:R
0`2YZJT20:FUY@<0Z:RX0P2[Zj/30:f][@<0[jn_0P2[Zj/30:f][@80];Bd0`2e]KD30;Rh^080]kNg
0`2l_;`20;jn_P<0`l?37038h=P001/0b>3H1@0W9bL302PX:080:BTY0`0Z:RX302LW9`80:b/[0`1<
C4`206MWI`<0DU9B0`0h>3P204=3@`<0CDe=0P14A4@303Ph>080<30`0`0[:b/303<c<`80?3`l0`0k
>c/203Lg=`<0<C4a0`0];Bd2038b<PD0>CTi0`0h>3P303@d=080<S8b0`0e=CD203Xj>P<0@T920`1:
BTX20451@@<0=CDe0P0Y:BT3028R8P<0;2`/0P0j>SX306][J`80GEeM0`14A4@305eMG@80Cdm?0`11
@D4204M7A`<0C4a<0P0i>CT302TY:@<0=cLg0P19BDT308n?S`80QhN70`1JFUX302<S8`806QXJ0`0M
7Ad202TY:@<0?clo0`1/K6`2092@T0<0[jn_0P21PH4307QhN0<0L71`0P1eMGD308>3P`80X:2P0`2i
^KT30;Bd]080ZJVY0`2WYjL20:VYZ@<0/;2`0`2g]kL20;^k^`<0_;bl0P2k^k/30;Vi^@80];Bd0`2`
/;030;>c/`80]kNg0`2;Rh/209ZJVP<0TY:B0`2=SHd20;2`/0<0Vi^K0P2VYZH30:n_[`<0^k^k0P35
aLD30<S8b080a/K60`2k^k/30:n_[`80Z:RX3@2TY:@30:FUY@80Y:BT0`2JVYX309:BTP80UYJF1@2M
WId309jNWP80XJ6Q0`2TY:@30:FUY@80YZJV0`2YZJT20:^[Z`H0[:b/0P2][Jd30:j^[P80/[:b0`2g
]kL30;Rh^080^KVi0`2l_;`20;no_`<0`<30=038h=P302DU9@809bLW0`0Y:BT202<S8`<0;Bd]0`0X
:2P202l_;`<0ADE50P1XJ6P305MGE`<0<c<c0P17AdL304];B`80CTi>0`0e=CD202/[:`<0;2`/0`0_
;bl203Xj>P<0@T92200a<C42030`<0<0>CTi0P0h>3P303De=@<0=SHf0P0c<c<3038b<P80>CTi0`18
B4P304];B`80>SXj0`0i>CT202HV9P<09bLW0`0/;2`203Ph>0<0JVYZ0P1KFe/303`l?0<0IfMW0P13
@d<30492@P80DE5A0`17AdL203Lg=`<0<c<c0`0d=3@204m?C`<0VYZJ0P28R8P3055AD@<0:RXZ0P0O
7al3024Q8@80820P0`11@D4307QhN080Rh^;0`2ZZZX208F5Q@<0NGUi0`1`L70207MgM`<0PH610P2R
XZ830;Jf]P<0/k>c1`2ZZZX30:f][@<0^k^k0P2h^;P30;^k^`80_[jn1@2d];@30:f][@<0][Jf0P2b
/[8309>CT`80VYZJ0`2?Shl309FEU@80YjNW0`2QXJ420:BTY0<0/[:b0`2i^KT50<K6aP80aLG50`2l
_;`30:j^[P80ZZZZ0`2RXZ820:FUY@<0YZJV0`2QXJ420:BTY0<0YZJV0P2WYjL309NGU`<0Ti>C1@2J
VYX209jNWP<0Vi^K0P2UYJD30::RXP<0ZJVY0P2UYJD30:RXZ080Zj^[0`2][Jd30:n_[`80Zj^[0`2]
[Jd20;Bd]0<0]KFe0`2h^;P20;Ng]`<0_;bl0P2n_[h30<?3`a`0b>3H000K0<SPf0D09bLW0`0X:2P2
02TY:@<0:RXZ0`0W9bL202/[:`<0C4a<0P1WIfL3059BDP<0>3Ph0P13@d<304e=C@80A4A40`0h>3P2
030`<0<0:b/[0`0c<c<203`l?0<0>c/k0P0g=cL3034a<@<0;Bd]0P0b<S8503Ti>@<0>3Ph0`0d=3@2
038b<P<0=CDe0P0j>SX30492@P<0BTY:0P11@D4303De=@80:BTY0`0R8R8302`/;080>SXj0`1[Jf/2
05eMG@<0A4A40`1MGEd204m?C`<0@D510P17AdL304a<C080>CTi0`0Y:BT303Lg=`80BDU90`2?Shl2
08N7Q`<0FUYJ0`0S8b<201XJ6P<07AdM0P0Y:BT303lo?`<0K6a/0P2@T9030:n_[`80PH610`1hN7P3
071`L080MGEe0`23Ph<20:2PX0<0^KVi0`2d];@20:VYZ@<0YjNW0P2YZJT30;2`/0<0]kNg0P2k^k/3
0;bl_080^k^k0`2i^KT20;Bd]0<0/;2`0`2c/k<20;Ng]`<0Rh^;0P2JVYX309:BTP<0SHf=0P2`/;03
09^KV`80YZJV0`2_[jl30;^k^`80aLG50`38b<P20<K6aP<0^k^k0`2_[jl20:RXZ0d0Y:BT0`2UYJD2
0:BTY0<0VYZJ0`2BTY8209JFUPD0WIfM0`2NWYh20:6QX@<0Y:BT0`2UYJD20:JVYP<0ZJVY0P2[Zj/6
0:b/[080[Jf]0`2^[Zh20;:b/P<0]kNg0`2h^;P20;Vi^@<0_;bl0P2o_kl30<30`3@0b>3H0`0U9BD2
02LW9`<0:BTY0P0S8b<302d];@<0:2PX0P0_;bl304E5A@80J6QX0`1GEeL303<c<`80AdM70`1;Bd/2
04i>CP<0=CDe0P0[:b/302`/;0<0;bl_0P0j>SX30492@PP0<C4a0P0`<30303Ti>@80>3Ph0`0e=CD3
03Hf=P80<c<c0`0b<S8203Ti>@<0B4Q80`1;Bd/203Xj>P<0>CTi0P0V9RH302LW9`<0;2`/0P0h>3P3
06YZJP80Fe]K0`0l?3`306MWI`80@d=30`12@T82055AD@<0AdM70P0g=cL303<c<`<0=3@d0P1?Cdl3
09ZJVP80R8R80`1ADE4302XZ:P807alO0`0Q8B42020P80<0@D510`1hN7P208^;R`<0ZZZZ0P25QHD3
07UiN@<0L71`0P1gMgL30861P@80XZ:R0`2f][H30;>c/`L0ZZZZ0`2][Jd30;^k^`80^;Rh0`2k^k/2
0;jn_PD0];Bd0`2][Jd30;Jf]P80/[:b0`2CTi<209ZJVP<0Shn?0`2EUID20:NWY`<0XJ6Q0P2TY:@3
0;:b/P<0^KVi1@36a/H20<G5a@<0_;bl0`2^[Zh20:ZZZP<0XZ:R0P2UYJD30:JVYP<0XJ6Q0P2TY:@3
0:JVYP80YjNW0`2GUiL309>CT`D0VYZJ0P2NWYh309^KV`80YJFU0`2RXZ830:VYZ@80YJFU0`2XZ:P2
0:^[Z`<0[Jf]0`2_[jl20:^[Z`<0[Jf]0P2d];@30;Fe]@<0^;Rh0P2g]kL30;bl_080_[jn0`33`l<L
0<SPf0006`38h=P302/[:`80:2PX0`0V9RH202PX:0<0:b/[0`0X:2P202d];@<0Cdm?0P1aLG430410
@0<0<30`0P0e=CD303`l?080>c/k0`0i>CT203Hf=P<0<c<c0`0b<S8203<c<`<0>SXj0P0o?cl303De
=@<0:b/[0P0_;bl303De=@80>CTi0`0j>SX303Hf=P80<S8b0`0a<C4203<c<`<0?3`l0`17AdL203lo
?`<0<c<c0P0Z:RX302LW9`<0=CDe0P15ADD305iNGP80EEEE0`1=CDd3061PH080AdM70`1ADE4205EE
E@<0F5QH0P1GEeL305]KF`<0G5aL0P1hN7P30:ZZZP80Rh^;0`1PH60302TY:@807alO0`0L71`201dM
7@<0:BTY0`1=CDd2079bLP<0Vi^K0P2FUYH308V9R@<0MWIf0P1bLW8307MgM`80SXj>0`2VYZH30;>c
/`80^KVi0`2_[jl20:FUY@<0[Jf]0`2h^;P20;Zj^P<0^KVi0P2h^;P30;Jf]P80/[:b0`2`/;030;Bd
]080][Jf0`2FUYH209:BTP<0UIFE0`2GUiL20:VYZ@<0WYjN0P2WYjL30:n_[`<0^[Zj0P33`l<50<S8
b0<0`L710`2h^;P20:j^[P<0YJFU0P2VYZH60:RXZ080YZJV0`2UYJD20:>SX`<0WYjN0`2IVIT209NG
U`<0UYJF0P2HV9P309bLW080WinO202SXj<30:NWY`d0Zj^[0P2a/K430;Jf]P<0^;Rh0P2j^[X30;fm
_@D0`<30=038h=P302/[:`809bLW0`0U9BD202`/;0H0:BTY0P0a<C4304e=C@80KVi^0`19BDT302`/
;080<c<c0`0f=SH203Ph>0<0?Shn0P0c<c<302h^;P<0;Bd]0P0e=CD303dm?@80AdM70`0`<30302d]
;@80<c<c0`0g=cL203<c<`<0>SXj0`12@T85034a<@80=cLg0`0k>c/304Q8B080?Cdm0`0e=CD202HV
9P<092@T0`0^;Rh204M7A`<0JFUY0P1IFET304i>CP<0I6AT0P0l?3`304];B`80FEUI0`1QHF4205eM
G@H0EUIF0P1gMgL30:JVYP80RXZ:0`1NGUh302LW9`807AdM0`0N7Qh2020P80<0:RXZ0`16ATH207If
MP<0VYZJ0P2KVi/308>3P`<0N7Qh0P1kNg/307QhN080PH610`2ZZZX30;jn_P80][Jf0`2UYJD20:ZZ
ZP<0[:b/0`2i^KT20;>c/`<0^;Rh0P2k^k/30;Jf]P80]KFe0`2/[:`30;Fe]@80/k>c0`2IVIT2096A
T@<0TY:B0`2HV9P20:NWY`<0X:2P0P2SXj<30:j^[P<0][Jf0P33`l<30<W9b@80alO70`33`l<30;Jf
]P80[Jf]0`2UYJD20:NWY`<0Z:RX0`2YZJT20:BTY0<0WinO0P2PX:030:JVYP<0U9BD0P2CTi<309RH
V080Vi^K0`2LW9`20:2PX0<0WinO0`2SXj<20::RXP<0YZJV0P2][Jd30:ZZZP<0ZJVY0P2XZ:P30:j^
[P80/k>c0`2g]kL30;Bd]080^[Zj0`2k^k/20;fm_@<0_kno7038h=P001/0b>3H0`0[:b/202PX:0<0
9RHV0P0X:2P302/[:`<0:2PX0P0];Bd304m?C`80LG5a0`10@403030`<080=CDe0`0l?3`203/k>`<0
>CTi0P0f=SH303<c<`<0<S8b0P0c<c<303Xj>P80?clo0`0e=CD302/[:`80;bl_0`0e=CD203Ti>@<0
>SXj0`0f=SH2038b<P<0<C4a0P0c<c<303`l?0<0AdM70P0o?cl303<c<`80:RXZ0`0W9bL303De=@80
ADE50`1NGUh205EEE@<0CDe=0`1PH60204M7A`<0DE5A0P1EEED305QHF080EeMG0`1KFe/305aLG080
N7Qh0`2ZZZX208^;R`<0H61P0`0Y:BT201lO7`<071`L0P0M7Ad302TY:@<0CDe=0P1bLW8309^KV`80
UYJF0`29RHT307IfMP80LW9b0`1gMgL208j>SP<0YZJV0`2c/k<20;Vi^@<0[jn_0P2UYJD30:f][@<0
^;Rh0P2j^[X30;Vi^@80^;Rh0`2f][H20;:b/P<0/;2`0`2d];@20;Jf]P<0UYJF0P2BTY8309FEU@<0
UiNG0P2YZJT309jNWP80YjNW0`2_[jl30;Zj^P80`l?31@38b<P30<71`@<0^;Rh0P2^[Zh30:FUY@80
YZJV1P2XZ:P20:JVYP<0YJFU0P2SXj<309jNWP<0VIVI0P2GUiL309JFUP80V9RH0`2LW9`209nOW`P0
Xj>S0`2WYjL=0:^[Z`80/K6a0`2f][H30;Rh^080^[Zj0`2m_Kd50<30`3@0b>3H0`0[:b/202LW9`<0
9BDU0P0/;2`602TY:@80<C4a0`1=CDd206i^KP<0BDU90`0/;2`203<c<`<0=SHf0P0h>3P303hn?P80
<c<c0`0^;Rh302d];@80=CDe0`0m?Cd204M7A`<0<30`0`0];Bd203<c<`<0=cLg0P0c<c<303Xj>P<0
@T921@0a<C4203Lg=`<0>c/k0`18B4P203dm?@<0=CDe0P0V9RH302@T90<0;Rh^0P17AdL306UYJ@80
FEUI0`1>CTh306ATI080?3`l0`1;Bd/205UIF@<0HF5Q0P1MGEd605IFEP80MgMg0`2VYZH208Z:RP<0
GUiN0`0W9bL201dM7@<07QhN0P0P820302XZ:P<0ATI60P1fMWH309ZJVP80Vi^K0`23Ph<307QhN080
Ng]k0`1hN7P20861P@<0ZZZZ0`2n_[h20;Jf]P<0YJFU0P2ZZZX30:b/[0<0^KVi0P2c/k<30;Rh^080
^k^k0`2f][H20;Fe]@<0[:b/0`2e]KD20;>c/`<0VIVI0P2ATI4309:BTP<0V9RH0P2WYjL30:2PX080
Xj>S0`2^[Zh30;Jf]P80`l?30`39bLT20<O7a`<0`l?30`2f][H20:f][@<0YJFU0P2WYjL30:RXZ0<0
ZJVY0P2TY:@309nOW`80X:2P0`2VYZH309BDU080Ti>C0`2HV9P209^KV`<0W9bL0P2PX:0309nOW`<0
Xj>S0P2RXZ830:JVYP80[Jf]0`2ZZZX30:VYZ@80Z:RX0`2^[Zh20;>c/`<0]kNg0`2d];@20;Zj^P<0
^k^k0P2m_Kd30;no_a`0b>3H000K0<SPf0<0:b/[0P0X:2P302HV9P80:2PX0`0[:b/302PX:080;Bd]
0`1?Cdl2075aL@<0@4100`0`<30203De=@<0?3`l0P0k>c/303Ti>@80=SHf0`0c<c<3038b<P80<c<c
0`0j>SX203lo?`<0=CDe0`0[:b/202l_;`<0=CDe0P0i>CT303Xj>P<0=SHf0P0b<S83034a<@80<c<c
0`0l?3`304M7A`80?clo0`0c<c<202XZ:P<09bLW0`0e=CD204E5A@<0GUiN0P1EEED304e=C@<0H61P
0P17AdL3055AD@80EEEE0`1HF5P205MGE`<0Fe]K0`1LG5`207QhN0<0ZZZZ0P2;Rh/3061PH0<0:BTY
0P0O7al301`L70807AdM0`0Y:BT304e=C@80LW9b0`2KVi/209JFUP<0RHV90`1fMWH2079bLP<0MgMg
0P2>SXh30:JVYP<0/k>c0P2i^KT30:n_[`80YJFU0`2][Jd30;Rh^080^[Zj0`2i^KT20;Rh^0<0][Jf
0P2b/[830;2`/0<0];Bd0P2f][H309JFUP80TY:B0`2EUID309NGU`80ZJVY0`2NWYh20:NWY`<0[jn_
0`2j^[X20<?3``D0b<S80`31`L430;Rh^080[Zj^0`2UYJD20:JVYPH0Z:RX0P2VYZH30:FUY@80Xj>S
0`2NWYh309VIV@80UiNG0`2FUYH209RHV0<0W9bL0P2OWil80:>SX`<0YjNW3@2[Zj/20;6a/@<0][Jf
0`2h^;P20;Zj^P<0_Kfm1@30`<0d0<SPf0<0:b/[0P0W9bL302DU9@80;2`/1P0Y:BT2034a<@<0CDe=
0P1^KVh304U9B@<0;2`/0P0c<c<303Hf=P80>3Ph0`0n?Sh203<c<`<0;Rh^0`0];Bd203De=@<0?Cdm
0P17AdL3030`<0<0;Bd]0P0c<c<303Lg=`80<c<c0`0j>SX30492@PD0<C4a0P0g=cL303/k>`<0B4Q8
0P0m?Cd303De=@809RHV0`0T92@302h^;P80AdM70`1YJFT205UIF@<0CTi>0`1TI6@203`l?0<0Bd];
0P1IFET3065QH@80GEeM1P1FEUH207MgM`<0YZJV0P2:RXX305iNGP<09bLW0P0M7Ad301hN7P80820P
0`0Z:RX304I6AP80MWIf0`2JVYX209^KV`<0Ph>30`1hN7P207]kN`<0N7Qh0P21PH430:ZZZP<0_[jn
0P2f][H30:FUY@80ZZZZ0`2/[:`30;Vi^@80/k>c0`2h^;P20;^k^`<0][Jf0P2e]KD30:b/[0<0]KFe
0P2c/k<309VIV@80TI6A0`2BTY8309RHV080YjNW0`2PX:020:>SX`<0[Zj^0`2f][H20<?3``<0bLW9
0P37alL30<?3``<0][Jf0P2][Jd30:FUY@80YjNW0`2XZ:P30:VYZ@80Y:BT0`2OWil20:2PX0<0YZJV
0`2DU9@209>CT`<0V9RH0P2KVi/309bLW080X:2P0`2OWil30:>SX`80XZ:R0`2VYZH20:f][@<0ZZZZ
0`2YZJT20:RXZ0<0[Zj^0P2c/k<30;Ng]`<0];Bd0P2j^[X30;^k^`80_Kfm0`2o_klL0<SPf0006`38
h=P302l_;`80:RXZ0`0U9BD202PX:0<0;Bd]0`0Z:RX202l_;`<0DU9B0P1cLg<303@d=0<0;Bd]0P0U
9BD302TY:@80;bl_0`0g=cL203`l?0<0?Shn0`0f=SH202l_;`<0>c/k0P15ADD303Ti>@<0:RXZ0P0/
;2`3038b<P80=cLg0`0k>c/303Lg=`80<S8b0`0^;Rh202d];@<0=cLg0`10@40203/k>`<0<c<c1@0^
;Rh303`l?0D0C4a<0P1>CTh305IFEP<0H61P0P14A4@306MWI`80IFEU0`1PH602059BDP<0Bd];0`0i
>CT206IVIP<0W9bL0P2=SHd306MWI`<0<c<c0P0S8b<301dM7@8061PH0`0M7Ad3034a<@80Cdm?0`1k
Ng/20:6QX@<0V9RH0`23Ph<207MgM`<0LW9b0P1lO7`308j>SP<0[:b/0P33`l<30;Jf]P80Y:BT0`2/
[:`30;Ng]`80^;Rh0`2g]kL20;Bd]0<0/K6a1@2`/;030;>c/`80/[:b0`2OWil208^;R`<0U9BD1@2R
XZ830:FUY@80ZZZZ0`2`/;030;Vi^@80`L710`35aLD20<O7a`<0aLG50`30`<020;:b/P<0YZJV0P2X
Z:P30:b/[0<0Zj^[0P2YZJT30:FUY@80XZ:R1P2SXj<209^KV`<0Ti>C0P2EUID309VIV@80WIfM202Q
XJ430:JVYPD0ZZZZ1@2YZJT30:ZZZP80[jn_0`2e]KD30;Rh^080^k^k0`2n_[h20<30`0<0`L71=038
h=P302d];@80:BTY0`0V9RH202LW9`<0;Rh^0`0X:2P202/[:`<0EeMG0P1^KVh303hn?P<09bLW0P0[
:b/302h^;P80:RXZ0`0h>3P20410@0<0?clo0`0_;bl203De=@<0=cLg0P14A4@303@d=0<0;2`/0P0_
;bl303@d=080>3Ph0`0m?Cd303Lg=`80<C4a0`0b<S82034a<@<0;Rh^0`14A4@203`l?0<0<C4a0P0^
;Rh3034a<@<0?3`l0P1;Bd/305EEE@80B4Q80`1IFET305]KF`80ADE50`1XJ6P206EUI@<0GemO0P1B
DU8305=CD`<0?Shn0P1XJ6P30:BTY080S8b<0`1_Kfl303Hf=P808b<S1@0M7Ad3020P80<0:BTY0P1B
DU8308F5Q@80UiNG0`2KVi/30820P080NGUi0`1bLW8207]kN`<0SXj>0`2_[jl20<30`0<0]kNg0P2V
YZH30:b/[0<0^;Rh0P2e]KD30;Zj^P80/;2`0`2b/[820;2`/0H0/k>c0P2a/K430:6QX@80SHf=0`2@
T9030:BTY0D0YZJV0P2ZZZX30;6a/@<0]kNg0P30`<030<O7a`80aLG50`3:b/X30;jn_P80/;2`0`2X
Z:P20:JVYPH0[Jf]0P2[Zj/30:BTY080XZ:R0`2SXj<30:BTY080WIfM0`2EUID209:BTP<0Vi^K0P2L
W9`30:6QX@<0X:2P0P2RXZ830:JVYP80ZZZZ1P2[Zj/20:ZZZP<0Z:RX0P2/[:`30;Bd]0<0^;Rh0P2k
^k/30;fm_@80`<300`31`L4L0<SPf0006`38h=P302l_;`80:RXZ0`0U9BD202PX:0<0;Bd]0`0Z:RX2
02l_;`<0DU9B0P1cLg<303@d=0<0;Bd]0P0U9BD302TY:@80;bl_0`0g=cL203`l?0<0?Shn0`0f=SH2
02l_;`<0>c/k0P15ADD303Ti>@<0:RXZ0P0/;2`3038b<P80=cLg0`0k>c/303Lg=`80<S8b0`0^;Rh2
02d];@<0=cLg0`10@40203/k>`<0<c<c1@0^;Rh303`l?0D0C4a<0P1>CTh305IFEP<0H61P0P14A4@3
06MWI`80IFEU0`1PH602059BDP<0Bd];0`0i>CT206IVIP<0W9bL0P2=SHd306MWI`<0<c<c0P0S8b<3
01dM7@8061PH0`0M7Ad3034a<@80Cdm?0`1kNg/20:6QX@<0V9RH0`23Ph<207MgM`<0LW9b0P1lO7`3
08j>SP<0[:b/0P33`l<30;Jf]P80Y:BT0`2/[:`30;Ng]`80^;Rh0`2g]kL20;Bd]0<0/K6a1@2`/;03
0;>c/`80/[:b0`2OWil208^;R`<0U9BD1@2RXZ830:FUY@80ZZZZ0`2`/;030;Vi^@80`L710`35aLD2
0<O7a`<0aLG50`30`<020;:b/P<0YZJV0P2XZ:P30:b/[0<0Zj^[0P2YZJT30:FUY@80XZ:R1P2SXj<2
09^KV`<0Ti>C0P2EUID309VIV@80WIfM202QXJ430:JVYPD0ZZZZ1@2YZJT30:ZZZP80[jn_0`2e]KD3
0;Rh^080^k^k0`2n_[h20<30`0<0`L71=038h=P302d];@80:BTY0`0V9RH202LW9`<0;Rh^0`0X:2P2
02/[:`<0EeMG0P1^KVh303hn?P<09bLW0P0[:b/302h^;P80:RXZ0`0h>3P20410@0<0?clo0`0_;bl2
03De=@<0=cLg0P14A4@303@d=0<0;2`/0P0_;bl303@d=080>3Ph0`0m?Cd303Lg=`80<C4a0`0b<S82
034a<@<0;Rh^0`14A4@203`l?0<0<C4a0P0^;Rh3034a<@<0?3`l0P1;Bd/305EEE@80B4Q80`1IFET3
05]KF`80ADE50`1XJ6P206EUI@<0GemO0P1BDU8305=CD`<0?Shn0P1XJ6P30:BTY080S8b<0`1_Kfl3
03Hf=P808b<S1@0M7Ad3020P80<0:BTY0P1BDU8308F5Q@80UiNG0`2KVi/30820P080NGUi0`1bLW82
07]kN`<0SXj>0`2_[jl20<30`0<0]kNg0P2VYZH30:b/[0<0^;Rh0P2e]KD30;Zj^P80/;2`0`2b/[82
0;2`/0H0/k>c0P2a/K430:6QX@80SHf=0`2@T9030:BTY0D0YZJV0P2ZZZX30;6a/@<0]kNg0P30`<03
0<O7a`80aLG50`3:b/X30;jn_P80/;2`0`2XZ:P20:JVYPH0[Jf]0P2[Zj/30:BTY080XZ:R0`2SXj<3
0:BTY080WIfM0`2EUID209:BTP<0Vi^K0P2LW9`30:6QX@<0X:2P0P2RXZ830:JVYP80ZZZZ1P2[Zj/2
0:ZZZP<0Z:RX0P2/[:`30;Bd]0<0^;Rh0P2k^k/30;fm_@80`<300`31`L4L0<SPf0006`38h=P302h^
;P80:RXZ0`0U9BD202PX:0<0;Bd]0`0^;Rh203<c<`<0Hf=S0P1[Jf/303dm?@<0:2PX0P0T92@302TY
:@80;Bd]0`0c<c<20410@0<0BDU90`0m?Cd2030`<0<0=cLg0P0o?cl303Lg=`<0;Rh^0P0_;bl3038b
<P80=SHf1P0i>CT203Lg=`<0;bl_0P0Z:RX3038b<PD0>c/k0`0h>3P203De=@<0<c<c0`0f=SH203dm
?@<0ATI60P1EEED3065QH@<0K6a/0P1VIVH307MgM`80EeMG0`1BDU8204=3@`<0@D510`0e=CD206UY
J@<0TI6A0P1gMgL304=3@`<0;2`/0P0P820301lO7`8071`L0`0N7Qh302@T9080=3@d0`1IFET208>3
P`<0UYJF0`2MWId208V9R@<0N7Qh0P1fMWH307inOP<0V9RH0P2b/[830;Fe]@80/K6a0`2_[jl30:j^
[P80/k>c0`2g]kL20;:b/P<0[Jf]1@2[Zj/30:j^[P80[Jf]0`2LW9`208R8R0<0UIFE1@2WYjL30:ZZ
ZP80[Jf]0`2a/K430;Jf]P80_;bl0`31`L420<G5a@<0a<C40`2o_kl20;Bd]0D0ZJVY0`2/[:`30:ZZ
ZP80ZJVY0`2XZ:P50:NWY`<0YZJV0P2QXJ4309bLW080V9RH0`2FUYH209NGU`<0VIVI0`2MWId20:2P
X0<0YJFU2P2YZJT30:^[Z`80[jn_0`2d];@30;Rh^080^k^k0`2n_[h20<30`0<0`L71=038h=P303Xj
>P809bLW0`0Y:BT202DU9@<0;Rh^0`0i>CT203@d=0<0Fe]K0P1YJFT303lo?`<09BDU1@0W9bL202l_
;`<0<30`0P17AdL3055AD@<0?Shn0P0`<30303Ph>080@4100`12@T8302/[:`80:BTY0`0];Bd203Ph
>0<0=3@d0`0h>3P203Hf=P<0:RXZ0P0[:b/302h^;P<0>SXj0P18B4P303/k>`80;Bd]0`0i>CT303Ph
>080<c<c0`16ATH204U9B@<0IVIV0`1/K6`206m_K`<0NGUi0P1IFET304a<C0D0>c/k0`0];Bd205iN
GP<0V9RH0P1ZJVX30451@@<09BDU0P0O7al301`L7080820P0`0M7Ad302DU9@80;Rh^0`1IFET208>3
P`<0XJ6Q0`2FUYH208F5Q@<0O7al0P1cLg<307]kN`<0Ti>C0P2d];@30;fm_@80ZJVY0`2ZZZX30;2`
/080^;Rh0`2i^KT50:j^[P80ZJVY0`2XZ:P30:^[Z`80[Zj^0`2IVIT208Z:RP<0T92@0`2WYjL20:RX
Z0<0YjNW0P2VYZH30;Jf]P<0^[Zj0P2m_Kd50;no_`<0a<C40`2o_kl20;>c/`<0Zj^[0P2UYJD30:VY
Z@<0[:b/1@2WYjL20:VYZ@<0YjNW0`2RXZ820:FUY@<0VIVI0P2ATI4309JFUP80Vi^K0`2MWId309bL
W080WinO1@2VYZH30:RXZ0<0YjNW0P2YZJT30:f][@80[jn_0`2g]kL30;Rh^080^[Zj0`31`L420<;2
`P<0_[jn7038h=P001/0b>3H0`0^;Rh202XZ:P<09BDU0P0X:2P302d];@<0;Rh^0P0c<c<306=SH`80
Jf][0`0m?Cd302PX:08092@T0`0Y:BT202d];@<0<c<c0P10@40304U9B@<0?Cdm0P0`<30303Lg=`80
?clo0`0g=cL302h^;P80;bl_0`0b<S8203Hf=PH0>CTi0P0g=cL302l_;`80:RXZ0`0b<S8503/k>`<0
>3Ph0P0e=CD303<c<`<0=SHf0P0m?Cd304I6AP80EEEE0`1QHF4306a/K080IVIV0`1gMgL205MGE`<0
DU9B0P13@d<30451@@<0=CDe0P1YJFT3096AT@80MgMg0`13@d<302`/;080820P0`0O7al201`L70<0
7QhN0`0T92@203@d=0<0FEUI0P23Ph<309JFUP<0WIfM0P29RHT307QhN080MWIf0`1nOWh309RHV080
/[:b0`2e]KD20;6a/@<0[jn_0`2^[Zh20;>c/`<0]kNg0P2b/[830:f][@D0Zj^[0`2^[Zh20:f][@<0
W9bL0P28R8P309FEU@D0YjNW0`2ZZZX20:f][@<0/K6a0`2f][H20;bl_0<0`L710P35aLD30<C4a0<0
_kno0P2d];@50:VYZ@<0[:b/0`2ZZZX20:VYZ@<0Z:RX1@2WYjL30:JVYP80XJ6Q0`2LW9`209RHV0<0
UYJF0P2GUiL309VIV@<0WIfM0P2PX:030:FUY@X0ZJVY0`2[Zj/20:n_[`<0];Bd0`2h^;P20;^k^`<0
_[jn0P30`<030<71`C@0b>3H0`0j>SX202LW9`<0:BTY0P0U9BD302h^;P<0>CTi0P0d=3@305]KF`80
JFUY0`0o?cl302DU9@D09bLW0P0_;bl3030`<080AdM70`1ADE4303hn?P80<30`0`0h>3P20410@0<0
@T920`0[:b/202TY:@<0;Bd]0P0h>3P303@d=0<0>3Ph0P0f=SH302XZ:P80:b/[0`0^;Rh303Xj>P80
B4Q80`0k>c/202d];@<0>CTi0`0h>3P203<c<`<0ATI60P19BDT306IVIP<0K6a/0P1_Kfl307UiN@80
FEUI0`1<C4`503/k>`<0;Bd]0P1NGUh309RHV080JVYZ0`11@D4302DU9@807alO0`0L71`2020P80<0
7AdM0`0U9BD202h^;P<0FEUI0P23Ph<30:6QX@<0UYJF0P25QHD307alO080Lg=c0`1kNg/309>CT`80
];Bd0`2m_Kd20:VYZ@<0ZZZZ0`2`/;020;Rh^0<0^KVi1@2^[Zh20:VYZ@<0Z:RX0`2[Zj/20:j^[P<0
VIVI0P2:RXX3092@T0<0YjNW0P2XZ:P30:NWY`80YZJV0`2f][H30;Zj^P80_Kfm1@2o_kl30<C4a0<0
_kno0P2c/k<30:^[Z`80YJFU0`2YZJT30:b/[0D0YjNW0P2YZJT30:NWY`<0XZ:R0P2UYJD309VIV@80
TI6A0`2FUYH209^KV`<0WIfM0`2LW9`209nOW`D0YZJV0`2XZ:P30:NWY`80ZJVY0`2][Jd20:n_[`<0
]kNg0`2h^;P20;Zj^P<0`L710P32`/830;jn_Q`0b>3H000K0<SPf0<0;Rh^0P0Z:RX302DU9@80:2PX
0`0];Bd302h^;P80<c<c0`1SHf<206][J`<0?Cdm0`0X:2P202@T90<0:BTY0P0];Bd303<c<`80@410
0`19BDT303dm?@80<30`0`0g=cL203lo?`<0=cLg0`0^;Rh202l_;`<0<S8b0P0f=SH603Ti>@80=cLg
0`0_;bl202XZ:P<0<S8b1@0k>c/303Ph>080=CDe0`0c<c<303Hf=P80?Cdm0`16ATH205EEE@<0HF5Q
0`1/K6`206IVIP<0MgMg0P1GEeL3059BDP80@d=30`11@D4303De=@80JFUY0`2ATI4207MgM`<0@d=3
0`0/;2`2020P80<07alO0P0L71`301hN7P<092@T0P0d=3@305UIF@80Ph>30`2FUYH309fMW@80RHV9
0`1hN7P207IfMP<0OWin0`2HV9P20;:b/P<0]KFe0P2a/K430:n_[`<0[Zj^0P2c/k<30;Ng]`80/[:b
0`2][Jd50:^[Z`<0[Zj^0P2][Jd309bLW080R8R80`2EUID50:NWY`<0ZZZZ0P2][Jd30;6a/@<0][Jf
0P2l_;`30<71`@80aLG50`34a<@30;no_`80];Bd1@2YZJT30:b/[0<0ZZZZ0P2YZJT30:RXZ0D0YjNW
0`2VYZH20:6QX@<0W9bL0P2HV9P309JFUP80UiNG0`2IVIT309fMW@80X:2P0`2UYJD:0:VYZ@<0Zj^[
0P2_[jl30;Bd]0<0^;Rh0P2k^k/30;jn_P80`<300`31`L4d0<SPf0<0>SXj0P0W9bL302TY:@809BDU
0`0^;Rh303Ti>@80=3@d0`1KFe/206UYJ@<0?clo0`0U9BD502LW9`80;bl_0`0`<30204M7A`<0DE5A
0`0n?Sh2030`<0<0>3Ph0P10@4030492@P<0:b/[0P0Y:BT302d];@80>3Ph0`0d=3@303Ph>080=SHf
0`0Z:RX202/[:`<0;Rh^0`0j>SX204Q8B0<0>c/k0P0];Bd303Ti>@<0>3Ph0P0c<c<304I6AP80BDU9
0`1VIVH306a/K080Kfm_0`1iNGT205UIF@<0C4a<1@0k>c/302d];@80GUiN0`2HV9P206YZJP<0@D51
0`0U9BD201lO7`<071`L0P0P820301dM7@<09BDU0P0^;Rh305UIF@80Ph>30`2QXJ4309JFUP80QHF5
0`1lO7`207=cL`<0Ng]k0`2CTi<20;Bd]0<0_Kfm0P2YZJT30:ZZZP<0/;2`0P2h^;P30;Vi^@D0[Zj^
0P2YZJT30:RXZ0<0Zj^[0P2^[Zh309VIV@80RXZ:0`2@T9030:NWY`80Z:RX0`2WYjL20:JVYP<0][Jf
0`2j^[X20;fm_@D0_kno0`34a<@30;no_`80/k>c0`2[Zj/20:FUY@<0ZJVY0`2/[:`50:NWY`80ZJVY
0`2WYjL30::RXP80YJFU0`2IVIT2096AT@<0UYJF0P2KVi/309fMW@<0W9bL0P2OWil50:JVYP<0Z:RX
0`2WYjL20:VYZ@<0[Jf]0P2_[jl30;Ng]`<0^;Rh0P2j^[X30<71`@80`/;20`2n_[hL0<SPf0006`38
h=P3030`<080;2`/0`0X:2P202XZ:P<0;Rh^0`0b<S8203Hf=P<0LG5a0P1SHf<304Y:BPD09RHV0`0]
;Bd202`/;0<0;Rh^0P10@40304m?C`<0@d=31@0d=3@203Hf=P<0=3@d200b<S8203@d=0<0=SHf0`0j
>SX203`l?0<0<C4a0P0X:2P302l_;`<0>3Ph0P0l?3`303hn?P80>c/k0`0g=cL302l_;`80;Bd]0`14
A4@205mOG`<0JFUY0`1bLW820820P0<0PX:20P14A4@30410@080;Rh^0`0`<303034a<@80JFUY0`23
Ph<205aLG0<0820P0`0S8b<201hN7PD08R8R0`0S8b<301lO7`808B4Q0`0j>SX205]KF`<0RHV90`2[
Zj/209^KV`<0Ph>30P1gMgL307=cL`<0Ph>30P2IVIT30:f][@80_;bl0`2b/[830:JVYP80[Zj^0`2f
][H20;2`/0<0ZJVY0P2VYZH30:FUY@D0Z:RX0`2FUYH208N7Q`<0UYJF0`2YZJT20:j^[PP0[jn_0`2c
/k<20;Ng]`<0_Kfm0P32`/830<71`@<0_;bl0P2d];@30:b/[0D0ZZZZ0`2YZJT20:RXZ0<0Zj^[0P2]
[Jd30:ZZZPD0Z:RX0`2WYjL209jNWP<0UYJF0P2CTi<309BDU0<0VIVI0P2OWil30:BTY080YjNW0`2X
Z:P30:VYZ@80ZZZZ0`2/[:`20:n_[`<0/k>c0`2g]kL20;^k^`<0_[jn1@30`<0d0<SPf0<0<S8b0P0[
:b/3038b<P809RHV0`0_;bl303De=@80>3Ph0`1YJFT206e]K@<0@D510`0W9bL202XZ:P<0:BTY0P0_
;bl302h^;P80@D510`1<C4`304M7A`80>3Ph0`0/;2`203Hf=P<0?Cdm0`0`<30202d];@<0<c<c0P0g
=cL3038b<P<0@T920P0e=CD303Lg=`80:BTY0`0^;Rh303Hf=P80@D510`0l?3`203Ph>0<0=cLg0`0d
=3@2038b<P<0?clo0P1PH603079bLP<0JFUY0P1hN7P307inOP80D51@0`10@40202XZ:P<0=CDe0`0f
=SH206QXJ0<0RHV90P1HF5P302TY:@<0820P0P0V9RH3020P808092@T0`0R8R8301hN7P8092@T0`0f
=SH205eMG@<0TI6A0`2YZJT209BDU0<0Q8B40P1kNg/307MgM`<0OGem0P2EUID30;Jf]P80^KVi0`2Y
ZJT30:RXZ080][Jf0`2c/k<20:j^[P<0ZZZZ0P2VYZH30:>SX`<0/;2`0P2SXj<309BDU080Rh^;0`2?
Shl30:VYZ@80]KFe0`2][Jd20:b/[0<0[jn_0`2^[Zh20;Vi^@<0_[jn0P33`l<30;no_`<0^[Zj0P2f
][H30:b/[080YjNW0`2/[:`30:^[Z`80YjNW0`2[Zj/20:f][@<0Z:RX0`2WYjL20:^[Z`<0YJFU0P2P
X:0309FEU@80Ti>C0`2DU9@309NGU`80WIfM0`2UYJD20:JVYP<0ZJVY0`2[Zj/20:RXZ0D0[Jf]0`2c
/k<30;Ng]`80^KVi0`2n_[h20;no_`<0_[jn7038h=P001/0b>3H0`0`<30202`/;0<0:2PX0P0Z:RX3
02h^;P<0<S8b0P0f=SH3075aL@80Hf=S0`1:BTX502HV9P<0;Bd]0P0/;2`302h^;P80@4100`1?Cdl3
04=3@`D0=3@d0P0f=SH303@d=0P0<S8b0P0d=3@303Hf=P<0>SXj0P0l?3`3034a<@80:2PX0`0_;bl3
03Ph>080?3`l0`0n?Sh203/k>`<0=cLg0`0_;bl202d];@<0A4A40P1OGel306UYJ@<0LW9b0P20P803
08:2PP80A4A40`10@40202h^;P<0<30`0`0a<C4206UYJ@<0Ph>30P1LG5`3020P80<08b<S0P0N7Qh5
028R8P<08b<S0`0O7al2024Q8@<0>SXj0P1KFe/308V9R@<0Zj^[0P2KVi/308>3P`80MgMg0`1cLg<3
08>3P`80VIVI0`2][Jd20;bl_0<0/[:b0`2VYZH20:j^[P<0][Jf0P2`/;030:VYZ@80YZJV0`2UYJD5
0:RXZ0<0UYJF0P27QhL309JFUP<0ZJVY0P2^[Zh80:n_[`<0/k>c0P2g]kL30;fm_@80`/;20`31`L43
0;bl_080];Bd0`2/[:`50:ZZZP<0ZJVY0P2XZ:P30:^[Z`80[Jf]0`2ZZZX50:RXZ0<0YjNW0P2NWYh3
09JFUP80Ti>C0`2DU9@309VIV@80WinO0`2TY:@20:NWY`<0Z:RX0`2YZJT20:ZZZP<0[:b/0P2_[jl3
0;>c/`<0]kNg0P2k^k/30;jn_PD0`<30=038h=P3038b<P80:b/[0`0b<S8202HV9P<0;bl_0`0e=CD2
03Ph>0<0JFUY0P1]KFd30451@@<09bLW0P0Z:RX302TY:@80;bl_0`0^;Rh20451@@<0C4a<0`17AdL2
03Ph>0<0;2`/0P0f=SH303dm?@<0<30`0P0];Bd303<c<`80=cLg0`0b<S830492@P80=CDe0`0g=cL2
02TY:@<0;Rh^0`0f=SH20451@@<0?3`l0P0h>3P303Lg=`<0=3@d0P0b<S8303lo?`80H61P0`1bLW83
06UYJ@80N7Qh0`1nOWh2051@D0<0@4100P0Z:RX303De=@<0=SHf0P1XJ6P308V9R@80F5QH0`0Y:BT3
020P80809RHV0`0P820202@T90<08R8R0`0N7Qh202@T90<0=SHf0P1MGEd3096AT@<0ZJVY0P2DU9@3
08B4Q080Ng]k0`1gMgL307emO@80UIFE0`2f][H20;Vi^@<0ZJVY0`2XZ:P20;Jf]P<0/k>c0P2^[Zh3
0:ZZZP80YZJV0`2SXj<30;2`/080Xj>S0`2DU9@208^;R`<0Shn?0`2YZJT20;Fe]@<0[Jf]0P2/[:`3
0:n_[`<0[Zj^0P2i^KT30;jn_P80`l?30`2o_kl30;Zj^P80][Jf0`2/[:`20:NWY`<0[:b/0`2[Zj/2
0:NWY`<0Zj^[0P2][Jd30:RXZ0<0YjNW0P2[Zj/30:FUY@80X:2P0`2EUID209>CT`<0U9BD0`2GUiL2
09fMW@<0YJFU0P2VYZH30:VYZ@<0Zj^[0P2XZ:P50:f][@<0/k>c0`2g]kL20;Vi^@<0_[jn0P2o_kl3
0;jn_Q`0b>3H000K0<SPf0<0@D510P0m?Cd303Hf=P80;bl_0`0/;2`3030`<080>CTi0`1WIfL206UY
J@<0Cdm?0`0Z:RX202PX:0<0;Bd]1@0[:b/203Ph>0H0@d=30P0o?cl303Xj>PD0=SHf0`0e=CD2034a
<@<0;Rh^0P0_;bl3038b<P<0>3Ph0P0k>c/3038b<P80:BTY0`0`<30303/k>`80?Shn0`0o?cl203Xj
>P<0=3@d0`0b<S8203De=@<0CTi>0P1OGel306a/K0<0Fe]K0P1QHF4307inOP80>CTi0`0f=SH202XZ
:P<0<30`0`0j>SX207inOP<0QHF50P16ATH302@T90<09bLW0P0S8b<502@T90<08b<S1@0P820302LW
9`80>3Ph0`1SHf<308^;R`80YjNW0`2EUID20861P@<0LG5a0`1cLg<207inOP<0VIVI0P2b/[830;>c
/`D0[jn_0`2^[Zh20:ZZZP<0YZJV1@2UYJD30:NWY`80YZJV0`2CTi<208F5Q@<0UIFE0`2YZJT50:n_
[`80ZZZZ0`2VYZH30:n_[`80^[Zj0`2n_[h20<30`0<0_kno0`2k^k/20;Fe]@<0[Zj^0P2[Zj/30:VY
Z@<0Z:RX0P2YZJT30:^[Z`80[Jf]0`2[Zj/30:ZZZP80Zj^[0`2/[:`20:RXZ0<0XZ:R0P2KVi/609FE
U@80V9RH0`2OWil20:JVYP<0YjNW0`2XZ:P20:ZZZP<0[:b/0P2^[Zh30;6a/@<0];Bd0P2h^;P30;^k
^`80_[jn0`2o_kld0<SPf0<0?clo0P0g=cL302h^;P80:RXZ1P0/;2`203`l?0<0J6QX0P1]KFd304e=
C@<0;Rh^0P0a<C4302`/;0D0:b/[0P0`<30303hn?P<0AdM70P0o?cl3038b<P80<c<c0`0k>c/303De
=@80<S8b0`0e=CD2034a<@<0=cLg0`0f=SH204A4A0<0;Rh^0P0[:b/302h^;P<0>c/k0P0n?Sh30410
@080>CTi1P0b<S8203Lg=`<0CTi>0P1SHf<306i^KP<0IfMW0P1LG5`307YjNP80?clo0`0g=cL202d]
;@<0<c<c0`0k>c/20820P0<0RHV90P17AdL302DU9@<092@T0P0X:2P301lO7`8092@T0`0S8b<302PX
:0808b<S0`0Y:BT202/[:`<0HV9R0`2ATI420:FUY@<0UIFE0P21PH4307AdM0<0LW9b0P1kNg/30:2P
X080]KFe0`2i^KT30:FUY@80[Zj^0`2][Jd20:RXZ0<0ZJVY0P2QXJ460:RXZ080ZZZZ0`2FUYH208N7
Q`<0SXj>0`2YZJT20;Jf]P<0/K6a0P2YZJT30:RXZ0<0[jn_0P2i^KT30;bl_080`<300`36a/H30;Vi
^@80^;Rh0`2_[jl20:NWY`<0ZZZZ0`2[Zj/20:VYZ@<0ZZZZ0P2/[:`30:VYZ@<0Zj^[0P2^[Zh30:ZZ
ZP80[jn_0`2QXJ4209JFUP<0Ti>C0`2EUID209bLW0<0Xj>S0P2VYZH30:FUY@<0ZJVY0P2WYjL30:j^
[P80[:b/0`2b/[830;2`/080^[Zj0`2m_Kd20;no_`<0^KVi7038h=P001/0b>3H0`11@D4203dm?@<0
=SHf0P0_;bl302`/;0<0<30`0P0i>CT306MWI`80JFUY0`1?Cdl302XZ:P80:2PX0`0];Bd502/[:`80
>3Ph1P13@d<203lo?`<0>SXj1@0f=SH303De=@80<C4a0`0^;Rh202l_;`<0<S8b0`0h>3P203/k>`<0
<S8b0P0Y:BT3030`<0<0>c/k0P0n?Sh303lo?`80>SXj0`0d=3@3038b<P80=CDe0`1>CTh205mOG`<0
K6a/0`1KFe/2065QH@<0OWin0P0i>CT303Hf=P80:RXZ0`0`<30303Xj>P80OWin0`25QHD204I6AP<0
92@T0`0W9bL202<S8`D092@T0`0S8b<5020P80<09bLW0P0h>3P306=SH`<0Rh^;0P2WYjL309FEU@80
PH610`1aLG4307=cL`80OWin0`2IVIT20;:b/P<0/k>c1@2_[jl30:j^[P80ZZZZ0`2VYZH50:FUY@<0
YjNW0P2VYZH309>CT`80QHF50`2EUID30:VYZ@D0[jn_0P2ZZZX30:JVYP<0[jn_0P2j^[X30;jn_P80
`<300`2o_kl30;^k^`80]KFe0`2^[Zh20:^[Z`<0ZJVY0`2XZ:P20:VYZ@<0Zj^[0P2][Jd30:^[Z`<0
ZZZZ0P2[Zj/30:b/[080Z:RX0`2RXZ8209^KV`H0UIFE0P2HV9P309nOW`80YZJV0`2WYjL30:RXZ080
ZZZZ0`2/[:`20:j^[P<0/K6a0`2d];@20;Rh^0<0^k^k0P2n_[h30;no_c@0b>3H0`0o?cl203Lg=`<0
;Rh^0P0Z:RX602`/;080?3`l0`1XJ6P206e]K@<0CDe=0`0^;Rh2034a<@<0;2`/1@0[:b/2030`<0<0
?Shn0`17AdL203lo?`<0<S8b0P0c<c<303/k>`<0=CDe0P0b<S8303De=@80<C4a0`0g=cL303Hf=P80
A4A40`0^;Rh202/[:`<0;Rh^0`0k>c/203hn?P<0@4100P0i>CT6038b<P80=cLg0`1>CTh206=SH`<0
KVi^0`1WIfL205aLG0<0NWYj0P0o?cl303Lg=`80;Bd]0`0c<c<303/k>`80P8200`29RHT204M7A`<0
9BDU0`0T92@202PX:0<07alO0P0T92@302<S8`<0:2PX0P0S8b<302TY:@80:b/[0`1RHV83096AT@80
YJFU0`2EUID20861P@<0M7Ad0`1bLW8207]kN`<0X:2P0P2e]KD30;Vi^@<0YJFU0P2^[Zh30:f][@80
Z:RX0`2YZJT20:6QX@H0Z:RX0P2ZZZX309JFUP80QhN70`2>SXh30:VYZ@80][Jf0`2a/K420:VYZ@<0
Z:RX0`2_[jl20;Vi^@<0_;bl0P30`<030<K6aP<0^KVi0P2h^;P30:n_[`80YjNW0`2ZZZX30:^[Z`80
ZJVY0`2ZZZX20:b/[0<0ZJVY0`2[Zj/20:j^[P<0ZZZZ0P2_[jl30:6QX@80UYJF0`2CTi<309FEU@80
W9bL0`2SXj<20:JVYP<0YJFU0`2YZJT20:NWY`<0[Zj^0P2/[:`30;:b/P<0/;2`0P2j^[X30;fm_@80
_kno0`2i^KTL0<SPf0006`38h=P30451@@80?Cdm0`0f=SH202l_;`<0;2`/0`0`<30203Ti>@<0IfMW
0P1YJFT304m?C`<0:RXZ0P0X:2P302d];@D0:b/[0P0h>3P604=3@`80?clo0`0j>SX503Hf=P<0=CDe
0P0a<C4302h^;P80;bl_0`0b<S8303Ph>080>c/k0`0b<S8202TY:@<0<30`0`0k>c/203hn?P<0?clo
0P0j>SX303@d=0<0<S8b0P0e=CD304i>CP80GemO0`1/K6`305]KF`80HF5Q0`1nOWh203Ti>@<0=SHf
0P0Z:RX3030`<0<0>SXj0P1nOWh308F5Q@80ATI60`0T92@302LW9`808b<S1@0T92@302<S8`D0820P
0`0W9bL203Ph>0<0Hf=S0`2;Rh/20:NWY`<0UIFE0P21PH43075aL@<0Lg=c0P1nOWh309VIV@80/[:b
0`2c/k<50:n_[`<0[Zj^0P2ZZZX30:JVYPD0YJFU0`2WYjL20:JVYP<0Ti>C0P25QHD309FEU@<0ZJVY
1@2_[jl20:ZZZP<0YZJV0`2_[jl20;Zj^P<0_[jn0P30`<030;no_`<0^k^k0P2e]KD30:j^[P80Zj^[
0`2YZJT30:RXZ080ZJVY0`2[Zj/20:f][@<0Zj^[0`2ZZZX20:^[Z`<0[:b/0P2XZ:P30::RXP80Vi^K
1P2EUID209RHV0<0WinO0P2VYZH30:NWY`<0Z:RX0P2ZZZX30:b/[080[Zj^0`2a/K430;Bd]080^;Rh
0`2k^k/20;jn_P<0_kno=038h=P303lo?`80=cLg0`0^;Rh202XZ:PH0;2`/0P0l?3`306QXJ080KFe]
0`1=CDd302h^;P80<C4a0`0/;2`502/[:`80<30`0`0n?Sh304M7A`80?clo0`0b<S8203<c<`<0>c/k
0`0e=CD2038b<P<0=CDe0P0a<C4303Lg=`<0=SHf0P14A4@302h^;P80:b/[0`0^;Rh303/k>`80?Shn
0`10@40203Ti>@H0<S8b0P0g=cL304i>CP80Hf=S0`1^KVh306MWI`80G5aL0`1jNWX203lo?`<0=cLg
0P0];Bd303<c<`<0>c/k0P20P80308V9R@80AdM70`0U9BD302@T9080:2PX0`0O7al202@T90<08b<S
0`0X:2P202<S8`<0:BTY0P0[:b/3069RHP<0TI6A0P2UYJD309FEU@80PH610`1dM7@3079bLP80Ng]k
0`2PX:020;Fe]@<0^KVi0`2UYJD20:j^[P<0[Jf]0P2XZ:P30:VYZ@80XJ6Q1P2XZ:P20:ZZZP<0UYJF
0P27QhL308j>SP<0ZJVY0P2f][H30;6a/@80ZJVY0`2XZ:P30:n_[`80^KVi0`2l_;`20<30`0<0a/K6
0`2i^KT20;Rh^0<0[jn_0P2WYjL30:ZZZP<0Zj^[0P2YZJT30:ZZZP80[:b/0`2YZJT30:^[Z`80[Zj^
0`2ZZZX20:n_[`<0XJ6Q0P2FUYH309>CT`<0UIFE0P2LW9`30:>SX`80YZJV0`2UYJD30:VYZ@80YjNW
0`2^[Zh20:b/[0<0/[:b0`2`/;020;Zj^P<0_Kfm0P2o_kl30;Vi^A`0b>3H000K0<SPf0<0CTi>0P19
BDT303lo?`80<c<c0`0[:b/302l_;`80>c/k0`1HF5P206m_K`<0De=C0`0a<C4502/[:`D0:RXZ0P0^
;Rh303@d=0<0?clo0P17AdL30410@0D0=cLg0`0h>3P2034a<@D0:b/[0`0_;bl303@d=080>CTi0`0c
<c<202h^;P<0=SHf0`10@4020451@@<0?clo0P0g=cL3038b<P<0>3Ph0P12@T8305IFEP80GUiN0`1Z
JVX303lo?`80>SXj0`1bLW8203<c<`<0<30`0P0Z:RX303Lg=`<0Bd];0P2ATI4308F5Q@80=3@d0`0^
;Rh302`/;080:2PX0`0V9RH202@T90<08b<S1@0T92@501dM7@<0?3`l0`1OGel20:FUY@<0WinO0P2?
Shl307MgM`<0JVYZ0P1XJ6P308:2PP80X:2P0`2_[jl30;Ng]`80/K6a0`2XZ:P20:JVYP<0YJFU1@2V
YZH30:NWY`80YJFU0`2ATI4208>3P`<0Ti>C0`2XZ:P50:f][@80YJFU0`2NWYh30:f][@80_Kfm0`30
`<020;no_`<0_Kfm0`2i^KT20;Fe]@<0/;2`0P2[Zj/60:RXZ080ZJVY0`2ZZZX50:^[Z`<0ZZZZ0P2/
[:`30:f][@80[jn_0`2^[Zh20:JVYP<0W9bL0`2FUYH209>CT`<0VYZJ0P2SXj<30:FUY@<0YjNW0P2Y
ZJT30:b/[080[Jf]0`2^[Zh30;6a/@80]KFe0`2i^KT20;bl_0<0_Kfm=038h=P304m?C`80DU9B0`17
AdL203<c<`<0:b/[0`0/;2`203De=@<0IVIV0P1]KFd304U9B@<0=3@d0P0];Bd502XZ:P<0;2`/0P0^
;Rh303Hf=PD0ATI60`0j>SX203/k>`<0?3`l0`0i>CT202XZ:P<0:b/[0P0^;Rh602l_;`80>c/k0`0e
=CD2034a<@<0=3@d0`13@d<203hn?P<0@T920P0i>CT303Hf=P<0=3@d0P14A4@305YJFP80H61P0`1S
Hf<303/k>`80@d=30`1ZJVX203Lg=`<0;2`/0P0_;bl303@d=0<0D51@0P2@T9030861P@80=cLg0`0Y
:BT302d];@80:RXZ0`0W9bL202@T90<08B4Q0`0S8b<2020P80<08B4Q0P0T92@303@d=0<0Jf][0P2K
Vi/30:2PX080Shn?0`1hN7P306][J`80JVYZ0`1mOGd209^KV`H0]KFe0P2/[:`30:^[Z`D0YJFU1@2V
YZH30:NWY`80Xj>S0`2DU9@208B4Q0<0SHf=0`2WYjL20;6a/@<0[Jf]0P2SXj<309nOW`<0/K6a0P2j
^[X30<71`@80_[jn0`2m_Kd30;Rh^080]kNg0`2a/K480:NWY`80Z:RX0`2ZZZX50:^[Z`<0ZZZZ0P2[
Zj/30:f][@80[Zj^0`2/[:`20:NWY`<0W9bL0`2CTi<209FEU@<0XZ:R0P2PX:030::RXP<0ZJVY0P2Z
ZZX30:f][@80[jn_0`2`/;030:j^[P80][Jf0`2j^[X20;bl_0<0^k^k7038h=P001/0b>3H0`1>CTh2
04U9B@<0?clo0P0c<c<302/[:`<0;bl_0P0k>c/305QHF080Kfm_0`1CDe<3034a<@D0:b/[1@0Z:RX2
02h^;P<0=3@d0`0o?cl204M7A`<0@4101@0g=cL303Ph>080<C4a1@0[:b/302l_;`<0=3@d0P0i>CT3
03<c<`80;Rh^0`0f=SH30410@080@D510`0o?cl203Lg=`<0<S8b0`0h>3P20492@P<0EUIF0P1NGUh3
06YZJP<0?clo0P0j>SX3079bLP80<c<c0`0`<30202XZ:P<0=cLg0`1;Bd/2096AT@<0QHF50P0d=3@3
02h^;P<0;2`/0P0X:2P302HV9P8092@T0`0S8b<502@T90D07AdM0`0l?3`305mOG`80YJFU0`2OWil2
08n?S`<0MgMg0`1ZJVX206QXJ0<0PX:20P2PX:030:n_[`<0]kNg0P2a/K430:RXZ080YZJV0`2UYJD5
0:JVYP<0YjNW0P2UYJD3096AT@80Ph>30`2CTi<30:RXZ0D0[Jf]0P2UYJD309jNWP<0[Jf]0P2m_Kd3
0<30`080_kno0`2m_Kd30;Vi^@80]KFe0`2`/;020:^[Z`H0Z:RX0P2YZJT30:ZZZPD0Zj^[0`2ZZZX2
0:b/[0<0[Jf]0P2_[jl30:j^[P80YZJV0`2LW9`309JFUP80Ti>C0`2JVYX20:>SX`<0YJFU0`2WYjL2
0:VYZ@<0[:b/0P2][Jd30:j^[P<0/K6a0P2e]KD30;Vi^@80_;bl0`2m_Kdd0<SPf0<0Cdm?0P1BDU83
04M7A`80<c<c0`0[:b/302`/;080=CDe0`1VIVH206e]K@<0BDU90`0d=3@202d];@D0:RXZ0`0/;2`2
02h^;P<0=SHf1@16ATH303Xj>P80>c/k0`0l?3`303Ti>@80:RXZ0`0[:b/202h^;PH0;bl_0P0k>c/3
03De=@80<C4a0`0d=3@304=3@`80?Shn0`12@T8203Ti>@<0=SHf0`0d=3@204A4A0<0FUYJ0P1PH603
06=SH`<0>c/k0P13@d<306YZJP80=cLg0`0/;2`202l_;`<0=3@d0`1@D502092@T0<0PH610P0g=cL3
02TY:@<0;Bd]0P0Z:RX302LW9`8092@T0`0Q8B4302<S8`80820P0`0Q8B4202@T90<0=3@d0`1[Jf/2
09^KV`<0X:2P0P2?Shl307QhN0<0Jf][0P1ZJVX307emO@80Vi^K1P2e]KD20:b/[0<0Zj^[1@2UYJD5
0:JVYP<0YjNW0P2SXj<309BDU080Q8B40`2=SHd30:NWY`80/K6a0`2][Jd20:>SX`<0WinO0`2a/K42
0;Zj^P<0`L710P2n_[h30;fm_@<0^;Rh0P2g]kL30;6a/@P0YjNW0P2XZ:P30:ZZZPD0Zj^[0`2ZZZX2
0:^[Z`<0[Jf]0P2^[Zh30:b/[080YjNW0`2LW9`309>CT`80UIFE0`2RXZ820:2PX0<0XZ:R0`2YZJT2
0:ZZZP<0[Jf]0P2_[jl30;2`/0<0[Zj^0P2f][H30;Zj^P80_;bl0`2k^k/L0<SPf0006`38h=P3065Q
H@80HV9R0`1NGUh204E5A@<0;bl_0`0];Bd203Lg=`<0De=C0P1^KVh305IFEP<0=cLg0P0`<30302TY
:@80:2PX0`0Z:RX202/[:`<0;Rh^0`0i>CT20492@P<0>SXj0P0b<S8303Lg=`<0?3`l0P0e=CD302`/
;080;Bd]1P0a<C4203<c<`<0>3Ph0P0n?Sh304=3@`<0ATI60P13@d<303hn?P80>3Ph0`0f=SH303hn
?P80Bd];0`18B4P205aLG0<0HF5Q0`0];Bd203@d=0<0G5aL0P0i>CT303@d=0809RHV0`18B4P3079b
LP80Shn?0`1aLG4202`/;0<09bLW0`0V9RH502DU9@808b<S0`0Q8B43028R8P808b<S0`0L71`201XJ
6P<09bLW0`0l?3`207MgM`<0Rh^;0P2WYjL3092@T0<0NWYj0P1TI6@3075aL@80QXJ60`2MWId30;6a
/@80]kNg0`2e]KD20:b/[0<0XZ:R0P2TY:@60:NWY`80Xj>S0`2@T9020861P@<0SXj>0`2OWil20:NW
Y`<0ZZZZ0P2UYJD30::RXP<0Zj^[0P2f][H30;fm_@80`<300`2i^KT30;6a/@80/k>c0`2e]KD20:j^
[PH0Z:RX1`2ZZZX30:RXZ0<0YjNW0P2XZ:P30:VYZ@80[Jf]1@2_[jl30:b/[0<0X:2P1@2FUYH209^K
V`<0X:2P0`2VYZH20:VYZ@<0[:b/0P2][Jd30:n_[`<0/[:b0P2e]KD30;Rh^0D0^[Zj=038h=P505aL
G0<0FUYJ0P13@d<303Ti>@<0;Rh^0P0g=cL305ADE080J6QX0`1JFUX3038b<P80;Bd]0`0Y:BT202XZ
:P<0;Bd]0P0V9RH302d];@<0@4100P13@d<303Lg=`80;Rh^0`11@D4303Xj>P80<S8b0`0/;2`202h^
;P<0=3@d0`0[:b/2030`<0<0>SXj0P0l?3`30451@@<0C4a<0P0j>SX303/k>`80@D510`0e=CD303@d
=080B4Q80`1DE5@205aLG0<0Cdm?0`0a<C4203Lg=`<0HF5Q0P0j>SX302`/;080;Rh^0`10@40306m_
K`80Shn?0`1aLG4202`/;0<0;Rh^0`0Y:BT202<S8`<09bLW0P0V9RH302<S8`<08R8R0P0Q8B4301lO
7`80820P0`0U9BD303Hf=P80L71`0`2GUiL20:RXZ0<0SXj>0`1dM7@206MWI`<0LW9b0P23Ph<30:2P
X0<0/k>c0P2o_kl30;6a/@80ZJVY0`2TY:@20:FUY@<0Y:BT0`2UYJD20:2PX0<0SXj>0P24Q8@308V9
R@<0Y:BT0P2YZJT30:FUY@80WYjN0`2OWil30:VYZ@80][Jf0`31`L420;^k^`<0]KFe0`2][Jd20;Jf
]P<0];Bd0P2[Zj/60:b/[0D0ZJVY0P2/[:`30:JVYP<0Z:RX0P2TY:@30:ZZZP80Z:RX0`2b/[820;>c
/`<0[jn_0`2MWId208Z:RP<0Ti>C0P2MWId309nOW`<0YZJV0P2WYjL30:VYZ@80[:b/1P2_[jl20;Bd
]0<0^KVi0P2k^k/30;Ng]a`0b>3H000K0<SPf0<0HF5Q0P1RHV8305iNGP80ADE50`0_;bl302d];@80
=cLg0`1CDe<206i^KP<0EUIF0`0g=cL2030`<0<0:BTY0P0X:2P302XZ:P80:b/[0`0^;Rh303Ti>@80
@T920`0j>SX2038b<P<0=cLg0`0l?3`203De=@<0;2`/0P0];Bd6034a<@80<c<c0`0h>3P203hn?P<0
@d=30`16ATH204=3@`<0?Shn0P0h>3P303Hf=P<0?Shn0P1;Bd/304Q8B080G5aL0`1QHF4302d];@80
=3@d0`1LG5`203Ti>@<0=3@d0P0V9RH304Q8B0<0LW9b0P2?Shl3075aL@80;2`/0`0W9bL302HV9PD0
9BDU0P0S8b<3024Q8@<08R8R0P0S8b<301`L70806QXJ0`0W9bL303`l?080MgMg0`2;Rh/20:NWY`<0
T92@0`1jNWX206ATI0<0LG5a0P26QXH309fMW@<0/K6a0P2g]kL30;Fe]@80[:b/0`2RXZ820:BTY0H0
YjNW0P2SXj<3092@T080PH610`2>SXh309nOW`80YjNW0`2ZZZX20:FUY@<0XZ:R0`2[Zj/20;Jf]P<0
_Kfm0P30`<030;Vi^@<0/K6a0P2c/k<30;Fe]@80[Zj^1P2XZ:P70:ZZZP<0Z:RX0`2WYjL20:RXZ0<0
ZJVY0P2][Jd50:n_[`<0[:b/0`2PX:0509JFUP80Vi^K0`2PX:030:JVYP80ZJVY0`2/[:`20:f][@<0
[jn_0`2b/[820;Fe]@<0^;Rh1@2j^[Xd0<SPf0D0G5aL0`1JFUX204=3@`<0>CTi0`0^;Rh203Lg=`<0
E5AD0P1XJ6P305YJFP<0<S8b0P0];Bd302TY:@80:RXZ0`0];Bd202HV9P<0;Bd]0`10@40204=3@`<0
=cLg0P0^;Rh30451@@<0>SXj0P0b<S8302`/;080;Rh^0`0d=3@302/[:`80<30`0`0j>SX203`l?0<0
@D510`1<C4`203Xj>P<0>c/k0P11@D4303De=@<0=3@d0P18B4P305ADE080G5aL0`1?Cdl3034a<@80
=cLg0`1QHF4203Xj>P<0;2`/0P0^;Rh30410@0<0Kfm_0P2?Shl3075aL@80;2`/0`0^;Rh302TY:@80
8b<S0`0W9bL202HV9P<08b<S0`0R8R82024Q8@<07alO0P0P820302DU9@<0=SHf0P1`L70309NGU`80
Z:RX0`2>SXh307AdM080IfMW0`1bLW8208>3P`<0X:2P0`2c/k<20;no_`<0/K6a0P2YZJT30:BTY080
YJFU0`2TY:@30:FUY@80X:2P0`2>SXh208B4Q0<0RHV90`2TY:@20:VYZ@<0YJFU0P2NWYh309nOW`<0
ZJVY0P2f][H30<71`@80^k^k0`2e]KD30:f][@80][Jf0`2d];@20:^[Z`H0[:b/1@2YZJT20:b/[0<0
YZJV0`2XZ:P20:BTY0<0ZZZZ0P2XZ:P30;:b/P80/k>c0`2_[jl309fMW@80RXZ:0`2CTi<209fMW@<0
WinO0`2VYZH20:NWY`<0ZJVY0P2/[:`60:n_[`80];Bd0`2i^KT20;^k^`<0]kNg7038h=P001/0b>3H
0`1QHF42069RHP<0GUiN0P15ADD302l_;`<0;Bd]0P0g=cL305=CD`80KVi^0`1FEUH303Lg=`80<30`
0`0Y:BT202PX:0<0:RXZ0P0[:b/302h^;P<0>CTi0P12@T8303Xj>P80<S8b0`0g=cL303`l?080=CDe
0`0/;2`202d];@H0<C4a0P0c<c<303Ph>080?Shn0`13@d<304I6AP80@d=30`0n?Sh203Ph>0<0=SHf
0`0n?Sh204];B`<0B4Q80P1LG5`3065QH@<0;Bd]0P0d=3@305aLG080>CTi0`0d=3@202HV9P<0B4Q8
0`1bLW8208n?S`<0LG5a0P0/;2`302LW9`<09RHV1@0U9BD202<S8`<08B4Q0`0R8R8202<S8`<071`L
0P0J6QX302LW9`<0?3`l0P1gMgL308^;R`80YjNW0`2@T90307YjNP80I6AT0`1aLG4208J6QP<0WIfM
0`2a/K420;Ng]`<0]KFe0P2/[:`30::RXP80Y:BT1P2WYjL20:>SX`<0T92@0P21PH4308j>SP<0WinO
0P2WYjL30:ZZZP80YJFU0`2RXZ830:^[Z`80][Jf0`2m_Kd20<30`0<0^KVi0`2a/K420;>c/`<0]KFe
0P2^[Zh60:RXZ0L0ZZZZ0`2XZ:P30:NWY`80Z:RX0`2YZJT20:f][@D0[jn_0`2/[:`30:2PX0D0UYJF
0P2KVi/30:2PX0<0YZJV0P2YZJT30:b/[080[Jf]0`2_[jl30;:b/P80]KFe0`2h^;P50;Zj^S@0b>3H
1@1LG5`305YJFP80@d=30`0i>CT302h^;P80=cLg0`1DE5@206QXJ0<0FUYJ0`0b<S8202d];@<0:BTY
0P0Z:RX302d];@809RHV0`0];Bd30410@080@d=30`0g=cL202h^;P<0@D510`0j>SX2038b<P<0;2`/
0P0^;Rh303@d=0<0:b/[0P0`<30303Xj>P80?3`l0`11@D4304a<C080>SXj0`0k>c/20451@@<0=CDe
0`0d=3@204Q8B0<0E5AD0P1LG5`304m?C`<0<C4a0P0g=cL3065QH@80>SXj0`0/;2`202h^;P<0@410
0`1_Kfl208n?S`<0LG5a0P0/;2`302h^;P<0:BTY0P0S8b<302LW9`809RHV0`0S8b<3028R8P808B4Q
0`0O7al2020P80<09BDU0`0f=SH2071`L0<0UiNG0P2XZ:P308j>SP<0M7Ad0P1WIfL3079bLP80Ph>3
0`2PX:030;>c/`80_kno0`2a/K420:VYZ@<0Y:BT0P2UYJD30:BTY0<0YJFU0P2PX:0308j>SP80Q8B4
0`29RHT30:BTY080ZJVY0`2UYJD209jNWP<0WinO0`2YZJT20;Jf]P<0`L710P2k^k/30;Fe]@<0[Jf]
0P2f][H30;Bd]080Zj^[1P2/[:`50:VYZ@80[:b/0`2VYZH30:RXZ080Y:BT0`2ZZZX20:RXZ0<0/[:b
0P2c/k<30:n_[`<0WIfM0P2:RXX309>CT`80WIfM0`2OWil30:JVYP80YjNW0`2YZJT20:b/[0H0[jn_
0P2d];@30;Vi^@80^k^k0`2g]kLL0<SPf0006`38h=P803dm?@80>3Ph0`0d=3@3030`<080<c<c0`1@
D50206QXJ0<0F5QH0`0o?cl203<c<`D0:2PX1@0Z:RX302/[:`<0<c<c0P0j>SX303<c<`80;Bd]0`0f
=SH303hn?P80=cLg0`0_;bl2030`<0<0<c<c1@0`<3030410@0D0Cdm?0`1:BTX204A4A0<0?Shn1@0k
>c/304=3@`80Cdm?0`0j>SX205YJFP<0F5QH0`0Q8B4203@d=0<0ATI60P10@40303Ti>@809RHV0`1G
EeL309FEU@80R8R80`1LG5`202XZ:P<08R8R0`0T92@202DU9@<09bLW0P0T92@6024Q8@808R8R0`0P
820201lO7`<06a/K0`0Q8B4204A4A0<0KFe]0P2a/K430:FUY@<0SHf=0P1/K6`306QXJ080L71`0`28
R8P30:>SX`80][Jf0`30`<020;>c/`<0XZ:R0P2SXj<60:JVYP80XJ6Q0`2?Shl20820P0<0RXZ:0`2I
VIT20::RXPD0ZJVY0`2XZ:P30:^[Z`80/;2`0`2j^[X20<71`@<0][Jf0`2[Zj/20;6a/@<0^KVi0P2b
/[860:VYZ@80ZZZZ0`2YZJT20:RXZ0<0YJFU1@2SXj<30:BTY080Z:RX0`2/[:`20;Fe]@<0^[Zj0`2]
[Jd209fMW@<0UYJF0P2EUID309bLW0<0YJFU0P2XZ:P30:^[Z`80[Jf]0`2_[jl30;:b/P80][Jf0`2g
]kL50;Rh^3@0b>3H0`13@d<20492@P<0A4A40P0e=CD303@d=0D0;Rh^0`1EEED2065QH@<0HV9R0`0n
?Sh202d];@<0:RXZ0P0W9bL302d];@80:BTY0`0];Bd303@d=080>c/k1@0^;Rh303Ph>0<0?Shn0P0c
<c<3034a<@80;bl_0`0f=SH3034a<@80<c<c0`10@402055AD@<0C4a<0`1:BTX20451@@<0?Cdm0P14
A4@303Ti>@<0@D510P1=CDd304I6AP80FEUI0`1@D50302TY:@80:b/[0`1;Bd/203/k>`<0=CDe0P0]
;Bd305UIF@<0R8R80P2:RXX305iNGP809bLW0`0Y:BT302HV9P8092@T0`0^;Rh202PX:0H08b<S0P0Q
8B4301dM7@807QhN0`0O7al302HV9P80@D510`1cLg<20:BTY0<0[:b/0`28R8P2075aL@<0IfMW0P1d
M7@308N7Q`<0WinO0P2f][H30;no_`80[Jf]0`2VYZH20:BTY0<0YZJV0`2UYJD20:>SX`<0SHf=0P26
QXH30820P0<0Vi^K0P2WYjL30:BTY0D0[:b/0`2RXZ820;2`/0<0`<300P2o_kl30;Jf]P<0[Jf]0P2/
[:`30;fm_@80[Zj^0`2WYjL30:f][@80ZZZZ0`2YZJT20:ZZZP<0XJ6Q0`2WYjL20:2PX0<0Z:RX0P2S
Xj<30:j^[P80/;2`0`2g]kL30;Fe]@80WYjN0`2?Shl209VIV@<0WinO0`2VYZH20:FUY@<0ZZZZ0P2b
/[830:f][@<0[jn_0P2d];@30;^k^`80];Bd0`2i^KTL0<SPf0006`38h=P803dm?@80>3Ph0`0d=3@3
030`<080<c<c0`1@D50206QXJ0<0F5QH0`0o?cl203<c<`D0:2PX1@0Z:RX302/[:`<0<c<c0P0j>SX3
03<c<`80;Bd]0`0f=SH303hn?P80=cLg0`0_;bl2030`<0<0<c<c1@0`<3030410@0D0Cdm?0`1:BTX2
04A4A0<0?Shn1@0k>c/304=3@`80Cdm?0`0j>SX205YJFP<0F5QH0`0Q8B4203@d=0<0ATI60P10@403
03Ti>@809RHV0`1GEeL309FEU@80R8R80`1LG5`202XZ:P<08R8R0`0T92@202DU9@<09bLW0P0T92@6
024Q8@808R8R0`0P820201lO7`<06a/K0`0Q8B4204A4A0<0KFe]0P2a/K430:FUY@<0SHf=0P1/K6`3
06QXJ080L71`0`28R8P30:>SX`80][Jf0`30`<020;>c/`<0XZ:R0P2SXj<60:JVYP80XJ6Q0`2?Shl2
0820P0<0RXZ:0`2IVIT20::RXPD0ZJVY0`2XZ:P30:^[Z`80/;2`0`2j^[X20<71`@<0][Jf0`2[Zj/2
0;6a/@<0^KVi0P2b/[860:VYZ@80ZZZZ0`2YZJT20:RXZ0<0YJFU1@2SXj<30:BTY080Z:RX0`2/[:`2
0;Fe]@<0^[Zj0`2][Jd209fMW@<0UYJF0P2EUID309bLW0<0YJFU0P2XZ:P30:^[Z`80[Jf]0`2_[jl3
0;:b/P80][Jf0`2g]kL50;Rh^3@0b>3H0`13@d<20492@P<0A4A40P0e=CD303@d=0D0;Rh^0`1EEED2
065QH@<0HV9R0`0n?Sh202d];@<0:RXZ0P0W9bL302d];@80:BTY0`0];Bd303@d=080>c/k1@0^;Rh3
03Ph>0<0?Shn0P0c<c<3034a<@80;bl_0`0f=SH3034a<@80<c<c0`10@402055AD@<0C4a<0`1:BTX2
0451@@<0?Cdm0P14A4@303Ti>@<0@D510P1=CDd304I6AP80FEUI0`1@D50302TY:@80:b/[0`1;Bd/2
03/k>`<0=CDe0P0];Bd305UIF@<0R8R80P2:RXX305iNGP809bLW0`0Y:BT302HV9P8092@T0`0^;Rh2
02PX:0H08b<S0P0Q8B4301dM7@807QhN0`0O7al302HV9P80@D510`1cLg<20:BTY0<0[:b/0`28R8P2
075aL@<0IfMW0P1dM7@308N7Q`<0WinO0P2f][H30;no_`80[Jf]0`2VYZH20:BTY0<0YZJV0`2UYJD2
0:>SX`<0SHf=0P26QXH30820P0<0Vi^K0P2WYjL30:BTY0D0[:b/0`2RXZ820;2`/0<0`<300P2o_kl3
0;Jf]P<0[Jf]0P2/[:`30;fm_@80[Zj^0`2WYjL30:f][@80ZZZZ0`2YZJT20:ZZZP<0XJ6Q0`2WYjL2
0:2PX0<0Z:RX0P2SXj<30:j^[P80/;2`0`2g]kL30;Fe]@80WYjN0`2?Shl209VIV@<0WinO0`2VYZH2
0:FUY@<0ZZZZ0P2b/[830:f][@<0[jn_0P2d];@30;^k^`80];Bd0`2i^KTL0<SPf0006`38h=P803dm
?@80>3Ph0`0d=3@3030`<080<c<c0`1@D50206QXJ0<0F5QH0`0o?cl203<c<`D0:2PX1@0Z:RX302/[
:`<0<c<c0P0j>SX303<c<`80;Bd]0`0f=SH303hn?P80=cLg0`0_;bl2030`<0<0<c<c1@0`<3030410
@0D0Cdm?0`1:BTX204A4A0<0?Shn1@0k>c/304=3@`80Cdm?0`0j>SX205YJFP<0F5QH0`0Q8B4203@d
=0<0ATI60P10@40303Ti>@809RHV0`1GEeL309FEU@80R8R80`1LG5`202XZ:P<08R8R0`0T92@202DU
9@<09bLW0P0T92@6024Q8@808R8R0`0P820201lO7`<06a/K0`0Q8B4204A4A0<0KFe]0P2a/K430:FU
Y@<0SHf=0P1/K6`306QXJ080L71`0`28R8P30:>SX`80][Jf0`30`<020;>c/`<0XZ:R0P2SXj<60:JV
YP80XJ6Q0`2?Shl20820P0<0RXZ:0`2IVIT20::RXPD0ZJVY0`2XZ:P30:^[Z`80/;2`0`2j^[X20<71
`@<0][Jf0`2[Zj/20;6a/@<0^KVi0P2b/[860:VYZ@80ZZZZ0`2YZJT20:RXZ0<0YJFU1@2SXj<30:BT
Y080Z:RX0`2/[:`20;Fe]@<0^[Zj0`2][Jd209fMW@<0UYJF0P2EUID309bLW0<0YJFU0P2XZ:P30:^[
Z`80[Jf]0`2_[jl30;:b/P80][Jf0`2g]kL50;Rh^3@0b>3H0`13@d<20492@P<0A4A40P0e=CD303@d
=0D0;Rh^0`1EEED2065QH@<0HV9R0`0n?Sh202d];@<0:RXZ0P0W9bL302d];@80:BTY0`0];Bd303@d
=080>c/k1@0^;Rh303Ph>0<0?Shn0P0c<c<3034a<@80;bl_0`0f=SH3034a<@80<c<c0`10@402055A
D@<0C4a<0`1:BTX20451@@<0?Cdm0P14A4@303Ti>@<0@D510P1=CDd304I6AP80FEUI0`1@D50302TY
:@80:b/[0`1;Bd/203/k>`<0=CDe0P0];Bd305UIF@<0R8R80P2:RXX305iNGP809bLW0`0Y:BT302HV
9P8092@T0`0^;Rh202PX:0H08b<S0P0Q8B4301dM7@807QhN0`0O7al302HV9P80@D510`1cLg<20:BT
Y0<0[:b/0`28R8P2075aL@<0IfMW0P1dM7@308N7Q`<0WinO0P2f][H30;no_`80[Jf]0`2VYZH20:BT
Y0<0YZJV0`2UYJD20:>SX`<0SHf=0P26QXH30820P0<0Vi^K0P2WYjL30:BTY0D0[:b/0`2RXZ820;2`
/0<0`<300P2o_kl30;Jf]P<0[Jf]0P2/[:`30;fm_@80[Zj^0`2WYjL30:f][@80ZZZZ0`2YZJT20:ZZ
ZP<0XJ6Q0`2WYjL20:2PX0<0Z:RX0P2SXj<30:j^[P80/;2`0`2g]kL30;Fe]@80WYjN0`2?Shl209VI
V@<0WinO0`2VYZH20:FUY@<0ZZZZ0P2b/[830:f][@<0[jn_0P2d];@30;^k^`80];Bd0`2i^KTL0<SP
f0006`38h=P305]KF`80DU9B0`13@d<203Lg=`<0;Rh^0`0[:b/2030`<0<0BDU90P1QHF4305aLG0<0
Cdm?0P0[:b/302XZ:P809bLW1@0Z:RX302/[:`<0<C4a0P0f=SH3034a<@80;2`/0`0a<C4303Ph>080
=3@d0`0_;bl2030`<0<0<S8b0`0f=SH203/k>`<0BDU90P1DE5@304a<C0D0@D510`13@d<504A4A0<0
?clo0P0n?Sh30492@P80Fe]K0`1JFUX3024Q8@80<S8b0`0o?cl203/k>`<0<c<c0P0`<303059BDP<0
UYJF0P25QHD305YJFPD0:RXZ0`0c<c<503De=@80<30`0`0Z:RX302HV9P8092@T0`0R8R82024Q8@<0
71`L0`0M7Ad202`/;0<0BDU90P27QhL309bLW0<0VYZJ0P29RHT307QhN080Jf][0`1cLg<308B4Q080
WinO0`2f][H20;Fe]@<0[Zj^0P2XZ:P60:6QX@80WIfM0`2<S8`207UiN@<0R8R80`2MWId20:ZZZP<0
/k>c0P2`/;030:^[Z`<0[:b/0P2a/K430;^k^`80`/;20`2k^k/30;>c/`80][Jf0`2j^[X20;:b/P<0
ZZZZ1@2XZ:P30:NWY`80YJFU0`2SXj<30::RXP80X:2P0`2QXJ420:FUY@<0ZZZZ0P2b/[830;Rh^0<0
]KFe0P2^[Zh30:JVYP80WinO1P2MWId20::RXP<0Z:RX0P2ZZZX30:b/[0<0[jn_0P2b/[830;Bd]080
][Jf0`2g]kLd0<SPf0<0D51@0P1FEUH303lo?`80;bl_0`0^;Rh3038b<P80<c<c0`1ADE4205iNGP<0
H61P0`1=CDd2038b<P<0:b/[0P0Z:RX302TY:@809bLW0`0];Bd3038b<P80=cLg0`0c<c<202l_;`<0
<C4a0`0k>c/203<c<`<0<S8b0P0e=CD302h^;P<0<c<c0P0h>3P305=CD`80E5AD1P18B4P204E5A@<0
@T920P15ADD30451@@<0@d=30P0j>SX30410@080HF5Q0`1FEUH302/[:`80;Rh^0`0n?Sh20410@0<0
=cLg0P0l?3`305MGE`<0TY:B0P2>SXh305]KF`80:2PX0`0W9bL302`/;080;Bd]0`0[:b/202XZ:P<0
9BDU0`0T92@202XZ:P<08B4Q1@0N7Qh3024Q8@809BDU0`1:BTX208F5Q@<0Y:BT0`2LW9`208V9R@<0
L71`0P1ZJVX3079bLP<0Q8B40P2PX:030;Zj^P80_Kfm0`2WYjL20:BTY0<0YJFU0`2TY:@20:>SX`<0
QXJ60P20P80308>3P`<0VIVI0P2_[jl30;Fe]@80][Jf0`2^[Zh30:BTY080/[:b0`31`L420<30`0<0
^;Rh0`2i^KT20;>c/`<0^k^k0P2c/k<30:VYZ@<0YjNW0P2VYZH30:2PX080Z:RX0`2PX:030:BTY080
XJ6Q0`2UYJD20:BTY0<0[Zj^0P2_[jl30;Bd]0<0^k^k0P2e]KD30:FUY@80Vi^K0`2LW9`309^KV`80
Y:BT0`2WYjL20:j^[P<0[:b/0`2][Jd20;Fe]@<0][Jf0P2c/k<30;fm_A`0b>3H000K0<SPf0<0Fe]K
0P1BDU8304=3@`80=cLg0`0^;Rh302/[:`80<30`0`19BDT2065QH@<0G5aL0`1?Cdl202/[:`<0:RXZ
0P0W9bL502XZ:P<0:b/[0`0a<C4203Hf=P<0<C4a0P0/;2`3034a<@<0>3Ph0P0d=3@302l_;`80<30`
0`0b<S8303Hf=P80>c/k0`19BDT205ADE0<0C4a<1@11@D4304=3@`D0A4A40`0o?cl203hn?P<0@T92
0P1KFe/305YJFP<08B4Q0P0b<S8303lo?`80>c/k0`0c<c<2030`<0<0DU9B0`2FUYH208F5Q@<0FUYJ
1@0Z:RX303<c<`D0=CDe0P0`<30302XZ:P<09RHV0P0T92@3028R8P808B4Q0`0L71`301dM7@80;2`/
0`19BDT208N7Q`<0W9bL0`2JVYX208V9R@<0N7Qh0P1[Jf/307=cL`<0Q8B40P2OWil30;Jf]P80]KFe
0`2^[Zh20:RXZ0H0XJ6Q0P2MWId308b<S080NGUi0`28R8P309fMW@80ZZZZ0`2c/k<20;2`/0<0Zj^[
0`2/[:`20;6a/@<0^k^k0P32`/830;^k^`<0/k>c0P2f][H30;Zj^P80/[:b0`2ZZZX50:RXZ0<0YjNW
0P2UYJD30:>SX`<0XZ:R0P2PX:030:6QX@80YJFU0`2ZZZX20;:b/P<0^;Rh0`2e]KD20:j^[P<0YZJV
0P2OWil609fMW@80XZ:R0`2XZ:P20:ZZZP<0[:b/0`2_[jl20;:b/P<0];Bd0P2f][H30;Ng]c@0b>3H
0`1@D50205IFEP<0?clo0P0_;bl302h^;P<0<S8b0P0c<c<3055AD@80GUiN0`1PH60304e=C@80<S8b
0`0[:b/202XZ:P<0:BTY0P0W9bL302d];@<0<S8b0P0g=cL303<c<`80;bl_0`0a<C4303/k>`80<c<c
0`0b<S8203De=@<0;Rh^0`0c<c<203Ph>0<0De=C0P1DE5@604Q8B080ADE50`12@T8204E5A@<0@D51
0`13@d<203Xj>P<0@4100P1QHF4305IFEP<0:b/[0P0^;Rh303hn?P80@4100`0g=cL203`l?0<0EeMG
0`2BTY8208j>SP<0Fe]K0P0X:2P302LW9`<0;2`/0P0];Bd302/[:`80:RXZ0`0U9BD302@T9080:RXZ
0`0Q8B4501hN7P<08B4Q0P0U9BD304Y:BP80QHF50`2TY:@309bLW080RHV90`1`L70206YZJP<0LW9b
0`24Q8@20:2PX0<0^[Zj0P2m_Kd30:NWY`80Y:BT0`2UYJD30:BTY080Xj>S0`26QXH20820P0<0Ph>3
0`2IVIT20:n_[`<0]KFe0P2f][H30:j^[P<0Y:BT0P2b/[830<71`@80`<300`2h^;P30;Vi^@80/k>c
0`2k^k/20;>c/`<0ZJVY0`2WYjL20:JVYP<0X:2P0P2XZ:P30:2PX0<0Y:BT0P2QXJ430:FUY@80Y:BT
0`2^[Zh20:n_[`<0];Bd0`2k^k/20;Fe]@<0YJFU0P2KVi/309bLW0<0Vi^K0P2TY:@30:NWY`80[Zj^
0`2/[:`30:f][@80]KFe0`2f][H20;>c/`<0_Kfm7038h=P001/0b>3H0`1hN7P2065QH@<0@D510P0a
<C4602LW9`80;Rh^0`12@T8205IFEPH0GEeM0P0V9RH302l_;`80:2PX0`0[:b/202XZ:P<0:b/[0`0`
<30203<c<`<0<30`0P0/;2`302h^;P<0<C4a0P0`<30302l_;`80<30`0`0c<c<303hn?P80BDU90`1A
DE4205=CD`<0ATI60`0i>CT20410@0<0BTY:0P1=CDd304Y:BP<0>CTi0P0];Bd304];B`80G5aL0`1O
Gel302DU9@80;bl_0`0l?3`203@d=0<0;Rh^0P0n?Sh304i>CP<0SXj>0P24Q8@305iNGP80<C4a0`0h
>3P304M7A`80ATI60`11@D4203Xj>P<0<C4a0`0[:b/202HV9P<092@T0P0S8b<3024Q8@<0820P0P0O
7al302TY:@80E5AD0`23Ph<309^KV`80Xj>S0`2;Rh/206m_K`<0IFEU0`1VIVH208:2PP<0XJ6Q0P2`
/;030;Jf]P80[:b/0`2OWil309fMW@80V9RH0`26QXH207IfMP<0RXZ:0`2UYJD20;Bd]0<0_Kfm0P2f
][H30:f][@<0[jn_0P2d];@30;bl_080`l?30`31`L430;fm_@80_;bl0`2k^k/20;>c/`<0[:b/0`2Y
ZJT20:NWY`<0YJFU0P2SXj<30:6QX@<0X:2P1@2OWil20::RXP<0Z:RX0P2][Jd30;:b/P<0^KVi0P2m
_Kd30;Jf]P80[:b/0`2PX:0309RHV080WIfM0`2TY:@20:NWY`<0Z:RX0`2[Zj/20:j^[P<0/[:b0P2e
]KD30;Jf]S@0b>3H0`1eMGD206UYJ@<0AdM70P0];Bd302LW9`<0:b/[0P0];Bd303hn?P80EeMG0`1O
Gel305IFEP80;2`/0`0];Bd202TY:@<0;bl_0P0V9RH302/[:`<0;bl_0P0f=SH303@d=080;Bd]0`0[
:b/3038b<P80<30`0`0];Bd2034a<@<0=3@d0`0h>3P204Y:BP<0EUIF0P1?Cdl304E5A@<0>SXj0P0o
?cl304U9B@80Bd];0`15ADD30410@080<C4a0`15ADD2069RHP<0F5QH0`0[:b/202d];@D0?3`l0`0/
;2`2038b<P<0DE5A0`2>SXh208F5Q@<0F5QH0P0a<C4303hn?P<0@4100P1;Bd/304=3@`80?Shn0`0^
;Rh302TY:@809RHV0`0T92@502<S8`<07alO0P0Q8B4302TY:@80EUIF0`22PX8309ZJVP80X:2P0`28
R8P2075aL@<0K6a/0`1XJ6P207QhN0<0WinO0P2h^;P30;Fe]@80X:2P0`2WYjL30::RXP80V9RH0`20
P80207]kN`<0SXj>0`2PX:020;^k^`<0^[Zj0P2a/K430;Bd]0<0YZJV0P2g]kL30;bl_080`l?31P2l
_;`20;jn_P<0^;Rh0P2e]KD30:f][@<0ZZZZ0P2/[:`30::RXP80Y:BT0`2SXj<309nOW`80XJ6Q0`2N
WYh209nOW`<0YjNW0P2a/K430;Bd]0<0][Jf0P2l_;`30;6a/@80/;2`0`2OWil309RHV080W9bL0`2T
Y:@50:RXZ0<0YjNW0P2_[jl30;2`/080];Bd0`2j^[XL0<SPf0006`38h=P307QhN080HF5Q0`11@D42
034a<@H09bLW0P0^;Rh30492@P80EUIF1P1MGEd202HV9P<0;bl_0P0X:2P302/[:`80:RXZ0`0[:b/3
030`<080<c<c0`0`<30202`/;0<0;Rh^0`0a<C42030`<0<0;bl_0P0`<30303<c<`<0?Shn0P19BDT3
055AD@80De=C0`16ATH303Ti>@80@4100`1:BTX204e=C@<0BTY:0`0i>CT202d];@<0Bd];0P1LG5`3
05mOG`<09BDU0P0_;bl303`l?080=3@d0`0^;Rh203hn?P<0CTi>0`2>SXh208B4Q0<0GUiN0P0a<C43
03Ph>0<0AdM70P16ATH30451@@80>SXj0`0a<C4302/[:`809RHV0`0T92@202<S8`<08B4Q0`0P8202
01lO7`<0:BTY0P1DE5@308>3P`<0Vi^K0P2SXj<308^;R`80Kfm_0`1UIFD306IVIP80PX:20`2QXJ42
0;2`/0<0][Jf0P2/[:`309nOW`<0WIfM0P2HV9P308J6QP80MWIf0`2:RXX30:FUY@80];Bd0`2m_Kd2
0;Jf]P<0[Jf]0`2_[jl20;Bd]0<0_;bl0P33`l<30<71`@<0_Kfm0P2l_;`30;^k^`80/k>c0`2/[:`3
0:VYZ@80YjNW0`2UYJD20:>SX`<0XJ6Q0`2PX:0509nOW`80XZ:R0`2XZ:P20:f][@<0/[:b0`2i^KT2
0;fm_@<0][Jf0P2/[:`30:2PX0<0V9RH0P2MWId30:BTY080YjNW0`2XZ:P30:^[Z`80[Zj^0`2b/[82
0;Fe]@<0][Jf=038h=P307EeM@80JFUY0`17AdL202d];@<09bLW0`0[:b/202d];@<0?Shn0P1GEeL3
05mOG`<0EUIF0P0/;2`302d];@80:BTY0`0_;bl202HV9P<0:b/[0`0_;bl203Hf=P<0=3@d0P0];Bd3
02/[:`<0<S8b0P0`<30302d];@80<C4a0`0d=3@303Ph>080BTY:0`1FEUH204m?C`<0ADE50`0j>SX2
03lo?`<0BDU90P1;Bd/304E5A@<0@4100P0a<C4304E5A@80HV9R0`1HF5P302/[:`80;Bd]1@0l?3`3
02`/;080<S8b0`1ADE4308j>SP80QHF50`1HF5P2034a<@<0?Shn0`10@40204];B`<0@d=30P0n?Sh3
02h^;P<0:BTY0P0V9RH302@T90D08b<S0`0O7al2024Q8@<0:BTY0P1FEUH308:2PP<0VYZJ0P2PX:03
08R8R080LG5a0`1/K6`306QXJ080N7Qh0`2OWil20;Rh^0<0]KFe0P2PX:030:NWY`<0XZ:R0P2HV9P3
0820P080Ng]k0`2>SXh30:2PX080^k^k0`2j^[X20;6a/@<0];Bd0`2VYZH20;Ng]`<0_;bl0P33`l<6
0;bl_080_[jn0`2h^;P20;Fe]@<0[Jf]0`2ZZZX20:b/[0<0XZ:R0P2TY:@30:>SX`<0WinO0P2QXJ43
09jNWP80WinO0`2WYjL20;6a/@<0];Bd0`2f][H20;bl_0<0/K6a0P2`/;0309nOW`<0V9RH0P2LW9`3
0:BTY0D0Z:RX0`2WYjL20:n_[`<0/;2`0P2d];@30;Zj^Q`0b>3H000K0<SPf0<0N7Qh0P1QHF430451
@@80<C4a1P0W9bL202h^;P<0@T920P1FEUH605eMG@809RHV0`0_;bl202PX:0<0:b/[0P0Z:RX302/[
:`<0<30`0P0c<c<3030`<080;2`/0`0^;Rh3034a<@80<30`0`0_;bl2030`<0<0<c<c0`0n?Sh204U9
B@<0DE5A0P1CDe<304I6AP<0>CTi0P10@40304Y:BP80CDe=0`1:BTX303Ti>@80;Bd]0`1;Bd/205aL
G0<0GemO0`0U9BD202l_;`<0?3`l0P0d=3@302h^;P80?Shn0`1>CTh308j>SP80Q8B40`1NGUh2034a
<@<0>3Ph0`17AdL204I6AP<0@D510P0j>SX3034a<@<0:b/[0P0V9RH302@T90808b<S0`0Q8B43020P
80807alO0`0Y:BT205ADE0<0Ph>30`2KVi/20:>SX`<0Rh^;0P1_Kfl306EUI@<0IVIV0P22PX830:6Q
X@80/;2`0`2f][H20:b/[0<0WinO0`2MWId209RHV0<0QXJ60P1fMWH308Z:RP<0YJFU0P2d];@30;fm
_@80][Jf0`2][Jd30:n_[`80];Bd0`2l_;`20<?3``<0`L710`2m_Kd20;bl_0<0^k^k0P2c/k<30:b/
[0<0ZJVY0P2WYjL30:FUY@80Xj>S0`2QXJ430:2PX0D0WinO0P2RXZ830:RXZ080[Jf]0`2b/[830;Vi
^@80_Kfm0`2f][H20:b/[0<0X:2P0`2HV9P209fMW@<0Y:BT0P2WYjL30:RXZ0<0Zj^[0P2^[Zh30;:b
/P80]KFe0`2f][Hd0<SPf0<0MGEe0P1YJFT304M7A`80;Bd]0`0W9bL302/[:`80;Bd]0`0n?Sh205MG
E`<0GemO0`1FEUH202`/;0<0;Bd]0P0Y:BT302l_;`809RHV0`0[:b/302l_;`80=SHf0`0d=3@202d]
;@<0:b/[0`0b<S82030`<0<0;Bd]0P0a<C4303@d=0<0>3Ph0P1:BTX305IFEP80Cdm?0`15ADD303Xj
>P80?clo0`19BDT204];B`<0ADE50`10@402034a<@<0ADE50P1RHV8305QHF0<0:b/[0P0];Bd503`l
?0<0;2`/0P0b<S83055AD@<0SXj>0P25QHD305QHF080<C4a0`0n?Sh30410@080Bd];0`13@d<203hn
?P<0;Rh^0`0Y:BT202HV9P<092@T1@0S8b<301lO7`808B4Q0`0Y:BT205IFEP<0PX:20`2JVYX20:2P
X0<0R8R80P1aLG4306a/K0<0J6QX0P1hN7P309nOW`80^;Rh0`2e]KD20:2PX0<0YjNW0`2RXZ8209RH
V0<0P8200P1kNg/308j>SP<0X:2P0P2k^k/30;Zj^P80/K6a0`2d];@30:JVYP80]kNg0`2l_;`20<?3
``H0_;bl0P2n_[h30;Rh^080]KFe0`2][Jd30:ZZZP80[:b/0`2RXZ820:BTY0<0Xj>S0`2OWil20:6Q
X@<0WYjN0P2OWil30:NWY`80/K6a0`2d];@30;Jf]P80_;bl0`2a/K420;2`/0<0WinO0`2HV9P209bL
W0<0Y:BT1@2XZ:P30:NWY`80[jn_0`2`/;020;Bd]0<0^[Zj7038h=P001/0b>3H0`1fMWH206a/K0<0
F5QH0P0k>c/302@T90<09BDU0P0`<30303Xj>P80ADE50`1CDe<305aLG080=SHf0`0c<c<502d];@D0
;2`/0`0^;Rh202l_;`D0;Rh^0`0`<303034a<@80;Rh^0`0];Bd203@d=0<0?Cdm0`1;Bd/205ADE0<0
D51@0P18B4P30492@P<0?clo0P19BDT305=CD`80CTi>0`15ADD303@d=080;2`/0`0k>c/205mOG`<0
HF5Q0`0Q8B4202TY:@<0<c<c0P0_;bl302h^;P80B4Q80`1PH60308V9R@80R8R80`1]KFd204e=C@<0
Cdm?0`1IFET206EUI@<0JFUY0P1<C4`302`/;0D09BDU1@0T92@3028R8P<08B4Q0P0O7al302<S8`80
=cLg0`1GEeL307inOP80WIfM0`2GUiL208B4Q0<0K6a/0`1KFe/206IVIP<0PH610P2HV9P30:b/[080
/K6a0`2_[jl309nOW`80Ti>C0`1gMgL20820P0<0Ti>C0`2/[:`20;Jf]P<0_[jn0P2g]kL30:n_[`<0
/[:b0P2g]kL30;bl_080`<300`31`L450<30`0<0_[jn0P2h^;P30;6a/@<0[:b/0P2WYjL30:FUY@80
Y:BT0`2RXZ830:2PX080WinO0`2PX:020:>SX`<0YjNW0P2[Zj/30;2`/0<0][Jf0P2j^[X30;Rh^080
/[:b0`2ZZZX30::RXP80XJ6Q0`2RXZ820:BTY0<0YjNW0`2[Zj/20:j^[P<0/[:b0P2d];@30;Fe]C@0
b>3H0`1hN7P206QXJ0<0EeMG0P0`<30302`/;0<09RHV0P0[:b/303Hf=P80?clo0`1KFe/305eMG@80
=SHf0`0];Bd202l_;`<0;2`/0P0[:b/303De=@P0:RXZ0P0[:b/302h^;P<0<30`0P0a<C4302/[:`80
=cLg0`13@d<304a<C080E5AD0`1@D50204i>CP<0>c/k0`0o?cl204Q8B0<0EUIF0P1EEED304E5A@<0
>3Ph0P0X:2P303Ph>080IfMW0`1CDe<302@T90808b<S0`0];Bd203Ti>@<0:b/[0P0k>c/3069RHP<0
TI6A0P27QhL306=SH`80EUIF0`1ADE4306ATI080Kfm_0`1SHf<205UIF@<0<c<c0`0U9BD2024Q8@<0
:RXZ0P0R8R8302@T90<07alO0P0R8R8302PX:080;Rh^0`1@D50308J6QP80WinO0`2RXZ820861P@<0
IVIV0`1MGEd206=SH`<0O7al0P2NWYh30;Fe]@80Zj^[0`2QXJ430:BTY080SXj>0`1jNWX207]kN`<0
QXJ60`2`/;020;jn_P<0^[Zj0P2^[Zh30:n_[`<0];Bd0P2e]KD30<30`080`L711P2o_kl20<71`@<0
_kno0P2e]KD30:j^[P<0ZZZZ0P2VYZH30::RXP80YJFU0`2RXZ8309nOW`80W9bL0`2QXJ4209nOW`<0
YZJV0P2ZZZX30:f][@<0]KFe0P2i^KT30;Jf]P80/[:b0`2`/;030::RXP80WYjN0`2PX:020:BTY0<0
YjNW202][Jd20;2`/0<0^k^k7038h=P001/0b>3H0`1fMWH206a/K0<0F5QH0P0k>c/302@T90<09BDU
0P0`<30303Xj>P80ADE50`1CDe<305aLG080=SHf0`0c<c<502d];@D0;2`/0`0^;Rh202l_;`D0;Rh^
0`0`<303034a<@80;Rh^0`0];Bd203@d=0<0?Cdm0`1;Bd/205ADE0<0D51@0P18B4P30492@P<0?clo
0P19BDT305=CD`80CTi>0`15ADD303@d=080;2`/0`0k>c/205mOG`<0HF5Q0`0Q8B4202TY:@<0<c<c
0P0_;bl302h^;P80B4Q80`1PH60308V9R@80R8R80`1]KFd204e=C@<0Cdm?0`1IFET206EUI@<0JFUY
0P1<C4`302`/;0D09BDU1@0T92@3028R8P<08B4Q0P0O7al302<S8`80=cLg0`1GEeL307inOP80WIfM
0`2GUiL208B4Q0<0K6a/0`1KFe/206IVIP<0PH610P2HV9P30:b/[080/K6a0`2_[jl309nOW`80Ti>C
0`1gMgL20820P0<0Ti>C0`2/[:`20;Jf]P<0_[jn0P2g]kL30:n_[`<0/[:b0P2g]kL30;bl_080`<30
0`31`L450<30`0<0_[jn0P2h^;P30;6a/@<0[:b/0P2WYjL30:FUY@80Y:BT0`2RXZ830:2PX080WinO
0`2PX:020:>SX`<0YjNW0P2[Zj/30;2`/0<0][Jf0P2j^[X30;Rh^080/[:b0`2ZZZX30::RXP80XJ6Q
0`2RXZ820:BTY0<0YjNW0`2[Zj/20:j^[P<0/[:b0P2d];@30;Fe]C@0b>3H0`1hN7P206QXJ0<0EeMG
0P0`<30302`/;0<09RHV0P0[:b/303Hf=P80?clo0`1KFe/305eMG@80=SHf0`0];Bd202l_;`<0;2`/
0P0[:b/303De=@P0:RXZ0P0[:b/302h^;P<0<30`0P0a<C4302/[:`80=cLg0`13@d<304a<C080E5AD
0`1@D50204i>CP<0>c/k0`0o?cl204Q8B0<0EUIF0P1EEED304E5A@<0>3Ph0P0X:2P303Ph>080IfMW
0`1CDe<302@T90808b<S0`0];Bd203Ti>@<0:b/[0P0k>c/3069RHP<0TI6A0P27QhL306=SH`80EUIF
0`1ADE4306ATI080Kfm_0`1SHf<205UIF@<0<c<c0`0U9BD2024Q8@<0:RXZ0P0R8R8302@T90<07alO
0P0R8R8302PX:080;Rh^0`1@D50308J6QP80WinO0`2RXZ820861P@<0IVIV0`1MGEd206=SH`<0O7al
0P2NWYh30;Fe]@80Zj^[0`2QXJ430:BTY080SXj>0`1jNWX207]kN`<0QXJ60`2`/;020;jn_P<0^[Zj
0P2^[Zh30:n_[`<0];Bd0P2e]KD30<30`080`L711P2o_kl20<71`@<0_kno0P2e]KD30:j^[P<0ZZZZ
0P2VYZH30::RXP80YJFU0`2RXZ8309nOW`80W9bL0`2QXJ4209nOW`<0YZJV0P2ZZZX30:f][@<0]KFe
0P2i^KT30;Jf]P80/[:b0`2`/;030::RXP80WYjN0`2PX:020:BTY0<0YjNW202][Jd20;2`/0<0^k^k
7038h=P001/0b>3H0`1eMGD205IFEP<0;bl_0P0V9RH302LW9`<0;2`/1@0c<c<203@d=0<0AdM70`1F
EUH204Y:BP<0>CTi0P0c<c<3030`<080;Rh^0`0];Bd502`/;0<0;Bd]0P0_;bl3038b<P<0<c<c0P0^
;Rh302`/;080>SXj0`1:BTX305IFEP80Fe]K0`1<C4`203`l?0<0@4100`18B4P205=CD`<0FUYJ0P1<
C4`303/k>`D0;bl_0`0/;2`2065QH@<0GemO0`0N7Qh202<S8`<0;Bd]0P0^;Rh303Hf=P80EEEE0`1e
MGD308>3P`80RHV90`1fMWH2065QH@<0I6AT0`1XJ6P205iNGP<0CTi>0P0j>SX302TY:@P09BDU0P0T
92@802<S8`<09BDU0P0T92@302d];@<0FUYJ0P28R8P309RHV080UYJF0`1hN7P305UIF@80EEEE0`1R
HV8207alO0<0V9RH0P2_[jl30;Zj^P<0Xj>S0P2>SXh306a/K080Shn?0`2LW9`30:n_[`80][Jf0`2l
_;`20;Jf]P<0/;2`0`2d];@20;Zj^P<0^k^k0P2m_Kd30;no_`D0`/;20`31`L420;fm_@<0]kNg0`2`
/;020:ZZZP<0YjNW0P2VYZH30::RXP<0WinO0P2PX:030::RXP80Y:BT0`2VYZH20:VYZ@<0[Jf]0`2`
/;020;>c/`D0][Jf0`2c/k<30:j^[P80YjNW0`2QXJ420::RXP<0YZJV0`2ZZZX20:j^[P<0/K6a0P2c
/k<30;Bd]3@0b>3H0`1bLW8205eMG@<0=3@d0P0];Bd302HV9P<0:BTY0P0_;bl303`l?080<c<c0`13
@d<305QHF080AdM70`11@D4203<c<`D0<30`0`0[:b/302d];@80<C4a0`0];Bd2034a<@<0<S8b0`0h
>3P202l_;`<0<C4a0P0d=3@304I6AP<0G5aL0P1@D50305=CD`80>c/k0`0o?cl304];B`80CTi>0`1I
FET204];B`<0?Cdm0`0/;2`202h^;P<0>SXj0P1RHV8305=CD`<09BDU0P0S8b<302XZ:P80=cLg0`0a
<C4205=CD`<0LW9b0`28R8P208N7Q`<0Jf][0P1XJ6P305iNGP<0GemO0P1MGEd304Q8B080=CDe0`0U
9BD302<S8`809RHV0`0Z:RX202@T90<08B4Q0`0U9BD202@T90<09BDU0P0Q8B43038b<P<0Fe]K0P23
Ph<309ZJVP80U9BD0`1eMGD305YJFP80De=C0`1VIVH207IfMP<0UYJF0P2d];@30;Jf]P<0YJFU0P29
RHT307QhN080SHf=0`2EUID30:b/[080^k^k0`2l_;`20;Jf]P<0/;2`0`2e]KD20;^k^`<0^[Zj0P2l
_;`30<30`0<0`/;21@31`L420;fm_@<0][Jf0`2c/k<20:NWY`<0ZJVY1@2UYJD80:6QX@80YZJV0`2U
YJD20:ZZZP<0[jn_0`2/[:`20;Bd]0<0]kNg0P2f][H30;:b/P<0[Jf]0P2WYjL30:BTY080XJ6Q0`2V
YZH30:^[Z`80[Jf]0`2/[:`20;6a/@<0^;Rh7038h=P001/0b>3H0`1eMGD205IFEP<0;bl_0P0V9RH3
02LW9`<0;2`/1@0c<c<203@d=0<0AdM70`1FEUH204Y:BP<0>CTi0P0c<c<3030`<080;Rh^0`0];Bd5
02`/;0<0;Bd]0P0_;bl3038b<P<0<c<c0P0^;Rh302`/;080>SXj0`1:BTX305IFEP80Fe]K0`1<C4`2
03`l?0<0@4100`18B4P205=CD`<0FUYJ0P1<C4`303/k>`D0;bl_0`0/;2`2065QH@<0GemO0`0N7Qh2
02<S8`<0;Bd]0P0^;Rh303Hf=P80EEEE0`1eMGD308>3P`80RHV90`1fMWH2065QH@<0I6AT0`1XJ6P2
05iNGP<0CTi>0P0j>SX302TY:@P09BDU0P0T92@802<S8`<09BDU0P0T92@302d];@<0FUYJ0P28R8P3
09RHV080UYJF0`1hN7P305UIF@80EEEE0`1RHV8207alO0<0V9RH0P2_[jl30;Zj^P<0Xj>S0P2>SXh3
06a/K080Shn?0`2LW9`30:n_[`80][Jf0`2l_;`20;Jf]P<0/;2`0`2d];@20;Zj^P<0^k^k0P2m_Kd3
0;no_`D0`/;20`31`L420;fm_@<0]kNg0`2`/;020:ZZZP<0YjNW0P2VYZH30::RXP<0WinO0P2PX:03
0::RXP80Y:BT0`2VYZH20:VYZ@<0[Jf]0`2`/;020;>c/`D0][Jf0`2c/k<30:j^[P80YjNW0`2QXJ42
0::RXP<0YZJV0`2ZZZX20:j^[P<0/K6a0P2c/k<30;Bd]3@0b>3H0`1bLW8205eMG@<0=3@d0P0];Bd3
02HV9P<0:BTY0P0_;bl303`l?080<c<c0`13@d<305QHF080AdM70`11@D4203<c<`D0<30`0`0[:b/3
02d];@80<C4a0`0];Bd2034a<@<0<S8b0`0h>3P202l_;`<0<C4a0P0d=3@304I6AP<0G5aL0P1@D503
05=CD`80>c/k0`0o?cl304];B`80CTi>0`1IFET204];B`<0?Cdm0`0/;2`202h^;P<0>SXj0P1RHV83
05=CD`<09BDU0P0S8b<302XZ:P80=cLg0`0a<C4205=CD`<0LW9b0`28R8P208N7Q`<0Jf][0P1XJ6P3
05iNGP<0GemO0P1MGEd304Q8B080=CDe0`0U9BD302<S8`809RHV0`0Z:RX202@T90<08B4Q0`0U9BD2
02@T90<09BDU0P0Q8B43038b<P<0Fe]K0P23Ph<309ZJVP80U9BD0`1eMGD305YJFP80De=C0`1VIVH2
07IfMP<0UYJF0P2d];@30;Jf]P<0YJFU0P29RHT307QhN080SHf=0`2EUID30:b/[080^k^k0`2l_;`2
0;Jf]P<0/;2`0`2e]KD20;^k^`<0^[Zj0P2l_;`30<30`0<0`/;21@31`L420;fm_@<0][Jf0`2c/k<2
0:NWY`<0ZJVY1@2UYJD80:6QX@80YZJV0`2UYJD20:ZZZP<0[jn_0`2/[:`20;Bd]0<0]kNg0P2f][H3
0;:b/P<0[Jf]0P2WYjL30:BTY080XJ6Q0`2VYZH30:^[Z`80[Jf]0`2/[:`20;6a/@<0^;Rh7038h=P0
01/0b>3H0`1eMGD205IFEP<0;bl_0P0V9RH302LW9`<0;2`/1@0c<c<203@d=0<0AdM70`1FEUH204Y:
BP<0>CTi0P0c<c<3030`<080;Rh^0`0];Bd502`/;0<0;Bd]0P0_;bl3038b<P<0<c<c0P0^;Rh302`/
;080>SXj0`1:BTX305IFEP80Fe]K0`1<C4`203`l?0<0@4100`18B4P205=CD`<0FUYJ0P1<C4`303/k
>`D0;bl_0`0/;2`2065QH@<0GemO0`0N7Qh202<S8`<0;Bd]0P0^;Rh303Hf=P80EEEE0`1eMGD308>3
P`80RHV90`1fMWH2065QH@<0I6AT0`1XJ6P205iNGP<0CTi>0P0j>SX302TY:@P09BDU0P0T92@802<S
8`<09BDU0P0T92@302d];@<0FUYJ0P28R8P309RHV080UYJF0`1hN7P305UIF@80EEEE0`1RHV8207al
O0<0V9RH0P2_[jl30;Zj^P<0Xj>S0P2>SXh306a/K080Shn?0`2LW9`30:n_[`80][Jf0`2l_;`20;Jf
]P<0/;2`0`2d];@20;Zj^P<0^k^k0P2m_Kd30;no_`D0`/;20`31`L420;fm_@<0]kNg0`2`/;020:ZZ
ZP<0YjNW0P2VYZH30::RXP<0WinO0P2PX:030::RXP80Y:BT0`2VYZH20:VYZ@<0[Jf]0`2`/;020;>c
/`D0][Jf0`2c/k<30:j^[P80YjNW0`2QXJ420::RXP<0YZJV0`2ZZZX20:j^[P<0/K6a0P2c/k<30;Bd
]3@0b>3H0`1bLW8205eMG@<0=3@d0P0];Bd302HV9P<0:BTY0P0_;bl303`l?080<c<c0`13@d<305QH
F080AdM70`11@D4203<c<`D0<30`0`0[:b/302d];@80<C4a0`0];Bd2034a<@<0<S8b0`0h>3P202l_
;`<0<C4a0P0d=3@304I6AP<0G5aL0P1@D50305=CD`80>c/k0`0o?cl304];B`80CTi>0`1IFET204];
B`<0?Cdm0`0/;2`202h^;P<0>SXj0P1RHV8305=CD`<09BDU0P0S8b<302XZ:P80=cLg0`0a<C4205=C
D`<0LW9b0`28R8P208N7Q`<0Jf][0P1XJ6P305iNGP<0GemO0P1MGEd304Q8B080=CDe0`0U9BD302<S
8`809RHV0`0Z:RX202@T90<08B4Q0`0U9BD202@T90<09BDU0P0Q8B43038b<P<0Fe]K0P23Ph<309ZJ
VP80U9BD0`1eMGD305YJFP80De=C0`1VIVH207IfMP<0UYJF0P2d];@30;Jf]P<0YJFU0P29RHT307Qh
N080SHf=0`2EUID30:b/[080^k^k0`2l_;`20;Jf]P<0/;2`0`2e]KD20;^k^`<0^[Zj0P2l_;`30<30
`0<0`/;21@31`L420;fm_@<0][Jf0`2c/k<20:NWY`<0ZJVY1@2UYJD80:6QX@80YZJV0`2UYJD20:ZZ
ZP<0[jn_0`2/[:`20;Bd]0<0]kNg0P2f][H30;:b/P<0[Jf]0P2WYjL30:BTY080XJ6Q0`2VYZH30:^[
Z`80[Jf]0`2/[:`20;6a/@<0^;Rh7038h=P001/0b>3H0`1cLg<205QHF0<0=CDe0P0^;Rh302XZ:P<0
;bl_0P0e=CD302h^;P80:RXZ0`0n?Sh304m?C`80GEeM0`0n?Sh203Lg=`<0<30`0P0^;Rh302d];@<0
;2`/0P0];Bd302h^;P80<30`1P0a<C4202h^;P<0;bl_0P14A4@605QHF080DU9B0`16ATH203dm?@<0
@d=30`1>CTh205UIF@<0GUiN0P17AdL3030`<0<0;2`/0P0c<c<303Xj>P80Fe]K0`1?Cdl302@T9080
8B4Q0`0X:2P203hn?P<0De=C0P1[Jf/307moO`<0P8200P1kNg/3069RHP80AdM70`0j>SX3034a<@80
:BTY0`0U9BD202TY:@<0;bl_0`0/;2`702PX:0<09BDU0`0R8R8202<S8`<092@T0P0P820302<S8`<0
?Shn0P1MGEd307alO080Shn?0`1lO7`3061PH080IfMW0`1GEeL206ATI0<0MgMg0P2EUID30:^[Z`<0
ZZZZ0P2<S8`307EeM@D0WinO0`2PX:020;bl_0D0][Jf0`2c/k<30;Fe]@80^;Rh0`2i^KT20;Zj^P<0
_Kfm0`2o_kl50<30`080_;bl0`2g]kL30;>c/`80[Zj^0`2YZJT20:FUY@<0XZ:R0`2OWil20:2PX0<0
XJ6Q0P2SXj<30:FUY@80YjNW0`2YZJT30:b/[080[jn_0`2d];@20;Rh^0<0]KFe0`2`/;020:RXZ0<0
XZ:R1@2PX:030:>SX`80YjNW0`2][Jd20;6a/@<0/k>c=038h=P307IfMP80DU9B0`0^;Rh202LW9`<0
:b/[0`0a<C4203/k>`<0=3@d0P0[:b/303`l?0<0E5AD0P1@D50303dm?@80>CTi0`0a<C4202`/;0<0
:b/[0`0];Bd502l_;`80=CDe0`0_;bl302h^;P80:b/[0`0_;bl203hn?P<0F5QH0`1OGel205QHF0<0
@T920P0j>SX30451@@<0EEEE0P1GEeL3061PH080CDe=0`0[:b/302LW9`80;bl_0`10@40205MGE`<0
D51@0`0U9BD202XZ:P<0;2`/0P0j>SX305aLG080J6QX0`1mOGd308f=S@80QXJ60`1LG5`204I6AP<0
?clo0`0f=SH202l_;`<0;Rh^0P0Z:RX3034a<@<0:BTY0P0Z:RX302HV9P80:BTY0`0S8b<5028R8P<0
92@T0P0X:2P302HV9P<0;bl_0P1OGel307inOP80Ti>C0`1jNWX306IVIP80JFUY0`1PH60205aLG0<0
MgMg0P2EUID30;Fe]@<0[Zj^0P26QXH307MgM`80YZJV0`2NWYh30:NWY`80_;bl0`2f][H50;Bd]0<0
]KFe0P2f][H30;Fe]@80^[Zj0`2l_;`30<71`@80_[jn0`2o_kl20;jn_P<0^KVi0`2d];@20;6a/@<0
ZJVY0P2RXZ830:BTY0<0Vi^K0P2LW9`30::RXP80Y:BT0`2UYJD20:RXZ0<0Zj^[0`2/[:`20;2`/0<0
]KFe0P2f][H30;>c/`<0/K6a0P2VYZH30::RXP80Vi^K0`2PX:030:FUY@80[:b/0`2^[Zh50;Jf]Q`0
b>3H000K0<SPf0<0Lg=c0P1HF5P303De=@80;Rh^0`0Z:RX302l_;`80=CDe0`0^;Rh202XZ:P<0?Shn
0`1?Cdl205eMG@<0?Shn0P0g=cL3030`<080;Rh^0`0];Bd302`/;080;Bd]0`0^;Rh2030`<0H0<C4a
0P0^;Rh302l_;`80A4A41P1HF5P2059BDP<0ATI60P0m?Cd304=3@`<0CTi>0P1IFET305iNGP80AdM7
0`0`<30302`/;080<c<c0`0j>SX205]KF`<0Cdm?0`0T92@2024Q8@<0:2PX0P0n?Sh305=CD`80Jf][
0`1oOgl30820P080Ng]k0`1RHV8204M7A`<0>SXj0`0a<C4202TY:@<09BDU0P0Y:BT302l_;`<0;2`/
1`0X:2P302DU9@<08R8R0P0S8b<302@T9080820P0`0S8b<303hn?P80GEeM0`1lO7`208n?S`<0O7al
0`1PH60206MWI`<0EeMG0P1TI6@307MgM`80UIFE0`2[Zj/30:ZZZP80S8b<0`1eMGD509nOW`<0X:2P
0P2l_;`50;Jf]P<0/k>c0`2e]KD20;Rh^0<0^KVi0P2j^[X30;fm_@<0_kno1@30`<020;bl_0<0]kNg
0`2c/k<20:j^[P<0ZJVY0P2UYJD30::RXP<0WinO0P2PX:030:6QX@80Xj>S0`2UYJD20:NWY`<0ZJVY
0`2/[:`20:n_[`<0];Bd0P2h^;P30;Fe]@<0/;2`0P2XZ:P30::RXPD0X:2P0`2SXj<20:NWY`<0[Jf]
0P2a/K430;>c/c@0b>3H0`1fMWH2059BDP<0;Rh^0P0W9bL302/[:`<0<C4a0P0k>c/303@d=080:b/[
0`0l?3`305ADE080D51@0`0m?Cd203Ti>@<0<C4a0P0/;2`302/[:`<0;Bd]1@0_;bl203De=@<0;bl_
0`0^;Rh202/[:`<0;bl_0P0n?Sh305QHF0<0GemO0P1HF5P30492@P80>SXj0`11@D4305EEE@80EeMG
0`1PH60204e=C@<0:b/[0`0W9bL202l_;`<0@4100P1GEeL3051@D0<09BDU0P0Z:RX302`/;080>SXj
0`1LG5`206QXJ0<0OGem0`2=SHd208J6QP<0G5aL0P16ATH303lo?`<0=SHf0P0_;bl302h^;P80:RXZ
0`0a<C4302TY:@80:RXZ0`0V9RH202TY:@<08b<S1@0R8R8302@T9080:2PX0`0V9RH302l_;`80GemO
0`1nOWh209>CT`<0NWYj0`1VIVH206UYJ@<0H61P0P1LG5`307MgM`80UIFE0`2e]KD30:j^[P80QXJ6
0`1gMgL20:JVYP<0WYjN0`2WYjL20;bl_0<0][Jf1@2d];@30;Fe]@80][Jf0`2e]KD20;Zj^P<0_;bl
0`31`L420;jn_P<0_kno0P2n_[h30;Vi^@<0];Bd0P2a/K430:VYZ@80XZ:R0`2TY:@309^KV`80W9bL
0`2RXZ820:BTY0<0YJFU0P2XZ:P30:^[Z`<0[:b/0P2`/;030;Fe]@80][Jf0`2c/k<30;6a/@80YZJV
0`2RXZ8209^KV`<0X:2P0`2UYJD20:b/[0<0[Zj^1@2f][HL0<SPf0006`38h=P307=cL`80F5QH0`0e
=CD202h^;P<0:RXZ0`0_;bl203De=@<0;Rh^0P0Z:RX303hn?P<0Cdm?0P1MGEd303hn?P80=cLg0`0`
<30202h^;P<0;Bd]0`0/;2`202d];@<0;Rh^0P0`<306034a<@80;Rh^0`0_;bl204A4A0H0F5QH0P1B
DU8304I6AP80?Cdm0`13@d<304i>CP80FEUI0`1NGUh204M7A`<0<30`0`0/;2`203<c<`<0>SXj0P1K
Fe/304m?C`<092@T0P0Q8B4302PX:080?Shn0`1CDe<206][J`<0Ogmo0`20P80207]kN`<0HV9R0P17
AdL303Xj>P<0<C4a0P0Y:BT302DU9@80:BTY0`0_;bl302`/;0L0:2PX0`0U9BD3028R8P808b<S0`0T
92@2020P80<08b<S0`0n?Sh205eMG@<0O7al0P2?Shl307alO0<0H61P0P1WIfL305MGE`80I6AT0`1g
MgL209FEU@<0Zj^[0`2ZZZX208b<S0<0MGEe1@2OWil30:2PX080_;bl1@2f][H30;>c/`<0]KFe0P2h
^;P30;Vi^@80^[Zj0`2m_Kd30;no_`D0`<300P2l_;`30;Ng]`<0/k>c0P2^[Zh30:VYZ@80YJFU0`2R
XZ8309nOW`80X:2P0`2QXJ420:>SX`<0YJFU0P2WYjL30:VYZ@<0[:b/0P2_[jl30;Bd]080^;Rh0`2e
]KD30;2`/080Z:RX0`2RXZ850:2PX0<0Xj>S0P2WYjL30:f][@80/K6a0`2c/k<d0<SPf0<0MWIf0P1B
DU8302h^;P809bLW0`0[:b/3034a<@80>c/k0`0d=3@202/[:`<0?3`l0`1DE5@2051@D0<0?Cdm0P0i
>CT3034a<@80;2`/0`0[:b/302d];@D0;bl_0P0e=CD302l_;`<0;Rh^0P0[:b/302l_;`80?Shn0`1H
F5P305mOG`80F5QH0`12@T8203Xj>P<0@D510`1EEED205MGE`<0H61P0P1=CDd302/[:`<09bLW0P0_
;bl30410@080EeMG0`1@D50302DU9@80:RXZ0`0/;2`203Xj>P<0G5aL0P1XJ6P307emO@<0SHf=0P26
QXH305aLG080ATI60`0o?cl303Hf=P80;bl_0`0^;Rh202XZ:P<0<C4a0`0Y:BT202XZ:P<09RHV0P0Y
:BT302<S8`D08R8R0`0T92@202PX:0<09RHV0`0_;bl205mOG`<0OWin0P2CTi<307YjNP<0IVIV0P1Y
JFT3061PH080G5aL0`1gMgL209FEU@<0]KFe0`2^[Zh208J6QP<0MgMg0P2VYZH309jNWP<0YjNW0P2l
_;`30;Jf]PD0];Bd0`2e]KD20;Jf]P<0]KFe0P2j^[X30;bl_0<0`L710P2n_[h30;no_`80_[jn0`2i
^KT30;Bd]080/K6a0`2YZJT20::RXP<0Y:BT0`2KVi/209bLW0<0XZ:R0P2TY:@30:FUY@80Z:RX0`2[
Zj/30:b/[080/;2`0`2e]KD20;Jf]P<0/k>c0`2a/K420:JVYP<0XZ:R0P2KVi/30:2PX0<0YJFU0P2/
[:`30:j^[PD0][Jf7038h=P001/0b>3H0`1bLW8205]KF`<0?Shn0P0g=cL303<c<`<0=cLg0P0j>SX3
02l_;`809RHV0`0h>3P304Q8B080JFUY0`14A4@203`l?0<0<C4a0P0^;Rh602d];@l0;bl_0`0c<c<2
04a<C0<0HF5Q0`1GEeL204I6AP<0@T920P11@D4304U9B@<0DU9B0P1LG5`305iNGP80@T920`0W9bL3
02XZ:P80=SHf0`19BDT205ADE0<0?Shn0`0Y:BT202@T90<0:b/[0P1?Cdl3075aL@80Ogmo0`22PX83
07UiN@80IVIV0`14A4@202DU9@<0:2PX0`0b<S8503@d=080<c<c0`0b<S8302h^;P80:RXZ0`0[:b/2
02`/;0<0:2PX0`0T92@202<S8`<092@T0P0S8b<302@T90<0:2PX0P0d=3@305YJFP80Ng]k0`1jNWX3
06YZJP80OWin0`1FEUH205=CD`<0EUIF0P1fMWH309:BTP<0Zj^[0P27QhL30820P080[Jf]0`2NWYh3
08n?S`80_[jn0`2a/K420;Jf]PH0]KFe1@2f][H20;Rh^0<0^[Zj0`2l_;`50;fm_@80^[Zj0`2g]kL3
0;Fe]@80/k>c0`2/[:`20:FUY@<0XZ:R1@2PX:030:6QX@80Xj>S1@2UYJD30:JVYP<0Z:RX0P2/[:`3
0;>c/`80^;Rh0`2e]KD30:n_[`80ZZZZ0`2TY:@209jNWP<0Vi^K0`2MWId20::RXP<0ZJVY0P2_[jl3
0;6a/C@0b>3H0`1fMWH205eMG@<0@d=31@0e=CD303dm?@80>CTi0`0^;Rh202/[:`<0>3Ph0`1>CTh2
05mOG`<0BTY:0P0f=SH303@d=080:b/[0`0];Bd303<c<`80<C4a0`0Y:BT2034a<@<0;bl_0`0b<S82
03<c<`<0>CTi0P1:BTX3069RHP<0FEUI0P1:BTX303hn?P80ADE50`17AdL3059BDP80E5AD0`1QHF42
03/k>`<0:b/[0`0_;bl203Hf=P<0B4Q80P1FEUH30451@@<09bLW0P0X:2P302h^;P80AdM70`1fMWH2
07EeM@<0OWin0`21PH42069RHP<0>CTi1@0Z:RX302d];@80;bl_0`0^;Rh2030`<0<0<C4a0`0d=3@2
02/[:`<0;bl_0P0/;2`302h^;P<08b<S1@0R8R8202@T90<09RHV0`0Y:BT203Lg=`<0GemO0P1fMWH3
07alO0<0K6a/0P1eMGD305aLG080CTi>0`1KFe/207MgM`<0Ti>C0`2SXj<208^;R`<0NWYj0P2a/K43
09RHV0<0Ti>C0P2i^KT30;Fe]@80/k>c0`2f][H30;Bd]080^;Rh0`2f][H20;Rh^0<0^[Zj0`2l_;`2
0;^k^`<0_Kfm0P2k^k/30;Jf]P<0]KFe0P2c/k<30:ZZZPD0YJFU0`2QXJ420:2PX0<0XJ6Q0P2PX:03
0:JVYP80Y:BT0`2VYZH30:^[Z`80[:b/0`2c/k<20;Vi^@<0];Bd0`2_[jl20:b/[0<0YjNW0P2IVIT3
09bLW0<0Xj>S0P2NWYh30:FUY@80[Zj^0`2e]KDL0<SPf0006`38h=P3079bLP80Fe]K0`0n?Sh203Lg
=`<0<c<c0`0g=cL203Xj>P<0;bl_0P0V9RH303Ph>0<0B4Q80P1YJFT304A4A080?3`l0`0a<C4202h^
;PH0;Bd]3`0_;bl303<c<`80C4a<0`1QHF4305MGE`80ATI60`12@T820451@@<0BDU90`1BDU8205aL
G0<0GUiN0P12@T8302LW9`<0:RXZ0P0f=SH304U9B@80E5AD0`0n?Sh302TY:@8092@T0`0[:b/204m?
C`<0LG5a0P1oOgl308:2PP<0NGUi0P1VIVH304A4A0809BDU0`0X:2P3038b<PD0=3@d0P0c<c<3038b
<P<0;Rh^0P0Z:RX302/[:`80;2`/0`0X:2P302@T90808b<S0`0T92@202<S8`<092@T0`0X:2P203@d
=0<0FUYJ0P1kNg/307YjNP<0JVYZ0P1nOWh305IFEP80De=C0`1FEUH207IfMP<0TY:B0`2[Zj/208N7
Q`<0P8200P2][Jd309jNWP<0Shn?0P2n_[h30;6a/@80][Jf1P2e]KD50;Jf]P80^;Rh0`2j^[X30;bl
_0D0_Kfm0P2j^[X30;Ng]`<0]KFe0P2c/k<30:b/[080YJFU0`2RXZ850:2PX0<0XJ6Q0P2SXj<50:FU
Y@<0YZJV0`2XZ:P20:b/[0<0/k>c0P2h^;P30;Fe]@<0[jn_0P2ZZZX30:BTY080WYjN0`2KVi/309fM
W@80XZ:R0`2YZJT20:n_[`<0/K6a=038h=P307IfMP80GEeM0`13@d<503De=@<0?Cdm0P0i>CT302h^
;P80:b/[0`0h>3P304i>CP80GemO0`1:BTX203Hf=P<0=3@d0P0[:b/302d];@<0<c<c0P0a<C4302TY
:@80<C4a0`0_;bl3038b<P80<c<c0`0i>CT204Y:BP<0HV9R0`1IFET204Y:BP<0?Shn0P15ADD304M7
A`<0DU9B0P1DE5@3065QH@80>c/k0`0[:b/302l_;`80=SHf0`18B4P205IFEP<0@D510`0W9bL202PX
:0<0;Rh^0P17AdL307IfMP80MGEe0`1nOWh30861P@80HV9R0`0i>CT502XZ:P<0;Bd]0P0_;bl302h^
;P80<30`0`0a<C4303@d=080:b/[0`0_;bl202`/;0<0;Rh^0`0S8b<5028R8P8092@T0`0V9RH302TY
:@80=cLg0`1OGel207IfMP<0O7al0`1/K6`207EeM@<0G5aL0P1>CTh305]KF`80MgMg0`2CTi<30:>S
X`80Rh^;0`1jNWX20;6a/@<0V9RH0`2CTi<20;Vi^@<0]KFe0P2c/k<30;Jf]P<0];Bd0P2h^;P30;Jf
]P80^;Rh0`2j^[X30;bl_080^k^k0`2m_Kd20;^k^`<0][Jf0`2e]KD20;>c/`<0ZZZZ1@2UYJD30:6Q
X@80X:2P0`2QXJ420:2PX0<0YZJV0P2TY:@30:JVYP<0Zj^[0P2/[:`30;>c/`80^KVi0`2d];@30:n_
[`80[:b/0`2WYjL209VIV@<0W9bL0`2SXj<209jNWP<0YJFU0P2^[Zh30;Fe]A`0b>3H000K0<SPf0<0
L71`0P1QHF43051@D080@D510`1BDU8304m?C`80C4a<0`0m?Cd2034a<@<0>c/k0`17AdL205mOG`<0
D51@0P17AdL303Xj>P80=3@d0`0a<C4502l_;`<0;Rh^0P0];Bd302h^;P<0<30`0P0c<c<303Ti>@80
C4a<0`1KFe/3059BDP80ADE50`13@d<204A4A0<0C4a<0`1EEED205UIF@<0EUIF0P10@40302/[:`<0
;Bd]0P0f=SH304U9B@80DU9B0`0i>CT302HV9P80;bl_0`14A4@205=CD`<0Ng]k0P20P80307YjNP<0
IVIV0P1=CDd303Hf=P809BDU0`0W9bL302d];@80;bl_0`0`<302034a<@<0<S8b0`0`<30202d];@/0
;2`/0P0Y:BT302HV9PD09BDU0`0T92@202TY:@<0@4100P1IFET306MWI`<0KVi^0P22PX8306IVIP80
EeMG0`1:BTX205iNGP<0Lg=c0`2BTY8207MgM`<0Ng]k0P2a/K4309fMW@<0RHV90P2_[jl30;Jf]P80
^;Rh1P2c/k<20;Bd]0<0]KFe0P2f][H30;Ng]`<0^;Rh0P2k^k/30;bl_080^k^k0`2i^KT30;Rh^080
]KFe0`2`/;020:ZZZP<0YZJV0`2TY:@50::RXP80Y:BT0`2WYjL50:RXZ0<0Zj^[0P2][Jd30;:b/P80
][Jf0`2d];@30;6a/@80[Zj^0`2[Zj/20::RXP<0W9bL0`2OWil20:FUY@<0ZJVY0P2/[:`30:f][C@0
b>3H0`1]KFd205iNGP<0EUIF0P13@d<304Y:BP<0De=C0P14A4@303<c<`80<C4a0`0b<S8304U9B@80
IVIV0`1IFET204U9B@<0@D510P0^;Rh303<c<`<0=3@d1@0Z:RX2030`<0<0:b/[0`0_;bl203@d=0<0
<c<c0P16ATH3065QH@<0Bd];0P0k>c/304E5A@80A4A40`1HF5P305EEE@80Fe]K0`1IFET204E5A@<0
:BTY0`0];Bd203Lg=`<0B4Q80P1@D50303Hf=P<08R8R0P0_;bl303/k>`80FUYJ0`1fMWH208F5Q@<0
O7al0`1_Kfl204];B`<0:RXZ0P0[:b/302`/;0<0<30`0P0^;Rh303<c<`80>SXj0`0a<C4302/[:`L0
:BTY0`0/;2`302d];@80:2PX0`0Z:RX202<S8`H092@T0P0W9bL303Hf=P80G5aL0`1YJFT306i^KP80
NWYj0`1[Jf/504m?C`80GemO0`1_Kfl308V9R@80PX:20`1mOGd20;6a/@<0UiNG0`25QHD20;>c/`<0
]kNg0P2d];@30;Ng]`<0/K6a0P2f][H30;:b/P80][Jf0`2k^k/30;Jf]P80^k^k0`2m_Kd20;^k^`<0
^;Rh1@2d];@30:n_[`80ZJVY0`2WYjL30:6QX@80XZ:R0`2SXj<20:FUY@<0YjNW1@2VYZH30:FUY@80
Zj^[0`2a/K450;Jf]P<0/;2`0P2/[:`30:^[Z`80Xj>S0`2JVYX309fMW@80YJFU0`2WYjL20:VYZ@<0
YjNW7038h=P001/0b>3H0`1`L702065QH@<0D51@0P11@D43059BDP<0Cdm?0P1<C4`303dm?@80<C4a
0`0k>c/304M7A`80GemO0`1@D50204M7A`<0>SXj0P0d=3@3034a<@D0;bl_0`0^;Rh202d];@<0;Rh^
0`0`<30203<c<`<0>CTi0P1<C4`305]KF`<0DU9B0P15ADD304=3@`80A4A40`1<C4`305EEE@80FEUI
0`1FEUH20410@0<0:b/[0`0];Bd203Hf=P<0BDU90P1BDU8303Ti>@<09RHV0P0_;bl304A4A080De=C
0`1kNg/20820P0<0NWYj0`1VIVH204e=C@<0=SHf0P0U9BD302LW9`<0;Bd]0P0_;bl3030`<080<C4a
0`0b<S83030`<080;Bd]2`0/;2`202TY:@<09RHV1@0U9BD302@T9080:BTY0`10@40205UIF@<0IfMW
0`1^KVh208:2PP<0IVIV0P1GEeL304Y:BP80GUiN0`1cLg<309:BTP80MgMg0`1kNg/20;6a/@<0WIfM
0`29RHT20:n_[`<0][Jf0P2h^;P60;>c/`80];Bd0`2e]KD20;Jf]P<0]kNg0`2h^;P20;^k^`<0_;bl
0P2k^k/30;Vi^@<0^;Rh0P2e]KD30;2`/080ZZZZ0`2VYZH30:BTY0D0XZ:R0P2TY:@30:NWY`D0Z:RX
0`2[Zj/20:f][@<0/[:b0P2f][H30;Bd]0<0/K6a0P2^[Zh30:^[Z`80XZ:R0`2LW9`309nOW`80YJFU
0`2YZJT20:b/[0<0[Jf]=038h=P306e]K@80GUiN0`1FEUH204=3@`<0BTY:0`1CDe<204A4A0<0<c<c
0P0a<C43038b<P<0BDU90P1VIVH305UIF@80BDU90`11@D4202h^;P<0<c<c0`0d=3@502XZ:P80<30`
0`0[:b/302l_;`80=3@d0`0c<c<204I6AP<0HF5Q0`1;Bd/203/k>`<0ADE50P14A4@305QHF0<0EEEE
0P1KFe/305UIF@80ADE50`0Y:BT302d];@80=cLg0`18B4P2051@D0<0=SHf0`0R8R8202l_;`<0>c/k
0P1JFUX307IfMP80QHF50`1lO7`306m_K`80Bd];0`0Z:RX202/[:`<0;2`/0`0`<30202h^;P<0<c<c
0P0j>SX3034a<@<0:b/[1`0Y:BT302`/;0<0;Bd]0P0X:2P302XZ:P808b<S1P0T92@202LW9`<0=SHf
0P1LG5`306UYJ@<0KVi^0P1jNWX306][J`D0Cdm?0P1OGel306m_K`<0RHV90P22PX8307emO@80/K6a
0`2GUiL308F5Q@80/k>c0`2g]kL20;Bd]0<0]kNg0`2a/K420;Jf]P<0/[:b0P2f][H30;^k^`<0][Jf
0P2k^k/30;fm_@80^k^k0`2h^;P50;Bd]0<0[jn_0P2YZJT30:NWY`<0XJ6Q0P2RXZ830:>SX`80YJFU
0`2WYjL50:JVYP<0YJFU0P2[Zj/30;6a/@D0][Jf0`2`/;020:b/[0<0Zj^[0P2SXj<309ZJVP<0WIfM
0P2UYJD30:NWY`80ZJVY0`2WYjLL0<SPf0006`38h=P3071`L080HF5Q0`1@D5020451@@<0DU9B0`1?
Cdl204a<C0<0?Cdm0P0a<C4303/k>`<0AdM70P1OGel3051@D080AdM70`0j>SX203@d=0<0<C4a1@0_
;bl302h^;P80;Bd]0`0^;Rh3030`<080<c<c0`0i>CT204a<C0<0Fe]K0`1BDU8204E5A@<0@d=30P14
A4@304a<C0<0EEEE0P1IFET305IFEP80@4100`0[:b/302d];@80=SHf0`19BDT2059BDP<0>CTi0`0V
9RH202l_;`<0A4A40P1CDe<307]kN`80P8200`1jNWX306IVIP80CDe=0`0f=SH202DU9@<09bLW0`0]
;Bd202l_;`<0<30`0P0a<C43038b<P<0<30`0P0];Bd;02`/;080:BTY0`0V9RH502DU9@<092@T0P0Y
:BT30410@080FEUI0`1WIfL306i^KP80PX:20`1VIVH205MGE`<0BTY:0P1NGUh307=cL`<0TY:B0P1g
MgL307]kN`80/K6a0`2MWId308V9R@80[jn_0`2f][H20;Rh^0H0/k>c0P2d];@30;Fe]@80][Jf0`2g
]kL30;Rh^080^k^k0`2l_;`20;^k^`<0^KVi0`2h^;P20;Fe]@<0/;2`0P2ZZZX30:JVYP<0Y:BT1@2R
XZ820:BTY0<0YjNW1@2XZ:P30:^[Z`80[Jf]0`2b/[820;Jf]P<0];Bd0`2a/K420:j^[P<0Zj^[0P2R
XZ8309bLW0<0WinO0P2UYJD30:VYZ@80[:b/0`2][Jdd0<SPf0<0KFe]0P1NGUh305IFEP80@d=30`1:
BTX305=CD`80A4A40`0c<c<2034a<@<0<S8b0`19BDT206IVIP<0FEUI0P19BDT30451@@80;Rh^0`0c
<c<303@d=0D0:RXZ0P0`<30302/[:`<0;bl_0P0d=3@303<c<`80ATI60`1QHF4304];B`80>c/k0`15
ADD204A4A0<0F5QH0`1EEED205]KF`<0FEUI0P15ADD302TY:@<0;Bd]0P0g=cL304Q8B080D51@0`0f
=SH3028R8P80;bl_0`0k>c/205YJFP<0MWIf0P25QHD307alO0<0Kfm_0P1;Bd/302XZ:P80:b/[0`0/
;2`3030`<080;Rh^0`0c<c<203Xj>P<0<C4a0`0[:b/702TY:@<0;2`/0`0];Bd202PX:0<0:RXZ0P0S
8b<602@T90809bLW0`0f=SH205aLG0<0JFUY0`1^KVh207YjNP<0Jf][1@1?Cdl205mOG`<0Kfm_0`29
RHT208:2PP<0OGem0P2a/K4309NGU`<0QHF50P2c/k<30;Ng]`80];Bd0`2g]kL30;6a/@80][Jf0`2b
/[820;Jf]P<0^k^k0`2f][H20;^k^`<0_Kfm0P2k^k/30;Rh^0D0];Bd0`2_[jl20:VYZ@<0YjNW0`2Q
XJ420::RXP<0Xj>S0P2UYJD30:NWY`D0YZJV0`2UYJD20:^[Z`<0/K6a1@2f][H30;2`/080[:b/0`2[
Zj/20:>SX`<0VYZJ0`2MWId20:FUY@<0YjNW0P2YZJT30:NWYa`0b>3H000K0<SPf0<0Kfm_0P1VIVH3
061PH080BDU90`1^KVh306MWI`80GEeM0`1:BTX203/k>`<0?Shn0`17AdL2055AD@<0Fe]K0P1@D503
0492@P80>c/k0`0e=CD3034a<@80;bl_0`0/;2`202/[:`<0;Bd]0`0a<C4203Hf=P<0?Cdm0P19BDT3
05=CD`<0CDe=0P16ATH304E5A@80AdM70`1?Cdl305IFEP80EEEE0`1>CTh203lo?`<0<S8b0`0`<302
03De=@<0ATI60P1BDU8303Ph>0<08R8R0P0j>SX305eMG@80De=C0`1nOWh207]kN`<0LG5a0`1DE5@2
03Lg=`<0;Bd]0P0[:b/302d];@<0<C4a1@0b<S85034a<@<0<30`0P0_;bl302d];@80:b/[0`0`<303
03<c<`80;bl_0`0Y:BT202PX:0H09bLW0P0X:2P302d];@80>CTi0`1GEeL3075aL@80QhN70`1eMGD2
05aLG0<0@d=30P1;Bd/305QHF0<0Ng]k0P1[Jf/307IfMP80/K6a0`2LW9`308N7Q`80WYjN0`2l_;`2
0;Vi^@H0/K6a0P2b/[830;Bd]080][Jf1P2e]KD20;Vi^@<0_;bl0P2m_Kd30;bl_0<0^[Zj0P2g]kL3
0;>c/`80[Zj^0`2ZZZX30:NWY`80Y:BT0`2SXj<20:JVYP<0ZZZZ0P2[Zj/30:b/[0<0[Zj^0P2`/;03
0;:b/PD0/k>c1@2b/[830;6a/@80YjNW0`2NWYh30:>SX`80ZZZZ0`2[Zj/50:VYZC@0b>3H0`1ZJVX2
06IVIP<0F5QH0P1?Cdl306MWI`<0HV9R0P1MGEd304i>CP80ATI60`0k>c/304A4A080EeMG0`1JFUX2
04m?C`<0@T920P0c<c<303@d=0<0;Rh^0P0_;bl302d];@80;Rh^0`0[:b/3034a<@80=CDe0`0m?Cd2
04Y:BP<0EEEE0`1ADE4204I6AP<0EEEE0P14A4@304Q8B0<0EEEE0P1PH60304a<C080?Cdm0`0h>3P3
02DU9@80>3Ph0`1;Bd/204m?C`<0?clo0`0X:2P202`/;0<0GUiN0P1IFET307]kN`80P8200`1/K6`3
05iNGP80=CDe0`0Y:BT202d];@<0;bl_0`0b<S8202d];@<0<C4a1@0b<S8303@d=080<30`0`0/;2`2
02XZ:P<0<C4a0`0c<c<202/[:`<0;bl_0P0Q8B4302LW9`<0;2`/0P0V9RH303De=@80?3`l0`1CDe<3
06m_K`80RXZ:0`1fMWH205IFEP<0BDU90P1DE5@305eMG@<0K6a/0P1UIFD307alO080/K6a0`2JVYX3
08J6QP80YjNW0`2m_Kd50;Ng]`<0[jn_0P2c/k<30;Ng]`D0][Jf0`2g]kL20;Vi^@<0_Kfm0P2o_kl3
0;bl_0<0^KVi1@2f][H20:f][@<0[:b/0`2TY:@20::RXP<0X:2P0P2YZJT30:RXZ080ZJVY1P2^[Zh2
0;2`/0<0/k>c0P2a/K430;Rh^0<0/;2`0P2^[Zh30;6a/@80Zj^[1P2MWId20:ZZZP<0[Jf]0P2XZ:P3
0:JVYQ`0b>3H000K0<SPf0<0Kfm_0P1VIVH3061PH080BDU90`1^KVh306MWI`80GEeM0`1:BTX203/k
>`<0?Shn0`17AdL2055AD@<0Fe]K0P1@D5030492@P80>c/k0`0e=CD3034a<@80;bl_0`0/;2`202/[
:`<0;Bd]0`0a<C4203Hf=P<0?Cdm0P19BDT305=CD`<0CDe=0P16ATH304E5A@80AdM70`1?Cdl305IF
EP80EEEE0`1>CTh203lo?`<0<S8b0`0`<30203De=@<0ATI60P1BDU8303Ph>0<08R8R0P0j>SX305eM
G@80De=C0`1nOWh207]kN`<0LG5a0`1DE5@203Lg=`<0;Bd]0P0[:b/302d];@<0<C4a1@0b<S85034a
<@<0<30`0P0_;bl302d];@80:b/[0`0`<30303<c<`80;bl_0`0Y:BT202PX:0H09bLW0P0X:2P302d]
;@80>CTi0`1GEeL3075aL@80QhN70`1eMGD205aLG0<0@d=30P1;Bd/305QHF0<0Ng]k0P1[Jf/307If
MP80/K6a0`2LW9`308N7Q`80WYjN0`2l_;`20;Vi^@H0/K6a0P2b/[830;Bd]080][Jf1P2e]KD20;Vi
^@<0_;bl0P2m_Kd30;bl_0<0^[Zj0P2g]kL30;>c/`80[Zj^0`2ZZZX30:NWY`80Y:BT0`2SXj<20:JV
YP<0ZZZZ0P2[Zj/30:b/[0<0[Zj^0P2`/;030;:b/PD0/k>c1@2b/[830;6a/@80YjNW0`2NWYh30:>S
X`80ZZZZ0`2[Zj/50:VYZC@0b>3H0`1ZJVX206IVIP<0F5QH0P1?Cdl306MWI`<0HV9R0P1MGEd304i>
CP80ATI60`0k>c/304A4A080EeMG0`1JFUX204m?C`<0@T920P0c<c<303@d=0<0;Rh^0P0_;bl302d]
;@80;Rh^0`0[:b/3034a<@80=CDe0`0m?Cd204Y:BP<0EEEE0`1ADE4204I6AP<0EEEE0P14A4@304Q8
B0<0EEEE0P1PH60304a<C080?Cdm0`0h>3P302DU9@80>3Ph0`1;Bd/204m?C`<0?clo0`0X:2P202`/
;0<0GUiN0P1IFET307]kN`80P8200`1/K6`305iNGP80=CDe0`0Y:BT202d];@<0;bl_0`0b<S8202d]
;@<0<C4a1@0b<S8303@d=080<30`0`0/;2`202XZ:P<0<C4a0`0c<c<202/[:`<0;bl_0P0Q8B4302LW
9`<0;2`/0P0V9RH303De=@80?3`l0`1CDe<306m_K`80RXZ:0`1fMWH205IFEP<0BDU90P1DE5@305eM
G@<0K6a/0P1UIFD307alO080/K6a0`2JVYX308J6QP80YjNW0`2m_Kd50;Ng]`<0[jn_0P2c/k<30;Ng
]`D0][Jf0`2g]kL20;Vi^@<0_Kfm0P2o_kl30;bl_0<0^KVi1@2f][H20:f][@<0[:b/0`2TY:@20::R
XP<0X:2P0P2YZJT30:RXZ080ZJVY1P2^[Zh20;2`/0<0/k>c0P2a/K430;Rh^0<0/;2`0P2^[Zh30;6a
/@80Zj^[1P2MWId20:ZZZP<0[Jf]0P2XZ:P30:JVYQ`0b>3H000K0<SPf0<0Kfm_0P1WIfL306ATI080
Bd];0`1eMGD306UYJ@80GemO1@1NGUh3051@D0<0ADE50P1<C4`305eMG@80De=C0`14A4@203`l?0<0
=SHf0`0b<S8202l_;`<0;2`/0P0[:b/302d];@<0<C4a0P0g=cL303lo?`80BDU90`1ADE4304a<C080
ATI60`15ADD204M7A`<0D51@0`1GEeL205ADE0<0C4a<0P0o?cl303<c<`<0<C4a0P0d=3@304I6AP80
DU9B0`0g=cL3024Q8@80?3`l0`1SHf<205ADE0<0P8200P1kNg/306m_K`<0D51@0P0a<C4302XZ:P80
:b/[0`0];Bd:034a<@P0<30`0`0];Bd202/[:`<0<30`0`0e=CD2030`<0<0:RXZ1@0X:2P502HV9P<0
:BTY0P0b<S8304I6AP<0HF5Q0P1ADE4308R8R080MGEe0`1PH60205QHF0<0DU9B0`1QHF4204Q8B0<0
I6AT0P2c/k<309jNWP<0QXJ60P2KVi/30;fm_@80^KVi1P2`/;020;:b/P<0];Bd0P2f][H60;Fe]@80
^;Rh0`2l_;`20;fm_@<0_;bl0`2j^[X20;Ng]`<0/k>c0P2_[jl30:^[Z`<0Z:RX0P2TY:@30:>SX`80
YZJV0`2ZZZX20:^[Z`<0[:b/0`2^[Zh20;2`/0<0/[:b1@2c/k<30;:b/P80/k>c0`2b/[820:RXZ0<0
WinO0`2TY:@50:^[Z`D0ZJVY=038h=P307IfMP80Kfm_0`1LG5`205]KF`<0O7al0`1aLG4206YZJP<0
FEUI0P1EEED305=CD`<0BDU90P1:BTX3055AD@80CDe=0`1<C4`203dm?@<0?Shn0`0k>c/2038b<P<0
<30`0P0Y:BT302XZ:P<0>3Ph0P0j>SX304Q8B080CDe=0`18B4P304i>CP80@d=30`11@D4504E5A@<0
EEEE0P1ADE4304M7A`80?Shn0`0k>c/302LW9`80=SHf0`1<C4`2055AD@<0>3Ph0`0V9RH203Hf=P<0
LG5a0P1KFe/307UiN@80N7Qh0`1OGel305QHF080<S8b0`0X:2P202`/;0<0:b/[0`0_;bl203Xj>P<0
;bl_0P0/;2`302d];@D0<30`0`0f=SH2034a<@<0<30`0`0j>SX202l_;`<0:BTY0P0Z:RX302`/;0<0
:BTY0P0W9bL302TY:@80;2`/0`11@D4305mOG`80K6a/0`24Q8@206][J`<0F5QH0P1EEED305UIF@<0
HF5Q0P1?Cdl3079bLP80YjNW0`2QXJ4308>3P`80WIfM0`2f][H20;2`/0<0[Zj^0`2YZJT20;6a/@<0
]kNg0P2a/K430;2`/0<0/k>c0P2e]KD30;Ng]`80^k^k1P2l_;`20;Ng]`<0/[:b0P2[Zj/60:f][@80
YJFU0`2SXj<20:JVYP<0Zj^[0P2/[:`30:n_[`<0[:b/1@2c/k<20:n_[`<0/[:b0`2d];@20;>c/`<0
/;2`0P2YZJT30:NWY`<0X:2P0P2_[jl30;>c/`80[:b/0`2][JdL0<SPf0006`38h=P306m_K`80IfMW
0`1TI6@204];B`<0MGEe0`1YJFT205mOG`D0GUiN0`1@D50304E5A@80C4a<0`1MGEd205=CD`<0A4A4
0P0l?3`303Hf=P<0<S8b0P0_;bl302`/;080:b/[0`0];Bd3034a<@80=cLg0`0o?cl204U9B@<0DE5A
0`1<C4`204I6AP<0ADE50P17AdL3051@D0<0EeMG0P1DE5@304a<C080?clo0`0c<c<3034a<@80=3@d
0`16ATH2059BDP<0=cLg0`0Q8B4203`l?0<0Hf=S0P1DE5@30820P080Ng]k0`1_Kfl3051@D080<C4a
0`0Z:RX202/[:`<0;Bd]2P0a<C48030`<0<0;Bd]0P0[:b/3030`<0<0=CDe0P0`<30302XZ:PD0:2PX
1@0V9RH302TY:@80<S8b0`16ATH3065QH@80DE5A0`28R8P207EeM@<0H61P0P1HF5P3059BDP<0HF5Q
0P18B4P306ATI080/k>c0`2NWYh308J6QP80Vi^K0`2m_Kd20;Vi^@H0/;2`0P2b/[830;Bd]080][Jf
1P2e]KD20;Rh^0<0_;bl0P2m_Kd30;bl_0<0^[Zj0P2g]kL30;>c/`80[jn_0`2[Zj/30:RXZ080Y:BT
0`2SXj<20:JVYP<0ZZZZ0P2[Zj/30:b/[0<0[Zj^0P2`/;030;:b/PD0/k>c0`2b/[820;>c/`<0/[:b
0P2XZ:P309nOW`<0Y:BT1@2[Zj/50:VYZC@0b>3H0`1fMWH206m_K`<0G5aL0P1KFe/307alO0<0LG5a
0P1ZJVX305UIF@80EEEE0`1CDe<304U9B@80BTY:0`1ADE4204e=C@<0C4a<0P0m?Cd303hn?P<0>c/k
0P0b<S83030`<080:BTY0`0Z:RX303Ph>080>SXj0`18B4P204e=C@<0B4Q80`1>CTh204=3@`<0@D51
1@15ADD305EEE@80DE5A0`17AdL203hn?P<0>c/k0`0W9bL203Hf=P<0C4a<0P1ADE4303Ph>0<09RHV
0P0f=SH3075aL@80Fe]K0`1iNGT207QhN0<0GemO0`1HF5P2038b<P<0:2PX0P0/;2`302/[:`<0;bl_
0P0j>SX302l_;`80;2`/0`0];Bd5030`<0<0=SHf0P0a<C43030`<0<0>SXj0P0_;bl302TY:@80:RXZ
0`0/;2`302TY:@809bLW0`0Y:BT202`/;0<0@D510`1OGel206a/K0<0Q8B40P1[Jf/305QHF080EEEE
0`1IFET3065QH@80Cdm?0`1bLW820:NWY`<0XJ6Q0`23Ph<209fMW@<0][Jf0P2`/;030:j^[P<0ZJVY
0P2a/K430;Ng]`80/K6a0`2`/;030;>c/`80]KFe0`2g]kL20;^k^`H0_;bl0P2g]kL30;:b/P80Zj^[
1P2][Jd20:FUY@<0Xj>S0P2VYZH30:^[Z`80[:b/0`2_[jl30:b/[0D0/k>c0P2_[jl30;:b/P<0];Bd
0P2c/k<30;2`/080ZJVY0`2WYjL30:2PX080[jn_0`2c/k<20:b/[0<0[Jf]7038h=P001/0b>3H0`1_
Kfl206MWI`<0I6AT0P1;Bd/307EeM@<0JFUY0P1OGel505iNGP<0D51@0`15ADD204a<C0<0GEeM0P1C
De<304A4A080?3`l0`0f=SH3038b<P80;bl_0`0/;2`202/[:`<0;Bd]0`0a<C4203Lg=`<0?clo0P19
BDT3055AD@<0C4a<0P16ATH304E5A@80AdM70`1@D50305MGE`80E5AD0`1<C4`203lo?`<0<c<c0`0a
<C4203@d=0<0ATI60P1BDU8303Lg=`<08B4Q0P0l?3`306=SH`80E5AD0`20P80207]kN`<0Kfm_0`1@
D502034a<@<0:RXZ0P0[:b/302d];@X0<C4a200`<30302d];@80:b/[0`0`<30303De=@80<30`0`0Z
:RX502PX:0D09RHV0`0Y:BT2038b<P<0ATI60`1QHF42055AD@<0R8R80P1eMGD3061PH080F5QH0`1B
DU83065QH@80B4Q80`1TI6@20;>c/`<0WYjN0`26QXH209^KV`<0_Kfm0P2i^KT60;2`/080/[:b0`2d
];@20;Jf]PH0]KFe0P2h^;P30;bl_080_Kfm0`2l_;`30;Zj^P80]kNg0`2c/k<20:n_[`<0Zj^[0`2X
Z:P20:BTY0<0Xj>S0P2VYZH30:ZZZP80Zj^[0`2/[:`30:j^[P80/;2`0`2b/[850;>c/`<0/[:b0P2c
/k<30;:b/P80Z:RX0`2OWil30:BTY0D0Zj^[1@2YZJTd0<SPf0<0MWIf0P1_Kfl305aLG080Fe]K0`1l
O7`3075aL@80JVYZ0`1IFET205EEE@<0De=C0`19BDT204Y:BP<0DE5A0P1=CDd304a<C080?Cdm0`0n
?Sh303/k>`80<S8b0`0`<30202TY:@<0:RXZ0`0h>3P203Xj>P<0B4Q80P1=CDd304Q8B0<0CTi>0P13
@d<30451@@D0ADE50`1EEED2055AD@<0AdM70P0n?Sh303/k>`<09bLW0P0f=SH304a<C080DE5A0`0h
>3P302HV9P80=SHf0`1aLG4205]KF`<0NGUi0P1hN7P305mOG`<0F5QH0P0b<S8302PX:080;2`/0`0[
:b/302l_;`80>SXj0`0_;bl202`/;0<0;Bd]1@0`<30303Hf=P80<C4a0`0`<30303Xj>P80;bl_0`0Y
:BT202XZ:P<0;2`/0`0Y:BT202LW9`<0:BTY0P0/;2`30451@@<0GemO0P1/K6`308B4Q080Jf][0`1H
F5P205EEE@<0FEUI0`1QHF4204m?C`<0LW9b0P2WYjL30:6QX@<0Ph>30P2MWId30;Jf]P80/;2`0`2^
[Zh30:VYZ@80/K6a0`2g]kL20;6a/@<0/;2`0`2c/k<20;Fe]@<0]kNg0P2k^k/60;bl_080]kNg0`2b
/[820:^[Z`H0[Jf]0P2UYJD30:>SX`80YZJV0`2[Zj/20:b/[0<0[jn_0`2/[:`50;>c/`80[jn_0`2b
/[830;Bd]080/k>c0`2`/;020:VYZ@<0YjNW0`2PX:020:n_[`<0/k>c0P2/[:`30:f][A`0b>3H003o
0<SPf?l0b>3Ho`38h=P60<SPf000o`38h=So0<SPf?l0b>3H1P38h=P00?l0b>3Ho`38h=So0<SPf0H0
b>3H003o0<SPf?l0b>3Ho`38h=P60<SPf000o`38h=So0<SPf?l0b>3H1P38h=P00?l0b>3Ho`38h=So
0<SPf0H0b>3H003o0<SPf?l0b>3Ho`38h=P60<SPf000o`38h=So0<SPf?l0b>3H1P38h=P00?l0b>3H
o`38h=So0<SPf0H0b>3H003o0<SPf?l0b>3Ho`38h=P60<SPf000o`38h=So0<SPf?l0b>3H1P38h=P0
0?l0b>3Ho`38h=So0<SPf0H0b>3H003o0<SPf?l0b>3Ho`38h=P60<SPf000o`38h=So0<SPf?l0b>3H
1P38h=P00?l0b>3Ho`38h=So0<SPf0H0b>3H003o0<SPf?l0b>3Ho`38h=P60<SPf000o`38h=So0<SP
f?l0b>3H1P38h=P00001\
\>"],
  ImageRangeCache->{{{0, 770.75}, {366.438, 0}} -> {-0.0516895, -0.0238146, \
0.00272901, 0.00272901}, {{18.9375, 367.875}, {357.688, 8.6875}} -> \
{-10.4949, -6.58297, 0.385173, 0.385173}, {{402.813, 751.75}, {357.688, \
8.6875}} -> {-158.353, -6.58297, 0.385173, 0.385173}}]
}, Open  ]],

Cell["\<\
As you can see,  not that much quality was lost - especially considering that \
the above picture is enlarged on the screen! But the final filesize due to \
skipping  bits is (compare with 100%):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[25 + \((50*4/8)\) + \((25*3/8)\)]\)], "Input"],

Cell[BoxData[
    \(59.375`\)], "Output"]
}, Open  ]],

Cell["\<\
This might not seem much, but note that the remaining information is much \
more (i.e. orders of magnitude more) compressible with ordinary entropy \
coding techniques (usually preceded by run-length coding), as we also \
denoised the image! Furthermore, we can recursively filter the LL subband \
again, and repeat the procedure on LLLH, LLHL, and LLHH.

Examine the subbands after quantization. Note that the LH, HL and HH subbands \
have become extremely simple and very well compressible.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Map[Graphics[Raster[\((# + 128)\)/256], 
                AspectRatio \[Rule] 1] &, \((qdecomp)\), {2}], 
          GraphicsSpacing \[Rule] 0]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080A080808080808080808080808080808080608060A080808080808080808080808080
808080808080808080808080808080808080808080808080808080A0
808060A08080808080808080808080808080806080608080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080A060A080808080808080806080808080806080608080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080A06080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080A08080808080808080808080808080A080A0808080808080808080808080808080
808080808080808080808080808080808080808080808080808080A0
A06080808060A08080808080808080808080A080A0808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
60A08080808060A080808080808080808080A080A0808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080A080808080808080808080A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808060808080808080808080A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80A080808080808060808080808080808080A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808040808080808080608080808080808080A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080A08080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080A0608080808080808080A08080808080A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808060A08080808080A06080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080806080808080608080A08080808080A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808060808080808060A080808080A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8060A0808080808080A06080808080808080A06080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8060808080808060808080808080A0808080806080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080A06080808080808060A08080A06080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080A0808080808060808060808080608080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080A080A080A080808080A080806080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080A06080808060A0808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080A080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
A08080808080808080808080A06080808060A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808060A08080A080808060A080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080A060808080806080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080A060A08080A08080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080608080808060A08080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080A060A08080808080808060A080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080808060808060808080808060A0808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080A08080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080806080A080808080808080808080808080808080808080
8080808080808080808080A080808080808080808080808080808080
808080808080808080808080808080808060808080808080808080808080808080808080
80808080808080806080608080808080808080808080808080808080
8080808080808080808080808080A060A080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080806080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080A06080808080808080808080808080808080
80808080808080808080808080808080806080808080808080808080
80808080808080808080808080808080A060A08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808060A080808080808080808080808080808060808080808080808080808080808080
80808080808080808080A06080808080808060808080808080808080
8080A040A0808080808080808080808080A0608080808080808080808080808080808080
8080808080A080808060A06080808080808080808080808080808080
8080A0808080808080808080808080808080806080808080808080808080808080808080
8080808080808080A080808080806080808080808080808080808080
806080A08080808080808080808080808080A08080806080808080808080808080A08080
80808080808080808080808080808080808080808080808080808080
608080A080808080A080808080808080808080806080808080808080808080808060A080
80808080808080808080808080808080808080808080808080808080
A08060A0808080806080808080808080808080806080A060A08080808080808080806080
80808080808080808080808080808080808080808080808080808080
808080A080808080808080808080808080A080808060A080608080808080808080808080
8080808080808080808080808080808080A060808080808080808080
808060808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080A06080808080808080808080808080
8080608080808080A08080808080A08060A080A080808080808080808080808080808080
808080808080808080808080808080A0808080808080808080808080
8080608080608060806080808080808060A060A080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080808080608080C060A080808080608080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080A08080A0A080A0808080A0808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808060808080808080A08080A08080A060808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080A040808080A08060A08080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080A0808080608080808080808060A08080A080A060A080808080808080608080808080
80808080808080808080808080808080808080808080808080808080
608060808080808080808080808080A08080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080608080808080808080808080A0608080808080808060806080808080808080
808080808080A0608080808080808080808080808080808080808080
8080808060A08080808080808080806080808080A080808080A080A08080808080808080
8080808080A0A0608080808080808080808080808080808080808080
8080808080808080808080808080808080808060A0808080806080808080608080808080
8080808080A080608080808080808080808080808080808080808080
80808080A080808080808080808080808080808080A08080A06080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808060808080808080808080808080808080808080A080A060A0808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808060A0A080A06080808080808060808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080A0608080A0608080808080808080608080
80808080808080808080808080808080808080808080808080808080
8080808080A0808080808080808080808080808060808080608080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080A060808080808080808080808080808080
8080808080A080808080808080808080808080808080808080808080
808080808060808080808080808080808080808080808080808080808080808080808080
8060808060A080608080808080808080808080808080808080808080
80A08080808080808080808080808080808080808080A080808080808080808080808080
8080808060A080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080C0808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080804080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080C0808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080804080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080C080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080C0808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080804080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080C080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080808080C0808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080C080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808040808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080C08080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080804080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808040808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080C0808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080C08080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080408080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080804080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080808080C0808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080808080C080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080C0808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080C08080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080C08080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
C0808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080408080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080408080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080408080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80408080808080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5B80AE292E243D383434303633394D41362C2943686365586672767D7E807E7F82878988
8B8F8B8E89888B8C8D8F9191919092949093909694989BA0A9C1CEC9
5B5E9E8B282A322E3E313230353C443C2E3127436667605B706F767C7E81818182868889
8D8D8A898F898F8D909395939494979A95949294969A9A9FA8C3D2C9
5E5B6BB562252931322C322C343944373130274F69685C626D72787A7F7F838180898889
8B8B8B8D8D8D8E90959596979598989B969193989495989BA5BDD0C6
635B5E8DC1432B2C2B303332363C403D332F2C4D72685A6870727D7C7D807E8085848A8B
8C8D8B8A8C8E909699979996989A9B9A97959794929391979EB5CBC0
5663618EB6B53A35333B3735383E3B35322E2F586C6558666F767A7E7D81808283898B8C
8C8C8C9090929699999A9A9B9E9E9C9C97989895949290909CABC2B7
806267758BCA912C30333134373D3736332F2E5B755D54646E74797B7C7C7A828184878A
8C90908E909191989A9A9B9EA09C9D9D9A9B969592918B8B8E9BB1A5
AE786C6573A1D85E262A272E3542302F2E27265F715B52657173767A7B7E817F81858987
8D8F8F90919497969B999C989D9E9D9B9B9795928F8B8483858B9486
667B6A808187AFA53428242C4846392A2B302F56755A52646C73747C7E7C7F8381868889
929092949190949699969B9DA09B9D9B95959188847F7B8183848276
36478391A0AEB3B9A43627262C2A2C2C2E2E28596E5153666B73737B7A7E81828588898F
909091959593989A999B9B9E9E9C9E9893938C7B797E7F7D7D817D71
241D77A7ACBEBBBFBB6E25282726282F312E25536F4E5561656E74797C7C828184878A8C
92909497969795989C9E9E9D9E9D9E95948F847781846946475E5D59
231F47B4A8B9B1B9B1AC66342423242C2C282558614D505D6472767B7A817E81868B8A8D
8F909894979997999B9C9D9D9E9C9E9590897D7884867645445D6F76
261E269BA1A7ABAAB2B7AD6E3425232C2D2C26566244475A6672757D7F817F8285898E8B
919092989597969A9D999F9E9E9C9A938F8E72737F898787898A887D
2B291D73A49E95877987A9AA5B222529292B2657654846576571767D7C81808386888D8F
8E919497969A9D9D9D9E9F9F9D9F99928F89746E7D888D888C8D887C
222D232B757B786870A89E917C372425282B24565A404C556171747B7D808085878B8C91
919498989699999C9D9EA0A0A29F99968C8B76707A8488878A87807D
282F2F1E355181747BA2CDAA8F242327252924545A3C4B56626D757A7E82838687868A91
9595979696999B9FA1A1A3A2A29F9B95908E8277778186867F7C7A7B
2331312223227C7E7383C7CACF5C24292726214E523F4B5A6470777A7F838285878F8E90
949597979C9B9C9DA0A6A3A1A0A29E99928B857F7F7D83837C7E7979
2852521E1F1D4F8E7177A3C9C8C33B2725242448493B4957677077807C8381878A879193
9399989FA19DA0A3A6A5A6A7A5A3A49E958F89848184827D7D787A7C
3D6B79291E1D2B8F797187C2C8CAA428252521464338475A686F787D81828284898C9195
989B9CA1A29FA6A9A5ABA8A9A8A3A39C999288868385848080797B7C
5898902E22231F5A8F6E77B5C9CBCE84232723423D33495B6670767B828285858A8F9197
979D9E9FA0A5ACABA9AAADA9AAA5A4A099948985858784817E797A80
7CA86825262829348C716F91CAC5C9CF4528253C39394D5D6A727980818186898D8F9597
989C9CA4A8AAB1ACB0AFADA8AAA7A39F99958C8887868C81807D7C82
A36A302B222426276A876F7ABABCC6CDA52A27353239495F6B78797B8085838A8C909598
98999DA4A6A9B0ADB1B1AEA9ABA8A6A09C94928C898C8A85807C7D82
6F312326232424213E9374709DBFBFC0CC6E2B3333364B636F78767D8386848790909094
999DA1A5AAAFB3B0B1B4AEACB0A9A6A19D968D8F8C928B87827C8183
3F2E2C29272A292423728B727CC3B9C0BAC23F2A2C374E6071757A807F8185868B959496
9BA3A9ABAEB1B2B3BAB3AEAAACAAABA19D9B969391928C89857E8185
4E2E2B2B2D2831262844967774A3B9BCBAC9A028303645606E78787C7A80858E8F96989B
9EA4ACADAFB4B2B2B2ADB2ACB1ADABA7A19C969692938E8B85837E82
3B2D2E2E2C2E2B2E2A2F6C90737AAFB3C2C2D17A2331455C6976797D7F83878C9393999C
A3A6AAACAFB2B2AFB2B1AEB1B0B2ACA7A29B9A9193908C878483827E
412C3330302D312C2C2A3A99746CA2B3BAC1C4CA4F2D41546574767B7F81898D9297979F
A0A7ACAAAFB3AAAEB2B0B2ADAEAFAFAAA59E949393918D8684848083
382432302A2C2D2D2E2A2D7391637DB6AFBEBDC8B73E404E6370747A8181878D92999A9E
A3A7A8AAADAEACB2AEACABA6ABB0AFABA199968F8B918B8581827D7F
3130362C2E29303230312B3D94786BA9A9B9BEC0C6A139505C6C747B7E828C8C94979C9D
A5A7A1A8AEADA8A5A7A9AEADA7A7A9A8A39D95898B8E868482818282
2E2E2F2C2A2C343231312C2C678F627BAFB0B9BFC6CF87405B6972757E87878F95989D9F
A4A5A2A6ABA6A2A6A4A6ADA9ADA9A5ABA4A5948B898F8B8782818082
2E2A2E2D2B2D352F2E2F2425348E7D68A3B1B1B6BFC7CD744A616B737B8587909799979A
9EA0A09D99949698979B9EA0A4A8A6A5A0A59B8882868B867E828086
2A2F2F2F2C32312F2D2C27262159976B82B8A0B2B5BFC6C6685563727B84899193999896
96979593938E928E8D8E9097989CA0A59C9FA08A80848786827F7F85
2E2F32302C302E2F33332723212D858163A2A7A9B0B6C4C6BE66556A7880858B918D9194
948E8D92968689827F848B838B919B989692948D787F8583817F808A
292E2B2B2C312C2F35302726232147926480BEA0ADB4BFC7C3BC6466747E85898B8B8F90
8E918F8E8C7C757B668388717B6C9C95A3A09383797A818281818090
2B262B2F2F2E302C3031312426232372855EB2B7A5B0BAC3C9C1B7686A797F8284828E8F
8E8E84777E7A68786A868F8C9D8FA5B0ABAB9D8A7E7C787E7F828491
2A25283132303E333031372D2623283C91677EC7A1A7B4BBC8C6C1B568737B7E807E8F8E
8C817367586F828C9AA0ACB8BFC1B5A8938B777F827A767A82818394
2F2F2A343C2C37312A2A3228292325345D8E56A0AC9CB4B5C2C6C6C1BA757478777E8787
7D6545527076806C6587B7C5CBCFC9AD8B93757A7C73777B7E838690
38282A38662E31322B2D352B2A272A2C2C756567A594A1ACB9C3C7C5C2BD716F77807673
664A2E486877563D40446EC1CCCFC9BF9B70687D697279737F868A95
322A284B6D372B2A2B2B3728282E2626284B7F6091B99D98A8B5C3CAC5C3BC6E6B6F5F51
4331334D7160405D56583D82D1CECDC5934E6B6B637070777D858895
2E30276850362B262C2E352F2A35332B3F39718D62BCB2AEB6B8B8CAC9C8C4B4595F523C
332E314567385948294A514BC9C3C4AB66467B567276727F83898D90
2F302E75362E2E2B2C2E353C3354492C221F3898707DC1A5ADB2B4BACCC4C3C4A54F574B
3C2B2C3648303C2F234B4677C7BBA468313A484E7C7C7880878B9195
2C4F3B7728322A28292F66705E41272B242622679962ABBAA6ACB3BAC8C8C2BCC39C474A
403531303033322E2D323C629C86502D2B272F5F83847F82898C9296
43403564242925252963745A2D242A312828222C907F79BCAAACB0B6C3C8C1BCB9C19C42
463E3735353534312E2F3139503E2F2B2A2D598085817D828B8E939A
4629395A2326282F4D7444282D2D2F2E26272424519D6E8EBCA7AEB3C1C9C6BBB8B3C698
49534D43374037363432333431312C28394F84867C817C868C929B9C
2F2C3A542A272840654F272D2D2E2D2D2C233E25237C8C66ABB4A7ACBBC4C9C0B1ABB4C6
A254605E625A4B4B50412F51613643436B74657C747474808D999E9F
2E29394C2628294F683428262B2F282B2E513E20233D94767ABAAAAAB1BDC3C3AFA2A9B8
C7AD6A6C717175787B724082947175626A75656A60666D879C9DA1A4
242C3943363036555535272829292B4665592A4D1E215D9E7F83BEA5ADB3BDC5B99B9DAF
BDC3BA7B7881838F8F8779A09E8C8278615B534D4B547695A8A6A8A9
2627394A3A43374D38332E262825355C4856384334242F8390659AB9A1B1B7C0C1A696A4
B3BDC2BD8D788C929992999A94826D5A4C4641485B7F9EABAAABA9AC
252D29374A373846302F342B2F345C50344A512D48202A42957462A5AEAAB1B7C2B49A9B
A9BBBDC0C09B75828E8B8779716450424B50697C9BA8B1AEB1B3AFAC
23382B35313039332D2D372D363645322F4F5B2B532C24206393676FB2ADAAAFBBB99D9B
9EB7C0C3C1C0A15F5563636362675F6F798799A5ADB3B6B2B1B0B0AC
22313140473C3C322B272A2E352E4C2C244D61224E46432B2D78925F7FBFA7A8B1B3A49A
9CB0BEBEC2BBB9B0714F65747C89909498A2A8ACB0B1B5B2AFB0B0B2
232C2B2D4B635A4C3D2C2C2F3A28503B263B6828345924372C338D785A91B6A2ABACA9A0
A0B1BEBBBABBB2B1B19D818B969A9FA3A5A7A8ADAEB1B1B4B2B0B4B6
382834383E36674E4131262E3724414E2443593B2A5A452926244D8262659CAD9FA3A29D
A1AFBEBCB6B9AEAEB3A9A69C9BA2A4A4A3A3A7A7ADB1AEB0B1B2AEB7
4A3E2D2F262F40605A37292D392B325A22443D2F35357E2C201F2C69907872A4AB9EA0A0
A4B1BCBAB9B9A894B7B4A6A59C9BA0A49FA0A4A6ACAEADAFB2B4B4BA
27412C2D284C432B52472C31352F2A5530502E2B323B5A252320536A749B7478A4A5A1A3
AAB6BBB8BBB09384B2C0B6A69F999A9B9AA0A1A5AAABABB0B1B3B4BB
262B2B2A495C2F313953342F39312B4938372D394C32522C2326824732878D7782A9A2A8
AFB1C0B8BAA78F8CB0B8C3B6A89F9FA1999DA2A0A9ABADADB0B0B8BB
27282A2E603C48382E3B372E3837323A463525435A524549355A872A214390897385B2AA
A9B6BBB8B0AC9297A4AEC2C3AFA4A4A3A2949C9DA3A6ABACADB5B8BE
2E262C3263282C373D32422C323A322F3E342F4950575D5D4B6D8C351F21519684768FBB
A7B4B6B1AFAF8EA0A4B0BFC5BDA7AAA8A2A195999FA1A9A9AAB4BABF
302A2D40672A2D304A36373232363A2A383D36325C6E733B2D675A1F2223265C9F847798
B6A9B4A9A5A68AA6ADAEB7C0BBACAAA8ABA7A597959EA6A8ABB2B9BE
52462D3B68332C2B354337372C2F37303F3E344263435A2D3486412B26232424679D796E
9DB2A9A5A5A386A5ACA1BABEB8B0A8A8AAA9ABAC9D95A2A6ABAEB5BB
4844343663402A2A2C392E3B2F33334B483F3D44572F453256892F27272222202773A371
749FBAA4A59F8299A8A7B0BEADB6A9A9A7A3A4ACB59E97A3AAAEB4B7
6F4929305350292B2C322D312F3548503C4947325F303A31598538454830262321307D9A
736B9DB0A1977BA3B9AEB3C0BBB9ACA7A3A09FA7B1B9AB9AA4A8ADB4
6E3B293337523A302D2D2F322E49563F48573C2A5B2B2E3A71845E5A4B2B262423263481
8F5D6795B28888ACBAB0B8BCC0BFB6AAA59FA1A5ACB2B5ACA2A5ADB2
6C40363A2A4F4B322D2E2F30355C484251592C36502B316C7D642C2C2C312B2B2524263A
7571615B9588A09AB8B3B5B7BBBCB6B1A5A0A0A4A6ACB6AEA49CA2AE
6D57615A44475742352F2C313D514647554E33364E2751726F3B2C3132302E2C3129272A
3E6A754F6367A38CB8B1B2B5B5BBBBB6ADA6A2A8ABAFB3B1AF9FA9A9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
808060808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080608080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
806080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080608080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080806080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080806060608080
808080808080808080608080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080A0A080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080A0A0A080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808060808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808060808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080A0A0A08080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808060808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080806080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080A080808080808080808080808080808080808080
808080808080808080A080A080808080808080808080808080808080
808080808080808080808080806080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080A0
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808060
A0808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080A0808080808080808080808080808080808080
60808080808080808080808060808080808080808080808080808080
808080808080808080808080808080808060808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808060608060608080808080808080A06080808080808080808080808080808080808080
80808080A08080808080808080808080808080808080808080808080
80808080808080808080808080808080A080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080806080808080808080808080808080808080808080808080
808080808060A0808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080A080808080808080808080808080808080808080
808080806080808080808080808080808080808080A08080808080808080808080808080
80808080808080806080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080A06080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080606080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
606080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
806080808080808080808080808080808080808080808080808080806080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080A0A080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080806080808080808080808080808080808080808080808080808080808080808080
80A0806080A080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{390, 390},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660001QR000`400?l00000o`00003oo`38h=R7
0<SPf000o`38h=R70<SPf000o`38h=R70<SPf000o`38h=R70<SPf000o`38h=R70<SPf000o`38h=R7
0<SPf000o`38h=R70<SPf000o`38h=R70<SPf000o`38h=R70<SPf000o`38h=R70<SPf000o`38h=R7
0<SPf000o`38h=R70<SPf000o`38h=R70<SPf000o`38h=R70<SPf000o`38h=R70<SPf0003@38h=P6
0820P080X:2P;@20P802061PH0<0P8200`1PH6030:2PX6h0P8200`2PX:080<SPf0H0P8200P30`<2Y
0820P0l0b>3H000=0<SPf0H0P8200P2PX:0]0820P080H61P0`20P803061PH0<0X:2PKP20P8030:2P
X0P0b>3H1P20P8020<30`:T0P8203`38h=P000d0b>3H1P20P8020:2PX2d0P8200P1PH6030820P0<0
H61P0`2PX:1^0820P0<0X:2P2038h=P60820P080`<30Z@20P80?0<SPf0003@38h=P60820P080H61P
0`2PX:0Z0820P080H61P0`20P803061PH7@0P8202038h=Ra0820P0l0b>3H000=0<SPf0H0P8200P1P
H6030:2PX2X0P8200P1PH6030820P0<0H61PM020P8080<SPf;40P8203`38h=P000d0b>3H1P20P802
061PH0<0X:2P:P20P802061PH0<0P8200`1PH61d0820P0P0b>3H/@20P80?0<SPf0003@38h=P60820
P080X:2P0`1PH6030:2PX1H0P8200`1PH60>0820P080H61P0`20P803061PH7@0P8202038h=P;0820
P0<0@410X`20P80?0<SPf0003@38h=P60820P080X:2P0`1PH6030:2PX1H0P8200`1PH60>0820P080
H61P0`20P803061PH7@0P8202038h=P;0820P0<0@410X`20P80?0<SPf0003@38h=Pb0820P0<0X:2P
0P1PH61j0820P0P0b>3H/@20P80?0<SPf0003@38h=Pb0820P0<0X:2P0P1PH61j0820P0P0b>3H/@20
P80?0<SPf0003@38h=Pb0820P0<0X:2P0P1PH61j0820P0P0b>3H/@20P80?0<SPf0003@38h=P80820
P0<0X:2P9`20P8030:2PX080P8200`2PX:1d0820P0<0X:2P2038h=P>0820P0<0`<30X020P80?0<SP
f0003@38h=P80820P0<0X:2P9`20P8030:2PX080P8200`2PX:1d0820P0<0X:2P2038h=P>0820P0<0
`<30X020P80?0<SPf0003@38h=P80820P0<0X:2P9`20P8030:2PX080P8200`2PX:1d0820P0<0X:2P
2038h=P>0820P0<0`<30X020P80?0<SPf0003@38h=P30:2PX0<0H61P2020P803061PH080X:2P7`20
P8030:2PX080P8200`2PX:1g0820P0P0b>3H/@20P80?0<SPf0003@38h=P30:2PX0<0H61P2020P803
061PH080X:2P7`20P8030:2PX080P8200`2PX:1g0820P0P0b>3H/@20P80?0<SPf0003@38h=P30:2P
X0<0H61P2020P803061PH080X:2P7`20P8030:2PX080P8200`2PX:1g0820P0P0b>3H/@20P80?0<SP
f0003@38h=P3061PH0<0X:2P2`20P802061PH0<0X:2P7020P8030:2PX080P8200`2PX:1g0820P0P0
b>3H4`20P8030410@9/0P8203`38h=P000d0b>3H0`1PH6030:2PX0/0P8200P1PH6030:2PX1`0P820
0`2PX:020820P0<0X:2PM`20P8080<SPf1<0P8200`10@42K0820P0l0b>3H000=0<SPf1<0P8200`2P
X:0L0820P0<0X:2PO020P8080<SPf1<0P8200`30`<2K0820P0l0b>3H000=0<SPf1<0P8200`2PX:0L
0820P0<0X:2PO020P8080<SPf1<0P8200`30`<2K0820P0l0b>3H000=0<SPf1<0P8200`2PX:0L0820
P0<0X:2PO020P8080<SPf1<0P8200`30`<2K0820P0l0b>3H000=0<SPf1H0P8200`1PH60I0820P0<0
X:2PO020P8080<SPf;40P8203`38h=P000d0b>3H5P20P803061PH1T0P8200`2PX:1l0820P0P0b>3H
/@20P80?0<SPf0003@38h=PF0820P0<0H61P6@20P8030:2PX7`0P8202038h=Ra0820P0l0b>3H000=
0<SPf0<0P8200`2PX:0@0820P0<0H61P6@20P8030:2PX7`0P8202038h=Ra0820P0l0b>3H000=0<SP
f0<0P8200`2PX:0@0820P0<0H61P6@20P8030:2PX7`0P8202038h=Ra0820P0l0b>3H000=0<SPf0<0
P8200`2PX:0@0820P0<0H61P6@20P8030:2PX7`0P8202038h=Ra0820P0l0b>3H000=0<SPf0H0P820
0P10@40A0820P0<0H61P5P20P8030:2PX7`0P8202038h=Ra0820P0l0b>3H000=0<SPf0H0P8200P10
@40A0820P0<0H61P5P20P8030:2PX7`0P8202038h=Ra0820P0l0b>3H000=0<SPf0P0P8200`2PX:2V
0820P0P0b>3H/@20P80?0<SPf0003@38h=P80820P0<0X:2PYP20P8080<SPf;40P8203`38h=P000d0
b>3H2020P8030:2PX:H0P8202038h=Ra0820P0l0b>3H000=0<SPf0H0P8200P2PX:03061PH1H0P820
0`2PX:0>0820P0<0X:2PO020P8080<SPf2l0P8200`30`<1o0820P0l0b>3H000=0<SPf0H0P8200P2P
X:03061PH1H0P8200`2PX:0>0820P0<0X:2PO020P8080<SPf2l0P8200`30`<1o0820P0l0b>3H000=
0<SPf0H0P8200P2PX:03061PH1H0P8200`2PX:0>0820P0<0X:2PO020P8080<SPf2l0P8200`30`<1o
0820P0l0b>3H000=0<SPf1h0P8200`1PH6030:2PX0h0P8200`2PX:02061PH7X0P8202038h=Ra0820
P0l0b>3H000=0<SPf1h0P8200`1PH6030:2PX0h0P8200`2PX:02061PH7X0P8202038h=Ra0820P0l0
b>3H000=0<SPf1h0P8200`1PH6030:2PX0h0P8200`2PX:02061PH7X0P8202038h=Ra0820P0l0b>3H
000=0<SPf0/0P8200`1PH60;0820P0<0H61P1@20P8030:2PX0h0P8200`2PX:1l0820P0P0b>3H/@20
P80?0<SPf0003@38h=P;0820P0<0H61P2`20P803061PH0D0P8200`2PX:0>0820P0<0X:2PO020P808
0<SPf;40P8203`38h=P000d0b>3H4@20P802061PH0h0P8200`1PH6030:2PX0/0P8200`2PX:1l0820
P0P0b>3H9020P8030410@8X0P8203`38h=P000d0b>3H4@20P802061PH0h0P8200`1PH6030:2PX0/0
P8200`2PX:1l0820P0P0b>3H9020P8030410@8X0P8203`38h=P000d0b>3H4@20P802061PH0h0P820
0`1PH6030:2PX0/0P8200`2PX:1l0820P0P0b>3H9020P8030410@8X0P8203`38h=P000d0b>3H0`20
P803061PH080X:2P4@20P8030:2PX080H61P5020P8030:2PX080H61PNP20P8080<SPf2@0P8200`30
`<2:0820P0l0b>3H000=0<SPf0<0P8200`1PH6020:2PX140P8200`2PX:02061PH1@0P8200`2PX:02
061PH7X0P8202038h=PT0820P0<0`<30RP20P80?0<SPf0003@38h=P30820P0<0H61P0P2PX:0A0820
P0<0X:2P0P1PH60D0820P0<0X:2P0P1PH61j0820P0P0b>3H9020P8030<30`8X0P8203`38h=P000d0
b>3H0`20P803061PH0d0P8200`1PH60A0820P080X:2P3020P802061PH7X0P8202038h=PW0820P080
`<30R020P80?0<SPf0003@38h=P30820P0<0H61P3@20P803061PH140P8200P2PX:0<0820P080H61P
NP20P8080<SPf2L0P8200P30`<280820P0l0b>3H000=0<SPf0<0P8200`1PH60=0820P0<0H61P4@20
P8020:2PX0`0P8200P1PH61j0820P0P0b>3H9`20P8020<30`8P0P8203`38h=P000d0b>3H4@20P802
0:2PX0<0H61P4@20P802061PH0<0X:2P1P20P8030:2PX080H61PNP20P8080<SPf;40P8203`38h=P0
00d0b>3H4@20P8020:2PX0<0H61P4@20P802061PH0<0X:2P1P20P8030:2PX080H61PNP20P8080<SP
f;40P8203`38h=P000d0b>3H4@20P8020:2PX0<0H61P4@20P802061PH0<0X:2P1P20P8030:2PX080
H61PNP20P8080<SPf;40P8203`38h=P000d0b>3H1P20P8020:2PX0h0P8200`1PH6050820P0<0H61P
2020P803061PH8D0P8202038h=Ra0820P0l0b>3H000=0<SPf0H0P8200P2PX:0>0820P0<0H61P1@20
P803061PH0P0P8200`1PH6250820P0P0b>3H/@20P80?0<SPf0003@38h=PC0820P0<0X:2P0`20P803
0:2PX080P8200`2PX:0;0820P0<0X:2P1P20P802061PH7X0P8202038h=P/0820P0<0`<30PP20P80?
0<SPf0003@38h=PC0820P0<0X:2P0`20P8030:2PX080P8200`2PX:0;0820P0<0X:2P1P20P802061P
H7X0P8202038h=P/0820P0<0`<30PP20P80?0<SPf0003@38h=PC0820P0<0X:2P0`20P8030:2PX080
P8200`2PX:0;0820P0<0X:2P1P20P802061PH7X0P8202038h=P/0820P0<0`<30PP20P80?0<SPf000
3@38h=PN0820P0<0X:2P0`1PH6080820P0<0H61P0`2PX:1o0820P0P0b>3H;`20P8030410@7l0P820
3`38h=P000d0b>3H7P20P8030:2PX0<0H61P2020P803061PH0<0X:2PO`20P8080<SPf2l0P8200`10
@41o0820P0l0b>3H000=0<SPf1h0P8200`2PX:03061PH0P0P8200`1PH6030:2PX7l0P8202038h=P_
0820P0<0@410O`20P80?0<SPf0003@38h=PL0820P080X:2PT`20P8080<SPf;40P8203`38h=P000d0
b>3H7020P8020:2PX9<0P8202038h=Ra0820P0l0b>3H000=0<SPf1`0P8200P2PX:2C0820P0P0b>3H
/@20P80?0<SPf0003@38h=P30:2PX1h0P8200`2PX:03061PH0P0P8200`1PH6030:2PX7`0P8202038
h=Pb0820P0<0`<30O020P80?0<SPf0003@38h=P30:2PX1h0P8200`2PX:03061PH0P0P8200`1PH603
0:2PX7`0P8202038h=Pb0820P0<0`<30O020P80?0<SPf0003@38h=PL0820P080H61P0`2PX:060820
P080X:2P2@20P803061PH080X:2PNP20P8080<SPf3D0P8200P10@41j0820P0l0b>3H000=0<SPf1`0
P8200P1PH6030:2PX0H0P8200P2PX:090820P0<0H61P0P2PX:1j0820P0P0b>3H=@20P8020410@7X0
P8203`38h=P000d0b>3H7020P802061PH0<0X:2P1P20P8020:2PX0T0P8200`1PH6020:2PX7X0P820
2038h=Pe0820P080@410NP20P80?0<SPf0003@38h=PT0820P0<0X:2P0P1PH60<0820P080H61PNP20
P8080<SPf3L0P8200`10@41g0820P0l0b>3H000=0<SPf2@0P8200`2PX:02061PH0`0P8200P1PH61j
0820P0P0b>3H=`20P8030410@7L0P8203`38h=P000d0b>3H9020P8030:2PX080H61P3020P802061P
H7X0P8202038h=Pg0820P0<0@410M`20P80?0<SPf0003@38h=PL0820P080X:2P0`1PH6030:2PX0D0
P8200`2PX:250820P0P0b>3H=`20P8030<30`7L0P8203`38h=P000d0b>3H7020P8020:2PX0<0H61P
0`2PX:050820P0<0X:2PQ@20P8080<SPf3L0P8200`30`<1g0820P0l0b>3H000=0<SPf1`0P8200P2P
X:03061PH0<0X:2P1@20P8030:2PX8D0P8202038h=Pg0820P0<0`<30M`20P80?0<SPf0003@38h=PY
0820P0<0H61P2`20P803061PH0<0X:2PM020P8080<SPf3X0P8200`30`<1d0820P0l0b>3H000=0<SP
f2T0P8200`1PH60;0820P0<0H61P0`2PX:1d0820P0P0b>3H>P20P8030<30`7@0P8203`38h=P000d0
b>3H7P20P8030:2PX0<0H61P0`2PX:0C0820P0<0H61P0`2PX:1a0820P0P0b>3H/@20P80?0<SPf000
3@38h=PN0820P0<0X:2P0`1PH6030:2PX1<0P8200`1PH6030:2PX740P8202038h=Ra0820P0l0b>3H
000=0<SPf1h0P8200`2PX:03061PH0<0X:2P4`20P803061PH0<0X:2PL@20P8080<SPf;40P8203`38
h=P000d0b>3H9020P803061PH0D0P8200`1PH60>0820P0<0H61P0P2PX:1_0820P0P0b>3H/@20P80?
0<SPf0003@38h=PT0820P0<0H61P1@20P803061PH0h0P8200`1PH6020:2PX6l0P8202038h=Ra0820
P0l0b>3H000=0<SPf2@0P8200`1PH6050820P0<0H61P3P20P803061PH080X:2PK`20P8080<SPf;40
P8203`38h=P000d0b>3H8@20P8030:2PX8d0P8202038h=Q20820P0<0@410K020P80?0<SPf0003@38
h=PQ0820P0<0X:2PS@20P8080<SPf480P8200`10@41/0820P0l0b>3H000=0<SPf240P8200`2PX:2=
0820P0P0b>3H@P20P8030410@6`0P8203`38h=P000d0b>3H9`20P802061PH0<0P8200`2PX:1C0820
P0<0X:2P;020P8080<SPf4D0P8200`10@41Y0820P0l0b>3H000=0<SPf2L0P8200P1PH6030820P0<0
X:2PD`20P8030:2PX2`0P8202038h=Q50820P0<0@410J@20P80?0<SPf0003@38h=PW0820P080H61P
0`20P8030:2PX5<0P8200`2PX:0/0820P0P0b>3HA@20P8030410@6T0P8203`38h=P000d0b>3H;`20
P803061PH4P0P8200P1PH6030820P0<0H61P;`20P8080<SPf;40P8203`38h=P000d0b>3H;`20P803
061PH4P0P8200P1PH6030820P0<0H61P;`20P8080<SPf;40P8203`38h=P000d0b>3H9`20P8020:2P
X0<0H61P0`2PX:220820P0P0b>3H/@20P80?0<SPf0003@38h=PW0820P080X:2P0`1PH6030:2PX880
P8202038h=Ra0820P0l0b>3H000=0<SPf2L0P8200P2PX:03061PH0<0X:2PPP20P8080<SPf;40P820
3`38h=P000d0b>3H;020P803061PH880P8202038h=PW0820P080`<30R020P80?0<SPf0003@38h=P/
0820P0<0H61PPP20P8080<SPf2L0P8200P30`<280820P0l0b>3H000=0<SPf2`0P8200`1PH6220820
P0P0b>3H9`20P8020<30`8P0P8203`38h=P000d0b>3H<P20P8030:2PX080H61PG020P802061PH1`0
P8202038h=Ra0820P0l0b>3H000=0<SPf380P8200`2PX:02061PH5`0P8200P1PH60L0820P0P0b>3H
/@20P80?0<SPf0003@38h=Pb0820P0<0X:2P0P1PH61L0820P080H61P7020P8080<SPf;40P8203`38
h=P000d0b>3H;020P8030:2PX0<0H61P0`2PX:1l0820P0P0b>3H/@20P80?0<SPf0003@38h=P/0820
P0<0X:2P0`1PH6030:2PX7`0P8202038h=Ra0820P0l0b>3H000=0<SPf0P0P8200`1PH6030:2PX2T0
P8200`1PH6150820P0<0X:2P0`1PH60@0820P0<0H61P6@20P8080<SPf;40P8203`38h=P000d0b>3H
2020P803061PH0<0X:2P:@20P803061PH4D0P8200`2PX:03061PH100P8200`1PH60I0820P0P0b>3H
/@20P80?0<SPf0003@38h=P80820P0<0H61P0`2PX:0Y0820P0<0H61PA@20P8030:2PX0<0H61P4020
P803061PH1T0P8202038h=Ra0820P0l0b>3H000=0<SPf0H0P8200P2PX:030410@0<0X:2P8@20P803
0:2PX0<0H61P?020P8030:2PX0P0P8200`1PH6030:2PX0<0H61P;020P8080<SPf5H0P8200P30`<1I
0820P0l0b>3H000=0<SPf0H0P8200P2PX:030410@0<0X:2P8@20P8030:2PX0<0H61P?020P8030:2P
X0P0P8200`1PH6030:2PX0<0H61P;020P8080<SPf5H0P8200P30`<1I0820P0l0b>3H000=0<SPf0H0
P8200P2PX:030410@0<0X:2P8@20P8030:2PX0<0H61P?020P8030:2PX0P0P8200`1PH6030:2PX0<0
H61P;020P8080<SPf5H0P8200P30`<1I0820P0l0b>3H000=0<SPf0H0P8200P2PX:0]0820P080H61P
@`20P8020:2PX0h0P8200`1PH60T0820P0P0b>3HF020P8030<30`5H0P8203`38h=P000d0b>3H1P20
P8020:2PX2d0P8200P1PH6130820P080X:2P3P20P803061PH2@0P8202038h=QH0820P0<0`<30EP20
P80?0<SPf0003@38h=P60820P080X:2P;@20P802061PH4<0P8200P2PX:0>0820P0<0H61P9020P808
0<SPf5P0P8200`30`<1F0820P0l0b>3H000=0<SPf0<0P8200`1PH6020820P0<0X:2P9`20P8030:2P
X0P0P8200`1PH60K0820P0<0X:2PD`20P8080<SPf5/0P8200`30`<1C0820P0l0b>3H000=0<SPf0<0
P8200`1PH6020820P0<0X:2P9`20P8030:2PX0P0P8200`1PH60K0820P0<0X:2PD`20P8080<SPf5/0
P8200`30`<1C0820P0l0b>3H000=0<SPf0<0H61P1@20P8030:2PX0/0P8200`2PX:0N0820P0<0H61P
8@20P803061PH0<0X:2PD020P8080<SPf;40P8203`38h=P000d0b>3H0`1PH6050820P0<0X:2P2`20
P8030:2PX1h0P8200`1PH60Q0820P0<0H61P0`2PX:1@0820P0P0b>3H/@20P80?0<SPf0003@38h=P3
061PH0D0P8200`2PX:0;0820P0<0X:2P7P20P803061PH240P8200`1PH6030:2PX500P8202038h=Ra
0820P0l0b>3H000=0<SPf0<0X:2P0`20P802061PH0<0X:2P2`20P803061PH1h0P8200`1PH6030820
P0<0X:2P0P1PH6030:2PX1T0P8200`1PH61@0820P0P0b>3HT020P8030<30`1h0P8203`38h=P000d0
b>3H0`2PX:030820P080H61P0`2PX:0;0820P0<0H61P7P20P803061PH0<0P8200`2PX:02061PH0<0
X:2P6@20P803061PH500P8202038h=R@0820P0<0`<307P20P80?0<SPf0003@38h=P30:2PX0<0P820
0P1PH6030:2PX0/0P8200`1PH60N0820P0<0H61P0`20P8030:2PX080H61P0`2PX:0I0820P0<0H61P
D020P8080<SPf900P8200`30`<0N0820P0l0b>3H000=0<SPf0P0P8200`2PX:0T0820P0<0X:2P2020
P803061PH0<0X:2P0P20P803061PH4h0P8200P2PX:03061PH1T0P8202038h=QT0820P080`<30B`20
P80?0<SPf0003@38h=P80820P0<0X:2P9020P8030:2PX0P0P8200`1PH6030:2PX080P8200`1PH61>
0820P080X:2P0`1PH60I0820P0P0b>3HI020P8020<30`4/0P8203`38h=P000d0b>3H2020P8030:2P
X2@0P8200`2PX:080820P0<0H61P0`2PX:020820P0<0H61PCP20P8020:2PX0<0H61P6@20P8080<SP
f6@0P8200P30`<1;0820P0l0b>3H000=0<SPf0H0P8200P1PH6200820P080X:2P0`1PH60T0820P0P0
b>3H/@20P80?0<SPf0003@38h=P60820P080H61PP020P8020:2PX0<0H61P9020P8080<SPf;40P820
3`38h=P000d0b>3H1P20P802061PH0h0P8200`2PX:0>0820P080X:2P0`20P803061PH0<0X:2P0`20
P8020:2PX5H0P8200`2PX:0Q0820P0P0b>3H/@20P80?0<SPf0003@38h=P60820P080H61P3P20P803
0:2PX0h0P8200P2PX:030820P0<0H61P0`2PX:030820P080X:2PEP20P8030:2PX240P8202038h=Ra
0820P0l0b>3H000=0<SPf0H0P8200P1PH60>0820P0<0X:2P3P20P8020:2PX0<0P8200`1PH6030:2P
X0<0P8200P2PX:1F0820P0<0X:2P8@20P8080<SPf;40P8203`38h=P000d0b>3H1P20P802061PH0H0
P8200`1PH6020820P0<0H61P0`20P803061PH100P8200`1PH6030:2PX0<0H61P0P2PX:1j0820P0P0
b>3H:@20P8030410@8D0P8203`38h=P000d0b>3H1P20P802061PH0H0P8200`1PH6020820P0<0H61P
0`20P803061PH100P8200`1PH6030:2PX0<0H61P0P2PX:1j0820P0P0b>3H:@20P8030410@8D0P820
3`38h=P000d0b>3H1P20P802061PH0H0P8200`1PH6020820P0<0H61P0`20P803061PH100P8200`1P
H6030:2PX0<0H61P0P2PX:1j0820P0P0b>3H:@20P8030410@8D0P8203`38h=P000d0b>3H9`20P802
061PH0H0P8200`30`<03061PH080X:2P2`20P803061PH6`0P8202038h=Ra0820P0l0b>3H000=0<SP
f2L0P8200P1PH6060820P0<0`<300`1PH6020:2PX0/0P8200`1PH61/0820P0P0b>3H/@20P80?0<SP
f0003@38h=PW0820P080H61P1P20P8030<30`0<0H61P0P2PX:0;0820P0<0H61PK020P8080<SPf;40
P8203`38h=P000d0b>3H9020P8030:2PX0D0P8201P2PX:030820P080X:2P2@20P8020:2PX6l0P820
2038h=Qg0820P0<0@410=`20P80?0<SPf0003@38h=PT0820P0<0X:2P1@20P8060:2PX0<0P8200P2P
X:090820P080X:2PK`20P8080<SPf7L0P8200`10@40g0820P0l0b>3H000=0<SPf2@0P8200`2PX:05
0820P0H0X:2P0`20P8020:2PX0T0P8200P2PX:1_0820P0P0b>3HM`20P8030410@3L0P8203`38h=P0
00d0b>3H4@20P802061PH140P8200`2PX:050820P0<0X:2P1P20P8020:2PX0<0H61PM`20P8080<SP
f;40P8203`38h=P000d0b>3H4@20P802061PH140P8200`2PX:050820P0<0X:2P1P20P8020:2PX0<0
H61PM`20P8080<SPf;40P8203`38h=P000d0b>3H9020P8030:2PX080@4102@20P8030:2PX080P820
0`1PH6030:2PX7@0P8202038h=Pj0820P0<0@410M020P80?0<SPf0003@38h=PT0820P0<0X:2P0P10
@4090820P0<0X:2P0P20P803061PH0<0X:2PM020P8080<SPf3X0P8200`10@41d0820P0l0b>3H000=
0<SPf2@0P8200`2PX:020410@0T0P8200`2PX:020820P0<0H61P0`2PX:1d0820P0P0b>3H>P20P803
0410@7@0P8203`38h=P000d0b>3H1P20P8020:2PX0T0P8200P1PH60D0820P080H61P0`2PX:060820
P0<0X:2P0P20P8030:2PX0<0H61P0`2PX:0C0820P0<0H61PF`20P8080<SPf;40P8203`38h=P000d0
b>3H1P20P8020:2PX0T0P8200P1PH60D0820P080H61P0`2PX:060820P0<0X:2P0P20P8030:2PX0<0
H61P0`2PX:0C0820P0<0H61PF`20P8080<SPf;40P8203`38h=P000d0b>3H1P20P8020:2PX0T0P820
0P1PH60D0820P080H61P0`2PX:060820P0<0X:2P0P20P8030:2PX0<0H61P0`2PX:0C0820P0<0H61P
F`20P8080<SPf;40P8203`38h=P000d0b>3H0`1PH6030820P080H61P8@20P8030:2PX8D0P8202038
h=Ra0820P0l0b>3H000=0<SPf0<0H61P0`20P802061PH240P8200`2PX:250820P0P0b>3H/@20P80?
0<SPf0003@38h=P3061PH0<0P8200P1PH60Q0820P0<0X:2PQ@20P8080<SPf;40P8203`38h=P000d0
b>3H3P20P803061PH1h0P8200`2PX:03061PH1<0P8200`1PH6020820P0<0H61P9020P8030:2PX0<0
H61P=`20P8080<SPf;40P8203`38h=P000d0b>3H3P20P803061PH1h0P8200`2PX:03061PH1<0P820
0`1PH6020820P0<0H61P9020P8030:2PX0<0H61P=`20P8080<SPf;40P8203`38h=P000d0b>3H2`20
P803061PH0<0X:2P6020P803061PH0/0P8200`2PX:0;0820P0<0X:2P0`20P8020:2PX2@0P8201P2P
X:03061PH3L0P8202038h=Ra0820P0l0b>3H000=0<SPf0/0P8200`1PH6030:2PX1P0P8200`1PH60;
0820P0<0X:2P2`20P8030:2PX0<0P8200P2PX:0T0820P0H0X:2P0`1PH60g0820P0P0b>3H/@20P80?
0<SPf0003@38h=P;0820P0<0H61P0`2PX:0H0820P0<0H61P2`20P8030:2PX0/0P8200`2PX:030820
P080X:2P9020P8060:2PX0<0H61P=`20P8080<SPf;40P8203`38h=P000d0b>3H=@20P802061PH0<0
X:2P2`20P803061PH0/0P8200`1PH60K0820P0<0X:2P0`20P803061PH3L0P8202038h=Ra0820P0l0
b>3H000=0<SPf3D0P8200P1PH6030:2PX0/0P8200`1PH60;0820P0<0H61P6`20P8030:2PX0<0P820
0`1PH60g0820P0P0b>3H/@20P80?0<SPf0003@38h=Pe0820P080H61P0`2PX:0;0820P0<0H61P2`20
P803061PH1/0P8200`2PX:030820P0<0H61P=`20P8080<SPf;40P8203`38h=P000d0b>3H2`20P803
0:2PX2`0P8200`2PX:050820P0<0X:2P0`1PH61Y0820P0P0b>3H/@20P80?0<SPf0003@38h=P;0820
P0<0X:2P;020P8030:2PX0D0P8200`2PX:03061PH6T0P8202038h=Ra0820P0l0b>3H000=0<SPf0/0
P8200`2PX:0/0820P0<0X:2P1@20P8030:2PX0<0H61PJ@20P8080<SPf;40P8203`38h=P000d0b>3H
2020P803061PH380P8200`2PX:020820P0<0X:2P0`1PH6030:2PX6H0P8202038h=Ra0820P0l0b>3H
000=0<SPf0P0P8200`1PH60b0820P0<0X:2P0P20P8030:2PX0<0H61P0`2PX:1V0820P0P0b>3H/@20
P80?0<SPf0003@38h=Pg0820P0<0H61P1P2PX:020820P0<0X:2P0`1PH60@0820P0<0H61PEP20P808
0<SPf;40P8203`38h=P000d0b>3H=`20P803061PH0H0X:2P0P20P8030:2PX0<0H61P4020P803061P
H5H0P8202038h=Ra0820P0l0b>3H000=0<SPf3L0P8200`1PH6060:2PX080P8200`2PX:03061PH100
P8200`1PH61F0820P0P0b>3H/@20P80?0<SPf0003@38h=Pe0820P080X:2P0`1PH6060820P080X:2P
0`1PH60F0820P0<0H61PD`20P8080<SPf;40P8203`38h=P000d0b>3H=@20P8020:2PX0<0H61P1P20
P8020:2PX0<0H61P5P20P803061PH5<0P8202038h=Ra0820P0l0b>3H000=0<SPf3D0P8200P2PX:03
061PH0H0P8200P2PX:03061PH1H0P8200`1PH61C0820P0P0b>3H/@20P80?0<SPf0003@38h=P>0820
P0<0X:2P9P20P803061PH0P0P8200`1PH61/0820P0P0b>3H/@20P80?0<SPf0003@38h=P>0820P0<0
X:2P9P20P803061PH0P0P8200`1PH61/0820P0P0b>3H/@20P80?0<SPf0003@38h=P>0820P0<0X:2P
9P20P803061PH0P0P8200`1PH61/0820P0P0b>3H/@20P80?0<SPf0003@38h=Pe0820P080X:2P0`1P
H60g0820P0<0X:2P?@20P8080<SPf;40P8203`38h=P000d0b>3H=@20P8020:2PX0<0H61P=`20P803
0:2PX3d0P8202038h=Ra0820P0l0b>3H000=0<SPf0h0P8200`1PH61E0820P0<0H61P1P20P802061P
H0<0X:2P0`20P803061PH3L0P8202038h=Ra0820P0l0b>3H000=0<SPf0h0P8200`1PH61E0820P0<0
H61P1P20P802061PH0<0X:2P0`20P803061PH3L0P8202038h=Ra0820P0l0b>3H000=0<SPf0h0P820
0`1PH61E0820P0<0H61P1P20P802061PH0<0X:2P0`20P803061PH3L0P8202038h=Ra0820P0l0b>3H
000=0<SPf0<0P8200`2PX:0g0820P0<0X:2P;`20P802061PH0<0X:2P?@20P8080<SPf6H0P8200`10
@4180820P0l0b>3H000=0<SPf0<0P8200`2PX:0g0820P0<0X:2P;`20P802061PH0<0X:2P?@20P808
0<SPf6H0P8200`10@4180820P0l0b>3H000=0<SPf0<0P8200`2PX:0g0820P0<0X:2P;`20P802061P
H0<0X:2P?@20P8080<SPf6H0P8200`10@4180820P0l0b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H
003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H
003o0<SPf8L0b>3H000=0<SPf0<0Fe]K0`20P8020:j^[P<0:BTY0`0^;Rh302@T9080?Cdm0`0h>3P6
03@d=080<30`0`0f=SH303<c<`<0>CTi0P1=CDd30451@@<0=SHf0`0/;2`302TY:@80@d=30`1XJ6P3
06=SH`<0IFEU0P1HF5P306IVIP<0LW9b0`1fMWH207emO@<0OWin0`20P80307inOP80Ogmo0`22PX83
08N7Q`<0RHV90`28R8P208^;R`<0Shn?0`2;Rh/308j>SP80RHV90`28R8P308^;R`<0S8b<0P2=SHd3
08n?S`T0TI6A0P2@T90309:BTP<0U9BD0`2@T90209>CT`<0T92@0`2FUYH309BDU080V9RH0`2KVi/3
0:2PX0<0ZJVY0P31`L430<k>cP<0bLW92038h=P60820P080H61PZ@20P80?0<SPf0003@38h=P305]K
F`<0P8200P2^[Zh302TY:@<0;Rh^0`0T92@203dm?@<0>3Ph1P0d=3@2030`<0<0=SHf0`0c<c<303Ti
>@80CDe=0`11@D4303Hf=P<0;2`/0`0Y:BT204=3@`<0J6QX0`1SHf<306EUI@80F5QH0`1VIVH3079b
LP<0MWIf0P1mOGd307inOP<0P8200`1nOWh207moO`<0PX:20`27QhL308V9R@<0R8R80P2;Rh/308n?
S`<0Rh^;0`2>SXh208V9R@<0R8R80`2;Rh/308b<S080SHf=0`2?Shl9096AT@80T92@0`2BTY8309BD
U0<0T92@0P2CTi<3092@T0<0UYJF0`2DU9@209RHV0<0Vi^K0`2PX:030:VYZ@80`L710`3>c/h30<W9
b@P0b>3H1P20P802061PH:T0P8203`38h=P000d0b>3H0`1KFe/30820P080[Zj^0`0Y:BT302h^;P<0
92@T0P0m?Cd303Ph>0H0=3@d0P0`<30303Hf=P<0<c<c0`0i>CT204e=C@<0@D510`0f=SH302`/;0<0
:BTY0P13@d<306QXJ0<0Hf=S0`1UIFD205QHF0<0IVIV0`1bLW8307IfMP80OGem0`1nOWh30820P0<0
OWin0P1oOgl308:2PP<0QhN70`29RHT308R8R080Rh^;0`2?Shl308^;R`<0SXj>0P29RHT308R8R0<0
Rh^;0`2<S8`208f=S@<0Shn?2@2ATI42092@T0<0TY:B0`2DU9@3092@T080Ti>C0`2@T90309JFUP<0
U9BD0P2HV9P309^KV`<0X:2P0`2YZJT20<71`@<0c/k>0`39bLT80<SPf0H0P8200P1PH62Y0820P0l0
b>3H000=0<SPf0<0Fe]K0`1NGUh209jNWP<0Rh^;0`0X:2P302XZ:P80<S8b0`0^;Rh303hn?P<0<C4a
0P0b<S83030`<0<0=CDe0`0l?3`204A4A0<0?3`l0`0^;Rh3034a<@<09bLW0P13@d<306IVIP<0IfMW
0`1PH60205]KF`<0L71`0`1_Kfl307IfMP80O7al0`1nOWh80861P@<0PX:20`26QXH308R8R0<0RHV9
1@2=SHd308Z:RP<0RHV90P2?Shl308V9R@<0Shn?0`2=SHd2092@T0<0Ti>C0`2EUID309>CT`D0U9BD
0`2GUiL309ZJVP<0UIFE0P2DU9@309:BTP<0U9BD0`2FUYH509ZJVP<0WinO0`2XZ:P20<?3``<0d];B
0`39bLT80<SPf;40P8203`38h=P000d0b>3H0`1KFe/305iNGP80WYjN0`2;Rh/302PX:0<0:RXZ0P0b
<S8302h^;P<0?Shn0`0a<C42038b<P<0<30`0`0e=CD303`l?080A4A40`0l?3`302h^;P<0<C4a0`0W
9bL204=3@`<0IVIV0`1WIfL3061PH080Fe]K0`1`L70306m_K`<0MWIf0P1lO7`307inOPP0PH610`22
PX8308J6QP<0R8R80`29RHT508f=S@<0RXZ:0`29RHT208n?S`<0RHV90`2?Shl308f=S@80T92@0`2C
Ti<309FEU@<0Ti>C1@2DU9@309NGU`<0VYZJ0`2EUID209BDU0<0TY:B0`2DU9@309JFUPD0VYZJ0`2O
Wil30:RXZ080`l?30`3Bd]830<W9b@P0b>3H/@20P80?0<SPf0003@38h=P305]KF`<0GUiN0P2NWYh3
08^;R`<0:2PX0`0Z:RX2038b<P<0;Rh^0`0n?Sh3034a<@80<S8b0`0`<30303De=@<0?3`l0P14A4@3
03`l?0<0;Rh^0`0a<C4302LW9`80@d=30`1VIVH306MWI`<0H61P0P1KFe/3071`L0<0Kfm_0`1fMWH2
07alO0<0OWin2021PH4308:2PP<0QXJ60`28R8P308V9R@D0SHf=0`2:RXX308V9R@80Shn?0`29RHT3
08n?S`<0SHf=0P2@T90309>CT`<0UIFE0`2CTi<509BDU0<0UiNG0`2JVYX309FEU@80U9BD0`2BTY83
09BDU0<0UYJF1@2JVYX309nOW`<0Z:RX0P33`l<30=;BdP<0bLW92038h=Ra0820P0l0b>3H000=0<SP
f0<0GUiN0`1KFe/206][J`<0]KFe0`1RHV8302DU9@80:BTY0`0a<C43038b<P<0;2`/0P0b<S8302`/
;0<0=3@d0`0i>CT204A4A0<0=cLg0`0a<C43030`<0<09bLW0P1?Cdl306UYJ@<0J6QX0`1LG5`2069R
HP<0KFe]0`1bLW8307QhN080NWYj1P1oOgl308>3P`80PH610`20P80308V9R@<0R8R80`29RHT808^;
R`P0SHf=0`2>SXh3092@T0D0UIFE0`2FUYH309NGU`<0UIFE1@2HV9P309^KV`<0UYJF0P2ATI4309>C
T`<0V9RH0`2DU9@209FEU@<0V9RH0`2KVi/30:FUY@80_Kfm0`3@d=030<K6aPP0b>3H/@20P80?0<SP
f0003@38h=P305iNGP<0Fe]K0P1[Jf/30;Fe]@<0HV9R0`0U9BD202TY:@<0<C4a0`0b<S8302`/;080
<S8b0`0/;2`303@d=0<0>CTi0P14A4@303Lg=`<0<C4a0`0`<30302LW9`80Cdm?0`1YJFT306QXJ0<0
G5aL0P1RHV8306e]K@<0LW9b0`1hN7P207YjNPH0Ogmo0`23Ph<20861P@<0P8200`29RHT308R8R0<0
RHV9202;Rh/808f=S@<0SXj>0`2@T90509FEU@<0UYJF0`2GUiL309FEU@D0V9RH0`2KVi/309JFUP80
TI6A0`2CTi<309RHV0<0U9BD0P2EUID309RHV0<0Vi^K0`2UYJD20;fm_@<0d=3@0`36a/H80<SPf;40
P8203`38h=P000d0b>3H0`1SHf<305]KF`80GUiN0`2=SHd30<71`@<0@d=30P0[:b/302`/;0<0:b/[
0`0`<30203<c<`<0<S8b0`0f=SH303`l?080@4100`0m?Cd303<c<`<0;bl_0`0/;2`204e=C@<0LW9b
0`1XJ6P305YJFP80J6QX0`1`L703079bLP<0OGem0P1lO7`307emO@<0P8200`1nOWh20820P0<0QHF5
0`24Q8@308Z:RP<0Rh^;0P2<S8`308f=S@<0Rh^;0`2:RXX208b<S0<0SXj>0`2@T90309JFUP80VIVI
0`2GUiL309VIV@<0UYJF0`2HV9P209ZJVP<0Vi^K0`2JVYX309NGU`80UIFE0`2GUiL309BDU0<0TY:B
0P2CTi<3096AT@<0UiNG0`2NWYh20;Fe]@<0bl_;0`30`<080<SPf380P8200`1PH61l0820P0l0b>3H
000=0<SPf0<0Hf=S0`1KFe/205iNGP<0SHf=0`31`L4304=3@`80:b/[0`0/;2`302/[:`<0<30`0P0c
<c<3038b<P<0=SHf0`0l?3`20410@0<0?Cdm0`0c<c<302l_;`<0;2`/0P1=CDd3079bLP<0J6QX0`1J
FUX206QXJ0<0L71`0`1bLW8307emO@80O7al0`1mOGd30820P0<0OWin0P20P80308F5Q@<0Q8B40`2:
RXX308^;R`80S8b<0`2=SHd308^;R`<0RXZ:0P2<S8`308j>SP<0T92@0`2FUYH209VIV@<0UiNG0`2I
VIT309JFUP<0V9RH0P2JVYX309^KV`<0VYZJ0`2GUiL209FEU@<0UiNG0`2DU9@309:BTP80Ti>C0`2A
TI4309NGU`<0WYjN0P2e]KD30<_;b`<0`<302038h=Pb0820P0<0H61PO020P80?0<SPf0003@38h=P3
06=SH`<0Fe]K0P1NGUh308f=S@<0`L710`13@d<202/[:`<0;2`/0`0[:b/3030`<080<c<c0`0b<S83
03Hf=P<0?3`l0P10@40303dm?@<0<c<c0`0_;bl302`/;080CDe=0`1bLW8306QXJ0<0FUYJ0P1XJ6P3
071`L0<0LW9b0`1mOGd207alO0<0OGem0`20P80307inOP80P8200`25QHD308B4Q0<0RXZ:0`2;Rh/2
08b<S0<0SHf=0`2;Rh/308Z:RP80S8b<0`2>SXh3092@T0<0UYJF0P2IVIT309NGU`<0VIVI0`2FUYH3
09RHV080VYZJ0`2KVi/309ZJVP<0UiNG0P2EUID309NGU`<0U9BD0`2BTY8209>CT`<0TI6A0`2GUiL3
09jNWP80]KFe0`3;bl/30<30`0P0b>3H<P20P803061PH7`0P8203`38h=P000d0b>3H0`1FEUH306=S
H`80HF5Q0`2>SXh30;Jf]P<0]KFe0P0j>SX303De=@<0<c<c0`0k>c/203Lg=`<0=CDe0`0h>3P303hn
?P80>c/k0`0e=CD3038b<P<0;Rh^0`0_;bl205QHF0<0K6a/0`1UIFD305QHF080IVIV0`1_Kfl307If
MP<0NWYj0P1nOWh307emO@<0PH610`20P80208:2PP<0Ph>30`29RHT308^;R`/0S8b<1@2@T90309:B
TP<0UYJF1@2IVIT609ZJVP<0Vi^K1@2NWYh609bLW0<0UiNG1@2HV9P309FEU@<0U9BD0P2BTY86092@
T0<0W9bL0P2[Zj/30<;2`P<0]kNg2038h=Ra0820P0l0b>3H000=0<SPf0<0EUIF0`1SHf<2065QH@<0
SXj>0`2f][H30;Fe]@80>SXj0`0e=CD303<c<`<0>c/k0P0g=cL303De=@<0>3Ph0`0n?Sh203/k>`<0
=CDe0`0b<S8302h^;P<0;bl_0P1HF5P306a/K0<0IFEU0`1HF5P206IVIP<0Kfm_0`1fMWH307YjNP80
OWin0`1mOGd30861P@<0P8200P22PX8308>3P`<0RHV90`2;Rh/;08b<S0D0T92@0`2BTY8309JFUPD0
VIVI1P2JVYX309^KV`D0WYjN1P2LW9`309NGU`D0V9RH0`2EUID309BDU080TY:B1P2@T90309bLW080
Zj^[0`32`/830;Ng]`P0b>3H/@20P80?0<SPf0003@38h=P305IFEP<0Hf=S0P1QHF4308j>SP<0][Jf
0`2e]KD203Xj>P<0=CDe0`0c<c<303/k>`80=cLg0`0e=CD303Ph>0<0?Shn0P0k>c/303De=@<0<S8b
0`0^;Rh302l_;`80F5QH0`1/K6`306EUI@<0F5QH0P1VIVH306m_K`<0MWIf0`1jNWX207inOP<0OGem
0`21PH430820P080PX:20`23Ph<308V9R@<0Rh^;2`2<S8`5092@T0<0TY:B0`2FUYH509VIV@H0VYZJ
0`2KVi/509jNWPH0W9bL0`2GUiL509RHV0<0UIFE0`2DU9@209:BTPH0T92@0`2LW9`20:^[Z`<0`/;2
0`2g]kL80<SPf;40P8203`38h=P000d0b>3H0`20P803069RHP80IfMW0`1eMGD308^;R`<0b/[:0P2A
TI4302`/;0<0<30`0`0c<c<2034a<@<0=3@d0`0g=cL303dm?@80=cLg0`0f=SH303<c<`<0;bl_0`0^
;Rh205]KF`<0MGEe0`1MGEd305ADE080I6AT0`1^KVh307AdM0<0NGUi0P1kNg/607alO0<0NWYj0P22
PX830861P@<0Q8B40`27QhL308Z:RP80S8b<1P2@T90308j>SP80T92@1P2ATI4309RHV0D0VYZJ0`2K
Vi/309jNWP<0X:2P0P2LW9`609fMW@<0VYZJ0P2KVi/309JFUP<0UIFE0`2BTY82096AT@H0Rh^;0`2>
SXh209^KV`<0/K6a0`2UYJD80<SPf;40P8203`38h=P000d0b>3H0`20P803069RHP80IfMW0`1eMGD3
08^;R`<0b/[:0P2ATI4302`/;0<0<30`0`0c<c<2034a<@<0=3@d0`0g=cL303dm?@80=cLg0`0f=SH3
03<c<`<0;bl_0`0^;Rh205]KF`<0MGEe0`1MGEd305ADE080I6AT0`1^KVh307AdM0<0NGUi0P1kNg/6
07alO0<0NWYj0P22PX830861P@<0Q8B40`27QhL308Z:RP80S8b<1P2@T90308j>SP80T92@1P2ATI43
09RHV0D0VYZJ0`2KVi/309jNWP<0X:2P0P2LW9`609fMW@<0VYZJ0P2KVi/309JFUP<0UIFE0`2BTY82
096AT@H0Rh^;0`2>SXh209^KV`<0/K6a0`2UYJD80<SPf;40P8203`38h=P000d0b>3H0`20P803069R
HP80IfMW0`1eMGD308^;R`<0b/[:0P2ATI4302`/;0<0<30`0`0c<c<2034a<@<0=3@d0`0g=cL303dm
?@80=cLg0`0f=SH303<c<`<0;bl_0`0^;Rh205]KF`<0MGEe0`1MGEd305ADE080I6AT0`1^KVh307Ad
M0<0NGUi0P1kNg/607alO0<0NWYj0P22PX830861P@<0Q8B40`27QhL308Z:RP80S8b<1P2@T90308j>
SP80T92@1P2ATI4309RHV0D0VYZJ0`2KVi/309jNWP<0X:2P0P2LW9`609fMW@<0VYZJ0P2KVi/309JF
UP<0UIFE0`2BTY82096AT@H0Rh^;0`2>SXh209^KV`<0/K6a0`2UYJD80<SPf;40P8203`38h=P000d0
b>3H0`2^[Zh307QhN080K6a/0`1UIFD307=cL`<0XJ6Q0P3Hf=P305iNGP<09RHV0`0Z:RX202LW9`<0
;Rh^0`0e=CD30492@P80<30`0`0_;bl302h^;P<09bLW0`0V9RH205mOG`<0LG5a0`1KFe/3059BDP80
IFEU0`1aLG4307=cL`<0MWIf0P1jNWX307]kN`<0OWin0`21PH4207moO`<0PH610`25QHD308V9R@<0
QhN70P2=SHd608n?S`<0T92@0P2ATI4309BDU0<0UiNG0`2FUYH209^KV`<0VIVI0`2LW9`309RHV0<0
WIfM0P2NWYh309fMW@H0Vi^K0P2GUiL309FEU@<0TY:B0`2?Shl208^;R`<0Q8B40`23Ph<308F5Q@80
Rh^;0`2DU9@308J6QPP0b>3H0`20P803061PH:/0P8203`38h=P000d0b>3H0`2^[Zh307QhN080K6a/
0`1UIFD307=cL`<0XJ6Q0P3Hf=P305iNGP<09RHV0`0Z:RX202LW9`<0;Rh^0`0e=CD30492@P80<30`
0`0_;bl302h^;P<09bLW0`0V9RH205mOG`<0LG5a0`1KFe/3059BDP80IFEU0`1aLG4307=cL`<0MWIf
0P1jNWX307]kN`<0OWin0`21PH4207moO`<0PH610`25QHD308V9R@<0QhN70P2=SHd608n?S`<0T92@
0P2ATI4309BDU0<0UiNG0`2FUYH209^KV`<0VIVI0`2LW9`309RHV0<0WIfM0P2NWYh309fMW@H0Vi^K
0P2GUiL309FEU@<0TY:B0`2?Shl208^;R`<0Q8B40`23Ph<308F5Q@80Rh^;0`2DU9@308J6QPP0b>3H
0`20P803061PH:/0P8203`38h=P000d0b>3H0`1VIVH307]kN`80JVYZ0`20P8030861P@<0QhN70P2_
[jl30:FUY@<0=3@d0`0X:2P202@T90<0;2`/0`18B4P304I6AP80>CTi0`0Z:RX302/[:`<0<30`0`0_
;bl205IFEP<0MGEe0`1JFUX3059BDP80I6AT0`1/K6`307=cL`<0M7Ad0P1lO7`307inOP<0O7al0`1o
Ogl208>3P`<0PH610`26QXH308R8R0<0RHV90P2BTY83092@T0<0TY:B0`2DU9@2096AT@<0T92@0`2D
U9@309JFUP80VIVI0`2FUYH309^KV`<0WIfM0`2PX:0209^KV`<0WIfM0`2KVi/509FEU@<0TI6A0`28
R8P308B4Q080Ogmo0`1kNg/30861P@<0Ph>30P24Q8@308:2PP<0MWIf2038h=Ra0820P0l0b>3H000=
0<SPf0<0IVIV0`1kNg/206YZJP<0P8200`21PH4308N7Q`80[jn_0`2UYJD303@d=0<0:2PX0P0T92@3
02`/;0<0B4Q80`16ATH203Ti>@<0:RXZ0`0[:b/3030`<0<0;bl_0P1FEUH307EeM@<0FUYJ0`1BDU82
06ATI0<0K6a/0`1cLg<307AdM080O7al0`1nOWh307alO0<0Ogmo0P23Ph<30861P@<0QXJ60`28R8P3
08V9R@80TY:B0`2@T90309:BTP<0U9BD0P2ATI43092@T0<0U9BD0`2FUYH209VIV@<0UYJF0`2KVi/3
09fMW@<0X:2P0P2KVi/309fMW@<0Vi^K1@2EUID3096AT@<0R8R80`24Q8@207moO`<0Ng]k0`21PH43
08>3P`80Q8B40`22PX8307IfMPP0b>3H/@20P80?0<SPf0003@38h=P306IVIP<0Ng]k0P1ZJVX30820
P0<0PH610`27QhL20:n_[`<0YJFU0`0d=3@302PX:08092@T0`0/;2`304Q8B0<0ATI60P0i>CT302XZ
:P<0:b/[0`0`<30302l_;`80EUIF0`1eMGD305YJFP<0DU9B0P1TI6@306a/K0<0Lg=c0`1dM7@207al
O0<0OWin0`1lO7`307moO`80Ph>30`21PH4308J6QP<0R8R80`29RHT209:BTP<0T92@0`2BTY8309BD
U080TI6A0`2@T90309BDU0<0UYJF0P2IVIT309JFUP<0Vi^K0`2MWId30:2PX080Vi^K0`2MWId309^K
V`D0UIFE0`2ATI4308R8R0<0Q8B40P1oOgl307]kN`<0PH610`23Ph<208B4Q0<0PX:20`1fMWH80<SP
f;40P8203`38h=P000d0b>3H0`0f=SH304M7A`80Ph>30`2ATI430:2PX0<0[Zj^0P2c/k<30;Vi^@<0
Y:BT0`0f=SH202LW9`<09RHV0`0/;2`302XZ:PD0;2`/1P0^;Rh302PX:080FEUI0`1^KVh3055AD@<0
De=C0P1VIVH306][J`H0Lg=c0P1kNg/307YjNP<0OWin0`21PH4208:2PP<0QHF50`28R8P308V9R@<0
Shn?1@2@T903096AT@D0UIFE0`2CTi<309RHV0<0VYZJ0P2IVIT609^KV`H0WYjN0P2LW9`309jNWP<0
V9RH1@2CTi<308b<S0<0Ng]k0`1iNGT207inOP<0Ogmo1P1mOGd20861P@<0OGem0`1aLG480<SPf;40
P8203`38h=P000d0b>3H0`0f=SH304M7A`80Ph>30`2ATI430:2PX0<0[Zj^0P2c/k<30;Vi^@<0Y:BT
0`0f=SH202LW9`<09RHV0`0/;2`302XZ:PD0;2`/1P0^;Rh302PX:080FEUI0`1^KVh3055AD@<0De=C
0P1VIVH306][J`H0Lg=c0P1kNg/307YjNP<0OWin0`21PH4208:2PP<0QHF50`28R8P308V9R@<0Shn?
1@2@T903096AT@D0UIFE0`2CTi<309RHV0<0VYZJ0P2IVIT609^KV`H0WYjN0P2LW9`309jNWP<0V9RH
1@2CTi<308b<S0<0Ng]k0`1iNGT207inOP<0Ogmo1P1mOGd20861P@<0OGem0`1aLG480<SPf;40P820
3`38h=P000d0b>3H0`0f=SH304M7A`80Ph>30`2ATI430:2PX0<0[Zj^0P2c/k<30;Vi^@<0Y:BT0`0f
=SH202LW9`<09RHV0`0/;2`302XZ:PD0;2`/1P0^;Rh302PX:080FEUI0`1^KVh3055AD@<0De=C0P1V
IVH306][J`H0Lg=c0P1kNg/307YjNP<0OWin0`21PH4208:2PP<0QHF50`28R8P308V9R@<0Shn?1@2@
T903096AT@D0UIFE0`2CTi<309RHV0<0VYZJ0P2IVIT609^KV`H0WYjN0P2LW9`309jNWP<0V9RH1@2C
Ti<308b<S0<0Ng]k0`1iNGT207inOP<0Ogmo1P1mOGd20861P@<0OGem0`1aLG480<SPf;40P8203`38
h=P000d0b>3H0`0T92@301dM7@80MgMg0`2WYjL30:b/[0<0_[jn0P2k^k/30;no_`<0^k^k0`1^KVh2
02DU9@<0:2PX0`0W9bL302HV9P80:2PX0`0_;bl3034a<@<0;Rh^0`0U9BD205=CD`<0Kfm_0`1>CTh3
05EEE@80HF5Q0`1UIFD306i^KP<0M7Ad0P1iNGT607alO0<0PX:20P21PH4308B4Q0<0QhN70`2:RXX3
08b<S080TY:B0`2@T90309BDU0<0UiNG0P2FUYH309NGU`<0UIFE0`2HV9P209bLW0H0WYjN0`2MWId3
09jNWP80WIfM0`2NWYh309FEU@<0U9BD0P2?Shl308B4Q0<0MgMg0`21PH4208B4Q0<0JFUY0`16ATH3
04M7A`80GUiN0`1MGEd305UIF@P0b>3H6@20P803061PH9D0P8203`38h=P000d0b>3H0`0T92@301dM
7@80MgMg0`2WYjL30:b/[0<0_[jn0P2k^k/30;no_`<0^k^k0`1^KVh202DU9@<0:2PX0`0W9bL302HV
9P80:2PX0`0_;bl3034a<@<0;Rh^0`0U9BD205=CD`<0Kfm_0`1>CTh305EEE@80HF5Q0`1UIFD306i^
KP<0M7Ad0P1iNGT607alO0<0PX:20P21PH4308B4Q0<0QhN70`2:RXX308b<S080TY:B0`2@T90309BD
U0<0UiNG0P2FUYH309NGU`<0UIFE0`2HV9P209bLW0H0WYjN0`2MWId309jNWP80WIfM0`2NWYh309FE
U@<0U9BD0P2?Shl308B4Q0<0MgMg0`21PH4208B4Q0<0JFUY0`16ATH304M7A`80GUiN0`1MGEd305UI
F@P0b>3H6@20P803061PH9D0P8203`38h=P000d0b>3H0`0T92@301dM7@80MgMg0`2WYjL30:b/[0<0
_[jn0P2k^k/30;no_`<0^k^k0`1^KVh202DU9@<0:2PX0`0W9bL302HV9P80:2PX0`0_;bl3034a<@<0
;Rh^0`0U9BD205=CD`<0Kfm_0`1>CTh305EEE@80HF5Q0`1UIFD306i^KP<0M7Ad0P1iNGT607alO0<0
PX:20P21PH4308B4Q0<0QhN70`2:RXX308b<S080TY:B0`2@T90309BDU0<0UiNG0P2FUYH309NGU`<0
UIFE0`2HV9P209bLW0H0WYjN0`2MWId309jNWP80WIfM0`2NWYh309FEU@<0U9BD0P2?Shl308B4Q0<0
MgMg0`21PH4208B4Q0<0JFUY0`16ATH304M7A`80GUiN0`1MGEd305UIF@P0b>3H6@20P803061PH9D0
P8203`38h=P000d0b>3H0`0S8b<301lO7`80AdM70`2d];@30:RXZ0<0^KVi0P2a/K430;Vi^@<0/K6a
0`2/[:`206IVIP<0=3@d0`0T92@302<S8`8092@T1P0/;2`302PX:0<09BDU0P1HF5P3065QH@<0CDe=
0`1@D50205eMG@<0I6AT0`1bLW8307IfMP80Ng]k0`1jNWX30861P@<0OWin0P21PH4308J6QP<0Rh^;
0`2:RXX308f=S@80Shn?0`2@T90309RHV0<0U9BD0P2GUiL309VIV@<0UiNG0`2IVIT209^KV`<0W9bL
1P2MWId309jNWP80W9bL0`2NWYh309FEU@<0T92@0P29RHT307emO@<0N7Qh0`24Q8@208J6QP<0MWIf
0`15ADD304A4A080GEeM0`1_Kfl307IfMPP0b>3H7020P802061PH8D0P820201PH6060820P0l0b>3H
000=0<SPf0<08b<S0`0O7al204M7A`<0];Bd0`2XZ:P30;Vi^@80/K6a0`2i^KT30;6a/@<0[:b/0P1V
IVH303@d=0<092@T0`0S8b<202@T90H0;2`/0`0X:2P302DU9@80F5QH0`1QHF4304e=C@<0D51@0P1M
GEd306ATI0<0LW9b0`1fMWH207]kN`<0NWYj0`21PH4307inOP80PH610`26QXH308^;R`<0RXZ:0`2=
SHd208n?S`<0T92@0`2HV9P309BDU080UiNG0`2IVIT309NGU`<0VIVI0P2KVi/309bLW0H0WIfM0`2N
WYh209bLW0<0WYjN0`2EUID3092@T080RHV90`1mOGd307QhN0<0Q8B40P26QXH307IfMP<0ADE50`14
A4@205eMG@<0Kfm_0`1fMWH80<SPf1`0P8200P1PH6250820P0P0H61P1P20P80?0<SPf0003@38h=P3
02HV9P<07QhN0P0V9RH309^KV`<0XJ6Q0`2WYjL20:^[Z`<0ZZZZ0`2b/[830;Ng]`80[Jf]0`1^KVh3
03@d=0<09BDU0P0S8b<302`/;0<0;Bd]0`0/;2`302HV9P80EUIF0`1RHV8304A4A0<0AdM70P1JFUX3
06IVIP<0LW9b0`1eMGD207emO@<0Ogmo0`21PH4307moO`80PX:20`25QHD308V9R@<0SXj>0`2;Rh/2
096AT@<0T92@0`2BTY8309RHV080UIFE0`2GUiL309JFUP<0VYZJ0P2MWId309VIV@<0WinO1P2NWYh2
09bLW0<0VYZJ0`2CTi<308n?S`80SXj>0`1bLW8307=cL`<0Ogmo0P29RHT608N7Q`<0RHV90P2:RXX3
08R8R0<0OGem2038h=PI0820P0<0H61PU@20P80?0<SPf0003@38h=P302HV9P<07QhN0P0V9RH309^K
V`<0XJ6Q0`2WYjL20:^[Z`<0ZZZZ0`2b/[830;Ng]`80[Jf]0`1^KVh303@d=0<09BDU0P0S8b<302`/
;0<0;Bd]0`0/;2`302HV9P80EUIF0`1RHV8304A4A0<0AdM70P1JFUX306IVIP<0LW9b0`1eMGD207em
O@<0Ogmo0`21PH4307moO`80PX:20`25QHD308V9R@<0SXj>0`2;Rh/2096AT@<0T92@0`2BTY8309RH
V080UIFE0`2GUiL309JFUP<0VYZJ0P2MWId309VIV@<0WinO1P2NWYh209bLW0<0VYZJ0`2CTi<308n?
S`80SXj>0`1bLW8307=cL`<0Ogmo0P29RHT608N7Q`<0RHV90P2:RXX308R8R0<0OGem2038h=PI0820
P0<0H61PU@20P80?0<SPf0003@38h=P302HV9P<07QhN0P0V9RH309^KV`<0XJ6Q0`2WYjL20:^[Z`<0
ZZZZ0`2b/[830;Ng]`80[Jf]0`1^KVh303@d=0<09BDU0P0S8b<302`/;0<0;Bd]0`0/;2`302HV9P80
EUIF0`1RHV8304A4A0<0AdM70P1JFUX306IVIP<0LW9b0`1eMGD207emO@<0Ogmo0`21PH4307moO`80
PX:20`25QHD308V9R@<0SXj>0`2;Rh/2096AT@<0T92@0`2BTY8309RHV080UIFE0`2GUiL309JFUP<0
VYZJ0P2MWId309VIV@<0WinO1P2NWYh209bLW0<0VYZJ0`2CTi<308n?S`80SXj>0`1bLW8307=cL`<0
Ogmo0P29RHT608N7Q`<0RHV90P2:RXX308R8R0<0OGem2038h=PI0820P0<0H61PU@20P80?0<SPf000
3@38h=P302/[:`<0:BTY0P0M7Ad307=cL`<0Y:BT0`2NWYh209FEU@<0QhN70`1iNGT308N7Q`80ZJVY
0`2ZZZX305]KF`<08R8R0P0U9BD602TY:@<0:b/[0`0V9RH205MGE`<0IFEU0`18B4P304I6AP80EeMG
0`1UIFD3075aL@<0MWIf0P1mOGd307alO0<0PH610`20P80208>3P`<0QXJ60`28R8P308f=S@<0Shn?
0P2>SXh3096AT@<0U9BD0`2GUiL209JFUP<0VYZJ202MWId309jNWPH0WinO0`2MWId209nOW`<0VIVI
0`2BTY8308n?S`80RHV90`1dM7@306i^KP<0OGem0P28R8P308f=S@<0R8R80`2<S8`208f=S@<0R8R8
0`1lO7`80<SPf1T0P8201@2PX:2C0820P0l0b>3H000=0<SPf0<0:b/[0`0Y:BT201dM7@<0Lg=c0`2T
Y:@309jNWP80UIFE0`27QhL307UiN@<0QhN70P2YZJT30:ZZZP<0Fe]K0`0R8R8202DU9@H0:BTY0`0[
:b/302HV9P80EeMG0`1UIFD304Q8B0<0ATI60P1GEeL306EUI@<0LG5a0`1fMWH207emO@<0O7al0`21
PH430820P080Ph>30`26QXH308R8R0<0SHf=0`2?Shl208j>SP<0TI6A0`2DU9@309NGU`80UYJF0`2J
VYX809fMW@<0WYjN1P2OWil309fMW@80WinO0`2IVIT309:BTP<0Shn?0P29RHT307AdM0<0KVi^0`1m
OGd208R8R0<0SHf=0`28R8P308b<S080SHf=0`28R8P307alO0P0b>3H6@20P8050:2PX9<0P8203`38
h=P000d0b>3H0`0[:b/302TY:@807AdM0`1cLg<30:BTY0<0WYjN0P2EUID308N7Q`<0NGUi0`27QhL2
0:VYZ@<0ZZZZ0`1KFe/3028R8P809BDU1P0Y:BT302/[:`<09RHV0P1GEeL306EUI@<0B4Q80`16ATH2
05MGE`<0IFEU0`1aLG4307IfMP80OGem0`1lO7`30861P@<0P8200P23Ph<308J6QP<0R8R80`2=SHd3
08n?S`80SXj>0`2ATI4309BDU0<0UiNG0P2FUYH309ZJVPP0WIfM0`2NWYh609nOW`<0WIfM0P2OWil3
09VIV@<0TY:B0`2?Shl208V9R@<0M7Ad0`1^KVh307emO@80R8R80`2=SHd308R8R0<0S8b<0P2=SHd3
08R8R0<0O7al2038h=PI0820P0D0X:2PT`20P80?0<SPf0003@38h=P3028R8P<0;Bd]0P0S8b<302/[
:`<0MGEe0`1kNg/207QhN0<0J6QX0`1`L7030:RXZ080WYjN0`2ATI4307alO0<0=cLg0P0T92@302DU
9@<0:2PX0`0[:b/302@T9080EUIF0`1JFUX30410@0<0C4a<0P1EEED3065QH@<0LG5a0`1dM7@207]k
N`<0OGem1P20P80208F5Q@<0QhN70`2;Rh/308b<S0D0TI6A0`2DU9@609RHV080UYJF1P2IVIT309bL
W080WIfM0`2NWYh60:2PX0<0XZ:R0P2OWil309VIV@<0UYJF0`2<S8`208^;R`<0MWIf0`1`L70307Yj
NP80Q8B40`28R8P308N7Q`<0RXZ:0P27QhL30820P0<0OGem2038h=PN0820P0T0X:2PRP20P80?0<SP
f0003@38h=P3028R8P<0;Bd]0P0S8b<302/[:`<0MGEe0`1kNg/207QhN0<0J6QX0`1`L7030:RXZ080
WYjN0`2ATI4307alO0<0=cLg0P0T92@302DU9@<0:2PX0`0[:b/302@T9080EUIF0`1JFUX30410@0<0
C4a<0P1EEED3065QH@<0LG5a0`1dM7@207]kN`<0OGem1P20P80208F5Q@<0QhN70`2;Rh/308b<S0D0
TI6A0`2DU9@609RHV080UYJF1P2IVIT309bLW080WIfM0`2NWYh60:2PX0<0XZ:R0P2OWil309VIV@<0
UYJF0`2<S8`208^;R`<0MWIf0`1`L70307YjNP80Q8B40`28R8P308N7Q`<0RXZ:0P27QhL30820P0<0
OGem2038h=PN0820P0T0X:2PRP20P80?0<SPf0003@38h=P3028R8P<0;Bd]0P0S8b<302/[:`<0MGEe
0`1kNg/207QhN0<0J6QX0`1`L7030:RXZ080WYjN0`2ATI4307alO0<0=cLg0P0T92@302DU9@<0:2PX
0`0[:b/302@T9080EUIF0`1JFUX30410@0<0C4a<0P1EEED3065QH@<0LG5a0`1dM7@207]kN`<0OGem
1P20P80208F5Q@<0QhN70`2;Rh/308b<S0D0TI6A0`2DU9@609RHV080UYJF1P2IVIT309bLW080WIfM
0`2NWYh60:2PX0<0XZ:R0P2OWil309VIV@<0UYJF0`2<S8`208^;R`<0MWIf0`1`L70307YjNP80Q8B4
0`28R8P308N7Q`<0RXZ:0P27QhL30820P0<0OGem2038h=PN0820P0T0X:2PRP20P80?0<SPf0003@38
h=P302PX:0D0;bl_0`0N7Qh303De=@<0DE5A0P21PH4307AdM0<0Ng]k0`2RXZ820<g=c@<0ZZZZ0`2?
Shl302@T90808b<S0`0W9bL302DU9@<0:BTY0`0T92@205ADE0<0FUYJ0`0l?3`304];B`80EUIF0`1R
HV8306e]K@<0MGEe0P1jNWX307inOP<0PX:20`23Ph<208J6QP<0QhN70`26QXH308Z:RP<0TI6A1@2E
UID309NGU`D0UYJF0`2IVIT309^KV`<0WinO1@2QXJ430:>SX`H0XZ:R0P2OWil309^KV`<0UIFE0`2@
T90208j>SP<0PX:21P1gMgL20861P@H0QXJ60`1oOgl207alO0<0NWYj0`1kNg/80<SPf;40P8203`38
h=P000d0b>3H0`0X:2P502l_;`<07QhN0`0e=CD3055AD@80PH610`1dM7@307]kN`<0XZ:R0P3=cLd3
0:ZZZP<0Shn?0`0T92@202<S8`<09bLW0`0U9BD302TY:@<092@T0P1DE5@305YJFP<0?3`l0`1;Bd/2
05IFEP<0HV9R0`1]KFd307EeM@80NWYj0`1nOWh308:2PP<0Ph>30P26QXH308N7Q`<0QXJ60`2:RXX3
096AT@D0UIFE0`2GUiL509JFUP<0VIVI0`2KVi/309nOW`D0XJ6Q0`2SXj<60::RXP80WinO0`2KVi/3
09FEU@<0T92@0P2>SXh308:2PPH0MgMg0P21PH4608J6QP<0Ogmo0P1lO7`307YjNP<0Ng]k2038h=Ra
0820P0l0b>3H000=0<SPf0<08b<S1@0a<C43028R8P<08b<S0`0R8R8207alO0<0OWin0`1cLg<308>3
P`80alO70`3:b/X30<o?c`<0G5aL0P0T92@302TY:@<09bLW0`0V9RH3024Q8@80CTi>0`1BDU8303lo
?`<0Bd];0P1JFUX306ATI0<0L71`0`1gMgL207YjNP<0Ogmo0`23Ph<308:2PP80QHF50`27QhL308n?
S`<0SXj>0`2@T90209BDU0<0UIFE1P2GUiL209bLW0<0Vi^K0`2LW9`309fMW@80X:2P0`2VYZH30:>S
X`<0XJ6Q0`2PX:020::RXP<0WYjN0`2IVIT309:BTP80Rh^;0`25QHD607moO`80OGem1P23Ph<307al
O080OWin1P1iNGT80<SPf;40P8203`38h=P000d0b>3H0`0S8b<5034a<@<08R8R0`0S8b<3028R8P80
O7al0`1nOWh307=cL`<0Ph>30P37alL30<[:bP<0clo?0`1LG5`202@T90<0:BTY0`0W9bL302HV9P<0
8B4Q0P1>CTh3059BDP<0?clo0`1;Bd/205YJFP<0I6AT0`1`L70307MgM`80NWYj0`1oOgl308>3P`<0
PX:20P25QHD308N7Q`<0Shn?0`2>SXh3092@T080U9BD0`2EUID609NGU`80W9bL0`2KVi/309bLW0<0
WIfM0P2PX:030:JVYP<0Xj>S0`2QXJ430:2PX080XZ:R0`2NWYh309VIV@<0TY:B0P2;Rh/308F5Q@H0
Ogmo0P1mOGd608>3P`<0O7al0P1nOWh607UiN@P0b>3H/@20P80?0<SPf0003@38h=P302<S8`D0<C4a
0`0R8R8302<S8`<08R8R0P1lO7`307inOP<0Lg=c0`23Ph<20<O7a`<0b/[:0`3?cll305aLG08092@T
0`0Y:BT302LW9`<09RHV0`0Q8B4204i>CP<0DU9B0`0o?cl304];B`80FUYJ0`1TI6@3071`L0<0MgMg
0P1jNWX307moO`<0Ph>30`22PX8208F5Q@<0QhN70`2?Shl308j>SP<0T92@0P2DU9@309FEU@H0UiNG
0P2LW9`309^KV`<0W9bL0`2MWId20:2PX0<0YZJV0`2SXj<30:6QX@<0X:2P0P2RXZ8309jNWP<0VIVI
0`2BTY8208^;R`<0QHF51P1oOgl207emO@H0Ph>30`1lO7`207inOPH0NGUi2038h=Ra0820P0l0b>3H
000=0<SPf0<0:2PX1@1BDU8301hN7P<07alO0`0M7Ad204m?C`<0SXj>0`1aLG4307MgM`80Xj>S0`39
bLT30<S8b0<0`l?30P0k>c/302LW9`<09BDU1P0T92@204Q8B0<0BDU90`0k>c/304U9B@80EeMG0`1W
IfL3071`L0<0MgMg0P20P80307alO0<0Ph>30`21PH4208N7Q`<0RXZ:0`27QhL3096AT@D0Ti>C0`2I
VIT309RHV0<0WinO0P2QXJ4309fMW@<0X:2P0`2SXj<20:JVYP<0YJFU0`2VYZH30:NWY`<0YJFU0P2S
Xj<30:BTY0<0WYjN0`2EUID208n?S`<0RHV90`24Q8@30861P@80Q8B40`22PX8607emO@80N7Qh0`1j
NWX307alO0P0b>3H1P20P802061PH:T0P8203`38h=P000d0b>3H0`0X:2P5059BDP<07QhN0`0O7al3
01dM7@80Cdm?0`2>SXh3075aL@<0MgMg0P2SXj<30<W9b@<0b<S80`33`l<203/k>`<09bLW0`0U9BD6
02@T9080B4Q80`19BDT303/k>`<0BDU90P1GEeL306MWI`<0L71`0`1gMgL20820P0<0O7al0`23Ph<3
0861P@80QhN70`2:RXX308N7Q`<0TI6A1@2CTi<309VIV@<0V9RH0`2OWil20:6QX@<0WIfM0`2PX:03
0:>SX`80YZJV0`2UYJD30:JVYP<0YjNW0`2UYJD20:>SX`<0Y:BT0`2NWYh309FEU@80Shn?0`29RHT3
08B4Q0<0PH610P24Q8@308:2PPH0OGem0P1hN7P307YjNP<0O7al2038h=P60820P080H61PZ@20P80?
0<SPf0003@38h=P302PX:0D0DU9B0`0N7Qh301lO7`<07AdM0P1?Cdl308j>SP<0LG5a0`1gMgL20:>S
X`<0bLW90`38b<P30<?3``80>c/k0`0W9bL302DU9@H092@T0P18B4P304U9B@<0>c/k0`19BDT205MG
E`<0IfMW0`1`L70307MgM`80P8200`1lO7`308>3P`<0PH610P27QhL308Z:RP<0QhN70`2ATI4509>C
T`<0VIVI0`2HV9P309nOW`80XJ6Q0`2MWId30:2PX0<0Xj>S0P2VYZH30:FUY@<0YZJV0`2WYjL30:FU
Y@80Xj>S0`2TY:@309jNWP<0UIFE0P2?Shl308V9R@<0Q8B40`21PH4208B4Q0<0PX:21P1mOGd207Qh
N0<0NWYj0`1lO7`80<SPf0H0P8200P1PH62Y0820P0l0b>3H000=0<SPf0<0?Cdm0`1[Jf/207UiN@<0
:BTY0`0N7Qh301dM7@80:b/[0`2?Shl307UiN@<0LG5a0P27QhL30<;2`P<0b<S80`3:b/X20:BTY0<0
:2PX1P0U9BD3024Q8@80ATI60`13@d<303Ph>0<0AdM70P1JFUX306QXJ0<0Kfm_0`1hN7P207emO@<0
PH611P22PX8208B4Q0<0RHV90`2<S8`3096AT@<0UIFE0P2HV9P309^KV`<0W9bL0`2QXJ420::RXP<0
WinO0`2VYZH30:VYZ@80YJFU0`2[Zj/30:RXZ0<0ZJVY0`2XZ:P50:>SX`<0W9bL0`2IVIT209:BTP<0
R8R80`26QXH308>3P`80QHF50`24Q8@60820P080NGUi0`1kNg/307alO0P0b>3H/@20P80?0<SPf000
3@38h=P303dm?@<0Jf][0P1iNGT302TY:@<07QhN0`0M7Ad202/[:`<0Shn?0`1iNGT3075aL@80QhN7
0`32`/830<S8b0<0b/[:0P2TY:@302PX:0H09BDU0`0Q8B4204I6AP<0@d=30`0h>3P304M7A`80FUYJ
0`1XJ6P306m_K`<0N7Qh0P1mOGd30861P@H0PX:20P24Q8@308V9R@<0S8b<0`2ATI4309FEU@80V9RH
0`2KVi/309bLW0<0XJ6Q0P2RXZ8309nOW`<0YZJV0`2YZJT20:FUY@<0Zj^[0`2XZ:P30:VYZ@<0Z:RX
1@2SXj<309bLW0<0VIVI0P2BTY8308R8R0<0QXJ60`23Ph<208F5Q@<0Q8B41P20P80207UiN@<0Ng]k
0`1lO7`80<SPf;40P8203`38h=P000d0b>3H0`0m?Cd306][J`80NGUi0`0Y:BT301hN7P<07AdM0P0[
:b/308n?S`<0NGUi0`1aLG4208N7Q`<0`/;20`38b<P30<[:bP80Y:BT0`0X:2P602DU9@<08B4Q0P16
ATH304=3@`<0>3Ph0`17AdL205YJFP<0J6QX0`1_Kfl307QhN080OGem0`21PH4608:2PP80Q8B40`29
RHT308b<S0<0TI6A0`2EUID209RHV0<0Vi^K0`2LW9`30:6QX@80XZ:R0`2OWil30:JVYP<0ZJVY0P2U
YJD30:^[Z`<0Z:RX0`2YZJT30:RXZ0D0Xj>S0`2LW9`309VIV@80TY:B0`28R8P308J6QP<0Ph>30P25
QHD308B4Q0H0P8200P1iNGT307]kN`<0O7al2038h=Ra0820P0l0b>3H000=0<SPf0<0F5QH0`2HV9P2
092@T0<0;Rh^0`0R8R8302<S8`807alO0`1JFUX308n?S`<0KVi^0P1gMgL30;Fe]@<0bLW90`3;bl/2
0<k>cP<0Q8B40`0S8b<302LW9`<08b<S0P12@T8303dm?@<0<c<c0`19BDT205]KF`<0IVIV0`1`L703
07IfMP80Ng]k1P22PX8508F5Q@<0RXZ:0`2?Shl3096AT@D0UiNG0`2MWId309jNWP<0WinO0P2PX:03
0:FUY@<0[:b/0`2[Zj/20:VYZ@<0ZZZZ0`2][Jd30:VYZ@<0ZZZZ0P2UYJD30:BTY0<0X:2P0`2IVIT2
09BDU0<0RHV91P25QHD208N7Q`<0Q8B40`21PH4307inOP80NGUi0`1jNWX30820P0P0b>3H/@20P80?
0<SPf0003@38h=P305QHF0<0V9RH0P2@T90302h^;P<08R8R0`0S8b<201lO7`<0FUYJ0`2?Shl306i^
KP80MgMg0`2e]KD30<W9b@<0bl_;0P3>c/h308B4Q0<08b<S0`0W9bL302<S8`80@T920`0m?Cd303<c
<`<0BDU90P1KFe/306IVIP<0L71`0`1fMWH207]kN`H0PX:21@25QHD308Z:RP<0Shn?0`2ATI4509NG
U`<0WIfM0`2NWYh309nOW`80X:2P0`2UYJD30:b/[0<0Zj^[0P2YZJT30:ZZZP<0[Jf]0`2YZJT30:ZZ
ZP80YJFU0`2TY:@30:2PX0<0VIVI0P2DU9@308V9R@H0QHF50P27QhL308B4Q0<0PH610`1nOWh207Ui
N@<0NWYj0`20P8080<SPf;40P8203`38h=P000d0b>3H0`1HF5P309RHV080T92@0`0^;Rh3028R8P<0
8b<S0P0O7al305YJFP<0Shn?0`1^KVh207MgM`<0]KFe0`39bLT30<_;b`80c/k>0`24Q8@302<S8`<0
9bLW0`0S8b<20492@P<0?Cdm0`0c<c<304U9B@80Fe]K0`1VIVH3071`L0<0MWIf0P1kNg/608:2PPD0
QHF50`2:RXX308n?S`<0TI6A1@2GUiL309fMW@<0WYjN0`2OWil20:2PX0<0YJFU0`2/[:`30:^[Z`80
ZJVY0`2ZZZX30:f][@<0ZJVY0`2ZZZX20:FUY@<0Y:BT0`2PX:0309VIV@80U9BD0`29RHT608F5Q@80
QhN70`24Q8@30861P@<0OWin0P1iNGT307YjNP<0P8202038h=Ra0820P0l0b>3H000=0<SPf0<0O7al
0`2XZ:P206QXJ0<09BDU0`0V9RH302PX:080:BTY0`0d=3@308b<S0<0LG5a0P1_Kfl3096AT@<0b/[:
0`35aLD20<W9b@<0clo?0`15ADD302PX:0<09BDU0P0l?3`603Ti>@<0CDe=0P1MGEd306YZJP<0LW9b
0`1iNGT20820P0H0PH610`26QXH208V9R@<0SHf=0`2?Shl309FEU@<0UiNG0P2HV9P609bLW0<0Y:BT
0P2XZ:P30:ZZZP<0/K6a0`2/[:`20;2`/0<0[jn_0`2][Jd30:RXZ0<0ZZZZ0P2WYjL30:>SX`<0WinO
0`2IVIT209FEU@<0S8b<0`28R8P308N7Q`80QXJ60`2<S8`30861P@<0P8200P1mOGd307alO0<0PX:2
2038h=Ra0820P0l0b>3H000=0<SPf0<0O7al0`2XZ:P206QXJ0<09BDU0`0V9RH302PX:080:BTY0`0d
=3@308b<S0<0LG5a0P1_Kfl3096AT@<0b/[:0`35aLD20<W9b@<0clo?0`15ADD302PX:0<09BDU0P0l
?3`603Ti>@<0CDe=0P1MGEd306YZJP<0LW9b0`1iNGT20820P0H0PH610`26QXH208V9R@<0SHf=0`2?
Shl309FEU@<0UiNG0P2HV9P609bLW0<0Y:BT0P2XZ:P30:ZZZP<0/K6a0`2/[:`20;2`/0<0[jn_0`2]
[Jd30:RXZ0<0ZZZZ0P2WYjL30:>SX`<0WinO0`2IVIT209FEU@<0S8b<0`28R8P308N7Q`80QXJ60`2<
S8`30861P@<0P8200P1mOGd307alO0<0PX:22038h=Ra0820P0l0b>3H000=0<SPf0<0Xj>S0`1ZJVX2
030`<0<0:b/[0`0R8R8302@T90809RHV0`0W9bL306YZJP<0QhN70P1_Kfl307YjNP<0^[Zj0`2l_;`2
0<K6aP<0cLg=0`2UYJD302XZ:P<09bLW0P0e=CD3038b<P<0>CTi0`19BDT205mOG`<0Jf][0`1hN7P3
07UiN@80Ng]k0`20P80308F5Q@<0Ph>30P2:RXX308b<S0<0T92@0`2EUID509RHV0<0VIVI0`2MWId3
0:BTY080YZJV0`2YZJT30;2`/0<0[Jf]1@2a/K430:j^[P<0ZJVY0`2[Zj/20:RXZ0<0YZJV0`2PX:03
09bLW080U9BD0`2BTY8308b<S0<0RHV90P2<S8`308Z:RP<0QHF50`20P80207alO0<0OGem0`22PX88
0<SPf;40P8203`38h=P000d0b>3H0`2SXj<306YZJP80<30`0`0[:b/3028R8P<092@T0P0V9RH302LW
9`<0JVYZ0`27QhL206m_K`<0NWYj0`2j^[X30;bl_080a/K60`3=cLd30:FUY@<0:RXZ0`0W9bL203De
=@<0<S8b0`0i>CT304U9B@80GemO0`1[Jf/307QhN0<0NGUi0P1kNg/30820P0<0QHF50`23Ph<208Z:
RP<0S8b<0`2@T90309FEU@D0V9RH0`2IVIT309fMW@<0Y:BT0P2VYZH30:VYZ@<0/;2`0`2][Jd50;6a
/@<0[Zj^0`2YZJT30:^[Z`80Z:RX0`2VYZH30:2PX0<0W9bL0P2DU9@309:BTP<0S8b<0`29RHT208b<
S0<0RXZ:0`25QHD30820P080O7al0`1mOGd308:2PPP0b>3H/@20P80?0<SPf0003@38h=P30:>SX`<0
JVYZ0P0`<30302/[:`<08R8R0`0T92@202HV9P<09bLW0`1ZJVX308N7Q`80Kfm_0`1jNWX30;Zj^P<0
_;bl0P36a/H30<g=c@<0YJFU0`0Z:RX302LW9`80=CDe0`0b<S8303Ti>@<0BDU90P1OGel306][J`<0
N7Qh0`1iNGT207]kN`<0P8200`25QHD308>3P`80RXZ:0`2<S8`3092@T0<0UIFE1@2HV9P309VIV@<0
WIfM0`2TY:@20:JVYP<0ZJVY0`2`/;030:f][@D0/K6a0`2^[Zh30:VYZ@<0Zj^[0P2XZ:P30:JVYP<0
X:2P0`2LW9`209BDU0<0TY:B0`2<S8`308V9R@80S8b<0`2:RXX308F5Q@<0P8200P1lO7`307emO@<0
PX:22038h=Ra0820P0l0b>3H000=0<SPf0<0Kfm_0`0a<C4202<S8`<09RHV0`0S8b<502@T90<08B4Q
0`0n?Sh309>CT`80M7Ad0`1`L70309fMW@D0_kno0`30`<030<c<c0<0KVi^0`0[:b/503<c<`<0=SHf
0`1;Bd/206=SH`<0Kfm_0`1hN7P307IfMP80OGem0`23Ph<308J6QP<0Q8B40P27QhL9092@T0<0U9BD
0P2IVIT309fMW@<0XJ6Q0`2UYJD20:ZZZP<0[jn_0`2c/k<30;2`/080/K6a0`2d];@30:j^[P<0[:b/
0`2`/;020:VYZ@<0YZJV0`2QXJ4309fMW@80UYJF0`2=SHd308n?S`<0S8b<0P2BTY8308^;R`<0QhN7
0`22PX8207alO0<0PH610`23Ph<80<SPf;40P8203`38h=P000d0b>3H0`1_Kfl3034a<@808b<S0`0V
9RH302<S8`D092@T0`0Q8B4303hn?P<0Ti>C0P1dM7@3071`L0<0WIfM1@2o_kl30<30`0<0c<c<0`1^
KVh302/[:`D0<c<c0`0f=SH304];B`80Hf=S0`1_Kfl307QhN0<0MWIf0P1mOGd308>3P`<0QXJ60`24
Q8@208N7Q`T0T92@0`2DU9@209VIV@<0WIfM0`2QXJ430:FUY@80ZZZZ0`2_[jl30;>c/`<0/;2`0P2a
/K430;Bd]0<0[Zj^0`2/[:`30;2`/080ZJVY0`2VYZH30:6QX@<0WIfM0P2FUYH308f=S@<0Shn?0`2<
S8`209:BTP<0Rh^;0`27QhL308:2PP80O7al0`21PH4308>3P`P0b>3H/@20P80?0<SPf0003@38h=P3
06m_K`<0<C4a0P0S8b<302HV9P<08b<S1@0T92@3024Q8@<0?Shn0`2CTi<207AdM0<0L71`0`2MWId5
0;no_`<0`<300`3<c<`306i^KP<0:b/[1@0c<c<303Hf=P<0Bd];0P1SHf<306m_K`<0N7Qh0`1fMWH2
07emO@<0Ph>30`26QXH308B4Q080QhN72@2@T90309BDU080VIVI0`2MWId30:6QX@<0YJFU0P2ZZZX3
0:n_[`<0/k>c0`2`/;020;6a/@<0];Bd0`2^[Zh30:b/[0<0/;2`0P2YZJT30:JVYP<0XJ6Q0`2MWId2
09JFUP<0SHf=0`2?Shl308b<S080TY:B0`2;Rh/308N7Q`<0PX:20P1lO7`30861P@<0Ph>32038h=Ra
0820P0l0b>3H000=0<SPf0<0?clo0`0^;Rh202`/;0<0:BTY0`0W9bL302XZ:P80:BTY0`0T92@302<S
8`<0LW9b0P2;Rh/3079bLP<0O7al0`33`l<20;Vi^@<0`<300`2j^[X30<;2`P<0?clo0P0Z:RX302`/
;0<0=cLg0`1>CTh2061PH0<0LG5a0`1eMGD307YjNP80P8200`1oOgl30861P@<0QHF50P26QXH308^;
R`<0UIFE0`2DU9@309JFUP80Vi^K0`2SXj<30:VYZ@<0Zj^[0P2^[Zh30;6a/@<0/[:b0`2c/k<20;Zj
^P<0/k>c0`2^[Zh30:ZZZP<0[:b/0P2ZZZX30:^[Z`<0XJ6Q0`2MWId209^KV`<0UYJF0`2CTi<3096A
T@80TY:B0`2<S8`308V9R@<0QHF50P1nOWh30861P@<0QHF52038h=P60820P080H61PZ@20P80?0<SP
f0003@38h=P303lo?`<0;Rh^0P0/;2`302TY:@<09bLW0`0Z:RX202TY:@<092@T0`0S8b<3079bLP80
Rh^;0`1bLW8307alO0<0`l?30P2i^KT30<30`0<0^[Zj0`32`/8303lo?`80:RXZ0`0/;2`303Lg=`<0
CTi>0P1PH603075aL@<0MGEe0`1jNWX20820P0<0Ogmo0`21PH4308F5Q@80QXJ60`2;Rh/309FEU@<0
U9BD0`2FUYH209^KV`<0Xj>S0`2YZJT30:^[Z`80[Zj^0`2a/K430;:b/P<0/k>c0P2j^[X30;>c/`<0
[Zj^0`2ZZZX30:b/[080ZZZZ0`2[Zj/30:6QX@<0WIfM0P2KVi/309JFUP<0Ti>C0`2ATI4209:BTP<0
S8b<0`29RHT308F5Q@80OWin0`21PH4308F5Q@P0b>3H1P20P802061PH:T0P8203`38h=P000d0b>3H
0`0o?cl302h^;P80;2`/0`0Y:BT302LW9`<0:RXZ0P0Y:BT302@T90<08b<S0`1bLW8208^;R`<0LW9b
0`1lO7`30<?3``80^KVi0`30`<030;Zj^P<0`/;20`0o?cl202XZ:P<0;2`/0`0g=cL304i>CP80H61P
0`1aLG4307EeM@<0NWYj0P20P80307moO`<0PH610`25QHD208J6QP<0Rh^;0`2EUID309BDU0<0UYJF
0P2KVi/30:>SX`<0ZJVY0`2[Zj/20:j^[P<0/K6a0`2b/[830;>c/`80^[Zj0`2c/k<30:j^[P<0ZZZZ
0`2/[:`20:ZZZP<0Zj^[0`2QXJ4309fMW@80Vi^K0`2FUYH309>CT`<0TI6A0P2BTY8308b<S0<0RHV9
0`25QHD207inOP<0PH610`25QHD80<SPf0H0P8200P1PH62Y0820P0l0b>3H000=0<SPf0<0CTi>0`0^
;Rh502/[:`<0;Bd]0`0X:2P2034a<@<09RHV0`0X:2P304A4A080UYJF0`1gMgL307AdM0<0Xj>S0P2i
^KT30;bl_0<0^[Zj0`39bLT30:2PX080:2PX0`0`<30303Hf=P<0ADE50P1PH60306i^KPH0N7Qh0P1l
O7`307YjNP<0P8200`25QHD208j>SP<0Shn?0`2FUYH309RHV0<0Vi^K0P2NWYh30:BTY0<0[:b/0`2]
[Jd20:n_[`<0];Bd202b/[830:f][@<0/[:b0`2/[:`30;6a/@80[Jf]0`2[Zj/30:NWY`<0XJ6Q0P2L
W9`609JFUP<0TY:B0P2CTi<308j>SP<0Rh^;0`25QHD208>3P`<0OWin0`22PX880<SPf;40P8203`38
h=P000d0b>3H0`1>CTh302h^;PD0:b/[0`0];Bd302PX:080<C4a0`0V9RH302PX:0<0A4A40P2FUYH3
07MgM`<0M7Ad0`2SXj<20;Vi^@<0_;bl0`2j^[X30<W9b@<0X:2P0P0X:2P3030`<0<0=SHf0`15ADD2
061PH0<0KVi^1P1hN7P207alO0<0NWYj0`20P80308F5Q@80SXj>0`2?Shl309JFUP<0V9RH0`2KVi/2
09jNWP<0Y:BT0`2/[:`30:f][@80[jn_0`2d];@80;:b/P<0[Jf]0`2b/[830:b/[0<0/K6a0P2][Jd3
0:^[Z`<0YjNW0`2QXJ4209bLW0H0UYJF0`2BTY8209>CT`<0SXj>0`2;Rh/308F5Q@80Ph>30`1nOWh3
08:2PPP0b>3H/@20P80?0<SPf0003@38h=P303/k>`<0;Bd]1@0^;Rh302`/;0<0;Rh^0P0[:b/302h^
;P<0:RXZ0`0_;bl206a/K0<0T92@0`1cLg<307YjNP80[jn_0`2c/k<60<;2`P<0dM7A0P1jNWX302<S
8`<0<C4a0`15ADD205aLG0<0JFUY0`1fMWH307UiN@80OGem0`1oOgl308>3P`<0QhN70P2<S8`609>C
T`<0VIVI0`2LW9`20:>SX`<0YZJV0`2ZZZX30:b/[080[jn_1P2b/[830:n_[`80/[:b0`2a/K430:j^
[P<0/K6a0`2`/;020;:b/P<0[:b/0`2WYjL30::RXP80Vi^K0`2JVYX3096AT@<0Ti>C0P2@T90308b<
S0<0QhN70`24Q8@208>3P`<0PX:20`1nOWh80<SPf;40P8203`38h=P000d0b>3H0`0k>c/302d];@D0
;Rh^0`0/;2`302h^;P80:b/[0`0^;Rh302XZ:P<0;bl_0P1/K6`3092@T0<0Lg=c0`1jNWX20:n_[`<0
/k>c1P32`/830=7Ad@80NWYj0`0S8b<3034a<@<0ADE50P1LG5`306UYJ@<0MWIf0`1iNGT207emO@<0
Ogmo0`23Ph<308N7Q`80S8b<1P2CTi<309VIV@<0W9bL0P2SXj<30:JVYP<0ZZZZ0`2/[:`20:n_[`H0
/[:b0`2_[jl20;:b/P<0/K6a0`2^[Zh30;6a/@<0/;2`0P2b/[830:b/[0<0YjNW0`2RXZ8209^KV`<0
VYZJ0`2ATI4309>CT`80T92@0`2<S8`308N7Q`<0Q8B40P23Ph<308:2PP<0OWin2038h=Ra0820P0l0
b>3H000=0<SPf0<0>c/k0`0];Bd502h^;P<0;2`/0`0^;Rh202/[:`<0;Rh^0`0Z:RX302l_;`80K6a/
0`2@T90307=cL`<0NWYj0P2_[jl30;>c/`H0`/;20`3AdM4207YjNP<08b<S0`0a<C4304E5A@80G5aL
0`1YJFT307IfMP<0NGUi0P1mOGd307moO`<0Ph>30`27QhL208b<S0H0Ti>C0`2IVIT309bLW080Xj>S
0`2VYZH30:ZZZP<0[:b/0P2_[jl60;:b/P<0[jn_0P2b/[830;6a/@<0[Zj^0`2a/K430;2`/080/[:b
0`2/[:`30:NWY`<0XZ:R0P2KVi/309ZJVP<0TI6A0`2CTi<2092@T0<0S8b<0`27QhL308B4Q080Ph>3
0`22PX8307inOPP0b>3H/@20P80?0<SPf0003@38h=P30451@@<0;2`/0P0c<c<6030`<0<0;Bd]0P0a
<C4602`/;0<0:RXZ0P0j>SX309VIV@<0M7Ad0`1/K6`20::RXP<0/k>c0`2j^[X30<71`@<0a<C40P3:
b/X304m?C`<0;Bd]0`11@D4205ADE0<0IFEU0`1dM7@307IfMP80Ng]k0`1oOgl30861P@<0RHV90P2=
SHd309:BTPH0UiNG0`2OWil20:2PX0<0YjNW0`2/[:`30:ZZZP80[jn_0`2c/k<30:ZZZP<0[Zj^0P2b
/[830;2`/0<0/[:b0`2][Jd30:j^[PD0[jn_0`2ZZZX30:FUY@80WYjN0`2DU9@609>CT`80TI6A0`2=
SHd308J6QPD0Q8B40`20P80308>3P`P0b>3H/@20P80?0<SPf0003@38h=P30451@@<0;2`/0P0c<c<6
030`<0<0;Bd]0P0a<C4602`/;0<0:RXZ0P0j>SX309VIV@<0M7Ad0`1/K6`20::RXP<0/k>c0`2j^[X3
0<71`@<0a<C40P3:b/X304m?C`<0;Bd]0`11@D4205ADE0<0IFEU0`1dM7@307IfMP80Ng]k0`1oOgl3
0861P@<0RHV90P2=SHd309:BTPH0UiNG0`2OWil20:2PX0<0YjNW0`2/[:`30:ZZZP80[jn_0`2c/k<3
0:ZZZP<0[Zj^0P2b/[830;2`/0<0/[:b0`2][Jd30:j^[PD0[jn_0`2ZZZX30:FUY@80WYjN0`2DU9@6
09>CT`80TI6A0`2=SHd308J6QPD0Q8B40`20P80308>3P`P0b>3H/@20P80?0<SPf0003@38h=P30451
@@<0;2`/0P0c<c<6030`<0<0;Bd]0P0a<C4602`/;0<0:RXZ0P0j>SX309VIV@<0M7Ad0`1/K6`20::R
XP<0/k>c0`2j^[X30<71`@<0a<C40P3:b/X304m?C`<0;Bd]0`11@D4205ADE0<0IFEU0`1dM7@307If
MP80Ng]k0`1oOgl30861P@<0RHV90P2=SHd309:BTPH0UiNG0`2OWil20:2PX0<0YjNW0`2/[:`30:ZZ
ZP80[jn_0`2c/k<30:ZZZP<0[Zj^0P2b/[830;2`/0<0/[:b0`2][Jd30:j^[PD0[jn_0`2ZZZX30:FU
Y@80WYjN0`2DU9@609>CT`80TI6A0`2=SHd308J6QPD0Q8B40`20P80308>3P`P0b>3H/@20P80?0<SP
f0003@38h=P303Ph>0<092@T0P0b<S83030`<0<0:RXZ0`0/;2`502d];@<0;Rh^0`0Z:RX202d];@<0
Lg=c0`2ATI4306=SH`80OGem0`2f][H30:n_[`<0_[jn0`2m_Kd20<S8b0<0]kNg0`0n?Sh30410@080
CTi>0`1SHf<3071`L0<0M7Ad0P1jNWX60861P@<0QhN70P2=SHd309:BTP<0VIVI0`2JVYX309jNWP80
Xj>S0`2WYjL30:RXZ0<0ZZZZ0P2][Jd30:j^[P<0[:b/0`2b/[820:j^[P<0[:b/0`2[Zj/30:JVYP<0
Zj^[0P2`/;030:n_[`<0Zj^[0`2QXJ4209VIV@<0UYJF0`2?Shl308^;R`80TI6A0`2;Rh/308F5Q@<0
PH610P22PX8307emO@<0Ogmo2038h=Ra0820P0l0b>3H000=0<SPf0<0>3Ph0`0T92@2038b<P<0<30`
0`0Z:RX302`/;0D0;Bd]0`0^;Rh302XZ:P80;Bd]0`1cLg<3096AT@<0Hf=S0P1mOGd30;Jf]P<0[jn_
0`2n_[h30;fm_@80b<S80`2g]kL303hn?P<0@4100P1>CTh306=SH`<0L71`0`1dM7@207YjNPH0PH61
0`27QhL208f=S@<0TY:B0`2IVIT309ZJVP<0WYjN0P2SXj<30:NWY`<0Z:RX0`2ZZZX20:f][@<0[Zj^
0`2/[:`30;:b/P80[Zj^0`2/[:`30:^[Z`<0YZJV0`2[Zj/20;2`/0<0[jn_0`2[Zj/30:6QX@80VIVI
0`2FUYH308n?S`<0Rh^;0P2ATI4308^;R`<0QHF50`21PH4208:2PP<0OGem0`1oOgl80<SPf;40P820
3`38h=P000d0b>3H0`0h>3P302@T9080<S8b0`0`<30302XZ:P<0;2`/1@0];Bd302h^;P<0:RXZ0P0]
;Bd307=cL`<0TI6A0`1SHf<207emO@<0][Jf0`2_[jl30;jn_P<0_Kfm0P38b<P30;Ng]`<0?Shn0`10
@40204i>CP<0Hf=S0`1`L70307AdM080NWYj1P21PH4308N7Q`80SHf=0`2BTY8309VIV@<0VYZJ0`2N
WYh20:>SX`<0YjNW0`2XZ:P30:ZZZP80[Jf]0`2^[Zh30:b/[0<0/[:b0P2^[Zh30:b/[0<0Zj^[0`2V
YZH30:^[Z`80/;2`0`2_[jl30:^[Z`<0XJ6Q0P2IVIT309JFUP<0Shn?0`2;Rh/2096AT@<0Rh^;0`25
QHD30861P@80PX:20`1mOGd307moO`P0b>3H/@20P80?0<SPf0003@38h=P3034a<@<0<30`0P0f=SH3
02`/;0<0;Rh^0`0Y:BT2030`<0<0<S8b0`0`<303034a<@80:b/[0`0m?Cd309BDU0<0N7Qh0P1[Jf/6
0:VYZ@<0^KVi0`2n_[h20<30`0<0a/K60`2QXJ4303Ti>@80D51@0`1LG5`306a/K0<0M7Ad0P1kNg/3
07inOP<0PX:21@2<S8`309BDU0<0UiNG0`2LW9`309fMW@80YJFU0`2WYjL30:6QX@<0Z:RX0P2^[Zh3
0:f][@<0Z:RX0`2UYJD20:NWY`<0ZJVY0`2^[Zh30:f][@D0YjNW0`2YZJT30:RXZ0<0Xj>S0P2MWId3
09FEU@<0RHV90`2;Rh/208j>SP<0QXJ60`24Q8@308:2PP80PH611P22PX880<SPf;40P8203`38h=P0
00d0b>3H0`0a<C43030`<080=SHf0`0/;2`302h^;P<0:BTY0P0`<303038b<P<0<30`0`0a<C4202/[
:`<0?Cdm0`2DU9@307QhN080Jf][1P2YZJT30;Vi^@<0_[jn0P30`<030<K6aP<0XJ6Q0`0i>CT2051@
D0<0G5aL0`1/K6`307AdM080Ng]k0`1nOWh308:2PPD0S8b<0`2DU9@309NGU`<0W9bL0`2MWId20:FU
Y@<0YjNW0`2QXJ430:RXZ080[Zj^0`2][Jd30:RXZ0<0YJFU0P2WYjL30:VYZ@<0[Zj^0`2][Jd50:NW
Y`<0ZJVY0`2XZ:P30:>SX`80WIfM0`2EUID308V9R@<0Rh^;0P2>SXh308J6QP<0Q8B40`22PX820861
P@H0PX:22038h=Ra0820P0l0b>3H000=0<SPf0H0;Rh^0P0_;bl302`/;0<0:RXZ0`0/;2`203@d=0<0
<S8b1P0a<C4502`/;0<0IfMW0`2?Shl2069RHP<0Ng]k0`2_[jl30;2`/0<0^KVi0P2o_kl30<K6aP<0
clo?0`27QhL20410@0<0Fe]K0`1YJFT3079bLP80MGEe0`1nOWh608N7Q`80Shn?0`2EUID309RHV0<0
WIfM0`2OWil20:BTY0<0YJFU0`2RXZ830:JVYP80Zj^[0`2VYZH30::RXP<0YZJV0P2TY:@30:JVYP<0
[Jf]0`2YZJT30:f][@80ZJVY0`2UYJD30:^[Z`<0Y:BT0P2UYJD309BDU0<0Rh^;0`29RHT208n?S`<0
Rh^;0`27QhL308:2PP80PH610`20P80308:2PPP0b>3H/@20P80?0<SPf0003@38h=P602h^;P80;bl_
0`0/;2`302XZ:P<0;2`/0P0d=3@3038b<PH0<C4a1@0/;2`306MWI`<0Shn?0P1RHV8307]kN`<0[jn_
0`2`/;030;Vi^@80_kno0`36a/H30<o?c`<0QhN70P10@40305]KF`<0JFUY0`1bLW8207EeM@<0OWin
1P27QhL208n?S`<0UIFE0`2HV9P309fMW@<0WinO0P2TY:@30:FUY@<0XZ:R0`2VYZH20:^[Z`<0YZJV
0`2RXZ830:JVYP80Y:BT0`2VYZH30:f][@<0ZJVY0`2][Jd20:VYZ@<0YJFU0`2[Zj/30:BTY080YJFU
0`2DU9@308^;R`<0RHV90P2?Shl308^;R`<0QhN70`22PX820861P@<0P8200`22PX880<SPf;40P820
3`38h=P000d0b>3H1P0^;Rh202l_;`<0;2`/0`0Z:RX302`/;080=3@d0`0b<S86034a<@D0;2`/0`1W
IfL308n?S`80HV9R0`1kNg/30:n_[`<0/;2`0`2i^KT20;no_`<0a/K60`3?cll308N7Q`80@4100`1K
Fe/306UYJ@<0LW9b0P1eMGD307inOPH0QhN70P2?Shl309FEU@<0V9RH0`2MWId309nOW`80Y:BT0`2U
YJD30::RXP<0YZJV0P2[Zj/30:JVYP<0XZ:R0`2VYZH20:BTY0<0YZJV0`2][Jd30:VYZ@<0[Jf]0P2Y
ZJT30:FUY@<0Zj^[0`2TY:@20:FUY@<0U9BD0`2;Rh/308V9R@80Shn?0`2;Rh/308N7Q`<0PX:20P21
PH430820P0<0PX:22038h=Ra0820P0l0b>3H000=0<SPf0<0;Rh^0`0Z:RX202h^;P<0;Bd]0`0[:b/3
02d];@80=CDe0`0_;bl302h^;P<0;bl_0P0T92@302DU9@<0=3@d0`2>SXh207emO@<0J6QX0`2SXj<6
0;6a/@80][Jf0`2o_kl30<O7a`<0cLg=0P1dM7@304Y:BP<0HF5Q0`1[Jf/207=cL`<0Ng]k0`25QHD3
08N7Q`80T92@0`2GUiL309VIV@<0UiNG0`2JVYX209jNWPH0X:2P0`2MWId209VIV@<0U9BD0`2FUYH3
09RHV080UiNG0`2KVi/309jNWP<0X:2P0`2TY:@20:RXZ0<0YZJV0`2UYJD30:2PX080YJFU0`2KVi/3
08R8R0<0PX:20P26QXH308^;R`<0QXJ60`1nOWh208:2PP<0P8200`26QXH80<SPf;40P8203`38h=P0
00d0b>3H0`0^;Rh302XZ:P80;Rh^0`0];Bd302/[:`<0;Bd]0P0e=CD302l_;`<0;Rh^0`0_;bl202@T
90<09BDU0`0d=3@308j>SP80OGem0`1XJ6P30:>SX`H0/K6a0P2f][H30;no_`<0alO70`3=cLd207Ad
M0<0BTY:0`1QHF4306][J`80Lg=c0`1kNg/308F5Q@<0QhN70P2@T90309NGU`<0VIVI0`2GUiL309ZJ
VP80WYjN1P2PX:0309fMW@80VIVI0`2DU9@309JFUP<0V9RH0P2GUiL309^KV`<0WYjN0`2PX:030:BT
Y080Z:RX0`2VYZH30:FUY@<0X:2P0P2UYJD309^KV`<0R8R80`22PX8208J6QP<0Rh^;0`26QXH307in
OP80PX:20`20P80308J6QPP0b>3H/@20P80?0<SPf0003@38h=P302h^;P<0:RXZ0P0^;Rh302d];@<0
:b/[0`0];Bd203De=@<0;bl_0`0^;Rh302l_;`8092@T0`0U9BD303@d=0<0SXj>0P1mOGd306QXJ0<0
Xj>S1P2a/K420;Jf]P<0_kno0`37alL30<g=c@80M7Ad0`1:BTX3065QH@<0Jf][0P1cLg<307]kN`<0
QHF50`27QhL2092@T0<0UiNG0`2IVIT309NGU`<0VYZJ0P2NWYh60:2PX0<0WIfM0P2IVIT309BDU0<0
UYJF0`2HV9P209NGU`<0Vi^K0`2NWYh30:2PX0<0Y:BT0P2XZ:P30:JVYP<0YJFU0`2PX:020:FUY@<0
Vi^K0`28R8P308:2PP80QXJ60`2;Rh/308J6QP<0OWin0P22PX830820P0<0QXJ62038h=Ra0820P0l0
b>3H000=0<SPf0<0:RXZ200_;bl302`/;0<0<S8b0P0a<C4302l_;`<0;Bd]0`0/;2`202LW9`<09RHV
0`0Q8B4305UIF@80UiNG0`1[Jf/308:2PP<0^;Rh0`2PX:020;:b/P<0]KFe0`2o_kl50<K6aP<0J6QX
0`1EEED306=SH`80LW9b0`1kNg/308B4Q0<0RHV90P2ATI4309>CT`<0VIVI0`2HV9P509JFUP<0UiNG
0`2EUID509>CT`<0SXj>0`2BTY8308j>SP80SHf=0`2>SXh3092@T0<0UiNG0`2HV9P209bLW0<0X:2P
0`2UYJD309bLW080WinO0`2PX:0308Z:RP<0P8200P24Q8@308N7Q`<0QXJ60`22PX8507moO`<0QHF5
2038h=Ra0820P0l0b>3H000=0<SPf0<0:RXZ200_;bl302`/;0<0<S8b0P0a<C4302l_;`<0;Bd]0`0/
;2`202LW9`<09RHV0`0Q8B4305UIF@80UiNG0`1[Jf/308:2PP<0^;Rh0`2PX:020;:b/P<0]KFe0`2o
_kl50<K6aP<0J6QX0`1EEED306=SH`80LW9b0`1kNg/308B4Q0<0RHV90P2ATI4309>CT`<0VIVI0`2H
V9P509JFUP<0UiNG0`2EUID509>CT`<0SXj>0`2BTY8308j>SP80SHf=0`2>SXh3092@T0<0UiNG0`2H
V9P209bLW0<0X:2P0`2UYJD309bLW080WinO0`2PX:0308Z:RP<0P8200P24Q8@308N7Q`<0QXJ60`22
PX8507moO`<0QHF52038h=Ra0820P0l0b>3H000=0<SPf0<0:RXZ200_;bl302`/;0<0<S8b0P0a<C43
02l_;`<0;Bd]0`0/;2`202LW9`<09RHV0`0Q8B4305UIF@80UiNG0`1[Jf/308:2PP<0^;Rh0`2PX:02
0;:b/P<0]KFe0`2o_kl50<K6aP<0J6QX0`1EEED306=SH`80LW9b0`1kNg/308B4Q0<0RHV90P2ATI43
09>CT`<0VIVI0`2HV9P509JFUP<0UiNG0`2EUID509>CT`<0SXj>0`2BTY8308j>SP80SHf=0`2>SXh3
092@T0<0UiNG0`2HV9P209bLW0<0X:2P0`2UYJD309bLW080WinO0`2PX:0308Z:RP<0P8200P24Q8@3
08N7Q`<0QXJ60`22PX8507moO`<0QHF52038h=Ra0820P0l0b>3H000=0<SPf0<0;Rh^0`0_;bl2038b
<P<0<30`0`0/;2`3030`<080;Rh^0`0_;bl603<c<`809bLW0`0S8b<3024Q8@<0;Bd]0P25QHD30861
P@<0Hf=S0`2RXZ830:NWY`80ZJVY0`2`/;030;Jf]P<0a<C40P36a/H30;jn_P<0IVIV0`1EEED206YZ
JP<0N7Qh0`20P80308F5Q@80Rh^;0`2ATI4308f=S@<0TI6A1@2DU9@308j>SP<0SHf=0`2BTY8209JF
UP<0QXJ60`29RHT308:2PP80Ogmo0`24Q8@308^;R`<0Ph>30`2;Rh/2096AT@<0Vi^K0`2HV9P309JF
UP80TY:B0`2DU9@308f=S@<0N7Qh0P1oOgl308F5Q@<0Ph>30`21PH4207moO`<0P8200`2:RXX80<SP
f;40P8203`38h=P000d0b>3H0`0^;Rh302l_;`80<S8b0`0`<30302`/;0<0<30`0P0^;Rh302l_;`H0
<c<c0P0W9bL302<S8`<08B4Q0`0];Bd208F5Q@<0PH610`1SHf<30::RXP<0YjNW0P2YZJT30;2`/0<0
][Jf0`34a<@20<K6aP<0_[jn0`1VIVH305EEE@80JVYZ0`1hN7P30820P0<0QHF50P2;Rh/3096AT@<0
SHf=0`2ATI4509BDU0<0SXj>0`2=SHd309:BTP80UYJF0`26QXH308V9R@<0PX:20P1oOgl308B4Q0<0
Rh^;0`23Ph<308^;R`80TI6A0`2KVi/309RHV0<0UYJF0P2BTY8309BDU0<0SHf=0`1hN7P207moO`<0
QHF50`23Ph<30861P@80Ogmo0`20P80308Z:RPP0b>3H/@20P80?0<SPf0003@38h=P302h^;P<0;bl_
0P0b<S83030`<0<0;2`/0`0`<30202h^;P<0;bl_1P0c<c<202LW9`<08b<S0`0Q8B4302d];@80QHF5
0`21PH4306=SH`<0XZ:R0`2WYjL20:VYZ@<0/;2`0`2f][H30<C4a080a/K60`2n_[h306IVIP<0EEEE
0P1ZJVX307QhN0<0P8200`25QHD208^;R`<0TI6A0`2=SHd3096AT@D0U9BD0`2>SXh308f=S@<0TY:B
0P2FUYH308J6QP<0RHV90`22PX8207moO`<0Q8B40`2;Rh/308>3P`<0Rh^;0P2ATI4309^KV`<0V9RH
0`2FUYH209:BTP<0U9BD0`2=SHd307QhN080Ogmo0`25QHD308>3P`<0PH610P1oOgl30820P0<0RXZ:
2038h=Ra0820P0l0b>3H000=0<SPf0<0:BTY0`0^;Rh502/[:`<0;2`/0`0a<C4202`/;0<0;bl_0`0e
=CD3030`<0809bLW0`0V9RH302<S8`<08B4Q0P17AdL309:BTP<0I6AT0`20P8030;jn_P80X:2P0`2]
[Jd30;Bd]0<0_kno0P37alL30<?3``<0_;bl0`1TI6@206IVIP<0M7Ad0`1nOWh308F5Q@80RHV91P2;
Rh/308n?S`<0T92@0P2>SXh3096AT@<0Shn?0`2>SXh208b<S0<0O7al0`1eMGD307]kN`80IVIV0`23
Ph<308R8R0<0LG5a0`1kNg/206a/K0<0W9bL0`2EUID30:>SX`80X:2P0`2CTi<308>3P`<0NGUi0P1j
NWX30861P@<0PX:21@21PH430820P0<0T92@2038h=R20820P0P0X:2P9`20P80?0<SPf0003@38h=P3
02TY:@<0;Rh^1@0[:b/302`/;0<0<C4a0P0/;2`302l_;`<0=CDe0`0`<30202LW9`<09RHV0`0S8b<3
024Q8@80AdM70`2BTY8306ATI0<0P8200`2n_[h20:2PX0<0[Jf]0`2d];@30;no_`80alO70`33`l<3
0;bl_0<0I6AT0P1VIVH307AdM0<0OWin0`25QHD208V9R@H0Rh^;0`2?Shl3092@T080SXj>0`2ATI43
08n?S`<0SXj>0P2<S8`307alO0<0MGEe0`1kNg/206IVIP<0Ph>30`28R8P3075aL@<0Ng]k0P1/K6`3
09bLW0<0UIFE0`2SXj<20:2PX0<0Ti>C0`23Ph<307UiN@80NWYj0`21PH4308:2PPD0PH610`20P803
092@T0P0b>3HPP20P8080:2PX2L0P8203`38h=P000d0b>3H0`0[:b/302HV9P80:b/[1P0_;bl302h^
;P80<30`0`0/;2`3030`<0D0<C4a0`0T92@302HV9PD08b<S0`1bLW8308F5Q@<0GUiN0`2b/[820;Ng
]`<0YJFU0`2`/;030;Zj^P80`l?30`39bLT30<71`@<0]kNg0P1XJ6P306YZJP<0NGUi0`1oOgl208:2
PP<0Q8B40`22PX8308j>SP<0Shn?1@2>SXh308B4Q0<0MgMg0P1nOWh307YjNP<0J6QX0`1hN7P206YZ
JP<0QXJ60`2?Shl308b<S0<0WIfM0P2?Shl30:FUY@<0/;2`1@2[Zj/309fMW@<0RXZ:0`1nOWh207al
O0<0N7Qh0`1nOWh307moO`80PX:20`24Q8@3096AT@P0b>3HS@20P803061PH240P8203`38h=P000d0
b>3H0`0[:b/302HV9P80:b/[1P0_;bl302h^;P80<30`0`0/;2`3030`<0D0<C4a0`0T92@302HV9PD0
8b<S0`1bLW8308F5Q@<0GUiN0`2b/[820;Ng]`<0YJFU0`2`/;030;Zj^P80`l?30`39bLT30<71`@<0
]kNg0P1XJ6P306YZJP<0NGUi0`1oOgl208:2PP<0Q8B40`22PX8308j>SP<0Shn?1@2>SXh308B4Q0<0
MgMg0P1nOWh307YjNP<0J6QX0`1hN7P206YZJP<0QXJ60`2?Shl308b<S0<0WIfM0P2?Shl30:FUY@<0
/;2`1@2[Zj/309fMW@<0RXZ:0`1nOWh207alO0<0N7Qh0`1nOWh307moO`80PX:20`24Q8@3096AT@P0
b>3HS@20P803061PH240P8203`38h=P000d0b>3H0`0[:b/302HV9P80:b/[1P0_;bl302h^;P80<30`
0`0/;2`3030`<0D0<C4a0`0T92@302HV9PD08b<S0`1bLW8308F5Q@<0GUiN0`2b/[820;Ng]`<0YJFU
0`2`/;030;Zj^P80`l?30`39bLT30<71`@<0]kNg0P1XJ6P306YZJP<0NGUi0`1oOgl208:2PP<0Q8B4
0`22PX8308j>SP<0Shn?1@2>SXh308B4Q0<0MgMg0P1nOWh307YjNP<0J6QX0`1hN7P206YZJP<0QXJ6
0`2?Shl308b<S0<0WIfM0P2?Shl30:FUY@<0/;2`1@2[Zj/309fMW@<0RXZ:0`1nOWh207alO0<0N7Qh
0`1nOWh307moO`80PX:20`24Q8@3096AT@P0b>3HS@20P803061PH240P8203`38h=P000d0b>3H0`0Z
:RX302DU9@80:2PX0`0a<C43038b<P<0<30`0P0n?Sh303<c<`<0<30`0`0a<C4203Lg=`<0;Bd]0`0V
9RH302<S8`80:2PX0`0l?3`3096AT@<0IfMW0`1nOWh20<O7a`<0XJ6Q0`2WYjL30;Bd]080^k^k0`38
b<P30<K6aP<0`L710P2e]KD306QXJ0<0Lg=c0`1kNg/207inOP<0P8200`1nOWh308n?S`<0SXj>0P2<
S8`30861P@<0Lg=c0`1WIfL205QHF0<0Kfm_0`22PX8308b<S080VYZJ0`2PX:030:b/[0<0^;Rh0`2o
_kl20<71`@<0]KFe0`2XZ:P309>CT`80Rh^;0`1gMgL307moO`<0PX:20P1jNWX307IfMP<0NWYj0`22
PX820861P@<0Ph>30`2DU9@80<SPf;40P8203`38h=P000d0b>3H0`0Z:RX302DU9@80:2PX0`0a<C43
038b<P<0<30`0P0n?Sh303<c<`<0<30`0`0a<C4203Lg=`<0;Bd]0`0V9RH302<S8`80:2PX0`0l?3`3
096AT@<0IfMW0`1nOWh20<O7a`<0XJ6Q0`2WYjL30;Bd]080^k^k0`38b<P30<K6aP<0`L710P2e]KD3
06QXJ0<0Lg=c0`1kNg/207inOP<0P8200`1nOWh308n?S`<0SXj>0P2<S8`30861P@<0Lg=c0`1WIfL2
05QHF0<0Kfm_0`22PX8308b<S080VYZJ0`2PX:030:b/[0<0^;Rh0`2o_kl20<71`@<0]KFe0`2XZ:P3
09>CT`80Rh^;0`1gMgL307moO`<0PX:20P1jNWX307IfMP<0NWYj0`22PX820861P@<0Ph>30`2DU9@8
0<SPf;40P8203`38h=P000d0b>3H0`0Z:RX302DU9@80:2PX0`0a<C43038b<P<0<30`0P0n?Sh303<c
<`<0<30`0`0a<C4203Lg=`<0;Bd]0`0V9RH302<S8`80:2PX0`0l?3`3096AT@<0IfMW0`1nOWh20<O7
a`<0XJ6Q0`2WYjL30;Bd]080^k^k0`38b<P30<K6aP<0`L710P2e]KD306QXJ0<0Lg=c0`1kNg/207in
OP<0P8200`1nOWh308n?S`<0SXj>0P2<S8`30861P@<0Lg=c0`1WIfL205QHF0<0Kfm_0`22PX8308b<
S080VYZJ0`2PX:030:b/[0<0^;Rh0`2o_kl20<71`@<0]KFe0`2XZ:P309>CT`80Rh^;0`1gMgL307mo
O`<0PX:20P1jNWX307IfMP<0NWYj0`22PX820861P@<0Ph>30`2DU9@80<SPf;40P8203`38h=P000d0
b>3H1P0_;bl202XZ:P<0=3@d0`0l?3`302`/;080=cLg0`0a<C4602XZ:P80<S8b0`0X:2P302TY:@<0
8b<S0P0U9BD303@d=0<0GEeM0`2>SXh305IFEP80X:2P0`2/[:`309bLW0<0];Bd0P2e]KD30<;2`PH0
a/K60P31`L430;Zj^P<0MGEe0`1dM7@207QhN0<0MgMg0`1nOWh608N7Q`80OGem0`1UIFD304E5A@<0
DU9B0P1`L70307IfMP<0P8200`1/K6`206EUI@<0QhN70`2g]kL30<G5a@<0bl_;0P3?cll30<W9b@<0
[Jf]0`2;Rh/209>CT`<0MGEe0`1jNWX307alO080Lg=c0`1gMgL307]kN`<0OWin0P23Ph<308J6QP<0
T92@2038h=Ra0820P0l0b>3H000=0<SPf0H0;bl_0P0Z:RX303@d=0<0?3`l0`0/;2`203Lg=`<0<C4a
1P0Z:RX2038b<P<0:2PX0`0Y:BT302<S8`809BDU0`0d=3@305eMG@<0SXj>0`1FEUH20:2PX0<0[:b/
0`2LW9`30;Bd]080]KFe0`32`/860<K6aP80`L710`2j^[X307EeM@<0M7Ad0P1hN7P307MgM`<0OWin
1P27QhL207emO@<0IFEU0`15ADD3059BDP80L71`0`1fMWH30820P0<0K6a/0P1UIFD308N7Q`<0]kNg
0`35aLD30<_;b`80clo?0`39bLT30:f][@<0Rh^;0P2CTi<307EeM@<0NWYj0`1lO7`207=cL`<0MgMg
0`1kNg/307inOP80Ph>30`26QXH3092@T0P0b>3H/@20P80?0<SPf0003@38h=P602l_;`80:RXZ0`0d
=3@303`l?0<0;2`/0P0g=cL3034a<@H0:RXZ0P0b<S8302PX:0<0:BTY0`0S8b<202DU9@<0=3@d0`1M
GEd308j>SP<0EUIF0P2PX:030:b/[0<0W9bL0`2d];@20;Fe]@<0`/;21P36a/H20<71`@<0^[Zj0`1e
MGD307AdM080N7Qh0`1gMgL307inOPH0QhN70P1mOGd306EUI@<0ADE50`1BDU82071`L0<0MWIf0`20
P80306a/K080IFEU0`27QhL30;Ng]`<0aLG50`3;bl/20<o?c`<0bLW90`2][Jd308^;R`80Ti>C0`1e
MGD307YjNP<0O7al0P1cLg<307MgM`<0Ng]k0`1nOWh208>3P`<0QXJ60`2@T9080<SPf;40P8203`38
h=P000d0b>3H0`0h>3P302PX:080:RXZ0`0h>3P306IVIP<0;Rh^0P0a<C43038b<P<0:b/[0`0];Bd2
03De=@<0:b/[0`0Z:RX302LW9`80:RXZ1P0/;2`307EeM@<0IFEU0P1WIfL30:FUY@<0U9BD0`2QXJ42
0:b/[0<0^KVi0`33`l<30<O7a`80aLG50`32`/830;fm_@<0LG5a0P1_Kfl307MgM`<0P8200`1fMWH3
07=cL`80IVIV0`1:BTX302h^;P<0B4Q80P1XJ6P307MgM`<0EUIF0`0m?Cd20410@0<0A4A40`1^KVh3
0<71`@<0c<c<0P3?cll30<W9b@<0_kno0`2KVi/2071`L0<0J6QX0`1mOGd306UYJ@80LW9b0`1iNGT3
07=cL`<0Ogmo0P26QXH308Z:RP<0UIFE2038h=Qj0820P080H61P=@20P80?0<SPf0003@38h=P303Ph
>0<0:2PX0P0Z:RX303Ph>0<0IVIV0`0^;Rh2034a<@<0<S8b0`0[:b/302d];@80=CDe0`0[:b/302XZ
:P<09bLW0P0Z:RX602`/;0<0MGEe0`1UIFD206MWI`<0YJFU0`2DU9@30:6QX@80[:b/0`2i^KT30<?3
``<0alO70P35aLD30<;2`P<0_Kfm0`1aLG4206m_K`<0MgMg0`20P80307IfMP<0Lg=c0P1VIVH304Y:
BP<0;Rh^0`18B4P206QXJ0<0MgMg0`1FEUH303dm?@80@4100`14A4@306i^KP<0`L710`3<c<`20<o?
c`<0bLW90`2o_kl309^KV`80L71`0`1XJ6P307emO@<0JFUY0P1bLW8307UiN@<0Lg=c0`1oOgl208J6
QP<0RXZ:0`2EUID80<SPf7X0P8200P1PH60e0820P0l0b>3H000=0<SPf0<0<S8b0`0Z:RX202PX:0<0
Bd];0`1]KFd303Lg=`80:b/[0`0Z:RX602/[:`80=cLg1P0X:2P302h^;PD09RHV0`0X:2P304];B`<0
Ogmo0P1PH603096AT@<0^KVi0`2MWId209RHV0<0Z:RX0`2e]KD30<?3``80b/[:0`35aLD30<?3``<0
_;bl0P1^KVh306][J`<0Kfm_0`1OGel3055AD@80@d=30`0a<C4303<c<`<0CDe=0P1aLG43061PH0<0
@4100`1MGEd205IFEP<0F5QH0`0m?Cd308:2PP<0dM7A0P3>c/h30<g=c@<0aLG50`2CTi<204i>CPH0
Jf][0`1SHf<5071`L0<0MgMg0`1mOGd208F5Q@<0R8R80`2EUID80<SPf;40P8203`38h=P000d0b>3H
0`0b<S8302XZ:P80:2PX0`1;Bd/306e]K@<0=cLg0P0[:b/302XZ:PH0:b/[0P0g=cL602PX:0<0;Rh^
1@0V9RH302PX:0<0Bd];0`1oOgl2061PH0<0TI6A0`2i^KT309fMW@80V9RH0`2XZ:P30;Fe]@<0`l?3
0P3:b/X30<G5a@<0`l?30`2l_;`206i^KP<0Jf][0`1_Kfl305mOG`<0DE5A0P13@d<3034a<@<0<c<c
0`1=CDd2075aL@<0H61P0`10@40305eMG@80EUIF0`1HF5P303dm?@<0PX:20`3AdM420<k>cP<0cLg=
0`35aLD309>CT`80CTi>1P1[Jf/306=SH`D0L71`0`1gMgL307emO@80QHF50`28R8P309FEU@P0b>3H
/@20P80?0<SPf0003@38h=P3038b<P<0:RXZ0P0X:2P304];B`<0KFe]0`0g=cL202/[:`<0:RXZ1P0[
:b/203Lg=`H0:2PX0`0^;Rh502HV9P<0:2PX0`1;Bd/307moO`80H61P0`2ATI430;Vi^@<0WIfM0P2H
V9P30:RXZ0<0]KFe0`33`l<20<[:bP<0aLG50`33`l<30;bl_080KVi^0`1[Jf/306m_K`<0GemO0`1A
DE4204=3@`<0<C4a0`0c<c<304e=C@80LG5a0`1PH6030410@0<0GEeM0P1FEUH305QHF0<0?Cdm0`22
PX830=7Ad@80c/k>0`3=cLd30<G5a@<0Ti>C0P1>CTh606][J`<0Hf=S1@1`L70307MgM`<0OGem0P25
QHD308R8R0<0UIFE2038h=Ra0820P0l0b>3H000=0<SPf0<0;Rh^0`0`<30202LW9`<0J6QX0`1@D503
03Hf=P80:b/[0`0V9RH302`/;0<0;Rh^0P0e=CD302l_;`<0:RXZ0`0e=CD203<c<`<0:b/[0`0o?cl3
03Ti>@<0LG5a0P2=SHd3069RHP<0_;bl0`2b/[820:j^[P<0][Jf1P2h^;P20<[:bP<0bLW90`38b<P3
0<C4a080];Bd0`1IFET305mOG`<0DU9B0`0l?3`203<c<`<0;Rh^0`0a<C4304E5A@80IfMW0`0h>3P3
05UIF@<0B4Q80P0Y:BT304Y:BP<0DE5A0`1;Bd/30<W9b@80`l?30`34a<@30:^[Z`<0IVIV0P16ATH3
07]kN`<0EUIF0`1bLW8207IfMP<0LW9b0`1oOgl308>3P`80RHV90`2=SHd3092@T0P0b>3H;020P803
0:2PX4d0P8200`2PX:030820P0<0X:2P;020P80?0<SPf0003@38h=P302h^;P<0<30`0P0W9bL306QX
J0<0D51@0`0f=SH202/[:`<09RHV0`0/;2`302h^;P80=CDe0`0_;bl302XZ:P<0=CDe0P0c<c<302/[
:`<0?clo0`0i>CT3075aL@80SHf=0`1RHV830;bl_0<0/[:b0P2^[Zh30;Jf]PH0^;Rh0P3:b/X30<W9
b@<0b<S80`34a<@20;Bd]0<0FEUI0`1OGel3059BDP<0?3`l0P0c<c<302h^;P<0<C4a0`15ADD206MW
I`<0>3Ph0`1IFET304Q8B080:BTY0`1:BTX3055AD@<0Bd];0`39bLT20<?3``<0a<C40`2[Zj/306IV
IP80ATI60`1kNg/305IFEP<0LW9b0P1fMWH3079bLP<0Ogmo0`23Ph<208V9R@<0SHf=0`2@T9080<SP
f2`0P8200`2PX:1=0820P0<0X:2P0`20P8030:2PX2`0P8203`38h=P000d0b>3H0`0^;Rh3030`<080
9bLW0`1XJ6P3051@D0<0=SHf0P0[:b/302HV9P<0;2`/0`0^;Rh203De=@<0;bl_0`0Z:RX303De=@80
<c<c0`0[:b/303lo?`<0>CTi0`1aLG4208f=S@<0HV9R0`2l_;`30;:b/P80[Zj^0`2f][H60;Rh^080
b/[:0`39bLT30<S8b0<0a<C40P2d];@305UIF@<0GemO0`1BDU8303`l?080<c<c0`0^;Rh3034a<@<0
ADE50P1WIfL303Ph>0<0FEUI0`18B4P202TY:@<0BTY:0`1ADE4304];B`<0bLW90P33`l<30<C4a0<0
Zj^[0`1VIVH204I6AP<0Ng]k0`1FEUH3079bLP80MWIf0`1bLW8307moO`<0Ph>30P29RHT308f=S@<0
T92@2038h=P/0820P0<0X:2PC@20P8030:2PX0<0P8200`2PX:0/0820P0l0b>3H000=0<SPf0<0;bl_
0`0`<30202h^;P<0MGEe0`0f=SH502h^;P<0:b/[0`0/;2`302h^;P80=CDe0`0l?3`303<c<`<0E5AD
0P19BDT302`/;0<08R8R0`0O7al303Ph>080V9RH0`1`L70307emO@<0`L710P2UYJD30:f][@<0/[:b
0`2d];@20;Zj^P<0c<c<0`34a<@30<?3``80a<C40`2UYJD304m?C`<0EeMG0`1;Bd/203`l?0<0:b/[
0`0/;2`303Hf=P80B4Q80`0`<30303`l?0<0;bl_0P0S8b<304];B`<0ATI60`1gMgL30<O7a`80^k^k
0`2TY:@306QXJ0<0<C4a0P0j>SX304Q8B0<0CTi>1@1lO7`307QhN0<0P8200`27QhL208^;R`<0TI6A
0`2EUID80<SPf2@0P8200`1PH62:0820P0l0b>3H000=0<SPf0<0;bl_0`0`<30202h^;P<0MGEe0`0f
=SH502h^;P<0:b/[0`0/;2`302h^;P80=CDe0`0l?3`303<c<`<0E5AD0P19BDT302`/;0<08R8R0`0O
7al303Ph>080V9RH0`1`L70307emO@<0`L710P2UYJD30:f][@<0/[:b0`2d];@20;Zj^P<0c<c<0`34
a<@30<?3``80a<C40`2UYJD304m?C`<0EeMG0`1;Bd/203`l?0<0:b/[0`0/;2`303Hf=P80B4Q80`0`
<30303`l?0<0;bl_0P0S8b<304];B`<0ATI60`1gMgL30<O7a`80^k^k0`2TY:@306QXJ0<0<C4a0P0j
>SX304Q8B0<0CTi>1@1lO7`307QhN0<0P8200`27QhL208^;R`<0TI6A0`2EUID80<SPf2@0P8200`1P
H62:0820P0l0b>3H000=0<SPf0<0;bl_0`0`<30202h^;P<0MGEe0`0f=SH502h^;P<0:b/[0`0/;2`3
02h^;P80=CDe0`0l?3`303<c<`<0E5AD0P19BDT302`/;0<08R8R0`0O7al303Ph>080V9RH0`1`L703
07emO@<0`L710P2UYJD30:f][@<0/[:b0`2d];@20;Zj^P<0c<c<0`34a<@30<?3``80a<C40`2UYJD3
04m?C`<0EeMG0`1;Bd/203`l?0<0:b/[0`0/;2`303Hf=P80B4Q80`0`<30303`l?0<0;bl_0P0S8b<3
04];B`<0ATI60`1gMgL30<O7a`80^k^k0`2TY:@306QXJ0<0<C4a0P0j>SX304Q8B0<0CTi>1@1lO7`3
07QhN0<0P8200`27QhL208^;R`<0TI6A0`2EUID80<SPf2@0P8200`1PH62:0820P0l0b>3H000=0<SP
f0<0;2`/0`1?Cdl203/k>`<0MgMg0`0X:2P3038b<P80:RXZ0`0X:2P302TY:@<0;bl_0P1VIVH3071`
L0<0GUiN0`11@D4202LW9`<0:b/[0`0T92@302HV9P<08R8R0P1WIfL309VIV@<0HV9R0`2[Zj/20;Zj
^P<0YZJV0`2/[:`30;>c/`80^[Zj1P38b<P30<;2`P80_;bl0`33`l<309bLW0<0AdM70`1:BTX20410
@0<0=CDe0`0a<C45030`<0<0<c<c0`0b<S8302h^;P80;Bd]0`0b<S8303`l?0<0HV9R0`2LW9`208J6
QP<0D51@0`0];Bd302/[:`809bLW0`0_;bl305mOG`<0Ph>30P24Q8@307moO`<0PX:20`29RHT208b<
S0<0TY:B0`2FUYH80<SPf;40P8203`38h=P000d0b>3H0`0/;2`304m?C`80>c/k0`1gMgL302PX:0<0
<S8b0P0Z:RX302PX:0<0:BTY0`0_;bl206IVIP<0L71`0`1NGUh30451@@809bLW0`0[:b/302@T90<0
9RHV0`0R8R8206MWI`<0VIVI0`1RHV830:^[Z`80^[Zj0`2VYZH30:b/[0<0/k>c0P2j^[X60<S8b0<0
`/;20P2l_;`30<?3``<0W9bL0`17AdL304Y:BP80@4100`0e=CD3034a<@D0<30`0`0c<c<3038b<P<0
;Rh^0P0];Bd3038b<P<0?3`l0`1RHV8309bLW080QXJ60`1@D50302d];@<0:b/[0P0W9bL302l_;`<0
GemO0`23Ph<208B4Q0<0Ogmo0`22PX8308V9R@80S8b<0`2BTY8309JFUPP0b>3H/@20P80?0<SPf000
3@38h=P304=3@`<0@4100P0e=CD306ATI0<092@T0`0Y:BT502DU9@<0:BTY0`1SHf<207AdM0<0FUYJ
0`0];Bd302@T9080:RXZ0`0a<C4602PX:0<08R8R0P0/;2`3092@T0<0Ogmo0`1iNGT20;bl_0<0ZZZZ
0`2/[:`30;2`/080][Jf0`33`l<30<S8b0<0`L710P2l_;`30;Vi^@<0`L710`2LW9`30492@P80ATI6
0`0n?Sh303Lg=`P0=CDe0`0d=3@3034a<@80;Rh^0`0_;bl3034a<@<0>CTi0`1@D50203hn?P<0;bl_
0`0[:b/302XZ:P80;Bd]0`1IFET30820P0<0QHF50P21PH4307emO@<0PX:20`2;Rh/208j>SP<0Ti>C
0`2JVYX80<SPf640P8200`2PX:1=0820P0l0b>3H000=0<SPf0<0@d=30`10@40203De=@<0I6AT0`0T
92@302TY:@D09BDU0`0Y:BT306=SH`80M7Ad0`1JFUX302d];@<092@T0P0Z:RX3034a<@H0:2PX0`0R
8R8202`/;0<0T92@0`1oOgl307UiN@80_;bl0`2ZZZX30:b/[0<0/;2`0P2f][H30<?3``<0b<S80`31
`L420;bl_0<0^KVi0`31`L4309bLW0<0@T920P16ATH303hn?P<0=cLg200e=CD303@d=0<0<C4a0P0^
;Rh302l_;`<0<C4a0`0i>CT3051@D080?Shn0`0_;bl302/[:`<0:RXZ0P0];Bd305UIF@<0P8200`25
QHD20861P@<0OGem0`22PX8308^;R`80SXj>0`2CTi<309ZJVPP0b>3HH@20P8030:2PX4d0P8203`38
h=P000d0b>3H0`13@d<30410@080=CDe0`1TI6@302@T90<0:BTY1@0U9BD302TY:@<0Hf=S0P1dM7@3
05YJFP<0;Bd]0`0T92@202XZ:P<0<C4a1P0X:2P3028R8P80;2`/0`2@T90307moO`<0NGUi0P2l_;`3
0:ZZZP<0[:b/0`2`/;020;Jf]P<0`l?30`38b<P30<71`@80_;bl0`2i^KT30<71`@<0W9bL0`12@T82
04I6AP<0?Shn0`0g=cL803De=@<0=3@d0`0a<C4202h^;P<0;bl_0`0a<C4303Ti>@<0D51@0P0n?Sh3
02l_;`<0:b/[0`0Z:RX202d];@<0FEUI0`20P80308F5Q@80PH610`1mOGd308:2PP<0Rh^;0P2>SXh3
09>CT`<0VYZJ2038h=QQ0820P0<0X:2PC@20P80?0<SPf0003@38h=P304I6AP<0:BTY0P0i>CT305YJ
FP<08b<S0`0V9RH202PX:0<0;bl_0`1=CDd307AdM080A4A40`0X:2P602d];@80;bl_0`0^;Rh302HV
9P<09bLW1@0T92@3055AD@<0WIfM0`1^KVh208j>SP<0_;bl0`2WYjL30:j^[P80/k>c0`31`L430<W9
b@<0a/K60P2k^k/30;Rh^0<0/k>c0`36a/H309RHV080BDU90`1CDe<304e=C@<0@d=30P0g=cL30410
@0<0=cLg0`0f=SH203@d=0<0<S8b0`0c<c<303@d=0D0<C4a0`0/;2`302PX:0<0>CTi0P1?Cdl308B4
Q0<0QXJ60`1lO7`20861P@<0O7al0`26QXH308b<S080TY:B0`2KVi/309bLW0P0b>3HH@20P803061P
H080X:2PB`20P80?0<SPf0003@38h=P304I6AP<0:BTY0P0i>CT305YJFP<08b<S0`0V9RH202PX:0<0
;bl_0`1=CDd307AdM080A4A40`0X:2P602d];@80;bl_0`0^;Rh302HV9P<09bLW1@0T92@3055AD@<0
WIfM0`1^KVh208j>SP<0_;bl0`2WYjL30:j^[P80/k>c0`31`L430<W9b@<0a/K60P2k^k/30;Rh^0<0
/k>c0`36a/H309RHV080BDU90`1CDe<304e=C@<0@d=30P0g=cL30410@0<0=cLg0`0f=SH203@d=0<0
<S8b0`0c<c<303@d=0D0<C4a0`0/;2`302PX:0<0>CTi0P1?Cdl308B4Q0<0QXJ60`1lO7`20861P@<0
O7al0`26QXH308b<S080TY:B0`2KVi/309bLW0P0b>3HH@20P803061PH080X:2PB`20P80?0<SPf000
3@38h=P304I6AP<0:BTY0P0i>CT305YJFP<08b<S0`0V9RH202PX:0<0;bl_0`1=CDd307AdM080A4A4
0`0X:2P602d];@80;bl_0`0^;Rh302HV9P<09bLW1@0T92@3055AD@<0WIfM0`1^KVh208j>SP<0_;bl
0`2WYjL30:j^[P80/k>c0`31`L430<W9b@<0a/K60P2k^k/30;Rh^0<0/k>c0`36a/H309RHV080BDU9
0`1CDe<304e=C@<0@d=30P0g=cL30410@0<0=cLg0`0f=SH203@d=0<0<S8b0`0c<c<303@d=0D0<C4a
0`0/;2`302PX:0<0>CTi0P1?Cdl308B4Q0<0QXJ60`1lO7`20861P@<0O7al0`26QXH308b<S080TY:B
0`2KVi/309bLW0P0b>3HH@20P803061PH080X:2PB`20P80?0<SPf0003@38h=P302l_;`<0;2`/0P0j
>SX305ADE0<0:RXZ0`0W9bL202PX:0<0@4100`1UIFD304m?C`809bLW1P0];Bd302h^;PD0;Bd]0`0/
;2`302<S8`<0?Shn0P0U9BD302<S8`<0O7al0`2<S8`206IVIP<0Zj^[0`2d];@30:NWY`80[:b/0`2k
^k/30<C4a0<0bLW90P30`<030;6a/@<0Zj^[0`2d];@30<K6aP80XZ:R0`1DE5@3061PH0<0GUiN0P1R
HV8305YJFPH0Bd];0P1@D5030451@@<0;bl_0`1ADE43065QH@80=SHf1P13@d<306][J`80M7Ad0`1U
IFD307alO0P0M7Ad0`20P80308f=S@80VIVI0`2NWYh309nOW`P0b>3H;`20P8030:2PX380P8200P1P
H60O0820P0<0H61P:@20P80?0<SPf0003@38h=P302l_;`<0;2`/0P0j>SX305ADE0<0:RXZ0`0W9bL2
02PX:0<0@4100`1UIFD304m?C`809bLW1P0];Bd302h^;PD0;Bd]0`0/;2`302<S8`<0?Shn0P0U9BD3
02<S8`<0O7al0`2<S8`206IVIP<0Zj^[0`2d];@30:NWY`80[:b/0`2k^k/30<C4a0<0bLW90P30`<03
0;6a/@<0Zj^[0`2d];@30<K6aP80XZ:R0`1DE5@3061PH0<0GUiN0P1RHV8305YJFPH0Bd];0P1@D503
0451@@<0;bl_0`1ADE43065QH@80=SHf1P13@d<306][J`80M7Ad0`1UIFD307alO0P0M7Ad0`20P803
08f=S@80VIVI0`2NWYh309nOW`P0b>3H;`20P8030:2PX380P8200P1PH60O0820P0<0H61P:@20P80?
0<SPf0003@38h=P302l_;`<0;2`/0P0j>SX305ADE0<0:RXZ0`0W9bL202PX:0<0@4100`1UIFD304m?
C`809bLW1P0];Bd302h^;PD0;Bd]0`0/;2`302<S8`<0?Shn0P0U9BD302<S8`<0O7al0`2<S8`206IV
IP<0Zj^[0`2d];@30:NWY`80[:b/0`2k^k/30<C4a0<0bLW90P30`<030;6a/@<0Zj^[0`2d];@30<K6
aP80XZ:R0`1DE5@3061PH0<0GUiN0P1RHV8305YJFPH0Bd];0P1@D5030451@@<0;bl_0`1ADE43065Q
H@80=SHf1P13@d<306][J`80M7Ad0`1UIFD307alO0P0M7Ad0`20P80308f=S@80VIVI0`2NWYh309nO
W`P0b>3H;`20P8030:2PX380P8200P1PH60O0820P0<0H61P:@20P80?0<SPf0003@38h=P302h^;P<0
:BTY0P0i>CT304a<C0<09RHV0`0X:2P202TY:@<0Cdm?0`1XJ6P303@d=080:2PX0`0V9RH302/[:`<0
;bl_0P0X:2P302/[:`<0;Rh^0`1ADE4303hn?P80820P0`0S8b<303dm?@<0U9BD0P1fMWH307YjNP<0
^[Zj1@2ZZZX30;6a/@<0_Kfm1@33`l<30:n_[`<0XZ:R0`2YZJT30;Rh^080alO70`2][Jd306YZJP<0
K6a/1@1aLG4307EeM@<0N7Qh0P1kNg/3079bLP<0@4100`22PX8309BDU080LG5a0`1eMGD3069RHP<0
JVYZ0P1eMGD306EUI@<0JVYZ0`1PH60206IVIP<0KFe]0`27QhL309bLW080WIfM0`2QXJ430:BTY0P0
b>3H;`20P803061PH7l0P8203`38h=P000d0b>3H0`0^;Rh302TY:@80>CTi0`1<C4`302HV9P<0:2PX
0P0Y:BT304m?C`<0J6QX0`0d=3@202PX:0<09RHV0`0[:b/302l_;`80:2PX0`0[:b/302h^;P<0DE5A
0`0n?Sh2020P80<08b<S0`0m?Cd309BDU080MWIf0`1jNWX30;Zj^PD0ZZZZ0`2a/K430;fm_@D0`l?3
0`2_[jl30::RXP<0ZJVY0`2h^;P20<O7a`<0[Jf]0`1ZJVX306a/K0D0LG5a0`1eMGD307QhN080Ng]k
0`1bLW830410@0<0PX:20`2DU9@2075aL@<0MGEe0`1RHV8306YZJP80MGEe0`1UIFD306YZJP<0H61P
0P1VIVH306e]K@<0QhN70`2LW9`209fMW@<0XJ6Q0`2TY:@80<SPf2l0P8200`1PH61o0820P0l0b>3H
000=0<SPf0<092@T0`0/;2`203Ti>@<0@d=30`0f=SH3030`<080=SHf1P1EEED303De=@809bLW0`0X
:2P602TY:@80:b/[0`16ATH306EUI@<0FEUI0`0Z:RX204e=C@<07QhN0`0Q8B4305eMG@80WYjN0`1o
Ogl308>3P`<0_[jn0P2UYJD30:f][@<0/k>c0`2m_Kd20<G5a@<0^KVi0`2KVi/309fMW@<0[jn_0P2m
_Kd30<?3``<0^[Zj0`1kNg/207QhN0<0PH610`23Ph<508n?S`<0QhN70`1iNGT30:2PX0<0WYjN0P2<
S8`308:2PP<0N7Qh0`1QHF4205]KF`<0De=C0`1=CDd304];B`80E5AD0`1fMWH309FEU@<0Z:RX0P2V
YZH30:RXZ0<0ZJVY2038h=P60820P0D0H61P0`20P805061PH1H0P8200`2PX:03061PH400P8200P2P
X:100820P0l0b>3H000=0<SPf0<092@T0`0/;2`203Ti>@<0@d=30`0f=SH3030`<080=SHf1P1EEED3
03De=@809bLW0`0X:2P602TY:@80:b/[0`16ATH306EUI@<0FEUI0`0Z:RX204e=C@<07QhN0`0Q8B43
05eMG@80WYjN0`1oOgl308>3P`<0_[jn0P2UYJD30:f][@<0/k>c0`2m_Kd20<G5a@<0^KVi0`2KVi/3
09fMW@<0[jn_0P2m_Kd30<?3``<0^[Zj0`1kNg/207QhN0<0PH610`23Ph<508n?S`<0QhN70`1iNGT3
0:2PX0<0WYjN0P2<S8`308:2PP<0N7Qh0`1QHF4205]KF`<0De=C0`1=CDd304];B`80E5AD0`1fMWH3
09FEU@<0Z:RX0P2VYZH30:RXZ0<0ZJVY2038h=P60820P0D0H61P0`20P805061PH1H0P8200`2PX:03
061PH400P8200P2PX:100820P0l0b>3H000=0<SPf0<092@T0`0/;2`203Ti>@<0@d=30`0f=SH3030`
<080=SHf1P1EEED303De=@809bLW0`0X:2P602TY:@80:b/[0`16ATH306EUI@<0FEUI0`0Z:RX204e=
C@<07QhN0`0Q8B4305eMG@80WYjN0`1oOgl308>3P`<0_[jn0P2UYJD30:f][@<0/k>c0`2m_Kd20<G5
a@<0^KVi0`2KVi/309fMW@<0[jn_0P2m_Kd30<?3``<0^[Zj0`1kNg/207QhN0<0PH610`23Ph<508n?
S`<0QhN70`1iNGT30:2PX0<0WYjN0P2<S8`308:2PP<0N7Qh0`1QHF4205]KF`<0De=C0`1=CDd304];
B`80E5AD0`1fMWH309FEU@<0Z:RX0P2VYZH30:RXZ0<0ZJVY2038h=P60820P0D0H61P0`20P805061P
H1H0P8200`2PX:03061PH400P8200P2PX:100820P0l0b>3H000=0<SPf0<09RHV0`0W9bL203Ti>@<0
BTY:0`0j>SX304=3@`80=cLg0`1=CDd303Ph>0<0<c<c0P0^;Rh302HV9P<0:2PX0`0U9BD203De=@<0
G5aL0`18B4P305IFEP<0>3Ph0P13@d<303@d=0<092@T0`0_;bl208>3P`<0T92@0`1UIFD309ZJVP80
^KVi0`2QXJ430;6a/@<0]kNg0P30`<030<71`@<0YZJV0`2FUYH30:BTY080/k>c0`2m_Kd30<;2`P<0
_Kfm0P2=SHd307QhN0<0S8b<0`2BTY8209VIV@<0TY:B0`2IVIT309ZJVP<0U9BD0P22PX8306e]K@<0
FUYJ0`1<C4`204I6AP<0@D510`18B4P305]KF`80Ogmo0`2NWYh30:^[Z`<0ZZZZ0P2[Zj/30:VYZ@<0
[:b/2038h=P/0820P0<0X:2PPP20P80?0<SPf0003@38h=P302HV9P<09bLW0P0i>CT304Y:BP<0>SXj
0`13@d<203Lg=`<0CDe=0`0h>3P303<c<`80;Rh^0`0V9RH302PX:0<09BDU0P0e=CD305aLG0<0B4Q8
0`1FEUH303Ph>080@d=30`0d=3@302@T90<0;bl_0P23Ph<3092@T0<0IFEU0`2JVYX20;Vi^@<0XJ6Q
0`2a/K430;Ng]`80`<300`31`L430:JVYP<0UYJF0`2TY:@20;>c/`<0_Kfm0`32`/830;fm_@80SHf=
0`1hN7P308b<S0<0TY:B0P2IVIT309:BTP<0VIVI0`2JVYX309BDU080PX:20`1]KFd305YJFP<0C4a<
0P16ATH30451@@<0B4Q80`1KFe/207moO`<0WYjN0`2[Zj/30:ZZZP80Zj^[0`2YZJT30:b/[0P0b>3H
;020P8030:2PX880P8203`38h=P000d0b>3H0`0V9RH302LW9`80>CTi0`1:BTX303Xj>P<0@d=30P0g
=cL304e=C@<0>3Ph0`0c<c<202h^;P<09RHV0`0X:2P302DU9@80=CDe0`1LG5`304Q8B0<0EUIF0`0h
>3P204=3@`<0=3@d0`0T92@302l_;`80Ph>30`2@T90306EUI@<0VYZJ0P2i^KT30:6QX@<0/K6a0`2g
]kL20<30`0<0`L710`2VYZH309JFUP<0Y:BT0P2c/k<30;fm_@<0`/;20`2m_Kd208f=S@<0N7Qh0`2<
S8`309:BTP80VIVI0`2BTY8309VIV@<0VYZJ0`2DU9@208:2PP<0KFe]0`1JFUX304a<C080ATI60`11
@D4304Q8B0<0Fe]K0P1oOgl309jNWP<0Zj^[0`2ZZZX20:^[Z`<0ZJVY0`2/[:`80<SPf2`0P8200`2P
X:220820P0l0b>3H000=0<SPf0<09BDU0`0];Bd202TY:@<0=cLg0`1:BTX303Lg=`80>3Ph0`16ATH3
030`<0<0;bl_0P0d=3@302/[:`<0;bl_0`0d=3@205aLG0<0D51@0`0d=3@304Y:BP<0DE5A0P0];Bd3
04Q8B0<0820P0`0Z:RX20492@P<0UIFE0`1dM7@3069RHP80YJFU0`2^[Zh30:ZZZP<0/K6a0P2g]kL3
0<;2`P<0];Bd0`2JVYX309^KV`80ZJVY0`2k^k/30;fm_@D0`<300`2KVi/307EeM@<0PX:20P2>SXh3
08^;R`<0QhN70`1iNGT3075aL@80I6AT0`1@D5030492@P<0Bd];0P1@D50306UYJ@<0O7al0`2KVi/2
0:RXZ0<0/K6a0`2^[Zh30;6a/@80/k>c0`2_[jl30:b/[0P0b>3H9020P803061PH4X0P8200`1PH603
0:2PX3X0P8203`38h=P000d0b>3H0`0U9BD302d];@80:BTY0`0g=cL304Y:BP<0=cLg0P0h>3P304I6
AP<0<30`0`0_;bl203@d=0<0:b/[0`0_;bl303@d=080G5aL0`1@D50303@d=0<0BTY:0`1ADE4202d]
;@<0B4Q80`0P820302XZ:P80@T920`2EUID307AdM0<0HV9R0P2UYJD30:j^[P<0ZZZZ0`2a/K420;Ng
]`<0`/;20`2d];@309ZJVP<0Vi^K0P2YZJT30;^k^`<0_Kfm1@30`<0309^KV`<0MGEe0`22PX8208j>
SP<0Rh^;0`27QhL307UiN@<0LG5a0P1TI6@3051@D0<0@T920`1;Bd/2051@D0<0JFUY0`1lO7`309^K
V`80Z:RX0`2a/K430:j^[P<0/K6a0P2c/k<30:n_[`<0[:b/2038h=PT0820P0<0H61PBP20P803061P
H0<0X:2P>P20P80?0<SPf0003@38h=P302DU9@<0;Bd]0P0Y:BT303Lg=`<0BTY:0`0g=cL203Ph>0<0
ATI60`0`<30302l_;`80=3@d0`0[:b/302l_;`<0=3@d0P1LG5`3051@D0<0=3@d0`1:BTX3055AD@80
;Bd]0`18B4P3020P80<0:RXZ0P12@T8309FEU@<0M7Ad0`1RHV820:FUY@<0[Zj^0`2ZZZX30;6a/@80
]kNg0`32`/830;Bd]0<0VYZJ0`2KVi/20:VYZ@<0^k^k0`2m_Kd50<30`0<0Vi^K0`1eMGD308:2PP80
SXj>0`2;Rh/308N7Q`<0NGUi0`1aLG4206ATI0<0D51@0`12@T8304];B`80D51@0`1YJFT307alO0<0
Vi^K0P2XZ:P30;6a/@<0[Zj^0`2a/K420;>c/`<0[jn_0`2/[:`80<SPf2@0P8200`1PH61:0820P0<0
H61P0`2PX:0j0820P0l0b>3H000=0<SPf0<08b<S0`0h>3P202/[:`<0=CDe0`0a<C43030`<080>CTi
0`0c<c<602d];@80=cLg0`0];Bd603Hf=P80ADE50`0b<S8302l_;`<0Cdm?0`1KFe/202/[:`<0De=C
0`0/;2`302@T9080820P0`1SHf<309>CT`<0IfMW0P1_Kfl30;:b/P<0[Jf]0`2ZZZX20:n_[`<0^k^k
0`2i^KT309fMW@<0Vi^K0P2NWYh30;Ng]`<0`<300`33`l<20<71`@<0`<300`2QXJ4305mOG`80EEEE
2@1SHf<3069RHP80IfMW0`1OGel306m_K`<0NGUi0P27QhL309VIV@<0YJFU0`2][Jd20;>c/`<0][Jf
0`2b/[830;6a/@D0/;2`0`2/[:`80<SPf7X0P8200P2PX:0e0820P0l0b>3H000=0<SPf0<08b<S0`0h
>3P202/[:`<0=CDe0`0a<C43030`<080>CTi0`0c<c<602d];@80=cLg0`0];Bd603Hf=P80ADE50`0b
<S8302l_;`<0Cdm?0`1KFe/202/[:`<0De=C0`0/;2`302@T9080820P0`1SHf<309>CT`<0IfMW0P1_
Kfl30;:b/P<0[Jf]0`2ZZZX20:n_[`<0^k^k0`2i^KT309fMW@<0Vi^K0P2NWYh30;Ng]`<0`<300`33
`l<20<71`@<0`<300`2QXJ4305mOG`80EEEE2@1SHf<3069RHP80IfMW0`1OGel306m_K`<0NGUi0P27
QhL309VIV@<0YJFU0`2][Jd20;>c/`<0][Jf0`2b/[830;6a/@D0/;2`0`2/[:`80<SPf7X0P8200P2P
X:0e0820P0l0b>3H000=0<SPf0<08b<S0`0h>3P202/[:`<0=CDe0`0a<C43030`<080>CTi0`0c<c<6
02d];@80=cLg0`0];Bd603Hf=P80ADE50`0b<S8302l_;`<0Cdm?0`1KFe/202/[:`<0De=C0`0/;2`3
02@T9080820P0`1SHf<309>CT`<0IfMW0P1_Kfl30;:b/P<0[Jf]0`2ZZZX20:n_[`<0^k^k0`2i^KT3
09fMW@<0Vi^K0P2NWYh30;Ng]`<0`<300`33`l<20<71`@<0`<300`2QXJ4305mOG`80EEEE2@1SHf<3
069RHP80IfMW0`1OGel306m_K`<0NGUi0P27QhL309VIV@<0YJFU0`2][Jd20;>c/`<0][Jf0`2b/[83
0;6a/@D0/;2`0`2/[:`80<SPf7X0P8200P2PX:0e0820P0l0b>3H000=0<SPf0<08R8R1@0a<C430410
@0<0AdM71@0l?3`3038b<P<0:b/[0`0W9bL202XZ:P<0;Rh^0`0e=CD302h^;P80C4a<0`0/;2`302@T
90<0CDe=0`1QHF42028R8P<0CTi>0`16ATH304=3@`80:b/[0`0];Bd307QhN0<0TY:B0P1OGel307mo
O`<0_kno0`2WYjL20:RXZ0<0/K6a0`2c/k<30:BTY0<0VYZJ0P2LW9`30;2`/0H0_[jn0P32`/830;^k
^`<0^KVi0`2`/;02075aL@<0Cdm?0`1UIFD307AdM0<0O7al0P29RHT3092@T0<0U9BD0`2HV9P20::R
XP<0Z:RX0`2/[:`30;2`/080/K6a0`2e]KD30;:b/P<0[jn_1@2`/;030;:b/PP0b>3H2`20P803061P
H2`0P8200`2PX:0m0820P080H61P=@20P80?0<SPf0003@38h=P3028R8PD0<C4a0`10@40304M7A`D0
?3`l0`0b<S8302/[:`<09bLW0P0Z:RX302h^;P<0=CDe0`0^;Rh204a<C0<0;2`/0`0T92@304e=C@<0
HF5Q0P0R8R8304i>CP<0ATI60`13@d<202/[:`<0;Bd]0`1hN7P309:BTP80GemO0`1oOgl30;no_`<0
YjNW0P2XZ:P30;6a/@<0/k>c0`2TY:@309ZJVP80W9bL0`2`/;060;jn_P80`/;20`2k^k/30;Vi^@<0
/;2`0P1aLG4304m?C`<0IFEU0`1dM7@307alO080RHV90`2@T90309BDU0<0V9RH0P2RXZ830:RXZ0<0
[:b/0`2`/;020;6a/@<0]KFe0`2b/[830:n_[`D0/;2`0`2b/[880<SPf0/0P8200`1PH60/0820P0<0
X:2P?@20P802061PH3D0P8203`38h=P000d0b>3H0`0S8b<302`/;080:b/[0`0];Bd304];B`<0Hf=S
0P1JFUX304a<C0<0?Cdm1@0/;2`302l_;`<0>SXj0`0X:2P2051@D0<0>c/k0`0V9RH303/k>`<0J6QX
0P0X:2P303@d=0<0FEUI0`0T92@203Lg=`<0;2`/0`0c<c<308f=S@80N7Qh0`1JFUX3096AT@<0][Jf
0P2RXZ830:^[Z`<0[:b/0`2YZJT50:2PX0<0/K6a0`2n_[h30;^k^`80^[Zj0`2k^k/30;:b/PD0/K6a
0`2MWId30861P@<0Rh^;0`2FUYH209ZJVP<0WinO0`2SXj<30:FUY@80YjNW0`2XZ:P30:f][@<0[Zj^
1@2a/K430;Bd]0<0/[:b0P2`/;030;Bd]0<0][Jf2038h=Ra0820P0l0b>3H000=0<SPf0<08b<S0`0/
;2`202/[:`<0;Bd]0`1;Bd/306=SH`80FUYJ0`1<C4`303dm?@D0;2`/0`0_;bl303Xj>P<0:2PX0P1@
D50303/k>`<09RHV0`0k>c/306QXJ080:2PX0`0d=3@305UIF@<092@T0P0g=cL302`/;0<0<c<c0`2=
SHd207QhN0<0FUYJ0`2ATI430;Jf]P80XZ:R0`2[Zj/30:b/[0<0ZJVY1@2PX:030;6a/@<0_[jn0`2k
^k/20;Zj^P<0^k^k0`2b/[850;6a/@<0WIfM0`21PH4308^;R`<0UYJF0P2JVYX309nOW`<0Xj>S0`2U
YJD20:NWY`<0Z:RX0`2][Jd30:j^[PD0/K6a0`2d];@30;:b/P80/;2`0`2d];@30;Jf]PP0b>3H/@20
P80?0<SPf0003@38h=P302<S8`<0;2`/0P0[:b/302d];@<0Bd];0`1SHf<205YJFP<0C4a<0`0m?Cd5
02`/;0<0;bl_0`0j>SX302PX:080D51@0`0k>c/302HV9P<0>c/k0`1XJ6P202PX:0<0=3@d0`1IFET3
02@T9080=cLg0`0/;2`303<c<`<0SHf=0P1hN7P305YJFP<0TI6A0`2f][H20::RXP<0Zj^[0`2/[:`3
0:VYZ@D0X:2P0`2a/K430;jn_P<0^k^k0P2j^[X30;^k^`<0/[:b1@2a/K4309fMW@<0PH610`2;Rh/3
09JFUP80VYZJ0`2OWil30:>SX`<0YJFU0P2WYjL30:RXZ0<0[Jf]0`2^[Zh50;6a/@<0];Bd0`2b/[82
0;2`/0<0];Bd0`2f][H80<SPf;40P8203`38h=P000d0b>3H0`0h>3P302PX:080=3@d0`0h>3P303hn
?P<0=SHf0P1WIfL304i>CP<0@D510`0a<C4202HV9P<0;Rh^0`0g=cL302@T9080@D510`1>CTh302@T
90<0@d=30`1IFET203/k>`<0:RXZ0`1JFUX304E5A@80:BTY0`0V9RH302@T90<0CDe=0P22PX83069R
HP<0IFEU0`2LW9`20:f][@<0WinO0`2SXj<30::RXP<0WIfM0P2QXJ430:n_[`<0_[jn0`2l_;`20;Jf
]P<0^KVi1P2^[Zh20;>c/`<0ZJVY0`2VYZH309bLW0<0Vi^K0P2RXZ860:BTY0D0Xj>S1P2WYjL30:f]
[@80/K6a0`2^[Zh30;2`/0<0/K6a0P2b/[830:j^[P<0]kNg2038h=PA0820P080X:2P0`1PH62K0820
P0l0b>3H000=0<SPf0<0>3Ph0`0X:2P203@d=0<0>3Ph0`0n?Sh303Hf=P80IfMW0`1>CTh30451@@<0
<C4a0P0V9RH302h^;P<0=cLg0`0T92@20451@@<0CTi>0`0T92@304=3@`<0FEUI0P0k>c/302XZ:P<0
FUYJ0`15ADD202TY:@<09RHV0`0T92@304e=C@80PX:20`1RHV8306EUI@<0W9bL0P2][Jd309nOW`<0
Xj>S0`2RXZ8309fMW@80XJ6Q0`2_[jl30;jn_P<0_;bl0P2f][H30;Vi^@H0[Zj^0P2c/k<30:VYZ@<0
YZJV0`2LW9`309^KV`80XZ:R1P2TY:@50:>SX`H0YjNW0`2][Jd20;6a/@<0[Zj^0`2`/;030;6a/@80
/[:b0`2^[Zh30;Ng]`P0b>3H4@20P8020:2PX0<0H61PV`20P80?0<SPf0003@38h=P303Ph>0<0:2PX
0P0d=3@303Ph>0<0?Shn0`0f=SH206MWI`<0CTi>0`11@D43034a<@809RHV0`0^;Rh303Lg=`<092@T
0P11@D4304i>CP<092@T0`13@d<305UIF@80>c/k0`0Z:RX305YJFP<0ADE50P0Y:BT302HV9P<092@T
0`1=CDd208:2PP<0HV9R0`1UIFD309bLW080[Jf]0`2OWil30:>SX`<0XZ:R0`2MWId20:6QX@<0[jn_
0`2n_[h30;bl_080][Jf0`2i^KT60:j^[P80/k>c0`2YZJT30:JVYP<0W9bL0`2KVi/20::RXPH0Y:BT
1@2SXj<60:NWY`<0[Jf]0P2a/K430:j^[P<0/;2`0`2a/K420;:b/P<0[Zj^0`2g]kL80<SPf140P820
0P2PX:03061PH9/0P8203`38h=P000d0b>3H0`1:BTX303hn?P80;Bd]0`0_;bl302HV9P<0;bl_0P10
@403061PH0<0FUYJ0`0g=cL202TY:@<0;Bd]0`0i>CT302/[:`80<S8b0`1JFUX3028R8P<0A4A40`0m
?Cd202l_;`H0=CDe0`1nOWh202`/;0<0820P0`0O7al302`/;080JFUY0`2@T90307QhN0<0LW9b0P2T
Y:@30:^[Z`<0WYjN1P2PX:020:BTY0<0/K6a0`2l_;`30;Zj^PD0^KVi0`2XZ:P309BDU080]kNg0`2d
];@30:JVYP<0YJFU0`2LW9`209^KV`<0X:2P0`2TY:@309nOW`80X:2P0`2TY:@30:JVYP<0[:b/0P2^
[Zh30:f][@<0[jn_0`2b/[850;Bd]0<0^[Zj2038h=Ra0820P0l0b>3H000=0<SPf0<0BTY:0`0n?Sh2
02d];@<0;bl_0`0V9RH302l_;`80@4100`1PH60305YJFP<0=cLg0P0Y:BT302d];@<0>CTi0`0[:b/2
038b<P<0FUYJ0`0R8R8304A4A0<0?Cdm0P0_;bl603De=@<0OWin0P0/;2`3020P80<07alO0`0/;2`2
06UYJ@<0T92@0`1hN7P3079bLP80Y:BT0`2[Zj/309jNWPH0X:2P0P2TY:@30;6a/@<0_;bl0`2j^[X5
0;Vi^@<0Z:RX0`2DU9@20;Ng]`<0];Bd0`2VYZH30:FUY@<0W9bL0P2KVi/30:2PX0<0Y:BT0`2OWil2
0:2PX0<0Y:BT0`2VYZH30:b/[080[Zj^0`2][Jd30:n_[`<0/[:b1@2d];@30;Zj^PP0b>3H/@20P80?
0<SPf0003@38h=P304Y:BP<0?Shn0P0];Bd302l_;`<09RHV0`0_;bl20410@0<0H61P0`1JFUX303Lg
=`80:BTY0`0];Bd303Ti>@<0:b/[0P0b<S8305YJFP<08R8R0`14A4@303dm?@80;bl_1P0e=CD307in
OP80;2`/0`0P820301lO7`<0;2`/0P1YJFT3092@T0<0N7Qh0`1bLW820:BTY0<0Zj^[0`2NWYh60:2P
X080Y:BT0`2a/K430;bl_0<0^[Zj1@2i^KT30:RXZ0<0U9BD0P2g]kL30;Bd]0<0YZJV0`2UYJD309bL
W080Vi^K0`2PX:030:BTY0<0WinO0P2PX:030:BTY0<0YZJV0`2/[:`20:j^[P<0[Jf]0`2_[jl30;:b
/PD0];Bd0`2j^[X80<SPf;40P8203`38h=P000d0b>3H0`0W9bL30451@@80;2`/0`0];Bd302PX:0<0
C4a<0P13@d<302/[:`<0DU9B0`17AdL202`/;0<0<C4a0`0e=CD302l_;`80:RXZ0`1EEED3030`<0<0
D51@0`0^;Rh202/[:`<0<S8b0`0k>c/305YJFP809BDU0`0S8b<3020P80<0De=C0P1ZJVX307AdM0<0
Vi^K0`1dM7@207QhN0<0Y:BT0`2UYJD30:6QX@<0Xj>S0P2ZZZX30;Jf]P<0^k^k0`2h^;P20;^k^`<0
/;2`0`2CTi<308B4Q080/[:b0`30`<030;Jf]P<0YZJV0`2OWil209VIV@<0VYZJ0`2KVi/309ZJVP80
X:2P0`2QXJ430:FUY@<0ZZZZ1@2[Zj/30;2`/0<0/K6a0P2c/k<30;Bd]0<0^k^k2038h=Ra0820P0l0
b>3H000=0<SPf0<09bLW0`11@D4202`/;0<0;Bd]0`0X:2P304a<C080@d=30`0[:b/3059BDP<0AdM7
0P0/;2`3034a<@<0=CDe0`0_;bl202XZ:P<0EEEE0`0`<303051@D0<0;Rh^0P0[:b/3038b<P<0>c/k
0`1JFUX202DU9@<08b<S0`0P820305=CD`80JVYZ0`1dM7@309^KV`<0M7Ad0P1hN7P30:BTY0<0YJFU
0`2QXJ430:>SX`80ZZZZ0`2f][H30;^k^`<0^;Rh0P2k^k/30;2`/0<0Ti>C0`24Q8@20;:b/P<0`<30
0`2f][H30:JVYP<0WinO0P2IVIT309ZJVP<0Vi^K0`2JVYX20:2PX0<0XJ6Q0`2UYJD30:ZZZPD0Zj^[
0`2`/;030;6a/@80/k>c0`2d];@30;^k^`P0b>3H/@20P80?0<SPf0003@38h=P302HV9PD0:b/[0`0Z
:RX304U9B@<0G5aL0P0_;bl3034a<@<0>CTi0`1CDe<203@d=0<0;bl_0`0i>CT3034a<@80:b/[0`19
BDT303Ph>0<0=cLg0`0];Bd203Ti>@<0C4a<0`0b<S83059BDP80;2`/0`0S8b<302HV9P<0PX:20P17
AdL3038b<P<0QhN70`2=SHd207MgM`<0PX:20`2YZJT30::RXP<0Z:RX0P2_[jl30;6a/@<0`<300`2h
^;P20;Zj^P<0YjNW0`2?Shl308b<S080/;2`0`2h^;P30<?3``<0][Jf0`2XZ:P509nOW`<0XJ6Q0`2I
VIT209fMW@<0XZ:R0`2PX:030:VYZ@80Zj^[1P2][Jd50;2`/0<0^;Rh0`2k^k/80<SPf;40P8203`38
h=P000d0b>3H0`0V9RH502/[:`<0:RXZ0`19BDT305aLG080;bl_0`0a<C4303Ti>@<0De=C0P0d=3@3
02l_;`<0>CTi0`0a<C4202/[:`<0BDU90`0h>3P303Lg=`<0;Bd]0P0i>CT304a<C0<0<S8b0`1BDU82
02`/;0<08b<S0`0V9RH308:2PP80AdM70`0b<S8308N7Q`<0SHf=0P1gMgL308:2PP<0ZJVY0`2RXZ83
0:RXZ080[jn_0`2a/K430<30`0<0^;Rh0P2j^[X30:NWY`<0Shn?0`2<S8`20;2`/0<0^;Rh0`33`l<3
0;Jf]P<0Z:RX1@2OWil30:6QX@<0VIVI0P2MWId30::RXP<0X:2P0`2YZJT20:^[Z`H0[Jf]1@2`/;03
0;Rh^0<0^k^k2038h=Ra0820P0l0b>3H000=0<SPf0<09RHV1@0[:b/302XZ:P<0BDU90`1LG5`202l_
;`<0<C4a0`0i>CT305=CD`80=3@d0`0_;bl303Ti>@<0<C4a0P0[:b/304U9B@<0>3Ph0`0g=cL302d]
;@80>CTi0`1<C4`3038b<P<0DU9B0P0/;2`302<S8`<09RHV0`22PX8204M7A`<0<S8b0`27QhL308f=
S@80MgMg0`22PX830:VYZ@<0XZ:R0`2XZ:P20:n_[`<0/K6a0`30`<030;Rh^080^[Zj0`2WYjL308n?
S`<0S8b<0P2`/;030;Rh^0<0`l?30`2f][H30:RXZ0D0WinO0`2QXJ4309VIV@80WIfM0`2RXZ830:2P
X0<0ZJVY0P2[Zj/60:f][@D0/;2`0`2h^;P30;^k^`P0b>3H/@20P80?0<SPf0003@38h=P302LW9`<0
:2PX0P0Z:RX302h^;P<0H61P0`0l?3`204Q8B0<0>3Ph0`0^;Rh303/k>`80=cLg0`0^;Rh303Ph>0<0
=cLg0P0b<S8303Xj>P<0ATI60`0e=CD302DU9@80@d=30`1JFUX3059BDP<0ADE50P19BDT303De=@<0
FUYJ0`27QhL202XZ:P<08B4Q0`13@d<3092@T080RHV90`1cLg<308F5Q@<0/[:b0`2ZZZX20:VYZ@<0
][Jf0`2k^k/30;Rh^080/;2`0`2/[:`309:BTP<0UiNG0P2TY:@30:j^[P<0`/;20`33`l<30:n_[`D0
Y:BT0`2SXj<30::RXP80U9BD0`2LW9`309fMW@<0Xj>S0P2VYZH30:^[Z`<0[:b/0`2][Jd20;Fe]@<0
^;Rh0`2n_[h80<SPf480P8201P1PH61Y0820P0l0b>3H000=0<SPf0<09bLW0`0X:2P202XZ:P<0;Rh^
0`1PH60303`l?080B4Q80`0h>3P302h^;P<0>c/k0P0g=cL302h^;P<0>3Ph0`0g=cL2038b<P<0>SXj
0`16ATH303De=@<09BDU0P13@d<305YJFP<0DU9B0`15ADD204U9B@<0=CDe0`1JFUX308N7Q`80:RXZ
0`0Q8B4304=3@`<0T92@0P29RHT307=cL`<0QHF50`2b/[830:ZZZP80ZJVY0`2f][H30;^k^`<0^;Rh
0P2`/;030:b/[0<0TY:B0`2GUiL20:BTY0<0[Zj^0`32`/830<?3``<0[jn_1@2TY:@30:>SX`<0XZ:R
0P2DU9@309bLW0<0WIfM0`2SXj<20:JVYP<0Zj^[0`2/[:`30:f][@80]KFe0`2h^;P30;jn_PP0b>3H
@P20P806061PH6T0P8203`38h=P000d0b>3H0`0W9bL302PX:080:RXZ0`0^;Rh3061PH0<0?3`l0P18
B4P303Ph>0<0;Rh^0`0k>c/203Lg=`<0;Rh^0`0h>3P303Lg=`80<S8b0`0j>SX304I6AP<0=CDe0`0U
9BD204=3@`<0FUYJ0`1BDU8304E5A@80BDU90`0e=CD305YJFP<0QhN70P0Z:RX3024Q8@<0@d=30`2@
T90208V9R@<0Lg=c0`25QHD30;:b/P<0ZZZZ0P2YZJT30;Jf]P<0^k^k0`2h^;P20;2`/0<0[:b/0`2B
TY8309NGU`80Y:BT0`2^[Zh30<;2`P<0`l?30`2_[jl50:BTY0<0Xj>S0`2RXZ8209BDU0<0W9bL0`2M
WId30:>SX`80YZJV0`2[Zj/30:b/[0<0[Jf]0P2e]KD30;Rh^0<0_[jn2038h=Q20820P0H0H61PJ@20
P80?0<SPf0003@38h=P302h^;P<09RHV0P0/;2`3038b<P<0Hf=S0`0X:2P202`/;0<0=cLg0`0m?Cd3
038b<P80@T920`0/;2`3038b<P<0>SXj0P0b<S8302l_;`<0?Shn0`0d=3@302l_;`80BDU90`1@D503
05MGE`D0GEeM0`1;Bd/306e]K@<0S8b<0P0e=CD301lO7`<08B4Q0`1ADE4209JFUP<0Q8B40`1fMWH3
08n?S`<0^k^k0P2WYjL30;Bd]0<0][Jf0`2a/K450:n_[`<0SXj>0`2PX:020:BTY0<0/;2`0`2o_kl3
0<G5a@<0_Kfm0P2WYjL30:ZZZP<0Z:RX0`2RXZ820:6QX@<0UIFE0`2IVIT309nOW`80XJ6Q1P2YZJT3
0:ZZZP80];Bd0`2j^[X30;no_`P0b>3H/@20P80?0<SPf0003@38h=P302h^;P<09RHV0P0/;2`3038b
<P<0Hf=S0`0X:2P202`/;0<0=cLg0`0m?Cd3038b<P80@T920`0/;2`3038b<P<0>SXj0P0b<S8302l_
;`<0?Shn0`0d=3@302l_;`80BDU90`1@D50305MGE`D0GEeM0`1;Bd/306e]K@<0S8b<0P0e=CD301lO
7`<08B4Q0`1ADE4209JFUP<0Q8B40`1fMWH308n?S`<0^k^k0P2WYjL30;Bd]0<0][Jf0`2a/K450:n_
[`<0SXj>0`2PX:020:BTY0<0/;2`0`2o_kl30<G5a@<0_Kfm0P2WYjL30:ZZZP<0Z:RX0`2RXZ820:6Q
X@<0UIFE0`2IVIT309nOW`80XJ6Q1P2YZJT30:ZZZP80];Bd0`2j^[X30;no_`P0b>3H/@20P80?0<SP
f0003@38h=P302h^;P<09RHV0P0/;2`3038b<P<0Hf=S0`0X:2P202`/;0<0=cLg0`0m?Cd3038b<P80
@T920`0/;2`3038b<P<0>SXj0P0b<S8302l_;`<0?Shn0`0d=3@302l_;`80BDU90`1@D50305MGE`D0
GEeM0`1;Bd/306e]K@<0S8b<0P0e=CD301lO7`<08B4Q0`1ADE4209JFUP<0Q8B40`1fMWH308n?S`<0
^k^k0P2WYjL30;Bd]0<0][Jf0`2a/K450:n_[`<0SXj>0`2PX:020:BTY0<0/;2`0`2o_kl30<G5a@<0
_Kfm0P2WYjL30:ZZZP<0Z:RX0`2RXZ820:6QX@<0UIFE0`2IVIT309nOW`80XJ6Q1P2YZJT30:ZZZP80
];Bd0`2j^[X30;no_`P0b>3H/@20P80?0<SPf0003@38h=P3030`<0<0:RXZ0P0];Bd30410@0<0IfMW
0`0Z:RX202d];@<0<30`0`1:BTX303Hf=P80=cLg1P0b<S8303Hf=P80>SXj0`0Z:RX303Ph>0<0?Cdm
0`0f=SH2038b<P<0G5aL0`1^KVh307=cL`80>c/k0`0];Bd306MWI`<0FUYJ0P0O7al3028R8P<08b<S
0`0V9RH205aLG0<0WinO0`24Q8@307MgM`<0V9RH0P2f][H30:VYZ@<0];Bd0`2YZJT20:FUY@<0YZJV
0`2:RXX30:JVYP80[Jf]0`2^[Zh30;Ng]`<0`<300`2k^k/20:b/[0<0ZZZZ0`2XZ:P30:^[Z`80YjNW
0`2UYJD309NGU`<0UIFE0P2NWYh30:JVYP<0Z:RX0`2[Zj/20;:b/P<0^KVi0`2n_[h80<SPf;40P820
3`38h=P000d0b>3H0`0`<30302XZ:P80;Bd]0`10@40306MWI`<0:RXZ0P0];Bd3030`<0<0BTY:0`0f
=SH203Lg=`H0<S8b0`0f=SH203Xj>P<0:RXZ0`0h>3P303dm?@<0=SHf0P0b<S8305aLG0<0KVi^0`1c
Lg<203/k>`<0;Bd]0`1WIfL305YJFP807alO0`0R8R8302<S8`<09RHV0P1LG5`309nOW`<0Q8B40`1g
MgL309RHV080][Jf0`2YZJT30;Bd]0<0ZJVY0P2UYJD30:JVYP<0RXZ:0`2VYZH20:f][@<0[Zj^0`2g
]kL30<30`0<0^k^k0P2/[:`30:ZZZP<0Z:RX0`2[Zj/20:NWY`<0YJFU0`2GUiL309FEU@80WYjN0`2V
YZH30:RXZ0<0Zj^[0P2b/[830;Vi^@<0_[jn2038h=Ra0820P0l0b>3H000=0<SPf0<0DU9B0`16ATH2
02d];@<0>c/k0`1XJ6P303<c<`80;2`/0`0[:b/303De=@<0@d=31@0g=cL302`/;0<0;bl_0P0g=cL3
030`<0<0?clo0`0n?Sh303@d=080@T920`1SHf<304=3@`<0FUYJ0P0];Bd303@d=0<0QXJ60`11@D42
02/[:`<09RHV0`0S8b<502@T90<0IfMW0`2MWId307UiN@<0KVi^0P2MWId30;:b/P<0ZJVY1@2UYJD3
0:>SX`<0QXJ60`2UYJD20:b/[0<0XJ6Q0`2j^[X30;jn_P<0^;Rh0P2`/;060:RXZ0<0ZZZZ0P2YZJT3
0:^[Z`<0[:b/0`2MWId209FEU@<0XZ:R0`2VYZH30:^[Z`80[Zj^0`2e]KD30;^k^`P0b>3H1P1PH62[
0820P0l0b>3H000=0<SPf0<0DU9B0`16ATH202d];@<0>c/k0`1XJ6P303<c<`80;2`/0`0[:b/303De
=@<0@d=31@0g=cL302`/;0<0;bl_0P0g=cL3030`<0<0?clo0`0n?Sh303@d=080@T920`1SHf<304=3
@`<0FUYJ0P0];Bd303@d=0<0QXJ60`11@D4202/[:`<09RHV0`0S8b<502@T90<0IfMW0`2MWId307Ui
N@<0KVi^0P2MWId30;:b/P<0ZJVY1@2UYJD30:>SX`<0QXJ60`2UYJD20:b/[0<0XJ6Q0`2j^[X30;jn
_P<0^;Rh0P2`/;060:RXZ0<0ZZZZ0P2YZJT30:^[Z`<0[:b/0`2MWId209FEU@<0XZ:R0`2VYZH30:^[
Z`80[Zj^0`2e]KD30;^k^`P0b>3H1P1PH62[0820P0l0b>3H000=0<SPf0<0DU9B0`16ATH202d];@<0
>c/k0`1XJ6P303<c<`80;2`/0`0[:b/303De=@<0@d=31@0g=cL302`/;0<0;bl_0P0g=cL3030`<0<0
?clo0`0n?Sh303@d=080@T920`1SHf<304=3@`<0FUYJ0P0];Bd303@d=0<0QXJ60`11@D4202/[:`<0
9RHV0`0S8b<502@T90<0IfMW0`2MWId307UiN@<0KVi^0P2MWId30;:b/P<0ZJVY1@2UYJD30:>SX`<0
QXJ60`2UYJD20:b/[0<0XJ6Q0`2j^[X30;jn_P<0^;Rh0P2`/;060:RXZ0<0ZZZZ0P2YZJT30:^[Z`<0
[:b/0`2MWId209FEU@<0XZ:R0`2VYZH30:^[Z`80[Zj^0`2e]KD30;^k^`P0b>3H1P1PH62[0820P0l0
b>3H000=0<SPf0<0B4Q80`14A4@203@d=0<0=SHf0`1SHf<30410@0D0:RXZ0`0/;2`303Ti>@80;Rh^
0`0k>c/302l_;`D0<c<c0`1;Bd/304Q8B0<0?clo0`0m?Cd204A4A0<0EeMG0`0_;bl304E5A@80<S8b
0`1FEUH308V9R@<0;bl_1@0W9bL6028R8P80820P0`0W9bL307=cL`<0Xj>S0`1aLG4207AdM0<0WinO
0`2j^[X30:BTY080YJFU0`2OWil308:2PP<0VIVI0P2XZ:P30:NWY`<0/;2`0`2n_[h30:f][@80][Jf
1P2YZJT30:NWY`80Xj>S0`2TY:@30:b/[0<0]KFe0P2NWYh309NGU`<0Xj>S0`2ZZZX20:j^[P<0];Bd
0`2g]kL80<SPf;40P8203`38h=P000d0b>3H0`18B4P304A4A080=3@d0`0f=SH306=SH`<0@4101@0Z
:RX302`/;0<0>CTi0P0^;Rh303/k>`<0;bl_1@0c<c<304];B`<0B4Q80`0o?cl303dm?@80A4A40`1G
EeL302l_;`<0ADE50P0b<S8305IFEP<0RHV90`0_;bl502LW9`H08R8R0P0P820302LW9`<0Lg=c0`2S
Xj<3075aL@80M7Ad0`2OWil30;Zj^P<0Y:BT0P2UYJD309nOW`<0PX:20`2IVIT20:RXZ0<0YjNW0`2`
/;030;jn_P<0[Jf]0P2f][H60:VYZ@<0YjNW0P2SXj<30:BTY0<0[:b/0`2e]KD209jNWP<0UiNG0`2S
Xj<30:ZZZP80[Zj^0`2d];@30;Ng]`P0b>3H/@20P80?0<SPf0003@38h=P304Q8B0<0A4A40P0d=3@3
03Hf=P<0Hf=S0`10@40502XZ:P<0;2`/0`0i>CT202h^;P<0>c/k0`0_;bl503<c<`<0Bd];0`18B4P3
03lo?`<0?Cdm0P14A4@305MGE`<0;bl_0`15ADD2038b<P<0EUIF0`29RHT302l_;`D09bLW1P0R8R82
020P80<09bLW0`1cLg<30:>SX`<0LG5a0P1dM7@309nOW`<0^[Zj0`2TY:@20:FUY@<0WinO0`22PX83
09VIV@80Z:RX0`2WYjL30;2`/0<0_[jn0`2][Jd20;Jf]PH0ZJVY0`2WYjL20:>SX`<0Y:BT0`2/[:`3
0;Fe]@80WYjN0`2GUiL30:>SX`<0ZZZZ0P2^[Zh30;Bd]0<0]kNg2038h=Ra0820P0l0b>3H000=0<SP
f0<0Kfm_0`19BDT202TY:@<0<30`0`1CDe<3051@D080:BTY0`0[:b/302`/;0<0<S8b0P0];Bd3034a
<@<0;bl_0`0e=CD204Q8B0<0D51@0`0l?3`304U9B@<0AdM70P0b<S8305mOG`<0<30`0`0j>SX2034a
<@<0FEUI0`25QHD303Ph>080ADE50`18B4P3030`<0<09RHV0P0S8b<3024Q8@<0<30`0`1mOGd309ZJ
VP80Lg=c0`1[Jf/309fMW@<0/;2`0P2QXJ4309NGU`<0Ng]k0`2SXj<20;Vi^@<0[Zj^0`2c/k<30<30
`0<0^k^k0P2i^KT30:b/[0<0YjNW0`2SXj<20:2PX0<0WinO0`2WYjL30;6a/@80^KVi0`2[Zj/309ZJ
VP<0Y:BT0P2XZ:P30:f][@<0];Bd2038h=P30820P0<0H61PA`20P803061PH640P8203`38h=P000d0
b>3H0`1_Kfl304U9B@80:BTY0`0`<30305=CD`<0D51@0P0Y:BT302/[:`<0;2`/0`0b<S8202d];@<0
<C4a0`0_;bl303De=@80B4Q80`1@D50303`l?0<0BDU90`17AdL2038b<P<0GemO0`0`<30303Xj>P80
<C4a0`1IFET308F5Q@<0>3Ph0P15ADD304Q8B0<0<30`0`0V9RH202<S8`<08B4Q0`0`<30307emO@<0
VYZJ0P1cLg<306][J`<0WIfM0`2`/;020:6QX@<0UiNG0`1kNg/30:>SX`80^KVi0`2^[Zh30;>c/`<0
`<300`2k^k/20;Vi^@<0[:b/0`2WYjL30:>SX`80X:2P0`2OWil30:NWY`<0/K6a0P2i^KT30:^[Z`<0
VYZJ0`2TY:@20:RXZ0<0[Jf]0`2d];@80<SPf0<0P8200`1PH6170820P0<0H61PH@20P80?0<SPf000
3@38h=P306m_K`<0BDU90P0Y:BT3030`<0<0De=C0`1@D50202TY:@<0:b/[0`0/;2`3038b<P80;Bd]
0`0a<C4302l_;`<0=CDe0P18B4P3051@D0<0?3`l0`19BDT304M7A`80<S8b0`1OGel3030`<0<0>SXj
0P0a<C4305UIF@<0QHF50`0h>3P204E5A@<0B4Q80`0`<30302HV9P808b<S0`0Q8B43030`<0<0OGem
0`2JVYX207=cL`<0Jf][0`2MWId30;2`/080XJ6Q0`2GUiL307]kN`<0Xj>S0P2i^KT30:j^[P<0/k>c
0`30`<030;^k^`80^KVi0`2/[:`30:NWY`<0Xj>S0P2PX:0309nOW`<0YjNW0`2a/K420;Vi^@<0Zj^[
0`2JVYX30:BTY080Z:RX0`2][Jd30;Bd]0P0b>3H0`20P803061PH4L0P8200`1PH61Q0820P0l0b>3H
000=0<SPf0<0KVi^0`0k>c/202TY:@<0<c<c0`0g=cL3059BDP80>SXj0`0`<30602d];@80;bl_0`0b
<S8302h^;P<0BDU90P1FEUH303lo?`<0B4Q80`1GEeL303`l?080:RXZ0`1KFe/302/[:`<0;Rh^0P0j
>SX3075aL@<0Q8B40`1NGUh205YJFP<0Bd];0`0[:b/302HV9P8092@T0`0S8b<302HV9P<0=3@d0`21
PH4208n?S`<0GEeM0`1WIfL309FEU@80/[:b1P28R8P30:b/[080^[Zj0`2`/;030;Rh^0<0_;bl0`30
`<020;no_`<0][Jf0`2ZZZX30:FUY@80WinO0`2QXJ430:FUY@<0[:b/0P2b/[830;Fe]@<0[:b/0`2R
XZ820:FUY@<0[Jf]0`2b/[880<SPf4/0P8201@2PX:1Q0820P0l0b>3H000=0<SPf0<0KVi^0`0k>c/2
02TY:@<0<c<c0`0g=cL3059BDP80>SXj0`0`<30602d];@80;bl_0`0b<S8302h^;P<0BDU90P1FEUH3
03lo?`<0B4Q80`1GEeL303`l?080:RXZ0`1KFe/302/[:`<0;Rh^0P0j>SX3075aL@<0Q8B40`1NGUh2
05YJFP<0Bd];0`0[:b/302HV9P8092@T0`0S8b<302HV9P<0=3@d0`21PH4208n?S`<0GEeM0`1WIfL3
09FEU@80/[:b1P28R8P30:b/[080^[Zj0`2`/;030;Rh^0<0_;bl0`30`<020;no_`<0][Jf0`2ZZZX3
0:FUY@80WinO0`2QXJ430:FUY@<0[:b/0P2b/[830;Fe]@<0[:b/0`2RXZ820:FUY@<0[Jf]0`2b/[88
0<SPf4/0P8201@2PX:1Q0820P0l0b>3H000=0<SPf0<0K6a/0`10@40203Hf=P<0>SXj0`0Z:RX304m?
C`80Bd];0`0b<S8302d];@<0;Rh^0P0_;bl3030`<0<0=CDe0`1LG5`204Q8B0<0@T920`1ADE4305UI
F@<0;2`/0P0f=SH3051@D0<0:b/[0`0a<C4206a/K0<0OGem0`1TI6@802`/;0<0<C4a1@0[:b/302DU
9@<092@T0`0V9RH303Xj>P80MGEe0`1aLG43065QH@<0Fe]K0P2EUID308R8R0<0X:2P0`2JVYX20;Rh
^0<0/k>c0`2e]KD30;Ng]`<0^k^k0P2l_;`30;Jf]P<0/K6a0`2UYJD50:2PX0<0Y:BT0`2VYZH20:b/
[0<0][Jf0`2^[Zh30:BTY080W9bL0`2RXZ830:j^[PP0b>3H/@20P80?0<SPf0003@38h=P306a/K0<0
@4100P0f=SH303Xj>P<0:RXZ0`1?Cdl204];B`<0<S8b0`0];Bd302h^;P80;bl_0`0`<30303De=@<0
G5aL0P18B4P30492@P<0DE5A0`1IFET302`/;080=SHf0`1@D50302/[:`<0<C4a0P1/K6`307emO@<0
I6AT200/;2`3034a<@D0:b/[0`0U9BD302@T90<09RHV0`0j>SX207EeM@<0LG5a0`1QHF4305]KF`80
UIFE0`28R8P30:2PX0<0VYZJ0P2h^;P30;>c/`<0]KFe0`2g]kL30;^k^`80_;bl0`2f][H30;6a/@<0
YJFU1@2PX:030:BTY0<0YZJV0P2/[:`30;Jf]P<0[Zj^0`2TY:@209bLW0<0XZ:R0`2^[Zh80<SPf;40
P8203`38h=P000d0b>3H0`1/K6`30410@080=SHf0`0j>SX302XZ:P<0Cdm?0P1;Bd/3038b<P<0;Bd]
0`0^;Rh202l_;`<0<30`0`0e=CD305aLG080B4Q80`12@T83055AD@<0FEUI0`0/;2`203Hf=P<0D51@
0`0[:b/3034a<@80K6a/0`1mOGd306ATI0P0;2`/0`0a<C4502/[:`<09BDU0`0T92@302HV9P<0>SXj
0P1eMGD3075aL@<0HF5Q0`1KFe/209FEU@<0R8R80`2PX:0309ZJVP80^;Rh0`2c/k<30;Fe]@<0]kNg
0`2k^k/20;bl_0<0][Jf0`2a/K430:FUY@D0X:2P0`2TY:@30:JVYP80[:b/0`2f][H30:j^[P<0Y:BT
0P2LW9`30::RXP<0[Zj^2038h=Ra0820P0l0b>3H000=0<SPf0<0KFe]0`1GEeL2065QH@<0FUYJ0`14
A4@304M7A`80EeMG0`12@T8303De=@<0;bl_0P0/;2`3034a<@<0?Cdm0`1ADE4204I6AP<0AdM70`1E
EED304i>CP<0<c<c0P0f=SH304i>CP<09bLW0`1ADE42079bLP<0Kfm_0`0k>c/302`/;080<C4a0`0b
<S83030`<0<0;Rh^0P0/;2`3034a<@<0:BTY0`0W9bL302XZ:P80?Shn0`1ZJVX307EeM@<0Cdm?0P1S
Hf<306MWI`<0Xj>S0`2<S8`20;Rh^0<0/K6a0`2b/[860;Fe]@D0^k^k0`2f][H30:f][@80YZJV0`2R
XZ830:RXZ0<0Zj^[0P2_[jl30;>c/`<0/K6a0`2_[jl209nOW`H0ZJVY2038h=P;0820P0<0H61PF020
P8030:2PX0<0P8200`1PH6020820P0<0X:2P?@20P80?0<SPf0003@38h=P306e]K@<0EeMG0P1QHF43
05YJFP<0A4A40`17AdL205MGE`<0@T920`0e=CD302l_;`80;2`/0`0a<C4303dm?@<0DE5A0P16ATH3
04M7A`<0EEEE0`1>CTh303<c<`80=SHf0`1>CTh302LW9`<0DE5A0P1bLW8306m_K`<0>c/k0`0/;2`2
034a<@<0<S8b0`0`<30302h^;P80;2`/0`0a<C4302TY:@<09bLW0`0Z:RX203hn?P<0JVYZ0`1eMGD3
04m?C`80Hf=S0`1WIfL30:>SX`<0S8b<0P2h^;P30;6a/@<0/[:b1P2e]KD50;^k^`<0][Jf0`2][Jd2
0:JVYP<0XZ:R0`2XZ:P30:^[Z`80[jn_0`2c/k<30;6a/@<0[jn_0P2OWil60:VYZ@P0b>3H2`20P803
061PH5P0P8200`2PX:030820P0<0H61P0P20P8030:2PX3d0P8203`38h=P000d0b>3H0`1]KFd305MG
E`80HF5Q0`1JFUX304A4A0<0AdM70P1GEeL30492@P<0=CDe0`0_;bl202`/;0<0<C4a0`0m?Cd3055A
D@80ATI60`17AdL305EEE@<0CTi>0`0c<c<203Hf=P<0CTi>0`0W9bL3055AD@80LW9b0`1_Kfl303/k
>`<0;2`/0P0a<C43038b<P<0<30`0`0^;Rh202`/;0<0<C4a0`0Y:BT302LW9`<0:RXZ0P0n?Sh306YZ
JP<0MGEe0`1?Cdl206=SH`<0IfMW0`2SXj<308b<S080^;Rh0`2a/K430;:b/PH0]KFe1@2k^k/30;Jf
]P<0[Jf]0P2VYZH30::RXP<0Z:RX0`2[Zj/20:n_[`<0/k>c0`2a/K430:n_[`80WinO1P2YZJT80<SP
f0/0P8200`1PH61H0820P0<0X:2P0`20P803061PH080P8200`2PX:0m0820P0l0b>3H003o0<SPf8L0
b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0
b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H003o0<SPf8L0
b>3H003o0<SPf8L0b>3H003o0<SPf8L0b>3H0000\
\>"],
  ImageRangeCache->{{{0, 389}, {389, 0}} -> {-0.0500105, -0.0500105, \
0.00539852, 0.00539852}, {{9.25, 194.5}, {379.688, 194.5}} -> {-4.96829, \
-4.97963, 0.362878, 0.362878}, {{194.5, 379.688}, {379.688, 194.5}} -> \
{-72.1801, -4.97963, 0.362878, 0.362878}, {{9.25, 194.5}, {194.5, 9.25}} -> \
{-4.95582, -72.1563, 0.362756, 0.362756}, {{194.5, 379.688}, {194.5, 9.25}} -> \
{-72.1801, -72.1914, 0.362878, 0.362878}}]
}, Open  ]],

Cell["\<\
We notice that the sharp edge information remains in the LH, HL and HH \
subbands, but most of the lower amplitude noise, as well as the exact \
magnitudes of the edges have been compromised.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other decompositions", "Section"],

Cell["\<\
Let us automatize some earlier operations. Specifically,we will perform DWT \
recursively in each subband. This is sometimes called a packet or SPACL \
decomposition (if we recursively subdivided the LLLL once or twice more), \
unlike the above 1-level Mallat decompositions where the high-pass subbands \
remain undecomposed. The decompositions can be performed recursively - if we \
performed a Mallat decomposition again on the LL, we would obtain a 2-level \
Mallat decomposition. The decomposition below is actually a 2-level packet \
decomposition, as we performed it twice recursively, and it's packet \
decomposition because it was performed on all subbands.\
\>", "Text"],

Cell[BoxData[
    \(\(trecomp = Map[DeInterleave2[ImgDWT[#]] &, decomp, {2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(GfxMat[X_, s_] := 
        GraphicsArray[
          Map[GraphicsArray[
                Map[Graphics[Raster[\((# + \((s/2)\))\)/s], 
                      AspectRatio \[Rule] 1] &, #, {2}], 
                GraphicsSpacing \[Rule] 0] &, X, {2}], 
          GraphicsSpacing \[Rule] 0];\)\), "\[IndentingNewLine]", 
    \(\(Show[GfxMat[trecomp, 256]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7D626D7D77747A758A9CA78E7D797E7A83807A8183827C7D7A7882817C858C6E
789788847B75957984A2957C8285837D8085867F83807D7B7B7C80837E868A72
8776858A7C8488758DA37E7A80857D8181847E80837F7F7C7E82817D7F827F63
728C93667F837A7D96A37B8183807E7D787F818082897E7C827E817F7A7F7B7D
75857F74707F8483978E76797D817E7F7C7F807C86877D8080837C807F7D8082
615C817A937881829192787E7C82807E8082858283817F807F82898A867E7D89
8E9C7783808B8B7F9A997E797E7F7C7D817E867C837F7C7F818481847B7E807D
867579949085867D8FA48E7B83867E82877A84807D8182867D817F7E7F798588
A389696B636F828A8CA48A857C7B827F7C7B7C7E817F7A7A7D817C81817C8183
887C8AA382977C6883A37C837983828183807D80797D7E837D7E7F83807C7F85
7E857C605A6F859A80937F857F807E7D7D81857C7C827F7F817E807E7C7E8380
8A7F8B849B897F6D82937D7E7E878081808081807E7C7A807D8183837C7E7E81
8480837E6C61858E7E6C7E7E80827C86817D7F7C7E837F7F7E7E7F7F85787D80
847A808090A27C6C7E8B74797C7A847F797E7F837D817D7C8083807D7D80778C
82827A8183637397837B8A7E817D82838280807C807F7D7D7E75847E82807E8E
837E8584808A926677857C7D817D82808182837B817C7E797F84807E7E7D808A
878281867D7A6E909F808081827E7E897F81878072756E6178857F7F817A7E81
83837C7E7F7C837D668786828083817F7D7D8192837C827C827C8A8381827B84
8785817A7C817B7FA0937783807E817B837E787E817E7B87837D76777E818389
85CC857D7E7F8B78596C95887B887F787F7D7E745F7BB2AB7884817680827C90
90637B8B7A798C868B9574747D807B8279797A7F7F827B80787889867D818384
7A507C78787F877F7B5E85A47F7C7B81867A7A7C767E7F827D79697D87807D81
70688B86757F807F7B8A8C6C85837C7F7E7F7D8279758284526B7C7B7A857B7B
6F76A69697847D71265B8B9476797E847C7D7C7E8182737B81777F84877E7C82
7C776F70857B6191656886668884747D7D7D7C7F828181797E7F7F7E7F807D83
9188817F80884D65A685618C7C76857E7D81837A7C867B80807F867E7F827B83
5F7E88868686806575848F86757A7981877E867E8699787D7F7F80807D7E7D87
866E77777E7A829D6C9C917E68608A7D8080838068AA7D7D7E7980837F7E8688
7B888E84837E877578976689C78472837B85827E7C8C7C847D7C83817F7F7F7E
799385776D747B7E89736F98A980837786828480828F7D7F7680817E857E7A79
737F667E84807A7787606C5C65827885848178737790747A817A8282787D7C8B
768092797A85847E837A827E6A817E808083957D549E7F82817E7C80817F8382
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7191767C7F7B8179837D7E81807E7D80817F7D807E80847E817D7F7C847C817F
8F7D8D79837C847F7D7D867C7F7F807C807E8280817D7C7F827F8381827C807F
6F8D84658979827C7E817E8481827D807F847D7F7E808082847F7D807C807F81
718B7A6E76817E798084848280817F8581838581837E7D7E82817D8382807E80
70747E7C82787E7C847F7E7C81837D807F8383847C7D7E7B7E7D82807D82787F
857481827D7683797D7F7B8381827C837D7C7C807C7F7E7D7F807E817D7D807E
6C8D757B81738D767D837F847F807E7C817D7F808182857D827B7D847D7A857E
7388758A7E6CA076818081827E817C828283837D837E80837D80837F83807E7F
80858285877B8172868182868080817C837F857B837B7F807E81807D827B8183
7E758184898A877B927E7F807B7E7E808181847B807B7D807F7E7E83827C7F7F
877E7F7A888092739673857F837F807F7F81817F7D84807E8082818180847C79
76867F7C828B758E7E6E8A7E848280827C7D817D81827E7B7B827E7C7D81847D
7B84818283867A907B7F837F838082828383848480837F828080827C807F7F81
85817D7982818D7994797F8079827F807F807E7C827A8180818180817E7F807F
837F837B877C8C7B8A807B857A7E8180818082827E8081817F82817D827E7C7E
84857E7D8179878A7484827C83827E7F7F828380837C7E797E7C8181817C7D7F
7F84827E777A8380738476817F7E867F867B807C86787C7C8285808286807F7E
7F7F848778867F7F80797C7F7D8281818279837B838284837D8287818383827D
76897580817C82828281847C7B857C7D82817E887C818175837E7E817E827F81
8175878284837D7E808B867F817E7F807A837C7F8086747B808A81808382837F
8F787C806D86828081818E7887817D847E78877F828386827F7D7D807F81807C
857780867A837F807B817774837B80817C7A7A867C7E887887807C897E817C7F
7782817B6F7F846D8E6C837D7981818281867C83827C7F7B7D7C7383837D7F81
8479797D8577838D7085807A8D787A828480837C827B82807D7C7E817F7F827F
80817985807E826B858498857E7D85817A787A7C7B7F7F85847A837D7F807F84
786E828677827D85807D76867C7A79827B7E7E8183807F8083817E80837E7F80
6B837C85847B877B807F8B767E958179837883828282818280828286827F7E7C
8077848B7F867A84778A6F848B83788E7C7F7B877F837F7B847C8187837E817F
7685818680858586887F80808074887E7B808182837C807980817E857F807E82
7E7F8B7F7E807E82827D7B7C8181787F7B7D7D7F8177838277857A77837D8384
858081827F807E867E778086777B7E7F7D807B7C847A82837E8481837D827E7F
80767D7E7E8083898B767D758C7E817F77877783828A768380817F847C84817E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9195806D8686887F797C7980857F8376847B817B7E828280797C7C7B7D7C827E
6F7B7685727E7B7C7E7F7F8183887E80818784817D807884837C7B817E7F7F83
867F7B7D7D757E7E817D84807D848084837E797B8281827C7F837D7F7E797E7F
8D857B827B7B8E8B877A7F78817D7C85817F7A7F827B83807E7F8182837B8181
737980687982877F7C808683847D7E7C7C817F7D827A7F7B7F867F7982777F79
8285827F8C947B7A84847887817D8385887B81857E7C837F827F7B8285857A83
817B7E8688777B81637D82877F7C7B7F7C80807E837D7E827D81827E7E7B7B81
7275787D7B788A7A89837E7B7E817D83837D86847E7F818084807A7F81867B81
85817A858A8280838A807A7E86847B7A7F80817D7C80797E8282837E807E7E7C
7A8D8B74737B868D76837C827E84828185827B81788182857B80817F80838382
8481767E878A818990758483817F8081807981817A7E837F7C84827E7A80757B
7B85797A827980788785737F7C8080817C857F7C838280817C7889837E7A8281
8186837F7589848483837C7A8583857F837B807F7C7E7F8780857E847E827C7D
827E7A807676797A7D876F897B7E7D827E82847A8380827C7878807F8785807D
817A83807A818A86807A7F84807A7D83837A81827E7D817B83837C7E7D817D81
7476837E75747C8583807E7A867884827B7D7F808A7B847D7A7A80807D847C7E
708182878F81827A7E827B7D8182827F80818182778B837E83867D838178857B
7D79827890818693737F7D848475857C7E857B888A877A7D817A848186788081
7B827D7C827C877C7E7B80827D867989817F7B86827281857E817A827C7F8280
837D86807F7F7A897F8D7682817D87758285837C84877D737E86767C817C837C
81897F7A76706B8586768C827B7D7C8778806B7B837F928D87797880887C7B81
7F807F88887E89817A83777880827D7A827497868383857B8A8B83858A7C827D
7E846D7C777B817B8D7D8980817F7E7F808F6A7E85807A8589767C7F7F7F8481
6E8C968180828F937B7B8784797C808084778B8B6D7B817B86877F8B7C848186
8884818582797271807F7C897E81827680807B7B90A87F788181847880838388
827B7762818A8079827E8F7E7F7F867A82837E807C757E7E848480857A83797E
867E807D8B847C798288877C86887B828A7C7D8483817A7F868282807F7F8483
748780887B817F83738075818C7F847C7B817A7F878285857C7886867F7D7A81
798A84837E807A7693757D76788278818E85837B807E787A808A807D82818586
7A8A7C84817D868275768078828085787A7D798082837E82827F7F827B7A7C81
857E89877A817F8680887B867B7F897C837773877C7B7A847E81828284867F7C
7F887F887E7C806F7281767D82808687738A8C8385807F7D818080797B7D8582
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AF6657968E7D837E70768172776F858B7887898C778179818C878B85797F7E79
7666268A7F7C81807D77888C7E7388727E88877E7D7F7A7D78847A8B82837C82
95AC57B7818DB7787F8782868580767B7A7F88837B8A8D7F787B7D7F7F7A7884
8E887DE99D6688828771787E7E768681858976818C7F7B82937F86818A807B7E
6D656E94A4847D91788E61797A7F8781808093838A7F7D7F7F917C7A979284A0
A2726D7B9D7D7C676176878392727986827F798B798F767F82847B858D868F8C
81538C7B729D8390717F888087757E7A848378837E6E837F807F808082858A81
6A636B8F8495228C859F78797F7977827E887F897877768780878E7C87787475
7D838A857575328A877C8B7D86847D717A7B93737A7F84807D827A798788858F
8E72797A6C89809C7C77817F86767E777B817A826F7A83897C89857B89857D71
878283718E696C9023727889807F75828C847E897F7C79888A7C8586768D7572
7B888286756F898243978B76728B807C808087828170837D7A7A7D807A849286
866A837A7993737C76C7A3877F8C81817D74798C7B7D7F837F79737D89797674
80747888755F79977396CE5E828D877C796B86847A8D817F818184888B7B896A
7A6F7A73707F9D707A7CA0395C899076818B7882817A8B847F8A7B81777E8481
9789877074887270898E7C6D0C748C85797779808081766C7A967E81867D7B82
7E807498757B8F899072818B5A1A778078888B857D876B7E7683858388807977
7C837C7F887A8BA26473937989682184818489A5925C8C8B867D797C887B7B7C
88967092A4727A8F6D6A797077884D2D8273807E6390977E84917C7D757C8373
9683757E6F5192798C7C609B787B972550988574818A75608F78617A7D7F7974
818A8691657365808880AA858281827D31709A807F8778A76DAB9A79698F767A
756F7A7B9179887C86A18E9457797F82703B41849B81709762A5977571717C81
7476B194837880BCB9738A836C82828D78816842777660928A8B74758388837A
8C997E91786F84A37F6C877C64A2A6788775848A96A6726E737F8375877B8476
716056768677816B9E658B807895A9827A7D75788BA06F757F78787A81768080
8B6480678695857C9494BE837A648C7E7B877F78866D76808378887B81848082
96A4867070848A7379708D7C836190503A7F72798284799273888D7981747174
8B8D8C8263A3A1768C76738A5A706C6441627D787B8A7C7F796263807D797187
8C8E8381809382868A7666807F8A7179736F7B7B8A81759382847666707C7C84
769C938588777F6F687383978A8C857C8D6B68967B7073858F7F817B8986788A
8E86778186797F7891847E967C739480A58E8D717B737A798B7E788087807573
887A548B825EA8817683867D7FAC8A6990A2556986647C6E7F77818182998686
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{486, 486},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007V0001iR000`400?l00000o`00003oo`38h=SW
0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW
0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW
0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW
0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW
0<SPf0004`38h=P307emO@@0HV9R0`1]KFd307emO@@0MgMg0`1dM7@307YjNP@0MGEe0`2:RXX309bL
W0<0YjNW102>SXh307emO@<0NGUi101nOWh307YjNP<0Ph>31020P80307YjNP<0PH611023Ph<308:2
PP<0O7al0`1mOGd407YjNP<0N7Qh0`22PX840861P@<0O7al0`25QHD408b<S0<0KVi^1038h=P30;Ng
]`@0n_[j0`1nOWh307QhN0@0Ng]k0`2<S8`307AdM0@0RHV90`21PH4308b<S0<0KFe]1023Ph<3079b
LP<0OWin1029RHT30861P@<0NWYj101mOGd30820P0<0OWin0`1lO7`708F5Q@<0OWin101mOGd308:2
PP<0QHF51023Ph<308:2PP<0O7al101mOGd307=cL`l0b>3H0`2ATI4409FEU@<0P8200`1]KFd708J6
QP<0R8R8101oOgl307UiN@<0O7al0`1iNGT40820P0<0QHF50`1oOgl408>3P`<0MWIf0`24Q8@407]k
N`<0PH610`1kNg/307inOPL0PX:20`20P80407UiN@H0O7al101kNg/307emO@<0O7al1022PX8307in
OP@0b>3H0`2_[jl406IVIP<0EeMG0`2FUYH408j>SP<0OGem0`23Ph<307inOP@0L71`0`1fMWH30861
P@@0LW9b0`1gMgL306m_K`@0QHF50`2;Rh/307QhN0@0QhN70`29RHT308b<S0<0MgMg1021PH4307Ui
N@<0PH61102<S8`308N7Q`<0Rh^;1025QHD307UiN@<0Ogmo101nOWh307UiNA@0b>3H000C0<SPf0<0
OGem101RHV8306e]K@<0OGem101gMgL307AdM0<0NWYj101eMGD308Z:RP<0W9bL0`2WYjL408j>SP<0
OGem0`1iNGT407inOP<0NWYj0`23Ph<40820P0<0NWYj0`21PH4408>3P`<0PX:20`1lO7`307emO@@0
NWYj0`1hN7P308:2PP@0PH610`1lO7`308F5Q@@0S8b<0`1^KVh40<SPf0<0]kNg103jn_X307inOP<0
N7Qh101kNg/308b<S0<0M7Ad1029RHT30861P@<0S8b<0`1]KFd408>3P`<0LW9b0`1nOWh408V9R@<0
PH610`1jNWX407emO@<0P8200`1nOWh307alO0L0QHF50`1nOWh407emO@<0PX:20`25QHD408>3P`<0
PX:20`1lO7`407emO@<0Lg=c3`38h=P3096AT@@0UIFE0`20P80306e]K@L0QXJ60`28R8P407moO`<0
NGUi0`1lO7`307UiN@@0P8200`25QHD307moO`@0Ph>30`1fMWH308B4Q0@0Ng]k0`21PH4307]kN`<0
OWin1`22PX830820P0@0NGUi1P1lO7`407]kN`<0OGem0`1lO7`408:2PP<0OWin1038h=P30:n_[`@0
IVIV0`1GEeL309JFUP@0SXj>0`1mOGd308>3P`<0OWin101`L70307IfMP<0PH61101bLW8307MgM`<0
Kfm_1025QHD308^;R`<0N7Qh1027QhL308V9R@<0S8b<0`1gMgL40861P@<0NGUi0`21PH4408b<S0<0
QhN70`2;Rh/408F5Q@<0NGUi0`1oOgl407inOP<0NGUi5038h=P001<0b>3H0`1mOGd4069RHP<0KFe]
0`1mOGd407MgM`<0M7Ad0`1jNWX407EeM@<0RXZ:0`2LW9`30:NWY`@0SXj>0`1mOGd307UiN@@0OWin
0`1jNWX308>3P`@0P8200`1jNWX30861P@@0Ph>30`22PX8307alO0<0OGem101jNWX307QhN0<0PX:2
1021PH4307alO0<0QHF5102<S8`306i^KP@0b>3H0`2g]kL40?[jnP<0OWin0`1hN7P407]kN`<0S8b<
0`1dM7@408V9R@<0PH610`2<S8`306e]K@@0Ph>30`1bLW8307inOP@0RHV90`21PH4307YjNP@0OGem
0`20P80307inOP<0O7al1`25QHD307inOP@0OGem0`22PX8308F5Q@@0Ph>30`22PX8307alO0@0OGem
0`1cLg<?0<SPf0<0TI6A102EUID30820P0<0KFe]1`26QXH308R8R0@0Ogmo0`1iNGT307alO0<0NGUi
1020P80308F5Q@<0Ogmo1023Ph<307IfMP<0Q8B4101kNg/30861P@<0Ng]k0`1nOWh708:2PP<0P820
101iNGT607alO0@0Ng]k0`1mOGd307alO0@0PX:20`1nOWh40<SPf0<0[jn_101VIVH305MGE`<0UYJF
102>SXh307emO@<0Ph>30`1nOWh4071`L0<0MWIf0`21PH44079bLP<0MgMg0`1_Kfl408F5Q@<0Rh^;
0`1hN7P408N7Q`<0RHV90`2<S8`307MgM`@0PH610`1iNGT30861P@@0S8b<0`27QhL308^;R`@0QHF5
0`1iNGT307moO`@0OWin0`1iNGTD0<SPf0004`38h=P307QhN0@0UiNG0`28R8P308B4Q0@0Ng]k0`1e
MGD309FEU@@0NGUi0`24Q8@30::RXP<0UIFE101lO7`308:2PP<0QHF51023Ph<307emO@<0P8201025
QHD308J6QP<0Ogmo1023Ph<30820P0<0OGem1`1kNg/307alO0<0P8201023Ph<307inOP<0QXJ6102:
RXX3079bLP@0b>3H0`1nOWh4075aL@<0SHf=0`1kNg/408J6QP<0QhN70`28R8P408:2PP<0Lg=c0`23
Ph<307]kN`@0P8200`23Ph<:07inOP<0QhN7101mOGd308:2PPH0O7al1023Ph<307inOP<0R8R81021
PH4308>3P`<0MgMg1022PX8307moO`<0RXZ:1025QHD307AdM0l0b>3H0`1_Kfl407]kN`<0MWIf0`25
QHD4079bLP<0OWin0`1kNg/407alO0<0OWin1P1oOgl40861P@<0Ph>30`28R8P407inOP<0P8200`21
PH4408N7Q`<0Q8B40`21PH4307emO@@0P8200`1hN7P308B4Q0@0Ph>30`1lO7`307]kN`@0PH610`1n
OWh707moO`<0Ph>31038h=P307IfMP@0IVIV0`0V9RH308Z:RP@0Ogmo0`1lO7`30861P@<0P820101m
OGd307MgM`<0R8R8102<S8`307inOP<0Lg=c1028R8P3079bLP<0OWin1028R8P308N7Q`<0OWin0`1m
OGd407moO`<0NWYj0`1mOGd407QhN0<0Q8B40`1jNWX408^;R`<0PX:20`23Ph<407alO0<0PX:25038
h=P001<0b>3H0`1hN7P409NGU`<0R8R80`24Q8@407]kN`<0MGEe0`2EUID407UiN@<0Q8B40`2RXZ83
09FEU@@0O7al0`22PX8308F5Q@@0Ph>30`1mOGd30820P0@0QHF50`26QXH307moO`@0Ph>30`20P803
07emO@L0Ng]k0`1lO7`30820P0@0Ph>30`1nOWh308J6QP@0RXZ:0`1bLW840<SPf0<0OWin101aLG43
08f=S@<0Ng]k1026QXH308N7Q`<0R8R81022PX8307=cL`<0Ph>30`1kNg/40820P0<0Ph>32P1nOWh3
08N7Q`@0OGem0`22PX8607alO0@0Ph>30`1nOWh308R8R0@0PH610`23Ph<307MgM`@0PX:20`1oOgl3
08Z:RP@0QHF50`1dM7@?0<SPf0<0Kfm_101kNg/307IfMP<0QHF5101bLW8307inOP<0Ng]k101lO7`3
07inOPH0Ogmo1021PH4308>3P`<0R8R8101nOWh30820P0<0PH611027QhL308B4Q0<0PH610`1mOGd4
0820P0<0N7Qh0`24Q8@408>3P`<0O7al0`1kNg/40861P@<0OWin1`1oOgl308>3P`@0b>3H0`1fMWH4
06IVIP<09RHV0`2:RXX407moO`<0O7al0`21PH430820P0@0OGem0`1gMgL308R8R0@0S8b<0`1nOWh3
07=cL`@0R8R80`1bLW8307inOP@0R8R80`27QhL307inOP<0OGem101oOgl307YjNP<0OGem101hN7P3
08B4Q0<0NWYj102;Rh/308:2PP<0Ph>3101lO7`308:2PQ@0b>3H000C0<SPf0<0N7Qh102GUiL308R8
R0<0Q8B4101kNg/307EeM@<0UIFE101iNGT308B4Q0<0XZ:R0`2EUID407alO0<0PX:20`25QHD408>3
P`<0OGem0`20P80408F5Q@<0QXJ60`1oOgl408>3P`<0P8200`1mOGd707]kN`<0O7al0`20P80408>3
P`<0OWin0`26QXH408Z:RP<0LW9b1038h=P307inOP@0LG5a0`2=SHd307]kN`@0QXJ60`27QhL308R8
R0@0PX:20`1cLg<308>3P`<0Ng]k1020P80308>3P`X0OWin0`27QhL407emO@<0PX:21P1lO7`408>3
P`<0OWin0`28R8P40861P@<0Ph>30`1gMgL408:2PP<0Ogmo0`2:RXX408F5Q@<0M7Ad3`38h=P306m_
K`@0Ng]k0`1fMWH308F5Q@@0LW9b0`1nOWh307]kN`@0O7al0`1nOWh607moO`@0PH610`23Ph<308R8
R0@0OWin0`20P8030861P@@0QhN70`24Q8@30861P@<0OGem1020P80307QhN0<0Q8B41023Ph<307al
O0<0Ng]k1021PH4307inOPL0Ogmo0`23Ph<40<SPf0<0MWIf101VIVH302HV9P<0RXZ:101oOgl307al
O0<0PH610`20P80407emO@<0MgMg0`28R8P408b<S0<0OWin0`1cLg<408R8R0<0LW9b0`1nOWh408R8
R0<0QhN70`1nOWh307emO@@0Ogmo0`1jNWX307emO@@0N7Qh0`24Q8@307YjNP@0Rh^;0`22PX8308>3
P`@0O7al0`22PX8D0<SPf0004`38h=P307QhN0@0UiNG0`28R8P308B4Q0@0Ng]k0`1eMGD309FEU@@0
NGUi0`24Q8@30::RXP<0UIFE101lO7`308:2PP<0QHF51023Ph<307emO@<0P8201025QHD308J6QP<0
Ogmo1023Ph<30820P0<0OGem1`1kNg/307alO0<0P8201023Ph<307inOP<0QXJ6102:RXX3079bLP@0
b>3H0`1nOWh4075aL@<0SHf=0`1kNg/408J6QP<0QhN70`28R8P408:2PP<0Lg=c0`23Ph<307]kN`@0
P8200`23Ph<:07inOP<0QhN7101mOGd308:2PPH0O7al1023Ph<307inOP<0R8R81021PH4308>3P`<0
MgMg1022PX8307moO`<0RXZ:1025QHD307AdM0l0b>3H0`1_Kfl407]kN`<0MWIf0`25QHD4079bLP<0
OWin0`1kNg/407alO0<0OWin1P1oOgl40861P@<0Ph>30`28R8P407inOP<0P8200`21PH4408N7Q`<0
Q8B40`21PH4307emO@@0P8200`1hN7P308B4Q0@0Ph>30`1lO7`307]kN`@0PH610`1nOWh707moO`<0
Ph>31038h=P307IfMP@0IVIV0`0V9RH308Z:RP@0Ogmo0`1lO7`30861P@<0P820101mOGd307MgM`<0
R8R8102<S8`307inOP<0Lg=c1028R8P3079bLP<0OWin1028R8P308N7Q`<0OWin0`1mOGd407moO`<0
NWYj0`1mOGd407QhN0<0Q8B40`1jNWX408^;R`<0PX:20`23Ph<407alO0<0PX:25038h=P001<0b>3H
0`27QhL407IfMP<0QHF50`2:RXX407alO0<0Q8B40`28R8P407EeM@<0SHf=0`2SXj<307inOP@0NWYj
0`20P80308F5Q@@0OGem1P21PH4408B4Q0<0OWin0`20P80408>3P`H0Ogmo0`1lO7`407inOP<0PX:2
0`21PH4407emO@<0Ogmo0`22PX8407moO`<0Hf=S1038h=P303@d=0@0OWin0`0d=3@303Lg=`@0P820
0`22PX8307UiN@@0N7Qh0`27QhL30861P@<0NGUi101kNg/308:2PP<0PH61101kNg/307QhN0<0QHF5
1023Ph<607emO@<0NGUi1026QXH307]kN`L0QHF50`1nOWh308^;R`L0NWYj0`1lO7`408R8R0<0RXZ:
3`38h=P308J6QP@0Ogmo0`1kNg/707emO@<0MGEe1`1nOWh30861P@<0OGem0`24Q8@40820P0<0OGem
0`24Q8@40820P0<0Q8B40`23Ph<407inOP<0NGUi0`1kNg/308:2PP@0PH610`22PX8307alO0@0Ogmo
0`23Ph<307emO@@0Ogmo0`1nOWh307UiN@@0OWin0`1oOgl40<SPf0<0UIFE102/[:`305MGE`<0]kNg
1021PH4308f=S@<0]kNg0`1hN7P407moO`<0QhN70`22PX8408J6QP<0QHF50`20P80407IfMP<0Ng]k
0`1jNWX407moO`<0R8R80`23Ph<307]kN`@0RXZ:0`2=SHd307moO`@0N7Qh0`1kNg/307emO@L0Ogmo
0`1jNWX407QhN0<0Q8B45038h=P001<0b>3H0`27QhL407IfMP<0QHF50`2:RXX407alO0<0Q8B40`28
R8P407EeM@<0SHf=0`2SXj<307inOP@0NWYj0`20P80308F5Q@@0OGem1P21PH4408B4Q0<0OWin0`20
P80408>3P`H0Ogmo0`1lO7`407inOP<0PX:20`21PH4407emO@<0Ogmo0`22PX8407moO`<0Hf=S1038
h=P303@d=0@0OWin0`0d=3@303Lg=`@0P8200`22PX8307UiN@@0N7Qh0`27QhL30861P@<0NGUi101k
Ng/308:2PP<0PH61101kNg/307QhN0<0QHF51023Ph<607emO@<0NGUi1026QXH307]kN`L0QHF50`1n
OWh308^;R`L0NWYj0`1lO7`408R8R0<0RXZ:3`38h=P308J6QP@0Ogmo0`1kNg/707emO@<0MGEe1`1n
OWh30861P@<0OGem0`24Q8@40820P0<0OGem0`24Q8@40820P0<0Q8B40`23Ph<407inOP<0NGUi0`1k
Ng/308:2PP@0PH610`22PX8307alO0@0Ogmo0`23Ph<307emO@@0Ogmo0`1nOWh307UiN@@0OWin0`1o
Ogl40<SPf0<0UIFE102/[:`305MGE`<0]kNg1021PH4308f=S@<0]kNg0`1hN7P407moO`<0QhN70`22
PX8408J6QP<0QHF50`20P80407IfMP<0Ng]k0`1jNWX407moO`<0R8R80`23Ph<307]kN`@0RXZ:0`2=
SHd307moO`@0N7Qh0`1kNg/307emO@L0Ogmo0`1jNWX407QhN0<0Q8B45038h=P001<0b>3H0`27QhL4
07IfMP<0QHF50`2:RXX407alO0<0Q8B40`28R8P407EeM@<0SHf=0`2SXj<307inOP@0NWYj0`20P803
08F5Q@@0OGem1P21PH4408B4Q0<0OWin0`20P80408>3P`H0Ogmo0`1lO7`407inOP<0PX:20`21PH44
07emO@<0Ogmo0`22PX8407moO`<0Hf=S1038h=P303@d=0@0OWin0`0d=3@303Lg=`@0P8200`22PX83
07UiN@@0N7Qh0`27QhL30861P@<0NGUi101kNg/308:2PP<0PH61101kNg/307QhN0<0QHF51023Ph<6
07emO@<0NGUi1026QXH307]kN`L0QHF50`1nOWh308^;R`L0NWYj0`1lO7`408R8R0<0RXZ:3`38h=P3
08J6QP@0Ogmo0`1kNg/707emO@<0MGEe1`1nOWh30861P@<0OGem0`24Q8@40820P0<0OGem0`24Q8@4
0820P0<0Q8B40`23Ph<407inOP<0NGUi0`1kNg/308:2PP@0PH610`22PX8307alO0@0Ogmo0`23Ph<3
07emO@@0Ogmo0`1nOWh307UiN@@0OWin0`1oOgl40<SPf0<0UIFE102/[:`305MGE`<0]kNg1021PH43
08f=S@<0]kNg0`1hN7P407moO`<0QhN70`22PX8408J6QP<0QHF50`20P80407IfMP<0Ng]k0`1jNWX4
07moO`<0R8R80`23Ph<307]kN`@0RXZ:0`2=SHd307moO`@0N7Qh0`1kNg/307emO@L0Ogmo0`1jNWX4
07QhN0<0Q8B45038h=P001<0b>3H0`1bLW8408b<S0<0Ti>C0`1VIVH407moO`<0Ph>30`1jNWX407em
O@<0UYJF0`2SXj<307]kN`@0PH610`23Ph<30820P0@0OWin0`1mOGd307QhN0@0Ogmo0`21PH430820
P0@0PX:20`29RHT307inOP<0O7al1022PX8307inOP<0PH61101oOgl307YjNP<0Ogmo101kNg/307em
O@@0b>3H0`28R8P409>CT`<0L71`0`1]KFd407=cL`<0QhN70`22PX84079bLP<0MgMg1P1lO7`407If
MP<0O7al0`20P80407moO`<0P8200`1lO7`408>3P`<0PX:21P21PH4407inOP<0OGem0`25QHD408N7
Q`<0Ogmo0`26QXH707emO@<0O7al101iNGT307moO`l0b>3H0`2=SHd408F5Q@<0Ng]k0`22PX8707]k
N`<0SXj>102;Rh/308N7Q`<0NWYj0`1oOgl407QhN0<0PH610`1mOGd407alO0<0QHF50`21PH4407mo
O`<0NWYj0`1oOgl308:2PP@0Ng]k0`23Ph<30820P0@0OWin0`1oOgl30861P@@0PX:20`23Ph<307]k
N`L0PH611038h=P308j>SP@0R8R80`1mOGd30>WYj@@0WIfM0`1VIVH308R8R0<0PX:21027QhL3075a
L@<0N7Qh1`1nOWh307IfMP@0QXJ60`21PH4308F5Q@@0RHV90`1fMWH30861P@<0S8b<101oOgl307]k
N`<0PX:2102CTi<307moO`<0QXJ61021PH4308Z:RP<0P820101kNg/307inOQ@0b>3H000C0<SPf0<0
LW9b102<S8`309>CT`<0IVIV101oOgl308>3P`<0NWYj101mOGd309JFUP<0Xj>S0`1kNg/40861P@<0
Ph>30`20P80407inOP<0OGem0`1hN7P407moO`<0PH610`20P80408:2PP<0RHV90`1nOWh307alO0@0
PX:20`1nOWh30861P@@0Ogmo0`1jNWX307moO`@0Ng]k0`1mOGd40<SPf0<0R8R8102CTi<3071`L0<0
KFe]101cLg<308N7Q`<0PX:2101bLW8307MgM`H0O7al101fMWH307alO0<0P820101oOgl30820P0<0
O7al1023Ph<308:2PPH0PH61101nOWh307emO@<0QHF51027QhL307moO`<0QXJ61`1mOGd307alO0@0
NGUi0`1oOgl?0<SPf0<0SHf=1025QHD307]kN`<0PX:21`1kNg/308j>SP@0Rh^;0`27QhL307YjNP<0
Ogmo101hN7P30861P@<0OGem101lO7`308F5Q@<0PH61101oOgl307YjNP<0Ogmo0`22PX8407]kN`<0
Ph>30`20P80407inOP<0Ogmo0`21PH4408:2PP<0Ph>30`1kNg/70861P@@0b>3H0`2>SXh408R8R0<0
OGem0`3YjNT409fMW@<0IVIV0`28R8P308:2PP@0QhN70`1aLG4307QhN0L0OWin0`1fMWH408J6QP<0
PH610`25QHD408V9R@<0MWIf0`21PH4308b<S0@0Ogmo0`1kNg/308:2PP@0Ti>C0`1oOgl308J6QP@0
PH610`2:RXX30820P0@0Ng]k0`1nOWhD0<SPf0004`38h=P3079bLP@0S8b<0`2CTi<306IVIP@0Ogmo
0`23Ph<307YjNP@0OGem0`2FUYH30:>SX`<0Ng]k1021PH4308>3P`<0P820101nOWh307emO@<0N7Qh
101oOgl30861P@<0P8201022PX8308V9R@<0OWin0`1lO7`408:2PP<0OWin0`21PH4407moO`<0NWYj
0`1oOgl407]kN`<0OGem1038h=P308R8R0@0Ti>C0`1`L70306e]K@@0Lg=c0`27QhL308:2PP@0LW9b
0`1gMgL607alO0@0MWIf0`1lO7`30820P0@0Ogmo0`20P80307alO0@0Ph>30`22PX860861P@@0OWin
0`1mOGd308F5Q@@0QhN70`1oOgl308J6QPL0OGem0`1lO7`407UiN@<0Ogmo3`38h=P308f=S@@0QHF5
0`1kNg/308:2PPL0Ng]k0`2>SXh408^;R`<0QhN70`1jNWX307moO`@0N7Qh0`21PH4307emO@@0O7al
0`25QHD30861P@@0Ogmo0`1jNWX307moO`<0PX:2101kNg/308>3P`<0P820101nOWh307moO`<0PH61
1022PX8308>3P`<0Ng]k1`21PH440<SPf0<0SXj>1028R8P307emO@<0jNWY102MWId306IVIP<0R8R8
0`22PX8408N7Q`<0LG5a0`1hN7P707inOP<0MWIf1026QXH30861P@<0QHF51029RHT307IfMP<0PH61
0`2<S8`407moO`<0Ng]k0`22PX8409>CT`<0Ogmo0`26QXH40861P@<0RXZ:0`20P80407]kN`<0OWin
5038h=P001<0b>3H0`1eMGD408F5Q@<0Ogmo0`1dM7@4071`L0<0Ogmo0`24Q8@408>3P`<0UiNG0`2>
SXh307IfMP@0NGUi0`1mOGd30861P@@0OWin0`1oOgl307alO0@0Ogmo0`20P80307alO0@0QXJ60`27
QhL307emO@L0P8200`23Ph<307alO0@0P8200`1oOgl307emO@@0P8200`22PX840<SPf0<0WinO101/
K6`308V9R@<0UiNG102_[jl307MgM`<0PH611023Ph<608R8R0<0PX:2101lO7`307MgM`<0Rh^;101n
OWh308>3P`<0P820101oOgl307inOP<0Q8B40`23Ph<707emO@<0P820101nOWh307YjNP<0QXJ61025
QHD307MgM`<0QHF5101mOGd307UiN@l0b>3H0`1cLg<407UiN@<0P8200`1XJ6P407UiN@<0PX:20`27
QhL407moO`<0O7al0`20P80308J6QP@0Ph>30`24Q8@307emO@@0OWin1P1lO7`40861P@<0Ogmo0`1m
OGd308:2PP@0NWYj0`1oOgl307]kN`@0Ogmo0`26QXH307moO`@0NGUi0`22PX8307MgM`@0Ogmo0`1i
NGT40<SPf0<0KFe]101UIFD306i^KP<0U9BD102TY:@308B4Q0<0OGem0`2ATI4407QhN0<0SXj>0`1Q
HF4407UiN@<0NWYj0`1oOgl408N7Q`<0PH611`20P80309>CT`<0Ph>30`2:RXX407moO`<0OGem1`1o
Ogl3096AT@<0O7al101jNWX309NGU`<0TY:B1024Q8@30:2PX1@0b>3H000C0<SPf0<0MGEe1025QHD3
07moO`<0M7Ad101`L70307moO`<0Q8B41023Ph<309NGU`<0SXj>0`1fMWH407UiN@<0OGem0`21PH44
07inOP<0Ogmo0`1lO7`407moO`<0P8200`1lO7`408J6QP<0QhN70`1mOGd70820P0<0Ph>30`1lO7`4
0820P0<0Ogmo0`1mOGd40820P0<0PX:21038h=P309nOW`@0K6a/0`29RHT309NGU`@0[jn_0`1gMgL3
0861P@@0Ph>31P28R8P308:2PP@0O7al0`1gMgL308^;R`@0OWin0`23Ph<30820P0@0Ogmo0`1nOWh3
08B4Q0<0Ph>31`1mOGd30820P0@0OWin0`1jNWX308J6QP@0QHF50`1gMgL308F5Q@@0OGem0`1iNGT?
0<SPf0<0Lg=c101iNGT30820P0<0J6QX101iNGT308:2PP<0QhN7101oOgl307alO0<0P8200`26QXH4
08>3P`<0Q8B40`1mOGd407inOPH0O7al1021PH4307moO`<0OGem0`22PX8407YjNP<0Ogmo0`1kNg/4
07moO`<0QXJ60`1oOgl407UiN@<0PX:20`1gMgL407moO`<0NGUi1038h=P306e]K@@0IFEU0`1^KVh3
09BDU0@0Y:BT0`24Q8@307emO@<0TI6A101hN7P308j>SP<0HF5Q101iNGT307YjNP<0Ogmo1027QhL3
0861P@L0P8200`2CTi<308>3P`<0RXZ:101oOgl307emO@L0Ogmo0`2ATI4307alO0@0NWYj0`2GUiL3
09:BTP@0Q8B40`2PX:0D0<SPf0004`38h=P307EeM@@0QHF50`1oOgl307AdM0@0L71`0`1oOgl308B4
Q0@0Ph>30`2GUiL308j>SP<0MWIf101iNGT307emO@<0PH61101nOWh307moO`<0O7al101oOgl30820
P0<0O7al1026QXH308N7Q`<0OGem1`20P80308>3P`<0O7al1020P80307moO`<0OGem1020P80308:2
PP@0b>3H0`2OWil406a/K0<0RHV90`2GUiL40:n_[`<0MgMg0`21PH4408>3P`H0R8R80`22PX8407al
O0<0MgMg0`2;Rh/407inOP<0Ph>30`20P80407moO`<0OWin0`24Q8@308>3P`L0OGem0`20P80407in
OP<0NWYj0`26QXH408F5Q@<0MgMg0`25QHD407emO@<0NGUi3`38h=P307=cL`@0NGUi0`20P80306QX
J0@0NGUi0`22PX8308N7Q`@0Ogmo0`1lO7`30820P0<0QXJ61023Ph<308B4Q0<0OGem101nOWh607al
O0@0PH610`1oOgl307emO@<0PX:2101jNWX307moO`<0Ng]k101oOgl308J6QP<0Ogmo101iNGT308:2
PP<0MgMg101oOgl307UiN@@0b>3H0`1]KFd406EUI@<0KVi^0`2DU9@40:BTY0<0Q8B40`1mOGd3096A
T@@0N7Qh0`2>SXh3065QH@@0NGUi0`1jNWX307moO`@0QhN70`21PH470820P0<0Ti>C0`23Ph<308Z:
RP@0Ogmo0`1mOGd707moO`<0TI6A0`1lO7`407YjNP<0UiNG0`2BTY8408B4Q0<0X:2P5038h=P001<0
b>3H0`1QHF4405aLG0<0PH610`1jNWX409>CT`<0N7Qh0`21PH4408:2PP<0TI6A0`2BTY8307QhN0@0
OWin0`1lO7`308:2PP@0P8200`1nOWh30820P0@0PX:20`25QHD308:2PP@0Ph>30`21PH4307moO`<0
P820101oOgl308:2PP<0RHV9102:RXX308J6QP<0OWin101mOGd308V9R@@0b>3H0`1QHF440:6QX@<0
LW9b0`21PH4408V9R@<0Rh^;0`1mOGd4096AT@<0V9RH1P2:RXX40820P0<0Ph>30`1nOWh40820P0<0
Ng]k0`1gMgL407inOP<0MWIf0`2=SHd308J6QP@0Ph>30`1kNg/307inOP@0Q8B40`1iNGT30861P@@0
Ph>31P2=SHd408Z:RP<0Shn?3`38h=P308:2PP@0QHF50`22PX8307moO`@0S8b<0`2DU9@307]kN`@0
NWYj1P24Q8@307QhN0@0QhN70`21PH4307emO@@0Ph>30`25QHD308R8R0@0Ng]k0`21PH4308F5Q@<0
OWin101lO7`308>3P`<0Ogmo1022PX8307moO`<0Ng]k1022PX8608F5Q@@0NWYj0`23Ph<40<SPf0<0
XZ:R101bLW8306e]K@<0Ng]k102MWId307emO@<0O7al0`1WIfL4065QH@<0MWIf0`27QhL408>3P`<0
TY:B0`1bLW8407UiN@<0QXJ60`22PX8407moO`<0NGUi0`2;Rh/307UiN@@0Shn?0`1fMWH307moO`@0
PX:20`24Q8@307]kN`@0QHF50`2=SHd308J6QP@0Shn?0`2<S8`D0<SPf0004`38h=P3065QH@@0G5aL
0`21PH4307YjNP@0Ti>C0`1hN7P30861P@@0PX:20`2ATI4309:BTP<0N7Qh101nOWh307alO0<0PX:2
1020P80307inOP<0P8201022PX8308F5Q@<0PX:21023Ph<30861P@<0Ogmo0`20P80407moO`<0PX:2
0`29RHT408Z:RP<0QXJ60`1nOWh407emO@<0RHV91038h=P3065QH@@0XJ6Q0`1bLW830861P@@0RHV9
0`2;Rh/307emO@@0TI6A0`2HV9P608Z:RP@0P8200`23Ph<307inOP@0P8200`1kNg/307MgM`@0OWin
0`1fMWH308f=S@<0QXJ61023Ph<307]kN`<0OWin1024Q8@307UiN@<0PH611023Ph<608f=S@@0RXZ:
0`2?Shl?0<SPf0<0PX:21025QHD308:2PP<0Ogmo102<S8`309BDU0<0Ng]k101jNWX608B4Q0<0N7Qh
1027QhL30861P@<0OGem1023Ph<308F5Q@<0R8R8101kNg/30861P@<0QHF50`1nOWh407alO0<0Ph>3
0`1oOgl408:2PP<0Ogmo0`1kNg/408:2PPH0QHF5101jNWX308>3P`@0b>3H0`2RXZ84079bLP<0KFe]
0`1kNg/409fMW@<0OGem0`1lO7`306MWI`@0HF5Q0`1fMWH308N7Q`@0Ph>30`2BTY83079bLP@0NGUi
0`26QXH308:2PP@0Ogmo0`1iNGT308^;R`<0NGUi102?Shl307IfMP<0Ogmo1022PX8308B4Q0<0Ng]k
1025QHD308f=S@<0QXJ6102?Shl308b<S1@0b>3H000C0<SPf0<0HF5Q101LG5`30861P@<0NWYj102C
Ti<307QhN0<0PH611022PX83096AT@<0TY:B0`1hN7P407inOP<0O7al0`22PX840820P0<0OWin0`20
P80408:2PP<0QHF50`22PX8408>3P`<0PH610`1oOgl30820P0@0Ogmo0`22PX8308V9R@@0RXZ:0`26
QXH307inOP@0OGem0`29RHT40<SPf0<0HF5Q102QXJ43079bLP<0PH611029RHT308^;R`<0OGem102A
TI4309RHV0H0RXZ:1020P80308>3P`<0OWin1020P80307]kN`<0MgMg101nOWh307IfMP<0SHf=0`26
QXH408>3P`<0Ng]k0`1nOWh408B4Q0<0NGUi0`21PH4408>3P`H0SHf=102:RXX308n?S`l0b>3H0`22
PX8408F5Q@<0PX:20`1oOgl408b<S0<0U9BD0`1kNg/407YjNPH0Q8B40`1hN7P408N7Q`<0PH610`1m
OGd408>3P`<0QHF50`28R8P407]kN`<0PH610`25QHD307inOP@0O7al0`23Ph<307moO`@0PX:20`1o
Ogl307]kN`@0PX:21P25QHD407YjNP<0Ph>31038h=P30::RXP@0LW9b0`1]KFd307]kN`@0WIfM0`1m
OGd307alO0<0IfMW101QHF4307IfMP<0QhN71023Ph<309:BTP<0LW9b101iNGT308J6QP<0PX:2101o
Ogl307UiN@<0Rh^;0`1iNGT408n?S`<0MWIf0`1oOgl408:2PP<0Q8B40`1kNg/408F5Q@<0SHf=0`26
QXH408n?S`<0S8b<5038h=P001<0b>3H0`1QHF4405aLG0<0PH610`1jNWX409>CT`<0N7Qh0`21PH44
08:2PP<0TI6A0`2BTY8307QhN0@0OWin0`1lO7`308:2PP@0P8200`1nOWh30820P0@0PX:20`25QHD3
08:2PP@0Ph>30`21PH4307moO`<0P820101oOgl308:2PP<0RHV9102:RXX308J6QP<0OWin101mOGd3
08V9R@@0b>3H0`1QHF440:6QX@<0LW9b0`21PH4408V9R@<0Rh^;0`1mOGd4096AT@<0V9RH1P2:RXX4
0820P0<0Ph>30`1nOWh40820P0<0Ng]k0`1gMgL407inOP<0MWIf0`2=SHd308J6QP@0Ph>30`1kNg/3
07inOP@0Q8B40`1iNGT30861P@@0Ph>31P2=SHd408Z:RP<0Shn?3`38h=P308:2PP@0QHF50`22PX83
07moO`@0S8b<0`2DU9@307]kN`@0NWYj1P24Q8@307QhN0@0QhN70`21PH4307emO@@0Ph>30`25QHD3
08R8R0@0Ng]k0`21PH4308F5Q@<0OWin101lO7`308>3P`<0Ogmo1022PX8307moO`<0Ng]k1022PX86
08F5Q@@0NWYj0`23Ph<40<SPf0<0XZ:R101bLW8306e]K@<0Ng]k102MWId307emO@<0O7al0`1WIfL4
065QH@<0MWIf0`27QhL408>3P`<0TY:B0`1bLW8407UiN@<0QXJ60`22PX8407moO`<0NGUi0`2;Rh/3
07UiN@@0Shn?0`1fMWH307moO`@0PX:20`24Q8@307]kN`@0QHF50`2=SHd308J6QP@0Shn?0`2<S8`D
0<SPf0004`38h=P308j>SP@0W9bL0`1gMgL308>3P`@0P8201P2;Rh/407moO`<0VYZJ0`2IVIT307in
OP@0NGUi0`1nOWh307moO`@0O7al0`1mOGd30861P@@0OWin0`26QXH307alO0@0Ph>30`1oOgl307al
O0<0Ogmo1021PH4308B4Q0<0PH611024Q8@307]kN`<0OWin1020P80307emO@@0b>3H0`2BTY840:2P
X0<0L71`0`23Ph<4096AT@<0Fe]K0`2>SXh408N7Q`<0OWin0`1fMWH307emO@@0L71`0`2:RXX307If
MP@0O7al0`26QXH308R8R0@0NWYj0`1fMWH30820P0<0SHf=1020P80308R8R0<0Ogmo1021PH4308:2
PP<0QhN71020P80307emO@<0PH611025QHD307QhN0l0b>3H0`21PH4407]kN`<0OWin0`26QXH408R8
R0<0MgMg0`1kNg/40861P@<0Hf=S0`1mOGd308:2PP@0QhN70`1oOgl307alO0@0Ng]k0`1oOgl307al
O0L0P8200`1nOWh308>3P`@0OGem0`1nOWh308:2PP@0OGem0`21PH4308:2PPL0OWin1`1kNg/30861
P@@0b>3H0`21PH4405=CD`<0S8b<0`1kNg/4079bLP<0WIfM0`23Ph<3092@T0@0LG5a0`1oOgl308R8
R0@0P8200`27QhL307EeM@@0OWin0`1jNWX308B4Q0@0Ph>30`1hN7P308>3P`<0OWin101^KVh308>3
P`<0Ogmo1020P80307moO`L0P8200`22PX8308F5Q@@0RXZ:0`21PH4D0<SPf0004`38h=P308j>SP@0
W9bL0`1gMgL308>3P`@0P8201P2;Rh/407moO`<0VYZJ0`2IVIT307inOP@0NGUi0`1nOWh307moO`@0
O7al0`1mOGd30861P@@0OWin0`26QXH307alO0@0Ph>30`1oOgl307alO0<0Ogmo1021PH4308B4Q0<0
PH611024Q8@307]kN`<0OWin1020P80307emO@@0b>3H0`2BTY840:2PX0<0L71`0`23Ph<4096AT@<0
Fe]K0`2>SXh408N7Q`<0OWin0`1fMWH307emO@@0L71`0`2:RXX307IfMP@0O7al0`26QXH308R8R0@0
NWYj0`1fMWH30820P0<0SHf=1020P80308R8R0<0Ogmo1021PH4308:2PP<0QhN71020P80307emO@<0
PH611025QHD307QhN0l0b>3H0`21PH4407]kN`<0OWin0`26QXH408R8R0<0MgMg0`1kNg/40861P@<0
Hf=S0`1mOGd308:2PP@0QhN70`1oOgl307alO0@0Ng]k0`1oOgl307alO0L0P8200`1nOWh308>3P`@0
OGem0`1nOWh308:2PP@0OGem0`21PH4308:2PPL0OWin1`1kNg/30861P@@0b>3H0`21PH4405=CD`<0
S8b<0`1kNg/4079bLP<0WIfM0`23Ph<3092@T0@0LG5a0`1oOgl308R8R0@0P8200`27QhL307EeM@@0
OWin0`1jNWX308B4Q0@0Ph>30`1hN7P308>3P`<0OWin101^KVh308>3P`<0Ogmo1020P80307moO`L0
P8200`22PX8308F5Q@@0RXZ:0`21PH4D0<SPf0004`38h=P308j>SP@0W9bL0`1gMgL308>3P`@0P820
1P2;Rh/407moO`<0VYZJ0`2IVIT307inOP@0NGUi0`1nOWh307moO`@0O7al0`1mOGd30861P@@0OWin
0`26QXH307alO0@0Ph>30`1oOgl307alO0<0Ogmo1021PH4308B4Q0<0PH611024Q8@307]kN`<0OWin
1020P80307emO@@0b>3H0`2BTY840:2PX0<0L71`0`23Ph<4096AT@<0Fe]K0`2>SXh408N7Q`<0OWin
0`1fMWH307emO@@0L71`0`2:RXX307IfMP@0O7al0`26QXH308R8R0@0NWYj0`1fMWH30820P0<0SHf=
1020P80308R8R0<0Ogmo1021PH4308:2PP<0QhN71020P80307emO@<0PH611025QHD307QhN0l0b>3H
0`21PH4407]kN`<0OWin0`26QXH408R8R0<0MgMg0`1kNg/40861P@<0Hf=S0`1mOGd308:2PP@0QhN7
0`1oOgl307alO0@0Ng]k0`1oOgl307alO0L0P8200`1nOWh308>3P`@0OGem0`1nOWh308:2PP@0OGem
0`21PH4308:2PPL0OWin1`1kNg/30861P@@0b>3H0`21PH4405=CD`<0S8b<0`1kNg/4079bLP<0WIfM
0`23Ph<3092@T0@0LG5a0`1oOgl308R8R0@0P8200`27QhL307EeM@@0OWin0`1jNWX308B4Q0@0Ph>3
0`1hN7P308>3P`<0OWin101^KVh308>3P`<0Ogmo1020P80307moO`L0P8200`22PX8308F5Q@@0RXZ:
0`21PH4D0<SPf0004`38h=P308J6QP@0MGEe0`1iNGT309BDU0@0T92@0`25QHD308J6QP@0OGem0`2?
Shl30:BTY0<0SXj>101kNg/308>3P`<0QXJ6101nOWh308:2PP<0QhN7101jNWX308B4Q0<0P820101m
OGd30861P@<0PX:20`26QXH407emO@<0PH610`1oOgl407inOP<0Ogmo0`1iNGT408F5Q@<0R8R81038
h=P309JFUP@0Ng]k0`2DU9@309>CT`@0GemO0`2YZJT30=[JfP@0QhN70`1jNWX308B4Q0<0PH61101o
Ogl30861P@<0N7Qh1026QXH308N7Q`<0M7Ad1024Q8@307moO`<0Ph>30`22PX8407EeM@<0PH610`22
PX8408>3P`<0RHV90`1mOGd407UiN@<0OWin0`21PH4407alO0<0LW9b3`38h=P3079bLP@0MGEe0`1h
N7P307emO@@0Ng]k0`1hN7P308Z:RP@0NWYj0`29RHT308>3P`<0OWin101kNg/307inOP<0PH61101m
OGd608>3P`@0OGem0`26QXH308B4Q0<0OWin101oOgl30861P@<0P8201024Q8@30820P0<0NWYj101o
Ogl30861P@<0QXJ6101kNg/30861P@@0b>3H0`1ZJVX406=SH`<0Jf][0`2?Shl408B4Q0<0UIFE0`0R
8R8308b<S0@0QHF50`2OWil307QhN0@0NGUi0`1oOgl307UiN@@0MgMg0`22PX8307inOP@0R8R80`1o
Ogl308V9R@<0N7Qh101gMgL307IfMP<0QhN71020P80308N7Q`<0SXj>101lO7`308N7Q`<0N7Qh101d
M7@307EeMA@0b>3H000C0<SPf0<0QXJ6101eMGD307UiN@<0U9BD102@T90308F5Q@<0QXJ6101mOGd3
08n?S`<0Y:BT0`2>SXh407]kN`<0Ph>30`26QXH407inOP<0PX:20`27QhL407YjNP<0Q8B40`20P804
07emO@<0PH610`22PX8308J6QP@0OGem0`21PH4307moO`@0OWin0`1oOgl307UiN@@0QHF50`28R8P4
0<SPf0<0UYJF101kNg/309BDU0<0Ti>C101OGel30:VYZ@<0f][J1027QhL307YjNP<0Q8B40`21PH44
07moO`<0PH610`1hN7P408J6QP<0QhN70`1dM7@408B4Q0<0Ogmo0`23Ph<308:2PP@0MGEe0`21PH43
08:2PP@0Ph>30`29RHT307emO@@0NGUi0`1nOWh30861P@@0O7al0`1bLW8?0<SPf0<0LW9b101eMGD3
07QhN0<0OGem101kNg/307QhN0<0RXZ:101jNWX308V9R@<0Ph>30`1nOWh407]kN`<0OWin0`21PH44
07emO@H0Ph>3101mOGd308J6QP<0Q8B40`1nOWh407moO`<0PH610`20P80408B4Q0<0P8200`1jNWX4
07moO`<0PH610`26QXH407]kN`<0PH611038h=P306YZJP@0Hf=S0`1[Jf/308n?S`@0Q8B40`2EUID3
028R8P<0S8b<1025QHD309nOW`<0N7Qh101iNGT307moO`<0NGUi101gMgL308:2PP<0OWin1028R8P3
07moO`<0RHV90`1hN7P407MgM`<0MWIf0`27QhL40820P0<0QhN70`2>SXh407alO0<0QhN70`1hN7P4
07AdM0<0MGEe5038h=P001<0b>3H0`26QXH407EeM@<0NGUi0`2DU9@4092@T0<0QHF50`26QXH407em
O@<0Shn?0`2TY:@308j>SP@0Ng]k0`23Ph<308J6QP@0OWin0`22PX8308N7Q`@0NWYj0`24Q8@30820
P0@0OGem0`21PH4308:2PP<0QXJ6101mOGd30861P@<0Ogmo101nOWh307moO`<0NGUi1025QHD308R8
R0@0b>3H0`2FUYH407]kN`<0U9BD0`2CTi<405mOG`<0ZJVY0`3Jf]X408N7Q`<0NWYj0`24Q8@30861
P@@0Ogmo0`21PH4307QhN0@0QXJ60`27QhL307AdM0@0Q8B40`1oOgl308>3P`<0PX:2101eMGD30861
P@<0PX:21023Ph<308V9R@<0OGem101iNGT307inOP<0PH61101lO7`3079bLPl0b>3H0`1bLW8407Ee
M@<0N7Qh0`1mOGd407]kN`<0N7Qh0`2:RXX407YjNP<0RHV90`23Ph<307inOP@0Ng]k0`1nOWh30861
P@@0OGem1P23Ph<407emO@<0QXJ60`24Q8@307inOP@0Ogmo0`21PH430820P0@0Q8B40`20P80307Yj
NP@0Ogmo0`21PH4308J6QP@0Ng]k0`21PH440<SPf0<0JVYZ101SHf<306][J`<0Shn?1024Q8@309FE
U@<08R8R0`2<S8`408F5Q@<0WinO0`1hN7P407UiN@<0Ogmo0`1iNGT407MgM`<0PX:20`1nOWh408R8
R0<0Ogmo0`29RHT307QhN0@0MgMg0`1fMWH308N7Q`@0P8200`27QhL308j>SP@0O7al0`27QhL307Qh
N0@0M7Ad0`1eMGDD0<SPf0004`38h=P30:>SX`@0RHV90`1YJFT306][J`@0Hf=S0`1_Kfl308:2PP@0
RXZ:0`2<S8`30:BTY0<0RXZ:1025QHD307alO0<0Ng]k1022PX8307moO`<0O7al101kNg/307alO0<0
OWin1021PH4307moO`H0NWYj101mOGd30861P@<0O7al1`21PH4307alO0@0PH610`23Ph<40<SPf0<0
Ti>C102;Rh/606QXJ0@0Ogmo0`2FUYH304];B`@0>c/k0`25QHD3092@T0<0RHV9101kNg/307QhN0<0
MgMg1026QXH30820P0<0O7al101fMWH308:2PP<0MWIf0`1oOgl407YjNPH0PH611023Ph<30820P0<0
Ogmo1024Q8@307]kN`<0Ogmo1022PX830861P@l0b>3H0`25QHD40861P@<0NWYj0`25QHD408Z:RP<0
PX:20`20P80408>3P`<0RXZ:0`20P80307YjNP@0OWin0`26QXH308B4Q0@0Ng]k0`1jNWX307moO`@0
P8200`21PH4307emO@<0O7al1020P80307UiN@<0OWin1`22PX8308>3P`@0OWin0`20P80707inOP<0
O7al1038h=P307emO@@0Ph>30`2:RXX308F5Q@L0MGEe0`0b<S8308Z:RP@0QhN70`1lO7`308^;R`@0
OGem0`26QXH308B4Q0@0OGem0`1aLG4307YjNP@0Ng]k0`2CTi<307=cL`<0NWYj101oOgl308B4Q0<0
P820101mOGd308:2PP<0NWYj101iNGT308N7Q`<0R8R81025QHD308n?Sa@0b>3H000C0<SPf0<0Xj>S
1029RHT306UYJ@<0Jf][101SHf<306m_K`<0PX:2102:RXX308b<S0<0Y:BT0`2:RXX408F5Q@<0O7al
0`1kNg/408:2PP<0Ogmo0`1lO7`407]kN`<0O7al0`1nOWh40861P@<0Ogmo1P1jNWX407emO@<0PH61
0`1lO7`70861P@<0O7al1021PH4308>3P`@0b>3H0`2CTi<408^;R`H0J6QX101oOgl309JFUP<0Bd];
100k>c/308F5Q@<0T92@0`29RHT407]kN`<0N7Qh0`1gMgL408J6QP<0P8200`1lO7`407IfMP<0PX:2
0`1fMWH307moO`@0NWYj1P21PH4408>3P`<0P8200`1oOgl408B4Q0<0Ng]k0`1oOgl408:2PP<0PH61
3`38h=P308F5Q@@0PH610`1jNWX308F5Q@@0RXZ:0`22PX830820P0@0Ph>30`2:RXX30820P0<0NWYj
101nOWh308J6QP<0Q8B4101kNg/307YjNP<0Ogmo1020P8030861P@<0OGem0`1lO7`40820P0<0NGUi
0`1nOWh708:2PP<0Ph>3101nOWh30820P0L0OWin0`1lO7`40<SPf0<0OGem1023Ph<308Z:RP<0QHF5
1`1eMGD3038b<P<0RXZ:1027QhL307alO0<0Rh^;101mOGd308J6QP<0Q8B4101mOGd3075aL@<0NWYj
101kNg/309>CT`<0Lg=c0`1jNWX407moO`<0Q8B40`20P80407emO@<0PX:20`1jNWX407UiN@<0QhN7
0`28R8P408F5Q@<0Shn?5038h=P001<0b>3H0`2SXj<408V9R@<0JFUY0`1[Jf/406=SH`<0Kfm_0`22
PX8408Z:RP<0S8b<0`2TY:@308Z:RP@0QHF50`1lO7`307]kN`@0PX:20`1oOgl307alO0@0Ng]k0`1l
O7`307inOP@0PH610`1oOgl607YjNP@0OGem0`21PH4307alO0L0PH610`1lO7`40861P@<0Ph>31038
h=P309>CT`@0Rh^;1P1XJ6P407moO`<0UYJF0`1;Bd/403/k>`<0QHF50`2@T90308V9R@@0Ng]k0`1h
N7P307MgM`@0QXJ60`20P80307alO0@0MWIf0`22PX8307IfMP<0Ogmo101jNWX60861P@@0Ph>30`20
P80307moO`@0Q8B40`1kNg/307moO`@0PX:20`21PH4?0<SPf0<0QHF51021PH4307YjNP<0QHF5102:
RXX308:2PP<0P8201023Ph<308Z:RP<0P8200`1jNWX407inOP<0QXJ60`24Q8@407]kN`<0NWYj0`1o
Ogl40820P0<0PH610`1mOGd307alO0@0P8200`1iNGT307inOPL0PX:20`23Ph<407inOP<0P8201`1n
OWh307alO0@0b>3H0`1mOGd408>3P`<0RXZ:0`25QHD707EeM@<0<S8b0`2:RXX408N7Q`<0O7al0`2;
Rh/407emO@<0QXJ60`24Q8@407emO@<0LG5a0`1jNWX407]kN`<0Ti>C0`1cLg<307YjNP@0Ogmo0`24
Q8@30820P0@0OGem0`22PX8307YjNP@0NGUi0`27QhL308R8R0@0QHF50`2?ShlD0<SPf0004`38h=P3
08R8R0@0O7al0`2:RXX30:>SX`@0PX:20`2GUiL307alO0@0J6QX0`23Ph<30:>SX`<0O7al1023Ph<3
07UiN@<0Ph>31022PX830861P@<0Ph>31020P80307emO@<0P820101iNGT307emO@<0OWin0`23Ph<4
07emO@<0OWin0`1oOgl408>3P`<0P8200`1lO7`407moO`<0QHF51038h=P306YZJP@0FUYJ0`2:RXX3
092@T0@0PX:20`1ADE4306UYJ@@0?clo0`2>SXh308V9R@<0MWIf101oOgl30820P0<0PH611020P803
07UiN@<0OGem1027QhL30861P@<0MWIf0`20P80407alO0<0P8200`1mOGd407AdM0<0OGem0`1oOgl4
07inOP<0Ogmo0`23Ph<40820P0<0N7Qh3`38h=P307YjNP@0SHf=0`2;Rh/307AdM0@0Lg=c0`1kNg/3
08J6QP@0SHf=0`1fMWH308>3P`<0O7al1022PX8307inOP<0Q8B41022PX830861P@<0QHF51022PX83
07]kN`<0PH610`1hN7P40861P@<0PX:20`25QHD407]kN`<0P8200`21PH4407moO`<0P8201`23Ph<3
08:2PP@0b>3H0`2>SXh4079bLP<0NGUi0`1jNWX406a/K0<0RHV90`20P80309bLW0@0O7al0`1gMgL3
0861P@@0Ogmo0`26QXH307IfMP@0OWin0`1gMgL307]kN`@0PH610`1jNWX308:2PP<0Kfm_101jNWX3
08>3P`<0RHV9101lO7`308V9R@<0QHF5101kNg/308V9R@<0QHF5101mOGd3075aLA@0b>3H000C0<SP
f0<0R8R8101lO7`308Z:RP<0Xj>S1022PX8309NGU`<0O7al101XJ6P308>3P`<0Xj>S0`1lO7`408>3
P`<0NGUi0`23Ph<408:2PP<0PH610`23Ph<40820P0<0OGem0`20P80407UiN@<0OGem0`1nOWh308>3
P`@0OGem0`1nOWh307moO`@0Ph>30`20P80307alO0@0Ogmo0`25QHD40<SPf0<0JVYZ101JFUX308Z:
RP<0T92@1022PX83055AD@<0JFUY100o?cl308j>SP<0RHV90`1fMWH407moO`<0P8200`21PH440820
P0<0NGUi0`1mOGd408N7Q`<0PH610`1fMWH30820P0@0O7al0`20P80307emO@@0M7Ad0`1mOGd307mo
O`@0OWin0`1oOgl308>3P`@0P8200`1hN7P?0<SPf0<0NWYj102=SHd308^;R`<0M7Ad101cLg<307]k
N`<0QXJ6102=SHd307IfMP<0Ph>30`1lO7`408:2PP<0OWin0`24Q8@408:2PP<0PH610`25QHD408:2
PP<0Ng]k0`21PH4307QhN0@0PH610`22PX8308F5Q@@0Ng]k0`20P8030861P@@0Ogmo0`20P80708>3
P`<0PX:21038h=P308j>SP@0LW9b0`1iNGT307YjNP@0K6a/0`29RHT30820P0<0W9bL101lO7`307Mg
M`<0PH61101oOgl308J6QP<0MWIf101nOWh307MgM`<0Ng]k1021PH4307YjNP<0PX:20`1_Kfl407Yj
NP<0Ph>30`29RHT407alO0<0RHV90`25QHD407]kN`<0RHV90`25QHD407emO@<0LG5a5038h=P001<0
b>3H0`28R8P407alO0<0RXZ:0`2SXj<408:2PP<0UiNG0`1lO7`406QXJ0<0Ph>30`2SXj<307alO0@0
Ph>30`1iNGT308>3P`@0PX:20`21PH4308>3P`@0P8200`1mOGd30820P0@0NGUi0`1mOGd307inOP<0
Ph>3101mOGd307inOP<0Ogmo1023Ph<30820P0<0O7al101oOgl308F5Q@@0b>3H0`1ZJVX405YJFP<0
RXZ:0`2@T90408:2PP<0DE5A0`1YJFT403lo?`<0SXj>0`29RHT307IfMP@0Ogmo0`20P8030861P@@0
P8200`1iNGT307emO@@0QhN70`21PH4307IfMP<0P820101lO7`30820P0<0OGem101dM7@307emO@<0
Ogmo101nOWh307moO`<0Ph>31020P80307QhN0l0b>3H0`1jNWX408f=S@<0Rh^;0`1dM7@407=cL`<0
Ng]k0`26QXH408f=S@<0MWIf0`23Ph<307alO0@0PX:20`1nOWh308B4Q0@0PX:20`21PH4308F5Q@@0
PX:20`1kNg/30861P@<0N7Qh1021PH4308:2PP<0QHF5101kNg/30820P0<0PH61101oOgl30820P0L0
Ph>30`22PX840<SPf0<0SXj>101bLW8307UiN@<0NWYj101/K6`308V9R@<0P8200`2LW9`407alO0<0
MgMg0`21PH4407moO`<0QXJ60`1fMWH407inOP<0MgMg0`1kNg/40861P@<0NWYj0`22PX8306m_K`@0
NWYj0`23Ph<308V9R@@0O7al0`29RHT308F5Q@@0Ng]k0`29RHT308F5Q@@0OGem0`1aLG4D0<SPf000
4`38h=P308R8R0@0O7al0`2:RXX30:>SX`@0PX:20`2GUiL307alO0@0J6QX0`23Ph<30:>SX`<0O7al
1023Ph<307UiN@<0Ph>31022PX830861P@<0Ph>31020P80307emO@<0P820101iNGT307emO@<0OWin
0`23Ph<407emO@<0OWin0`1oOgl408>3P`<0P8200`1lO7`407moO`<0QHF51038h=P306YZJP@0FUYJ
0`2:RXX3092@T0@0PX:20`1ADE4306UYJ@@0?clo0`2>SXh308V9R@<0MWIf101oOgl30820P0<0PH61
1020P80307UiN@<0OGem1027QhL30861P@<0MWIf0`20P80407alO0<0P8200`1mOGd407AdM0<0OGem
0`1oOgl407inOP<0Ogmo0`23Ph<40820P0<0N7Qh3`38h=P307YjNP@0SHf=0`2;Rh/307AdM0@0Lg=c
0`1kNg/308J6QP@0SHf=0`1fMWH308>3P`<0O7al1022PX8307inOP<0Q8B41022PX830861P@<0QHF5
1022PX8307]kN`<0PH610`1hN7P40861P@<0PX:20`25QHD407]kN`<0P8200`21PH4407moO`<0P820
1`23Ph<308:2PP@0b>3H0`2>SXh4079bLP<0NGUi0`1jNWX406a/K0<0RHV90`20P80309bLW0@0O7al
0`1gMgL30861P@@0Ogmo0`26QXH307IfMP@0OWin0`1gMgL307]kN`@0PH610`1jNWX308:2PP<0Kfm_
101jNWX308>3P`<0RHV9101lO7`308V9R@<0QHF5101kNg/308V9R@<0QHF5101mOGd3075aLA@0b>3H
000C0<SPf0<0OWin1025QHD307alO0<0H61P101JFUX306m_K`<0QHF5102JVYX30820P0<0Ti>C0`1o
Ogl408F5Q@<0Ogmo0`20P80407inOPH0OGem1021PH4308F5Q@L0O7al0`22PX8607moO`@0PH610`1n
OWh30820P0@0OWin0`1lO7`307inOP@0Ph>30`20P8040<SPf0<0Ph>31021PH4307alO0<0L71`1023
Ph<30;Vi^@<0V9RH102k^k/30=oOg`<0OGem0`2?Shl407moO`<0OGem0`1oOgl408>3P`<0OWin0`22
PX8408F5Q@<0OWin0`20P8030861P@@0Ph>30`22PX8308N7Q`@0NWYj0`24Q8@307alO0@0R8R80`20
P80307YjNP@0OGem0`1kNg/?0<SPf0<0Q8B41021PH4307IfMP<0OWin1027QhL308Z:RP<0PH611029
RHT3092@T0<0MGEe0`24Q8@408>3P`<0PH610`1oOgl40820P0<0PH610`20P80407UiN@H0PH610`1j
NWX407inOP<0Ph>30`1oOgl407alO0<0Q8B40`22PX8407inOP<0NWYj0`20P80407EeM@<0Ng]k1038
h=P308N7Q`@0PX:20`23Ph<3075aL@@0SXj>0`1YJFT306a/K0<0T92@100S8b<3079bLP<0N7Qh1029
RHT30820P0<0Ogmo101eMGD308:2PP<0S8b<1024Q8@307inOP<0RHV90`1oOgl407alO0<0NGUi0`28
R8P408Z:RP<0O7al0`25QHD408J6QP<0MWIf0`2=SHd407EeM@<0LW9b5038h=P001<0b>3H0`1nOWh4
08F5Q@<0O7al0`1PH60405YJFP<0Kfm_0`25QHD409ZJVP<0P8200`2CTi<307moO`@0QHF50`1oOgl3
0820P0@0OWin1P1mOGd40861P@<0QHF51`1lO7`308:2PPH0Ogmo1021PH4307inOP<0P820101nOWh3
07alO0<0OWin1023Ph<30820P0@0b>3H0`23Ph<40861P@<0O7al0`1`L70408>3P`<0^KVi0`2HV9P4
0;^k^`<0gmoO0`1mOGd308n?S`@0Ogmo0`1mOGd307moO`@0Ph>30`1nOWh308:2PP@0QHF50`1nOWh3
0820P0<0PH611023Ph<308:2PP<0QhN7101jNWX308B4Q0<0O7al1028R8P30820P0<0NWYj101mOGd3
07]kN`l0b>3H0`24Q8@40861P@<0MWIf0`1nOWh408N7Q`<0RXZ:0`21PH4408V9R@<0T92@0`1eMGD3
08B4Q0@0Ph>30`21PH4307moO`@0P8200`21PH430820P0@0NGUi1P21PH4307YjNP@0OWin0`23Ph<3
07moO`@0O7al0`24Q8@308:2PP@0OWin0`1jNWX30820P0@0MGEe0`1kNg/40<SPf0<0QhN71022PX83
08>3P`<0LG5a102>SXh306UYJ@<0K6a/0`2@T90402<S8`<0LW9b0`1hN7P408V9R@<0P8200`1oOgl4
07EeM@<0PX:20`2<S8`408B4Q0<0OWin0`29RHT307moO`@0O7al0`1iNGT308R8R0@0RXZ:0`1lO7`3
08F5Q@@0QXJ60`1fMWH308f=S@@0MGEe0`1bLW8D0<SPf0004`38h=P307inOP@0QHF50`1lO7`3061P
H0@0FUYJ0`1_Kfl308F5Q@@0VYZJ0`20P80309>CT`<0Ogmo1025QHD307moO`<0P820101nOWh607em
O@@0PH610`25QHD707alO0<0PX:21P1oOgl40861P@<0OWin0`20P80407inOP<0O7al0`1nOWh408>3
P`<0P8201038h=P308>3P`@0PH610`1lO7`3071`L0@0Ph>30`2i^KT309RHV0@0^k^k0`3Ogml307em
O@<0Shn?101oOgl307emO@<0Ogmo1023Ph<307inOP<0PX:21025QHD307inOP<0P8200`21PH4408>3
P`<0PX:20`27QhL407YjNP<0Q8B40`1lO7`408R8R0<0P8200`1jNWX407emO@<0Ng]k3`38h=P308B4
Q0@0PH610`1fMWH307inOP@0QhN70`2:RXX30861P@@0RHV90`2@T90307EeM@<0Q8B41023Ph<30861
P@<0Ogmo1020P8030861P@<0P820101iNGT60861P@<0NWYj101nOWh308>3P`<0Ogmo101lO7`308B4
Q0<0PX:2101nOWh307YjNP<0P820101eMGD307]kN`@0b>3H0`27QhL408:2PP<0Ph>30`1aLG4408j>
SP<0JFUY0`1/K6`3092@T0@08b<S0`1bLW8307QhN0@0RHV90`20P80307moO`@0MGEe0`22PX8308b<
S0@0Q8B40`1nOWh308V9R@<0Ogmo101lO7`307UiN@<0R8R8102:RXX307alO0<0QHF51026QXH307If
MP<0SHf=101eMGD3079bLQ@0b>3H000C0<SPf0<0RXZ:101oOgl308^;R`<0Q8B4102KVi/308V9R@<0
Ogmo101]KFd308:2PP<0Ti>C0`1mOGd707inOP<0QhN71020P8030861P@L0P8200`21PH430820P0@0
OWin0`1lO7`307YjNP<0P820101mOGd30861P@L0Ph>30`1lO7`707inOP<0PH611038h=P3079bLPL0
Ph>30`26QXH40820P0<0Kfm_0`0_;bl408R8R0<0?Shn0`1;Bd/308j>SP@0OWin0`23Ph<308B4Q0@0
Ng]k0`23Ph<307moO`@0PH610`23Ph<307emO@<0PH611020P80307moO`<0O7al1026QXH30820P0<0
PH61101gMgL307UiN@<0MWIf101nOWh308F5Q@l0b>3H0`1kNg/408F5Q@<0NGUi0`1jNWX408:2PP<0
NGUi0`20P80407QhN0<0QhN70`25QHD307=cL`@0Ogmo0`1lO7`70820P0<0PH610`1lO7`408F5Q@<0
Ogmo0`1lO7`308>3P`@0PX:20`20P8030861P@@0O7al0`1hN7P308V9R@@0Ph>30`1nOWh307YjNP@0
PX:20`21PH440<SPf0<0Ng]k1028R8P308:2PP<0QXJ6101eMGD306m_K`<0RHV90`22PX8404=3@`<0
UiNG0`2;Rh/407IfMP<0LW9b0`2;Rh/40820P0<0O7al1`20P80308N7Q`<0PX:20`21PH44071`L0<0
Ph>30`1mOGd707YjNP<0OGem1020P80307YjNP<0Q8B4102BTY8308J6QQ@0b>3H000C0<SPf0<0RXZ:
101oOgl308^;R`<0Q8B4102KVi/308V9R@<0Ogmo101]KFd308:2PP<0Ti>C0`1mOGd707inOP<0QhN7
1020P8030861P@L0P8200`21PH430820P0@0OWin0`1lO7`307YjNP<0P820101mOGd30861P@L0Ph>3
0`1lO7`707inOP<0PH611038h=P3079bLPL0Ph>30`26QXH40820P0<0Kfm_0`0_;bl408R8R0<0?Shn
0`1;Bd/308j>SP@0OWin0`23Ph<308B4Q0@0Ng]k0`23Ph<307moO`@0PH610`23Ph<307emO@<0PH61
1020P80307moO`<0O7al1026QXH30820P0<0PH61101gMgL307UiN@<0MWIf101nOWh308F5Q@l0b>3H
0`1kNg/408F5Q@<0NGUi0`1jNWX408:2PP<0NGUi0`20P80407QhN0<0QhN70`25QHD307=cL`@0Ogmo
0`1lO7`70820P0<0PH610`1lO7`408F5Q@<0Ogmo0`1lO7`308>3P`@0PX:20`20P8030861P@@0O7al
0`1hN7P308V9R@@0Ph>30`1nOWh307YjNP@0PX:20`21PH440<SPf0<0Ng]k1028R8P308:2PP<0QXJ6
101eMGD306m_K`<0RHV90`22PX8404=3@`<0UiNG0`2;Rh/407IfMP<0LW9b0`2;Rh/40820P0<0O7al
1`20P80308N7Q`<0PX:20`21PH44071`L0<0Ph>30`1mOGd707YjNP<0OGem1020P80307YjNP<0Q8B4
102BTY8308J6QQ@0b>3H000C0<SPf0<0RXZ:101oOgl308^;R`<0Q8B4102KVi/308V9R@<0Ogmo101]
KFd308:2PP<0Ti>C0`1mOGd707inOP<0QhN71020P8030861P@L0P8200`21PH430820P0@0OWin0`1l
O7`307YjNP<0P820101mOGd30861P@L0Ph>30`1lO7`707inOP<0PH611038h=P3079bLPL0Ph>30`26
QXH40820P0<0Kfm_0`0_;bl408R8R0<0?Shn0`1;Bd/308j>SP@0OWin0`23Ph<308B4Q0@0Ng]k0`23
Ph<307moO`@0PH610`23Ph<307emO@<0PH611020P80307moO`<0O7al1026QXH30820P0<0PH61101g
MgL307UiN@<0MWIf101nOWh308F5Q@l0b>3H0`1kNg/408F5Q@<0NGUi0`1jNWX408:2PP<0NGUi0`20
P80407QhN0<0QhN70`25QHD307=cL`@0Ogmo0`1lO7`70820P0<0PH610`1lO7`408F5Q@<0Ogmo0`1l
O7`308>3P`@0PX:20`20P8030861P@@0O7al0`1hN7P308V9R@@0Ph>30`1nOWh307YjNP@0PX:20`21
PH440<SPf0<0Ng]k1028R8P308:2PP<0QXJ6101eMGD306m_K`<0RHV90`22PX8404=3@`<0UiNG0`2;
Rh/407IfMP<0LW9b0`2;Rh/40820P0<0O7al1`20P80308N7Q`<0PX:20`21PH44071`L0<0Ph>30`1m
OGd707YjNP<0OGem1020P80307YjNP<0Q8B4102BTY8308J6QQ@0b>3H000C0<SPf0<0Q8B41020P803
08>3P`<0OWin101/K6`3065QH@<0QHF5102>SXh307inOP<0K6a/1`1nOWh30820P0<0PX:2101lO7`3
08J6QP<0PH61101mOGd307moO`<0O7al101nOWh308>3P`H0Ogmo1`1nOWh707moO`<0QHF50`1hN7P4
07emO@<0P8201038h=P307EeM@@0LG5a0`1oOgl307AdM0@0N7Qh0`1bLW830;Jf]P@0R8R80`1]KFd3
034a<@<0Kfm_101kNg/308F5Q@<0Ogmo101mOGd307alO0<0Ogmo101jNWX307inOPH0P820101mOGd3
07AdM0<0NWYj1`21PH4307alO0@0N7Qh0`22PX830861P@@0QXJ60`27QhL?0<SPf0<0PH611026QXH3
08>3P`<0Ogmo101eMGD308V9R@L0Q8B41P23Ph<307alO0@0NWYj0`25QHD308>3P`@0QHF50`1oOgl3
08>3P`@0Ng]k0`20P80307moO`<0O7al101nOWh307moO`<0QhN71020P80308F5Q@<0OWin1024Q8@3
07inOP<0PX:2101lO7`307emO@@0b>3H0`26QXH406YZJP<0Ph>30`1jNWX407UiN@<0Ti>C0`1cLg<3
07alO0@0MWIf0`37alL30:>SX`@0QhN70`1oOgl308b<S0L0PH610`1mOGd407AdM0<0NGUi0`2<S8`3
07]kN`@0OGem0`1oOgl308>3P`@0Ogmo0`1iNGT307=cL`@0OGem0`29RHT307UiN@@0MWIf0`1dM7@D
0<SPf0004`38h=P308B4Q0@0P8200`23Ph<307inOP@0K6a/0`1QHF4308F5Q@@0SXj>0`1nOWh306a/
K0L0OWin0`20P80308:2PP@0O7al0`26QXH30861P@@0OGem0`1oOgl307alO0@0OWin0`23Ph<607mo
O`L0OWin1`1oOgl308F5Q@<0N7Qh101mOGd30820P0@0b>3H0`1eMGD4075aL@<0Ogmo0`1dM7@407Qh
N0<0LW9b0`2f][H408R8R0<0KFe]0`0a<C4306m_K`@0Ng]k0`25QHD307moO`@0OGem0`1lO7`307mo
O`@0NWYj0`1nOWh60820P0@0OGem0`1dM7@307YjNPL0PH610`1lO7`407QhN0<0PX:20`21PH4408J6
QP<0QhN73`38h=P30861P@@0QXJ60`23Ph<307moO`@0MGEe0`29RHT708B4Q0H0Ph>30`1lO7`407Yj
NP<0QHF50`23Ph<408F5Q@<0Ogmo0`23Ph<407]kN`<0P8200`1oOgl307alO0@0OWin0`1oOgl308N7
Q`@0P8200`25QHD307inOP@0Q8B40`1nOWh308:2PP@0O7al0`1mOGd40<SPf0<0QXJ6101ZJVX308>3
P`<0NWYj101iNGT309>CT`<0Lg=c0`1lO7`407IfMP<0alO70`2SXj<408N7Q`<0Ogmo0`2<S8`70861
P@<0OGem101dM7@307UiN@<0S8b<0`1kNg/407emO@<0Ogmo0`23Ph<407moO`<0NGUi0`1cLg<407em
O@<0RHV90`1iNGT407IfMP<0M7Ad5038h=P001<0b>3H0`24Q8@40820P0<0Ph>30`1nOWh406a/K0<0
HF5Q0`25QHD408j>SP<0OWin0`1/K6`707inOP<0P8200`22PX8407alO0<0QXJ60`21PH4407emO@<0
Ogmo0`1lO7`407inOP<0Ph>31P1oOgl707inOPL0Ogmo0`25QHD307QhN0@0OGem0`20P8040<SPf0<0
MGEe101aLG4307moO`<0M7Ad101hN7P3079bLP<0][Jf1028R8P306e]K@<0<C4a0`1_Kfl407]kN`<0
QHF50`1oOgl407emO@<0O7al0`1oOgl407YjNP<0OWin1P20P80407emO@<0M7Ad0`1jNWX70861P@<0
O7al101hN7P308:2PP<0PH611026QXH308N7Q`l0b>3H0`21PH4408J6QP<0Ph>30`1oOgl407EeM@<0
RHV91`24Q8@608>3P`<0O7al101jNWX308F5Q@<0Ph>31025QHD307moO`<0Ph>3101kNg/30820P0<0
Ogmo0`1lO7`407inOP<0Ogmo0`27QhL40820P0<0QHF50`1nOWh408B4Q0<0OWin0`22PX8407alO0<0
OGem1038h=P308J6QP@0JVYZ0`23Ph<307YjNP@0NGUi0`2CTi<307=cL`<0O7al101fMWH30<O7a`<0
Xj>S1027QhL307moO`<0S8b<1`21PH4307emO@@0M7Ad0`1iNGT308b<S0<0Ng]k101mOGd307moO`<0
Ph>3101oOgl307UiN@<0Lg=c101mOGd308V9R@<0NGUi101fMWH307AdM1@0b>3H000C0<SPf0<0Q8B4
101jNWX60820P0@0T92@0`2RXZ8307alO0@0K6a/0`1nOWh308^;R`<0M7Ad101iNGT307alO0<0NWYj
1024Q8@307moO`<0NGUi101nOWh307moO`<0Ph>3101mOGd30861P@<0OGem0`1lO7`40820P0<0Ph>3
0`20P80707emO@<0P820101gMgL308b<S0@0b>3H0`2@T90408>3P`<0KFe]0`1dM7@407]kN`<0SXj>
0`1cLg<405MGE`<0Q8B40`2EUID30<o?c`@0RXZ:0`1oOgl308:2PP@0MgMg0`1lO7`308:2PP@0QhN7
0`24Q8@608:2PPL0Ng]k0`1cLg<408:2PP<0L71`0`22PX8407moO`<0OWin0`27QhL40820P0<0OGem
3`38h=P308:2PP@0OWin0`1jNWX30820P0L0MWIf0`1iNGT407YjNP<0OGem0`27QhL306m_K`@0RHV9
0`1kNg/307inOP@0OGem0`22PX8307inOP@0PX:20`24Q8@307YjNP<0Ph>31020P80308:2PP<0O7al
1`1hN7P30820P0@0Ogmo0`27QhL308F5Q@@0P8200`1mOGd40<SPf0<0P820101dM7@307QhN0<0R8R8
101eMGD305mOG`<0NGUi0`2GUiL407=cL`<0UYJF0`3>c/h405iNGP<0PX:20`2=SHd408N7Q`<0O7al
0`1iNGT406][J`<0QXJ60`24Q8@307YjNP@0SHf=0`21PH4307moO`L0PH610`24Q8@408R8R0<0Rh^;
0`1kNg/408V9R@<0JVYZ5038h=P001<0b>3H0`24Q8@407YjNPH0P820102@T9030::RXP<0O7al101/
K6`307inOP<0Rh^;0`1dM7@407UiN@<0O7al0`1jNWX408B4Q0<0Ogmo0`1iNGT407inOP<0Ogmo0`23
Ph<407emO@<0PH610`1mOGd307alO0@0P8200`23Ph<30820P0L0OGem0`20P80407MgM`<0S8b<1038
h=P3092@T0@0Ph>30`1]KFd307AdM0@0Ng]k0`2>SXh307=cL`@0EeMG0`24Q8@309FEU@<0clo?102:
RXX307moO`<0PX:2101gMgL307alO0<0PX:21027QhL308B4Q0H0PX:21`1kNg/307=cL`@0PX:20`1`
L70308:2PP@0Ogmo0`1nOWh308N7Q`@0P8200`1mOGd?0<SPf0<0PX:2101nOWh307YjNP<0P8201`1f
MWH307UiN@@0NWYj0`1mOGd308N7Q`<0Kfm_1029RHT307]kN`<0OWin101mOGd308:2PP<0OWin1022
PX8308B4Q0<0NWYj0`23Ph<40820P0<0PX:20`1lO7`707QhN0<0P820101oOgl308N7Q`<0QHF51020
P80307emO@@0b>3H0`20P80407AdM0<0N7Qh0`28R8P407EeM@<0GemO0`1iNGT309NGU`@0Lg=c0`2F
UYH30<k>cP@0GUiN0`22PX8308f=S@@0QhN70`1lO7`307UiN@@0Jf][0`26QXH308B4Q0<0NWYj102=
SHd30861P@<0Ogmo1`21PH4308B4Q0@0R8R80`2;Rh/307]kN`@0RHV90`1ZJVXD0<SPf0004`38h=P3
08B4Q0@0NWYj1P20P804092@T0<0XZ:R0`1lO7`406a/K0<0OWin0`2;Rh/307AdM0@0NGUi0`1lO7`3
07YjNP@0Q8B40`1oOgl307UiN@@0OWin0`1oOgl308>3P`@0OGem0`21PH4307emO@<0O7al1020P803
08>3P`<0P8201`1mOGd30820P0@0MgMg0`2<S8`40<SPf0<0T92@1023Ph<306e]K@<0M7Ad101kNg/3
08j>SP<0Lg=c101GEeL308B4Q0<0UIFE0`3?cll408Z:RP<0Ogmo0`22PX8407MgM`<0O7al0`22PX84
08N7Q`<0Q8B41P22PX8707]kN`<0Lg=c1022PX83071`L0<0PX:2101oOgl307inOP<0QhN71020P803
07emO@l0b>3H0`22PX8407inOP<0NWYj0`20P80707IfMP<0NGUi101jNWX307emO@<0QhN70`1_Kfl4
08V9R@<0Ng]k0`1nOWh407emO@<0PX:20`1nOWh408:2PP<0Q8B40`1jNWX308>3P`@0P8200`22PX83
07alO0L0N7Qh0`20P80407moO`<0QhN70`25QHD40820P0<0OGem1038h=P30820P0@0M7Ad0`1hN7P3
08R8R0@0MGEe0`1OGel307UiN@<0UiNG101cLg<309JFUP<0c/k>101NGUh308:2PP<0SHf=1027QhL3
07alO0<0NGUi101[Jf/308J6QP<0Q8B40`1jNWX408f=S@<0PH610`1oOgl70861P@<0Q8B41028R8P3
08^;R`<0Ng]k1029RHT306YZJQ@0b>3H000C0<SPf0<0Q8B4101jNWX60820P0@0T92@0`2RXZ8307al
O0@0K6a/0`1nOWh308^;R`<0M7Ad101iNGT307alO0<0NWYj1024Q8@307moO`<0NGUi101nOWh307mo
O`<0Ph>3101mOGd30861P@<0OGem0`1lO7`40820P0<0Ph>30`20P80707emO@<0P820101gMgL308b<
S0@0b>3H0`2@T90408>3P`<0KFe]0`1dM7@407]kN`<0SXj>0`1cLg<405MGE`<0Q8B40`2EUID30<o?
c`@0RXZ:0`1oOgl308:2PP@0MgMg0`1lO7`308:2PP@0QhN70`24Q8@608:2PPL0Ng]k0`1cLg<408:2
PP<0L71`0`22PX8407moO`<0OWin0`27QhL40820P0<0OGem3`38h=P308:2PP@0OWin0`1jNWX30820
P0L0MWIf0`1iNGT407YjNP<0OGem0`27QhL306m_K`@0RHV90`1kNg/307inOP@0OGem0`22PX8307in
OP@0PX:20`24Q8@307YjNP<0Ph>31020P80308:2PP<0O7al1`1hN7P30820P0@0Ogmo0`27QhL308F5
Q@@0P8200`1mOGd40<SPf0<0P820101dM7@307QhN0<0R8R8101eMGD305mOG`<0NGUi0`2GUiL407=c
L`<0UYJF0`3>c/h405iNGP<0PX:20`2=SHd408N7Q`<0O7al0`1iNGT406][J`<0QXJ60`24Q8@307Yj
NP@0SHf=0`21PH4307moO`L0PH610`24Q8@408R8R0<0Rh^;0`1kNg/408V9R@<0JVYZ5038h=P001<0
b>3H1`22PX8307YjNP<0PH611023Ph<306=SH`<0Lg=c102GUiL308>3P`<0Ng]k0`2:RXX407inOP<0
PH610`1mOGd408:2PP<0Ph>30`22PX870820P0<0O7al1020P80307moO`H0OGem101nOWh307EeM@<0
Q8B4101nOWh308:2PP<0P820101nOWh308j>SP@0b>3H0`23Ph<408J6QP<0NWYj0`1eMGD407moO`<0
M7Ad0`1MGEd40::RXP<0N7Qh0`1mOGd30;^k^`@0f=SH0`26QXH307IfMP@0QhN70`20P80307inOP@0
PX:20`23Ph<307inOP<0P8201`28R8P307inOP@0NWYj0`21PH4307MgM`@0OGem0`1lO7`308:2PP@0
P8200`22PX8?0<SPf0<0PH61101jNWX308>3P`<0P820101jNWX30861P@<0RXZ:1026QXH30820P0<0
NWYj0`1oOgl408B4Q0<0P8200`1jNWX407emO@H0Ph>3101jNWX30861P@<0PX:20`1nOWh407emO@<0
PH610`1kNg/708>3P`<0O7al101nOWh307emO@<0PH61101mOGd30861P@@0b>3H0`1jNWX406m_K`<0
NWYj0`1cLg<4071`L0<0Ogmo0`2MWId3071`L0@0NWYj0`1lO7`30:2PX0@0>CTi0`1LG5`308V9R@@0
T92@0`1fMWH30861P@@0Rh^;0`1hN7P308:2PP<0PH61101jNWX308^;R`<0Q8B4101oOgl308Z:RP<0
Ng]k1021PH4307MgM`<0OWin1024Q8@30861PA@0b>3H000C0<SPf0L0PX:20`1jNWX30861P@@0Ph>3
0`1SHf<307=cL`@0UiNG0`23Ph<307]kN`<0RXZ:101nOWh30861P@<0OGem1022PX8308>3P`<0PX:2
1`20P80307alO0@0P8200`1oOgl607emO@@0OWin0`1eMGD308B4Q0@0OWin0`22PX830820P0@0OWin
0`2>SXh40<SPf0<0Ph>31026QXH307YjNP<0MGEe101oOgl307AdM0<0GEeM102RXZ8307QhN0<0OGem
0`2k^k/40=SHf0<0QXJ60`1fMWH408N7Q`<0P8200`1nOWh408:2PP<0Ph>30`1nOWh30820P0L0R8R8
0`1nOWh407YjNP<0PH610`1gMgL407emO@<0O7al0`22PX840820P0<0PX:23`38h=P30861P@@0NWYj
0`23Ph<30820P0@0NWYj0`21PH4308Z:RP@0QXJ60`20P80307YjNP<0Ogmo1024Q8@30820P0<0NWYj
101mOGd608>3P`@0NWYj0`21PH4308:2PP<0OWin101mOGd30861P@<0Ng]k1`23Ph<307alO0@0OWin
0`1mOGd30861P@@0OGem0`21PH440<SPf0<0NWYj101_Kfl307YjNP<0Lg=c101`L70307moO`<0WIfM
0`1`L70407YjNP<0O7al0`2PX:0403Ti>@<0G5aL0`29RHT4092@T0<0MWIf0`21PH4408^;R`<0N7Qh
0`22PX830861P@@0NWYj0`2;Rh/308B4Q0@0Ogmo0`2:RXX307]kN`@0PH610`1gMgL307inOP@0Q8B4
0`21PH4D0<SPf0004`38h=P708:2PP<0NWYj0`21PH4408>3P`<0Hf=S0`1cLg<409NGU`<0Ph>30`1k
Ng/308Z:RP@0OWin0`21PH4307emO@@0PX:20`23Ph<308:2PPL0P8200`1lO7`40820P0<0Ogmo1P1m
OGd407inOP<0MGEe0`24Q8@407inOP<0PX:20`20P80407inOP<0SXj>1038h=P308>3P`@0QXJ60`1j
NWX307EeM@@0Ogmo0`1dM7@305eMG@@0XZ:R0`1hN7P307emO@<0^k^k103Hf=P308J6QP<0MWIf1027
QhL30820P0<0OWin1022PX8308>3P`<0OWin0`20P80708R8R0<0OWin101jNWX30861P@<0MgMg101m
OGd307alO0<0PX:21020P80308:2PPl0b>3H0`21PH4407YjNP<0Ph>30`20P80407YjNP<0PH610`2:
RXX408J6QP<0P8200`1jNWX307moO`@0Q8B40`20P80307YjNP@0OGem1P23Ph<407YjNP<0PH610`22
PX8307inOP@0OGem0`21PH4307]kN`L0Ph>30`1lO7`407inOP<0OGem0`21PH4407emO@<0PH611038
h=P307YjNP@0Kfm_0`1jNWX307=cL`@0L71`0`1oOgl309fMW@<0L71`101jNWX307alO0<0X:2P100i
>CT305aLG0<0RHV9102@T90307IfMP<0PH61102;Rh/307QhN0<0PX:20`21PH4407YjNP<0Rh^;0`24
Q8@407moO`<0RXZ:0`1kNg/40861P@<0MgMg0`1nOWh408B4Q0<0PH615038h=P001<0b>3H0`23Ph<4
07inOP<0QHF50`24Q8@40820P0<0RXZ:0`2BTY8406IVIP<0MgMg0`25QHD307alO0@0OGem0`21PH43
07emO@@0PX:20`20P8030861P@@0PX:20`23Ph<307]kN`@0PH610`1lO7`307inOP<0NGUi101oOgl3
08B4Q0<0P8201`1nOWh307emO@@0P8200`2:RXX40<SPf0<0LW9b102=SHd308b<S0<0O7al101hN7P3
08f=S@<0W9bL102>SXh3061PH0<0NWYj0`1nOWh409RHV0<0WIfM0`2:RXX40861P@<0Ogmo0`1kNg/4
08Z:RP<0QHF50`1lO7`308B4Q0@0P8200`1bLW8308Z:RPX0QHF5101oOgl307emO@<0Ph>31028R8P3
07]kN`l0b>3H0`1dM7@407IfMP<0Ph>30`1nOWh407EeM@<0M7Ad0`1lO7`408F5Q@<0Ph>30`20P803
07inOP@0NWYj0`26QXH307QhN0@0Q8B40`22PX8307]kN`@0OGem0`1oOgl30820P0<0RXZ:101kNg/3
08B4Q0<0OGem1`1jNWX70820P0<0OGem0`24Q8@407alO0<0OWin1038h=P309NGU`@0RHV90`27QhL3
071`L0@0M7Ad0`28R8P3079bLP<0L71`1029RHT308j>SP<0O7al101]KFd300`<30<0M7Ad102<S8`3
08F5Q@<0NGUi101gMgL307UiN@H0P8201021PH4307IfMP<0K6a/101jNWX309JFUP<0OWin1021PH43
08J6QP<0OGem101kNg/308:2PQ@0b>3H000C0<SPf0<0Ph>3101nOWh308F5Q@<0Q8B41020P80308Z:
RP<0TY:B101VIVH307MgM`<0QHF50`1lO7`407emO@<0PH610`1mOGd408:2PP<0P8200`21PH4408:2
PP<0Ph>30`1kNg/40861P@<0O7al0`1nOWh307UiN@@0Ogmo0`24Q8@30820P0L0OWin0`1mOGd40820
P0<0RXZ:1038h=P3079bLP@0SHf=0`2<S8`307alO0@0N7Qh0`2=SHd309bLW0@0SXj>0`1PH60307Yj
NP<0OWin102HV9P309fMW@<0RXZ:1021PH4307moO`<0Ng]k102:RXX308F5Q@<0O7al0`24Q8@40820
P0<0LW9b0`2:RXX:08F5Q@@0Ogmo0`1mOGd308>3P`@0R8R80`1kNg/?0<SPf0<0M7Ad101fMWH308>3
P`<0OWin101eMGD307AdM0<0O7al1025QHD308>3P`<0P8200`1nOWh407YjNP<0QXJ60`1hN7P408B4
Q0<0PX:20`1kNg/407emO@<0Ogmo0`20P80308Z:RP@0Ng]k0`24Q8@307emO@L0NWYj1`20P80307em
O@<0Q8B4101lO7`307inOP@0b>3H0`2GUiL408V9R@<0QhN70`1`L70407AdM0<0R8R80`1bLW83071`
L0@0RHV90`2>SXh307alO0@0KFe]0`0<30`307AdM0@0S8b<0`25QHD307UiN@@0MgMg0`1iNGT60820
P0@0PH610`1fMWH306a/K0@0NWYj0`2FUYH307inOP@0PH610`26QXH307emO@@0Ng]k0`22PX8D0<SP
f0004`38h=P308>3P`@0OWin0`25QHD308B4Q0@0P8200`2:RXX309:BTP@0IVIV0`1gMgL308F5Q@<0
O7al101mOGd30861P@<0OGem1022PX830820P0<0PH611022PX8308>3P`<0Ng]k1021PH4307alO0<0
OWin0`1iNGT407moO`<0Q8B40`20P80707inOP<0OGem1020P80308Z:RP@0b>3H0`1bLW8408f=S@<0
S8b<0`1lO7`407QhN0<0SHf=0`2LW9`408j>SP<0H61P0`1jNWX307inOP@0V9RH0`2MWId308Z:RP@0
PH610`1oOgl307]kN`@0RXZ:0`25QHD307alO0<0Q8B41020P803079bLP<0RXZ:2P25QHD407moO`<0
OGem0`23Ph<408R8R0<0Ng]k3`38h=P307AdM0@0MWIf0`23Ph<307inOP@0MGEe0`1dM7@307alO0@0
QHF50`23Ph<30820P0<0OWin101jNWX308J6QP<0N7Qh1024Q8@308:2PP<0Ng]k101mOGd307moO`<0
P8200`2:RXX407]kN`<0Q8B40`1mOGd707YjNPL0P8200`1mOGd308B4Q0@0O7al0`1nOWh40<SPf0<0
UiNG1029RHT308N7Q`<0L71`101dM7@308R8R0<0LW9b0`1`L70408V9R@<0SXj>0`1lO7`406e]K@<0
30`<0`1dM7@408b<S0<0QHF50`1iNGT407MgM`<0NGUi1P20P8040861P@<0MWIf0`1/K6`407YjNP<0
UYJF0`1nOWh40861P@<0QXJ60`1mOGd407]kN`<0PX:25038h=P001<0b>3H0`27QhL408:2PP<0PH61
0`26QXH407emO@<0NWYj0`1^KVh4092@T0<0WinO1P20P8040861P@<0PX:21`1nOWh308V9R@<0Ogmo
1021PH4308N7Q`<0P820101bLW8307EeM@<0KVi^0`1QHF4407QhN0<0QHF51`1oOgl30861P@<0NWYj
101nOWh30861P@@0b>3H0`1nOWh407IfMP<0QHF50`1lO7`409FEU@<0NWYj0`1OGel403lo?`<0SHf=
0`2SXj<307MgM`@0Ng]k0`1nOWh308f=S@@0OWin0`1iNGT308Z:RP@0NGUi0`1nOWh308R8R0<0Ng]k
101eMGD308b<S0<0OWin101^KVh308B4Q0<0MWIf1027QhL307QhN0L0PH610`1nOWh?0<SPf0<0L71`
1021PH4308:2PP<0QhN7102?Shl30861P@<0PX:2101jNWX307inOP<0PX:20`1kNg/407emO@<0PH61
1`22PX8307moO`<0P8201`21PH4308:2PP<0MgMg102;Rh/308>3P`<0OWin1023Ph<308J6QP<0OGem
1023Ph<30861P@<0N7Qh1025QHD307]kN`@0b>3H0`1nOWh40820P0<0M7Ad0`2HV9P407EeM@<0Ng]k
0`2?Shl308V9R@@0T92@0`1bLW830861P@@0Rh^;0`1JFUX301XJ6P@0MgMg0`20P80307QhN0@0R8R8
0`2;Rh/308F5Q@<0OGem1027QhL306][J`<0OWin101fMWH308>3P`<0QHF51023Ph<308R8R0<0P820
101iNGT307MgMa@0b>3H000C0<SPf0<0QhN71022PX830861P@<0QXJ6101mOGd307YjNP<0KVi^102@
T90309nOW`H0P8201021PH4308:2PPL0OWin0`29RHT307moO`@0PH610`27QhL30820P0@0LW9b0`1e
MGD306i^KP<0HF5Q101hN7P308F5Q@L0Ogmo0`21PH4307YjNP@0OWin0`21PH440<SPf0<0OWin101f
MWH308F5Q@<0O7al102EUID307YjNP<0GemO100o?cl308f=S@<0Xj>S0`1gMgL407]kN`<0OWin0`2=
SHd407inOP<0NGUi0`2:RXX407UiN@<0OWin0`28R8P307]kN`@0MGEe0`2<S8`307inOP@0KVi^0`24
Q8@307IfMP@0QhN70`1hN7P70861P@<0OWin3`38h=P3071`L0@0PH610`22PX8308N7Q`@0Shn?0`21
PH4308:2PP@0NWYj0`1nOWh308:2PP<0Ng]k101mOGd30861P@L0PX:20`1oOgl30820P0L0PH610`22
PX8307MgM`@0Rh^;0`23Ph<307inOP@0Ph>30`26QXH307emO@@0Ph>30`21PH4307QhN0@0QHF50`1k
Ng/40<SPf0<0OWin1020P80307AdM0<0V9RH101eMGD307]kN`<0Shn?0`29RHT4092@T0<0LW9b0`21
PH4408^;R`<0FUYJ0`0J6QX407MgM`<0P8200`1hN7P408R8R0<0Rh^;0`25QHD307emO@@0QhN70`1[
Jf/307inOP@0MWIf0`23Ph<308F5Q@@0Ph>30`28R8P30820P0@0NGUi0`1gMgLD0<SPf0004`38h=P3
08N7Q`@0PX:20`21PH4308J6QP@0OGem0`1jNWX306i^KP@0T92@0`2OWil60820P0@0PH610`22PX87
07inOP<0RHV90`1oOgl40861P@<0QhN70`20P804079bLP<0MGEe0`1^KVh3065QH@@0N7Qh0`25QHD7
07moO`<0PH610`1jNWX407inOP<0PH611038h=P307inOP@0MWIf0`25QHD307alO0@0UIFE0`1jNWX3
05mOG`@0?clo0`2=SHd30:>SX`<0MgMg101kNg/307inOP<0SHf=101nOWh307UiN@<0RXZ:101iNGT3
07inOP<0R8R80`1kNg/407EeM@<0S8b<0`1nOWh406i^KP<0Q8B40`1fMWH408N7Q`<0N7Qh1`21PH43
07inOPl0b>3H0`1`L7040861P@<0PX:20`27QhL408n?S`<0PH610`22PX8407YjNP<0OWin0`22PX83
07]kN`@0OGem0`21PH4708:2PP<0Ogmo0`20P8070861P@<0PX:20`1gMgL408^;R`<0Ph>30`1nOWh4
08>3P`<0QXJ60`1mOGd408>3P`<0PH610`1hN7P408F5Q@<0Ng]k1038h=P307inOP@0P8200`1dM7@3
09RHV0@0MGEe0`1kNg/308n?S`<0RHV9102@T903079bLP<0PH61102;Rh/305YJFP<06QXJ101gMgL3
0820P0<0N7Qh1028R8P308^;R`<0QHF50`1mOGd408N7Q`<0Jf][0`1nOWh407IfMP<0Ph>30`25QHD4
08>3P`<0R8R80`20P80407UiN@<0MgMg5038h=P001<0b>3H1`23Ph<307alO0<0OWin101oOgl307al
O0<0Ph>3101mOGd306IVIP<0QhN70`26QXH408:2PP<0P8200`23Ph<40861P@<0Ogmo1`1mOGd30861
P@<0TY:B1023Ph<307alO0<0PX:20`1lO7`408:2PP<0O7al0`2:RXX408>3P`<0PH610`22PX8407]k
N`<0Q8B41038h=P308F5Q@@0JFUY0`2LW9`308R8R0@0Shn?0`2GUiL307emO@@0W9bL0`2VYZH3055A
D@<0JFUY1023Ph<307QhN0<0OWin102BTY8308j>SP<0O7al101eMGD307IfMP<0TI6A0`2FUYH408F5
Q@<0MgMg0`1lO7`408R8R0<0Rh^;0`1PH60406UYJ@<0MgMg0`2;Rh/407alO0<0NWYj3`38h=P307em
O@@0NGUi0`22PX8307QhN0@0T92@0`21PH4308J6QP@0Ti>C0`1cLg<307moO`<0OGem1`24Q8@307Ee
M@@0QHF50`1lO7`307inOP@0QHF50`1kNg/308R8R0<0RXZ:1027QhL307YjNP<0OGem1021PH4307Yj
NP<0Q8B41021PH4308J6QP<0N7Qh1020P8030861P@@0b>3H0`1lO7`408>3P`<0O7al0`1oOgl408R8
R0<0NWYj0`2;Rh/30::RXP@0I6AT0`1cLg<309>CT`@0NGUi0`29RHT306QXJ0@08B4Q0`24Q8@30861
P@@0Q8B40`29RHT30:FUY@<0TY:B101LG5`308b<S0<0Rh^;1026QXH307emO@<0NGUi101lO7`308R8
R0L0Ng]k0`1lO7`D0<SPf0004`38h=P708>3P`<0O7al0`1nOWh407moO`<0O7al0`23Ph<407emO@<0
IVIV0`27QhL308J6QP@0PX:20`20P80308>3P`@0PH610`1oOgl707emO@<0PH610`2BTY8408>3P`<0
O7al0`22PX8307alO0@0PX:20`1lO7`308Z:RP@0Ph>30`21PH4308:2PP@0Ng]k0`24Q8@40<SPf0<0
QHF5101YJFT309bLW0<0R8R8102?Shl309NGU`<0OGem102LW9`30:JVYP<0DE5A0`1YJFT408>3P`<0
N7Qh0`1nOWh409:BTP<0SXj>0`1lO7`407EeM@<0MWIf0`2ATI4309JFUP@0QHF50`1gMgL307alO0@0
R8R80`2;Rh/3061PH0@0JFUY0`1gMgL308^;R`@0O7al0`1jNWX?0<SPf0<0OGem101iNGT308:2PP<0
N7Qh102@T9030861P@<0QXJ6102CTi<307=cL`<0Ogmo0`1mOGd708B4Q0<0MGEe1025QHD307alO0<0
OWin1025QHD307]kN`<0R8R80`2:RXX408N7Q`<0NWYj0`1mOGd40861P@<0NWYj0`24Q8@40861P@<0
QXJ60`1hN7P40820P0<0PH611038h=P307alO0@0Ph>30`1lO7`307moO`@0R8R80`1jNWX308^;R`<0
XZ:R101TI6@307=cL`<0Ti>C101iNGT308V9R@<0J6QX100Q8B4308B4Q0<0PH611024Q8@308V9R@<0
YJFU0`2BTY8405aLG0<0S8b<0`2;Rh/408J6QP<0OGem0`1iNGT407alO0<0R8R81`1kNg/307alO1@0
b>3H000C0<SPf0L0Ph>30`1lO7`307inOP@0Ogmo0`1lO7`308>3P`@0OGem0`1VIVH308N7Q`<0QXJ6
1022PX830820P0<0Ph>31021PH4307moO`L0OGem0`21PH4309:BTP@0Ph>30`1lO7`308:2PP<0O7al
1022PX8307alO0<0RXZ:1023Ph<30861P@<0PX:2101kNg/308B4Q0@0b>3H0`25QHD406UYJ@<0W9bL
0`28R8P408n?S`<0UiNG0`1mOGd409bLW0<0YZJV0`1ADE4306UYJ@@0Ph>30`1hN7P307inOP@0TY:B
0`2>SXh307alO0@0MGEe0`1fMWH3096AT@<0UYJF1025QHD307MgM`<0O7al1028R8P308^;R`<0H61P
101YJFT307MgM`<0Rh^;101lO7`307YjNPl0b>3H0`1mOGd407UiN@<0PX:20`1hN7P4092@T0<0PH61
0`26QXH409>CT`<0Lg=c0`1oOgl307emO@L0Q8B40`1eMGD408F5Q@<0O7al0`1nOWh408F5Q@<0Ng]k
0`28R8P308Z:RP@0QhN70`1jNWX307emO@@0PH610`1jNWX308B4Q0@0PH610`26QXH307QhN0@0P820
0`21PH440<SPf0<0O7al1023Ph<307alO0<0Ogmo1028R8P307YjNP<0Rh^;0`2RXZ8406ATI0<0Lg=c
0`2CTi<407UiN@<0RHV90`1XJ6P4024Q8@<0Q8B40`21PH4408B4Q0<0RHV90`2UYJD309:BTP@0G5aL
0`2<S8`308^;R`@0QXJ60`1mOGd307UiN@@0O7al0`28R8P707]kN`<0O7al5038h=P001<0b>3H1`23
Ph<307alO0<0OWin101oOgl307alO0<0Ph>3101mOGd306IVIP<0QhN70`26QXH408:2PP<0P8200`23
Ph<40861P@<0Ogmo1`1mOGd30861P@<0TY:B1023Ph<307alO0<0PX:20`1lO7`408:2PP<0O7al0`2:
RXX408>3P`<0PH610`22PX8407]kN`<0Q8B41038h=P308F5Q@@0JFUY0`2LW9`308R8R0@0Shn?0`2G
UiL307emO@@0W9bL0`2VYZH3055AD@<0JFUY1023Ph<307QhN0<0OWin102BTY8308j>SP<0O7al101e
MGD307IfMP<0TI6A0`2FUYH408F5Q@<0MgMg0`1lO7`408R8R0<0Rh^;0`1PH60406UYJ@<0MgMg0`2;
Rh/407alO0<0NWYj3`38h=P307emO@@0NGUi0`22PX8307QhN0@0T92@0`21PH4308J6QP@0Ti>C0`1c
Lg<307moO`<0OGem1`24Q8@307EeM@@0QHF50`1lO7`307inOP@0QHF50`1kNg/308R8R0<0RXZ:1027
QhL307YjNP<0OGem1021PH4307YjNP<0Q8B41021PH4308J6QP<0N7Qh1020P8030861P@@0b>3H0`1l
O7`408>3P`<0O7al0`1oOgl408R8R0<0NWYj0`2;Rh/30::RXP@0I6AT0`1cLg<309>CT`@0NGUi0`29
RHT306QXJ0@08B4Q0`24Q8@30861P@@0Q8B40`29RHT30:FUY@<0TY:B101LG5`308b<S0<0Rh^;1026
QXH307emO@<0NGUi101lO7`308R8R0L0Ng]k0`1lO7`D0<SPf0004`38h=P308N7Q`@0QHF50`21PH43
07YjNP@0O7al0`21PH4307]kN`@0Ogmo0`2PX:0309>CT`<0MgMg1023Ph<30820P0<0OWin1021PH43
07]kN`<0Ph>3101nOWh307QhN0<0OWin1021PH4307inOP<0Ng]k0`27QhL408>3P`<0OGem0`1fMWH4
07MgM`<0OWin0`21PH4408>3P`<0RHV91038h=P30820P0@0PH610`1mOGd30820P0@0O7al0`22PX83
08V9R@@0M7Ad0`1mOGd308f=S@<0ZJVY102ATI4307]kN`<0OWin101fMWH308N7Q`<0Q8B4101hN7P3
08F5Q@<0V9RH0`2<S8`408^;R`<0S8b<0`1RHV8407QhN0<0OWin0`2JVYX409:BTP<0S8b<0`24Q8@4
07QhN0<0QhN73`38h=P307]kN`@0PX:20`1mOGd307alO0@0PX:20`1lO7`308N7Q`@0O7al0`1nOWh3
07]kN`<0P8201022PX8307emO@<0QXJ6101iNGT308V9R@<0PH61101oOgl307]kN`<0QXJ60`22PX84
079bLP<0PH610`25QHD407inOP<0PH610`1jNWX408:2PP<0O7al0`1oOgl408:2PP<0P8201038h=P3
08R8R0@0UYJF0`1`L70309:BTP@0Y:BT0`1bLW8307YjNP<0Shn?101]KFd306YZJP<0NGUi101`L703
07MgM`<0R8R8101=CDd302d];@<0PX:2101cLg<30820P0<0OWin0`1SHf<4092@T0<0UiNG0`1nOWh4
08B4Q0<0TI6A0`1lO7`407emO@<0MGEe0`1lO7`408>3P`<0Lg=c5038h=P001<0b>3H0`27QhL408F5
Q@<0PH610`1jNWX407alO0<0PH610`1kNg/407moO`<0X:2P0`2CTi<307MgM`@0Ph>30`20P80307in
OP@0PH610`1kNg/308>3P`@0OWin0`1hN7P307inOP@0PH610`1nOWh307]kN`<0QhN71023Ph<307em
O@<0MWIf101gMgL307inOP<0PH611023Ph<308V9R@@0b>3H0`20P8040861P@<0OGem0`20P80407al
O0<0PX:20`29RHT407AdM0<0OGem0`2=SHd30:VYZ@@0TI6A0`1kNg/307inOP@0MWIf0`27QhL308B4
Q0@0N7Qh0`25QHD309RHV0<0S8b<102;Rh/308b<S0<0HV9R101hN7P307inOP<0VYZJ102BTY8308b<
S0<0Q8B4101hN7P308N7Q`l0b>3H0`1kNg/408:2PP<0OGem0`1lO7`408:2PP<0O7al0`27QhL407al
O0<0OWin0`1kNg/30820P0@0PX:20`1mOGd308J6QP@0NGUi0`29RHT30861P@@0Ogmo0`1kNg/308J6
QP<0PX:2101bLW830861P@<0QHF5101nOWh30861P@<0NWYj1022PX8307alO0<0Ogmo1022PX830820
P0@0b>3H0`28R8P409JFUP<0L71`0`2BTY840:BTY0<0LW9b0`1jNWX308n?S`@0KFe]0`1ZJVX307Ui
N@@0L71`0`1gMgL308R8R0@0CDe=0`0];Bd308:2PP@0Lg=c0`20P80307inOP<0Hf=S102@T90309NG
U`<0OWin1024Q8@3096AT@<0O7al101mOGd307EeM@<0O7al1023Ph<307=cLa@0b>3H000C0<SPf0<0
QhN71025QHD30861P@<0NWYj101lO7`30861P@<0Ng]k101oOgl30:2PX0<0Ti>C0`1gMgL408>3P`<0
P8200`1nOWh40861P@<0Ng]k0`23Ph<407inOP<0N7Qh0`1nOWh40861P@<0OWin0`1kNg/308N7Q`@0
Ph>30`1mOGd307IfMP@0MgMg0`1nOWh30861P@@0Ph>30`29RHT40<SPf0<0P8201021PH4307emO@<0
P820101lO7`308:2PP<0RHV9101dM7@307emO@<0SHf=0`2YZJT4096AT@<0Ng]k0`1nOWh407IfMP<0
QhN70`24Q8@407QhN0<0QHF50`2HV9P308b<S0@0Rh^;0`2<S8`3069RHP@0N7Qh0`1nOWh309ZJVP@0
TY:B0`2<S8`308B4Q0@0N7Qh0`27QhL?0<SPf0<0Ng]k1022PX8307emO@<0O7al1022PX8307alO0<0
QhN7101lO7`307inOP<0Ng]k0`20P80408:2PP<0OGem0`26QXH407UiN@<0RHV90`21PH4407moO`<0
Ng]k0`26QXH308:2PP@0LW9b0`21PH4308F5Q@@0OWin0`21PH4307YjNP@0PX:20`1lO7`307moO`@0
PX:20`20P8040<SPf0<0R8R8102FUYH3071`L0<0TY:B102TY:@3079bLP<0NWYj0`2?Shl406e]K@<0
JVYZ0`1iNGT4071`L0<0MgMg0`28R8P404e=C@<0;Bd]0`22PX8407=cL`<0P8200`1nOWh306=SH`@0
T92@0`2GUiL307inOP@0Q8B40`2ATI4307alO0@0OGem0`1eMGD307alO0@0Ph>30`1cLg<D0<SPf000
4`38h=P308F5Q@@0c<c<0`25QHD307emO@@0OWin0`1oOgl308^;R`@0N7Qh0`1IFET306a/K0<0UIFE
1028R8P307]kN`<0R8R8101oOgl307QhN0<0Ogmo101mOGd307inOP<0M7Ad101OGel307]kN`<0/[:b
0`2[Zj/407QhN0<0Q8B40`21PH4407IfMP<0P8200`22PX8407alO0<0T92@1038h=P30861P@@0SXj>
0`2=SHd307]kN`@0N7Qh0`2?Shl3079bLP@0L71`0`1aLG4306EUI@<0HF5Q101XJ6P308^;R`<0NWYj
101nOWh305UIF@<0H61P1`1lO7`308^;R`<0N7Qh101_Kfl308:2PP<0TI6A102CTi<309:BTP<0IfMW
101YJFT308>3P`<0MWIf101lO7`308:2PPl0b>3H0`23Ph<407emO@<0QXJ60`20P80707moO`<0NWYj
1029RHT307moO`<0SHf=0`1fMWH408:2PP<0PH610`1mOGd408N7Q`<0MGEe0`22PX8408F5Q@<0Ph>3
0`1lO7`308B4Q0@0QhN70`1mOGd307=cL`@0OWin0`26QXH307IfMP@0O7al0`21PH4307alO0@0Ph>3
0`1lO7`40<SPf0<0UYJF1023Ph<307EeM@<0OWin101_Kfl3055AD@<0TY:B0`1iNGT408b<S0<0O7al
0`1PH60409^KV`<0N7Qh0`1kNg/409NGU`<09BDU0`1@D50409RHV0<0QHF50`1dM7@30861P@@0RXZ:
0`1eMGD3061PH0@0Shn?0`1hN7P3065QH@@0NWYj0`1mOGd307moO`@0NGUi0`1dM7@D0<SPf0004`38
h=P308F5Q@@0c<c<0`25QHD307emO@@0OWin0`1oOgl308^;R`@0N7Qh0`1IFET306a/K0<0UIFE1028
R8P307]kN`<0R8R8101oOgl307QhN0<0Ogmo101mOGd307inOP<0M7Ad101OGel307]kN`<0/[:b0`2[
Zj/407QhN0<0Q8B40`21PH4407IfMP<0P8200`22PX8407alO0<0T92@1038h=P30861P@@0SXj>0`2=
SHd307]kN`@0N7Qh0`2?Shl3079bLP@0L71`0`1aLG4306EUI@<0HF5Q101XJ6P308^;R`<0NWYj101n
OWh305UIF@<0H61P1`1lO7`308^;R`<0N7Qh101_Kfl308:2PP<0TI6A102CTi<309:BTP<0IfMW101Y
JFT308>3P`<0MWIf101lO7`308:2PPl0b>3H0`23Ph<407emO@<0QXJ60`20P80707moO`<0NWYj1029
RHT307moO`<0SHf=0`1fMWH408:2PP<0PH610`1mOGd408N7Q`<0MGEe0`22PX8408F5Q@<0Ph>30`1l
O7`308B4Q0@0QhN70`1mOGd307=cL`@0OWin0`26QXH307IfMP@0O7al0`21PH4307alO0@0Ph>30`1l
O7`40<SPf0<0UYJF1023Ph<307EeM@<0OWin101_Kfl3055AD@<0TY:B0`1iNGT408b<S0<0O7al0`1P
H60409^KV`<0N7Qh0`1kNg/409NGU`<09BDU0`1@D50409RHV0<0QHF50`1dM7@30861P@@0RXZ:0`1e
MGD3061PH0@0Shn?0`1hN7P3065QH@@0NWYj0`1mOGd307moO`@0NGUi0`1dM7@D0<SPf0004`38h=P3
08F5Q@@0c<c<0`25QHD307emO@@0OWin0`1oOgl308^;R`@0N7Qh0`1IFET306a/K0<0UIFE1028R8P3
07]kN`<0R8R8101oOgl307QhN0<0Ogmo101mOGd307inOP<0M7Ad101OGel307]kN`<0/[:b0`2[Zj/4
07QhN0<0Q8B40`21PH4407IfMP<0P8200`22PX8407alO0<0T92@1038h=P30861P@@0SXj>0`2=SHd3
07]kN`@0N7Qh0`2?Shl3079bLP@0L71`0`1aLG4306EUI@<0HF5Q101XJ6P308^;R`<0NWYj101nOWh3
05UIF@<0H61P1`1lO7`308^;R`<0N7Qh101_Kfl308:2PP<0TI6A102CTi<309:BTP<0IfMW101YJFT3
08>3P`<0MWIf101lO7`308:2PPl0b>3H0`23Ph<407emO@<0QXJ60`20P80707moO`<0NWYj1029RHT3
07moO`<0SHf=0`1fMWH408:2PP<0PH610`1mOGd408N7Q`<0MGEe0`22PX8408F5Q@<0Ph>30`1lO7`3
08B4Q0@0QhN70`1mOGd307=cL`@0OWin0`26QXH307IfMP@0O7al0`21PH4307alO0@0Ph>30`1lO7`4
0<SPf0<0UYJF1023Ph<307EeM@<0OWin101_Kfl3055AD@<0TY:B0`1iNGT408b<S0<0O7al0`1PH604
09^KV`<0N7Qh0`1kNg/409NGU`<09BDU0`1@D50409RHV0<0QHF50`1dM7@30861P@@0RXZ:0`1eMGD3
061PH0@0Shn?0`1hN7P3065QH@@0NWYj0`1mOGd307moO`@0NGUi0`1dM7@D0<SPf0004`38h=P3092@
T0@0Hf=S0`1kNg/308^;R`@0NWYj0`1iNGT308b<S0@0QXJ60`2;Rh/309FEU@L0M7Ad0`1mOGd30820
P0@0Ng]k0`22PX8707UiN@<0NWYj1`1oOgl308:2PP<0Ng]k0`20P80707QhN0<0RHV91026QXH307em
O@<0PH611023Ph<308B4Q0@0b>3H0`2`/;0408:2PP<0Ph>30`1XJ6P405IFEP<0P8200`2=SHd407=c
L`<0MWIf0`2LW9`309jNWP@0MWIf0`1nOWh708F5Q@<0NWYj0`0h>3P4069RHP<0QHF50`22PX8306i^
KP@0MWIf0`21PH4308j>SP@0OWin0`1iNGT308B4Q0@0Ogmo0`1mOGd308^;R`@0N7Qh0`1iNGT?0<SP
f0<0PH611029RHT307moO`<0NWYj101fMWH3071`L0<0Jf][1025QHD308J6QP<0MWIf0`2<S8`408:2
PP<0Ng]k0`1mOGd407alO0<0QhN70`1hN7P40820P0<0Jf][0`1kNg/308>3P`@0Ogmo0`2BTY8308f=
S@@0QhN70`1iNGT307QhN0@0P8200`28R8P307alO0@0Ng]k0`21PH440<SPf0<0PH61102:RXX308J6
QP<0TI6A101UIFD307=cL`<0IFEU0`20P80408R8R0<0P8200`2ZZZX408F5Q@<0PX:20`21PH4408:2
PP<0OGem0`0a<C44071`L0<0VYZJ0`20P80307moO`@0QhN70`1hN7P30:NWY`@0KFe]0`2[Zj/309ZJ
VP@0NGUi0`1YJFT308n?S`@0MWIf0`1jNWXD0<SPf0004`38h=P3092@T0@0Hf=S0`1kNg/308^;R`@0
NWYj0`1iNGT308b<S0@0QXJ60`2;Rh/309FEU@L0M7Ad0`1mOGd30820P0@0Ng]k0`22PX8707UiN@<0
NWYj1`1oOgl308:2PP<0Ng]k0`20P80707QhN0<0RHV91026QXH307emO@<0PH611023Ph<308B4Q0@0
b>3H0`2`/;0408:2PP<0Ph>30`1XJ6P405IFEP<0P8200`2=SHd407=cL`<0MWIf0`2LW9`309jNWP@0
MWIf0`1nOWh708F5Q@<0NWYj0`0h>3P4069RHP<0QHF50`22PX8306i^KP@0MWIf0`21PH4308j>SP@0
OWin0`1iNGT308B4Q0@0Ogmo0`1mOGd308^;R`@0N7Qh0`1iNGT?0<SPf0<0PH611029RHT307moO`<0
NWYj101fMWH3071`L0<0Jf][1025QHD308J6QP<0MWIf0`2<S8`408:2PP<0Ng]k0`1mOGd407alO0<0
QhN70`1hN7P40820P0<0Jf][0`1kNg/308>3P`@0Ogmo0`2BTY8308f=S@@0QhN70`1iNGT307QhN0@0
P8200`28R8P307alO0@0Ng]k0`21PH440<SPf0<0PH61102:RXX308J6QP<0TI6A101UIFD307=cL`<0
IFEU0`20P80408R8R0<0P8200`2ZZZX408F5Q@<0PX:20`21PH4408:2PP<0OGem0`0a<C44071`L0<0
VYZJ0`20P80307moO`@0QhN70`1hN7P30:NWY`@0KFe]0`2[Zj/309ZJVP@0NGUi0`1YJFT308n?S`@0
MWIf0`1jNWXD0<SPf0004`38h=P3092@T0@0Hf=S0`1kNg/308^;R`@0NWYj0`1iNGT308b<S0@0QXJ6
0`2;Rh/309FEU@L0M7Ad0`1mOGd30820P0@0Ng]k0`22PX8707UiN@<0NWYj1`1oOgl308:2PP<0Ng]k
0`20P80707QhN0<0RHV91026QXH307emO@<0PH611023Ph<308B4Q0@0b>3H0`2`/;0408:2PP<0Ph>3
0`1XJ6P405IFEP<0P8200`2=SHd407=cL`<0MWIf0`2LW9`309jNWP@0MWIf0`1nOWh708F5Q@<0NWYj
0`0h>3P4069RHP<0QHF50`22PX8306i^KP@0MWIf0`21PH4308j>SP@0OWin0`1iNGT308B4Q0@0Ogmo
0`1mOGd308^;R`@0N7Qh0`1iNGT?0<SPf0<0PH611029RHT307moO`<0NWYj101fMWH3071`L0<0Jf][
1025QHD308J6QP<0MWIf0`2<S8`408:2PP<0Ng]k0`1mOGd407alO0<0QhN70`1hN7P40820P0<0Jf][
0`1kNg/308>3P`@0Ogmo0`2BTY8308f=S@@0QhN70`1iNGT307QhN0@0P8200`28R8P307alO0@0Ng]k
0`21PH440<SPf0<0PH61102:RXX308J6QP<0TI6A101UIFD307=cL`<0IFEU0`20P80408R8R0<0P820
0`2ZZZX408F5Q@<0PX:20`21PH4408:2PP<0OGem0`0a<C44071`L0<0VYZJ0`20P80307moO`@0QhN7
0`1hN7P30:NWY`@0KFe]0`2[Zj/309ZJVP@0NGUi0`1YJFT308n?S`@0MWIf0`1jNWXD0<SPf0004`38
h=P307YjNP@0D51@0`1lO7`707QhN0<0Ogmo0`27QhL407moO`<0Ng]k0`1NGUh308F5Q@@0Y:BT0`1o
Ogl307alO0@0Ng]k0`21PH4308J6QPL0NWYj0`1lO7`407IfMP<0OWin0`1oOgl308:2PP@0OGem0`1i
NGT306UYJ@@0OGem0`27QhL30820P0@0OGem0`21PH440<SPf0L0P8200`27QhL306m_K`@0T92@0`29
RHT307QhN0@0RHV90`2i^KT306IVIP<0CTi>102TY:@30:j^[P<0Q8B4101oOgl308J6QP<0NGUi1017
AdL307QhN0<0R8R80`25QHD407AdM0<0RHV90`1[Jf/407]kN`<0MWIf0`2a/K4408R8R0<0PX:20`27
QhL407alO0<0QXJ63`38h=P307moO`@0P8200`1oOgl708R8R0<0OWin0`29RHT40861P@<0NWYj0`23
Ph<307MgM`@0N7Qh0`20P80308:2PP@0OGem0`1jNWX308:2PP@0M7Ad0`2GUiL308J6QPL0Ph>30`25
QHD307]kN`@0RXZ:0`2;Rh/308>3P`@0QHF50`2:RXX307alO0@0PX:20`1mOGd40<SPf0<0MGEe101_
Kfl307YjNP<0Ng]k102ATI4307UiN@<0R8R80`1lO7`408J6QP<0XJ6Q0`2>SXh409BDU0<0EeMG0`1i
NGT407moO`<0PX:20`1`L70403/k>`<0@D510`24Q8@309^KV`@0PH610`1`L70309NGU`@0HV9R0`2U
YJD309NGU`@0MGEe1P1aLG4407alO0<0PH615038h=P001<0b>3H0`1jNWX4051@D0<0O7al1`1hN7P3
07moO`<0QhN7101oOgl307]kN`<0GUiN0`25QHD40:BTY0<0Ogmo0`1lO7`407]kN`<0PH610`26QXH7
07YjNP<0O7al101fMWH307inOP<0Ogmo0`22PX8407emO@<0NGUi0`1YJFT407emO@<0QhN70`20P804
07emO@<0PH611038h=P70820P0<0QhN70`1_Kfl4092@T0<0RHV90`1hN7P408V9R@<0^KVi0`1VIVH3
04i>CP@0Y:BT0`2^[Zh308B4Q0@0Ogmo0`26QXH307UiN@@0AdM70`1hN7P308R8R0<0QHF5101dM7@3
08V9R@<0Jf][101kNg/307IfMP<0/K6a1028R8P308:2PP<0QhN7101lO7`308J6QPl0b>3H0`1oOgl4
0820P0<0Ogmo1`28R8P307inOP<0RHV91021PH4307YjNP<0Ph>30`1gMgL407QhN0<0P8200`22PX84
07emO@<0NWYj0`22PX8407AdM0<0UiNG0`26QXH708>3P`<0QHF50`1kNg/408Z:RP<0Rh^;0`23Ph<4
08F5Q@<0RXZ:0`1lO7`408:2PP<0OGem1038h=P307EeM@@0Kfm_0`1jNWX307]kN`@0TI6A0`1iNGT3
08R8R0<0O7al1026QXH30:6QX@<0SXj>102DU9@305MGE`<0NGUi101oOgl308:2PP<0L71`100k>c/3
0451@@<0Q8B40`2KVi/40861P@<0L71`0`2GUiL4069RHP<0YJFU0`2GUiL407EeM@H0LG5a101lO7`3
0861PA@0b>3H000C0<SPf0<0NWYj101@D50307alO0L0N7Qh0`1oOgl308N7Q`@0Ogmo0`1kNg/305iN
GP<0QHF5102TY:@307moO`<0O7al101kNg/30861P@<0QXJ61`1jNWX307alO0@0MWIf0`1nOWh307mo
O`<0PX:2101mOGd307UiN@<0JFUY101mOGd308N7Q`<0P820101mOGd30861P@@0b>3H1`20P80308N7
Q`<0Kfm_102@T90308V9R@<0N7Qh1029RHT30;Vi^@<0IVIV0`1>CTh40:BTY0<0[Zj^0`24Q8@407mo
O`<0QXJ60`1iNGT404M7A`<0N7Qh0`28R8P308F5Q@@0M7Ad0`29RHT306][J`@0Ng]k0`1fMWH30;6a
/@@0R8R80`22PX8308N7Q`@0O7al0`26QXH?0<SPf0<0Ogmo1020P80307moO`L0R8R80`1nOWh308V9
R@@0PH610`1jNWX308>3P`<0MgMg101hN7P30820P0<0PX:2101mOGd307YjNP<0PX:2101dM7@309NG
U`<0QXJ61`23Ph<308F5Q@<0Ng]k102:RXX308^;R`<0Ph>31025QHD308Z:RP<0O7al1022PX8307em
O@@0b>3H0`1eMGD406m_K`<0NWYj0`1kNg/4096AT@<0NGUi0`28R8P307alO0@0QXJ60`2QXJ4308j>
SP@0U9BD0`1GEeL307UiN@@0Ogmo0`22PX83071`L0@0>c/k0`11@D4308B4Q0<0Vi^K1021PH43071`
L0<0UiNG101RHV830:FUY@<0UiNG101eMGD6075aL@@0O7al0`21PH4D0<SPf0004`38h=P307YjNP@0
D51@0`1lO7`707QhN0<0Ogmo0`27QhL407moO`<0Ng]k0`1NGUh308F5Q@@0Y:BT0`1oOgl307alO0@0
Ng]k0`21PH4308J6QPL0NWYj0`1lO7`407IfMP<0OWin0`1oOgl308:2PP@0OGem0`1iNGT306UYJ@@0
OGem0`27QhL30820P0@0OGem0`21PH440<SPf0L0P8200`27QhL306m_K`@0T92@0`29RHT307QhN0@0
RHV90`2i^KT306IVIP<0CTi>102TY:@30:j^[P<0Q8B4101oOgl308J6QP<0NGUi1017AdL307QhN0<0
R8R80`25QHD407AdM0<0RHV90`1[Jf/407]kN`<0MWIf0`2a/K4408R8R0<0PX:20`27QhL407alO0<0
QXJ63`38h=P307moO`@0P8200`1oOgl708R8R0<0OWin0`29RHT40861P@<0NWYj0`23Ph<307MgM`@0
N7Qh0`20P80308:2PP@0OGem0`1jNWX308:2PP@0M7Ad0`2GUiL308J6QPL0Ph>30`25QHD307]kN`@0
RXZ:0`2;Rh/308>3P`@0QHF50`2:RXX307alO0@0PX:20`1mOGd40<SPf0<0MGEe101_Kfl307YjNP<0
Ng]k102ATI4307UiN@<0R8R80`1lO7`408J6QP<0XJ6Q0`2>SXh409BDU0<0EeMG0`1iNGT407moO`<0
PX:20`1`L70403/k>`<0@D510`24Q8@309^KV`@0PH610`1`L70309NGU`@0HV9R0`2UYJD309NGU`@0
MGEe1P1aLG4407alO0<0PH615038h=P001<0b>3H0`1`L70406QXJ0<0Rh^;0`26QXH407EeM@<0Ogmo
0`20P80407moO`<0Ng]k0`2:RXX308b<S0@0K6a/0`25QHD308>3P`@0O7al0`1oOgl307inOP@0Ogmo
0`1mOGd308:2PP@0NGUi0`1eMGD308:2PP<0Q8B4101BDU8306][J`<0O7al101kNg/307YjNP<0QHF5
1`1kNg/40<SPf0<0Ph>3101iNGT308n?S`<0PH61101dM7@308N7Q`<0Jf][102GUiL309BDU0<0WinO
0`2^[Zh408:2PP<0KVi^0`1dM7@407inOP<0QHF50`1lO7`407AdM0<0K6a/0`2MWId308>3P`@0MgMg
0`2>SXh308F5Q@@0N7Qh0`2BTY830820P0@0Ogmo0`23Ph<307MgM`@0NWYj0`22PX8?0<SPf0<0OWin
1024Q8@306e]K@<0O7al101gMgL307]kN`<0PH61101kNg/308f=S@<0OGem0`29RHT40820P0<0PH61
0`1oOgl407inOP<0Ogmo0`20P80408n?S`<0JVYZ0`1nOWh308F5Q@@0P8200`1jNWX308F5Q@@0RHV9
0`1fMWH307alO0X0Ogmo1024Q8@30861P@@0b>3H0`1dM7@407IfMP<0/K6a0`2DU9@408>3P`<0N7Qh
0`20P8030;bl_0@0^KVi0`1cLg<308Z:RP@0Ph>30`1/K6`708:2PP<0SHf=0`1hN7P40861P@<0J6QX
0`12@T8307MgM`@0MWIf0`1PH60309:BTP@0RXZ:0`2;Rh/307AdM0@0MGEe0`23Ph<308R8R0@0Ph>3
0`1jNWXD0<SPf0004`38h=P3071`L0@0J6QX0`2;Rh/308J6QP@0MGEe0`1oOgl30820P0@0Ogmo0`1k
Ng/308Z:RP<0S8b<101/K6`308F5Q@<0Ph>3101lO7`307moO`<0OWin101oOgl307emO@<0PX:2101i
NGT307EeM@<0PX:20`24Q8@4059BDP<0Jf][0`1lO7`407]kN`<0NWYj0`25QHD707]kN`@0b>3H0`23
Ph<407UiN@<0Shn?0`21PH4407AdM0<0QhN70`1[Jf/409NGU`<0U9BD0`2OWil30:j^[P@0PX:20`1^
KVh307AdM0@0OWin0`25QHD307alO0@0M7Ad0`1/K6`309fMW@<0Ph>3101gMgL308j>SP<0QHF5101h
N7P309:BTP<0P820101oOgl308>3P`<0MgMg101jNWX308:2PPl0b>3H0`1nOWh408B4Q0<0KFe]0`1l
O7`407MgM`<0Ng]k0`21PH4407]kN`<0SHf=0`1mOGd308V9R@@0P8200`21PH4307moO`@0OWin0`1o
Ogl30820P0@0Shn?0`1ZJVX307inOP<0QHF51020P80307YjNP<0QHF51029RHT307IfMP<0O7al2P1o
Ogl408B4Q0<0PH611038h=P307AdM0@0MWIf0`2a/K4309BDU0@0Ph>30`1hN7P30820P0<0_;bl102i
^KT307=cL`<0RXZ:1023Ph<306a/K0L0PX:20`2=SHd307QhN0@0PH610`1XJ6P30492@P<0MgMg101f
MWH3061PH0<0TY:B102:RXX308^;R`<0M7Ad101eMGD308>3P`<0R8R81023Ph<307YjNQ@0b>3H000C
0<SPf0<0L71`101XJ6P308^;R`<0QXJ6101eMGD307moO`<0P820101oOgl307]kN`<0RXZ:0`2<S8`4
06a/K0<0QHF50`23Ph<407alO0<0Ogmo0`1nOWh407moO`<0OGem0`22PX8407UiN@<0MGEe0`22PX83
08B4Q0@0DU9B0`1[Jf/307alO0@0Ng]k0`1jNWX308F5Q@L0Ng]k1038h=P308>3P`@0NGUi0`2?Shl3
0861P@@0M7Ad0`27QhL306][J`@0UiNG0`2DU9@309nOW`<0[Zj^1022PX8306i^KP<0M7Ad101nOWh3
08F5Q@<0O7al101dM7@306a/K0<0WIfM0`23Ph<407MgM`<0SXj>0`25QHD407QhN0<0TY:B0`20P804
07moO`<0Ph>30`1gMgL407YjNP<0PX:23`38h=P307inOP@0Q8B40`1]KFd307alO0@0MgMg0`1kNg/3
0861P@@0Ng]k0`2=SHd307emO@<0RHV91020P8030861P@<0Ogmo101nOWh307moO`<0P820102?Shl3
06YZJP<0OWin0`25QHD40820P0<0NWYj0`25QHD408V9R@<0MWIf0`1lO7`:07moO`@0Q8B40`21PH44
0<SPf0<0M7Ad101fMWH30;6a/@<0U9BD1023Ph<307QhN0<0P8200`2l_;`40;Vi^@<0Lg=c0`2:RXX4
08>3P`<0K6a/1`22PX8308f=S@<0N7Qh1021PH4306QXJ0<0@T920`1gMgL407IfMP<0H61P0`2BTY84
08Z:RP<0Rh^;0`1dM7@407EeM@<0Ph>30`28R8P408>3P`<0NWYj5038h=P001<0b>3H0`1_Kfl407If
MP<0YZJV0`2FUYH409NGU`<0Q8B40`1mOGd4075aL@<09RHV0`1KFe/308^;R`@0U9BD0`1fMWH307Ui
N@@0OWin0`24Q8@307alO0@0OGem0`1lO7`307inOP@0PH610`22PX8307=cL`<0Ng]k1021PH4307Mg
M`<0Ogmo1024Q8@308N7Q`<0OWin101lO7`308:2PP@0b>3H0`1mOGd408j>SPH0V9RH101nOWh308V9
R@<0S8b<101lO7`308R8R0<0O7al0`1bLW840820P0<0T92@0`1BDU8406e]K@<0PH610`2;Rh/40820
P0<0Ph>30`2?Shl309RHV0@0OGem0`1_Kfl307AdM0@0QXJ60`1jNWX307alO0@0QHF50`21PH430820
P0@0NGUi0`27QhL?0<SPf0<0KVi^102<S8`309JFUP<0PH611020P80308:2PP<0Shn?102CTi<607]k
N`<0QhN71024Q8@307UiN@<0O7al1`20P80308B4Q0@0MgMg1P2;Rh/306e]K@@0Ng]k0`21PH4307]k
N`@0QXJ60`27QhL307moO`@0Rh^;0`1lO7`308B4Q0@0PH610`26QXH40<SPf0<0S8b<102IVIT307in
OP<0TI6A101hN7P306m_K`<0Q8B40`2SXj<407moO`<0K6a/0`27QhL407alO0<0I6AT0`2RXZ840:JV
YP<0N7Qh0`27QhL407EeM@<0Q8B40`2:RXX309JFUP@0YZJV0`1bLW8306i^KP@0Lg=c0`1oOgl308>3
P`@0MGEe0`27QhL307]kN`@0Q8B40`1fMWHD0<SPf0004`38h=P306m_K`@0MWIf0`2VYZH309JFUP@0
UiNG0`24Q8@307emO@@0LG5a0`0V9RH305]KF`<0Rh^;102DU9@307IfMP<0NGUi101nOWh308B4Q0<0
O7al101mOGd307alO0<0OWin1021PH4308:2PP<0Lg=c0`1kNg/40861P@<0MgMg0`1oOgl408B4Q0<0
QhN70`1nOWh407alO0<0PX:21038h=P307emO@@0SXj>1P2HV9P407inOP<0RHV90`2<S8`407alO0<0
R8R80`1lO7`3079bLP@0P8200`2@T903059BDP@0KFe]0`21PH4308^;R`@0P8200`23Ph<308n?S`<0
V9RH101mOGd306m_K`<0M7Ad1026QXH307YjNP<0O7al1025QHD30861P@<0P820101iNGT308N7Q`l0
b>3H0`1^KVh408b<S0<0UYJF0`21PH440820P0<0PX:20`2?Shl409>CT`H0Ng]k0`27QhL408B4Q0<0
NGUi0`1lO7`70820P0<0Q8B4101gMgL608^;R`<0KFe]101kNg/30861P@<0Ng]k1026QXH308N7Q`<0
Ogmo102;Rh/307alO0<0Q8B41021PH4308J6QP@0b>3H0`2<S8`409VIV@<0OWin0`2ATI4407QhN0<0
Kfm_0`24Q8@30:>SX`@0Ogmo0`1/K6`308N7Q`@0O7al0`1TI6@30::RXP@0YZJV0`1hN7P308N7Q`@0
MGEe0`24Q8@308Z:RP<0UYJF102VYZH3079bLP<0KVi^101cLg<307moO`<0Ph>3101eMGD308N7Q`<0
Ng]k1024Q8@307IfMQ@0b>3H000C0<SPf0<0Kfm_101fMWH30:JVYP<0UYJF102GUiL308B4Q0<0OGem
101aLG4302HV9P<0Fe]K0`2;Rh/409BDU0<0MWIf0`1iNGT407inOP<0Q8B40`1lO7`407emO@<0O7al
0`1nOWh40861P@<0PX:20`1cLg<307]kN`@0PH610`1gMgL307moO`@0Q8B40`27QhL307inOP@0O7al
0`22PX840<SPf0<0OGem102>SXh609RHV0@0OWin0`29RHT308b<S0@0O7al0`28R8P307alO0<0LW9b
1020P803092@T0<0DU9B101]KFd30861P@<0Rh^;1020P80308>3P`<0Shn?0`2HV9P407emO@<0Kfm_
0`1dM7@408J6QP<0NWYj0`1lO7`408F5Q@<0PH610`20P80407UiN@<0QhN73`38h=P306i^KP@0S8b<
0`2FUYH30861P@@0P8200`22PX8308n?S`@0Ti>C1P1kNg/308N7Q`@0Q8B40`1iNGT307alO0L0P820
0`24Q8@407MgM`H0Rh^;0`1]KFd407]kN`<0PH610`1kNg/408J6QP<0QhN70`1oOgl408^;R`<0O7al
0`24Q8@40861P@<0QXJ61038h=P308b<S0@0VIVI0`1nOWh3096AT@@0N7Qh0`1_Kfl308B4Q0<0Xj>S
101oOgl306a/K0<0QhN7101lO7`306ATI0<0XZ:R102VYZH307QhN0<0QhN7101eMGD308B4Q0<0RXZ:
0`2FUYH40:JVYP<0LW9b0`1^KVh407=cL`<0Ogmo0`23Ph<407EeM@<0QhN70`1kNg/408B4Q0<0MWIf
5038h=P001<0b>3H0`1lO7`407MgM`<0Kfm_0`1`L70408F5Q@<0Ng]k0`1QHF44096AT@<0IFEU0`1X
J6P308J6QP@0IVIV0`28R8P308B4Q0@0M7Ad2P1mOGd307alO0<0Ogmo1022PX860861P@<0NGUi101n
OWh607moO`@0OWin0`1oOgl30820P0@0OGem0`23Ph<40<SPf0<0PX:2101fMWH309VIV@<0R8R8101f
MWH308J6QP<0MgMg101XJ6P3079bLP<0ZJVY0`2;Rh/406ATI0<0GemO0`1mOGd408Z:RP<0NWYj0`1l
O7`408:2PP<0Ph>30`24Q8@307inOP@0Kfm_0`27QhL307]kN`@0PX:20`1iNGT308J6QP@0R8R80`22
PX8307YjNP@0OWin0`21PH4?0<SPf0<0R8R81024Q8@30861P@<0QHF51022PX8307UiN@<0LW9b101a
LG430820P0<0Ogmo0`1lO7`408V9R@<0OWin0`21PH4408:2PP<0MWIf1`20P80607]kN`<0T92@102X
Z:P307moO`<0N7Qh1`21PH4308B4Q0@0N7Qh0`20P80708>3P`<0R8R81038h=P3075aL@@0H61P0`1F
EUH307IfMP@0QXJ60`1gMgL30861P@<0Jf][102NWYh306EUI@<0Rh^;1020P80307QhN0<0UIFE102Y
ZJT308:2PP<0NWYj101mOGd307EeM@<0N7Qh0`2;Rh/40:2PX0<0Kfm_0`1eMGD407moO`H0N7Qh101j
NWX30861P@<0MWIf1`20P80D0<SPf0004`38h=P307alO0@0MgMg0`1_Kfl3071`L0@0QHF50`1kNg/3
065QH@@0TI6A0`1UIFD306QXJ0<0QXJ6101VIVH308R8R0<0Q8B4101dM7@:07emO@<0O7al0`1oOgl4
08:2PPH0PH610`1iNGT407inOPH0Ogmo101nOWh307moO`<0P820101mOGd308>3P`@0b>3H0`22PX84
07IfMP<0VIVI0`28R8P407IfMP<0QXJ60`1gMgL406QXJ0<0LW9b0`2YZJT308^;R`@0I6AT0`1OGel3
07emO@@0RXZ:0`1jNWX307alO0@0PX:20`23Ph<308B4Q0<0OWin101_Kfl308N7Q`<0Ng]k1022PX83
07UiN@<0QXJ61028R8P308:2PP<0NWYj101nOWh30861P@l0b>3H0`28R8P408B4Q0<0PH610`25QHD4
08:2PP<0NGUi0`1bLW84075aL@<0P8200`1oOgl307alO0@0RHV90`1nOWh30861P@@0PX:20`1fMWH7
0820P0H0Ng]k0`2@T9040:RXZ0<0Ogmo0`1hN7P70861P@<0Q8B4101hN7P30820P0L0Ph>30`28R8P4
0<SPf0<0LG5a101PH60305IFEP<0MWIf1026QXH307MgM`<0PH610`1[Jf/409jNWP<0IFEU0`2;Rh/4
0820P0<0N7Qh0`2EUID40:VYZ@<0PX:20`1jNWX407emO@<0MGEe0`1hN7P308^;R`@0X:2P0`1_Kfl3
07EeM@@0Ogmo1P1hN7P407YjNP<0PH610`1fMWH70820P1@0b>3H000C0<SPf0<0O7al101gMgL306m_
K`<0L71`1025QHD307]kN`<0HF5Q102ATI4306EUI@<0J6QX0`26QXH406IVIP<0R8R80`24Q8@407Ad
M0X0OGem0`1lO7`307moO`@0PX:21P21PH4307UiN@@0OWin1P1oOgl407inOP<0Ogmo0`20P80407em
O@<0Ph>31038h=P308:2PP@0MWIf0`2IVIT308R8R0@0MWIf0`26QXH307MgM`@0J6QX0`1bLW830:VY
Z@<0Rh^;101TI6@305mOG`<0OGem102:RXX307YjNP<0O7al1022PX8308>3P`<0Q8B40`1nOWh406m_
K`<0QhN70`1kNg/408:2PP<0NGUi0`26QXH408R8R0<0PX:20`1jNWX407inOP<0PH613`38h=P308R8
R0@0Q8B40`21PH4308F5Q@@0PX:20`1iNGT3079bLP@0LG5a0`20P80307moO`<0O7al1029RHT307in
OP<0PH611022PX8307IfMPL0P8201P1kNg/3092@T0@0Z:RX0`1oOgl307QhN0L0PH610`24Q8@407Qh
N0<0P8201`23Ph<308R8R0@0b>3H0`1aLG44061PH0<0EUIF0`1fMWH408J6QP<0MgMg0`21PH4306][
J`@0WYjN0`1UIFD308^;R`@0P8200`1hN7P309FEU@@0ZJVY0`22PX8307YjNP@0OGem0`1eMGD307Qh
N0<0Rh^;102PX:0306m_K`<0MGEe101oOgl607QhN0@0NWYj0`21PH4307IfMPL0P8205038h=P001<0
b>3H0`2ATI4408R8R0<0PH610`1oOgl40820P0<0R8R80`1=CDd406EUI@<0YZJV0`25QHD3065QH@@0
S8b<0`1lO7`307IfMP@0QHF50`1nOWh307emO@@0PH610`23Ph<307YjNP@0O7al0`26QXH307]kN`L0
P8200`1oOgl308J6QP@0OWin0`1oOgl308:2PP@0Ng]k0`23Ph<40<SPf0<0M7Ad101YJFT30;:b/P<0
U9BD102CTi<307YjNP<0Q8B4102>SXh3071`L0<0B4Q80`0G5aL407emO@<0UIFE0`2BTY840:2PX0<0
YjNW0`21PH4407alO0<0OWin0`28R8P307]kN`@0MgMg0`1iNGT308V9R@@0O7al0`21PH4308N7Q`@0
PH610`28R8P307YjNP@0NGUi0`1kNg/?0<SPf0<0PX:2101kNg/307MgM`<0HV9R1021PH4308Z:RP<0
P820101iNGT308:2PP<0OWin0`2?Shl407inOPH0Ogmo1026QXH307YjNP<0PX:21023Ph<307inOP<0
P8200`1lO7`407EeM@H0OWin1`24Q8@30820P0@0QHF50`1jNWX308>3P`@0NGUi0`1nOWh40<SPf0<0
Rh^;101TI6@30820P0<0IfMW1026QXH309FEU@<0QHF50`1lO7`709BDU0<0_[jn1023Ph<307YjNP<0
I6AT102<S8`307inOP<0Ng]k1027QhL307moO`<0N7Qh0`26QXH406e]K@<0MWIf0`20P80408>3P`<0
N7Qh0`28R8P407]kN`<0PH610`24Q8@40820P0<0PX:25038h=P001<0b>3H0`2ATI4408R8R0<0PH61
0`1oOgl40820P0<0R8R80`1=CDd406EUI@<0YZJV0`25QHD3065QH@@0S8b<0`1lO7`307IfMP@0QHF5
0`1nOWh307emO@@0PH610`23Ph<307YjNP@0O7al0`26QXH307]kN`L0P8200`1oOgl308J6QP@0OWin
0`1oOgl308:2PP@0Ng]k0`23Ph<40<SPf0<0M7Ad101YJFT30;:b/P<0U9BD102CTi<307YjNP<0Q8B4
102>SXh3071`L0<0B4Q80`0G5aL407emO@<0UIFE0`2BTY840:2PX0<0YjNW0`21PH4407alO0<0OWin
0`28R8P307]kN`@0MgMg0`1iNGT308V9R@@0O7al0`21PH4308N7Q`@0PH610`28R8P307YjNP@0NGUi
0`1kNg/?0<SPf0<0PX:2101kNg/307MgM`<0HV9R1021PH4308Z:RP<0P820101iNGT308:2PP<0OWin
0`2?Shl407inOPH0Ogmo1026QXH307YjNP<0PX:21023Ph<307inOP<0P8200`1lO7`407EeM@H0OWin
1`24Q8@30820P0@0QHF50`1jNWX308>3P`@0NGUi0`1nOWh40<SPf0<0Rh^;101TI6@30820P0<0IfMW
1026QXH309FEU@<0QHF50`1lO7`709BDU0<0_[jn1023Ph<307YjNP<0I6AT102<S8`307inOP<0Ng]k
1027QhL307moO`<0N7Qh0`26QXH406e]K@<0MWIf0`20P80408>3P`<0N7Qh0`28R8P407]kN`<0PH61
0`24Q8@40820P0<0PX:25038h=P001<0b>3H0`2ATI4408R8R0<0PH610`1oOgl40820P0<0R8R80`1=
CDd406EUI@<0YZJV0`25QHD3065QH@@0S8b<0`1lO7`307IfMP@0QHF50`1nOWh307emO@@0PH610`23
Ph<307YjNP@0O7al0`26QXH307]kN`L0P8200`1oOgl308J6QP@0OWin0`1oOgl308:2PP@0Ng]k0`23
Ph<40<SPf0<0M7Ad101YJFT30;:b/P<0U9BD102CTi<307YjNP<0Q8B4102>SXh3071`L0<0B4Q80`0G
5aL407emO@<0UIFE0`2BTY840:2PX0<0YjNW0`21PH4407alO0<0OWin0`28R8P307]kN`@0MgMg0`1i
NGT308V9R@@0O7al0`21PH4308N7Q`@0PH610`28R8P307YjNP@0NGUi0`1kNg/?0<SPf0<0PX:2101k
Ng/307MgM`<0HV9R1021PH4308Z:RP<0P820101iNGT308:2PP<0OWin0`2?Shl407inOPH0Ogmo1026
QXH307YjNP<0PX:21023Ph<307inOP<0P8200`1lO7`407EeM@H0OWin1`24Q8@30820P0@0QHF50`1j
NWX308>3P`@0NGUi0`1nOWh40<SPf0<0Rh^;101TI6@30820P0<0IfMW1026QXH309FEU@<0QHF50`1l
O7`709BDU0<0_[jn1023Ph<307YjNP<0I6AT102<S8`307inOP<0Ng]k1027QhL307moO`<0N7Qh0`26
QXH406e]K@<0MWIf0`20P80408>3P`<0N7Qh0`28R8P407]kN`<0PH610`24Q8@40820P0<0PX:25038
h=P001<0b>3H0`2ATI4408R8R0<0PH610`1oOgl40820P0<0R8R80`1=CDd406EUI@<0YZJV0`25QHD3
065QH@@0S8b<0`1lO7`307IfMP@0QHF50`1nOWh307emO@@0PH610`23Ph<307YjNP@0O7al0`26QXH3
07]kN`L0P8200`1oOgl308J6QP@0OWin0`1oOgl308:2PP@0Ng]k0`23Ph<40<SPf0<0LG5a101_Kfl3
04E5A@<0SXj>102ATI430820P0<0OGem1020P80309RHV0<0/;2`0`2YZJT407EeM@<0TI6A0`2YZJT4
09:BTP<0[:b/0`2=SHd407emO@<0R8R80`1kNg/3071`L0@0NWYj0`1fMWH307alO0@0N7Qh0`1eMGD3
07UiN@@0QHF50`26QXH307]kN`L0PH613`38h=P308J6QP@0OWin0`20P80307emO@@0Rh^;0`24Q8@3
07alO0@0NGUi0`22PX8308R8R0<0QhN7101lO7`308J6QP<0R8R8101kNg/308:2PP<0RXZ:101lO7`3
07emO@<0Q8B40`23Ph<40861P@<0NWYj0`1oOgl408J6QPH0PX:21020P80607moO`@0Q8B40`23Ph<4
0<SPf0<0Rh^;101TI6@30820P0<0IfMW1026QXH309FEU@<0QHF50`1lO7`709BDU0<0_[jn1023Ph<3
07YjNP<0I6AT102<S8`307inOP<0Ng]k1027QhL307moO`<0N7Qh0`26QXH406e]K@<0MWIf0`20P804
08>3P`<0N7Qh0`28R8P407]kN`<0PH610`24Q8@40820P0<0PX:25038h=P001<0b>3H0`1OGel407in
OP<0R8R82P26QXH30820P0@0IFEU0`1eMGD308B4Q0<0Shn?1026QXH307EeM@<0NWYj101iNGT30861
P@<0QhN7101nOWh308J6QP<0OWin1026QXH309VIV@<0N7Qh0`1mOGd707moO`L0P8200`1mOGd307in
OP@0OGem0`27QhL40<SPf0<0LG5a101_Kfl304E5A@<0SXj>102ATI430820P0<0OGem1020P80309RH
V0<0/;2`0`2YZJT407EeM@<0TI6A0`2YZJT409:BTP<0[:b/0`2=SHd407emO@<0R8R80`1kNg/3071`
L0@0NWYj0`1fMWH307alO0@0N7Qh0`1eMGD307UiN@@0QHF50`26QXH307]kN`L0PH613`38h=P308J6
QP@0OWin0`20P80307emO@@0Rh^;0`24Q8@307alO0@0NGUi0`22PX8308R8R0<0QhN7101lO7`308J6
QP<0R8R8101kNg/308:2PP<0RXZ:101lO7`307emO@<0Q8B40`23Ph<40861P@<0NWYj0`1oOgl408J6
QPH0PX:21020P80607moO`@0Q8B40`23Ph<40<SPf0<0UYJF102TY:@308J6QPL0L71`0`24Q8@308Z:
RP<0Lg=c101iNGT3071`L0<0SHf=101lO7`308>3P`<0HF5Q102@T903051@D0<0>SXj101oOgl3079b
LP<0NGUi0`22PX8408B4Q0<0NGUi0`2BTY8407=cL`<0R8R80`2=SHd407UiN@<0PH610`1dM7@4075a
L@<0M7Ad5038h=P001<0b>3H0`1OGel407inOP<0R8R82P26QXH30820P0@0IFEU0`1eMGD308B4Q0<0
Shn?1026QXH307EeM@<0NWYj101iNGT30861P@<0QhN7101nOWh308J6QP<0OWin1026QXH309VIV@<0
N7Qh0`1mOGd707moO`L0P8200`1mOGd307inOP@0OGem0`27QhL40<SPf0<0LG5a101_Kfl304E5A@<0
SXj>102ATI430820P0<0OGem1020P80309RHV0<0/;2`0`2YZJT407EeM@<0TI6A0`2YZJT409:BTP<0
[:b/0`2=SHd407emO@<0R8R80`1kNg/3071`L0@0NWYj0`1fMWH307alO0@0N7Qh0`1eMGD307UiN@@0
QHF50`26QXH307]kN`L0PH613`38h=P308J6QP@0OWin0`20P80307emO@@0Rh^;0`24Q8@307alO0@0
NGUi0`22PX8308R8R0<0QhN7101lO7`308J6QP<0R8R8101kNg/308:2PP<0RXZ:101lO7`307emO@<0
Q8B40`23Ph<40861P@<0NWYj0`1oOgl408J6QPH0PX:21020P80607moO`@0Q8B40`23Ph<40<SPf0<0
UYJF102TY:@308J6QPL0L71`0`24Q8@308Z:RP<0Lg=c101iNGT3071`L0<0SHf=101lO7`308>3P`<0
HF5Q102@T903051@D0<0>SXj101oOgl3079bLP<0NGUi0`22PX8408B4Q0<0NGUi0`2BTY8407=cL`<0
R8R80`2=SHd407UiN@<0PH610`1dM7@4075aL@<0M7Ad5038h=P001<0b>3H0`1OGel407inOP<0R8R8
2P26QXH30820P0@0IFEU0`1eMGD308B4Q0<0Shn?1026QXH307EeM@<0NWYj101iNGT30861P@<0QhN7
101nOWh308J6QP<0OWin1026QXH309VIV@<0N7Qh0`1mOGd707moO`L0P8200`1mOGd307inOP@0OGem
0`27QhL40<SPf0<0LG5a101_Kfl304E5A@<0SXj>102ATI430820P0<0OGem1020P80309RHV0<0/;2`
0`2YZJT407EeM@<0TI6A0`2YZJT409:BTP<0[:b/0`2=SHd407emO@<0R8R80`1kNg/3071`L0@0NWYj
0`1fMWH307alO0@0N7Qh0`1eMGD307UiN@@0QHF50`26QXH307]kN`L0PH613`38h=P308J6QP@0OWin
0`20P80307emO@@0Rh^;0`24Q8@307alO0@0NGUi0`22PX8308R8R0<0QhN7101lO7`308J6QP<0R8R8
101kNg/308:2PP<0RXZ:101lO7`307emO@<0Q8B40`23Ph<40861P@<0NWYj0`1oOgl408J6QPH0PX:2
1020P80607moO`@0Q8B40`23Ph<40<SPf0<0UYJF102TY:@308J6QPL0L71`0`24Q8@308Z:RP<0Lg=c
101iNGT3071`L0<0SHf=101lO7`308>3P`<0HF5Q102@T903051@D0<0>SXj101oOgl3079bLP<0NGUi
0`22PX8408B4Q0<0NGUi0`2BTY8407=cL`<0R8R80`2=SHd407UiN@<0PH610`1dM7@4075aL@<0M7Ad
5038h=P001<0b>3H0`26QXH406i^KPH0MgMg101nOWh307YjNP<0PX:2102MWId306a/K0<0W9bL0`2A
TI4407inOP<0J6QX0`1PH60408Z:RP<0OGem1`20P80308>3P`<0P820101XJ6P30:ZZZPH0OGem101n
OWh307UiN@<0P8201023Ph<307moO`<0OWin1026QXH308R8R0@0b>3H0`2:RXX409:BTP<0Ogmo0`2@
T90406IVIP<0QHF50`1mOGd407alO0<0M7Ad0`1:BTX30820P0@0UIFE0`1>CTh304e=C@@0N7Qh0`2P
X:0306m_K`@0OWin0`27QhL308>3P`<0TI6A1022PX8307moO`<0QXJ6101gMgL306i^KP<0P8201025
QHD608>3P`@0Q8B40`1oOgl?0<SPf0<0M7Ad1027QhL30820P0<0R8R8101kNg/30861P@<0Ogmo1023
Ph<307=cL`<0P8200`1eMGD40861P@<0S8b<0`1oOgl408B4Q0<0O7al0`1kNg/40861P@<0NWYj0`1o
Ogl308N7Q`@0PX:21P25QHD407alO0<0N7Qh1`26QXH307moO`<0OGem101jNWX30861P@@0b>3H0`2;
Rh/408f=S@<0S8b<0`22PX8406=SH`<0Xj>S0`2QXJ4307IfMP@0S8b<0`1fMWH307=cL`@0RXZ:0`1J
FUX3071`L0@0K6a/0`1TI6@30451@@@0HV9R0`1mOGd307QhN0<0Ng]k102:RXX307alO0<0Ogmo101i
NGT3069RHP<0Hf=S1020P80307emO@<0NGUi101aLG4308N7Qa@0b>3H000C0<SPf0<0QXJ6101^KVh6
07MgM`@0OWin0`1jNWX308:2PP@0WIfM0`1/K6`309bLW0<0TI6A101nOWh306QXJ0<0H61P102:RXX3
07emO@L0P8200`23Ph<30820P0@0J6QX0`2ZZZX607emO@@0OWin0`1iNGT30820P0@0Ph>30`1oOgl3
07inOP@0QXJ60`28R8P40<SPf0<0RXZ:102BTY8307moO`<0T92@101VIVH308F5Q@<0OGem101lO7`3
07AdM0<0BTY:0`20P80409FEU@<0CTi>0`1=CDd407QhN0<0X:2P0`1_Kfl407inOP<0QhN70`23Ph<3
096AT@@0PX:20`1oOgl308J6QP@0MgMg0`1^KVh30820P0@0QHF51P23Ph<408B4Q0<0Ogmo3`38h=P3
07AdM0@0QhN70`20P80308R8R0@0Ng]k0`21PH4307moO`@0Ph>30`1cLg<30820P0<0MGEe1021PH43
08b<S0<0Ogmo1024Q8@307alO0<0Ng]k1021PH4307YjNP<0Ogmo0`27QhL408:2PPH0QHF5101lO7`3
07QhN0L0QXJ60`1oOgl307emO@@0NWYj0`21PH440<SPf0<0Rh^;102=SHd308b<S0<0PX:2101SHf<3
0:>SX`<0XJ6Q0`1fMWH408b<S0<0MWIf0`1cLg<408Z:RP<0FUYJ0`1`L70406a/K0<0I6AT0`11@D44
069RHP<0OGem0`1hN7P307]kN`@0RXZ:0`1lO7`307moO`@0NGUi0`1RHV8306=SH`@0P8200`1mOGd3
07UiN@@0LG5a0`27QhLD0<SPf0004`38h=P308J6QP@0KVi^1P1gMgL407inOP<0NWYj0`22PX8409fM
W@<0K6a/0`2LW9`3096AT@@0OWin0`1XJ6P3061PH0@0RXZ:0`1mOGd70820P0<0Ph>30`20P80406QX
J0<0ZZZZ1P1mOGd407inOP<0NGUi0`20P80408>3P`<0Ogmo0`1nOWh408J6QP<0R8R81038h=P308Z:
RP@0TY:B0`1oOgl3092@T0@0IVIV0`25QHD307emO@@0O7al0`1dM7@304Y:BP<0P820102EUID304i>
CP<0CDe=101hN7P30:2PX0<0Kfm_101nOWh308N7Q`<0Ph>30`2ATI4408:2PP<0Ogmo0`26QXH407Mg
M`<0KVi^0`20P80408F5Q@H0Ph>31024Q8@307moO`l0b>3H0`1dM7@408N7Q`<0P8200`28R8P407]k
N`<0PH610`1oOgl408>3P`<0Lg=c0`20P80307EeM@@0PH610`2<S8`307moO`@0Q8B40`1lO7`307]k
N`@0PH610`1jNWX307moO`<0QhN71022PX8608F5Q@@0O7al0`1hN7P708J6QP<0Ogmo0`1mOGd407Yj
NP<0PH611038h=P308^;R`@0SHf=0`2<S8`308:2PP@0Hf=S0`2SXj<30:6QX@<0MWIf102<S8`307If
MP<0Lg=c102:RXX305YJFP<0L71`101/K6`306ATI0<0@D51101RHV8307emO@<0N7Qh0`1kNg/408Z:
RP<0O7al0`1oOgl407UiN@<0HV9R0`1SHf<40820P0<0OGem0`1iNGT4075aL@<0QhN75038h=P001<0
b>3H0`1kNg/408R8R0<0SXj>0`24Q8@408>3P`<0OWin0`27QhL407EeM@<0N7Qh0`2GUiL306IVIP@0
RHV90`37alL308B4Q0@0LW9b0`23Ph<307]kN`@0QHF50`22PX8307inOP@0O7al0`2<S8`307alO0<0
Q8B4101mOGd307alO0<0Ph>31021PH4:07moO`<0OWin1038h=P308F5Q@@0OGem0`28R8P308F5Q@@0
Rh^;0`2=SHd307AdM0@0NWYj0`2EUID309^KV`<0EeMG102>SXh306i^KP<0J6QX101dM7@305UIF@<0
Kfm_101RHV8306YZJP<0S8b<0`2:RXX407=cL`<0Q8B40`22PX8408>3P`<0Ng]k0`1hN7P408F5Q@H0
Ph>3101jNWX308>3P`l0b>3H0`1iNGT408Z:RP<0Q8B40`23Ph<407inOP<0P8200`1jNWX407IfMP<0
Ti>C0`1eMGD307emO@@0MWIf0`1hN7P308:2PP@0N7Qh0`21PH4308j>SP@0QHF50`23Ph<307]kN`<0
P820101nOWh307QhN0<0NWYj1020P80308Z:RP<0P820101mOGd308:2PP<0PH611025QHD308J6QP@0
b>3H0`2<S8`408j>SP<0Ph>30`21PH440820P0<0Ti>C0`22PX8308J6QP@0RXZ:0`1fMWH306IVIP@0
P8200`1oOgl308Z:RP@0LG5a0`1iNGT307=cL`@0Kfm_1P1kNg/308Z:RP@0PH610`1eMGD309>CT`@0
PX:20`24Q8@307IfMP@0IVIV0`1`L70707alO0<0Q8B45038h=P001<0b>3H0`1kNg/408R8R0<0SXj>
0`24Q8@408>3P`<0OWin0`27QhL407EeM@<0N7Qh0`2GUiL306IVIP@0RHV90`37alL308B4Q0@0LW9b
0`23Ph<307]kN`@0QHF50`22PX8307inOP@0O7al0`2<S8`307alO0<0Q8B4101mOGd307alO0<0Ph>3
1021PH4:07moO`<0OWin1038h=P308F5Q@@0OGem0`28R8P308F5Q@@0Rh^;0`2=SHd307AdM0@0NWYj
0`2EUID309^KV`<0EeMG102>SXh306i^KP<0J6QX101dM7@305UIF@<0Kfm_101RHV8306YZJP<0S8b<
0`2:RXX407=cL`<0Q8B40`22PX8408>3P`<0Ng]k0`1hN7P408F5Q@H0Ph>3101jNWX308>3P`l0b>3H
0`1iNGT408Z:RP<0Q8B40`23Ph<407inOP<0P8200`1jNWX407IfMP<0Ti>C0`1eMGD307emO@@0MWIf
0`1hN7P308:2PP@0N7Qh0`21PH4308j>SP@0QHF50`23Ph<307]kN`<0P820101nOWh307QhN0<0NWYj
1020P80308Z:RP<0P820101mOGd308:2PP<0PH611025QHD308J6QP@0b>3H0`2<S8`408j>SP<0Ph>3
0`21PH440820P0<0Ti>C0`22PX8308J6QP@0RXZ:0`1fMWH306IVIP@0P8200`1oOgl308Z:RP@0LG5a
0`1iNGT307=cL`@0Kfm_1P1kNg/308Z:RP@0PH610`1eMGD309>CT`@0PX:20`24Q8@307IfMP@0IVIV
0`1`L70707alO0<0Q8B45038h=P001<0b>3H0`1kNg/408R8R0<0SXj>0`24Q8@408>3P`<0OWin0`27
QhL407EeM@<0N7Qh0`2GUiL306IVIP@0RHV90`37alL308B4Q0@0LW9b0`23Ph<307]kN`@0QHF50`22
PX8307inOP@0O7al0`2<S8`307alO0<0Q8B4101mOGd307alO0<0Ph>31021PH4:07moO`<0OWin1038
h=P308F5Q@@0OGem0`28R8P308F5Q@@0Rh^;0`2=SHd307AdM0@0NWYj0`2EUID309^KV`<0EeMG102>
SXh306i^KP<0J6QX101dM7@305UIF@<0Kfm_101RHV8306YZJP<0S8b<0`2:RXX407=cL`<0Q8B40`22
PX8408>3P`<0Ng]k0`1hN7P408F5Q@H0Ph>3101jNWX308>3P`l0b>3H0`1iNGT408Z:RP<0Q8B40`23
Ph<407inOP<0P8200`1jNWX407IfMP<0Ti>C0`1eMGD307emO@@0MWIf0`1hN7P308:2PP@0N7Qh0`21
PH4308j>SP@0QHF50`23Ph<307]kN`<0P820101nOWh307QhN0<0NWYj1020P80308Z:RP<0P820101m
OGd308:2PP<0PH611025QHD308J6QP@0b>3H0`2<S8`408j>SP<0Ph>30`21PH440820P0<0Ti>C0`22
PX8308J6QP@0RXZ:0`1fMWH306IVIP@0P8200`1oOgl308Z:RP@0LG5a0`1iNGT307=cL`@0Kfm_1P1k
Ng/308Z:RP@0PH610`1eMGD309>CT`@0PX:20`24Q8@307IfMP@0IVIV0`1`L70707alO0<0Q8B45038
h=P001<0b>3H0`1iNGT409>CT`<0QHF50`1gMgL406e]K@<0M7Ad0`1kNg/407inOP<0RHV90`1cLg<3
06m_K`@0V9RH0`2YZJT30820P0@0Ph>30`1gMgL308J6QP@0PX:20`24Q8@30820P0@0PX:20`2?Shl3
07emO@<0Ogmo101fMWH30820P0<0PH61101nOWh308F5Q@<0OWin101jNWX307UiN@@0b>3H0`1jNWX4
08N7Q`<0OGem0`1hN7P408B4Q0<0PH610`1cLg<408>3P`<0LW9b0`2:RXX307emO@@0WinO0`2GUiL3
096AT@@0Ng]k0`1WIfL305UIF@@0OGem0`1VIVH306i^KP<0PH61101oOgl309JFUP<0NWYj1`1oOgl3
07alO0@0RXZ:0`2EUID308>3P`@0PX:20`24Q8@?0<SPf0<0NWYj102:RXX307alO0<0Q8B41021PH43
07emO@<0QXJ61022PX8307EeM@<0MWIf0`20P80407QhN0<0PX:20`20P80408F5Q@<0N7Qh0`1jNWX4
07emO@<0NGUi0`20P80308:2PP@0Ph>30`1nOWh708:2PPH0Ogmo1022PX8307]kN`<0NWYj101lO7`3
0861P@@0b>3H0`1fMWH409bLW0<0Ti>C0`25QHD408R8R0<0MgMg0`1oOgl306m_K`@0J6QX0`1cLg<3
08>3P`@0UiNG0`2:RXX308b<S0@0QHF50`1lO7`308f=S@@0Jf][0`1XJ6P309JFUP<0Ng]k101`L703
07=cL`<0QHF5102?Shl307moO`<0PH61101kNg/308V9R@<0QXJ6101hN7P308Z:RQ@0b>3H000C0<SP
f0<0NGUi102CTi<308F5Q@<0MgMg101]KFd307AdM0<0Ng]k101nOWh308V9R@<0Lg=c0`1_Kfl409RH
V0<0ZJVY0`20P80408>3P`<0MgMg0`26QXH408:2PP<0Q8B40`20P80408:2PP<0Shn?0`1mOGd307mo
O`@0MWIf0`20P8030861P@@0OWin0`25QHD307inOP@0NWYj0`1iNGT40<SPf0<0NWYj1027QhL307em
O@<0N7Qh1024Q8@30861P@<0Lg=c1023Ph<3079bLP<0RXZ:0`1mOGd409nOW`<0UiNG0`2ATI4407]k
N`<0IfMW0`1IFET407emO@<0IVIV0`1^KVh30861P@@0Ogmo0`2FUYH307YjNPL0Ogmo0`1lO7`408Z:
RP<0UIFE0`23Ph<408:2PP<0Q8B43`38h=P307YjNP@0RXZ:0`1lO7`308B4Q0@0PH610`1mOGd308J6
QP@0PX:20`1eMGD307IfMP<0P820101hN7P308:2PP<0P8201025QHD307QhN0<0NWYj101mOGd307Ui
N@<0P8200`22PX8408>3P`<0OWin1`22PX8607moO`@0PX:20`1kNg/307YjNP@0O7al0`21PH440<SP
f0<0MWIf102LW9`309>CT`<0QHF51028R8P307MgM`<0Ogmo0`1_Kfl406QXJ0<0Lg=c0`23Ph<409NG
U`<0RXZ:0`2<S8`408F5Q@<0O7al0`2=SHd406][J`<0J6QX0`2FUYH307]kN`@0L71`0`1cLg<308F5
Q@@0Shn?0`1oOgl30861P@@0Ng]k0`29RHT308J6QP@0N7Qh0`2:RXXD0<SPf0004`38h=P307UiN@@0
Ti>C0`25QHD307MgM`@0KFe]0`1dM7@307]kN`@0OWin0`29RHT307=cL`<0Kfm_102HV9P30:VYZ@<0
P8201023Ph<307MgM`<0QXJ61022PX8308B4Q0<0P8201022PX8308n?S`<0OGem0`1oOgl407IfMP<0
P8200`21PH4407inOP<0QHF50`1nOWh407YjNP<0NGUi1038h=P307YjNP@0QhN70`1mOGd307QhN0@0
Q8B40`21PH4307=cL`@0Ph>30`1bLW8308Z:RP<0OGem102OWil309NGU`<0TI6A101kNg/306MWI`<0
FEUI101mOGd306IVIP<0KVi^0`21PH4407moO`<0UYJF0`1jNWX707moO`<0O7al102:RXX309FEU@<0
Ph>31022PX8308B4Q0l0b>3H0`1jNWX408Z:RP<0O7al0`24Q8@40861P@<0OGem0`26QXH408:2PP<0
MGEe0`1fMWH30820P0@0N7Qh0`22PX830820P0@0QHF50`1hN7P307YjNP@0OGem0`1iNGT30820P0<0
PX:21023Ph<307inOPL0PX:21P1oOgl408:2PP<0Ng]k0`1jNWX407alO0<0PH611038h=P307IfMP@0
W9bL0`2CTi<308F5Q@@0R8R80`1gMgL307moO`<0Kfm_101XJ6P307=cL`<0Ph>3102GUiL308Z:RP<0
S8b<1025QHD307alO0<0SHf=101[Jf/306QXJ0<0UYJF0`1kNg/4071`L0<0Lg=c0`25QHD408n?S`<0
Ogmo0`21PH4407]kN`<0RHV90`26QXH407QhN0<0RXZ:5038h=P001<0b>3H0`1iNGT409>CT`<0QHF5
0`1gMgL406e]K@<0M7Ad0`1kNg/407inOP<0RHV90`1cLg<306m_K`@0V9RH0`2YZJT30820P0@0Ph>3
0`1gMgL308J6QP@0PX:20`24Q8@30820P0@0PX:20`2?Shl307emO@<0Ogmo101fMWH30820P0<0PH61
101nOWh308F5Q@<0OWin101jNWX307UiN@@0b>3H0`1aLG4406EUI@<0RXZ:0`1eMGD40861P@<0Ph>3
0`1]KFd408V9R@<0L71`0`29RHT308n?S`@0Kfm_0`1aLG4307=cL`@0Q8B40`2>SXh308Z:RP@0Kfm_
0`1oOgl306UYJ@<0L71`102?Shl307AdM0<0Ng]k1025QHD307YjNP<0QhN71021PH4307MgM`<0Q8B4
101lO7`307emO@l0b>3H0`25QHD407inOP<0RHV90`27QhL407YjNP<0PH610`1oOgl408J6QP<0P820
0`28R8P307]kN`@0QXJ60`1kNg/307moO`@0RHV90`1lO7`308>3P`@0MgMg0`1cLg<308N7Q`<0O7al
101kNg/307YjNP<0Q8B4101nOWh30861P@L0PX:20`24Q8@308J6QP@0Ogmo0`1lO7`40<SPf0<0MWIf
102LW9`309>CT`<0QHF51028R8P307MgM`<0Ogmo0`1_Kfl406QXJ0<0Lg=c0`23Ph<409NGU`<0RXZ:
0`2<S8`408F5Q@<0O7al0`2=SHd406][J`<0J6QX0`2FUYH307]kN`@0L71`0`1cLg<308F5Q@@0Shn?
0`1oOgl30861P@@0Ng]k0`29RHT308J6QP@0N7Qh0`2:RXXD0<SPf0004`38h=P307=cL`@0Ogmo0`1V
IVH307inOP@0Q8B40`20P80307YjNP@0MgMg0`27QhL3061PH0<0K6a/101LG5`306EUI@<0PX:2101h
N7P308F5Q@<0Q8B41021PH4307QhN0<0Lg=c101gMgL3092@T0<0M7Ad0`1jNWX40861P@<0NWYj1`22
PX8307QhN0<0OGem101lO7`308^;R`@0b>3H0`1aLG4406EUI@<0RXZ:0`1eMGD40861P@<0Ph>30`1]
KFd408V9R@<0L71`0`29RHT308n?S`@0Kfm_0`1aLG4307=cL`@0Q8B40`2>SXh308Z:RP@0Kfm_0`1o
Ogl306UYJ@<0L71`102?Shl307AdM0<0Ng]k1025QHD307YjNP<0QhN71021PH4307MgM`<0Q8B4101l
O7`307emO@l0b>3H0`25QHD407inOP<0RHV90`27QhL407YjNP<0PH610`1oOgl408J6QP<0P8200`28
R8P307]kN`@0QXJ60`1kNg/307moO`@0RHV90`1lO7`308>3P`@0MgMg0`1cLg<308N7Q`<0O7al101k
Ng/307YjNP<0Q8B4101nOWh30861P@L0PX:20`24Q8@308J6QP@0Ogmo0`1lO7`40<SPf0<0SXj>1026
QXH307MgM`<0PH611026QXH307UiN@<0Ogmo0`1hN7P4096AT@<0Q8B40`1nOWh409JFUP<0O7al0`1c
Lg<409BDU0<0P8200`2UYJD408j>SP<0SHf=0`1aLG4307]kN`@0Lg=c0`1jNWX307UiN@@0Rh^;0`1n
OWh307QhN0@0P8200`27QhL30820P0@0MGEe0`1cLg<D0<SPf0004`38h=P307=cL`@0Ogmo0`1VIVH3
07inOP@0Q8B40`20P80307YjNP@0MgMg0`27QhL3061PH0<0K6a/101LG5`306EUI@<0PX:2101hN7P3
08F5Q@<0Q8B41021PH4307QhN0<0Lg=c101gMgL3092@T0<0M7Ad0`1jNWX40861P@<0NWYj1`22PX83
07QhN0<0OGem101lO7`308^;R`@0b>3H0`1aLG4406EUI@<0RXZ:0`1eMGD40861P@<0Ph>30`1]KFd4
08V9R@<0L71`0`29RHT308n?S`@0Kfm_0`1aLG4307=cL`@0Q8B40`2>SXh308Z:RP@0Kfm_0`1oOgl3
06UYJ@<0L71`102?Shl307AdM0<0Ng]k1025QHD307YjNP<0QhN71021PH4307MgM`<0Q8B4101lO7`3
07emO@l0b>3H0`25QHD407inOP<0RHV90`27QhL407YjNP<0PH610`1oOgl408J6QP<0P8200`28R8P3
07]kN`@0QXJ60`1kNg/307moO`@0RHV90`1lO7`308>3P`@0MgMg0`1cLg<308N7Q`<0O7al101kNg/3
07YjNP<0Q8B4101nOWh30861P@L0PX:20`24Q8@308J6QP@0Ogmo0`1lO7`40<SPf0<0SXj>1026QXH3
07MgM`<0PH611026QXH307UiN@<0Ogmo0`1hN7P4096AT@<0Q8B40`1nOWh409JFUP<0O7al0`1cLg<4
09BDU0<0P8200`2UYJD408j>SP<0SHf=0`1aLG4307]kN`@0Lg=c0`1jNWX307UiN@@0Rh^;0`1nOWh3
07QhN0@0P8200`27QhL30820P0@0MGEe0`1cLg<D0<SPf0004`38h=P307=cL`@0Ogmo0`1VIVH307in
OP@0Q8B40`20P80307YjNP@0MgMg0`27QhL3061PH0<0K6a/101LG5`306EUI@<0PX:2101hN7P308F5
Q@<0Q8B41021PH4307QhN0<0Lg=c101gMgL3092@T0<0M7Ad0`1jNWX40861P@<0NWYj1`22PX8307Qh
N0<0OGem101lO7`308^;R`@0b>3H0`1aLG4406EUI@<0RXZ:0`1eMGD40861P@<0Ph>30`1]KFd408V9
R@<0L71`0`29RHT308n?S`@0Kfm_0`1aLG4307=cL`@0Q8B40`2>SXh308Z:RP@0Kfm_0`1oOgl306UY
J@<0L71`102?Shl307AdM0<0Ng]k1025QHD307YjNP<0QhN71021PH4307MgM`<0Q8B4101lO7`307em
O@l0b>3H0`25QHD407inOP<0RHV90`27QhL407YjNP<0PH610`1oOgl408J6QP<0P8200`28R8P307]k
N`@0QXJ60`1kNg/307moO`@0RHV90`1lO7`308>3P`@0MgMg0`1cLg<308N7Q`<0O7al101kNg/307Yj
NP<0Q8B4101nOWh30861P@L0PX:20`24Q8@308J6QP@0Ogmo0`1lO7`40<SPf0<0SXj>1026QXH307Mg
M`<0PH611026QXH307UiN@<0Ogmo0`1hN7P4096AT@<0Q8B40`1nOWh409JFUP<0O7al0`1cLg<409BD
U0<0P8200`2UYJD408j>SP<0SHf=0`1aLG4307]kN`@0Lg=c0`1jNWX307UiN@@0Rh^;0`1nOWh307Qh
N0@0P8200`27QhL30820P0@0MGEe0`1cLg<D0<SPf0004`38h=P307IfMP@0P8200`2BTY8307UiN@@0
NWYj0`25QHD308B4Q0@0OWin0`23Ph<307YjNP<0PX:2101nOWh306YZJP<0PH61101nOWh60820P0@0
Ph>30`2EUID307emO@@0E5AD0`2NWYh307moO`<0PX:21021PH4307inOP<0O7al1020P8030861P@<0
Ogmo1023Ph<308:2PP@0b>3H0`2CTi<407emO@<0V9RH0`24Q8@406i^KP<0QHF50`2>SXh40:2PX0<0
O7al0`1YJFT309VIV@@0IFEU0`1iNGT307emO@@0Q8B40`20P80309:BTP@0Ph>30`2=SHd307alO0<0
IFEU102LW9`608N7Q`@0PH610`1iNGT30861P@@0P8200`1mOGd308f=S@@0VYZJ0`28R8P?0<SPf0<0
Ogmo1028R8P307moO`<0R8R8101nOWh307alO0<0P820101_Kfl3079bLP<0PH610`1fMWH407emO@<0
PX:20`20P80408J6QP<0QhN70`1cLg<408Z:RP<0S8b<0`23Ph<308F5Q@@0P8200`1oOgl307emO@@0
PH611P20P80407UiN@<0Ng]k0`1mOGd408F5Q@<0PX:21038h=P308R8R0@0NWYj0`1DE5@308^;R`@0
PX:20`1NGUh30:RXZ0<0PH61101fMWH308>3P`<0QXJ6101mOGd307moO`<0[:b/102:RXX306UYJ@<0
T92@102RXZ8305EEE@<0JFUY0`26QXH406ATI0<0O7al0`1^KVh407moO`<0MgMg1`21PH4308:2PP<0
VIVI1`26QXHD0<SPf0004`38h=P307IfMP@0P8200`2BTY8307UiN@@0NWYj0`25QHD308B4Q0@0OWin
0`23Ph<307YjNP<0PX:2101nOWh306YZJP<0PH61101nOWh60820P0@0Ph>30`2EUID307emO@@0E5AD
0`2NWYh307moO`<0PX:21021PH4307inOP<0O7al1020P8030861P@<0Ogmo1023Ph<308:2PP@0b>3H
0`2CTi<407emO@<0V9RH0`24Q8@406i^KP<0QHF50`2>SXh40:2PX0<0O7al0`1YJFT309VIV@@0IFEU
0`1iNGT307emO@@0Q8B40`20P80309:BTP@0Ph>30`2=SHd307alO0<0IFEU102LW9`608N7Q`@0PH61
0`1iNGT30861P@@0P8200`1mOGd308f=S@@0VYZJ0`28R8P?0<SPf0<0Ogmo1028R8P307moO`<0R8R8
101nOWh307alO0<0P820101_Kfl3079bLP<0PH610`1fMWH407emO@<0PX:20`20P80408J6QP<0QhN7
0`1cLg<408Z:RP<0S8b<0`23Ph<308F5Q@@0P8200`1oOgl307emO@@0PH611P20P80407UiN@<0Ng]k
0`1mOGd408F5Q@<0PX:21038h=P308R8R0@0NWYj0`1DE5@308^;R`@0PX:20`1NGUh30:RXZ0<0PH61
101fMWH308>3P`<0QXJ6101mOGd307moO`<0[:b/102:RXX306UYJ@<0T92@102RXZ8305EEE@<0JFUY
0`26QXH406ATI0<0O7al0`1^KVh407moO`<0MgMg1`21PH4308:2PP<0VIVI1`26QXHD0<SPf0004`38
h=P307IfMP@0P8200`2BTY8307UiN@@0NWYj0`25QHD308B4Q0@0OWin0`23Ph<307YjNP<0PX:2101n
OWh306YZJP<0PH61101nOWh60820P0@0Ph>30`2EUID307emO@@0E5AD0`2NWYh307moO`<0PX:21021
PH4307inOP<0O7al1020P8030861P@<0Ogmo1023Ph<308:2PP@0b>3H0`2CTi<407emO@<0V9RH0`24
Q8@406i^KP<0QHF50`2>SXh40:2PX0<0O7al0`1YJFT309VIV@@0IFEU0`1iNGT307emO@@0Q8B40`20
P80309:BTP@0Ph>30`2=SHd307alO0<0IFEU102LW9`608N7Q`@0PH610`1iNGT30861P@@0P8200`1m
OGd308f=S@@0VYZJ0`28R8P?0<SPf0<0Ogmo1028R8P307moO`<0R8R8101nOWh307alO0<0P820101_
Kfl3079bLP<0PH610`1fMWH407emO@<0PX:20`20P80408J6QP<0QhN70`1cLg<408Z:RP<0S8b<0`23
Ph<308F5Q@@0P8200`1oOgl307emO@@0PH611P20P80407UiN@<0Ng]k0`1mOGd408F5Q@<0PX:21038
h=P308R8R0@0NWYj0`1DE5@308^;R`@0PX:20`1NGUh30:RXZ0<0PH61101fMWH308>3P`<0QXJ6101m
OGd307moO`<0[:b/102:RXX306UYJ@<0T92@102RXZ8305EEE@<0JFUY0`26QXH406ATI0<0O7al0`1^
KVh407moO`<0MgMg1`21PH4308:2PP<0VIVI1`26QXHD0<SPf000o`38h=SW0<SPf000o`38h=SW0<SP
f000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf0004`38h=P308B4
Q0L0PH610`1lO7`408J6QP<0O7al0`1gMgL407moO`<0P8200`22PX83071`L0@0Q8B40`21PH4707in
OP<0P8200`1oOgl40820P0<0PH610`23Ph<30861P@@0P8200`1oOgl70820P0<0PX:20`20P80408:2
PP<0P8200`1oOgl408>3P`<0PH611038h=P3075aL@@0TI6A0`1fMWH307alO0@0Ogmo0`1kNg/30861
P@@0NGUi0`23Ph<307emO@<0OWin1021PH430820P0<0OWin101mOGd30820P0<0PH61101oOgl307em
O@<0P8200`1nOWh40820P0<0Q8B40`1nOWh40861P@<0OGem0`1oOgl407alO0<0Q8B40`1lO7`40861
P@<0Ogmo3`38h=P307MgM`@0QHF50`2;Rh/70820P0<0PX:20`26QXH40861P@<0P8200`1oOgl30861
P@@0O7al0`20P80307moO`@0P8200`1jNWX30861P@@0Ogmo0`21PH4307inOP<0Ogmo1`21PH4707mo
O`<0O7al0`1nOWh40820P0<0OWin1`21PH4307moO`@0b>3H0`1WIfL409fMW@<0HF5Q0`1kNg/408B4
Q0<0OWin0`1jNWX307]kN`@0OWin0`23Ph<307moO`@0O7al0`21PH4308:2PP@0P8200`23Ph<307em
O@@0P8200`23Ph<307inOP<0O7al101kNg/60861P@@0OGem0`23Ph<307emO@@0Ph>30`1oOgl308N7
Q`<0NWYj101nOWhD0<SPf0004`38h=P308B4Q0L0PH610`1lO7`408J6QP<0O7al0`1gMgL407moO`<0
P8200`22PX83071`L0@0Q8B40`21PH4707inOP<0P8200`1oOgl40820P0<0PH610`23Ph<30861P@@0
P8200`1oOgl70820P0<0PX:20`20P80408:2PP<0P8200`1oOgl408>3P`<0PH611038h=P3075aL@@0
TI6A0`1fMWH307alO0@0Ogmo0`1kNg/30861P@@0NGUi0`23Ph<307emO@<0OWin1021PH430820P0<0
OWin101mOGd30820P0<0PH61101oOgl307emO@<0P8200`1nOWh40820P0<0Q8B40`1nOWh40861P@<0
OGem0`1oOgl407alO0<0Q8B40`1lO7`40861P@<0Ogmo3`38h=P307MgM`@0QHF50`2;Rh/70820P0<0
PX:20`26QXH40861P@<0P8200`1oOgl30861P@@0O7al0`20P80307moO`@0P8200`1jNWX30861P@@0
Ogmo0`21PH4307inOP<0Ogmo1`21PH4707moO`<0O7al0`1nOWh40820P0<0OWin1`21PH4307moO`@0
b>3H0`1WIfL409fMW@<0HF5Q0`1kNg/408B4Q0<0OWin0`1jNWX307]kN`@0OWin0`23Ph<307moO`@0
O7al0`21PH4308:2PP@0P8200`23Ph<307emO@@0P8200`23Ph<307inOP<0O7al101kNg/60861P@@0
OGem0`23Ph<307emO@@0Ph>30`1oOgl308N7Q`<0NWYj101nOWhD0<SPf0004`38h=P308B4Q0L0PH61
0`1lO7`408J6QP<0O7al0`1gMgL407moO`<0P8200`22PX83071`L0@0Q8B40`21PH4707inOP<0P820
0`1oOgl40820P0<0PH610`23Ph<30861P@@0P8200`1oOgl70820P0<0PX:20`20P80408:2PP<0P820
0`1oOgl408>3P`<0PH611038h=P3075aL@@0TI6A0`1fMWH307alO0@0Ogmo0`1kNg/30861P@@0NGUi
0`23Ph<307emO@<0OWin1021PH430820P0<0OWin101mOGd30820P0<0PH61101oOgl307emO@<0P820
0`1nOWh40820P0<0Q8B40`1nOWh40861P@<0OGem0`1oOgl407alO0<0Q8B40`1lO7`40861P@<0Ogmo
3`38h=P307MgM`@0QHF50`2;Rh/70820P0<0PX:20`26QXH40861P@<0P8200`1oOgl30861P@@0O7al
0`20P80307moO`@0P8200`1jNWX30861P@@0Ogmo0`21PH4307inOP<0Ogmo1`21PH4707moO`<0O7al
0`1nOWh40820P0<0OWin1`21PH4307moO`@0b>3H0`1WIfL409fMW@<0HF5Q0`1kNg/408B4Q0<0OWin
0`1jNWX307]kN`@0OWin0`23Ph<307moO`@0O7al0`21PH4308:2PP@0P8200`23Ph<307emO@@0P820
0`23Ph<307inOP<0O7al101kNg/60861P@@0OGem0`23Ph<307emO@@0Ph>30`1oOgl308N7Q`<0NWYj
101nOWhD0<SPf0004`38h=P30861P@@0Ogmo0`23Ph<30820P0@0Ogmo0`20P80307QhN0@0PH610`1l
O7`308:2PP<0Kfm_101kNg/30861P@<0P820101mOGd30861P@<0OGem101nOWh307moO`<0P8200`21
PH4407alO0<0OWin0`20P80407emO@<0Ogmo2P21PH4307emO@@0P8200`21PH440<SPf0<0Shn?101m
OGd308f=S@<0NGUi1023Ph<307alO0<0Q8B4101oOgl607emO@<0QXJ6101lO7`607moO`@0P8200`1l
O7`30820P0@0OWin0`22PX830820P0<0PH61101mOGd307alO0<0Ogmo1022PX8307moO`<0Ph>31021
PH4308:2PP<0O7al1020P80307moO`l0b>3H0`22PX8408>3P`<0L71`0`21PH4407UiN@<0P8200`21
PH440820P0<0Q8B40`1oOgl70861P@<0OWin0`1mOGd407moO`<0PH610`22PX840861P@<0OWin0`20
P80308>3P`@0PX:21P1nOWh70820P0<0Ogmo101nOWh308B4Q0<0Ng]k1020P80307moO`@0b>3H0`1e
MGD408^;R`<0IVIV0`2NWYh407QhN0<0PX:20`1eMGD307emO@L0OWin0`2:RXX408V9R@<0O7al0`1o
Ogl408F5Q@<0QXJ60`23Ph<408F5Q@<0O7al0`25QHD307]kN`@0OWin0`25QHD307YjNP@0OWin0`20
P80307emO@@0Ogmo0`21PH4307inOP<0QHF51022PX8D0<SPf0004`38h=P30861P@@0Ogmo0`23Ph<3
0820P0@0Ogmo0`20P80307QhN0@0PH610`1lO7`308:2PP<0Kfm_101kNg/30861P@<0P820101mOGd3
0861P@<0OGem101nOWh307moO`<0P8200`21PH4407alO0<0OWin0`20P80407emO@<0Ogmo2P21PH43
07emO@@0P8200`21PH440<SPf0<0Shn?101mOGd308f=S@<0NGUi1023Ph<307alO0<0Q8B4101oOgl6
07emO@<0QXJ6101lO7`607moO`@0P8200`1lO7`30820P0@0OWin0`22PX830820P0<0PH61101mOGd3
07alO0<0Ogmo1022PX8307moO`<0Ph>31021PH4308:2PP<0O7al1020P80307moO`l0b>3H0`22PX84
08>3P`<0L71`0`21PH4407UiN@<0P8200`21PH440820P0<0Q8B40`1oOgl70861P@<0OWin0`1mOGd4
07moO`<0PH610`22PX840861P@<0OWin0`20P80308>3P`@0PX:21P1nOWh70820P0<0Ogmo101nOWh3
08B4Q0<0Ng]k1020P80307moO`@0b>3H0`1eMGD408^;R`<0IVIV0`2NWYh407QhN0<0PX:20`1eMGD3
07emO@L0OWin0`2:RXX408V9R@<0O7al0`1oOgl408F5Q@<0QXJ60`23Ph<408F5Q@<0O7al0`25QHD3
07]kN`@0OWin0`25QHD307YjNP@0OWin0`20P80307emO@@0Ogmo0`21PH4307inOP<0QHF51022PX8D
0<SPf0004`38h=P30861P@@0Ogmo0`23Ph<30820P0@0Ogmo0`20P80307QhN0@0PH610`1lO7`308:2
PP<0Kfm_101kNg/30861P@<0P820101mOGd30861P@<0OGem101nOWh307moO`<0P8200`21PH4407al
O0<0OWin0`20P80407emO@<0Ogmo2P21PH4307emO@@0P8200`21PH440<SPf0<0Shn?101mOGd308f=
S@<0NGUi1023Ph<307alO0<0Q8B4101oOgl607emO@<0QXJ6101lO7`607moO`@0P8200`1lO7`30820
P0@0OWin0`22PX830820P0<0PH61101mOGd307alO0<0Ogmo1022PX8307moO`<0Ph>31021PH4308:2
PP<0O7al1020P80307moO`l0b>3H0`22PX8408>3P`<0L71`0`21PH4407UiN@<0P8200`21PH440820
P0<0Q8B40`1oOgl70861P@<0OWin0`1mOGd407moO`<0PH610`22PX840861P@<0OWin0`20P80308>3
P`@0PX:21P1nOWh70820P0<0Ogmo101nOWh308B4Q0<0Ng]k1020P80307moO`@0b>3H0`1eMGD408^;
R`<0IVIV0`2NWYh407QhN0<0PX:20`1eMGD307emO@L0OWin0`2:RXX408V9R@<0O7al0`1oOgl408F5
Q@<0QXJ60`23Ph<408F5Q@<0O7al0`25QHD307]kN`@0OWin0`25QHD307YjNP@0OWin0`20P80307em
O@@0Ogmo0`21PH4307inOP<0QHF51022PX8D0<SPf0004`38h=P30861P@@0Ogmo0`23Ph<30820P0@0
Ogmo0`20P80307QhN0@0PH610`1lO7`308:2PP<0Kfm_101kNg/30861P@<0P820101mOGd30861P@<0
OGem101nOWh307moO`<0P8200`21PH4407alO0<0OWin0`20P80407emO@<0Ogmo2P21PH4307emO@@0
P8200`21PH440<SPf0<0Shn?101mOGd308f=S@<0NGUi1023Ph<307alO0<0Q8B4101oOgl607emO@<0
QXJ6101lO7`607moO`@0P8200`1lO7`30820P0@0OWin0`22PX830820P0<0PH61101mOGd307alO0<0
Ogmo1022PX8307moO`<0Ph>31021PH4308:2PP<0O7al1020P80307moO`l0b>3H0`22PX8408>3P`<0
L71`0`21PH4407UiN@<0P8200`21PH440820P0<0Q8B40`1oOgl70861P@<0OWin0`1mOGd407moO`<0
PH610`22PX840861P@<0OWin0`20P80308>3P`@0PX:21P1nOWh70820P0<0Ogmo101nOWh308B4Q0<0
Ng]k1020P80307moO`@0b>3H0`1eMGD408^;R`<0IVIV0`2NWYh407QhN0<0PX:20`1eMGD307emO@L0
OWin0`2:RXX408V9R@<0O7al0`1oOgl408F5Q@<0QXJ60`23Ph<408F5Q@<0O7al0`25QHD307]kN`@0
OWin0`25QHD307YjNP@0OWin0`20P80307emO@@0Ogmo0`21PH4307inOP<0QHF51022PX8D0<SPf000
4`38h=P307emO@@0QHF50`1lO7`308B4Q0@0Ng]k0`1nOWh30820P0@0PH610`1kNg/308F5Q@<0R8R8
101mOGd30861P@<0P820101nOWh:07moO`<0OWin1P20P80407alO0H0Ogmo1`20P8030861P@L0P820
0`1oOgl40861P@<0P8201038h=P306m_K`@0SHf=0`24Q8@306EUI@@0RHV90`1iNGT308:2PP@0O7al
0`1nOWh30861P@<0OWin1024Q8@30861P@<0PX:2101mOGd30820P0<0Ogmo1024Q8@307emO@<0Ogmo
0`1nOWh70820P0<0PX:21024Q8@307moO`<0OGem1020P80307alO0<0P820101oOgl30861P@l0b>3H
0`23Ph<407alO0<0R8R80`2:RXX407emO@<0Q8B40`1lO7`40861P@<0Ogmo0`1nOWh30861P@@0Ph>3
0`1mOGd30820P0@0OWin1P1oOgl407inOP<0OGem0`24Q8@307moO`@0OWin0`22PX870820P0<0OWin
0`22PX8407inOP<0Ogmo0`1nOWh70820P0@0b>3H0`1_Kfl408:2PP<0VYZJ0`2=SHd407AdM0<0Ph>3
0`25QHD307emO@@0M7Ad0`25QHD308R8R0@0OWin0`1gMgL708>3P`<0Q8B40`1jNWX408>3P`<0PH61
1P1oOgl407alO0<0PH610`20P80407emO@<0Q8B40`1oOgl408J6QP<0NWYj0`22PX8308>3P`@0PH61
5038h=P001<0b>3H0`1mOGd408F5Q@<0O7al0`24Q8@407]kN`<0OWin0`20P8040861P@<0Ng]k0`25
QHD308R8R0@0OGem0`21PH430820P0@0OWin2P1oOgl307inOPH0P820101lO7`607moO`L0P8200`21
PH470820P0<0Ogmo1021PH430820P0@0b>3H0`1_Kfl408f=S@<0Q8B40`1UIFD408V9R@<0NGUi0`22
PX8407alO0<0OWin0`21PH4307inOP@0Q8B40`21PH4308:2PP@0OGem0`20P80307moO`@0Q8B40`1m
OGd307moO`<0OWin1`20P80308:2PP@0Q8B40`1oOgl307emO@@0P8200`1lO7`30820P0@0Ogmo0`21
PH4?0<SPf0<0Ph>3101lO7`308R8R0<0RXZ:101mOGd308B4Q0<0O7al1021PH4307moO`<0OWin0`21
PH4408>3P`<0OGem0`20P80407inOPH0Ogmo101nOWh307emO@<0Q8B40`1oOgl407inOP<0PX:21`20
P80307inOP<0PX:2101nOWh307moO`<0OWin1`20P8040<SPf0<0Kfm_1022PX8309ZJVP<0SHf=101d
M7@308>3P`<0QHF50`1mOGd407AdM0<0QHF50`28R8P407inOP<0MgMg1`23Ph<308B4Q0<0NWYj1023
Ph<30861P@H0Ogmo101lO7`30861P@<0P820101mOGd308B4Q0<0Ogmo1026QXH307YjNP<0PX:20`23
Ph<40861PA@0b>3H000C0<SPf0<0OGem1025QHD307alO0<0Q8B4101kNg/307inOP<0P8201021PH43
07]kN`<0QHF50`28R8P407emO@<0PH610`20P80407inOPX0Ogmo0`1nOWh60820P0@0O7al1P1oOgl7
0820P0<0PH611`20P80307moO`@0PH610`20P8040<SPf0<0Kfm_102=SHd308B4Q0<0IFEU1029RHT3
07UiN@<0PX:2101lO7`307inOP<0PH610`1nOWh408B4Q0<0PH610`22PX8407emO@<0P8200`1oOgl4
08B4Q0<0OGem0`1oOgl307inOPL0P8200`22PX8408B4Q0<0Ogmo0`1mOGd40820P0<0O7al0`20P804
07moO`<0PH613`38h=P308>3P`@0O7al0`28R8P308Z:RP@0OGem0`24Q8@307alO0@0PH610`1oOgl3
07inOP<0PH611023Ph<307emO@<0P820101nOWh607moO`@0OWin0`1mOGd308B4Q0<0Ogmo101nOWh3
08:2PPL0P8200`1nOWh308:2PP@0OWin0`1oOgl307inOPL0P8201038h=P306m_K`@0PX:20`2JVYX3
08f=S@@0M7Ad0`23Ph<308F5Q@<0OGem101dM7@308F5Q@<0R8R8101nOWh307MgM`L0Ph>30`24Q8@3
07YjNP@0Ph>30`21PH4607moO`@0O7al0`21PH430820P0@0OGem0`24Q8@307moO`@0QXJ60`1jNWX3
08:2PP<0Ph>31021PH4D0<SPf0004`38h=P308B4Q0@0OWin0`22PX8307alO0@0QXJ60`21PH4308F5
Q@@0PX:20`20P80308R8R0<0RXZ:1021PH4307inOP<0PH611020P80307moO`<0P820101nOWh308:2
PP<0OGem1`1oOgl30820P0<0Ogmo101nOWh30861P@L0Ogmo0`21PH4307alO0@0Ph>30`1nOWh40<SP
f0<0LG5a102;Rh/307YjNP<0KVi^101fMWH30861P@<0OWin101iNGT30820P0H0Q8B41022PX830820
P0<0PH61101oOgl308F5Q@<0PH611023Ph<308F5Q@<0PH610`23Ph<407inOP<0OGem0`1nOWh408:2
PP<0PH610`1mOGd408>3P`<0PX:20`20P80407inOP<0P8203`38h=P307MgM`@0PX:20`1mOGd307]k
N`@0MWIf0`1nOWh307emO@@0PH610`1kNg/308>3P`<0PH61101nOWh308>3P`<0PH61101oOgl307Ui
N@<0P820101nOWh308B4Q0<0OWin0`20P80707moO`<0PH61101lO7`30820P0<0PX:21021PH4308B4
Q0<0OGem1020P80307moO`@0b>3H0`1]KFd407emO@<0Ph>30`1ZJVX408:2PP<0O7al0`1cLg<307al
O0@0P8201P1mOGd40861P@<0M7Ad0`22PX8408N7Q`<0P8200`21PH4408:2PP<0N7Qh0`27QhL307al
O0@0Ogmo0`1nOWh30820P0@0OGem0`28R8P30861P@@0OGem0`25QHD307YjNP<0OWin1023Ph<D0<SP
f0004`38h=P308B4Q0@0OWin0`22PX8307alO0@0QXJ60`21PH4308F5Q@@0PX:20`20P80308R8R0<0
RXZ:1021PH4307inOP<0PH611020P80307moO`<0P820101nOWh308:2PP<0OGem1`1oOgl30820P0<0
Ogmo101nOWh30861P@L0Ogmo0`21PH4307alO0@0Ph>30`1nOWh40<SPf0<0LG5a102;Rh/307YjNP<0
KVi^101fMWH30861P@<0OWin101iNGT30820P0H0Q8B41022PX830820P0<0PH61101oOgl308F5Q@<0
PH611023Ph<308F5Q@<0PH610`23Ph<407inOP<0OGem0`1nOWh408:2PP<0PH610`1mOGd408>3P`<0
PX:20`20P80407inOP<0P8203`38h=P307MgM`@0PX:20`1mOGd307]kN`@0MWIf0`1nOWh307emO@@0
PH610`1kNg/308>3P`<0PH61101nOWh308>3P`<0PH61101oOgl307UiN@<0P820101nOWh308B4Q0<0
OWin0`20P80707moO`<0PH61101lO7`30820P0<0PX:21021PH4308B4Q0<0OGem1020P80307moO`@0
b>3H0`1]KFd407emO@<0Ph>30`1ZJVX408:2PP<0O7al0`1cLg<307alO0@0P8201P1mOGd40861P@<0
M7Ad0`22PX8408N7Q`<0P8200`21PH4408:2PP<0N7Qh0`27QhL307alO0@0Ogmo0`1nOWh30820P0@0
OGem0`28R8P30861P@@0OGem0`25QHD307YjNP<0OWin1023Ph<D0<SPf0004`38h=P308B4Q0@0OWin
0`22PX8307alO0@0QXJ60`21PH4308F5Q@@0PX:20`20P80308R8R0<0RXZ:1021PH4307inOP<0PH61
1020P80307moO`<0P820101nOWh308:2PP<0OGem1`1oOgl30820P0<0Ogmo101nOWh30861P@L0Ogmo
0`21PH4307alO0@0Ph>30`1nOWh40<SPf0<0LG5a102;Rh/307YjNP<0KVi^101fMWH30861P@<0OWin
101iNGT30820P0H0Q8B41022PX830820P0<0PH61101oOgl308F5Q@<0PH611023Ph<308F5Q@<0PH61
0`23Ph<407inOP<0OGem0`1nOWh408:2PP<0PH610`1mOGd408>3P`<0PX:20`20P80407inOP<0P820
3`38h=P307MgM`@0PX:20`1mOGd307]kN`@0MWIf0`1nOWh307emO@@0PH610`1kNg/308>3P`<0PH61
101nOWh308>3P`<0PH61101oOgl307UiN@<0P820101nOWh308B4Q0<0OWin0`20P80707moO`<0PH61
101lO7`30820P0<0PX:21021PH4308B4Q0<0OGem1020P80307moO`@0b>3H0`1]KFd407emO@<0Ph>3
0`1ZJVX408:2PP<0O7al0`1cLg<307alO0@0P8201P1mOGd40861P@<0M7Ad0`22PX8408N7Q`<0P820
0`21PH4408:2PP<0N7Qh0`27QhL307alO0@0Ogmo0`1nOWh30820P0@0OGem0`28R8P30861P@@0OGem
0`25QHD307YjNP<0OWin1023Ph<D0<SPf0004`38h=P30820P0@0QHF50`1oOgl308N7Q`@0M7Ad0`21
PH4307moO`L0PH610`2<S8`307UiN@@0OWin0`1oOgl308:2PP@0Ogmo0`20P80307emO@@0OWin0`20
P80607inOP@0Ogmo0`21PH430820P0@0OWin0`20P80307moO`@0PX:20`20P8030861P@@0P8200`1n
OWh40<SPf0<0L71`101dM7@307inOP<0O7al1022PX8307QhN0<0OWin101lO7`308B4Q0<0Ogmo0`1n
OWh407alO0<0PH610`23Ph<407emO@<0P8200`1oOgl708>3P`<0Q8B40`1lO7`407emO@<0OWin0`1k
Ng/407inOP<0OGem0`22PX840820P0<0OGem0`22PX8407QhN0<0Ogmo3`38h=P308N7Q`L0P8200`22
PX8408>3P`<0OWin0`23Ph<40861P@<0Ph>30`1oOgl307alO0@0OWin0`20P80307moO`@0P8200`1o
Ogl708:2PP<0Ogmo0`20P8030861P@L0OWin1`20P8030861P@<0O7al101oOgl307inOPX0P8201038
h=P70861P@<0Ng]k0`1hN7P408j>SP<0NWYj0`1nOWh307MgM`@0Ph>30`1nOWh308>3P`@0NWYj0`1k
Ng/307QhN0@0PH610`20P80307emO@@0Ogmo0`1nOWh307YjNP<0QHF5101nOWh308J6QP<0OWin1024
Q8@307emO@<0OWin1025QHD307inOP<0QXJ60`1fMWH408F5QA@0b>3H000C0<SPf0<0P8201025QHD3
07moO`<0QhN7101dM7@30861P@<0Ogmo1`21PH4308b<S0<0NGUi101nOWh307moO`<0PX:2101oOgl3
0820P0<0OGem101nOWh30820P0H0OWin101oOgl30861P@<0P820101nOWh30820P0<0Ogmo1022PX83
0820P0<0PH611020P80307inOP@0b>3H0`1`L70407AdM0<0OWin0`1lO7`408:2PP<0N7Qh0`1nOWh4
07alO0<0Q8B40`1oOgl307inOP@0O7al0`21PH4308>3P`@0OGem0`20P80307moO`L0Ph>30`24Q8@3
07alO0@0OGem0`1nOWh307]kN`@0OWin0`1mOGd308:2PP@0P8200`1mOGd308:2PP@0N7Qh0`1oOgl?
0<SPf0<0QhN71`20P80308:2PP@0Ph>30`1nOWh308>3P`@0PH610`23Ph<307moO`<0O7al101nOWh3
0820P0<0Ogmo1020P80307moO`L0PX:20`1oOgl30820P0<0PH611`1nOWh70820P0<0PH610`1lO7`4
07moO`<0OWin2P20P8040<SPf0L0PH610`1kNg/307QhN0@0SXj>0`1jNWX307inOP<0MgMg1023Ph<3
07inOP<0Ph>3101jNWX307]kN`<0N7Qh1021PH430820P0<0OGem101oOgl307inOP<0NWYj0`25QHD4
07inOP<0QXJ60`1nOWh408B4Q0<0OGem0`1nOWh408F5Q@<0OWin0`26QXH307IfMP@0QHF55038h=P0
01<0b>3H0`20P80408F5Q@<0Ogmo0`27QhL407AdM0<0PH610`1oOgl70861P@<0S8b<0`1iNGT407in
OP<0Ogmo0`22PX8407moO`<0P8200`1mOGd407inOP<0P8201P1nOWh407moO`<0PH610`20P80407in
OP<0P8200`1oOgl408:2PP<0P8200`21PH440820P0<0OWin1038h=P3071`L0@0M7Ad0`1nOWh307al
O0@0PX:20`1hN7P307inOP@0O7al0`24Q8@307moO`<0OWin101lO7`30861P@<0Ph>3101mOGd30820
P0<0Ogmo1`23Ph<308B4Q0<0O7al101mOGd307inOP<0Ng]k101nOWh307emO@<0PX:21020P80307em
O@<0PX:2101hN7P307moO`l0b>3H0`27QhL70820P0<0PX:21023Ph<307inOP<0Ph>31021PH4308>3
P`<0Ogmo0`1lO7`407inOP<0P8200`1oOgl40820P0<0Ogmo1`22PX8307moO`<0P8200`21PH4707in
OPL0P8200`21PH4307alO0@0Ogmo0`1nOWh:0820P0@0b>3H1`21PH4307]kN`<0N7Qh102>SXh307Yj
NP<0OWin0`1gMgL408>3P`<0OWin0`23Ph<407YjNP<0Ng]k0`1hN7P40861P@<0P8200`1mOGd407mo
O`<0OWin0`1jNWX308F5Q@@0OWin0`26QXH307inOP@0Q8B40`1mOGd307inOP@0QHF50`1nOWh308J6
QP<0MWIf1025QHDD0<SPf0004`38h=P308b<S0@0Kfm_0`2<S8`307emO@@0O7al0`1oOgl30820P0@0
PX:20`1nOWh308R8R0<0MGEe101nOWh308:2PP<0P8201021PH430820P0<0PH611`20P80307inOP<0
P820101oOgl307emO@<0P820101oOgl30820P0<0PX:21020P80307alO0L0Ogmo0`20P8040<SPf0<0
QHF5101dM7@30861P@<0PX:2101mOGd307IfMP<0Ph>3101iNGT307emO@<0Ogmo0`1kNg/408>3P`<0
PH610`22PX8407alO0<0Ph>30`1mOGd707alO0<0P8200`1lO7`407moO`<0OWin0`1mOGd407moO`<0
P8200`1nOWh40861P@H0OGem1020P80307inOPl0b>3H0`1mOGd408:2PP<0PH610`22PX8407MgM`<0
QHF50`20P80407emO@<0Ogmo0`20P80307]kN`@0Ph>30`20P80307inOP@0PX:20`1oOgl307emO@@0
P8200`1oOgl307emO@<0Ogmo101mOGd60820P0@0OWin0`1lO7`708>3P`<0Ogmo0`1nOWh40820P0<0
PH611038h=P307IfMP@0VIVI0`1nOWh308J6QP@0NWYj0`28R8P30820P0L0QhN70`26QXH308>3P`@0
L71`0`1jNWX308b<S0@0NGUi0`23Ph<307alO0@0PX:20`24Q8@308R8R0<0Ng]k1025QHD30861P@<0
Ng]k1025QHD307IfMP<0Ng]k1020P80308F5Q@<0PX:21`1oOglD0<SPf0004`38h=P308b<S0@0Kfm_
0`2<S8`307emO@@0O7al0`1oOgl30820P0@0PX:20`1nOWh308R8R0<0MGEe101nOWh308:2PP<0P820
1021PH430820P0<0PH611`20P80307inOP<0P820101oOgl307emO@<0P820101oOgl30820P0<0PX:2
1020P80307alO0L0Ogmo0`20P8040<SPf0<0QHF5101dM7@30861P@<0PX:2101mOGd307IfMP<0Ph>3
101iNGT307emO@<0Ogmo0`1kNg/408>3P`<0PH610`22PX8407alO0<0Ph>30`1mOGd707alO0<0P820
0`1lO7`407moO`<0OWin0`1mOGd407moO`<0P8200`1nOWh40861P@H0OGem1020P80307inOPl0b>3H
0`1mOGd408:2PP<0PH610`22PX8407MgM`<0QHF50`20P80407emO@<0Ogmo0`20P80307]kN`@0Ph>3
0`20P80307inOP@0PX:20`1oOgl307emO@@0P8200`1oOgl307emO@<0Ogmo101mOGd60820P0@0OWin
0`1lO7`708>3P`<0Ogmo0`1nOWh40820P0<0PH611038h=P307IfMP@0VIVI0`1nOWh308J6QP@0NWYj
0`28R8P30820P0L0QhN70`26QXH308>3P`@0L71`0`1jNWX308b<S0@0NGUi0`23Ph<307alO0@0PX:2
0`24Q8@308R8R0<0Ng]k1025QHD30861P@<0Ng]k1025QHD307IfMP<0Ng]k1020P80308F5Q@<0PX:2
1`1oOglD0<SPf0004`38h=P308b<S0@0Kfm_0`2<S8`307emO@@0O7al0`1oOgl30820P0@0PX:20`1n
OWh308R8R0<0MGEe101nOWh308:2PP<0P8201021PH430820P0<0PH611`20P80307inOP<0P820101o
Ogl307emO@<0P820101oOgl30820P0<0PX:21020P80307alO0L0Ogmo0`20P8040<SPf0<0QHF5101d
M7@30861P@<0PX:2101mOGd307IfMP<0Ph>3101iNGT307emO@<0Ogmo0`1kNg/408>3P`<0PH610`22
PX8407alO0<0Ph>30`1mOGd707alO0<0P8200`1lO7`407moO`<0OWin0`1mOGd407moO`<0P8200`1n
OWh40861P@H0OGem1020P80307inOPl0b>3H0`1mOGd408:2PP<0PH610`22PX8407MgM`<0QHF50`20
P80407emO@<0Ogmo0`20P80307]kN`@0Ph>30`20P80307inOP@0PX:20`1oOgl307emO@@0P8200`1o
Ogl307emO@<0Ogmo101mOGd60820P0@0OWin0`1lO7`708>3P`<0Ogmo0`1nOWh40820P0<0PH611038
h=P307IfMP@0VIVI0`1nOWh308J6QP@0NWYj0`28R8P30820P0L0QhN70`26QXH308>3P`@0L71`0`1j
NWX308b<S0@0NGUi0`23Ph<307alO0@0PX:20`24Q8@308R8R0<0Ng]k1025QHD30861P@<0Ng]k1025
QHD307IfMP<0Ng]k1020P80308F5Q@<0PX:21`1oOglD0<SPf0004`38h=P308b<S0@0Kfm_0`2<S8`3
07emO@@0O7al0`1oOgl30820P0@0PX:20`1nOWh308R8R0<0MGEe101nOWh308:2PP<0P8201021PH43
0820P0<0PH611`20P80307inOP<0P820101oOgl307emO@<0P820101oOgl30820P0<0PX:21020P803
07alO0L0Ogmo0`20P8040<SPf0<0QHF5101dM7@30861P@<0PX:2101mOGd307IfMP<0Ph>3101iNGT3
07emO@<0Ogmo0`1kNg/408>3P`<0PH610`22PX8407alO0<0Ph>30`1mOGd707alO0<0P8200`1lO7`4
07moO`<0OWin0`1mOGd407moO`<0P8200`1nOWh40861P@H0OGem1020P80307inOPl0b>3H0`1mOGd4
08:2PP<0PH610`22PX8407MgM`<0QHF50`20P80407emO@<0Ogmo0`20P80307]kN`@0Ph>30`20P803
07inOP@0PX:20`1oOgl307emO@@0P8200`1oOgl307emO@<0Ogmo101mOGd60820P0@0OWin0`1lO7`7
08>3P`<0Ogmo0`1nOWh40820P0<0PH611038h=P307IfMP@0VIVI0`1nOWh308J6QP@0NWYj0`28R8P3
0820P0L0QhN70`26QXH308>3P`@0L71`0`1jNWX308b<S0@0NGUi0`23Ph<307alO0@0PX:20`24Q8@3
08R8R0<0Ng]k1025QHD30861P@<0Ng]k1025QHD307IfMP<0Ng]k1020P80308F5Q@<0PX:21`1oOglD
0<SPf0004`38h=P307MgM`@0S8b<0`1lO7`307emO@@0OWin0`1mOGd308F5Q@@0Ogmo0`20P80308B4
Q0<0NGUi2P21PH4408:2PP<0OWin1`1oOgl308:2PP<0OWin0`20P80407inOP<0P8200`1nOWh40861
P@H0P8201023Ph<307inOP<0P8201`21PH440<SPf0<0K6a/102=SHd307EeM@<0Ng]k1021PH4307=c
L`<0SHf=101fMWH307emO@<0Ph>30`1oOgl408B4Q0<0Ogmo0`20P80407inOP<0O7al0`21PH4407em
O@<0Ogmo0`20P8030861P@@0PX:20`25QHD307emO@@0PX:20`1kNg/307emO@@0Q8B40`1mOGd307Yj
NP@0QHF50`1nOWh?0<SPf0<0PH61101oOgl307alO0<0OWin1021PH4307moO`<0PH61101oOgl307in
OP<0QXJ60`1nOWh408:2PP<0O7al0`21PH4408:2PP<0OGem0`25QHD407inOP<0Ogmo0`22PX830820
P0@0Ogmo0`1nOWh308:2PP@0PH610`1nOWh308F5Q@@0PH610`1nOWh30820P0@0O7al0`20P8040<SP
f0<0QhN7102<S8`308f=S@<0QHF51023Ph<307AdM0<0Lg=c0`1jNWX408:2PP<0TI6A0`1lO7`408B4
Q0<0OWin0`1oOgl40820P0<0Ogmo0`21PH4407emO@<0P8200`25QHD307moO`@0Q8B40`1oOgl70861
P@<0Ph>30`1mOGd:07inOP<0O7al101gMgLD0<SPf0004`38h=P307MgM`@0S8b<0`1lO7`307emO@@0
OWin0`1mOGd308F5Q@@0Ogmo0`20P80308B4Q0<0NGUi2P21PH4408:2PP<0OWin1`1oOgl308:2PP<0
OWin0`20P80407inOP<0P8200`1nOWh40861P@H0P8201023Ph<307inOP<0P8201`21PH440<SPf0<0
K6a/102=SHd307EeM@<0Ng]k1021PH4307=cL`<0SHf=101fMWH307emO@<0Ph>30`1oOgl408B4Q0<0
Ogmo0`20P80407inOP<0O7al0`21PH4407emO@<0Ogmo0`20P8030861P@@0PX:20`25QHD307emO@@0
PX:20`1kNg/307emO@@0Q8B40`1mOGd307YjNP@0QHF50`1nOWh?0<SPf0<0PH61101oOgl307alO0<0
OWin1021PH4307moO`<0PH61101oOgl307inOP<0QXJ60`1nOWh408:2PP<0O7al0`21PH4408:2PP<0
OGem0`25QHD407inOP<0Ogmo0`22PX830820P0@0Ogmo0`1nOWh308:2PP@0PH610`1nOWh308F5Q@@0
PH610`1nOWh30820P0@0O7al0`20P8040<SPf0<0QhN7102<S8`308f=S@<0QHF51023Ph<307AdM0<0
Lg=c0`1jNWX408:2PP<0TI6A0`1lO7`408B4Q0<0OWin0`1oOgl40820P0<0Ogmo0`21PH4407emO@<0
P8200`25QHD307moO`@0Q8B40`1oOgl70861P@<0Ph>30`1mOGd:07inOP<0O7al101gMgLD0<SPf000
4`38h=P307MgM`@0S8b<0`1lO7`307emO@@0OWin0`1mOGd308F5Q@@0Ogmo0`20P80308B4Q0<0NGUi
2P21PH4408:2PP<0OWin1`1oOgl308:2PP<0OWin0`20P80407inOP<0P8200`1nOWh40861P@H0P820
1023Ph<307inOP<0P8201`21PH440<SPf0<0K6a/102=SHd307EeM@<0Ng]k1021PH4307=cL`<0SHf=
101fMWH307emO@<0Ph>30`1oOgl408B4Q0<0Ogmo0`20P80407inOP<0O7al0`21PH4407emO@<0Ogmo
0`20P8030861P@@0PX:20`25QHD307emO@@0PX:20`1kNg/307emO@@0Q8B40`1mOGd307YjNP@0QHF5
0`1nOWh?0<SPf0<0PH61101oOgl307alO0<0OWin1021PH4307moO`<0PH61101oOgl307inOP<0QXJ6
0`1nOWh408:2PP<0O7al0`21PH4408:2PP<0OGem0`25QHD407inOP<0Ogmo0`22PX830820P0@0Ogmo
0`1nOWh308:2PP@0PH610`1nOWh308F5Q@@0PH610`1nOWh30820P0@0O7al0`20P8040<SPf0<0QhN7
102<S8`308f=S@<0QHF51023Ph<307AdM0<0Lg=c0`1jNWX408:2PP<0TI6A0`1lO7`408B4Q0<0OWin
0`1oOgl40820P0<0Ogmo0`21PH4407emO@<0P8200`25QHD307moO`@0Q8B40`1oOgl70861P@<0Ph>3
0`1mOGd:07inOP<0O7al101gMgLD0<SPf0004`38h=P307emO@@0P8200`1hN7P30861P@@0P8200`1k
Ng/308Z:RP@0OGem0`20P80308N7Q`<0PH61101mOGd30861P@<0Ogmo1021PH430820P0<0Ogmo2P1n
OWh30820P0@0PH610`1nOWh308:2PP@0P8200`1nOWh307moO`L0P8200`1nOWh407moO`<0OWin1038
h=P307=cL`@0R8R80`1eMGD308Z:RP@0OWin0`1/K6`30:2PX0@0MWIf0`21PH430820P0<0PH611022
PX8307inOP<0PH61101lO7`608:2PPL0Ph>30`1mOGd308>3P`@0OWin0`20P80308>3P`@0OGem0`20
P80308>3P`@0Ogmo0`23Ph<30820P0@0OWin0`1oOgl?0<SPf0<0P820101lO7`308>3P`<0Ogmo2P20
P80407UiN@<0Q8B40`1lO7`308N7Q`@0Q8B40`20P80307emO@@0OWin0`1mOGd307]kN`@0PH610`20
P80307inOP<0P820101oOgl307inOP<0OGem1021PH430820P0<0OWin101oOgl60861P@L0OWin1038
h=P307MgM`@0Ogmo0`29RHT30820P0@0PH610`1nOWh309VIV@<0U9BD1022PX8307inOP<0P8201024
Q8@307emO@<0PH61101oOgl307emO@<0OWin1029RHT307inOP<0QXJ60`23Ph<:0820P0@0PX:20`23
Ph<307YjNP@0OGem0`1oOgl30820P0<0PX:21021PH4D0<SPf0004`38h=P307emO@@0P8200`1hN7P3
0861P@@0P8200`1kNg/308Z:RP@0OGem0`20P80308N7Q`<0PH61101mOGd30861P@<0Ogmo1021PH43
0820P0<0Ogmo2P1nOWh30820P0@0PH610`1nOWh308:2PP@0P8200`1nOWh307moO`L0P8200`1nOWh4
07moO`<0OWin1038h=P307=cL`@0R8R80`1eMGD308Z:RP@0OWin0`1/K6`30:2PX0@0MWIf0`21PH43
0820P0<0PH611022PX8307inOP<0PH61101lO7`608:2PPL0Ph>30`1mOGd308>3P`@0OWin0`20P803
08>3P`@0OGem0`20P80308>3P`@0Ogmo0`23Ph<30820P0@0OWin0`1oOgl?0<SPf0<0P820101lO7`3
08>3P`<0Ogmo2P20P80407UiN@<0Q8B40`1lO7`308N7Q`@0Q8B40`20P80307emO@@0OWin0`1mOGd3
07]kN`@0PH610`20P80307inOP<0P820101oOgl307inOP<0OGem1021PH430820P0<0OWin101oOgl6
0861P@L0OWin1038h=P307MgM`@0Ogmo0`29RHT30820P0@0PH610`1nOWh309VIV@<0U9BD1022PX83
07inOP<0P8201024Q8@307emO@<0PH61101oOgl307emO@<0OWin1029RHT307inOP<0QXJ60`23Ph<:
0820P0@0PX:20`23Ph<307YjNP@0OGem0`1oOgl30820P0<0PX:21021PH4D0<SPf0004`38h=P307em
O@@0P8200`1hN7P30861P@@0P8200`1kNg/308Z:RP@0OGem0`20P80308N7Q`<0PH61101mOGd30861
P@<0Ogmo1021PH430820P0<0Ogmo2P1nOWh30820P0@0PH610`1nOWh308:2PP@0P8200`1nOWh307mo
O`L0P8200`1nOWh407moO`<0OWin1038h=P307=cL`@0R8R80`1eMGD308Z:RP@0OWin0`1/K6`30:2P
X0@0MWIf0`21PH430820P0<0PH611022PX8307inOP<0PH61101lO7`608:2PPL0Ph>30`1mOGd308>3
P`@0OWin0`20P80308>3P`@0OGem0`20P80308>3P`@0Ogmo0`23Ph<30820P0@0OWin0`1oOgl?0<SP
f0<0P820101lO7`308>3P`<0Ogmo2P20P80407UiN@<0Q8B40`1lO7`308N7Q`@0Q8B40`20P80307em
O@@0OWin0`1mOGd307]kN`@0PH610`20P80307inOP<0P820101oOgl307inOP<0OGem1021PH430820
P0<0OWin101oOgl60861P@L0OWin1038h=P307MgM`@0Ogmo0`29RHT30820P0@0PH610`1nOWh309VI
V@<0U9BD1022PX8307inOP<0P8201024Q8@307emO@<0PH61101oOgl307emO@<0OWin1029RHT307in
OP<0QXJ60`23Ph<:0820P0@0PX:20`23Ph<307YjNP@0OGem0`1oOgl30820P0<0PX:21021PH4D0<SP
f0004`38h=P307=cL`@0OWin0`21PH4307emO@L0P8200`1lO7`408>3P`<0OGem0`23Ph<307moO`@0
OGem0`20P80707moO`<0OWin0`1oOgl407alO0<0PH610`1nOWh30820P0@0PH610`1oOgl30861P@@0
OWin0`21PH4307inOP@0Ogmo1P1nOWh40861P@<0Ogmo1038h=P30820P0@0QHF50`22PX8308F5Q@@0
QhN70`1kNg/30861P@@0LW9b0`26QXH30861P@<0PX:21026QXH60820P0@0PH610`1lO7`308>3P`@0
Ogmo0`25QHD307]kN`<0Ph>3101kNg/307moO`<0P820101nOWh30861P@<0P820101mOGd308:2PP<0
Ng]k1021PH4308>3P`l0b>3H0`1kNg/407emO@<0PH610`1kNg/408B4Q0<0Ph>30`1oOgl408Z:RP<0
PX:20`20P80307inOP@0Ogmo0`1mOGd307alO0@0PH611P1nOWh70820P0<0PX:20`1oOgl40820P0H0
OWin1020P80307inOP<0PX:21`21PH4307inOP@0PX:20`1oOgl40<SPf0<0MgMg101kNg/307UiN@<0
QhN7101kNg/308V9R@<0TY:B0`1JFUX407YjNP<0LG5a0`1gMgL408B4Q0<0PH610`1iNGT407moO`<0
O7al0`1kNg/407emO@<0NWYj0`1nOWh307AdM0L0Ogmo0`20P80407UiN@<0Ogmo0`29RHT40820P0<0
OGem0`25QHD307YjNP@0PX:25038h=P001<0b>3H0`1cLg<407inOP<0PH610`1mOGd70820P0<0O7al
1023Ph<307emO@<0Ph>30`1oOgl407emO@<0P8201`1oOgl307inOP<0Ogmo101lO7`30861P@<0OWin
0`20P8040861P@<0Ogmo0`21PH4407inOP<0PH610`1nOWh407moO`H0OWin1021PH4307moO`@0b>3H
0`20P80408F5Q@<0PX:20`25QHD408N7Q`<0Ng]k0`21PH44079bLP<0QXJ60`21PH4308:2PP@0QXJ6
1P20P8040861P@<0O7al0`23Ph<407moO`<0QHF50`1kNg/308>3P`@0Ng]k0`1oOgl30820P0@0OWin
0`21PH430820P0@0OGem0`22PX8307]kN`@0PH610`23Ph<?0<SPf0<0Ng]k101mOGd30861P@<0Ng]k
1024Q8@308>3P`<0Ogmo102:RXX308:2PP<0P8200`1nOWh407moO`<0OGem0`1lO7`40861P@H0OWin
1`20P80308:2PP<0Ogmo1020P80607inOP@0P8200`1nOWh308:2PPL0PH610`1nOWh408:2PP<0Ogmo
1038h=P307MgM`@0Ng]k0`1iNGT308N7Q`@0Ng]k0`29RHT309:BTP<0FUYJ101jNWX3075aL@<0MgMg
1024Q8@30861P@<0NGUi101oOgl307alO0<0Ng]k101mOGd307YjNP<0OWin0`1dM7@707moO`<0P820
101iNGT307moO`<0RHV91020P80307emO@<0QHF50`1jNWX408:2PQ@0b>3H000C0<SPf0<0Lg=c101n
OWh30861P@<0OGem1`20P80307alO0@0Ph>30`1mOGd308>3P`<0Ogmo101mOGd30820P0L0Ogmo0`1n
OWh307moO`@0O7al0`21PH4307inOP<0P8201021PH4307moO`<0PH61101nOWh30861P@<0OWin101o
Ogl607inOP@0PH610`1oOgl40<SPf0<0P8201025QHD308:2PP<0QHF51027QhL307]kN`<0PH61101b
LW8308J6QP<0PH610`22PX8408J6QPH0P8201021PH4307alO0<0Ph>3101oOgl308F5Q@<0Ng]k0`23
Ph<407]kN`<0Ogmo0`20P80407inOP<0PH610`20P80407emO@<0PX:20`1kNg/40861P@<0Ph>33`38
h=P307]kN`@0OGem0`21PH4307]kN`@0Q8B40`23Ph<307moO`@0RXZ:0`22PX830820P0<0OWin101o
Ogl307emO@<0O7al1021PH4607inOPL0P8200`22PX8307moO`@0P8201P1nOWh40820P0<0OWin0`22
PX870861P@<0OWin1022PX8307moO`@0b>3H0`1gMgL407]kN`<0NGUi0`27QhL407]kN`<0RHV90`2B
TY8305YJFP@0NWYj0`1aLG4307MgM`@0Q8B40`21PH4307UiN@@0Ogmo0`1lO7`307]kN`@0OGem0`1j
NWX307inOP<0M7Ad1`1oOgl30820P0@0NGUi0`1oOgl308V9R@@0P8200`1mOGd308F5Q@<0NWYj1022
PX8D0<SPf0004`38h=P307alO0L0Ng]k0`25QHD407YjNP<0OGem0`1nOWh407moO`<0P8200`22PX83
07alO0@0OWin0`1oOgl307alO0@0PX:21P1oOgl407emO@<0Ogmo0`20P8070861P@<0OWin0`20P804
08:2PP<0OWin2P1oOgl307inOP@0PH610`20P8040<SPf0<0OWin101eMGD30861P@<0Q8B41029RHT3
08Z:RP<0QhN7101kNg/309:BTP<0OWin0`1oOgl40820P0<0Ng]k1`1nOWh30820P0L0PH610`24Q8@3
07]kN`<0P820101kNg/307emO@<0P820101oOgl607inOP@0Ph>30`22PX8307alO0L0Ogmo3`38h=P3
07emO@L0OWin0`1oOgl40820P0<0PH610`1nOWh40820P0<0NGUi0`1oOgl30820P0@0OWin0`22PX83
07alO0@0Ogmo1P21PH4407]kN`<0Ph>30`1lO7`30820P0@0OWin1P1oOgl40861P@<0PX:20`1kNg/4
0820P0<0PH610`24Q8@407alO0<0PH611038h=P308:2PP@0O7al0`26QXH308:2PP@0MGEe0`1hN7P3
08F5Q@<0LG5a1023Ph<308b<S0<0OGem101oOgl307]kN`<0OGem101eMGD30861P@<0O7al1029RHT6
07YjNP<0Ng]k1021PH4307emO@<0QHF51023Ph<307emO@<0QhN7101oOgl307alO0<0OGem0`23Ph<4
0820P1@0b>3H000C0<SPf0<0O7al1`1kNg/308F5Q@@0NWYj0`1mOGd307inOP@0Ogmo0`20P80308:2
PP<0O7al101nOWh307moO`<0O7al1022PX8607moO`@0OGem0`1oOgl30820P0L0PH610`1nOWh30820
P0@0PX:20`1nOWh:07moO`<0OWin1021PH430820P0@0b>3H0`1nOWh407EeM@<0PH610`24Q8@408V9
R@<0RXZ:0`27QhL407]kN`<0TY:B0`1nOWh307moO`@0P8200`1kNg/707inOP<0P8201`21PH4308B4
Q0<0Ng]k0`20P80407]kN`<0OGem0`20P80407moO`H0OWin1023Ph<308:2PP<0O7al1`1oOgl?0<SP
f0<0OGem1`1nOWh307moO`@0P8200`21PH4307inOP@0P8200`1iNGT307moO`<0P820101nOWh308:2
PP<0O7al101oOgl60861P@@0Ng]k0`23Ph<307alO0<0P820101nOWh607moO`@0PH610`22PX8307]k
N`@0P8200`21PH4308B4Q0@0O7al0`21PH440<SPf0<0PX:2101lO7`308J6QP<0PX:2101eMGD307Qh
N0<0QHF50`1aLG4408>3P`<0S8b<0`1mOGd407moO`<0Ng]k0`1mOGd407EeM@<0PH610`1lO7`408V9
R@H0NWYj0`1kNg/40861P@<0OGem0`25QHD408>3P`<0OGem0`27QhL407moO`<0O7al0`1mOGd308>3
P`@0P8205038h=P001<0b>3H0`1lO7`707]kN`<0QHF5101jNWX307emO@<0OWin101oOgl30820P0<0
PX:20`1lO7`407inOP<0Ogmo0`1lO7`408:2PPH0Ogmo101mOGd307moO`<0P8201`21PH4307inOP<0
P8201022PX8307inOPX0Ogmo0`1nOWh40861P@<0P8201038h=P307inOP@0MGEe0`21PH4308B4Q0@0
RHV90`2:RXX308N7Q`@0Ng]k0`2BTY8307inOP<0Ogmo1020P80307]kN`L0OWin0`20P8070861P@<0
Q8B40`1kNg/30820P0@0Ng]k0`1mOGd30820P0@0Ogmo1P1nOWh408>3P`<0PX:20`1lO7`707moO`l0
b>3H0`1mOGd707inOP<0Ogmo1020P8030861P@<0OWin1020P80307UiN@<0Ogmo0`20P80407inOP<0
PX:20`1lO7`407moO`H0PH61101kNg/308>3P`<0O7al0`20P80407inOPH0Ogmo1021PH4308:2PP<0
Ng]k1020P8030861P@<0Q8B4101lO7`30861P@@0b>3H0`22PX8407alO0<0QXJ60`22PX8407EeM@<0
N7Qh0`25QHD3075aL@@0Ph>30`2<S8`307emO@@0Ogmo0`1kNg/307emO@@0MGEe0`21PH4307alO0@0
RHV91P1jNWX307]kN`@0PH610`1mOGd308F5Q@@0Ph>30`1mOGd308N7Q`@0Ogmo0`1lO7`307emO@<0
Ph>31020P80D0<SPf0004`38h=P307alO0L0Ng]k0`25QHD407YjNP<0OGem0`1nOWh407moO`<0P820
0`22PX8307alO0@0OWin0`1oOgl307alO0@0PX:21P1oOgl407emO@<0Ogmo0`20P8070861P@<0OWin
0`20P80408:2PP<0OWin2P1oOgl307inOP@0PH610`20P8040<SPf0<0OWin101eMGD30861P@<0Q8B4
1029RHT308Z:RP<0QhN7101kNg/309:BTP<0OWin0`1oOgl40820P0<0Ng]k1`1nOWh30820P0L0PH61
0`24Q8@307]kN`<0P820101kNg/307emO@<0P820101oOgl607inOP@0Ph>30`22PX8307alO0L0Ogmo
3`38h=P307emO@L0OWin0`1oOgl40820P0<0PH610`1nOWh40820P0<0NGUi0`1oOgl30820P0@0OWin
0`22PX8307alO0@0Ogmo1P21PH4407]kN`<0Ph>30`1lO7`30820P0@0OWin1P1oOgl40861P@<0PX:2
0`1kNg/40820P0<0PH610`24Q8@407alO0<0PH611038h=P308:2PP@0O7al0`26QXH308:2PP@0MGEe
0`1hN7P308F5Q@<0LG5a1023Ph<308b<S0<0OGem101oOgl307]kN`<0OGem101eMGD30861P@<0O7al
1029RHT607YjNP<0Ng]k1021PH4307emO@<0QHF51023Ph<307emO@<0QhN7101oOgl307alO0<0OGem
0`23Ph<40820P1@0b>3H000C0<SPf0<0Ogmo1023Ph<307emO@<0PH611020P80608:2PP@0Ogmo0`21
PH4307inOP<0O7al1023Ph<308:2PP<0Ogmo1022PX830861P@<0P8201023Ph<30861P@<0P8200`1m
OGd407moO`<0PH610`20P80707moO`<0OGem101oOgl608:2PPL0OWin1038h=P308N7Q`@0OWin0`1o
Ogl307YjNP@0R8R80`20P80309:BTP@0Lg=c0`2FUYH307=cL`<0QHF5101oOgl308>3P`<0Ogmo1020
P80607moO`L0PH610`1oOgl307emO@@0Q8B40`20P80307inOP@0P8200`22PX870861P@<0P8200`24
Q8@407alO0<0NGUi3`38h=P30820P0@0PH611P1oOgl408:2PP<0OWin0`1oOgl407emO@<0Rh^;0`1i
NGT307alO0@0PH610`1oOgl30861P@@0P8200`1oOgl307inOP@0PH610`1lO7`308:2PP<0Ogmo101n
OWh60820P0@0PX:20`1oOgl308:2PP@0OWin0`1oOgl307emO@@0Ogmo0`23Ph<40<SPf0<0Ogmo1027
QhL607emO@@0MgMg0`1bLW8607alO0@0YjNW0`2CTi<307moO`@0QHF50`1jNWX308B4Q0@0NGUi0`20
P80307alO0@0Ogmo0`1kNg/308:2PP<0Ng]k102:RXX307alO0<0Ogmo101kNg/60820P0@0Q8B40`22
PX8308R8R0<0QHF51020P80D0<SPf0004`38h=P307moO`@0Ph>30`1mOGd30861P@@0P8201P22PX84
07moO`<0PH610`1nOWh307alO0@0Ph>30`22PX8307moO`@0PX:20`21PH430820P0@0Ph>30`21PH43
0820P0<0OGem101oOgl30861P@<0P8201`1oOgl307emO@@0Ogmo1P22PX8707inOP@0b>3H0`27QhL4
07inOP<0Ogmo0`1jNWX408R8R0<0P8200`2BTY8407=cL`<0UYJF0`1cLg<308F5Q@@0Ogmo0`23Ph<3
07moO`@0P8201P1oOgl70861P@<0Ogmo0`1mOGd408B4Q0<0P8200`1nOWh40820P0<0PX:21`21PH43
0820P0<0Q8B4101lO7`307UiN@l0b>3H0`20P8040861P@H0Ogmo1022PX8307inOP<0Ogmo101mOGd3
08^;R`<0NGUi0`1lO7`40861P@<0Ogmo0`21PH440820P0<0Ogmo0`1nOWh40861P@<0O7al0`22PX83
07moO`@0OWin1P20P80408:2PP<0Ogmo0`22PX8407inOP<0Ogmo0`1mOGd407moO`<0Ph>31038h=P3
07moO`@0QhN71P1mOGd407MgM`<0LW9b1P1lO7`40:NWY`<0Ti>C0`1oOgl408F5Q@<0NWYj0`24Q8@4
07UiN@<0P8200`1lO7`407moO`<0Ng]k0`22PX8307]kN`@0RXZ:0`1lO7`307moO`@0Ng]k1P20P804
08B4Q0<0PX:20`28R8P308F5Q@@0P8205038h=P001<0b>3H0`1oOgl408>3P`<0OGem0`21PH440820
P0H0PX:2101oOgl30861P@<0OWin0`1lO7`408>3P`<0PX:20`1oOgl408:2PP<0PH610`20P80408>3
P`<0PH610`20P80307emO@@0Ogmo0`21PH430820P0L0Ogmo0`1mOGd407moO`H0PX:21`1nOWh40<SP
f0<0QhN7101nOWh307moO`<0NWYj1028R8P30820P0<0TY:B101cLg<309JFUP<0Lg=c0`25QHD407mo
O`<0Ph>30`1oOgl40820P0H0Ogmo1`21PH4307moO`<0OGem1024Q8@30820P0<0OWin1020P80308:2
PPL0PH610`20P80308B4Q0@0O7al0`1iNGT?0<SPf0<0P8201021PH4607moO`@0PX:20`1nOWh307mo
O`@0OGem0`2;Rh/307UiN@<0O7al1021PH4307moO`<0PH611020P80307moO`<0OWin1021PH4307al
O0<0PX:20`1oOgl407inOPH0P8201022PX8307moO`<0PX:2101nOWh307moO`<0OGem101oOgl308>3
P`@0b>3H0`1oOgl408N7Q`H0OGem101gMgL3079bLPH0O7al102WYjL309>CT`<0Ogmo1025QHD307Yj
NP<0Q8B4101iNGT30820P0<0O7al101oOgl307]kN`<0PX:20`1kNg/408Z:RP<0O7al0`1oOgl407]k
N`H0P8201024Q8@308:2PP<0R8R80`25QHD40820P1@0b>3H000C0<SPf0<0QXJ6101kNg/307moO`<0
O7al1`21PH4707emO@<0O7al0`24Q8@307YjNP@0Ogmo0`23Ph<307moO`@0Q8B41P1oOgl40861P@<0
P8201P21PH4407emO@<0PX:20`20P8070861P@<0Ogmo1020P80307inOP<0PH61101nOWh30820P0@0
b>3H0`1fMWH408J6QP<0Ogmo0`1lO7`408:2PP<0Rh^;0`1eMGD408j>SP<0OWin0`1^KVh308Z:RP@0
OWin0`24Q8@308:2PP@0P8200`22PX8307alO0@0OGem0`21PH4307emO@<0PH611022PX8307inOPL0
Ng]k0`22PX8307inOP@0O7al0`1mOGd30861P@@0Q8B40`1mOGd?0<SPf0<0P8201026QXH30820P0<0
Ng]k1`22PX8308B4Q0@0Ph>30`1hN7P308R8R0L0PH610`1oOgl307inOP@0P8200`21PH4307inOP@0
Ogmo0`22PX8307inOP<0Q8B41021PH430820P0<0OWin1022PX8307alO0<0PH611020P80307moO`<0
PX:2101lO7`307inOP@0b>3H0`20P80407UiN@<0QHF50`1mOGd407inOP<0NGUi0`1hN7P30820P0@0
S8b<0`1KFe/307EeM@@0O7al0`24Q8@307inOP@0QXJ60`1mOGd308J6QP@0OGem0`22PX8307inOPX0
PX:20`1hN7P408:2PP<0OGem0`25QHD407]kN`<0PX:21P21PH4407alO1@0b>3H000C0<SPf0<0QXJ6
101kNg/307moO`<0O7al1`21PH4707emO@<0O7al0`24Q8@307YjNP@0Ogmo0`23Ph<307moO`@0Q8B4
1P1oOgl40861P@<0P8201P21PH4407emO@<0PX:20`20P8070861P@<0Ogmo1020P80307inOP<0PH61
101nOWh30820P0@0b>3H0`1fMWH408J6QP<0Ogmo0`1lO7`408:2PP<0Rh^;0`1eMGD408j>SP<0OWin
0`1^KVh308Z:RP@0OWin0`24Q8@308:2PP@0P8200`22PX8307alO0@0OGem0`21PH4307emO@<0PH61
1022PX8307inOPL0Ng]k0`22PX8307inOP@0O7al0`1mOGd30861P@@0Q8B40`1mOGd?0<SPf0<0P820
1026QXH30820P0<0Ng]k1`22PX8308B4Q0@0Ph>30`1hN7P308R8R0L0PH610`1oOgl307inOP@0P820
0`21PH4307inOP@0Ogmo0`22PX8307inOP<0Q8B41021PH430820P0<0OWin1022PX8307alO0<0PH61
1020P80307moO`<0PX:2101lO7`307inOP@0b>3H0`20P80407UiN@<0QHF50`1mOGd407inOP<0NGUi
0`1hN7P30820P0@0S8b<0`1KFe/307EeM@@0O7al0`24Q8@307inOP@0QXJ60`1mOGd308J6QP@0OGem
0`22PX8307inOPX0PX:20`1hN7P408:2PP<0OGem0`25QHD407]kN`<0PX:21P21PH4407alO1@0b>3H
000C0<SPf0<0QXJ6101kNg/307moO`<0O7al1`21PH4707emO@<0O7al0`24Q8@307YjNP@0Ogmo0`23
Ph<307moO`@0Q8B41P1oOgl40861P@<0P8201P21PH4407emO@<0PX:20`20P8070861P@<0Ogmo1020
P80307inOP<0PH61101nOWh30820P0@0b>3H0`1fMWH408J6QP<0Ogmo0`1lO7`408:2PP<0Rh^;0`1e
MGD408j>SP<0OWin0`1^KVh308Z:RP@0OWin0`24Q8@308:2PP@0P8200`22PX8307alO0@0OGem0`21
PH4307emO@<0PH611022PX8307inOPL0Ng]k0`22PX8307inOP@0O7al0`1mOGd30861P@@0Q8B40`1m
OGd?0<SPf0<0P8201026QXH30820P0<0Ng]k1`22PX8308B4Q0@0Ph>30`1hN7P308R8R0L0PH610`1o
Ogl307inOP@0P8200`21PH4307inOP@0Ogmo0`22PX8307inOP<0Q8B41021PH430820P0<0OWin1022
PX8307alO0<0PH611020P80307moO`<0PX:2101lO7`307inOP@0b>3H0`20P80407UiN@<0QHF50`1m
OGd407inOP<0NGUi0`1hN7P30820P0@0S8b<0`1KFe/307EeM@@0O7al0`24Q8@307inOP@0QXJ60`1m
OGd308J6QP@0OGem0`22PX8307inOPX0PX:20`1hN7P408:2PP<0OGem0`25QHD407]kN`<0PX:21P21
PH4407alO1@0b>3H000C0<SPf0<0PH61101jNWX30820P0<0Ogmo1022PX8307inOP<0QHF51022PX83
0861P@<0OGem0`21PH440820P0<0PH610`1oOgl408:2PP<0PH610`20P80407moO`<0PH610`1oOgl3
0820P0L0Ogmo0`22PX8707moO`<0OGem1`1nOWh307emO@@0P8200`1nOWh40<SPf0<0Ng]k1024Q8@3
0861P@<0PX:21023Ph<308J6QP<0NWYj102@T90307]kN`<0Ogmo0`23Ph<407moO`<0Ph>30`20P807
08:2PPL0Ph>31P24Q8@30820P0@0Ph>30`1oOgl308:2PPL0P8200`22PX8407alO0<0P8201`1oOgl3
0861P@l0b>3H0`1nOWh407moO`<0Ng]k0`1oOgl40861P@<0OGem0`20P80407moO`<0P8200`1kNg/3
071`L0@0PX:20`1oOgl307inOP@0Ph>30`1nOWh30820P0@0O7al0`1nOWh307emO@<0PH611022PX83
07alO0<0PH611020P80:07moO`<0PH612P1oOgl40<SPf0<0OWin101hN7P308F5Q@<0PH611`1nOWh3
075aL@<0K6a/1024Q8@306YZJP<0[jn_101cLg<307YjNP<0PH611026QXH307alO0<0P820101oOgl6
0861P@<0O7al1`20P80307moO`@0OWin0`1oOgl30820P0@0OGem0`1hN7P308B4Q0<0Ng]k101jNWXD
0<SPf0004`38h=P30861P@@0NWYj0`20P80307moO`@0PX:20`1nOWh308F5Q@@0PX:20`21PH4307em
O@<0PH611020P8030861P@<0Ogmo1022PX830861P@<0P820101oOgl30861P@<0Ogmo0`20P80707mo
O`<0PX:21`1oOgl307emO@L0OWin0`1mOGd40820P0<0OWin1038h=P307]kN`@0Q8B40`21PH4308:2
PP@0Ph>30`26QXH307YjNP@0T92@0`1kNg/307moO`<0Ph>3101oOgl308>3P`<0P8201`22PX8708>3
P`H0Q8B40`20P80408>3P`<0Ogmo0`22PX870820P0<0PX:2101lO7`30820P0L0Ogmo0`21PH4?0<SP
f0<0OWin101oOgl307]kN`<0Ogmo1021PH4307emO@<0P820101oOgl30820P0<0Ng]k0`1`L70408:2
PP<0Ogmo0`1nOWh408>3P`<0OWin0`20P80407alO0<0OWin0`1mOGd30861P@@0PX:20`1lO7`30861
P@@0P8202P1oOgl30861P@X0Ogmo1038h=P307inOP@0N7Qh0`25QHD30861P@L0OWin0`1aLG4306a/
K0@0Q8B40`1ZJVX30:n_[`@0Lg=c0`1jNWX30861P@@0QXJ60`1lO7`30820P0@0Ogmo1P21PH4307al
O0L0P8200`1oOgl407inOP<0Ogmo0`20P80407emO@<0N7Qh0`24Q8@307]kN`@0NWYj5038h=P001<0
b>3H0`21PH4407YjNP<0P8200`1oOgl408:2PP<0OWin0`25QHD408:2PP<0PH610`1mOGd30861P@@0
P8200`21PH4307moO`@0PX:20`21PH430820P0@0Ogmo0`21PH4307moO`<0P8201`1oOgl308:2PPL0
Ogmo0`1mOGd707inOP<0OGem1020P80307inOP@0b>3H0`1kNg/408B4Q0<0PH610`22PX8408>3P`<0
QXJ60`1jNWX4092@T0<0Ng]k0`1oOgl308>3P`@0Ogmo0`23Ph<30820P0L0PX:21`23Ph<608B4Q0<0
P8201023Ph<307moO`<0PX:21`20P80308:2PP@0O7al0`20P80707moO`<0PH613`38h=P307inOP@0
Ogmo0`1kNg/307moO`@0PH610`1mOGd30820P0@0Ogmo0`20P80307]kN`<0L71`1022PX8307moO`<0
OWin1023Ph<307inOP<0P820101lO7`307inOP<0OGem0`21PH4408:2PP<0O7al0`21PH440820P0X0
Ogmo0`21PH4:07moO`@0b>3H0`1nOWh407QhN0<0QHF50`21PH4707inOP<0LG5a0`1/K6`408B4Q0<0
JVYZ0`2_[jl407=cL`<0NWYj0`21PH4408J6QP<0O7al0`20P80407moO`H0PH610`1lO7`70820P0<0
Ogmo101nOWh307moO`<0P820101mOGd307QhN0<0Q8B40`1kNg/407YjNQ@0b>3H000C0<SPf0<0QXJ6
101oOgl307emO@<0PH61101nOWh60861P@@0O7al0`21PH430820P0<0Ogmo101nOWh:0861P@<0Ogmo
1`21PH430820P0<0PX:20`1kNg/40820P0H0OWin101oOgl307alO0L0Ogmo0`23Ph<307inOP@0PH61
0`22PX840<SPf0<0QHF51021PH4307emO@<0NGUi1022PX830861P@<0SHf=101iNGT309BDU0<0NGUi
0`1oOgl40820P0<0NGUi0`22PX8407moO`<0P8200`1oOgl40820P0<0OWin0`1lO7`308:2PP@0NWYj
0`21PH430820P0L0PH610`20P8040861P@<0OWin0`1oOgl40820P0<0Ogmo3`38h=P307moO`@0Ph>3
0`21PH4307alO0@0OWin0`1oOgl307inOP@0O7al0`20P80308:2PP<0RXZ:1023Ph<30861P@<0P820
101lO7`307inOP<0Ogmo101nOWh30861P@<0P8200`21PH4407moO`H0PH611024Q8@307moO`L0Ph>3
0`1mOGd30820P0@0PX:20`1nOWh40<SPf0<0Q8B4101jNWX30861P@<0O7al101nOWh307alO0<0L71`
0`1kNg/406YZJP<0PX:20`2>SXh4065QH@<0TI6A0`20P80408J6QP<0PH610`1oOgl407alO0<0QHF5
0`27QhL307inOP@0Ph>30`1eMGD30820P0@0N7Qh0`21PH4307]kN`@0OWin0`1lO7`30820P0<0MgMg
1022PX8D0<SPf0004`38h=P308J6QP@0Ogmo0`1mOGd30861P@@0OWin1P21PH4407alO0<0PH610`20
P80307moO`@0OWin2P21PH4307moO`L0PH610`20P80308:2PP<0Ng]k1020P80607inOP@0Ogmo0`1l
O7`707moO`<0Ph>30`1nOWh40861P@<0PX:21038h=P308F5Q@@0PH610`1mOGd307UiN@@0PX:20`21
PH4308f=S@@0NGUi0`2DU9@307UiN@<0Ogmo1020P80307UiN@<0PX:2101oOgl30820P0<0Ogmo1020
P80307inOP<0O7al0`22PX8407YjNP<0PH610`20P8070861P@<0P8201021PH4307inOP<0Ogmo1020
P80307moO`l0b>3H0`1oOgl408>3P`<0PH610`1lO7`407inOP<0Ogmo0`1nOWh407alO0<0P8200`22
PX8308Z:RP@0Ph>30`21PH430820P0@0O7al0`1nOWh307moO`@0OWin0`21PH430820P0<0PH61101o
Ogl60861P@@0Q8B40`1oOgl708>3P`<0OGem0`20P80408:2PP<0OWin1038h=P308B4Q0@0NWYj0`21
PH4307alO0@0OWin0`1lO7`3071`L0<0Ng]k101ZJVX308:2PP<0SXj>101QHF43096AT@<0P8201026
QXH30861P@<0Ogmo101lO7`308F5Q@<0QhN70`1nOWh408>3P`<0MGEe0`20P80407QhN0<0PH610`1k
Ng/407inOP<0O7al0`20P80307MgM`@0PX:25038h=P001<0b>3H0`26QXH407moO`<0OGem0`21PH44
07inOPH0PH61101lO7`30861P@<0P8200`1oOgl407inOPX0PH610`1oOgl70861P@<0P8200`22PX83
07]kN`@0P8201P1nOWh407moO`<0O7al1`1oOgl308>3P`<0OWin1021PH4308:2PP@0b>3H0`25QHD4
0861P@<0OGem0`1iNGT408:2PP<0PH610`2=SHd407UiN@<0U9BD0`1iNGT307moO`@0P8200`1iNGT3
08:2PP@0Ogmo0`20P80307moO`@0P8200`1nOWh307alO0<0PX:2101jNWX30861P@<0P8201`21PH43
0820P0@0PH610`1nOWh307moO`@0P8200`1oOgl?0<SPf0<0Ogmo1023Ph<30861P@<0O7al101nOWh3
07moO`<0OWin101lO7`30820P0<0PX:20`2:RXX408>3P`<0PH610`20P80407alO0<0OWin0`1oOgl4
07inOP<0PH610`20P8030861P@@0Ogmo1P21PH4408B4Q0<0Ogmo1`23Ph<307emO@<0P8201022PX83
07inOP@0b>3H0`24Q8@407YjNP<0PH610`1lO7`407inOP<0O7al0`1`L70307]kN`@0JVYZ0`22PX83
08j>SP@0HF5Q0`2ATI430820P0@0QXJ60`21PH4307moO`@0O7al0`25QHD308N7Q`<0OWin1023Ph<3
07EeM@<0P820101hN7P30861P@<0Ng]k101nOWh307alO0<0P8200`1gMgL408:2PQ@0b>3H000C0<SP
f0<0QXJ6101oOgl307emO@<0PH61101nOWh60861P@@0O7al0`21PH430820P0<0Ogmo101nOWh:0861
P@<0Ogmo1`21PH430820P0<0PX:20`1kNg/40820P0H0OWin101oOgl307alO0L0Ogmo0`23Ph<307in
OP@0PH610`22PX840<SPf0<0QHF51021PH4307emO@<0NGUi1022PX830861P@<0SHf=101iNGT309BD
U0<0NGUi0`1oOgl40820P0<0NGUi0`22PX8407moO`<0P8200`1oOgl40820P0<0OWin0`1lO7`308:2
PP@0NWYj0`21PH430820P0L0PH610`20P8040861P@<0OWin0`1oOgl40820P0<0Ogmo3`38h=P307mo
O`@0Ph>30`21PH4307alO0@0OWin0`1oOgl307inOP@0O7al0`20P80308:2PP<0RXZ:1023Ph<30861
P@<0P820101lO7`307inOP<0Ogmo101nOWh30861P@<0P8200`21PH4407moO`H0PH611024Q8@307mo
O`L0Ph>30`1mOGd30820P0@0PX:20`1nOWh40<SPf0<0Q8B4101jNWX30861P@<0O7al101nOWh307al
O0<0L71`0`1kNg/406YZJP<0PX:20`2>SXh4065QH@<0TI6A0`20P80408J6QP<0PH610`1oOgl407al
O0<0QHF50`27QhL307inOP@0Ph>30`1eMGD30820P0@0N7Qh0`21PH4307]kN`@0OWin0`1lO7`30820
P0<0MgMg1022PX8D0<SPf0004`38h=P307inOP@0P8201P1lO7`407moO`<0PH610`1hN7P408>3P`<0
Ng]k0`1oOgl307alO0@0PH610`20P80707moO`<0O7al0`1mOGd408>3P`<0OWin0`1oOgl307inOP@0
Ogmo0`21PH4307inOP@0PH610`20P80307YjNP@0PX:20`1mOGd308:2PP@0P8200`1mOGd40<SPf0<0
Ph>3101oOgl308>3P`<0Ng]k1027QhL307alO0<0S8b<101kNg/308Z:RP<0P8200`1kNg/408F5Q@<0
NWYj0`1nOWh40861P@<0P8200`21PH440820P0H0PX:20`1nOWh40820P0H0PH61101oOgl308:2PP<0
PH61101mOGd308:2PP<0OWin101lO7`307inOPl0b>3H0`21PH4707moO`<0P8201022PX8308J6QP<0
PH611020P80307emO@<0PH610`1lO7`408F5Q@<0Q8B40`20P80407inOP<0PX:20`1lO7`408>3P`<0
Ogmo0`21PH4307moO`@0PX:20`1oOgl307]kN`@0OWin1P20P8040861P@<0OWin0`21PH4407moO`<0
PX:21038h=P307alO0@0Ph>30`1nOWh307emO@@0P8200`1nOWh308>3P`<0QXJ6101]KFd308>3P`<0
LW9b102HV9P307MgM`<0OWin1021PH4308:2PP<0Ogmo1026QXH3079bLPH0PX:2101kNg/307emO@<0
Rh^;101kNg/308B4Q0<0Ng]k1022PX8307inOP<0P8200`1gMgL40820P1@0b>3H000C0<SPf0<0OWin
1020P80607alO0@0Ogmo0`21PH4307QhN0@0Ph>30`1kNg/307moO`<0O7al1021PH430820P0L0Ogmo
0`1lO7`307emO@@0Ph>30`1nOWh307moO`<0OWin101oOgl30861P@<0OWin1021PH430820P0<0NWYj
1022PX8307emO@<0PX:21020P80307emO@@0b>3H0`23Ph<407moO`<0Ph>30`1kNg/408N7Q`<0O7al
0`2<S8`407]kN`<0RXZ:0`20P80307]kN`@0QHF50`1jNWX307inOP@0PH610`20P8030861P@@0P820
1P22PX8307inOP@0P8201P21PH4407moO`<0PX:20`21PH4407emO@<0PX:20`1nOWh407alO0<0OWin
3`38h=P30861P@L0Ogmo0`20P80408:2PP<0QXJ60`21PH440820P0<0OGem0`21PH4307alO0@0QHF5
0`24Q8@30820P0@0OWin0`22PX8307alO0@0Ph>30`1oOgl30861P@<0Ogmo1022PX8307moO`<0Ng]k
101nOWh60820P0@0PH610`1nOWh30861P@@0Ogmo0`22PX840<SPf0<0O7al1023Ph<307inOP<0OGem
1020P80307inOP<0Ph>30`26QXH406e]K@<0Ph>30`1bLW8409RHV0<0MgMg0`1nOWh40861P@<0PX:2
0`1oOgl408J6QP<0LW9b1P22PX8407]kN`<0OGem0`2;Rh/407]kN`<0Q8B40`1kNg/408:2PP<0OWin
0`20P80307MgM`@0P8205038h=P001<0b>3H0`1nOWh40820P0H0O7al101oOgl30861P@<0N7Qh1023
Ph<307]kN`<0Ogmo0`1lO7`40861P@<0P8201`1oOgl307alO0<0OGem1023Ph<307inOP<0Ogmo0`1n
OWh407moO`<0PH610`1nOWh40861P@<0P8200`1jNWX408:2PP<0OGem0`22PX840820P0<0OGem1038
h=P308>3P`@0Ogmo0`23Ph<307]kN`@0QhN70`1lO7`308b<S0@0Ng]k0`2:RXX30820P0<0Ng]k1025
QHD307YjNP<0OWin1021PH430820P0<0PH611020P80608:2PP<0OWin1020P8060861P@@0Ogmo0`22
PX830861P@@0OGem0`22PX8307inOP@0O7al0`1nOWh?0<SPf0<0PH611`1oOgl30820P0@0PX:20`26
QXH30861P@@0P8200`1mOGd30861P@<0O7al1025QHD308B4Q0<0P820101nOWh308:2PP<0O7al1023
Ph<307moO`<0PH610`1oOgl408:2PP<0Ogmo0`1kNg/407inOPH0P8201021PH4307inOP<0PH61101o
Ogl308:2PP@0b>3H0`1lO7`408>3P`<0OWin0`1mOGd40820P0<0OWin0`23Ph<308J6QP@0KFe]0`23
Ph<3079bLP@0V9RH0`1gMgL307inOP@0PH610`22PX8307moO`@0QXJ60`1bLW8608:2PP@0Ng]k0`1m
OGd308^;R`@0Ng]k0`24Q8@307]kN`@0PX:20`1nOWh30820P0<0MgMg1020P80D0<SPf0004`38h=P3
07moO`@0P8200`1nOWh30820P0@0PX:20`1oOgl308B4Q0@0Ogmo0`20P80307moO`<0Ph>3101oOgl3
08>3P`L0Ogmo0`1nOWh30861P@@0OGem1P1nOWh307moO`@0P8200`1oOgl30820P0@0PH610`20P803
07inOP@0Ogmo0`21PH430820P0@0OWin0`1lO7`40<SPf0<0Q8B41025QHD307inOP<0OGem1021PH43
07UiN@<0QhN7102:RXX307AdM0<0Q8B40`22PX8407alO0<0Ph>30`22PX8407inOPH0Ogmo1022PX83
08>3P`<0P8200`23Ph<407alO0<0OWin0`1iNGT407inOP<0O7al2P21PH4307alO0@0OGem0`1oOgl?
0<SPf0<0Q8B41023Ph<307moO`<0OGem1022PX8307alO0L0PH610`20P80307alO0<0Ogmo101mOGd3
07AdM0<0P8201021PH4607moO`@0P8200`1nOWh60820P0@0OWin0`1oOgl30861P@@0O7al0`1nOWh3
07emO@@0Q8B40`21PH4308>3P`@0Ogmo0`21PH440<SPf0<0KFe]101dM7@307moO`<0Ng]k1027QhL3
08J6QP<0QhN70`2NWYh407alO0<0R8R80`1lO7`408F5Q@<0Ng]k0`1mOGd408N7Q`<0PX:20`28R8P4
08:2PP<0NGUi0`26QXH307emO@@0QHF50`1hN7P30861P@@0Ogmo0`24Q8@307alO0@0Ng]k0`20P803
0861P@<0NGUi1020P80D0<SPf0004`38h=P307moO`@0P8200`1nOWh30820P0@0PX:20`1oOgl308B4
Q0@0Ogmo0`20P80307moO`<0Ph>3101oOgl308>3P`L0Ogmo0`1nOWh30861P@@0OGem1P1nOWh307mo
O`@0P8200`1oOgl30820P0@0PH610`20P80307inOP@0Ogmo0`21PH430820P0@0OWin0`1lO7`40<SP
f0<0Q8B41025QHD307inOP<0OGem1021PH4307UiN@<0QhN7102:RXX307AdM0<0Q8B40`22PX8407al
O0<0Ph>30`22PX8407inOPH0Ogmo1022PX8308>3P`<0P8200`23Ph<407alO0<0OWin0`1iNGT407in
OP<0O7al2P21PH4307alO0@0OGem0`1oOgl?0<SPf0<0Q8B41023Ph<307moO`<0OGem1022PX8307al
O0L0PH610`20P80307alO0<0Ogmo101mOGd307AdM0<0P8201021PH4607moO`@0P8200`1nOWh60820
P0@0OWin0`1oOgl30861P@@0O7al0`1nOWh307emO@@0Q8B40`21PH4308>3P`@0Ogmo0`21PH440<SP
f0<0KFe]101dM7@307moO`<0Ng]k1027QhL308J6QP<0QhN70`2NWYh407alO0<0R8R80`1lO7`408F5
Q@<0Ng]k0`1mOGd408N7Q`<0PX:20`28R8P408:2PP<0NGUi0`26QXH307emO@@0QHF50`1hN7P30861
P@@0Ogmo0`24Q8@307alO0@0Ng]k0`20P8030861P@<0NGUi1020P80D0<SPf0004`38h=P307moO`@0
P8200`1nOWh30820P0@0PX:20`1oOgl308B4Q0@0Ogmo0`20P80307moO`<0Ph>3101oOgl308>3P`L0
Ogmo0`1nOWh30861P@@0OGem1P1nOWh307moO`@0P8200`1oOgl30820P0@0PH610`20P80307inOP@0
Ogmo0`21PH430820P0@0OWin0`1lO7`40<SPf0<0Q8B41025QHD307inOP<0OGem1021PH4307UiN@<0
QhN7102:RXX307AdM0<0Q8B40`22PX8407alO0<0Ph>30`22PX8407inOPH0Ogmo1022PX8308>3P`<0
P8200`23Ph<407alO0<0OWin0`1iNGT407inOP<0O7al2P21PH4307alO0@0OGem0`1oOgl?0<SPf0<0
Q8B41023Ph<307moO`<0OGem1022PX8307alO0L0PH610`20P80307alO0<0Ogmo101mOGd307AdM0<0
P8201021PH4607moO`@0P8200`1nOWh60820P0@0OWin0`1oOgl30861P@@0O7al0`1nOWh307emO@@0
Q8B40`21PH4308>3P`@0Ogmo0`21PH440<SPf0<0KFe]101dM7@307moO`<0Ng]k1027QhL308J6QP<0
QhN70`2NWYh407alO0<0R8R80`1lO7`408F5Q@<0Ng]k0`1mOGd408N7Q`<0PX:20`28R8P408:2PP<0
NGUi0`26QXH307emO@@0QHF50`1hN7P30861P@@0Ogmo0`24Q8@307alO0@0Ng]k0`20P8030861P@<0
NGUi1020P80D0<SPf0004`38h=P307inOP@0Ogmo0`1nOWh307moO`@0PH610`1oOgl30820P0@0Ng]k
0`27QhL307YjNP<0O7al1022PX8307]kN`<0Q8B4101lO7`308:2PP<0PH611020P80307inOP<0P820
0`21PH4408:2PP<0MgMg0`1nOWh40820P0<0QXJ60`21PH440820P0<0OWin0`20P8040861P@<0OWin
1038h=P307moO`@0Q8B40`22PX8307inOP@0MgMg0`1jNWX308>3P`@0P8200`1cLg<308B4Q0<0MWIf
1021PH4307moO`<0OWin1026QXH307moO`<0QXJ6101kNg/30820P0<0O7al0`26QXH407QhN0H0O7al
1022PX8308F5Q@<0P8201022PX8308J6QP<0P820101oOgl307inOPl0b>3H0`23Ph<707moO`<0PH61
1028R8P308B4Q0<0OWin1021PH4308:2PP<0Ph>30`21PH440820P0<0Ph>30`1mOGd407inOP<0Ogmo
0`1mOGd407inOPH0P8200`22PX840861P@<0NGUi0`20P80407alO0H0P8201021PH4308:2PPL0PH61
0`20P8040<SPf0<0PX:21021PH430820P0<0Ogmo101lO7`308R8R0<0Ph>30`2>SXh409BDU0<0QXJ6
1`23Ph<308F5Q@<0MWIf101oOgl30861P@<0Ogmo1020P80307moO`<0QHF50`20P80708B4Q0<0NGUi
101mOGd307]kN`<0NGUi101jNWX308>3P`<0Q8B40`22PX8408R8R1@0b>3H000C0<SPf0<0OWin101o
Ogl307inOP<0Ogmo1021PH4307moO`<0P820101kNg/308N7Q`<0NWYj0`1lO7`408:2PP<0Ng]k0`24
Q8@407alO0<0PX:20`21PH440820P0<0OWin0`20P8030861P@@0PX:20`1gMgL307inOP@0P8200`26
QXH30861P@@0P8200`1nOWh30820P0@0PH610`1nOWh40<SPf0<0Ogmo1024Q8@308:2PP<0OWin101g
MgL307YjNP<0Ph>31020P80307=cL`<0Q8B40`1fMWH40861P@<0Ogmo0`1nOWh408J6QP<0Ogmo0`26
QXH407]kN`<0P8200`1lO7`308J6QP@0N7Qh1P1lO7`408:2PP<0QHF50`20P80408:2PP<0QXJ60`20
P80407moO`<0OWin3`38h=P308>3P`L0Ogmo0`21PH4408R8R0<0Q8B40`1nOWh40861P@<0PX:20`23
Ph<30861P@@0P8200`23Ph<307emO@@0OWin0`1oOgl307emO@@0OWin1P20P80308:2PP@0PH610`1i
NGT30820P0@0O7al1P20P8040861P@<0PX:21`21PH430820P0@0b>3H0`22PX840861P@<0P8200`1o
Ogl407alO0<0R8R80`23Ph<308j>SP@0U9BD0`26QXH708>3P`<0QHF50`1fMWH407moO`<0PH610`1o
Ogl40820P0<0Ogmo0`25QHD30820P0L0Q8B40`1iNGT407emO@<0Ng]k0`1iNGT407YjNP<0Ph>30`24
Q8@308:2PP@0R8R85038h=P001<0b>3H0`1nOWh407moO`<0OWin0`1oOgl40861P@<0Ogmo0`20P804
07]kN`<0QhN70`1jNWX307alO0@0PX:20`1kNg/308B4Q0@0O7al0`22PX830861P@@0P8200`1nOWh3
0820P0<0PH611022PX8307MgM`<0OWin1020P80308J6QP<0PH611020P80307inOP<0P8201021PH43
07inOP@0b>3H0`1oOgl408B4Q0<0PX:20`1nOWh407MgM`<0NWYj0`23Ph<40820P0<0Lg=c0`24Q8@3
07IfMP@0PH610`1oOgl307inOP@0QXJ60`1oOgl308J6QP@0Ng]k0`20P80307alO0<0QXJ6101hN7P6
07alO0@0PX:20`25QHD30820P0@0PX:20`26QXH30820P0@0Ogmo0`1nOWh?0<SPf0<0Ph>31`1oOgl3
0861P@@0R8R80`24Q8@307inOP@0PH610`22PX8308>3P`<0PH611020P80308>3P`<0OGem101nOWh3
07moO`<0OGem101nOWh60820P0<0PX:21021PH4307UiN@<0P820101lO7`60820P0@0PH610`22PX87
0861P@<0P8201038h=P308:2PP@0PH610`20P80307moO`@0O7al0`28R8P308>3P`<0SXj>102DU9@3
08J6QPL0Ph>30`25QHD307IfMP@0Ogmo0`21PH4307moO`@0P8200`1oOgl308F5Q@<0P8201`24Q8@3
07UiN@@0OGem0`1kNg/307UiN@@0NWYj0`23Ph<308B4Q0<0PX:21028R8PD0<SPf0004`38h=P307mo
O`@0OWin0`20P80307inOPL0P8200`1oOgl40861P@<0Ng]k0`21PH4307moO`@0O7al1P1oOgl40861
P@<0P8200`1lO7`408>3P`<0O7al0`1nOWh30861P@@0PX:20`1oOgl30820P0@0Ogmo0`20P80307em
O@@0PH610`20P80307moO`@0P8200`1nOWh40<SPf0L0Ogmo0`24Q8@308N7Q`@0N7Qh0`26QXH707mo
O`<0P8200`1iNGT307alO0@0Ogmo0`1mOGd308:2PPL0PH610`22PX8407UiN@<0Ph>30`1kNg/308>3
P`@0PX:20`24Q8@308>3P`@0OGem0`22PX8308N7Q`@0PH611P23Ph<408:2PP<0OGem3`38h=P708F5
Q@<0P8200`23Ph<407YjNP<0Ph>30`1hN7P408^;R`<0NGUi0`22PX8307emO@@0Ph>30`1nOWh308>3
P`@0NGUi1P21PH440820P0<0PH610`1mOGd308F5Q@L0PX:20`23Ph<407moO`<0PX:20`1lO7`407mo
O`<0P8200`1mOGd708>3P`@0b>3H0`1eMGD407QhN0<0PH610`1fMWH408:2PP<0PH610`1oOgl308^;
R`@0MGEe0`1aLG4308Z:RP@0O7al0`1oOgl308V9R@@0OWin0`1kNg/307YjNP@0OGem0`23Ph<307]k
N`<0RXZ:1021PH4307YjNP<0PH61101oOgl308F5Q@<0PX:21025QHD307moO`<0OWin0`1hN7P408:2
PQ@0b>3H000C0<SPf0<0Ogmo101nOWh30820P0<0OWin1`20P80307moO`@0PH610`1kNg/30861P@<0
Ogmo101lO7`607moO`@0PH610`20P80307alO0@0Ph>30`1lO7`307inOP<0PH611022PX8307moO`<0
P820101oOgl30820P0<0OGem1021PH430820P0<0Ogmo1020P80307inOP@0b>3H1`1oOgl308B4Q0<0
QhN7101hN7P308J6QPL0Ogmo0`20P80307UiN@<0O7al101oOgl307emO@<0PX:21`21PH4308:2PP@0
NGUi0`23Ph<307]kN`<0Ph>31022PX8308B4Q0<0Ph>3101mOGd308:2PP<0QhN71021PH4608>3P`@0
PX:20`1mOGd?0<SPf0L0QHF50`20P80308>3P`@0NWYj0`23Ph<307QhN0@0Rh^;0`1iNGT308:2PP<0
OGem1023Ph<307inOP<0Ph>3101iNGT60861P@@0P8200`21PH4307emO@<0QHF51`22PX8308>3P`@0
Ogmo0`22PX8307alO0@0Ogmo0`20P80307emO@L0Ph>31038h=P307EeM@@0N7Qh0`21PH4307IfMP@0
PX:20`21PH4307moO`<0Rh^;101eMGD3075aL@<0RXZ:101lO7`307moO`<0RHV9101nOWh307]kN`<0
NWYj101mOGd308>3P`<0Ng]k0`2:RXX40861P@<0NWYj0`21PH4407moO`<0QHF50`22PX8408F5Q@<0
Ogmo0`1nOWh307QhN0@0PX:25038h=P001<0b>3H0`1oOgl407inOP<0P8200`1nOWh70820P0<0Ogmo
1021PH4307]kN`<0PH610`1oOgl407alO0H0Ogmo1021PH430820P0<0O7al1023Ph<307alO0<0OWin
0`21PH4408:2PP<0Ogmo0`20P80407moO`<0P8200`1mOGd40861P@<0P8200`1oOgl40820P0<0OWin
1038h=P707moO`<0Q8B40`27QhL407QhN0<0QXJ61`1oOgl30820P0<0NGUi0`1lO7`407moO`<0OGem
0`22PX870861P@<0PX:2101iNGT308>3P`<0Ng]k0`23Ph<408:2PP<0Q8B40`23Ph<407emO@<0PX:2
0`27QhL40861P@H0Ph>31022PX8307emO@l0b>3H1`25QHD30820P0<0Ph>3101jNWX308>3P`<0N7Qh
102;Rh/307UiN@<0PX:20`1mOGd408>3P`<0OWin0`23Ph<407UiN@H0PH611020P8030861P@<0OGem
0`25QHD708:2PP<0Ph>3101oOgl308:2PP<0O7al101oOgl30820P0<0OGem1`23Ph<40<SPf0<0MGEe
101hN7P30861P@<0MWIf1022PX830861P@<0Ogmo0`2;Rh/407EeM@<0LG5a0`2:RXX407alO0<0Ogmo
0`29RHT407inOP<0Ng]k0`1jNWX407emO@<0Ph>30`1kNg/308Z:RP@0PH610`1jNWX30861P@@0Ogmo
0`25QHD308:2PP@0QHF50`1oOgl307inOP<0N7Qh1022PX8D0<SPf0004`38h=P307moO`@0OWin0`20
P80307inOPL0P8200`1oOgl40861P@<0Ng]k0`21PH4307moO`@0O7al1P1oOgl40861P@<0P8200`1l
O7`408>3P`<0O7al0`1nOWh30861P@@0PX:20`1oOgl30820P0@0Ogmo0`20P80307emO@@0PH610`20
P80307moO`@0P8200`1nOWh40<SPf0L0Ogmo0`24Q8@308N7Q`@0N7Qh0`26QXH707moO`<0P8200`1i
NGT307alO0@0Ogmo0`1mOGd308:2PPL0PH610`22PX8407UiN@<0Ph>30`1kNg/308>3P`@0PX:20`24
Q8@308>3P`@0OGem0`22PX8308N7Q`@0PH611P23Ph<408:2PP<0OGem3`38h=P708F5Q@<0P8200`23
Ph<407YjNP<0Ph>30`1hN7P408^;R`<0NGUi0`22PX8307emO@@0Ph>30`1nOWh308>3P`@0NGUi1P21
PH440820P0<0PH610`1mOGd308F5Q@L0PX:20`23Ph<407moO`<0PX:20`1lO7`407moO`<0P8200`1m
OGd708>3P`@0b>3H0`1eMGD407QhN0<0PH610`1fMWH408:2PP<0PH610`1oOgl308^;R`@0MGEe0`1a
LG4308Z:RP@0O7al0`1oOgl308V9R@@0OWin0`1kNg/307YjNP@0OGem0`23Ph<307]kN`<0RXZ:1021
PH4307YjNP<0PH61101oOgl308F5Q@<0PX:21025QHD307moO`<0OWin0`1hN7P408:2PQ@0b>3H000C
0<SPf0<0Ph>31020P80308F5Q@L0PH610`1mOGd307moO`@0NWYj0`23Ph<308B4Q0<0Ng]k1020P803
07inOP<0P820101mOGd308F5Q@<0OGem1023Ph<307]kN`<0PH610`1nOWh408>3P`<0PH611`1oOgl3
07inOP<0PX:2101kNg/307inOP<0Ogmo1`1nOWh40<SPf0<0MWIf1029RHT307EeM@<0P8201021PH43
07alO0X0PX:20`21PH4308B4Q0@0O7al0`1kNg/308F5Q@@0O7al0`1mOGd308:2PP@0PH610`1nOWh3
08R8R0<0O7al1`21PH4307EeM@@0Ph>31P1nOWh40861P@<0OWin0`22PX8407moO`<0PH613`38h=P3
0820P0@0Ph>30`20P80307emO@@0PH610`1nOWh308B4Q0@0O7al0`26QXH307moO`<0Q8B4101lO7`3
0861P@<0OWin1025QHD307emO@<0Ng]k1021PH4607inOP<0PH61101nOWh307]kN`<0P820101nOWh3
07emO@<0P820101oOgl607inOP@0P8200`21PH440<SPf0<0TI6A101kNg/307UiN@<0P8201029RHT3
07EeM@<0OWin0`23Ph<407IfMP<0KFe]0`27QhL407]kN`<0P8200`1eMGD408b<S0<0K6a/0`2?Shl4
07=cL`<0SXj>0`1fMWH308^;R`@0QXJ60`28R8P307alO0L0OGem0`25QHD408:2PP<0O7al0`1nOWh7
07alO1@0b>3H000C0<SPf0<0Ph>31020P80308F5Q@L0PH610`1mOGd307moO`@0NWYj0`23Ph<308B4
Q0<0Ng]k1020P80307inOP<0P820101mOGd308F5Q@<0OGem1023Ph<307]kN`<0PH610`1nOWh408>3
P`<0PH611`1oOgl307inOP<0PX:2101kNg/307inOP<0Ogmo1`1nOWh40<SPf0<0MWIf1029RHT307Ee
M@<0P8201021PH4307alO0X0PX:20`21PH4308B4Q0@0O7al0`1kNg/308F5Q@@0O7al0`1mOGd308:2
PP@0PH610`1nOWh308R8R0<0O7al1`21PH4307EeM@@0Ph>31P1nOWh40861P@<0OWin0`22PX8407mo
O`<0PH613`38h=P30820P0@0Ph>30`20P80307emO@@0PH610`1nOWh308B4Q0@0O7al0`26QXH307mo
O`<0Q8B4101lO7`30861P@<0OWin1025QHD307emO@<0Ng]k1021PH4607inOP<0PH61101nOWh307]k
N`<0P820101nOWh307emO@<0P820101oOgl607inOP@0P8200`21PH440<SPf0<0TI6A101kNg/307Ui
N@<0P8201029RHT307EeM@<0OWin0`23Ph<407IfMP<0KFe]0`27QhL407]kN`<0P8200`1eMGD408b<
S0<0K6a/0`2?Shl407=cL`<0SXj>0`1fMWH308^;R`@0QXJ60`28R8P307alO0L0OGem0`25QHD408:2
PP<0O7al0`1nOWh707alO1@0b>3H000C0<SPf0<0Ph>31020P80308F5Q@L0PH610`1mOGd307moO`@0
NWYj0`23Ph<308B4Q0<0Ng]k1020P80307inOP<0P820101mOGd308F5Q@<0OGem1023Ph<307]kN`<0
PH610`1nOWh408>3P`<0PH611`1oOgl307inOP<0PX:2101kNg/307inOP<0Ogmo1`1nOWh40<SPf0<0
MWIf1029RHT307EeM@<0P8201021PH4307alO0X0PX:20`21PH4308B4Q0@0O7al0`1kNg/308F5Q@@0
O7al0`1mOGd308:2PP@0PH610`1nOWh308R8R0<0O7al1`21PH4307EeM@@0Ph>31P1nOWh40861P@<0
OWin0`22PX8407moO`<0PH613`38h=P30820P0@0Ph>30`20P80307emO@@0PH610`1nOWh308B4Q0@0
O7al0`26QXH307moO`<0Q8B4101lO7`30861P@<0OWin1025QHD307emO@<0Ng]k1021PH4607inOP<0
PH61101nOWh307]kN`<0P820101nOWh307emO@<0P820101oOgl607inOP@0P8200`21PH440<SPf0<0
TI6A101kNg/307UiN@<0P8201029RHT307EeM@<0OWin0`23Ph<407IfMP<0KFe]0`27QhL407]kN`<0
P8200`1eMGD408b<S0<0K6a/0`2?Shl407=cL`<0SXj>0`1fMWH308^;R`@0QXJ60`28R8P307alO0L0
OGem0`25QHD408:2PP<0O7al0`1nOWh707alO1@0b>3H000C0<SPf0<0Ng]k1021PH4307inOP<0PH61
1020P80308>3P`<0P8201022PX830861P@<0Ng]k0`1oOgl408B4Q0<0O7al0`1nOWh40861P@<0P820
2P1nOWh307moO`<0OGem1021PH430820P0<0NGUi101mOGd307UiN@<0PH611020P80307inOP<0PX:2
101oOgl30820P0@0b>3H0`21PH4407EeM@<0QhN70`22PX8408B4Q0<0Ph>30`1mOGd407inOP<0P820
0`2;Rh/308J6QP@0Ogmo0`21PH4307inOP@0Ogmo0`20P80307YjNP@0Ph>30`1lO7`307moO`<0P820
1026QXH307AdM0<0Ng]k1020P80308Z:RP<0PH611020P80308>3P`<0PX:21023Ph<307moO`l0b>3H
0`1nOWh407alO0<0NWYj0`1lO7`40820P0<0Q8B40`1lO7`408:2PP<0Ogmo0`20P80307emO@@0P820
0`23Ph<307inOP@0P8200`21PH4308R8R0@0OWin0`21PH4307moO`L0P8200`23Ph<307]kN`@0P820
0`1nOWh308B4Q0@0PX:20`1oOgl308B4Q0L0OGem1038h=P3075aL@@0QhN70`1jNWX30820P0@0TY:B
0`1iNGT308n?S`<0Lg=c1020P80307alO0<0NWYj101gMgL307QhN0<0PH61101lO7`308F5Q@<0LG5a
102=SHd307MgM`<0Q8B40`1mOGd4092@T0<0S8b<0`2CTi<407emO@<0PX:20`20P80408N7Q`<0OGem
0`21PH4308R8R0@0PX:25038h=P001<0b>3H0`1kNg/40861P@<0OWin0`21PH440820P0<0Ph>30`20
P80408:2PP<0PH610`1kNg/307moO`@0Q8B40`1lO7`307inOP@0PH610`20P80:07inOP<0Ogmo0`1m
OGd40861P@<0P8200`1iNGT407emO@<0NGUi0`21PH440820P0<0OWin0`22PX8407moO`<0P8201038
h=P30861P@@0MGEe0`27QhL308:2PP@0Q8B40`23Ph<307emO@@0OWin0`20P80308^;R`<0QXJ6101o
Ogl30861P@<0OWin101oOgl30820P0<0NWYj1023Ph<307alO0<0Ogmo0`20P80408J6QP<0M7Ad0`1k
Ng/40820P0<0RXZ:0`21PH440820P0<0Ph>30`22PX8408>3P`<0Ogmo3`38h=P307inOP@0O7al0`1j
NWX307alO0@0P8200`24Q8@307alO0@0PX:20`1oOgl30820P0<0OGem1020P80308>3P`<0OWin1020
P8030861P@<0R8R8101nOWh30861P@<0Ogmo1`20P80308>3P`<0Ng]k1020P80307inOP<0Q8B41022
PX8307moO`<0Q8B41`1mOGd40<SPf0<0LG5a1027QhL307YjNP<0P820102BTY8307UiN@<0Shn?0`1c
Lg<40820P0<0O7al0`1jNWX407MgM`<0N7Qh0`21PH4407alO0<0QHF50`1aLG4408f=S@<0MgMg0`24
Q8@307emO@@0T92@0`2<S8`309>CT`@0OGem0`22PX830820P0@0QhN70`1mOGd30861P@<0R8R81022
PX8D0<SPf0004`38h=P307]kN`@0PH610`1nOWh30861P@@0P8200`23Ph<30820P0@0PX:20`21PH43
07]kN`<0Ogmo1024Q8@307alO0<0OWin1021PH430820P0X0OWin0`1oOgl307emO@@0PH610`20P803
07UiN@@0OGem0`1iNGT30861P@@0P8200`1nOWh308:2PP@0Ogmo0`20P8040<SPf0<0PH61101eMGD3
08N7Q`<0PX:21024Q8@308>3P`<0OGem101nOWh30820P0<0Rh^;0`26QXH407moO`<0PH610`1nOWh4
07moO`<0P8200`1jNWX408>3P`<0O7al0`1oOgl30820P0@0QXJ60`1dM7@307]kN`@0P8200`2:RXX3
0861P@@0P8200`23Ph<308:2PP@0Ph>30`1oOgl?0<SPf0<0OWin101lO7`307YjNP<0O7al1020P803
08B4Q0<0O7al1022PX8307moO`<0P8200`1mOGd40820P0<0Ph>30`1nOWh40820P0<0PH610`28R8P4
07inOP<0PH610`1oOgl70820P0<0Ph>30`1kNg/40820P0<0OWin0`24Q8@408:2PP<0Ogmo0`24Q8@7
07emO@@0b>3H0`1aLG4408N7Q`<0NWYj0`20P80409:BTP<0NGUi0`2?Shl307=cL`@0P8200`1lO7`3
07YjNP@0MgMg0`1hN7P30861P@@0O7al0`25QHD3075aL@@0SHf=0`1gMgL308B4Q0<0OGem102@T903
08b<S0<0Ti>C101mOGd308:2PP<0P8201027QhL307emO@<0PH610`28R8P408:2PQ@0b>3H000C0<SP
f0<0MGEe102:RXX30820P0<0PH611024Q8@307alO0<0Q8B4101oOgl307emO@<0PH610`20P80407em
O@<0PH610`1mOGd407inOP<0PH610`1nOWh40820P0<0Ng]k0`1oOgl30861P@@0Ogmo0`22PX8307Yj
NP@0Ph>31P1nOWh408:2PP<0Ogmo0`1mOGd707moO`@0b>3H0`2?Shl407QhN0<0O7al0`20P80406e]
K@<0QXJ60`22PX840820P0H0PH610`2>SXh407QhN0<0QhN70`21PH4407emO@<0Q8B40`1nOWh407Qh
N0<0QhN70`1oOgl308:2PP@0Ph>30`26QXH308:2PP@0Ogmo1P1mOGd40820P0<0Ogmo0`21PH440820
P0<0O7al3`38h=P307QhN0@0P8200`1mOGd308>3P`@0RXZ:0`22PX8307YjNP@0QHF50`23Ph<307al
O0<0Ogmo1020P80607inOP@0Ph>30`1nOWh307moO`@0SXj>0`1hN7P307moO`<0PH611022PX8307]k
N`<0RHV9101oOgl30861P@<0MgMg1021PH4307alO0<0PX:2101lO7`307moO`@0b>3H0`1]KFd407If
MP<0Q8B40`21PH4407emO@<0PX:21P1jNWX407inOP<0Ph>30`2LW9`407alO0<0Ng]k0`2:RXX407mo
O`<0PX:20`26QXH407IfMP<0S8b<0`1hN7P308B4Q0@0P8200`1gMgL308>3P`@0SHf=0`1lO7`308j>
SP@0OWin0`24Q8@307YjNP<0OWin1022PX8D0<SPf0004`38h=P307EeM@@0RXZ:0`20P8030861P@@0
Q8B40`1lO7`308B4Q0@0Ogmo0`1mOGd30861P@<0P820101mOGd30861P@<0OGem101nOWh30861P@<0
OWin1020P80307]kN`<0Ogmo0`21PH4407moO`<0PX:20`1jNWX408>3P`H0OWin1022PX8307moO`<0
OGem1`1oOgl40<SPf0<0Shn?101hN7P307alO0<0P820101]KFd308J6QP<0PX:21020P8060861P@<0
SXj>101hN7P308N7Q`<0PH61101mOGd308B4Q0<0OWin101hN7P308N7Q`<0Ogmo0`22PX8408>3P`<0
QXJ60`22PX8407moO`H0OGem1020P80307moO`<0PH611020P80307alO0l0b>3H0`1hN7P40820P0<0
OGem0`23Ph<408Z:RP<0PX:20`1jNWX408F5Q@<0Ph>30`1lO7`307moO`@0P8201P1nOWh408>3P`<0
OWin0`1oOgl408j>SP<0N7Qh0`1oOgl30861P@@0PX:20`1kNg/308V9R@@0Ogmo0`21PH4307MgM`@0
PH610`1lO7`308:2PP@0O7al0`1oOgl40<SPf0<0KFe]101fMWH308B4Q0<0PH61101mOGd308:2PPH0
NWYj101nOWh308>3P`<0W9bL101lO7`307]kN`<0RXZ:101oOgl308:2PP<0QXJ6101fMWH308b<S0<0
N7Qh0`24Q8@40820P0<0MgMg0`23Ph<408f=S@<0O7al0`2>SXh407inOP<0Q8B40`1jNWX307inOP@0
PX:25038h=P001<0b>3H0`1eMGD408Z:RP<0P8200`21PH4408B4Q0<0O7al0`24Q8@407moO`<0OGem
0`21PH430820P0@0OGem0`21PH4307emO@@0OWin0`21PH4307inOP@0P8200`1kNg/307moO`<0PH61
101oOgl308:2PP<0NWYj1023Ph<607inOP@0PX:20`1oOgl307emO@L0Ogmo1038h=P308n?S`@0N7Qh
0`1lO7`30820P0@0KFe]0`26QXH308:2PP@0P8201P21PH4308j>SP@0N7Qh0`27QhL30861P@@0OGem
0`24Q8@307inOP@0N7Qh0`27QhL307moO`<0PX:21023Ph<308J6QP<0PX:2101oOgl607emO@@0P820
0`1oOgl30861P@@0P8200`1lO7`?0<SPf0<0N7Qh1020P80307emO@<0Ph>3102:RXX308:2PP<0NWYj
1025QHD308>3P`<0O7al0`1oOgl40820P0H0OWin1023Ph<307inOP<0Ogmo102>SXh307QhN0<0Ogmo
0`21PH4408:2PP<0Ng]k0`29RHT407moO`<0PH610`1gMgL40861P@<0O7al0`22PX8407alO0<0Ogmo
1038h=P306e]K@@0MWIf0`24Q8@30861P@@0OGem0`22PX8607YjNP@0OWin0`23Ph<309bLW0@0O7al
0`1kNg/308Z:RP@0Ogmo0`22PX8308J6QP@0MWIf0`2<S8`307QhN0<0Q8B41020P80307MgM`<0Ph>3
102=SHd307alO0<0SXj>101nOWh308B4Q0<0NWYj0`1nOWh408:2PQ@0b>3H000C0<SPf0<0Ph>3101n
OWh308R8R0<0OGem101iNGT30861P@<0O7al101nOWh30861P@<0Ng]k0`1eMGD408F5Q@H0OWin1022
PX8307inOP<0Q8B4101mOGd308>3P`<0PH612P1oOgl307emO@@0P8200`21PH4307alO0@0P8200`23
Ph<30820P0@0OWin0`1oOgl40<SPf0<0QHF5101gMgL30820P0<0QXJ6101jNWX308>3P`<0Ogmo1020
P80307]kN`<0PH610`1gMgL407AdM0<0Ph>30`1kNg/40820P0<0PH610`1lO7`707YjNP<0QXJ60`1l
O7`407inOP<0R8R80`1hN7P408N7Q`<0P8200`1lO7`408V9R@<0OWin0`21PH4407alO0<0Ogmo3`38
h=P30861P@@0QXJ60`1lO7`307YjNP@0O7al0`1jNWX308:2PP@0NGUi0`1lO7`308:2PP<0QHF51023
Ph<608F5Q@@0Ogmo1P20P80407emO@<0RXZ:0`1lO7`308>3P`@0OGem0`1kNg/:0820P0<0SHf=101o
Ogl30861P@<0Ph>3101mOGd30820P0@0b>3H0`27QhL407MgM`<0PX:20`25QHD407QhN0<0QXJ60`1h
N7P308n?S`@0Lg=c0`2VYZH308^;R`@0WinO0`24Q8@307UiN@X0PX:21023Ph<307emO@<0Q8B40`1m
OGd408:2PP<0QXJ60`2:RXX407YjNP<0Jf][0`1oOgl407=cL`<0RHV91P1nOWh408>3Pa@0b>3H000C
0<SPf0<0Ph>3101nOWh308R8R0<0OGem101iNGT30861P@<0O7al101nOWh30861P@<0Ng]k0`1eMGD4
08F5Q@H0OWin1022PX8307inOP<0Q8B4101mOGd308>3P`<0PH612P1oOgl307emO@@0P8200`21PH43
07alO0@0P8200`23Ph<30820P0@0OWin0`1oOgl40<SPf0<0QHF5101gMgL30820P0<0QXJ6101jNWX3
08>3P`<0Ogmo1020P80307]kN`<0PH610`1gMgL407AdM0<0Ph>30`1kNg/40820P0<0PH610`1lO7`7
07YjNP<0QXJ60`1lO7`407inOP<0R8R80`1hN7P408N7Q`<0P8200`1lO7`408V9R@<0OWin0`21PH44
07alO0<0Ogmo3`38h=P30861P@@0QXJ60`1lO7`307YjNP@0O7al0`1jNWX308:2PP@0NGUi0`1lO7`3
08:2PP<0QHF51023Ph<608F5Q@@0Ogmo1P20P80407emO@<0RXZ:0`1lO7`308>3P`@0OGem0`1kNg/:
0820P0<0SHf=101oOgl30861P@<0Ph>3101mOGd30820P0@0b>3H0`27QhL407MgM`<0PX:20`25QHD4
07QhN0<0QXJ60`1hN7P308n?S`@0Lg=c0`2VYZH308^;R`@0WinO0`24Q8@307UiN@X0PX:21023Ph<3
07emO@<0Q8B40`1mOGd408:2PP<0QXJ60`2:RXX407YjNP<0Jf][0`1oOgl407=cL`<0RHV91P1nOWh4
08>3Pa@0b>3H000C0<SPf0<0Ph>3101nOWh308R8R0<0OGem101iNGT30861P@<0O7al101nOWh30861
P@<0Ng]k0`1eMGD408F5Q@H0OWin1022PX8307inOP<0Q8B4101mOGd308>3P`<0PH612P1oOgl307em
O@@0P8200`21PH4307alO0@0P8200`23Ph<30820P0@0OWin0`1oOgl40<SPf0<0QHF5101gMgL30820
P0<0QXJ6101jNWX308>3P`<0Ogmo1020P80307]kN`<0PH610`1gMgL407AdM0<0Ph>30`1kNg/40820
P0<0PH610`1lO7`707YjNP<0QXJ60`1lO7`407inOP<0R8R80`1hN7P408N7Q`<0P8200`1lO7`408V9
R@<0OWin0`21PH4407alO0<0Ogmo3`38h=P30861P@@0QXJ60`1lO7`307YjNP@0O7al0`1jNWX308:2
PP@0NGUi0`1lO7`308:2PP<0QHF51023Ph<608F5Q@@0Ogmo1P20P80407emO@<0RXZ:0`1lO7`308>3
P`@0OGem0`1kNg/:0820P0<0SHf=101oOgl30861P@<0Ph>3101mOGd30820P0@0b>3H0`27QhL407Mg
M`<0PX:20`25QHD407QhN0<0QXJ60`1hN7P308n?S`@0Lg=c0`2VYZH308^;R`@0WinO0`24Q8@307Ui
N@X0PX:21023Ph<307emO@<0Q8B40`1mOGd408:2PP<0QXJ60`2:RXX407YjNP<0Jf][0`1oOgl407=c
L`<0RHV91P1nOWh408>3Pa@0b>3H000C0<SPf0<0Ph>3101nOWh308R8R0<0OGem101iNGT30861P@<0
O7al101nOWh30861P@<0Ng]k0`1eMGD408F5Q@H0OWin1022PX8307inOP<0Q8B4101mOGd308>3P`<0
PH612P1oOgl307emO@@0P8200`21PH4307alO0@0P8200`23Ph<30820P0@0OWin0`1oOgl40<SPf0<0
QHF5101gMgL30820P0<0QXJ6101jNWX308>3P`<0Ogmo1020P80307]kN`<0PH610`1gMgL407AdM0<0
Ph>30`1kNg/40820P0<0PH610`1lO7`707YjNP<0QXJ60`1lO7`407inOP<0R8R80`1hN7P408N7Q`<0
P8200`1lO7`408V9R@<0OWin0`21PH4407alO0<0Ogmo3`38h=P30861P@@0QXJ60`1lO7`307YjNP@0
O7al0`1jNWX308:2PP@0NGUi0`1lO7`308:2PP<0QHF51023Ph<608F5Q@@0Ogmo1P20P80407emO@<0
RXZ:0`1lO7`308>3P`@0OGem0`1kNg/:0820P0<0SHf=101oOgl30861P@<0Ph>3101mOGd30820P0@0
b>3H0`27QhL407MgM`<0PX:20`25QHD407QhN0<0QXJ60`1hN7P308n?S`@0Lg=c0`2VYZH308^;R`@0
WinO0`24Q8@307UiN@X0PX:21023Ph<307emO@<0Q8B40`1mOGd408:2PP<0QXJ60`2:RXX407YjNP<0
Jf][0`1oOgl407=cL`<0RHV91P1nOWh408>3Pa@0b>3H000C0<SPf0<0QXJ6101lO7`30820P0<0QHF5
101kNg/30861P@<0OWin1023Ph<307]kN`<0Ph>30`20P80407]kN`<0OWin1`1oOgl307inOP<0PH61
101lO7`30820P0<0Ph>31`1oOgl307UiN@<0O7al101nOWh307alO0<0QhN7101oOgl307alO0L0P820
0`1nOWh40<SPf0<0MgMg1022PX830861P@<0Ng]k101_Kfl307moO`<0Q8B4101]KFd308j>SP<0K6a/
0`23Ph<407emO@<0NGUi1`21PH4308:2PP<0PH611026QXH307alO0<0Ph>30`22PX8407alO0<0Ogmo
0`1kNg/407emO@<0O7al0`1cLg<708>3P`<0OGem101oOgl30861P@l0b>3H0`1jNWX408N7Q`<0PX:2
0`29RHT40820P0H0Ng]k1022PX8307YjNP<0O7al0`20P80407moO`<0PX:20`1oOgl407inOP<0O7al
0`21PH4407moO`<0Ph>30`1fMWH308>3P`@0PX:20`1mOGd708:2PP<0Ogmo0`23Ph<40861P@<0Ogmo
0`1jNWX407emO@<0Ogmo1038h=P308V9R@@0NGUi0`1lO7`30820P0@0Q8B40`1nOWh307alO0<0P820
101oOgl307inOP<0NWYj101ZJVX306m_K`<0MWIf1028R8P308:2PP<0Ph>31024Q8@308N7Q`H0OWin
1026QXH608N7Q`@0Ng]k0`1hN7P307alO0@0Q8B41P1jNWX308J6QP@0PX:25038h=P001<0b>3H0`26
QXH407alO0<0P8200`25QHD407]kN`<0PH610`1nOWh408>3P`<0Ng]k0`23Ph<30820P0@0Ng]k0`1n
OWh707moO`<0OWin0`21PH4407alO0<0P8200`23Ph<707moO`<0NGUi0`1lO7`407inOP<0O7al0`27
QhL407moO`<0O7al1`20P80307inOP@0b>3H0`1gMgL408:2PP<0PH610`1kNg/406m_K`<0Ogmo0`24
Q8@406e]K@<0SXj>0`1/K6`308>3P`@0OGem0`1iNGT70861P@<0PX:20`21PH4408J6QP<0O7al0`23
Ph<308:2PP@0O7al0`1oOgl307]kN`@0OGem0`1lO7`307=cL`L0Ph>30`1mOGd407moO`<0PH613`38
h=P307YjNP@0QhN70`22PX8308V9R@@0P8201P1kNg/408:2PP<0NWYj0`1lO7`30820P0@0Ogmo0`22
PX8307moO`@0OWin0`1lO7`30861P@@0Ogmo0`23Ph<307IfMP<0Ph>31022PX8307emO@L0PX:20`1o
Ogl308>3P`@0PH610`1oOgl307YjNP@0OGem0`1oOgl40<SPf0<0RHV9101iNGT307alO0<0P8201024
Q8@307inOP<0O7al0`20P80407moO`<0OWin0`1jNWX406YZJP<0Kfm_0`1fMWH408R8R0<0PX:20`23
Ph<408B4Q0<0QhN71P1nOWh408J6QPH0QhN7101kNg/307QhN0<0O7al1024Q8@607YjNP<0QXJ61022
PX8D0<SPf0004`38h=P308J6QP@0O7al0`20P80308F5Q@@0Ng]k0`21PH4307inOP@0Ph>30`1kNg/3
08>3P`<0P820101kNg/307inOPL0Ogmo0`1nOWh30861P@@0O7al0`20P80308>3P`L0Ogmo0`1iNGT3
07alO0@0OWin0`1lO7`308N7Q`@0Ogmo0`1lO7`70820P0<0OWin1038h=P307MgM`@0PX:20`21PH43
07]kN`@0Kfm_0`1oOgl308B4Q0@0KFe]0`2>SXh306a/K0<0Ph>3101mOGd307UiN@L0PH610`22PX83
0861P@@0QXJ60`1lO7`308>3P`<0PX:2101lO7`307moO`<0Ng]k101mOGd307alO0<0Lg=c1`23Ph<3
07emO@@0Ogmo0`21PH4?0<SPf0<0NWYj1027QhL308:2PP<0RHV91020P80607]kN`@0PX:20`1jNWX3
07alO0<0P820101oOgl308:2PP<0Ogmo101nOWh307alO0<0PH61101oOgl308>3P`<0MWIf0`23Ph<4
08:2PP<0OGem1`22PX8307moO`<0Ph>31021PH4307moO`<0NWYj101mOGd307moO`@0b>3H0`29RHT4
07UiN@<0O7al0`20P80408B4Q0<0OWin0`1lO7`30820P0@0Ogmo0`1nOWh307YjNP@0JVYZ0`1_Kfl3
07IfMP@0R8R80`22PX8308>3P`@0Q8B40`27QhL607inOP@0QXJ61P27QhL407]kN`<0N7Qh0`1lO7`4
08B4Q0H0NWYj0`26QXH408:2PQ@0b>3H000C0<SPf0<0QXJ6101hN7P30820P0<0NWYj1021PH4307]k
N`<0PX:21020P8030861P@<0Ng]k0`2<S8`407inOP<0P8200`1mOGd40861P@<0Ogmo0`20P80407em
O@<0Ogmo1P20P80407moO`<0PX:20`21PH4407inOP<0Ph>30`21PH440820P0H0Ogmo1020P80307mo
O`@0b>3H0`24Q8@707UiN@<0OGem1025QHD307MgM`<0Ph>3102=SHd3071`L0<0QHF50`20P80407Yj
NP<0SHf=0`1hN7P407YjNP<0PX:20`24Q8@40820P0<0Ph>30`1lO7`308:2PP@0Ng]k0`22PX830820
P0@0OGem0`1lO7`307inOP@0PH611P1oOgl408:2PP<0Ogmo3`38h=P308N7Q`@0NWYj0`24Q8@307Mg
M`@0QHF50`1oOgl70820P0<0NGUi0`23Ph<307moO`@0NWYj0`1kNg/707moO`<0PX:20`1lO7`40820
P0<0Ph>31P1kNg/707moO`L0OWin0`23Ph<307MgM`@0QXJ60`1oOgl308>3P`@0OWin0`20P8040<SP
f0<0Ogmo101_Kfl308^;R`L0N7Qh0`23Ph<307IfMP<0MgMg101nOWh307alO0<0PH61101jNWX30820
P0<0NWYj102<S8`307QhN0<0PH61101oOgl307UiN@<0OGem0`1nOWh407moO`<0NGUi1`22PX8307Qh
N0<0NGUi1`20P80307emO@<0PX:21021PH4D0<SPf0004`38h=P308J6QP@0N7Qh0`20P80307YjNP@0
PH610`1kNg/308:2PP@0P8200`21PH4307]kN`<0S8b<101nOWh30820P0<0OGem1021PH4307moO`<0
P820101mOGd307moO`H0P820101oOgl308:2PP<0PH61101nOWh308>3P`<0PH611020P80607moO`@0
P8200`1oOgl40<SPf0<0Q8B41`1iNGT307emO@@0QHF50`1gMgL308>3P`@0SHf=0`1`L70308F5Q@<0
P820101jNWX308f=S@<0N7Qh101jNWX308:2PP<0Q8B41020P80308>3P`<0O7al0`22PX8407]kN`<0
PX:20`20P80407emO@<0O7al0`1nOWh40861P@H0Ogmo1022PX8307moO`l0b>3H0`27QhL407YjNP<0
Q8B40`1gMgL408F5Q@<0Ogmo1`20P80307UiN@<0Ph>30`1oOgl407YjNP<0Ng]k1`1oOgl308:2PP<0
O7al1020P80308>3P`H0Ng]k1`1oOgl707inOP<0Ph>30`1gMgL408J6QP<0Ogmo0`23Ph<407inOP<0
P8201038h=P307moO`@0Kfm_0`2;Rh/707QhN0<0Ph>30`1fMWH307MgM`@0OWin0`1lO7`30861P@@0
NWYj0`20P80307YjNP@0S8b<0`1hN7P30861P@@0Ogmo0`1iNGT307emO@<0OWin101oOgl307UiN@L0
PX:20`1hN7P307UiN@L0P8200`1mOGd308:2PP@0PH615038h=P001<0b>3H0`26QXH407QhN0<0P820
0`1jNWX40861P@<0Ng]k0`22PX840820P0<0PH610`1kNg/308b<S0@0OWin0`20P80307emO@@0PH61
0`1oOgl30820P0@0OGem0`1oOgl60820P0@0Ogmo0`22PX830861P@@0OWin0`23Ph<30861P@@0P820
1P1oOgl40820P0<0Ogmo1038h=P308B4Q0L0NGUi0`1mOGd408F5Q@<0MgMg0`23Ph<408f=S@<0L71`
0`25QHD30820P0@0NWYj0`2=SHd307QhN0@0NWYj0`22PX8308B4Q0@0P8200`23Ph<307alO0<0PX:2
101kNg/308:2PP<0P820101mOGd307alO0<0OWin1021PH4607moO`@0PX:20`1oOgl?0<SPf0<0QhN7
101jNWX308B4Q0<0MgMg1025QHD307moO`L0P8200`1iNGT308>3P`<0Ogmo101jNWX307]kN`L0Ogmo
0`22PX8307alO0@0P8200`23Ph<607]kN`L0Ogmo1`1nOWh308>3P`<0MgMg1026QXH307moO`<0Ph>3
101nOWh30820P0@0b>3H0`1oOgl406m_K`<0Rh^;1`1hN7P308>3P`<0MWIf0`1gMgL407inOP<0O7al
0`21PH4407YjNP<0P8200`1jNWX408b<S0<0N7Qh0`21PH4407moO`<0NGUi0`1mOGd307inOP@0Ogmo
0`1iNGT708:2PP<0N7Qh0`1iNGT70820P0<0OGem0`22PX840861PA@0b>3H000C0<SPf0<0QhN71022
PX830861P@<0NWYj1020P8030861P@<0P820101nOWh309>CT`<0Shn?0`1oOgl408B4Q0<0N7Qh0`25
QHD407YjNP<0Ph>30`20P80707inOPH0PH611020P80308:2PP<0OWin101mOGd307inOP<0P820101o
Ogl307inOP<0Ogmo1020P80307moO`@0b>3H0`20P8040861P@<0NGUi0`25QHD40820P0<0OWin0`22
PX8406][J`<0QHF50`24Q8@309RHV0@0QHF50`1nOWh307emO@@0QHF50`21PH4307YjNP@0N7Qh0`1j
NWX307alO0<0Ng]k1`1oOgl308F5Q@@0Q8B40`1jNWX308>3P`@0OGem0`1oOgl30820P0@0Ogmo0`24
Q8@?0<SPf0<0OGem1025QHD307YjNP<0Q8B4101nOWh307]kN`<0QHF51`1lO7`308:2PP<0Ph>31026
QXH308n?S`<0OGem1024Q8@307emO@<0Ph>31`1oOgl30820P0<0OWin101oOgl307emO@<0Ogmo1020
P80307emO@<0Ph>3101mOGd30861P@<0OWin1`21PH440<SPf0<0OGem1025QHD307UiN@<0MWIf101j
NWX607emO@<0SXj>101dM7@3079bLP<0IfMW101eMGD30:FUY@<0MGEe101mOGd607alO0@0M7Ad0`23
Ph<608:2PP@0QXJ60`1hN7P307IfMP@0PH610`1jNWX308R8R0@0NWYj0`22PX8307emO@<0QXJ6101n
OWhD0<SPf0004`38h=P308N7Q`@0PX:20`21PH4307YjNP@0P8200`21PH430820P0@0OWin0`2CTi<3
08n?S`<0Ogmo1024Q8@307QhN0<0QHF5101jNWX308>3P`<0P8201`1nOWh60861P@@0P8200`22PX83
07inOP@0OGem0`1nOWh30820P0@0Ogmo0`1nOWh307moO`@0P8200`1oOgl40<SPf0<0P8201021PH43
07UiN@<0QHF51020P80307inOP<0PX:2101[Jf/308F5Q@<0Q8B40`2HV9P408F5Q@<0OWin0`1mOGd4
08F5Q@<0PH610`1jNWX407QhN0<0NWYj0`1lO7`307]kN`L0Ogmo0`25QHD408B4Q0<0NWYj0`23Ph<4
07emO@<0Ogmo0`20P80407moO`<0Q8B43`38h=P307emO@@0QHF50`1jNWX308B4Q0@0OWin0`1kNg/3
08F5Q@L0O7al0`22PX8308>3P`@0QXJ60`2?Shl307emO@@0Q8B40`1mOGd308>3P`L0Ogmo0`20P803
07inOP@0Ogmo0`1mOGd307moO`@0P8200`1mOGd308>3P`@0OGem0`21PH4307inOPL0PH611038h=P3
07emO@@0QHF50`1iNGT307IfMP@0NWYj1P1mOGd308j>SP@0M7Ad0`1bLW8306MWI`@0MGEe0`2UYJD3
07EeM@@0OGem1P1lO7`407AdM0<0Ph>31P22PX8408J6QP<0N7Qh0`1fMWH40861P@<0NWYj0`28R8P4
07YjNP<0PX:20`1mOGd308J6QP@0OWin5038h=P001<0b>3H0`27QhL408:2PP<0PH610`1jNWX40820
P0<0PH610`20P80407inOP<0Ti>C0`2?Shl307moO`@0Q8B40`1hN7P308F5Q@@0NWYj0`23Ph<30820
P0L0OWin1P21PH440820P0<0PX:20`1nOWh407emO@<0OWin0`20P80407moO`<0OWin0`1oOgl40820
P0<0Ogmo1038h=P30820P0@0PH610`1iNGT308F5Q@@0P8200`1nOWh308:2PP@0Jf][0`25QHD308B4
Q0<0V9RH1025QHD307inOP<0OGem1025QHD30861P@<0NWYj101hN7P307YjNP<0O7al0`1kNg/707mo
O`<0QHF51024Q8@307YjNP<0Ph>3101mOGd307moO`<0P820101oOgl308B4Q0l0b>3H0`1mOGd408F5
Q@<0NWYj0`24Q8@407inOP<0Ng]k0`25QHD707alO0<0PX:20`23Ph<408J6QP<0Shn?0`1mOGd408B4
Q0<0OGem0`23Ph<707moO`<0P8200`1nOWh407moO`<0OGem0`1oOgl40820P0<0OGem0`23Ph<407em
O@<0PH610`1nOWh70861P@@0b>3H0`1mOGd408F5Q@<0NGUi0`1fMWH407YjNPH0OGem0`2>SXh407Ad
M0<0LW9b0`1WIfL407EeM@<0YJFU0`1eMGD407emO@H0O7al101dM7@308>3P`H0PX:21026QXH307Qh
N0<0MWIf1021PH4307YjNP<0R8R8101jNWX308:2PP<0OGem0`26QXH407inOQ@0b>3H000C0<SPf0<0
NWYj1022PX830861P@<0OWin1023Ph<307]kN`<0Q8B4101]KFd308>3P`<0R8R80`1lO7`408>3P`<0
Q8B40`1kNg/408B4Q0<0O7al0`1mOGd707moO`<0P8200`1nOWh407moO`<0PH610`1kNg/:0820P0L0
Ogmo0`20P80407moO`<0P8201038h=P307QhN0@0KVi^0`22PX8308J6QP@0MgMg0`22PX8307emO@@0
QHF50`20P80307emO@<0MWIf1026QXH307alO0<0NWYj101iNGT308:2PP<0Ng]k1`1nOWh30861P@<0
Ph>31020P80307moO`<0P8201023Ph<30861P@<0OWin1020P80308>3P`<0OWin101oOgl30820P0l0
b>3H0`21PH4407YjNP<0Ogmo0`1nOWh408B4Q0<0P8200`22PX8407inOP<0PX:20`1mOGd307IfMP@0
O7al0`1kNg/307AdM0@0OWin0`1kNg/307emO@@0Ph>30`21PH4307emO@<0P820101nOWh308>3P`<0
O7al101oOgl308:2PP<0Ogmo1022PX8307]kN`<0P820101mOGd307moO`@0b>3H0`1kNg/40820P0<0
QhN70`1]KFd408B4Q0<0RHV90`1cLg<3096AT@@0OGem0`23Ph<306MWI`@0R8R80`1eMGD30820P0@0
RXZ:0`2;Rh/307alO0@0P8200`1nOWh30820P0<0Q8B41026QXH307inOP<0Ogmo1023Ph<30861P@<0
MgMg1021PH4307YjNP<0OGem0`20P80407inOQ@0b>3H000C0<SPf0<0NWYj1022PX830861P@<0OWin
1023Ph<307]kN`<0Q8B4101]KFd308>3P`<0R8R80`1lO7`408>3P`<0Q8B40`1kNg/408B4Q0<0O7al
0`1mOGd707moO`<0P8200`1nOWh407moO`<0PH610`1kNg/:0820P0L0Ogmo0`20P80407moO`<0P820
1038h=P307QhN0@0KVi^0`22PX8308J6QP@0MgMg0`22PX8307emO@@0QHF50`20P80307emO@<0MWIf
1026QXH307alO0<0NWYj101iNGT308:2PP<0Ng]k1`1nOWh30861P@<0Ph>31020P80307moO`<0P820
1023Ph<30861P@<0OWin1020P80308>3P`<0OWin101oOgl30820P0l0b>3H0`21PH4407YjNP<0Ogmo
0`1nOWh408B4Q0<0P8200`22PX8407inOP<0PX:20`1mOGd307IfMP@0O7al0`1kNg/307AdM0@0OWin
0`1kNg/307emO@@0Ph>30`21PH4307emO@<0P820101nOWh308>3P`<0O7al101oOgl308:2PP<0Ogmo
1022PX8307]kN`<0P820101mOGd307moO`@0b>3H0`1kNg/40820P0<0QhN70`1]KFd408B4Q0<0RHV9
0`1cLg<3096AT@@0OGem0`23Ph<306MWI`@0R8R80`1eMGD30820P0@0RXZ:0`2;Rh/307alO0@0P820
0`1nOWh30820P0<0Q8B41026QXH307inOP<0Ogmo1023Ph<30861P@<0MgMg1021PH4307YjNP<0OGem
0`20P80407inOQ@0b>3H000C0<SPf0<0NWYj1022PX830861P@<0OWin1023Ph<307]kN`<0Q8B4101]
KFd308>3P`<0R8R80`1lO7`408>3P`<0Q8B40`1kNg/408B4Q0<0O7al0`1mOGd707moO`<0P8200`1n
OWh407moO`<0PH610`1kNg/:0820P0L0Ogmo0`20P80407moO`<0P8201038h=P307QhN0@0KVi^0`22
PX8308J6QP@0MgMg0`22PX8307emO@@0QHF50`20P80307emO@<0MWIf1026QXH307alO0<0NWYj101i
NGT308:2PP<0Ng]k1`1nOWh30861P@<0Ph>31020P80307moO`<0P8201023Ph<30861P@<0OWin1020
P80308>3P`<0OWin101oOgl30820P0l0b>3H0`21PH4407YjNP<0Ogmo0`1nOWh408B4Q0<0P8200`22
PX8407inOP<0PX:20`1mOGd307IfMP@0O7al0`1kNg/307AdM0@0OWin0`1kNg/307emO@@0Ph>30`21
PH4307emO@<0P820101nOWh308>3P`<0O7al101oOgl308:2PP<0Ogmo1022PX8307]kN`<0P820101m
OGd307moO`@0b>3H0`1kNg/40820P0<0QhN70`1]KFd408B4Q0<0RHV90`1cLg<3096AT@@0OGem0`23
Ph<306MWI`@0R8R80`1eMGD30820P0@0RXZ:0`2;Rh/307alO0@0P8200`1nOWh30820P0<0Q8B41026
QXH307inOP<0Ogmo1023Ph<30861P@<0MgMg1021PH4307YjNP<0OGem0`20P80407inOQ@0b>3H000C
0<SPf0<0NWYj1`20P80307QhN0@0Ph>30`1mOGd307moO`@0PX:20`2=SHd308:2PP<0Ng]k1022PX83
0861P@<0O7al1`1oOgl30820P0@0PX:20`1mOGd307moO`<0OWin1022PX8307alO0<0PX:21020P803
07emO@<0PH612P20P8040861P@<0P8201038h=P306][J`@0Ph>30`1lO7`308F5Q@@0Q8B40`1kNg/3
08N7Q`@0Ng]k0`20P80307moO`<0Rh^;101fMWH307inOP<0UIFE1021PH4307UiN@<0Ph>3101hN7P3
08>3P`X0PX:20`21PH4308:2PP@0P8201P22PX8408J6QP<0PX:20`1oOgl407inOP<0O7al3`38h=P3
07MgM`@0OWin0`1kNg/708B4Q0<0Ng]k0`21PH4407UiN@<0OWin0`1gMgL308>3P`L0P8200`26QXH4
08N7Q`<0PX:20`21PH4407moO`<0PH611P1oOgl408B4Q0<0OWin0`20P80408:2PP<0OWin0`1oOgl4
08B4Q0<0Ph>30`1mOGd408B4Q0<0Ogmo1038h=P307IfMP@0O7al0`2?Shl3092@T0@0O7al0`2@T903
07moO`<0P8201028R8P30820P0<0T92@101iNGT30820P0<0Shn?102CTi<307YjNP<0M7Ad1025QHD3
0820P0H0PH611028R8P307emO@L0OWin0`1mOGd308:2PP@0OGem1P21PH430820P0@0OGem5038h=P0
01<0b>3H0`1jNWX70820P0<0N7Qh1023Ph<307emO@<0Ogmo1022PX8308f=S@<0PX:20`1kNg/408:2
PP<0PH610`1lO7`707moO`<0P8201022PX8307emO@<0Ogmo0`1nOWh408:2PP<0O7al0`22PX840820
P0<0OGem0`21PH4:0820P0@0PH610`20P8040<SPf0<0Jf][1023Ph<307alO0<0QHF51024Q8@307]k
N`<0QhN7101kNg/30820P0<0Ogmo0`2;Rh/407IfMP<0OWin0`2EUID40861P@<0NGUi0`23Ph<407Qh
N0<0Ph>32P22PX830861P@<0PX:21020P80608:2PP@0QXJ60`22PX8307moO`@0OWin0`1lO7`?0<SP
f0<0MgMg101nOWh307]kN`L0Q8B40`1kNg/30861P@@0NGUi0`1nOWh307MgM`<0Ph>31`20P80308J6
QP@0QhN70`22PX830861P@@0Ogmo0`21PH4607moO`@0Q8B40`1nOWh30820P0@0PX:20`1nOWh307mo
O`@0Q8B40`23Ph<307emO@@0Q8B40`1oOgl40<SPf0<0MWIf101lO7`308n?S`<0T92@101lO7`3092@
T0<0Ogmo0`20P80408R8R0<0P8200`2@T90407UiN@<0P8200`2?Shl409>CT`<0NWYj0`1dM7@408F5
Q@<0P8201P21PH4408R8R0<0OGem1`1nOWh307emO@<0PX:2101mOGd60861P@<0P820101mOGdD0<SP
f0004`38h=P307YjNPL0P8200`1hN7P408>3P`<0OGem0`1oOgl408:2PP<0SHf=0`22PX8307]kN`@0
PX:20`21PH4307alO0L0Ogmo0`20P80408:2PP<0OGem0`1oOgl307inOP@0PX:20`1lO7`308:2PP@0
P8200`1mOGd30861P@X0P8201021PH430820P0@0b>3H0`1[Jf/408>3P`<0O7al0`25QHD408B4Q0<0
Ng]k0`27QhL407]kN`<0P8200`1oOgl308^;R`@0MWIf0`1nOWh309FEU@@0PH610`1iNGT308>3P`@0
N7Qh0`23Ph<:08:2PP<0PH610`22PX840820P0H0PX:21026QXH308:2PP<0Ogmo101nOWh307alO0l0
b>3H0`1gMgL407inOP<0Ng]k1`24Q8@307]kN`<0PH61101iNGT307inOP<0MgMg0`23Ph<70820P0<0
QXJ61027QhL308:2PP<0PH61101oOgl30861P@H0Ogmo1024Q8@307inOP<0P8201022PX8307inOP<0
Ogmo1024Q8@308>3P`<0OGem1024Q8@307moO`@0b>3H0`1fMWH407alO0<0Shn?0`2@T90407alO0<0
T92@0`1oOgl30820P0@0R8R80`20P803092@T0@0NGUi0`20P80308n?S`@0Ti>C0`1jNWX307AdM0@0
QHF50`20P8060861P@@0R8R80`1mOGd707inOP<0OGem0`22PX8407emO@H0PH610`20P80407emOA@0
b>3H000C0<SPf0<0NWYj1`20P80307QhN0@0Ph>30`1mOGd307moO`@0PX:20`2=SHd308:2PP<0Ng]k
1022PX830861P@<0O7al1`1oOgl30820P0@0PX:20`1mOGd307moO`<0OWin1022PX8307alO0<0PX:2
1020P80307emO@<0PH612P20P8040861P@<0P8201038h=P306][J`@0Ph>30`1lO7`308F5Q@@0Q8B4
0`1kNg/308N7Q`@0Ng]k0`20P80307moO`<0Rh^;101fMWH307inOP<0UIFE1021PH4307UiN@<0Ph>3
101hN7P308>3P`X0PX:20`21PH4308:2PP@0P8201P22PX8408J6QP<0PX:20`1oOgl407inOP<0O7al
3`38h=P307MgM`@0OWin0`1kNg/708B4Q0<0Ng]k0`21PH4407UiN@<0OWin0`1gMgL308>3P`L0P820
0`26QXH408N7Q`<0PX:20`21PH4407moO`<0PH611P1oOgl408B4Q0<0OWin0`20P80408:2PP<0OWin
0`1oOgl408B4Q0<0Ph>30`1mOGd408B4Q0<0Ogmo1038h=P307IfMP@0O7al0`2?Shl3092@T0@0O7al
0`2@T90307moO`<0P8201028R8P30820P0<0T92@101iNGT30820P0<0Shn?102CTi<307YjNP<0M7Ad
1025QHD30820P0H0PH611028R8P307emO@L0OWin0`1mOGd308:2PP@0OGem1P21PH430820P0@0OGem
5038h=P001<0b>3H0`21PH440820P0<0O7al0`24Q8@407emO@<0Ph>30`1fMWH70861P@<0O7al0`2<
S8`407QhN0<0Ph>30`1oOgl70820P0<0O7al101nOWh607moO`<0P8201029RHT307UiN@<0OWin101o
Ogl307inOP<0Ph>3101oOgl307emO@<0PX:21020P80307moO`@0b>3H0`20P80407MgM`<0Q8B40`2;
Rh/407moO`<0QXJ60`1jNWX408B4Q0<0MgMg0`2:RXX306m_K`@0Q8B40`2;Rh/308>3P`@0N7Qh0`2>
SXh307alO0@0Ogmo0`1kNg/308N7Q`<0Ogmo1023Ph<307moO`<0Ng]k1024Q8@307alO0<0PH611027
QhL308>3P`<0OWin1021PH4307moO`l0b>3H0`22PX840861P@<0Ng]k0`1hN7P407moO`<0OWin0`26
QXH408>3P`<0PH610`22PX8307alO0@0Ph>30`22PX8308B4Q0@0M7Ad0`1bLW8308F5Q@@0Ogmo0`20
P80307moO`L0P8200`22PX830861P@@0Ogmo0`1nOWh308:2PP@0PH613@1mOGd40<SPf0<0MGEe1020
P80308:2PP<0QhN7101lO7`308n?S`<0Q8B40`1fMWH408>3P`<0QhN70`22PX8408B4Q0<0PX:20`27
QhL407AdM0<0S8b<0`29RHT40861P@<0Rh^;0`1hN7P307UiN@@0NWYj0`1mOGd30861P@@0O7al0`1m
OGd307UiN@@0Ph>30`1mOGd30861P@<0Ogmo1020P80D0<SPf0004`38h=P30861P@@0P8200`1lO7`3
08B4Q0@0OGem0`23Ph<307IfMPL0PH610`1lO7`308b<S0@0N7Qh0`23Ph<307moO`L0P8200`1lO7`4
07inOPH0Ogmo0`20P80408V9R@<0NGUi0`1nOWh407moO`<0OWin0`23Ph<407moO`<0OGem0`22PX84
0820P0<0Ogmo1038h=P30820P0@0MgMg0`24Q8@308^;R`@0Ogmo0`26QXH307YjNP@0Q8B40`1gMgL3
08Z:RP<0Kfm_1024Q8@308^;R`<0Ph>3101hN7P308j>SP<0O7al101oOgl307]kN`<0QhN70`1oOgl4
08>3P`<0Ogmo0`1kNg/408B4Q0<0O7al0`21PH4408N7Q`<0Ph>30`1nOWh40861P@<0Ogmo3`38h=P3
08:2PP@0PH610`1kNg/307QhN0@0Ogmo0`1nOWh308J6QP@0Ph>30`21PH4308:2PP<0O7al1023Ph<3
08:2PP<0Q8B4101dM7@3079bLP<0QHF5101oOgl30820P0<0Ogmo1`20P80308:2PP<0PH61101oOgl3
07inOP<0PX:21021PH4=07emO@@0b>3H0`1eMGD40820P0<0PX:20`27QhL407alO0<0Shn?0`24Q8@3
07IfMP@0Ph>30`27QhL308:2PP@0Q8B40`22PX8308N7Q`@0M7Ad0`2<S8`308V9R@@0PH610`2;Rh/3
07QhN0<0NGUi101jNWX307emO@<0PH61101lO7`307emO@<0NGUi1023Ph<307emO@<0PH610`1oOgl4
0820P1@0b>3H000C0<SPf0<0PH611020P80307alO0<0Q8B4101mOGd308>3P`<0MWIf1`21PH4307al
O0<0S8b<101hN7P308>3P`<0Ogmo1`20P80307alO0@0OWin1P1oOgl30820P0@0RHV90`1iNGT307in
OP@0Ogmo0`1nOWh308>3P`@0Ogmo0`1mOGd308:2PP@0P8200`1oOgl40<SPf0<0P820101gMgL308B4
Q0<0Rh^;101oOgl308J6QP<0NWYj1024Q8@307MgM`<0RXZ:0`1_Kfl408B4Q0<0Rh^;0`23Ph<407Qh
N0<0SXj>0`1lO7`407moO`<0Ng]k0`27QhL307moO`@0Ph>30`1oOgl307]kN`@0Q8B40`1lO7`30861
P@@0QhN70`23Ph<307inOP@0PH610`1oOgl?0<SPf0<0PX:21021PH4307]kN`<0N7Qh101oOgl307in
OP<0QXJ61023Ph<30861P@<0PX:20`1lO7`408>3P`<0PX:20`24Q8@407AdM0<0LW9b0`25QHD407mo
O`<0P8200`1oOgl70820P0<0PX:20`21PH4407moO`<0OWin0`22PX840861P@d0OGem1038h=P307Ee
M@@0P8200`22PX8308N7Q`@0O7al0`2?Shl308B4Q0<0MWIf1023Ph<308N7Q`<0PX:21024Q8@308:2
PP<0QhN7101dM7@308b<S0<0RHV91021PH4308^;R`<0N7Qh0`1iNGT407YjNP<0OGem0`21PH4407al
O0<0OGem0`1iNGT408>3P`<0OGem0`21PH4307moO`@0P8205038h=P001<0b>3H0`24Q8@407emO@<0
Ph>30`1kNg/408B4Q0<0Ogmo0`1nOWh40820P0<0PX:20`1lO7`308B4Q0@0QHF50`24Q8@307=cL`@0
PH610`1hN7P30820P0@0OWin0`22PX830861P@<0Ogmo1022PX830861P@L0Ogmo0`20P80307inOPL0
Ogmo0`20P8040861P@<0P8201038h=P307IfMP@0QHF50`21PH4308J6QP@0P8201P25QHD408J6QP<0
R8R80`1oOgl:0820P0<0M7Ad1028R8P307inOP<0Ng]k1020P8030861P@<0PX:20`23Ph<407alO0<0
P8200`1iNGT40820P0<0PH610`1nOWh408F5Q@<0Ogmo0`20P80407inOP<0PX:23`38h=P307moO`@0
Ph>32P21PH4308:2PP<0Ogmo101fMWH308:2PP<0Ogmo0`20P80407inOP<0P8200`1mOGd408F5Q@<0
PX:20`1mOGd407alO0<0PX:20`1oOgl307YjNP@0PH610`1lO7`30861P@@0Ogmo1P22PX8407moO`H0
P820101nOWh307moO`@0b>3H0`1fMWH408J6QP<0MgMg0`28R8P408>3P`<0R8R80`29RHT308f=S@@0
P8200`1jNWX308f=S@L0RXZ:0`1oOgl40861P@<0MWIf0`1nOWh407moO`<0Ng]k1P26QXH40820P0<0
Ng]k1`20P80307moO`<0QHF5101kNg/308>3P`<0Q8B41`21PH4D0<SPf0004`38h=P308B4Q0@0OGem
0`23Ph<307]kN`@0Q8B40`1oOgl307inOP@0P8200`22PX8307alO0<0Q8B41025QHD308B4Q0<0Lg=c
1021PH4307QhN0<0P820101nOWh308:2PP<0PH610`1oOgl408:2PP<0PH611`1oOgl30820P0<0OWin
1`1oOgl30820P0@0PH610`20P8040<SPf0<0MWIf1025QHD30861P@<0QXJ61020P80608F5Q@@0QXJ6
0`28R8P307moO`X0P8200`1dM7@408R8R0<0OWin0`1kNg/40820P0<0PH610`22PX8308>3P`@0O7al
0`20P80307UiN@@0P8200`21PH4307inOP@0QHF50`1oOgl30820P0@0OWin0`22PX8?0<SPf0<0Ogmo
1023Ph<:0861P@<0PX:20`1oOgl407IfMP<0PX:20`1oOgl30820P0@0OWin0`20P80307emO@@0QHF5
0`22PX8307emO@@0O7al0`22PX8307moO`<0NWYj1021PH4307alO0<0PH61101oOgl608:2PP@0Ogmo
1P20P80407inOP<0Ogmo1038h=P307IfMP@0QXJ60`1gMgL308R8R0@0Ph>30`28R8P308V9R@<0SHf=
1020P80307YjNP<0SHf=1`2:RXX307moO`@0PH610`1fMWH307inOP@0Ogmo0`1kNg/608J6QP@0P820
0`1kNg/70820P0<0Ogmo0`25QHD407]kN`<0Ph>30`24Q8@70861PA@0b>3H000C0<SPf0<0Q8B4101m
OGd308>3P`<0Ng]k1024Q8@307moO`<0OWin1020P80308:2PP<0O7al0`24Q8@408F5Q@<0Q8B40`1c
Lg<40861P@<0N7Qh0`20P80407inOP<0PX:20`21PH4307moO`@0PX:20`21PH4707moO`<0P8200`1n
OWh707moO`<0P8201021PH430820P0@0b>3H0`1fMWH408F5Q@<0PH610`26QXH40820P0H0QHF51026
QXH308R8R0<0Ogmo2P20P80307AdM0@0R8R80`1nOWh307]kN`@0P8200`21PH4308:2PP<0Ph>3101l
O7`30820P0<0NGUi1020P8030861P@<0OWin1025QHD307moO`<0P820101nOWh308:2PPl0b>3H0`1o
Ogl408>3P`X0PH610`22PX8307moO`@0MWIf0`22PX8307moO`<0P820101nOWh30820P0<0OGem1025
QHD308:2PP<0OGem101lO7`308:2PP<0Ogmo0`1jNWX40861P@<0O7al0`21PH4407moO`H0PX:2101o
Ogl60820P0@0OWin0`1oOgl40<SPf0<0MWIf1026QXH307MgM`<0R8R81023Ph<308R8R0<0RHV90`2=
SHd40820P0<0NWYj0`2=SHd708Z:RP<0Ogmo1021PH4307IfMP<0OWin101oOgl307]kN`H0QXJ61020
P80307]kN`L0P8200`1oOgl308F5Q@@0Ng]k0`23Ph<308B4Q0L0PH615038h=P001<0b>3H0`23Ph<4
07inOP<0Ng]k1`1oOgl307inOP<0PX:21`21PH4308>3P`<0NGUi102ATI430861P@<0O7al101nOWh3
0820P0<0Ng]k1022PX8307YjNP<0PX:20`1nOWh408F5Q@<0OWin0`1mOGd40820P0<0Ogmo0`22PX84
0820P0<0OWin1`21PH430820P0@0b>3H0`1nOWh407moO`<0Rh^;0`1oOgl407inOP<0P8200`1nOWh7
08:2PP<0OGem0`1kNg/407alO0H0PH61101hN7P307moO`<0Ng]k1`1mOGd307moO`<0PH61101gMgL3
08>3P`<0PX:2101gMgL308F5Q@<0NWYj101gMgL308>3P`<0OGem1023Ph<308B4Q0l0b>3H0`25QHD4
07YjNP<0PX:20`1oOgl40861P@<0QHF50`1nOWh408B4Q0<0OGem0`22PX8307UiN@@0PH611P22PX84
07moO`<0PH610`24Q8@408>3P`<0PX:20`25QHD307emO@@0P8200`1oOgl30820P0@0Q8B41P1nOWh4
0820P0<0Ogmo0`20P80407inOP<0OGem1038h=P306i^KP@0L71`0`27QhL707]kN`<0SHf=0`1jNWX3
075aL@@0PH610`22PX8307UiN@@0MWIf0`21PH4708>3P`<0QXJ60`29RHT408B4Q0<0QXJ60`1jNWX3
08N7Q`@0OGem0`1kNg/30861P@@0QhN70`1mOGd30861P@@0Ng]k0`21PH4307YjNPL0Ogmo5038h=P0
01<0b>3H0`23Ph<407inOP<0Ng]k1`1oOgl307inOP<0PX:21`21PH4308>3P`<0NGUi102ATI430861
P@<0O7al101nOWh30820P0<0Ng]k1022PX8307YjNP<0PX:20`1nOWh408F5Q@<0OWin0`1mOGd40820
P0<0Ogmo0`22PX840820P0<0OWin1`21PH430820P0@0b>3H0`1nOWh407moO`<0Rh^;0`1oOgl407in
OP<0P8200`1nOWh708:2PP<0OGem0`1kNg/407alO0H0PH61101hN7P307moO`<0Ng]k1`1mOGd307mo
O`<0PH61101gMgL308>3P`<0PX:2101gMgL308F5Q@<0NWYj101gMgL308>3P`<0OGem1023Ph<308B4
Q0l0b>3H0`25QHD407YjNP<0PX:20`1oOgl40861P@<0QHF50`1nOWh408B4Q0<0OGem0`22PX8307Ui
N@@0PH611P22PX8407moO`<0PH610`24Q8@408>3P`<0PX:20`25QHD307emO@@0P8200`1oOgl30820
P0@0Q8B41P1nOWh40820P0<0Ogmo0`20P80407inOP<0OGem1038h=P306i^KP@0L71`0`27QhL707]k
N`<0SHf=0`1jNWX3075aL@@0PH610`22PX8307UiN@@0MWIf0`21PH4708>3P`<0QXJ60`29RHT408B4
Q0<0QXJ60`1jNWX308N7Q`@0OGem0`1kNg/30861P@@0QhN70`1mOGd30861P@@0Ng]k0`21PH4307Yj
NPL0Ogmo5038h=P001<0b>3H0`23Ph<407inOP<0Ng]k1`1oOgl307inOP<0PX:21`21PH4308>3P`<0
NGUi102ATI430861P@<0O7al101nOWh30820P0<0Ng]k1022PX8307YjNP<0PX:20`1nOWh408F5Q@<0
OWin0`1mOGd40820P0<0Ogmo0`22PX840820P0<0OWin1`21PH430820P0@0b>3H0`1nOWh407moO`<0
Rh^;0`1oOgl407inOP<0P8200`1nOWh708:2PP<0OGem0`1kNg/407alO0H0PH61101hN7P307moO`<0
Ng]k1`1mOGd307moO`<0PH61101gMgL308>3P`<0PX:2101gMgL308F5Q@<0NWYj101gMgL308>3P`<0
OGem1023Ph<308B4Q0l0b>3H0`25QHD407YjNP<0PX:20`1oOgl40861P@<0QHF50`1nOWh408B4Q0<0
OGem0`22PX8307UiN@@0PH611P22PX8407moO`<0PH610`24Q8@408>3P`<0PX:20`25QHD307emO@@0
P8200`1oOgl30820P0@0Q8B41P1nOWh40820P0<0Ogmo0`20P80407inOP<0OGem1038h=P306i^KP@0
L71`0`27QhL707]kN`<0SHf=0`1jNWX3075aL@@0PH610`22PX8307UiN@@0MWIf0`21PH4708>3P`<0
QXJ60`29RHT408B4Q0<0QXJ60`1jNWX308N7Q`@0OGem0`1kNg/30861P@@0QhN70`1mOGd30861P@@0
Ng]k0`21PH4307YjNPL0Ogmo5038h=P001<0b>3H0`21PH440820P0<0OWin0`25QHD408:2PP<0PH61
0`20P80407emO@<0PH610`20P80307alO0@0P8200`1fMWH30820P0@0O7al0`1oOgl30820P0@0OWin
0`22PX830820P0<0PH611023Ph<30861P@<0P8201022PX830820P0<0PH611022PX830820P0<0PH61
101oOgl307inOP@0b>3H0`25QHD40820P0<0PH610`22PX8407moO`<0P8200`1nOWh408J6QP<0OWin
0`1gMgL30820P0@0QXJ60`1gMgL307]kN`@0OWin0`1oOgl307emO@@0P8200`1kNg/307alO0<0Q8B4
101jNWX308:2PP<0Ph>3101nOWh308B4Q0<0PH611023Ph<307emO@<0PX:2101nOWh307moO`l0b>3H
0`1hN7P407]kN`<0PX:20`26QXH407alO0<0PH610`24Q8@407EeM@H0PH610`20P80407inOP<0PH61
0`1hN7P408:2PP<0P8200`1mOGd408:2PP<0OGem0`21PH4308B4Q0@0N7Qh0`21PH4308F5Q@@0O7al
1P1nOWh407alO0<0Ph>30`24Q8@40820P0<0PH611038h=P307IfMP@0QHF50`24Q8@307YjNP@0P820
0`21PH430820P0<0PX:2101lO7`308>3P`<0Kfm_102DU9@307moO`<0LW9b102?Shl308^;R`<0N7Qh
102=SHd307moO`<0PX:20`27QhL407alO0<0PX:20`25QHD407moO`<0PX:20`1jNWX407alO0<0P820
0`24Q8@308:2PP@0QXJ65038h=P001<0b>3H0`21PH440820P0<0OWin0`25QHD408:2PP<0PH610`20
P80407emO@<0PH610`20P80307alO0@0P8200`1fMWH30820P0@0O7al0`1oOgl30820P0@0OWin0`22
PX830820P0<0PH611023Ph<30861P@<0P8201022PX830820P0<0PH611022PX830820P0<0PH61101o
Ogl307inOP@0b>3H0`25QHD40820P0<0PH610`22PX8407moO`<0P8200`1nOWh408J6QP<0OWin0`1g
MgL30820P0@0QXJ60`1gMgL307]kN`@0OWin0`1oOgl307emO@@0P8200`1kNg/307alO0<0Q8B4101j
NWX308:2PP<0Ph>3101nOWh308B4Q0<0PH611023Ph<307emO@<0PX:2101nOWh307moO`l0b>3H0`1h
N7P407]kN`<0PX:20`26QXH407alO0<0PH610`24Q8@407EeM@H0PH610`20P80407inOP<0PH610`1h
N7P408:2PP<0P8200`1mOGd408:2PP<0OGem0`21PH4308B4Q0@0N7Qh0`21PH4308F5Q@@0O7al1P1n
OWh407alO0<0Ph>30`24Q8@40820P0<0PH611038h=P307IfMP@0QHF50`24Q8@307YjNP@0P8200`21
PH430820P0<0PX:2101lO7`308>3P`<0Kfm_102DU9@307moO`<0LW9b102?Shl308^;R`<0N7Qh102=
SHd307moO`<0PX:20`27QhL407alO0<0PX:20`25QHD407moO`<0PX:20`1jNWX407alO0<0P8200`24
Q8@308:2PP@0QXJ65038h=P001<0b>3H0`21PH440820P0<0OWin0`25QHD408:2PP<0PH610`20P804
07emO@<0PH610`20P80307alO0@0P8200`1fMWH30820P0@0O7al0`1oOgl30820P0@0OWin0`22PX83
0820P0<0PH611023Ph<30861P@<0P8201022PX830820P0<0PH611022PX830820P0<0PH61101oOgl3
07inOP@0b>3H0`25QHD40820P0<0PH610`22PX8407moO`<0P8200`1nOWh408J6QP<0OWin0`1gMgL3
0820P0@0QXJ60`1gMgL307]kN`@0OWin0`1oOgl307emO@@0P8200`1kNg/307alO0<0Q8B4101jNWX3
08:2PP<0Ph>3101nOWh308B4Q0<0PH611023Ph<307emO@<0PX:2101nOWh307moO`l0b>3H0`1hN7P4
07]kN`<0PX:20`26QXH407alO0<0PH610`24Q8@407EeM@H0PH610`20P80407inOP<0PH610`1hN7P4
08:2PP<0P8200`1mOGd408:2PP<0OGem0`21PH4308B4Q0@0N7Qh0`21PH4308F5Q@@0O7al1P1nOWh4
07alO0<0Ph>30`24Q8@40820P0<0PH611038h=P307IfMP@0QHF50`24Q8@307YjNP@0P8200`21PH43
0820P0<0PX:2101lO7`308>3P`<0Kfm_102DU9@307moO`<0LW9b102?Shl308^;R`<0N7Qh102=SHd3
07moO`<0PX:20`27QhL407alO0<0PX:20`25QHD407moO`<0PX:20`1jNWX407alO0<0P8200`24Q8@3
08:2PP@0QXJ65038h=P001<0b>3H0`21PH440820P0<0OWin0`25QHD408:2PP<0PH610`20P80407em
O@<0PH610`20P80307alO0@0P8200`1fMWH30820P0@0O7al0`1oOgl30820P0@0OWin0`22PX830820
P0<0PH611023Ph<30861P@<0P8201022PX830820P0<0PH611022PX830820P0<0PH61101oOgl307in
OP@0b>3H0`25QHD40820P0<0PH610`22PX8407moO`<0P8200`1nOWh408J6QP<0OWin0`1gMgL30820
P0@0QXJ60`1gMgL307]kN`@0OWin0`1oOgl307emO@@0P8200`1kNg/307alO0<0Q8B4101jNWX308:2
PP<0Ph>3101nOWh308B4Q0<0PH611023Ph<307emO@<0PX:2101nOWh307moO`l0b>3H0`1hN7P407]k
N`<0PX:20`26QXH407alO0<0PH610`24Q8@407EeM@H0PH610`20P80407inOP<0PH610`1hN7P408:2
PP<0P8200`1mOGd408:2PP<0OGem0`21PH4308B4Q0@0N7Qh0`21PH4308F5Q@@0O7al1P1nOWh407al
O0<0Ph>30`24Q8@40820P0<0PH611038h=P307IfMP@0QHF50`24Q8@307YjNP@0P8200`21PH430820
P0<0PX:2101lO7`308>3P`<0Kfm_102DU9@307moO`<0LW9b102?Shl308^;R`<0N7Qh102=SHd307mo
O`<0PX:20`27QhL407alO0<0PX:20`25QHD407moO`<0PX:20`1jNWX407alO0<0P8200`24Q8@308:2
PP@0QXJ65038h=P001<0b>3H0`25QHD407moO`X0P8201P22PX8407inOP<0PX:20`23Ph<307]kN`@0
QXJ60`1lO7`308B4Q0L0OWin1`21PH4307]kN`<0QHF50`1kNg/408V9R@<0OGem1`20P80307moO`<0
OGem1`20P80307moO`@0PX:20`1oOgl40<SPf0<0P820101fMWH307emO@L0OWin0`20P80308>3P`@0
RHV90`2;Rh/307IfMP<0OGem101eMGD308b<S0<0OWin1021PH4307moO`<0MgMg1027QhL307MgM`<0
Ph>30`22PX8408Z:RP<0MWIf0`23Ph<40820P0<0PH610`1oOgl408B4Q0<0O7al0`24Q8@40861P@<0
OWin3`38h=P307emO@@0PH611P1oOgl408>3P`<0P8201`1oOgl30861P@<0QXJ60`1oOgl408N7Q`<0
OGem0`21PH4407moO`<0Ng]k0`21PH4707UiN@<0Ng]k0`1oOgl408B4Q0<0P8200`1nOWh408:2PP<0
OGem1`1oOgl307inOP<0OGem101oOgl307emO@@0b>3H0`1fMWH408j>SP<0Lg=c0`27QhL407alO0<0
Q8B40`1eMGD309^KV`@0TY:B0`27QhL30820P0@0WinO0`1fMWH307YjNP@0OWin0`1gMgL307YjNP@0
Ng]k0`1nOWh308F5Q@L0Ng]k0`23Ph<307UiN@@0QHF50`1lO7`308B4Q0@0QhN70`1mOGd30861P@<0
QhN7101iNGTD0<SPf0004`38h=P308F5Q@@0Ogmo2P20P80608:2PP@0OWin0`22PX8308>3P`<0Ng]k
1026QXH307alO0<0Q8B41`1nOWh70861P@<0Ng]k0`25QHD307]kN`@0RHV90`1mOGd70820P0<0Ogmo
0`1mOGd70820P0<0Ogmo1022PX8307moO`@0b>3H0`20P80407IfMP<0OGem1`1nOWh30820P0<0Ph>3
1029RHT308^;R`<0MWIf0`1mOGd407EeM@<0S8b<0`1nOWh40861P@<0Ogmo0`1gMgL408N7Q`<0MgMg
0`23Ph<308:2PP@0RXZ:0`1fMWH308>3P`@0P8200`21PH4307moO`@0Q8B40`1lO7`308B4Q0@0PH61
0`1nOWh?0<SPf0<0OGem1021PH4607moO`@0Ph>30`20P80707moO`<0PH610`26QXH307moO`@0QhN7
0`1mOGd30861P@@0Ogmo0`1kNg/30861P@L0NGUi0`1kNg/307moO`@0Q8B40`20P80307inOP@0PX:2
0`1mOGd707moO`<0OWin0`1mOGd407moO`<0OGem1038h=P307IfMP@0SXj>0`1cLg<308N7Q`@0O7al
0`24Q8@307EeM@<0Vi^K102BTY8308N7Q`<0P820102OWil307IfMP<0NWYj101nOWh307MgM`<0NWYj
101kNg/307inOP<0QHF51`1kNg/308>3P`<0NGUi1025QHD307alO0<0Q8B41027QhL307emO@<0PH61
0`27QhL407UiNA@0b>3H000C0<SPf0<0QHF5101oOgl:0820P0H0PX:2101nOWh308:2PP<0Ph>30`1k
Ng/408J6QP<0O7al0`24Q8@707inOPL0PH610`1kNg/308F5Q@<0Ng]k1029RHT307emO@L0P8200`1o
Ogl307emO@L0P8200`1oOgl408:2PP<0Ogmo1038h=P30820P0@0MWIf0`1mOGd707inOP<0P8200`23
Ph<408V9R@<0Rh^;0`1fMWH307emO@@0MGEe0`2<S8`307inOP@0PH610`1oOgl307MgM`@0QhN70`1g
MgL308>3P`<0PX:2102:RXX307IfMP<0Ph>31020P8030861P@<0Ogmo1024Q8@307alO0<0Q8B41021
PH4307inOPl0b>3H0`1mOGd40861P@H0Ogmo1023Ph<30820P0L0Ogmo0`21PH4308J6QP<0Ogmo1027
QhL307emO@<0PH61101oOgl307]kN`<0PH611`1iNGT307]kN`<0Ogmo1024Q8@30820P0<0OWin1022
PX8307emO@L0Ogmo0`1nOWh307emO@@0Ogmo0`1mOGd40<SPf0<0MWIf102>SXh307=cL`<0QhN7101l
O7`308B4Q0<0MGEe0`2KVi/409:BTP<0QhN70`20P80409nOW`<0MWIf0`1jNWX407inOP<0MgMg0`1j
NWX407]kN`<0OWin0`25QHD707]kN`<0Ph>30`1iNGT408F5Q@<0O7al0`24Q8@408N7Q`<0OGem0`21
PH4308N7Q`@0NGUi5038h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3H
i`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3H
i`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3H
i`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P001<0b>3H0`2CTi<40:JVYP<0
MgMg0`29RHT40820P0<0O7al0`26QXH407moO`<0NGUi0`25QHD308>3P`@0Shn?0`1nOWh707emO@<0
P8200`1oOgl408>3P`<0Ng]k0`1nOWh408B4Q0<0PH610`1nOWh30820P0@0PX:20`1kNg/307emO@@0
OWin0`1mOGd30820P0@0NGUi0`2<S8`40<SPf0<0HV9R102`/;030:FUY@<0KFe]101jNWX307alO0L0
QHF50`26QXH307alO0<0QHF5101jNWX307UiN@X0PH610`1mOGd70820P0<0N7Qh101jNWX307inOP<0
PH610`1mOGd407inOPH0PH61101jNWX308:2PPL0P8200`1nOWh?0<SPf0<0N7Qh101iNGT308R8R0<0
OGem1021PH4307]kN`<0N7Qh101mOGd30861P@<0PX:20`1nOWh40861P@<0QXJ60`23Ph<408F5Q@<0
Ng]k0`1nOWh70820P0<0Ogmo0`1mOGd408B4Q0<0O7al0`1mOGd408B4Q0<0Ogmo0`1kNg/707emO@<0
QHF51022PX8307moO`@0b>3H0`1/K6`405ADE0<0Jf][0`2:RXX407emO@<0Ph>30`2:RXX308B4Q0@0
NWYj0`20P80308b<S0@0MgMg0`20P80307inOP@0Q8B40`22PX8307inOP@0OGem0`20P80308>3P`L0
PH611P22PX8407UiN@<0OGem0`24Q8@408F5Q@<0O7al0`1mOGd307QhN0@0O7al5038h=P001<0b>3H
0`2CTi<40:JVYP<0MgMg0`29RHT40820P0<0O7al0`26QXH407moO`<0NGUi0`25QHD308>3P`@0Shn?
0`1nOWh707emO@<0P8200`1oOgl408>3P`<0Ng]k0`1nOWh408B4Q0<0PH610`1nOWh30820P0@0PX:2
0`1kNg/307emO@@0OWin0`1mOGd30820P0@0NGUi0`2<S8`40<SPf0<0HV9R102`/;030:FUY@<0KFe]
101jNWX307alO0L0QHF50`26QXH307alO0<0QHF5101jNWX307UiN@X0PH610`1mOGd70820P0<0N7Qh
101jNWX307inOP<0PH610`1mOGd407inOPH0PH61101jNWX308:2PPL0P8200`1nOWh?0<SPf0<0N7Qh
101iNGT308R8R0<0OGem1021PH4307]kN`<0N7Qh101mOGd30861P@<0PX:20`1nOWh40861P@<0QXJ6
0`23Ph<408F5Q@<0Ng]k0`1nOWh70820P0<0Ogmo0`1mOGd408B4Q0<0O7al0`1mOGd408B4Q0<0Ogmo
0`1kNg/707emO@<0QHF51022PX8307moO`@0b>3H0`1/K6`405ADE0<0Jf][0`2:RXX407emO@<0Ph>3
0`2:RXX308B4Q0@0NWYj0`20P80308b<S0@0MgMg0`20P80307inOP@0Q8B40`22PX8307inOP@0OGem
0`20P80308>3P`L0PH611P22PX8407UiN@<0OGem0`24Q8@408F5Q@<0O7al0`1mOGd307QhN0@0O7al
5038h=P001<0b>3H0`2CTi<40:JVYP<0MgMg0`29RHT40820P0<0O7al0`26QXH407moO`<0NGUi0`25
QHD308>3P`@0Shn?0`1nOWh707emO@<0P8200`1oOgl408>3P`<0Ng]k0`1nOWh408B4Q0<0PH610`1n
OWh30820P0@0PX:20`1kNg/307emO@@0OWin0`1mOGd30820P0@0NGUi0`2<S8`40<SPf0<0HV9R102`
/;030:FUY@<0KFe]101jNWX307alO0L0QHF50`26QXH307alO0<0QHF5101jNWX307UiN@X0PH610`1m
OGd70820P0<0N7Qh101jNWX307inOP<0PH610`1mOGd407inOPH0PH61101jNWX308:2PPL0P8200`1n
OWh?0<SPf0<0N7Qh101iNGT308R8R0<0OGem1021PH4307]kN`<0N7Qh101mOGd30861P@<0PX:20`1n
OWh40861P@<0QXJ60`23Ph<408F5Q@<0Ng]k0`1nOWh70820P0<0Ogmo0`1mOGd408B4Q0<0O7al0`1m
OGd408B4Q0<0Ogmo0`1kNg/707emO@<0QHF51022PX8307moO`@0b>3H0`1/K6`405ADE0<0Jf][0`2:
RXX407emO@<0Ph>30`2:RXX308B4Q0@0NWYj0`20P80308b<S0@0MgMg0`20P80307inOP@0Q8B40`22
PX8307inOP@0OGem0`20P80308>3P`L0PH611P22PX8407UiN@<0OGem0`24Q8@408F5Q@<0O7al0`1m
OGd307QhN0@0O7al5038h=P001<0b>3H0`2CTi<403Xj>P<0[Zj^0`1iNGT408J6QP<0Q8B40`21PH44
08:2PP<0MWIf1P1mOGd40861P@<0Ph>30`21PH470820P0<0OGem1021PH4307moO`<0PH611020P803
0861P@H0P820101oOgl307alO0<0PX:2101lO7`307inOP<0P820101mOGd3096AT@@0b>3H0`21PH44
03lo?`<09bLW0`27QhL708:2PP<0Ogmo1026QXH307emO@<0Lg=c0`1lO7`408F5Q@<0NGUi0`1nOWh4
08:2PP<0OWin0`1fMWH40820P0<0Ph>30`1lO7`408:2PP<0PH610`1mOGd307alO0@0P8200`1lO7`3
07inOP@0O7al0`23Ph<308F5Q@@0PX:20`1nOWh?0<SPf0<0PX:21023Ph<307]kN`<0Q8B41`1mOGd3
08B4Q0@0QhN70`1hN7P607]kN`@0OGem0`20P80:08:2PP<0Ogmo1020P80307moO`d0P8200`21PH44
0820P0<0Ogmo0`20P80408>3P`<0PH610`1oOgl407inOP<0Ph>31038h=P308n?S`@0Kfm_0`1lO7`3
08>3P`@0Ogmo0`1lO7`308:2PPL0Q8B40`1kNg/307emO@@0NGUi0`1hN7P308N7Q`@0OWin0`1mOGd3
07moO`@0NGUi0`23Ph<307emO@<0MgMg101oOgl307alO0<0OGem101lO7`308:2PP<0OWin101iNGT3
07YjNP<0O7al0`22PX840861PA@0b>3H000C0<SPf0<0Ti>C100j>SX30:j^[P<0NGUi1026QXH308B4
Q0<0PH611022PX8307IfMPH0OGem1021PH4308>3P`<0PH611`20P80307emO@@0PH610`1oOgl30861
P@@0P8200`21PH460820P0@0Ogmo0`1lO7`308:2PP@0O7al0`1nOWh30820P0@0OGem0`2ATI440<SP
f0<0PH61100o?cl302LW9`<0QhN71`22PX8307moO`@0QXJ60`1mOGd307=cL`<0O7al1025QHD307Ui
N@<0OWin1022PX8307inOP<0MWIf1020P80308>3P`<0O7al1022PX830861P@<0OGem0`1lO7`40820
P0<0O7al0`1nOWh407alO0<0Ph>30`25QHD408:2PP<0OWin3`38h=P308:2PP@0Ph>30`1kNg/308B4
Q0L0OGem0`24Q8@408N7Q`<0N7Qh1P1kNg/407emO@<0P8202P22PX8307moO`@0P8200`1oOgl=0820
P0<0PH611020P80307moO`<0P8201023Ph<30861P@<0Ogmo101nOWh308>3P`@0b>3H0`2?Shl406m_
K`<0O7al0`23Ph<407moO`<0O7al0`22PX8708B4Q0<0Ng]k0`1mOGd407UiN@<0N7Qh0`27QhL407in
OP<0OGem0`1oOgl407UiN@<0Ph>30`1mOGd307MgM`@0Ogmo0`1lO7`307emO@@0O7al0`22PX8307in
OP@0NGUi0`1jNWX307alO0<0PX:21021PH4D0<SPf0004`38h=P309>CT`@0>SXj0`2^[Zh307UiN@@0
QXJ60`24Q8@30861P@@0PX:20`1fMWH607emO@@0PH610`23Ph<30861P@L0P8200`1mOGd40861P@<0
Ogmo0`21PH440820P0<0PH611P20P80407moO`<0O7al0`22PX8407alO0<0OWin0`20P80407emO@<0
TI6A1038h=P30861P@@0?clo0`0W9bL308N7Q`L0PX:20`1oOgl408J6QP<0OGem0`1cLg<307alO0@0
QHF50`1iNGT307inOP@0PX:20`1nOWh307IfMP@0P8200`23Ph<307alO0@0PX:20`21PH4307emO@<0
O7al1020P80307alO0<0OWin101lO7`308>3P`<0QHF51022PX8307inOPl0b>3H0`22PX8408>3P`<0
Ng]k0`24Q8@707emO@<0Q8B41027QhL307QhN0H0Ng]k101mOGd30820P0X0PX:20`1oOgl40820P0<0
Ogmo3@20P8030861P@@0P8200`1oOgl30820P0@0Ph>30`21PH4307moO`@0OWin0`23Ph<40<SPf0<0
Shn?101_Kfl307alO0<0Ph>3101oOgl307alO0<0PX:21`24Q8@307]kN`<0OGem101iNGT307QhN0<0
QhN7101nOWh307emO@<0Ogmo101iNGT308>3P`<0OGem0`1gMgL407moO`<0O7al0`1mOGd407alO0<0
PX:20`1nOWh407UiN@<0NWYj0`1lO7`308:2PP@0PH615038h=P001<0b>3H0`2CTi<403Xj>P<0[Zj^
0`1iNGT408J6QP<0Q8B40`21PH4408:2PP<0MWIf1P1mOGd40861P@<0Ph>30`21PH470820P0<0OGem
1021PH4307moO`<0PH611020P8030861P@H0P820101oOgl307alO0<0PX:2101lO7`307inOP<0P820
101mOGd3096AT@@0b>3H0`21PH4403lo?`<09bLW0`27QhL708:2PP<0Ogmo1026QXH307emO@<0Lg=c
0`1lO7`408F5Q@<0NGUi0`1nOWh408:2PP<0OWin0`1fMWH40820P0<0Ph>30`1lO7`408:2PP<0PH61
0`1mOGd307alO0@0P8200`1lO7`307inOP@0O7al0`23Ph<308F5Q@@0PX:20`1nOWh?0<SPf0<0PX:2
1023Ph<307]kN`<0Q8B41`1mOGd308B4Q0@0QhN70`1hN7P607]kN`@0OGem0`20P80:08:2PP<0Ogmo
1020P80307moO`d0P8200`21PH440820P0<0Ogmo0`20P80408>3P`<0PH610`1oOgl407inOP<0Ph>3
1038h=P308n?S`@0Kfm_0`1lO7`308>3P`@0Ogmo0`1lO7`308:2PPL0Q8B40`1kNg/307emO@@0NGUi
0`1hN7P308N7Q`@0OWin0`1mOGd307moO`@0NGUi0`23Ph<307emO@<0MgMg101oOgl307alO0<0OGem
101lO7`308:2PP<0OWin101iNGT307YjNP<0O7al0`22PX840861PA@0b>3H000C0<SPf0<0NGUi102C
Ti<305EEE@<0RHV9101jNWX308:2PP<0OGem101oOgl307inOP<0NGUi0`23Ph<407YjNP<0PH610`1o
Ogl407alO0<0OWin0`20P80407moO`H0OWin1020P80307alO0<0P8201`21PH4607inOP@0PX:20`1m
OGd30861P@@0Ph>30`2ATI440<SPf0<0Kfm_1028R8P30:ZZZP<0D51@101jNWX308:2PP<0NWYj1021
PH4308:2PP<0NGUi0`1hN7P40820P0<0PH610`1nOWh40820P0<0QXJ60`1nOWh408>3P`<0PX:20`1l
O7`40861P@<0Q8B40`20P80308>3P`@0NWYj0`20P80308B4Q0@0PX:20`21PH4308:2PPL0Ogmo3`38
h=P308>3P`@0OWin0`2=SHd308:2PP@0MgMg0`21PH4308:2PP@0Ogmo0`1nOWh60861P@@0OGem0`20
P80308:2PP@0P8200`1oOgl308:2PPL0O7al1P1mOGd408:2PP<0PH610`1mOGd407alO0X0OWin0`1o
Ogl70820P0<0Ogmo1038h=P30:VYZ@@0QhN70`2:RXX309^KV`@0QhN70`1mOGd308B4Q0<0QHF5101j
NWX308B4Q0<0PX:21028R8P307UiN@<0OGem1029RHT307YjNP<0Ph>31022PX830820P0<0Ogmo0`1i
NGT407emO@<0O7al0`1oOgl408J6QP<0PH610`1hN7P407emO@<0Ogmo0`25QHD308:2PP@0Ng]k5038
h=P001<0b>3H0`1iNGT409>CT`<0EEEE0`29RHT407YjNP<0PX:20`1mOGd407moO`<0OWin0`1iNGT3
08>3P`@0NWYj0`21PH4307moO`@0O7al0`1nOWh30820P0@0Ogmo1P1nOWh40820P0<0O7al0`20P807
0861P@H0OWin1022PX8307emO@<0PH611023Ph<3096AT@@0b>3H0`1_Kfl408R8R0<0ZZZZ0`1@D504
07YjNP<0PX:20`1jNWX40861P@<0PX:20`1iNGT307QhN0@0P8200`21PH4307inOP@0P8200`26QXH3
07inOP@0Ph>30`22PX8307alO0@0PH610`24Q8@30820P0<0Ph>3101jNWX30820P0<0Q8B41022PX83
0861P@<0PX:21`1oOgl?0<SPf0<0Ph>3101nOWh308f=S@<0PX:2101gMgL30861P@<0PX:2101oOgl3
07inOPH0PH61101mOGd30820P0<0PX:21020P80307moO`<0PX:21`1lO7`607emO@@0PX:20`21PH43
07emO@@0O7al2P1nOWh307moO`L0P8200`1oOgl40<SPf0<0ZJVY1027QhL308Z:RP<0Vi^K1027QhL3
07emO@<0Q8B40`25QHD407YjNP<0Q8B40`22PX8408R8R0<0NGUi0`1mOGd408V9R@<0NWYj0`23Ph<4
08:2PP<0P8200`1oOgl307UiN@@0OGem0`1lO7`307moO`@0QXJ60`21PH4307QhN0@0OGem0`1oOgl3
08F5Q@<0PX:2101kNg/D0<SPf0004`38h=P307UiN@@0Ti>C0`1EEED308V9R@@0NWYj0`22PX8307em
O@@0Ogmo0`1nOWh307UiN@<0Ph>3101jNWX30861P@<0Ogmo101lO7`307inOP<0P820101oOgl607in
OP@0P8200`1lO7`30820P0L0PH611P1nOWh408:2PP<0OGem0`21PH4408>3P`<0TI6A1038h=P306m_
K`@0R8R80`2ZZZX3051@D0@0NWYj0`22PX8307YjNP@0PH610`22PX8307UiN@<0N7Qh1020P8030861
P@<0OWin1020P80308J6QP<0OWin1023Ph<308:2PP<0O7al1021PH4308B4Q0<0P8200`23Ph<407Yj
NP<0P8200`24Q8@408:2PP<0PH610`22PX8707moO`l0b>3H0`23Ph<407inOP<0SHf=0`22PX8407Mg
M`<0PH610`22PX8407moO`<0OWin1P21PH4407emO@<0P8200`22PX840820P0<0Ogmo0`22PX8707al
O0H0OGem1022PX830861P@<0OGem101lO7`:07inOP<0Ogmo1`20P80307moO`@0b>3H0`2YZJT408N7
Q`<0RXZ:0`2KVi/408N7Q`<0OGem0`24Q8@308F5Q@@0NWYj0`24Q8@308:2PP@0R8R80`1iNGT307em
O@@0RHV90`1jNWX308>3P`@0PX:20`20P80307moO`<0NGUi101mOGd307alO0<0Ogmo1026QXH30861
P@<0N7Qh101mOGd307moO`<0QHF50`22PX8407]kNa@0b>3H000C0<SPf0<0SXj>101hN7P308F5Q@<0
W9bL101]KFd308F5Q@<0Lg=c1022PX8307emO@<0LG5a0`2<S8`407QhN0<0PH610`1oOgl40820P0<0
OWin0`1oOgl408B4Q0<0Ogmo0`20P80407moO`<0PH611P22PX840861P@<0P8200`1oOgl40820P0<0
OGem0`1oOgl40861P@<0Shn?1038h=P30;>c/`@0UIFE0`1VIVH30=GEe@@0VYZJ0`1]KFd307alO0@0
MgMg0`25QHD306m_K`<0QHF51020P80308:2PP<0P820101lO7`308F5Q@<0PH61101kNg/307alO0<0
PH61101oOgl30861P@<0Ng]k0`20P80407]kN`<0Q8B41`20P80307alO0<0PX:2101nOWh308>3P`l0
b>3H0`2:RXX408B4Q0<0N7Qh0`23Ph<408F5Q@<0Q8B40`2;Rh/40861P@<0Ng]k0`28R8P30820P0@0
Ph>30`1iNGT30820P0L0Ph>31`1lO7`307moO`<0PX:20`1nOWh407emO@<0PH610`24Q8@407moO`<0
PH610`1kNg/408B4Q0<0QHF51`1nOWh30820P0@0b>3H0`21PH4407moO`<0MWIf0`23Ph<407YjNP<0
Ogmo0`2ATI4307alO0@0Ph>30`1hN7P308V9R@@0OWin0`20P80307alO0@0RXZ:0`24Q8@307alO0@0
PH610`1jNWX308F5Q@<0RHV91022PX8307UiN@<0Q8B41022PX830861P@<0OGem101lO7`308B4Q0<0
Ogmo0`21PH4407YjNQ@0b>3H000C0<SPf0<0SXj>101hN7P308F5Q@<0W9bL101]KFd308F5Q@<0Lg=c
1022PX8307emO@<0LG5a0`2<S8`407QhN0<0PH610`1oOgl40820P0<0OWin0`1oOgl408B4Q0<0Ogmo
0`20P80407moO`<0PH611P22PX840861P@<0P8200`1oOgl40820P0<0OGem0`1oOgl40861P@<0Shn?
1038h=P30;>c/`@0UIFE0`1VIVH30=GEe@@0VYZJ0`1]KFd307alO0@0MgMg0`25QHD306m_K`<0QHF5
1020P80308:2PP<0P820101lO7`308F5Q@<0PH61101kNg/307alO0<0PH61101oOgl30861P@<0Ng]k
0`20P80407]kN`<0Q8B41`20P80307alO0<0PX:2101nOWh308>3P`l0b>3H0`2:RXX408B4Q0<0N7Qh
0`23Ph<408F5Q@<0Q8B40`2;Rh/40861P@<0Ng]k0`28R8P30820P0@0Ph>30`1iNGT30820P0L0Ph>3
1`1lO7`307moO`<0PX:20`1nOWh407emO@<0PH610`24Q8@407moO`<0PH610`1kNg/408B4Q0<0QHF5
1`1nOWh30820P0@0b>3H0`21PH4407moO`<0MWIf0`23Ph<407YjNP<0Ogmo0`2ATI4307alO0@0Ph>3
0`1hN7P308V9R@@0OWin0`20P80307alO0@0RXZ:0`24Q8@307alO0@0PH610`1jNWX308F5Q@<0RHV9
1022PX8307UiN@<0Q8B41022PX830861P@<0OGem101lO7`308B4Q0<0Ogmo0`21PH4407YjNQ@0b>3H
000C0<SPf0<0SXj>101hN7P308F5Q@<0W9bL101]KFd308F5Q@<0Lg=c1022PX8307emO@<0LG5a0`2<
S8`407QhN0<0PH610`1oOgl40820P0<0OWin0`1oOgl408B4Q0<0Ogmo0`20P80407moO`<0PH611P22
PX840861P@<0P8200`1oOgl40820P0<0OGem0`1oOgl40861P@<0Shn?1038h=P30;>c/`@0UIFE0`1V
IVH30=GEe@@0VYZJ0`1]KFd307alO0@0MgMg0`25QHD306m_K`<0QHF51020P80308:2PP<0P820101l
O7`308F5Q@<0PH61101kNg/307alO0<0PH61101oOgl30861P@<0Ng]k0`20P80407]kN`<0Q8B41`20
P80307alO0<0PX:2101nOWh308>3P`l0b>3H0`2:RXX408B4Q0<0N7Qh0`23Ph<408F5Q@<0Q8B40`2;
Rh/40861P@<0Ng]k0`28R8P30820P0@0Ph>30`1iNGT30820P0L0Ph>31`1lO7`307moO`<0PX:20`1n
OWh407emO@<0PH610`24Q8@407moO`<0PH610`1kNg/408B4Q0<0QHF51`1nOWh30820P0@0b>3H0`21
PH4407moO`<0MWIf0`23Ph<407YjNP<0Ogmo0`2ATI4307alO0@0Ph>30`1hN7P308V9R@@0OWin0`20
P80307alO0@0RXZ:0`24Q8@307alO0@0PH610`1jNWX308F5Q@<0RHV91022PX8307UiN@<0Q8B41022
PX830861P@<0OGem101lO7`308B4Q0<0Ogmo0`21PH4407YjNQ@0b>3H000C0<SPf0<0RXZ:101nOWh3
08>3P`<0JFUY102TY:@307UiN@<0Ph>31022PX8307MgM`<0MWIf0`2EUID407EeM@<0OWin0`1lO7`4
08:2PP<0P8200`1nOWh407moO`<0PH610`1lO7`408>3P`<0OWin0`20P80307inOP@0PX:20`21PH43
07alO0@0RHV90`1jNWX308>3P`@0N7Qh0`2=SHd40<SPf0<0HF5Q101aLG4308F5Q@<0K6a/1028R8P3
09NGU`<0Ng]k1021PH4308:2PP<0MWIf0`1hN7P40820P0<0Ng]k0`1lO7`407UiN@H0OWin101kNg/3
07moO`L0PX:20`1nOWh30820P0<0OGem1023Ph<307]kN`<0P820101iNGT308^;R`<0NWYj102;Rh/3
07emO@l0b>3H0`1fMWH408:2PP<0QhN70`21PH4408>3P`<0Q8B40`1nOWh407moO`<0QXJ60`22PX83
0861P@@0PX:21P1lO7`407emO@<0P8200`23Ph<40861P@<0QHF50`1mOGd307UiN@@0Ogmo1P1nOWh4
08>3P`<0PH610`22PX870861P@<0PX:2101oOgl30820P0@0b>3H0`1gMgL407inOP<0Rh^;0`1nOWh4
04m?C`<0L71`0`1iNGT308J6QP@0Ph>30`29RHT307emO@L0Ng]k0`1oOgl407inOP<0Ph>30`1oOgl4
0861P@<0Q8B40`22PX8307]kN`@0OGem0`24Q8@307inOP@0P8200`22PX8307]kN`@0OGem0`1^KVh3
08R8R0<0RXZ:101eMGDD0<SPf0004`38h=P308Z:RP@0OWin0`23Ph<306UYJ@@0Y:BT0`1iNGT308>3
P`@0PX:20`1gMgL307IfMP<0UIFE101eMGD307inOP<0O7al1022PX830820P0<0OWin101oOgl30861
P@<0O7al1023Ph<307inOP<0P8200`1nOWh408:2PP<0PH610`1lO7`408V9R@<0NWYj0`23Ph<407Qh
N0<0SHf=1038h=P3065QH@@0LG5a0`25QHD306a/K0@0R8R80`2GUiL307]kN`@0PH610`22PX8307If
MP<0N7Qh1020P80307]kN`<0O7al101iNGT607inOP@0Ng]k0`1oOgl708:2PP<0OWin0`20P80307em
O@@0Ph>30`1kNg/30820P0@0NGUi0`2;Rh/307YjNP@0Rh^;0`1mOGd?0<SPf0<0MWIf1022PX8308N7
Q`<0PH611023Ph<308B4Q0<0OWin101oOgl308J6QP<0PX:20`21PH4408:2PPH0O7al101mOGd30820
P0<0Ph>31021PH4308F5Q@<0OGem0`1iNGT407moO`H0OWin1023Ph<30861P@<0PX:21`21PH4308:2
PP@0Ogmo0`20P8040<SPf0<0MgMg101nOWh308^;R`<0OWin101?Cdl3071`L0<0NGUi0`26QXH408>3
P`<0RHV90`1mOGd707]kN`<0Ogmo101nOWh308>3P`<0Ogmo1021PH4308B4Q0<0PX:20`1kNg/407em
O@<0Q8B40`1nOWh40820P0<0PX:20`1kNg/407emO@<0KVi^0`28R8P308Z:RP@0MGEe5038h=P001<0
b>3H0`2:RXX407inOP<0Ph>30`1YJFT40:BTY0<0NGUi0`23Ph<408:2PP<0MgMg0`1fMWH309FEU@@0
MGEe0`1nOWh307alO0@0PX:20`20P80307inOP@0Ogmo0`21PH4307alO0@0Ph>30`1nOWh30820P0<0
OWin1022PX830861P@<0O7al1029RHT307YjNP<0Ph>3101hN7P308f=S@@0b>3H0`1QHF44075aL@<0
QHF50`1/K6`408R8R0<0UiNG0`1kNg/40861P@<0PX:20`1fMWH307QhN0@0P8200`1kNg/307alO0@0
NGUi1P1nOWh407]kN`<0Ogmo1`22PX8307inOP<0P8200`1mOGd408>3P`<0Ng]k0`20P80407UiN@<0
Rh^;0`1jNWX408^;R`<0OGem3`38h=P307IfMP@0PX:20`27QhL30861P@@0Ph>30`24Q8@307inOP@0
Ogmo0`26QXH308:2PP<0PH611022PX8607alO0@0OGem0`20P80308>3P`@0PH610`25QHD307emO@<0
NGUi101oOgl607inOP@0Ph>30`21PH4308:2PPL0PH610`22PX8407moO`<0P8201038h=P307MgM`@0
OWin0`2;Rh/307inOP@0Cdm?0`1`L70307UiN@<0QXJ61023Ph<308V9R@<0OGem1`1kNg/307moO`@0
OWin0`23Ph<307moO`@0PH610`24Q8@308:2PP<0Ng]k101mOGd308B4Q0<0OWin1020P80308:2PP<0
Ng]k101mOGd306i^KP<0R8R80`2:RXX407EeMA@0b>3H000C0<SPf0<0V9RH1012@T8307emO@<0QHF5
101WIfL308^;R`<0O7al101kNg/307alO0<0Jf][0`2CTi<407UiN@<0O7al0`1nOWh407emO@<0PH61
0`1nOWh40861P@<0Ph>30`21PH4407emO@<0Ogmo0`21PH430820P0@0PX:20`24Q8@307QhN0@0RHV9
0`1eMGD309:BTP@0MgMg0`22PX840<SPf0<0Ogmo102BTY8307MgM`<0MWIf101_Kfl306][J`<0S8b<
101nOWh308:2PP<0OWin0`1jNWX408:2PP<0P8200`1nOWh407emO@<0PX:20`1oOgl407UiN@<0PH61
0`26QXH407inOP<0PH610`1hN7P307moO`@0OWin0`20P80308R8R0@0QHF50`20P803092@T0@0NWYj
0`1hN7P?0<SPf0<0PX:21025QHD30820P0L0PH610`1dM7@308V9R@@0R8R81P1mOGd307moO`@0OWin
0`1oOgl708:2PP<0PH610`1lO7`40861P@<0PX:20`1oOgl307emO@@0OWin1P20P8040861P@H0P820
101oOgl30861P@<0Q8B4101nOWh307moO`@0b>3H0`21PH44071`L0<0Shn?0`1gMgL406IVIP<0VIVI
0`1]KFd3075aL@@0R8R80`1nOWh307UiN@L0Ogmo0`1lO7`707moO`<0O7al101kNg/30820P0<0NGUi
0`1jNWX408:2PP<0NWYj1`1mOGd307QhN0<0PH61101oOgl307IfMP<0Rh^;0`23Ph<408:2PQ@0b>3H
000C0<SPf0<0V9RH1012@T8307emO@<0QHF5101WIfL308^;R`<0O7al101kNg/307alO0<0Jf][0`2C
Ti<407UiN@<0O7al0`1nOWh407emO@<0PH610`1nOWh40861P@<0Ph>30`21PH4407emO@<0Ogmo0`21
PH430820P0@0PX:20`24Q8@307QhN0@0RHV90`1eMGD309:BTP@0MgMg0`22PX840<SPf0<0Ogmo102B
TY8307MgM`<0MWIf101_Kfl306][J`<0S8b<101nOWh308:2PP<0OWin0`1jNWX408:2PP<0P8200`1n
OWh407emO@<0PX:20`1oOgl407UiN@<0PH610`26QXH407inOP<0PH610`1hN7P307moO`@0OWin0`20
P80308R8R0@0QHF50`20P803092@T0@0NWYj0`1hN7P?0<SPf0<0PX:21025QHD30820P0L0PH610`1d
M7@308V9R@@0R8R81P1mOGd307moO`@0OWin0`1oOgl708:2PP<0PH610`1lO7`40861P@<0PX:20`1o
Ogl307emO@@0OWin1P20P8040861P@H0P820101oOgl30861P@<0Q8B4101nOWh307moO`@0b>3H0`21
PH44071`L0<0Shn?0`1gMgL406IVIP<0VIVI0`1]KFd3075aL@@0R8R80`1nOWh307UiN@L0Ogmo0`1l
O7`707moO`<0O7al101kNg/30820P0<0NGUi0`1jNWX408:2PP<0NWYj1`1mOGd307QhN0<0PH61101o
Ogl307IfMP<0Rh^;0`23Ph<408:2PQ@0b>3H000C0<SPf0<0V9RH1012@T8307emO@<0QHF5101WIfL3
08^;R`<0O7al101kNg/307alO0<0Jf][0`2CTi<407UiN@<0O7al0`1nOWh407emO@<0PH610`1nOWh4
0861P@<0Ph>30`21PH4407emO@<0Ogmo0`21PH430820P0@0PX:20`24Q8@307QhN0@0RHV90`1eMGD3
09:BTP@0MgMg0`22PX840<SPf0<0Ogmo102BTY8307MgM`<0MWIf101_Kfl306][J`<0S8b<101nOWh3
08:2PP<0OWin0`1jNWX408:2PP<0P8200`1nOWh407emO@<0PX:20`1oOgl407UiN@<0PH610`26QXH4
07inOP<0PH610`1hN7P307moO`@0OWin0`20P80308R8R0@0QHF50`20P803092@T0@0NWYj0`1hN7P?
0<SPf0<0PX:21025QHD30820P0L0PH610`1dM7@308V9R@@0R8R81P1mOGd307moO`@0OWin0`1oOgl7
08:2PP<0PH610`1lO7`40861P@<0PX:20`1oOgl307emO@@0OWin1P20P8040861P@H0P820101oOgl3
0861P@<0Q8B4101nOWh307moO`@0b>3H0`21PH44071`L0<0Shn?0`1gMgL406IVIP<0VIVI0`1]KFd3
075aL@@0R8R80`1nOWh307UiN@L0Ogmo0`1lO7`707moO`<0O7al101kNg/30820P0<0NGUi0`1jNWX4
08:2PP<0NWYj1`1mOGd307QhN0<0PH61101oOgl307IfMP<0Rh^;0`23Ph<408:2PQ@0b>3H000C0<SP
f0<0V9RH1012@T8307emO@<0QHF5101WIfL308^;R`<0O7al101kNg/307alO0<0Jf][0`2CTi<407Ui
N@<0O7al0`1nOWh407emO@<0PH610`1nOWh40861P@<0Ph>30`21PH4407emO@<0Ogmo0`21PH430820
P0@0PX:20`24Q8@307QhN0@0RHV90`1eMGD309:BTP@0MgMg0`22PX840<SPf0<0Ogmo102BTY8307Mg
M`<0MWIf101_Kfl306][J`<0S8b<101nOWh308:2PP<0OWin0`1jNWX408:2PP<0P8200`1nOWh407em
O@<0PX:20`1oOgl407UiN@<0PH610`26QXH407inOP<0PH610`1hN7P307moO`@0OWin0`20P80308R8
R0@0QHF50`20P803092@T0@0NWYj0`1hN7P?0<SPf0<0PX:21025QHD30820P0L0PH610`1dM7@308V9
R@@0R8R81P1mOGd307moO`@0OWin0`1oOgl708:2PP<0PH610`1lO7`40861P@<0PX:20`1oOgl307em
O@@0OWin1P20P8040861P@H0P820101oOgl30861P@<0Q8B4101nOWh307moO`@0b>3H0`21PH44071`
L0<0Shn?0`1gMgL406IVIP<0VIVI0`1]KFd3075aL@@0R8R80`1nOWh307UiN@L0Ogmo0`1lO7`707mo
O`<0O7al101kNg/30820P0<0NGUi0`1jNWX408:2PP<0NWYj1`1mOGd307QhN0<0PH61101oOgl307If
MP<0Rh^;0`23Ph<408:2PQ@0b>3H000C0<SPf0<0Lg=c101bLW8308J6QP<0P8201024Q8@306MWI`<0
TY:B101jNWX307UiN@<0K6a/0`2DU9@407YjNPH0OGem101nOWh307moO`<0PH61101oOgl30820P0<0
O7al1`1oOgl308:2PP<0Ogmo101mOGd308:2PP<0LW9b1028R8P307]kN`<0Ph>3101mOGd308b<S0@0
b>3H0`2:RXX405=CD`<0T92@0`1iNGT40;Jf]P<0Jf][0`2OWil407QhN0<0Ogmo0`25QHD307moO`@0
O7al0`24Q8@70820P0<0PX:20`23Ph<70861P@<0Ogmo1021PH460820P0<0Ogmo101nOWh308J6QP<0
PX:2101oOgl30861P@<0Ng]k101oOgl308J6QPl0b>3H0`1nOWh70820P0<0Ph>3101lO7`308^;R`<0
NWYj101kNg/308B4Q0<0NGUi0`27QhL408B4Q0<0P8200`1mOGd407moO`<0PX:20`1mOGd407inOP<0
Q8B40`20P8030861P@X0OWin1021PH4307inOP<0Ogmo1021PH4308:2PP<0O7al1021PH4308:2PP@0
b>3H1`1jNWX306m_K`<0PH61101iNGT30:ZZZP<0NGUi0`21PH4408R8R0<0NWYj0`27QhL408J6QP<0
Shn?0`26QXH407emO@<0PH610`22PX8708B4Q0H0PX:21021PH4308:2PP<0QHF5101oOgl307inOP<0
QHF52P1jNWX307alO0@0PX:25038h=P001<0b>3H0`1cLg<4079bLP<0QXJ60`20P80408B4Q0<0IfMW
0`2BTY8407YjNP<0NGUi0`1/K6`309BDU0@0NWYj1P1mOGd407inOP<0Ogmo0`21PH4407moO`<0P820
0`1lO7`707moO`<0PX:20`1oOgl407emO@<0PX:20`1bLW8408R8R0<0Ng]k0`23Ph<407emO@<0S8b<
1038h=P308Z:RP@0De=C0`2@T90307UiN@@0][Jf0`1[Jf/309nOW`@0N7Qh0`1oOgl308F5Q@<0Ogmo
101lO7`308B4Q0L0P8200`22PX8308>3P`L0PH610`1oOgl40861P@H0P8200`1oOgl407inOP<0QXJ6
0`22PX8407moO`<0PH610`1kNg/407moO`<0QXJ63`38h=P307inOPL0P8200`23Ph<407alO0<0Rh^;
0`1jNWX407]kN`<0Q8B40`1iNGT308N7Q`@0Q8B40`20P80307emO@@0Ogmo0`22PX8307emO@@0OWin
0`24Q8@30820P0<0PH612P1nOWh40861P@<0OWin0`1oOgl40861P@<0PX:20`1lO7`40861P@<0PX:2
1038h=P707YjNP<0Kfm_0`21PH4407UiN@<0ZZZZ0`1iNGT30861P@@0R8R80`1jNWX308N7Q`@0QXJ6
0`2?Shl308J6QP@0OGem0`21PH4308:2PPL0Q8B41P22PX840861P@<0PX:20`25QHD407moO`<0OWin
0`25QHD:07YjNP<0O7al1022PX8D0<SPf0004`38h=P307=cL`@0LW9b0`26QXH30820P0@0Q8B40`1W
IfL309:BTP@0NWYj0`1iNGT306a/K0<0U9BD101jNWX607emO@@0OWin0`1oOgl30861P@@0Ogmo0`20
P80307alO0L0Ogmo0`22PX8307moO`@0OGem0`22PX83079bLP@0R8R80`1kNg/308>3P`@0OGem0`2<
S8`40<SPf0<0RXZ:101CDe<3092@T0<0NGUi102f][H306][J`<0WinO101hN7P307moO`<0QHF50`1o
Ogl407alO0<0Q8B41`20P80308:2PP<0Ph>31`21PH4307moO`@0PH611P20P80307moO`@0OWin0`26
QXH308:2PP@0Ogmo0`21PH4307]kN`@0Ogmo0`26QXH?0<SPf0<0OWin1`20P80308>3P`@0O7al0`2;
Rh/307YjNP@0Ng]k0`24Q8@307UiN@<0QhN71024Q8@30820P0<0OGem101oOgl308:2PP<0OGem101n
OWh308B4Q0<0P8200`21PH4:07inOP@0PH610`1nOWh307moO`@0PH610`22PX8307alO0@0PH610`22
PX840<SPf0L0NWYj0`1_Kfl30861P@@0NGUi0`2ZZZX307UiN@<0PH611028R8P307YjNP<0QhN71026
QXH308n?S`<0QXJ6101mOGd30861P@<0PX:21`24Q8@608:2PP@0PH610`22PX8308F5Q@@0Ogmo0`1n
OWh308F5Q@X0NWYj0`1lO7`408:2PQ@0b>3H000C0<SPf0<0N7Qh102DU9@308n?S`<0Rh^;101lO7`3
096AT@<0/k>c101aLG4307UiN@<0IfMW0`2JVYX707emO@<0P8201`1oOgl707inOPH0PH612P1oOgl3
08:2PP@0Ogmo0`20P80307YjNP@0Q8B42P1nOWh307emO@@0b>3H0`1kNg/409VIV@<0GEeM0`1_Kfl4
06a/K0<0NGUi0`1?Cdl409:BTP<0OWin0`20P80308:2PP@0Q8B40`21PH4307UiN@@0Ogmo0`1nOWh3
08^;R`@0OGem0`1nOWh307]kN`@0PH610`1lO7`308F5Q@<0OWin1025QHD30820P0<0OGem1020P803
07QhN0<0Ph>31027QhL307alO0l0b>3H0`1nOWh408N7Q`<0NGUi0`1mOGd408J6QP<0O7al0`1oOgl4
08F5Q@<0PH610`1mOGd307alO0@0PH610`1oOgl30861P@@0PX:20`1nOWh308:2PP@0PH610`22PX83
07alO0<0P820101mOGd307inOPL0P8200`1oOgl30820P0@0Ph>30`1oOgl308:2PP@0PH610`20P804
0<SPf0<0Lg=c101lO7`307MgM`<0Ph>3102@T90308:2PP<0KVi^0`1kNg/4079bLP<0OWin0`1fMWH7
0861P@<0O7al1026QXH607inOP@0NGUi0`1eMGD307moO`<0Q8B41021PH4307YjNP<0OGem101lO7`3
08:2PP<0O7al101mOGd307UiN@<0Ng]k0`22PX8407alO1@0b>3H000C0<SPf0<0N7Qh102DU9@308n?
S`<0Rh^;101lO7`3096AT@<0/k>c101aLG4307UiN@<0IfMW0`2JVYX707emO@<0P8201`1oOgl707in
OPH0PH612P1oOgl308:2PP@0Ogmo0`20P80307YjNP@0Q8B42P1nOWh307emO@@0b>3H0`1kNg/409VI
V@<0GEeM0`1_Kfl406a/K0<0NGUi0`1?Cdl409:BTP<0OWin0`20P80308:2PP@0Q8B40`21PH4307Ui
N@@0Ogmo0`1nOWh308^;R`@0OGem0`1nOWh307]kN`@0PH610`1lO7`308F5Q@<0OWin1025QHD30820
P0<0OGem1020P80307QhN0<0Ph>31027QhL307alO0l0b>3H0`1nOWh408N7Q`<0NGUi0`1mOGd408J6
QP<0O7al0`1oOgl408F5Q@<0PH610`1mOGd307alO0@0PH610`1oOgl30861P@@0PX:20`1nOWh308:2
PP@0PH610`22PX8307alO0<0P820101mOGd307inOPL0P8200`1oOgl30820P0@0Ph>30`1oOgl308:2
PP@0PH610`20P8040<SPf0<0Lg=c101lO7`307MgM`<0Ph>3102@T90308:2PP<0KVi^0`1kNg/4079b
LP<0OWin0`1fMWH70861P@<0O7al1026QXH607inOP@0NGUi0`1eMGD307moO`<0Q8B41021PH4307Yj
NP<0OGem101lO7`308:2PP<0O7al101mOGd307UiN@<0Ng]k0`22PX8407alO1@0b>3H000C0<SPf0<0
N7Qh102DU9@308n?S`<0Rh^;101lO7`3096AT@<0/k>c101aLG4307UiN@<0IfMW0`2JVYX707emO@<0
P8201`1oOgl707inOPH0PH612P1oOgl308:2PP@0Ogmo0`20P80307YjNP@0Q8B42P1nOWh307emO@@0
b>3H0`1kNg/409VIV@<0GEeM0`1_Kfl406a/K0<0NGUi0`1?Cdl409:BTP<0OWin0`20P80308:2PP@0
Q8B40`21PH4307UiN@@0Ogmo0`1nOWh308^;R`@0OGem0`1nOWh307]kN`@0PH610`1lO7`308F5Q@<0
OWin1025QHD30820P0<0OGem1020P80307QhN0<0Ph>31027QhL307alO0l0b>3H0`1nOWh408N7Q`<0
NGUi0`1mOGd408J6QP<0O7al0`1oOgl408F5Q@<0PH610`1mOGd307alO0@0PH610`1oOgl30861P@@0
PX:20`1nOWh308:2PP@0PH610`22PX8307alO0<0P820101mOGd307inOPL0P8200`1oOgl30820P0@0
Ph>30`1oOgl308:2PP@0PH610`20P8040<SPf0<0Lg=c101lO7`307MgM`<0Ph>3102@T90308:2PP<0
KVi^0`1kNg/4079bLP<0OWin0`1fMWH70861P@<0O7al1026QXH607inOP@0NGUi0`1eMGD307moO`<0
Q8B41021PH4307YjNP<0OGem101lO7`308:2PP<0O7al101mOGd307UiN@<0Ng]k0`22PX8407alO1@0
b>3H000C0<SPf0<0Kfm_102EUID309fMW@<0BDU9102JVYX307UiN@<0EeMG102CTi<307emO@<0JVYZ
0`2?Shl407emO@<0PH611`1lO7`307inOP<0Ph>31020P80307emO@<0OWin1024Q8@307moO`<0OWin
0`1oOgl40861P@H0P8201`1oOgl30861P@@0PX:20`1nOWh40<SPf0<0JVYZ1024Q8@308J6QP<0ZJVY
102:RXX308J6QP<0KVi^100^;Rh30861P@H0PX:21021PH4307inOP<0O7al1`1oOgl308:2PP@0OGem
0`1kNg/30861P@@0OGem0`24Q8@308J6QP<0P820101oOgl307YjNP<0Ogmo1022PX8307moO`L0OWin
0`1mOGd?0<SPf0<0Ng]k101mOGd608B4Q0@0PH610`20P80308N7Q`@0OGem0`1jNWX308:2PP<0PH61
101mOGd307alO0<0Ng]k101lO7`30861P@<0P820101mOGd30861P@<0P8200`1nOWh408:2PP<0P820
0`21PH4407inOP<0PH610`20P8040861P@<0PX:20`20P80407alO0<0Ogmo1038h=P307inOP@0LW9b
0`24Q8@307IfMP@0PX:20`1lO7`309:BTP<0UYJF1026QXH308F5Q@<0OGem101jNWX307UiN@<0NWYj
1020P80308:2PP<0MGEe1022PX8607QhN0<0PX:2101kNg/3075aL@<0OGem101lO7`308>3P`<0Q8B4
1022PX830861P@<0Ng]k0`29RHT407moOa@0b>3H000C0<SPf0<0Kfm_102EUID309fMW@<0BDU9102J
VYX307UiN@<0EeMG102CTi<307emO@<0JVYZ0`2?Shl407emO@<0PH611`1lO7`307inOP<0Ph>31020
P80307emO@<0OWin1024Q8@307moO`<0OWin0`1oOgl40861P@H0P8201`1oOgl30861P@@0PX:20`1n
OWh40<SPf0<0JVYZ1024Q8@308J6QP<0ZJVY102:RXX308J6QP<0KVi^100^;Rh30861P@H0PX:21021
PH4307inOP<0O7al1`1oOgl308:2PP@0OGem0`1kNg/30861P@@0OGem0`24Q8@308J6QP<0P820101o
Ogl307YjNP<0Ogmo1022PX8307moO`L0OWin0`1mOGd?0<SPf0<0Ng]k101mOGd608B4Q0@0PH610`20
P80308N7Q`@0OGem0`1jNWX308:2PP<0PH61101mOGd307alO0<0Ng]k101lO7`30861P@<0P820101m
OGd30861P@<0P8200`1nOWh408:2PP<0P8200`21PH4407inOP<0PH610`20P8040861P@<0PX:20`20
P80407alO0<0Ogmo1038h=P307inOP@0LW9b0`24Q8@307IfMP@0PX:20`1lO7`309:BTP<0UYJF1026
QXH308F5Q@<0OGem101jNWX307UiN@<0NWYj1020P80308:2PP<0MGEe1022PX8607QhN0<0PX:2101k
Ng/3075aL@<0OGem101lO7`308>3P`<0Q8B41022PX830861P@<0Ng]k0`29RHT407moOa@0b>3H000C
0<SPf0<0Kfm_102EUID309fMW@<0BDU9102JVYX307UiN@<0EeMG102CTi<307emO@<0JVYZ0`2?Shl4
07emO@<0PH611`1lO7`307inOP<0Ph>31020P80307emO@<0OWin1024Q8@307moO`<0OWin0`1oOgl4
0861P@H0P8201`1oOgl30861P@@0PX:20`1nOWh40<SPf0<0JVYZ1024Q8@308J6QP<0ZJVY102:RXX3
08J6QP<0KVi^100^;Rh30861P@H0PX:21021PH4307inOP<0O7al1`1oOgl308:2PP@0OGem0`1kNg/3
0861P@@0OGem0`24Q8@308J6QP<0P820101oOgl307YjNP<0Ogmo1022PX8307moO`L0OWin0`1mOGd?
0<SPf0<0Ng]k101mOGd608B4Q0@0PH610`20P80308N7Q`@0OGem0`1jNWX308:2PP<0PH61101mOGd3
07alO0<0Ng]k101lO7`30861P@<0P820101mOGd30861P@<0P8200`1nOWh408:2PP<0P8200`21PH44
07inOP<0PH610`20P8040861P@<0PX:20`20P80407alO0<0Ogmo1038h=P307inOP@0LW9b0`24Q8@3
07IfMP@0PX:20`1lO7`309:BTP<0UYJF1026QXH308F5Q@<0OGem101jNWX307UiN@<0NWYj1020P803
08:2PP<0MGEe1022PX8607QhN0<0PX:2101kNg/3075aL@<0OGem101lO7`308>3P`<0Q8B41022PX83
0861P@<0Ng]k0`29RHT407moOa@0b>3H000C0<SPf0<0EeMG102e]KD306i^KP<0NGUi102IVIT306YZ
JP<0TY:B101fMWH306e]K@<0Jf][0`2ATI4407alO0H0PH611`22PX8307moO`@0OGem1P1nOWh408:2
PP<0Ogmo0`1nOWh708:2PP<0P8200`1kNg/40820P0<0Ogmo1`22PX8307UiN@@0b>3H0`2/[:`406e]
K@<0Ogmo0`1TI6@406e]K@<0M7Ad0`21PH440<O7a`<0VIVI0`1jNWX30861P@L0Ng]k0`26QXH407al
O0<0P8201`1mOGd308:2PP<0P820101nOWh307alO0<0P8200`1nOWh70861P@<0PX:2101oOgl307Qh
N0<0NGUi1022PX830820P0l0b>3H0`25QHD40861P@<0Ng]k0`1mOGd407inOP<0PX:20`1mOGd407in
OP<0Q8B40`22PX8307inOP@0Q8B40`1oOgl308:2PP@0P8200`1kNg/307emO@@0PH610`20P80308:2
PP<0Ogmo1`1nOWh30820P0@0PX:20`1oOgl30861P@L0P8200`1oOgl408>3P`<0OWin1038h=P308j>
SP@0Rh^;0`1kNg/307MgM`@0QhN71P1nOWh308>3P`@0MGEe0`1iNGT308>3P`@0M7Ad0`24Q8@307Yj
NP@0SHf=0`1nOWh307MgM`L0Ph>30`25QHD307moO`@0OGem0`24Q8@708:2PPH0Ogmo1023Ph<307mo
O`<0OWin0`1oOgl408B4Q1@0b>3H000C0<SPf0<0EeMG102e]KD306i^KP<0NGUi102IVIT306YZJP<0
TY:B101fMWH306e]K@<0Jf][0`2ATI4407alO0H0PH611`22PX8307moO`@0OGem1P1nOWh408:2PP<0
Ogmo0`1nOWh708:2PP<0P8200`1kNg/40820P0<0Ogmo1`22PX8307UiN@@0b>3H0`2/[:`406e]K@<0
Ogmo0`1TI6@406e]K@<0M7Ad0`21PH440<O7a`<0VIVI0`1jNWX30861P@L0Ng]k0`26QXH407alO0<0
P8201`1mOGd308:2PP<0P820101nOWh307alO0<0P8200`1nOWh70861P@<0PX:2101oOgl307QhN0<0
NGUi1022PX830820P0l0b>3H0`25QHD40861P@<0Ng]k0`1mOGd407inOP<0PX:20`1mOGd407inOP<0
Q8B40`22PX8307inOP@0Q8B40`1oOgl308:2PP@0P8200`1kNg/307emO@@0PH610`20P80308:2PP<0
Ogmo1`1nOWh30820P0@0PX:20`1oOgl30861P@L0P8200`1oOgl408>3P`<0OWin1038h=P308j>SP@0
Rh^;0`1kNg/307MgM`@0QhN71P1nOWh308>3P`@0MGEe0`1iNGT308>3P`@0M7Ad0`24Q8@307YjNP@0
SHf=0`1nOWh307MgM`L0Ph>30`25QHD307moO`@0OGem0`24Q8@708:2PPH0Ogmo1023Ph<307moO`<0
OWin0`1oOgl408B4Q1@0b>3H000C0<SPf0<0EeMG102e]KD306i^KP<0NGUi102IVIT306YZJP<0TY:B
101fMWH306e]K@<0Jf][0`2ATI4407alO0H0PH611`22PX8307moO`@0OGem1P1nOWh408:2PP<0Ogmo
0`1nOWh708:2PP<0P8200`1kNg/40820P0<0Ogmo1`22PX8307UiN@@0b>3H0`2/[:`406e]K@<0Ogmo
0`1TI6@406e]K@<0M7Ad0`21PH440<O7a`<0VIVI0`1jNWX30861P@L0Ng]k0`26QXH407alO0<0P820
1`1mOGd308:2PP<0P820101nOWh307alO0<0P8200`1nOWh70861P@<0PX:2101oOgl307QhN0<0NGUi
1022PX830820P0l0b>3H0`25QHD40861P@<0Ng]k0`1mOGd407inOP<0PX:20`1mOGd407inOP<0Q8B4
0`22PX8307inOP@0Q8B40`1oOgl308:2PP@0P8200`1kNg/307emO@@0PH610`20P80308:2PP<0Ogmo
1`1nOWh30820P0@0PX:20`1oOgl30861P@L0P8200`1oOgl408>3P`<0OWin1038h=P308j>SP@0Rh^;
0`1kNg/307MgM`@0QhN71P1nOWh308>3P`@0MGEe0`1iNGT308>3P`@0M7Ad0`24Q8@307YjNP@0SHf=
0`1nOWh307MgM`L0Ph>30`25QHD307moO`@0OGem0`24Q8@708:2PPH0Ogmo1023Ph<307moO`<0OWin
0`1oOgl408B4Q1@0b>3H000C0<SPf0<0EeMG102e]KD306i^KP<0NGUi102IVIT306YZJP<0TY:B101f
MWH306e]K@<0Jf][0`2ATI4407alO0H0PH611`22PX8307moO`@0OGem1P1nOWh408:2PP<0Ogmo0`1n
OWh708:2PP<0P8200`1kNg/40820P0<0Ogmo1`22PX8307UiN@@0b>3H0`2/[:`406e]K@<0Ogmo0`1T
I6@406e]K@<0M7Ad0`21PH440<O7a`<0VIVI0`1jNWX30861P@L0Ng]k0`26QXH407alO0<0P8201`1m
OGd308:2PP<0P820101nOWh307alO0<0P8200`1nOWh70861P@<0PX:2101oOgl307QhN0<0NGUi1022
PX830820P0l0b>3H0`25QHD40861P@<0Ng]k0`1mOGd407inOP<0PX:20`1mOGd407inOP<0Q8B40`22
PX8307inOP@0Q8B40`1oOgl308:2PP@0P8200`1kNg/307emO@@0PH610`20P80308:2PP<0Ogmo1`1n
OWh30820P0@0PX:20`1oOgl30861P@L0P8200`1oOgl408>3P`<0OWin1038h=P308j>SP@0Rh^;0`1k
Ng/307MgM`@0QhN71P1nOWh308>3P`@0MGEe0`1iNGT308>3P`@0M7Ad0`24Q8@307YjNP@0SHf=0`1n
OWh307MgM`L0Ph>30`25QHD307moO`@0OGem0`24Q8@708:2PPH0Ogmo1023Ph<307moO`<0OWin0`1o
Ogl408B4Q1@0b>3H000C0<SPf0<0Ogmo101mOGd307UiN@<0YjNW101MGEd309fMW@<0RHV9101RHV83
0;Ng]`<0IfMW0`26QXH707]kN`<0P820101mOGd307inOP<0PX:2101oOgl30861P@<0OGem1022PX83
08B4Q0<0O7al0`24Q8@70820P0<0PH61101oOgl307inOP<0PH611022PX8307YjNP@0b>3H0`1XJ6P4
0861P@<0Ogmo0`25QHD40::RXP<0Ph>30`1lO7`4065QH@<0IVIV0`2>SXh307YjNPL0Ph>30`1oOgl4
0861P@<0NWYj0`1mOGd407moO`<0P8200`1nOWh70861P@<0QHF50`20P80407moO`H0PX:21024Q8@3
08>3P`<0PH61101nOWh307emO@l0b>3H0`1lO7`408Z:RP<0Ogmo0`1mOGd408>3P`<0PH610`1oOgl4
07UiN@<0N7Qh0`29RHT30861P@@0P8202P21PH4307inOP<0P8201022PX860861P@<0Ogmo1`22PX83
07]kN`@0OGem0`1nOWh308:2PP@0PH610`1oOgl308:2PP@0O7al0`1mOGd40<SPf0<0O7al101bLW83
07moO`<0QXJ6101mOGd307]kN`<0P8200`1oOgl407EeM@<0OGem0`23Ph<407QhN0<0RXZ:0`1lO7`4
07MgM`<0QHF50`23Ph<407emO@<0Ng]k0`28R8P308>3P`@0R8R80`24Q8@30820P0@0NGUi0`1kNg/3
08:2PP@0OWin0`23Ph<308R8R0<0Ng]k101jNWXD0<SPf0004`38h=P307moO`@0OGem0`1iNGT30:NW
Y`@0GEeM0`2MWId308V9R@@0HV9R0`2g]kL306MWI`<0QXJ61`1kNg/30820P0@0OGem0`1nOWh308:2
PP@0Ogmo0`21PH4307emO@@0PX:20`24Q8@307alO0<0Q8B41`20P8030861P@@0Ogmo0`1nOWh30861
P@@0PX:20`1jNWX40<SPf0<0J6QX1021PH4307moO`<0QHF5102RXZ8308>3P`<0O7al101QHF4306IV
IP<0SXj>0`1jNWX708>3P`<0Ogmo1021PH4307YjNP<0OGem101oOgl30820P0<0OWin1`21PH4308F5
Q@<0P820101oOgl608:2PP@0Q8B40`23Ph<30861P@@0OWin0`1mOGd?0<SPf0<0O7al102:RXX307mo
O`<0OGem1023Ph<30861P@<0Ogmo101iNGT307QhN0<0RHV90`21PH440820P0X0PH610`1nOWh30820
P0@0PX:21P21PH4307moO`L0PX:20`1kNg/407emO@<0OWin0`22PX840861P@<0Ogmo0`22PX8407al
O0<0OGem1038h=P307alO0@0LW9b0`1oOgl308J6QP@0OGem0`1kNg/30820P0<0Ogmo101eMGD307em
O@<0Ph>3101hN7P308Z:RP<0O7al101gMgL308F5Q@<0Ph>3101mOGd307]kN`<0R8R80`23Ph<408R8
R0<0Q8B40`20P80407UiN@<0Ng]k0`22PX8407inOP<0Ph>30`28R8P307]kN`@0NWYj5038h=P001<0
b>3H0`1oOgl407emO@<0NGUi0`2WYjL405eMG@<0WIfM0`29RHT4069RHP<0]kNg0`1WIfL308J6QPL0
Ng]k0`20P80407emO@<0OWin0`22PX8407moO`<0PH610`1mOGd408:2PP<0Q8B40`1lO7`308B4Q0L0
P8200`21PH4407moO`<0OWin0`21PH4408:2PP<0NWYj1038h=P306QXJ0@0PH610`1oOgl308F5Q@@0
XZ:R0`23Ph<307alO0@0HF5Q0`1VIVH308j>SP<0NWYj1`23Ph<307moO`@0PH610`1jNWX307emO@@0
Ogmo0`20P80307inOPL0PH610`25QHD30820P0@0Ogmo1P22PX8408B4Q0<0Ph>30`21PH4407inOP<0
OGem3`38h=P307alO0@0RXZ:0`1oOgl307emO@@0Ph>30`21PH4307moO`@0NGUi0`1hN7P308V9R@<0
PH611020P80:0861P@<0OWin0`20P80408:2PPH0PH610`1oOgl708:2PP<0Ng]k101mOGd307inOP<0
PX:21021PH4307moO`<0PX:2101lO7`307emO@@0b>3H0`1lO7`4079bLP<0Ogmo0`26QXH407emO@<0
Ng]k0`20P80307moO`@0MGEe0`1mOGd308>3P`@0N7Qh0`2:RXX307alO0@0MgMg0`25QHD308>3P`@0
OGem0`1kNg/308R8R0<0Ph>31028R8P308B4Q0<0P820101iNGT307]kN`<0PX:2101nOWh308>3P`<0
R8R80`1kNg/407YjNQ@0b>3H000C0<SPf0<0TI6A101mOGd60820P0@0I6AT0`2MWId305QHF0@0SHf=
0`16ATH309BDU0<0Q8B4101mOGd30820P0<0O7al1020P8030861P@<0Ng]k1021PH4307moO`<0PH61
101nOWh308:2PP<0P8200`24Q8@408:2PP<0PH610`1mOGd407inOP<0Ng]k0`1oOgl408B4Q0<0NWYj
1038h=P307IfMP@0PH610`1eMGD307MgM`@0GemO0`1QHF4308:2PP@0RXZ:0`1iNGT3038b<P<0Ogmo
1025QHD308:2PP<0P8201021PH4308J6QP<0P8201021PH4607inOP@0PH610`25QHD607YjNP@0OWin
0`23Ph<30861P@@0QHF51P21PH4708F5Q@l0b>3H0`1hN7P407MgM`<0Q8B40`22PX840861P@<0O7al
0`23Ph<408:2PP<0QXJ60`21PH4:07inOP<0Ph>31`1oOgl307emO@@0P8200`1nOWh307moO`<0Q8B4
1`1oOgl307emO@L0P8200`22PX8407moO`<0PH611`1oOgl307inOP@0b>3H0`1kNg/407UiN@<0QXJ6
0`27QhL407moO`H0S8b<0`24Q8@4096AT@<0YjNW0`21PH4407YjNP<0Ogmo0`20P80407emO@H0PX:2
1024Q8@307alO0<0QHF50`21PH4407emO@<0P8200`24Q8@407inOP<0P8200`24Q8@408>3P`<0PX:2
0`20P80308:2PP@0P8205038h=P001<0b>3H0`2ATI4407emO@H0P820101TI6@309fMW@<0F5QH102=
SHd304I6AP<0U9BD0`24Q8@407emO@<0P8200`1lO7`40820P0<0PH610`1kNg/40861P@<0Ogmo0`21
PH4407inOP<0PX:20`20P80308B4Q0@0PX:20`21PH4307emO@@0OWin0`1kNg/307moO`@0Q8B40`1j
NWX40<SPf0<0MWIf1021PH4307EeM@<0MgMg101OGel3065QH@<0PX:2102:RXX307UiN@<0<S8b0`1o
Ogl408F5Q@<0PX:20`20P8040861P@<0QXJ60`20P8040861P@H0OWin1021PH4308F5Q@H0NWYj101n
OWh308>3P`<0PH611025QHD60861P@L0QHF53`38h=P307QhN0@0MgMg0`24Q8@308:2PP@0PH610`1l
O7`308>3P`@0PX:20`26QXH30861P@X0OWin0`23Ph<707moO`<0OGem1020P80307inOP<0Ogmo0`24
Q8@707moO`<0OGem1`20P80308:2PP@0Ogmo0`21PH4707moO`<0OWin1038h=P307]kN`@0NGUi0`26
QXH308N7Q`@0Ogmo1P2<S8`308B4Q0@0TI6A0`2WYjL30861P@@0NWYj0`1oOgl30820P0@0OGem1P22
PX8408B4Q0<0O7al0`25QHD30861P@@0OGem0`20P80308B4Q0@0OWin0`20P80308B4Q0@0Ph>30`22
PX830820P0<0PX:21020P80D0<SPf0004`38h=P3096AT@@0OGem1P20P80406ATI0<0WIfM0`1HF5P4
08f=S@<0ATI60`2DU9@308B4Q0@0OGem0`20P80307alO0@0P8200`21PH4307]kN`@0PH610`1oOgl3
0861P@@0OWin0`22PX830820P0<0Q8B41022PX830861P@<0OGem101nOWh307]kN`<0Ogmo1024Q8@3
07YjNP@0b>3H0`1fMWH40861P@<0MGEe0`1gMgL405mOG`<0HF5Q0`22PX8408Z:RP<0NGUi0`0b<S83
07moO`@0QHF50`22PX830820P0@0PH610`26QXH30820P0@0PH611P1nOWh40861P@<0QHF51P1jNWX4
07inOP<0Ph>30`21PH4408F5Q@H0PH611`25QHD?0<SPf0<0N7Qh101gMgL308B4Q0<0PX:21021PH43
07alO0<0Ph>31022PX8308J6QP<0PH612P1nOWh308>3P`L0Ogmo0`1mOGd40820P0<0OWin0`1oOgl3
08B4Q0L0Ogmo0`1mOGd70820P0<0PX:2101oOgl30861P@L0Ogmo0`1nOWh40<SPf0<0Ng]k101iNGT3
08J6QP<0QhN7101oOgl608b<S0<0Q8B4102ATI430:NWY`<0PH61101jNWX307moO`<0P820101mOGd6
08:2PP@0Q8B40`1lO7`308F5Q@<0PH61101mOGd30820P0<0Q8B4101nOWh30820P0<0Q8B41023Ph<3
08:2PP<0P8200`22PX840820P1@0b>3H000C0<SPf0<0Rh^;101nOWh30861P@<0Ng]k102QXJ4305QH
F0<0UIFE1026QXH308n?S`<0OWin0`1hN7P707alO0X0Ogmo0`21PH4407moO`<0P8200`22PX8407al
O0<0PX:20`21PH430820P0@0OWin1P20P80408:2PP<0Ogmo0`20P80407emO@<0Ogmo1038h=P307in
OP@0OGem0`1jNWX307UiN@@0S8b<0`2`/;0308N7Q`@0KFe]0`22PX830<c<c0<0QhN7101fMWH308:2
PP<0P8201`1nOWh308>3P`@0QHF50`20P80307YjNP@0QhN70`1oOgl307alO0<0OWin1`1mOGd308J6
QP@0Q8B40`1lO7`307inOP@0Ogmo0`26QXH?0<SPf0<0PX:21`1oOgl307]kN`@0O7al2P21PH4307in
OP<0PH610`24Q8@707moO`<0OGem1020P80307alO0<0P820101nOWh307moO`<0P8200`1nOWh407mo
O`<0OWin0`1jNWX40861P@<0Ogmo0`1mOGd407inOP<0O7al0`1oOgl407inOP<0PH611038h=P3092@
T0@0QhN70`28R8P30820P0@0MgMg0`1bLW8307IfMPL0P8200`27QhL308B4Q0@0N7Qh0`24Q8@308V9
R@@0OGem0`21PH4308F5Q@@0Ogmo0`21PH4308J6QP<0PH61101cLg<307UiN@<0QHF51`1kNg/308:2
PP@0PH610`1oOgl307QhN0<0M7Ad1021PH4D0<SPf0004`38h=P308^;R`@0OWin0`21PH4307]kN`@0
XJ6Q0`1HF5P309FEU@@0QXJ60`2?Shl307inOP<0N7Qh1`1lO7`:07moO`<0PH61101oOgl30820P0<0
PX:2101lO7`308:2PP<0PH610`20P80407inOPH0P8201022PX8307moO`<0P820101mOGd307moO`@0
b>3H0`1nOWh407emO@<0NWYj0`1iNGT408b<S0<0/;2`0`27QhL406e]K@<0PX:20`3<c<`308N7Q`@0
MWIf0`22PX830820P0L0OWin0`23Ph<408F5Q@<0P8200`1jNWX408N7Q`<0Ogmo0`1lO7`307inOPL0
OGem0`26QXH408B4Q0<0O7al0`1nOWh407moO`<0QXJ63`38h=P308:2PPL0Ogmo0`1kNg/407alO0X0
PH610`1nOWh30861P@<0Q8B41`1oOgl307emO@@0P8200`1lO7`30820P0@0OWin0`1oOgl30820P0<0
OWin101oOgl307inOP<0NWYj1021PH4307moO`<0OGem101nOWh307alO0<0Ogmo101nOWh30861P@@0
b>3H0`2@T90408N7Q`<0R8R80`20P80407MgM`<0LW9b0`1fMWH70820P0<0QhN70`24Q8@407QhN0<0
Q8B40`29RHT407emO@<0PH610`25QHD407moO`<0PH610`26QXH30861P@@0Lg=c0`1iNGT308F5Q@L0
Ng]k0`22PX840861P@<0Ogmo0`1hN7P307AdM0@0PH615038h=P001<0b>3H0`2;Rh/407inOP<0PH61
0`1kNg/40:6QX@<0F5QH0`2EUID408J6QP<0Shn?0`1nOWh307QhN0L0O7al2P1oOgl30861P@@0Ogmo
0`20P80308:2PP@0O7al0`22PX830861P@<0P820101nOWh60820P0@0PX:20`1oOgl30820P0@0OGem
0`1oOgl40<SPf0<0OWin101mOGd307YjNP<0NGUi102<S8`30;2`/0<0QhN7101]KFd308:2PP<0c<c<
0`27QhL407IfMP<0PX:20`20P80707inOP<0Ph>31025QHD30820P0<0NWYj1027QhL307moO`<0O7al
0`1nOWh707emO@<0QXJ61024Q8@307alO0<0OWin101oOgl308J6QPl0b>3H0`22PX8707moO`<0Ng]k
101lO7`:0861P@<0OWin0`21PH4308B4Q0L0Ogmo0`1mOGd40820P0<0O7al0`20P80407inOP<0Ogmo
0`20P80307inOP@0Ogmo0`1nOWh307YjNP@0PH610`1oOgl307emO@@0OWin0`1lO7`307moO`@0OWin
0`21PH440<SPf0<0T92@1027QhL308R8R0<0P820101gMgL3079bLP<0MWIf1`20P80308N7Q`<0Q8B4
101hN7P308B4Q0<0RHV9101mOGd30861P@<0QHF5101oOgl30861P@<0QXJ60`21PH4407=cL`<0NGUi
0`25QHD707]kN`<0PX:21021PH4307moO`<0N7Qh0`1dM7@40861PA@0b>3H000C0<SPf0<0Shn?101o
Ogl30861P@<0P820101kNg/306QXJ0<0Zj^[101KFe/307]kN`<0JFUY0`2YZJT4071`L0<0O7al0`1o
Ogl408B4Q0<0PH610`1lO7`40820P0<0OGem0`22PX8407alO0<0OGem0`21PH4308:2PP@0Ogmo0`1n
OWh30820P0@0PX:20`1jNWX30861P@L0OGem1038h=P308V9R@@0MgMg0`1kNg/308B4Q0@0QHF50`1J
FUX306e]K@@0Vi^K0`27QhL306][J`<0^KVi102_[jl307QhN0<0QHF5101kNg/307YjNP<0OWin101l
O7`308>3P`L0PH610`1gMgL307moO`<0RHV9101nOWh607alO0@0NWYj0`1oOgl30861P@@0Ng]k0`1m
OGd?0<SPf0<0P820101jNWX307alO0<0Ng]k101mOGd307UiN@<0O7al1021PH430820P0<0Ng]k0`1i
NGT408Z:RP<0PX:20`21PH440820P0<0Ogmo0`20P80407inOP<0PH610`20P80=0861P@L0OGem0`1k
Ng/407inOP<0PX:20`1lO7`407emO@<0Ogmo1038h=P308^;R`@0QHF50`1kNg/307emO@@0Ogmo0`21
PH4308N7Q`<0PH61101hN7P307]kN`<0DU9B101TI6@308V9R@<0Ng]k101oOgl30820P0<0Ph>31020
P80308F5Q@<0PH610`1mOGd40820P0<0PX:20`1fMWH407]kN`<0Q8B40`26QXH408F5Q@<0O7al0`20
P80307moO`@0N7Qh5038h=P001<0b>3H0`2?Shl407moO`<0PH610`20P80407]kN`<0J6QX0`2[Zj/4
05]KF`<0Ng]k0`1YJFT30:VYZ@@0L71`0`1lO7`307moO`@0Q8B40`21PH4307alO0@0P8200`1mOGd3
08:2PP@0O7al0`1mOGd30861P@<0PX:2101oOgl307inOP<0P8201022PX8307YjNP<0PH611`1mOGd4
0<SPf0<0RHV9101gMgL307]kN`<0Q8B41025QHD305YJFP<0KFe]102KVi/308N7Q`<0Jf][0`2i^KT4
0:n_[`<0N7Qh0`25QHD407]kN`<0NWYj0`1nOWh407alO0<0Ph>31`21PH4307MgM`<0Ogmo0`29RHT4
07inOPH0O7al101jNWX307moO`<0PH61101kNg/307emO@l0b>3H0`20P80407YjNP<0O7al0`1kNg/4
07emO@<0NGUi0`1lO7`40861P@<0P8200`1kNg/307UiN@@0RXZ:0`22PX830861P@@0P8200`1oOgl3
0820P0@0OWin0`21PH430820P0d0PH611`1mOGd307]kN`@0OWin0`22PX8307alO0@0OGem0`1oOgl4
0<SPf0<0Rh^;1025QHD307]kN`<0OGem101oOgl30861P@<0QhN70`21PH4407QhN0<0Ng]k0`1BDU84
06ATI0<0RHV90`1kNg/407moO`<0P8200`23Ph<40820P0<0QHF50`21PH4307emO@@0P8200`22PX83
07IfMP@0Ng]k0`24Q8@308J6QP@0QHF50`1lO7`30820P0<0Ogmo101hN7PD0<SPf0004`38h=P308n?
S`@0Ogmo0`21PH430820P0@0Ng]k0`1XJ6P30:^[Z`@0Fe]K0`1kNg/306UYJ@<0ZJVY101`L70307al
O0<0Ogmo1024Q8@30861P@<0O7al1020P80307emO@<0PX:2101lO7`307emO@<0PH610`22PX8407mo
O`<0OWin0`20P80408:2PP<0NWYj0`21PH4707emO@@0b>3H0`29RHT407MgM`<0Ng]k0`24Q8@408F5
Q@<0FUYJ0`1]KFd409^KV`<0QhN70`1[Jf/30;Vi^@@0[jn_0`1hN7P308F5Q@@0Ng]k0`1jNWX307in
OP@0O7al0`23Ph<70861P@<0MgMg0`1oOgl308V9R@@0OWin1P1lO7`407YjNP<0Ogmo0`21PH4407]k
N`<0OGem3`38h=P30820P0@0NWYj0`1lO7`307]kN`@0OGem0`1iNGT307alO0@0PH610`20P80307]k
N`<0NGUi102:RXX308:2PP<0PH611020P80307moO`<0P820101nOWh30861P@<0P8203@21PH4707em
O@<0Ng]k101nOWh308:2PP<0O7al101mOGd307moO`@0b>3H0`2;Rh/408F5Q@<0Ng]k0`1mOGd407mo
O`<0PH610`27QhL30861P@@0N7Qh0`1kNg/3059BDP@0I6AT0`29RHT307]kN`@0Ogmo0`20P80308>3
P`@0P8200`25QHD30861P@<0OGem1020P80308:2PP<0MWIf101kNg/308B4Q0<0QXJ61025QHD307al
O0<0P8200`1oOgl407QhN1@0b>3H000C0<SPf0<0Shn?101oOgl30861P@<0P820101kNg/306QXJ0<0
Zj^[101KFe/307]kN`<0JFUY0`2YZJT4071`L0<0O7al0`1oOgl408B4Q0<0PH610`1lO7`40820P0<0
OGem0`22PX8407alO0<0OGem0`21PH4308:2PP@0Ogmo0`1nOWh30820P0@0PX:20`1jNWX30861P@L0
OGem1038h=P308V9R@@0MgMg0`1kNg/308B4Q0@0QHF50`1JFUX306e]K@@0Vi^K0`27QhL306][J`<0
^KVi102_[jl307QhN0<0QHF5101kNg/307YjNP<0OWin101lO7`308>3P`L0PH610`1gMgL307moO`<0
RHV9101nOWh607alO0@0NWYj0`1oOgl30861P@@0Ng]k0`1mOGd?0<SPf0<0P820101jNWX307alO0<0
Ng]k101mOGd307UiN@<0O7al1021PH430820P0<0Ng]k0`1iNGT408Z:RP<0PX:20`21PH440820P0<0
Ogmo0`20P80407inOP<0PH610`20P80=0861P@L0OGem0`1kNg/407inOP<0PX:20`1lO7`407emO@<0
Ogmo1038h=P308^;R`@0QHF50`1kNg/307emO@@0Ogmo0`21PH4308N7Q`<0PH61101hN7P307]kN`<0
DU9B101TI6@308V9R@<0Ng]k101oOgl30820P0<0Ph>31020P80308F5Q@<0PH610`1mOGd40820P0<0
PX:20`1fMWH407]kN`<0Q8B40`26QXH408F5Q@<0O7al0`20P80307moO`@0N7Qh5038h=P001<0b>3H
1`20P80308B4Q0<0P820101fMWH30:BTY0<0Cdm?102;Rh/308N7Q`<0S8b<0`1EEED40:NWY`<0LW9b
0`23Ph<407alO0<0P8200`21PH4408:2PP<0OGem1`20P80307emO@<0PH610`23Ph<40820P0<0O7al
0`1gMgL408F5Q@<0NWYj1`1oOgl307emO@@0b>3H0`1hN7P40861P@<0Ng]k0`1lO7`408>3P`<0SHf=
0`2VYZH4075aL@<0Kfm_0`1nOWh305]KF`@0Hf=S0`2LW9`307alO0@0PH610`1nOWh70861P@<0OGem
0`21PH4407moO`<0PX:20`23Ph<307emO@@0PH610`1hN7P308>3P`@0OWin0`1lO7`30820P0@0Q8B4
0`22PX8?0<SPf0<0PX:2101oOgl307inOP<0Ng]k101lO7`308>3P`<0QHF51021PH430820P0H0PX:2
101jNWX308B4Q0<0Ng]k101lO7`30820P0<0PX:21024Q8@307moO`<0PH610`1mOGd40861P@<0P820
0`1jNWX408>3P`H0P8202P1mOGd407moO`<0PH611038h=P30861P@@0N7Qh0`1jNWX30861P@@0Ogmo
0`1hN7P30861P@<0Ogmo1024Q8@308Z:RP<0NGUi101CDe<306IVIP<0OGem1025QHD30861P@<0QXJ6
101kNg/307emO@<0OWin0`20P80408F5Q@<0Ph>30`21PH440820P0<0RHV90`1mOGd408V9R@<0Q8B4
0`1mOGd308:2PP@0OGem5038h=P001<0b>3H1`20P80308B4Q0<0P820101fMWH30:BTY0<0Cdm?102;
Rh/308N7Q`<0S8b<0`1EEED40:NWY`<0LW9b0`23Ph<407alO0<0P8200`21PH4408:2PP<0OGem1`20
P80307emO@<0PH610`23Ph<40820P0<0O7al0`1gMgL408F5Q@<0NWYj1`1oOgl307emO@@0b>3H0`1h
N7P40861P@<0Ng]k0`1lO7`408>3P`<0SHf=0`2VYZH4075aL@<0Kfm_0`1nOWh305]KF`@0Hf=S0`2L
W9`307alO0@0PH610`1nOWh70861P@<0OGem0`21PH4407moO`<0PX:20`23Ph<307emO@@0PH610`1h
N7P308>3P`@0OWin0`1lO7`30820P0@0Q8B40`22PX8?0<SPf0<0PX:2101oOgl307inOP<0Ng]k101l
O7`308>3P`<0QHF51021PH430820P0H0PX:2101jNWX308B4Q0<0Ng]k101lO7`30820P0<0PX:21024
Q8@307moO`<0PH610`1mOGd40861P@<0P8200`1jNWX408>3P`H0P8202P1mOGd407moO`<0PH611038
h=P30861P@@0N7Qh0`1jNWX30861P@@0Ogmo0`1hN7P30861P@<0Ogmo1024Q8@308Z:RP<0NGUi101C
De<306IVIP<0OGem1025QHD30861P@<0QXJ6101kNg/307emO@<0OWin0`20P80408F5Q@<0Ph>30`21
PH440820P0<0RHV90`1mOGd408V9R@<0Q8B40`1mOGd308:2PP@0OGem5038h=P001<0b>3H1`20P803
08B4Q0<0P820101fMWH30:BTY0<0Cdm?102;Rh/308N7Q`<0S8b<0`1EEED40:NWY`<0LW9b0`23Ph<4
07alO0<0P8200`21PH4408:2PP<0OGem1`20P80307emO@<0PH610`23Ph<40820P0<0O7al0`1gMgL4
08F5Q@<0NWYj1`1oOgl307emO@@0b>3H0`1hN7P40861P@<0Ng]k0`1lO7`408>3P`<0SHf=0`2VYZH4
075aL@<0Kfm_0`1nOWh305]KF`@0Hf=S0`2LW9`307alO0@0PH610`1nOWh70861P@<0OGem0`21PH44
07moO`<0PX:20`23Ph<307emO@@0PH610`1hN7P308>3P`@0OWin0`1lO7`30820P0@0Q8B40`22PX8?
0<SPf0<0PX:2101oOgl307inOP<0Ng]k101lO7`308>3P`<0QHF51021PH430820P0H0PX:2101jNWX3
08B4Q0<0Ng]k101lO7`30820P0<0PX:21024Q8@307moO`<0PH610`1mOGd40861P@<0P8200`1jNWX4
08>3P`H0P8202P1mOGd407moO`<0PH611038h=P30861P@@0N7Qh0`1jNWX30861P@@0Ogmo0`1hN7P3
0861P@<0Ogmo1024Q8@308Z:RP<0NGUi101CDe<306IVIP<0OGem1025QHD30861P@<0QXJ6101kNg/3
07emO@<0OWin0`20P80408F5Q@<0Ph>30`21PH440820P0<0RHV90`1mOGd408V9R@<0Q8B40`1mOGd3
08:2PP@0OGem5038h=P001<0b>3H0`20P80407inOP<0OGem0`21PH4407alO0<0MGEe0`1oOgl40:^[
Z`<0EEEE0`1kNg/308j>SP@0Hf=S0`2BTY8307MgM`@0OWin0`1oOgl307inOP@0P8201P1oOgl408N7
Q`<0PH610`20P80307inOP@0OGem0`1kNg/30820P0@0PX:20`1nOWh307moO`@0P8200`1gMgL40<SP
f0<0NWYj1020P80607inOP@0Q8B40`1lO7`305iNGP@0N7Qh0`2HV9P308Z:RP<0PX:2101NGUh30492
@P<0TY:B101oOgl307inOP<0N7Qh1021PH4307]kN`<0Q8B4101iNGT307AdM0<0MWIf0`1oOgl409:B
TP<0PX:20`1hN7P408n?S`<0PH610`1mOGd707inOPl0b>3H0`1iNGT40861P@<0Q8B40`20P80407mo
O`<0NWYj1`1lO7`307inOPH0P8201021PH4307alO0<0PX:21021PH4307alO0<0PX:2101mOGd60861
P@<0PX:21020P80307moO`<0PH611024Q8@307moO`<0OWin1`1oOgl30861P@@0OWin0`20P8040<SP
f0<0Jf][1`2;Rh/308B4Q0@0O7al0`21PH4307emO@<0OWin101oOgl308:2PP<0Ng]k1021PH4306][
J`<0MWIf101oOgl30861P@<0RXZ:101lO7`30861P@<0P8200`1lO7`408Z:RP<0QXJ60`1nOWh407=c
L`<0R8R80`1dM7@40861P@<0N7Qh0`1lO7`308B4Q0@0Rh^;5038h=P001<0b>3H0`20P80407inOP<0
OGem0`21PH4407alO0<0MGEe0`1oOgl40:^[Z`<0EEEE0`1kNg/308j>SP@0Hf=S0`2BTY8307MgM`@0
OWin0`1oOgl307inOP@0P8201P1oOgl408N7Q`<0PH610`20P80307inOP@0OGem0`1kNg/30820P0@0
PX:20`1nOWh307moO`@0P8200`1gMgL40<SPf0<0NWYj1020P80607inOP@0Q8B40`1lO7`305iNGP@0
N7Qh0`2HV9P308Z:RP<0PX:2101NGUh30492@P<0TY:B101oOgl307inOP<0N7Qh1021PH4307]kN`<0
Q8B4101iNGT307AdM0<0MWIf0`1oOgl409:BTP<0PX:20`1hN7P408n?S`<0PH610`1mOGd707inOPl0
b>3H0`1iNGT40861P@<0Q8B40`20P80407moO`<0NWYj1`1lO7`307inOPH0P8201021PH4307alO0<0
PX:21021PH4307alO0<0PX:2101mOGd60861P@<0PX:21020P80307moO`<0PH611024Q8@307moO`<0
OWin1`1oOgl30861P@@0OWin0`20P8040<SPf0<0Jf][1`2;Rh/308B4Q0@0O7al0`21PH4307emO@<0
OWin101oOgl308:2PP<0Ng]k1021PH4306][J`<0MWIf101oOgl30861P@<0RXZ:101lO7`30861P@<0
P8200`1lO7`408Z:RP<0QXJ60`1nOWh407=cL`<0R8R80`1dM7@40861P@<0N7Qh0`1lO7`308B4Q0@0
Rh^;5038h=P001<0b>3H0`20P80407inOP<0OGem0`21PH4407alO0<0MGEe0`1oOgl40:^[Z`<0EEEE
0`1kNg/308j>SP@0Hf=S0`2BTY8307MgM`@0OWin0`1oOgl307inOP@0P8201P1oOgl408N7Q`<0PH61
0`20P80307inOP@0OGem0`1kNg/30820P0@0PX:20`1nOWh307moO`@0P8200`1gMgL40<SPf0<0NWYj
1020P80607inOP@0Q8B40`1lO7`305iNGP@0N7Qh0`2HV9P308Z:RP<0PX:2101NGUh30492@P<0TY:B
101oOgl307inOP<0N7Qh1021PH4307]kN`<0Q8B4101iNGT307AdM0<0MWIf0`1oOgl409:BTP<0PX:2
0`1hN7P408n?S`<0PH610`1mOGd707inOPl0b>3H0`1iNGT40861P@<0Q8B40`20P80407moO`<0NWYj
1`1lO7`307inOPH0P8201021PH4307alO0<0PX:21021PH4307alO0<0PX:2101mOGd60861P@<0PX:2
1020P80307moO`<0PH611024Q8@307moO`<0OWin1`1oOgl30861P@@0OWin0`20P8040<SPf0<0Jf][
1`2;Rh/308B4Q0@0O7al0`21PH4307emO@<0OWin101oOgl308:2PP<0Ng]k1021PH4306][J`<0MWIf
101oOgl30861P@<0RXZ:101lO7`30861P@<0P8200`1lO7`408Z:RP<0QXJ60`1nOWh407=cL`<0R8R8
0`1dM7@40861P@<0N7Qh0`1lO7`308B4Q0@0Rh^;5038h=P001<0b>3H0`1oOgl40820P0<0O7al0`22
PX8407emO@<0OWin0`2IVIT403hn?P<0VYZJ0`2EUID307inOP@0QXJ60`1]KFd308b<S0@0NWYj0`20
P80308B4Q0@0OWin0`1mOGd308>3P`@0Q8B40`1_Kfl307AdM0<0Shn?102JVYX308J6QPX0OWin0`1o
Ogl40820P0<0L71`1038h=P307UiN@L0OWin1`20P80307AdM0<0TI6A102BTY8305ADE0<0M7Ad0`26
QXH408N7Q`<0IfMW0`0j>SX408n?S`H0P820101oOgl308B4Q0<0KVi^1`2;Rh/308F5Q@<0P820101i
NGT3096AT@<0NWYj101lO7`308N7Q`<0PX:21021PH4307YjNPl0b>3H0`28R8P407inOP<0NWYj0`22
PX870820P0<0Ogmo1022PX8307QhN0<0Ng]k0`1oOgl708:2PP<0OWin1020P80308>3P`<0Ogmo1022
PX8307inOPH0Ogmo1020P8030861P@<0OGem101lO7`308J6QP<0Ogmo1022PX8307moO`<0Ng]k1`1o
Ogl40<SPf0<0Lg=c1022PX8307UiN@<0MWIf1027QhL308R8R0<0RHV90`24Q8@408V9R@<0OGem0`21
PH4408F5Q@<0Ph>30`1bLW8406YZJP<0NWYj0`24Q8@407inOP<0Q8B40`25QHD307MgM`@0RXZ:0`25
QHD3071`L0@0QHF50`1YJFT308f=S@@0O7al0`29RHT308Z:RP<0QXJ6101cLg<D0<SPf0004`38h=P3
07moO`@0P8200`1lO7`308:2PP@0OGem0`1nOWh309VIV@@0?Shn0`2JVYX309FEU@<0OWin1026QXH3
06e]K@<0S8b<101jNWX30820P0<0Q8B4101nOWh307emO@<0Ph>31024Q8@306m_K`<0M7Ad0`2?Shl4
09ZJVP<0QXJ62P1nOWh307moO`@0P8200`1`L7040<SPf0<0NGUi1`1nOWh70820P0<0M7Ad0`2ATI44
09:BTP<0E5AD0`1dM7@308J6QP@0QhN70`1WIfL303Xj>P@0Shn?1P20P80407moO`<0Q8B40`1^KVh7
08^;R`<0QHF50`20P80407UiN@<0TI6A0`1jNWX407alO0<0QhN70`22PX840861P@<0NWYj3`38h=P3
08R8R0@0OWin0`1jNWX308:2PPL0P8200`1oOgl408:2PP<0N7Qh0`1kNg/307moO`L0PX:20`1nOWh4
0820P0<0Ph>30`1oOgl408:2PP<0OWin1P1oOgl40820P0<0PH610`1mOGd407alO0<0QXJ60`1oOgl4
08:2PP<0Ogmo0`1kNg/707moO`@0b>3H0`1cLg<408:2PP<0NGUi0`1fMWH408N7Q`<0R8R80`29RHT3
08B4Q0@0RHV90`1mOGd30861P@@0QHF50`23Ph<3079bLP@0JVYZ0`1jNWX308B4Q0@0OWin0`24Q8@3
08F5Q@<0MgMg102:RXX308F5Q@<0L71`1025QHD306UYJ@<0SHf=101lO7`308V9R@<0RXZ:0`26QXH4
07=cLa@0b>3H000C0<SPf0<0Ogmo1020P80307alO0<0PX:2101mOGd307inOP<0VIVI100n?Sh309ZJ
VP<0UIFE0`1nOWh408J6QP<0KFe]0`2<S8`407YjNP<0P8200`24Q8@407inOP<0OGem0`23Ph<408B4
Q0<0Kfm_0`1dM7@308n?S`@0VYZJ0`26QXH:07inOP<0Ogmo1020P803071`L0@0b>3H0`1iNGT707in
OPL0P8200`1dM7@3096AT@@0TY:B0`1DE5@307AdM0<0QXJ61027QhL306MWI`<0>SXj102?Shl60820
P0@0Ogmo0`24Q8@306i^KPL0Rh^;0`25QHD30820P0@0NGUi0`2ATI4307YjNP@0O7al0`27QhL308:2
PP@0PH610`1jNWX?0<SPf0<0R8R8101nOWh307YjNP<0PX:21`20P80307moO`@0PX:20`1hN7P307]k
N`<0Ogmo1`22PX8307inOP@0P8200`23Ph<307moO`@0PX:20`1nOWh607moO`@0P8200`21PH4307em
O@@0O7al0`26QXH307moO`@0PX:20`1oOgl307]kN`L0Ogmo1038h=P307=cL`@0PX:20`1iNGT307If
MP@0QhN70`28R8P308V9R@<0Q8B41029RHT307emO@<0PH611025QHD308>3P`<0LW9b101ZJVX307Yj
NP<0Q8B4101nOWh308B4Q0<0QHF50`1gMgL408Z:RP<0QHF50`1`L70408F5Q@<0JFUY0`2=SHd407al
O0<0RHV90`2:RXX308J6QP@0Lg=c5038h=P001<0b>3H0`22PX8407QhN0<0R8R80`23Ph<408:2PP<0
Q8B40`1hN7P409NGU`<0XJ6Q0`13@d<308Z:RP@0Ph>30`27QhL307AdM0@0QXJ60`1jNWX308V9R@@0
P8200`1lO7`30861P@@0Ogmo0`1nOWh307moO`<0QXJ61020P80307YjNP<0LG5a1021PH4308:2PP<0
OWin1022PX83071`L0@0b>3H0`2:RXX408b<S0<0RHV90`1oOgl40820P0<0OGem0`1lO7`408:2PP<0
^KVi0`2HV9P3079bLP@0NWYj0`27QhL306i^KP@0>CTi0`2CTi<307moO`@0P8200`26QXH307QhN0@0
Hf=S1P26QXH3061PH0@0Ogmo0`1fMWH30:6QX@@0JVYZ0`1hN7P308R8R0@0PH610`1iNGT?0<SPf0<0
Ng]k101oOgl307emO@<0MWIf101eMGD30861P@<0O7al101fMWH307inOP<0Q8B40`20P80407inOP<0
OGem0`24Q8@407]kN`<0Ogmo0`20P80407alO0<0Ogmo0`1mOGd308>3P`X0Ogmo101nOWh307QhN0<0
QXJ61`20P80307moO`@0OGem0`1oOgl40<SPf0<0RXZ:101jNWX607EeM@@0P8200`1iNGT308N7Q`<0
MgMg101]KFd309>CT`<0RHV9101mOGd30820P0<0R8R8101]KFd306m_K`<0NWYj101oOgl307AdM0<0
P8200`2JVYX407=cL`<0RHV90`2ATI4407alO0<0KVi^0`2;Rh/407]kN`<0Ogmo0`23Ph<307QhN0@0
PX:25038h=P001<0b>3H0`22PX8407QhN0<0R8R80`23Ph<408:2PP<0Q8B40`1hN7P409NGU`<0XJ6Q
0`13@d<308Z:RP@0Ph>30`27QhL307AdM0@0QXJ60`1jNWX308V9R@@0P8200`1lO7`30861P@@0Ogmo
0`1nOWh307moO`<0QXJ61020P80307YjNP<0LG5a1021PH4308:2PP<0OWin1022PX83071`L0@0b>3H
0`2:RXX408b<S0<0RHV90`1oOgl40820P0<0OGem0`1lO7`408:2PP<0^KVi0`2HV9P3079bLP@0NWYj
0`27QhL306i^KP@0>CTi0`2CTi<307moO`@0P8200`26QXH307QhN0@0Hf=S1P26QXH3061PH0@0Ogmo
0`1fMWH30:6QX@@0JVYZ0`1hN7P308R8R0@0PH610`1iNGT?0<SPf0<0Ng]k101oOgl307emO@<0MWIf
101eMGD30861P@<0O7al101fMWH307inOP<0Q8B40`20P80407inOP<0OGem0`24Q8@407]kN`<0Ogmo
0`20P80407alO0<0Ogmo0`1mOGd308>3P`X0Ogmo101nOWh307QhN0<0QXJ61`20P80307moO`@0OGem
0`1oOgl40<SPf0<0RXZ:101jNWX607EeM@@0P8200`1iNGT308N7Q`<0MgMg101]KFd309>CT`<0RHV9
101mOGd30820P0<0R8R8101]KFd306m_K`<0NWYj101oOgl307AdM0<0P8200`2JVYX407=cL`<0RHV9
0`2ATI4407alO0<0KVi^0`2;Rh/407]kN`<0Ogmo0`23Ph<307QhN0@0PX:25038h=P001<0b>3H0`22
PX8407QhN0<0R8R80`23Ph<408:2PP<0Q8B40`1hN7P409NGU`<0XJ6Q0`13@d<308Z:RP@0Ph>30`27
QhL307AdM0@0QXJ60`1jNWX308V9R@@0P8200`1lO7`30861P@@0Ogmo0`1nOWh307moO`<0QXJ61020
P80307YjNP<0LG5a1021PH4308:2PP<0OWin1022PX83071`L0@0b>3H0`2:RXX408b<S0<0RHV90`1o
Ogl40820P0<0OGem0`1lO7`408:2PP<0^KVi0`2HV9P3079bLP@0NWYj0`27QhL306i^KP@0>CTi0`2C
Ti<307moO`@0P8200`26QXH307QhN0@0Hf=S1P26QXH3061PH0@0Ogmo0`1fMWH30:6QX@@0JVYZ0`1h
N7P308R8R0@0PH610`1iNGT?0<SPf0<0Ng]k101oOgl307emO@<0MWIf101eMGD30861P@<0O7al101f
MWH307inOP<0Q8B40`20P80407inOP<0OGem0`24Q8@407]kN`<0Ogmo0`20P80407alO0<0Ogmo0`1m
OGd308>3P`X0Ogmo101nOWh307QhN0<0QXJ61`20P80307moO`@0OGem0`1oOgl40<SPf0<0RXZ:101j
NWX607EeM@@0P8200`1iNGT308N7Q`<0MgMg101]KFd309>CT`<0RHV9101mOGd30820P0<0R8R8101]
KFd306m_K`<0NWYj101oOgl307AdM0<0P8200`2JVYX407=cL`<0RHV90`2ATI4407alO0<0KVi^0`2;
Rh/407]kN`<0Ogmo0`23Ph<307QhN0@0PX:25038h=P001<0b>3H0`22PX8407QhN0<0R8R80`23Ph<4
08:2PP<0Q8B40`1hN7P409NGU`<0XJ6Q0`13@d<308Z:RP@0Ph>30`27QhL307AdM0@0QXJ60`1jNWX3
08V9R@@0P8200`1lO7`30861P@@0Ogmo0`1nOWh307moO`<0QXJ61020P80307YjNP<0LG5a1021PH43
08:2PP<0OWin1022PX83071`L0@0b>3H0`2:RXX408b<S0<0RHV90`1oOgl40820P0<0OGem0`1lO7`4
08:2PP<0^KVi0`2HV9P3079bLP@0NWYj0`27QhL306i^KP@0>CTi0`2CTi<307moO`@0P8200`26QXH3
07QhN0@0Hf=S1P26QXH3061PH0@0Ogmo0`1fMWH30:6QX@@0JVYZ0`1hN7P308R8R0@0PH610`1iNGT?
0<SPf0<0Ng]k101oOgl307emO@<0MWIf101eMGD30861P@<0O7al101fMWH307inOP<0Q8B40`20P804
07inOP<0OGem0`24Q8@407]kN`<0Ogmo0`20P80407alO0<0Ogmo0`1mOGd308>3P`X0Ogmo101nOWh3
07QhN0<0QXJ61`20P80307moO`@0OGem0`1oOgl40<SPf0<0RXZ:101jNWX607EeM@@0P8200`1iNGT3
08N7Q`<0MgMg101]KFd309>CT`<0RHV9101mOGd30820P0<0R8R8101]KFd306m_K`<0NWYj101oOgl3
07AdM0<0P8200`2JVYX407=cL`<0RHV90`2ATI4407alO0<0KVi^0`2;Rh/407]kN`<0Ogmo0`23Ph<3
07QhN0@0PX:25038h=P001<0b>3H0`21PH4408j>SP<0X:2P0`1gMgL408F5Q@<0QXJ60`21PH4407al
O0<0BDU90`2VYZH308b<S0@0PX:20`1lO7`308J6QP@0LG5a0`2>SXh307AdM0L0OGem0`24Q8@406m_
K`<0PX:20`26QXH306ATI0@0QhN70`1eMGD308n?S`@0J6QX0`1oOgl308J6QP@0Ogmo0`1dM7@40<SP
f0<0PX:2101_Kfl60820P0L0NWYj0`24Q8@408V9R@<0J6QX0`17AdL309:BTP@0OWin0`1kNg/308N7
Q`@0LG5a0`0g=cL308Z:RP@0Ph>30`1fMWH307emO@@0V9RH0`2FUYH3092@T0<0TI6A101nOWh30861
P@<0IVIV102CTi<308B4Q0<0PX:21020P80308N7Q`l0b>3H0`1oOgl408B4Q0<0Ph>31`20P80307in
OP<0Q8B41020P8030861P@<0PX:20`1oOgl408>3P`<0PH610`1nOWh408B4Q0H0OWin101iNGT307al
O0<0Ph>30`1oOgl408:2PP<0P8200`26QXH40861P@<0Q8B40`20P8040861P@<0Ogmo0`1nOWh40820
P0<0PX:21038h=P307inOP@0N7Qh0`1fMWH3092@T0@0QHF50`20P80307=cL`<0Ti>C101eMGD308R8
R0<0MWIf101jNWX307inOP<0PX:2101lO7`309BDU0<0QhN7101iNGT3075aL@<0RHV90`2MWId407al
O0<0JFUY0`2<S8`407alO0<0P8200`21PH440820P0<0OGem0`2:RXX307inOP@0P8205038h=P001<0
b>3H0`21PH4408j>SP<0X:2P0`1gMgL408F5Q@<0QXJ60`21PH4407alO0<0BDU90`2VYZH308b<S0@0
PX:20`1lO7`308J6QP@0LG5a0`2>SXh307AdM0L0OGem0`24Q8@406m_K`<0PX:20`26QXH306ATI0@0
QhN70`1eMGD308n?S`@0J6QX0`1oOgl308J6QP@0Ogmo0`1dM7@40<SPf0<0PX:2101_Kfl60820P0L0
NWYj0`24Q8@408V9R@<0J6QX0`17AdL309:BTP@0OWin0`1kNg/308N7Q`@0LG5a0`0g=cL308Z:RP@0
Ph>30`1fMWH307emO@@0V9RH0`2FUYH3092@T0<0TI6A101nOWh30861P@<0IVIV102CTi<308B4Q0<0
PX:21020P80308N7Q`l0b>3H0`1oOgl408B4Q0<0Ph>31`20P80307inOP<0Q8B41020P8030861P@<0
PX:20`1oOgl408>3P`<0PH610`1nOWh408B4Q0H0OWin101iNGT307alO0<0Ph>30`1oOgl408:2PP<0
P8200`26QXH40861P@<0Q8B40`20P8040861P@<0Ogmo0`1nOWh40820P0<0PX:21038h=P307inOP@0
N7Qh0`1fMWH3092@T0@0QHF50`20P80307=cL`<0Ti>C101eMGD308R8R0<0MWIf101jNWX307inOP<0
PX:2101lO7`309BDU0<0QhN7101iNGT3075aL@<0RHV90`2MWId407alO0<0JFUY0`2<S8`407alO0<0
P8200`21PH440820P0<0OGem0`2:RXX307inOP@0P8205038h=P001<0b>3H0`21PH4408j>SP<0X:2P
0`1gMgL408F5Q@<0QXJ60`21PH4407alO0<0BDU90`2VYZH308b<S0@0PX:20`1lO7`308J6QP@0LG5a
0`2>SXh307AdM0L0OGem0`24Q8@406m_K`<0PX:20`26QXH306ATI0@0QhN70`1eMGD308n?S`@0J6QX
0`1oOgl308J6QP@0Ogmo0`1dM7@40<SPf0<0PX:2101_Kfl60820P0L0NWYj0`24Q8@408V9R@<0J6QX
0`17AdL309:BTP@0OWin0`1kNg/308N7Q`@0LG5a0`0g=cL308Z:RP@0Ph>30`1fMWH307emO@@0V9RH
0`2FUYH3092@T0<0TI6A101nOWh30861P@<0IVIV102CTi<308B4Q0<0PX:21020P80308N7Q`l0b>3H
0`1oOgl408B4Q0<0Ph>31`20P80307inOP<0Q8B41020P8030861P@<0PX:20`1oOgl408>3P`<0PH61
0`1nOWh408B4Q0H0OWin101iNGT307alO0<0Ph>30`1oOgl408:2PP<0P8200`26QXH40861P@<0Q8B4
0`20P8040861P@<0Ogmo0`1nOWh40820P0<0PX:21038h=P307inOP@0N7Qh0`1fMWH3092@T0@0QHF5
0`20P80307=cL`<0Ti>C101eMGD308R8R0<0MWIf101jNWX307inOP<0PX:2101lO7`309BDU0<0QhN7
101iNGT3075aL@<0RHV90`2MWId407alO0<0JFUY0`2<S8`407alO0<0P8200`21PH440820P0<0OGem
0`2:RXX307inOP@0P8205038h=P001<0b>3H0`1oOgl405=CD`<0SXj>0`21PH440820P0<0PH610`1a
LG4408Z:RP<0XZ:R0`1KFe/305ADE0@0UIFE0`1mOGd307UiN@@0RXZ:0`1]KFd308B4Q0@0PH610`22
PX8308F5Q@@0Y:BT0`1aLG4305iNGP<0]kNg102?Shl306QXJ0<0Xj>S102KVi/307QhN0<0Ng]k1020
P80307]kN`@0b>3H0`1XJ6P408Z:RP<0MgMg0`1mOGd409:BTP<0PH610`2DU9@407EeM@<0QhN70`2i
^KT306MWI`@0GEeM0`23Ph<307AdM0@0Ogmo0`24Q8@302XZ:P@0Rh^;0`1kNg/307moO`@0QHF50`1h
N7P309:BTP<0XZ:R101jNWX307IfMP<0XZ:R101gMgL307emO@<0OWin1020P80307moO`l0b>3H0`1o
Ogl408B4Q0<0OGem0`1nOWh408J6QP<0Ogmo0`2:RXX409:BTP<0P8200`25QHD70861P@<0O7al1`1o
Ogl308>3P`<0Ng]k1023Ph<308J6QP<0PX:20`21PH4407MgM`<0NGUi0`1gMgL40820P0<0Ng]k0`1o
Ogl407YjNP<0O7al0`1kNg/707inOP@0b>3H0`2HV9P40820P0<0Ogmo0`24Q8@407UiN@<0MgMg0`14
A4@308n?S`@0PH610`1fMWH30861P@@0QhN70`1jNWX308>3P`@0OWin0`2SXj<30:RXZ0@0P8200`2F
UYH30820P0<0N7Qh101dM7@307QhN0<0Jf][101dM7@308R8R0<0P820101hN7P30861P@<0Ogmo0`21
PH4407UiNA@0b>3H000C0<SPf0<0Ogmo101CDe<308j>SP<0PH611020P8030861P@<0LG5a102:RXX3
0::RXP<0Fe]K0`1DE5@409FEU@<0OGem0`1iNGT408Z:RP<0KFe]0`24Q8@40861P@<0PX:20`25QHD4
0:BTY0<0LG5a0`1NGUh30;Ng]`@0Shn?0`1XJ6P30:>SX`@0Vi^K0`1hN7P307]kN`@0P8200`1kNg/4
0<SPf0<0J6QX102:RXX307MgM`<0OGem102BTY830861P@<0U9BD101eMGD308N7Q`<0^KVi0`1WIfL4
05eMG@<0Ph>30`1dM7@407moO`<0Q8B40`0Z:RX408^;R`<0Ng]k0`1oOgl408F5Q@<0N7Qh0`2BTY83
0::RXP@0NWYj0`1fMWH30::RXP@0MgMg0`1mOGd307inOP@0P8200`1oOgl?0<SPf0<0Ogmo1024Q8@3
07emO@<0OWin1026QXH307moO`<0RXZ:102BTY830820P0<0QHF51`21PH4307alO0L0Ogmo0`23Ph<3
07]kN`@0Ph>30`26QXH308:2PP<0PH61101gMgL307UiN@<0MgMg1020P80307]kN`<0Ogmo101jNWX3
07alO0<0Ng]k1`1nOWh40<SPf0<0V9RH1020P80307moO`<0Q8B4101iNGT307MgM`<0A4A40`2?Shl4
0861P@<0MWIf0`21PH4408N7Q`<0NWYj0`23Ph<407inOP<0Xj>S0`2XZ:P40820P0<0UYJF0`20P803
07QhN0@0M7Ad0`1hN7P306][J`@0M7Ad0`28R8P30820P0@0N7Qh0`21PH4307moO`<0PH61101iNGTD
0<SPf0004`38h=P307moO`@0De=C0`2>SXh30861P@@0P8200`21PH43075aL@@0RXZ:0`2RXZ8305]K
F`<0E5AD102EUID307emO@<0NGUi102:RXX306e]K@<0Q8B41021PH4308:2PP<0QHF5102TY:@3075a
L@<0GUiN0`2g]kL408n?S`<0J6QX0`2SXj<409^KV`<0N7Qh0`1kNg/40820P0<0Ng]k1038h=P306QX
J0@0RXZ:0`1gMgL307emO@@0TY:B0`21PH4309BDU0@0MGEe0`27QhL30;Vi^@<0IfMW101MGEd308>3
P`<0M7Ad101oOgl308B4Q0<0:RXZ102;Rh/307]kN`<0Ogmo1025QHD307QhN0<0TY:B0`2RXZ8407Yj
NP<0MWIf0`2RXZ8407MgM`<0OGem0`1nOWh40820P0<0Ogmo3`38h=P307moO`@0Q8B40`1mOGd307in
OP@0QXJ60`1oOgl308Z:RP@0TY:B0`20P80308F5Q@L0PH610`1lO7`707moO`<0Ph>30`1kNg/408>3
P`<0QXJ60`22PX830861P@@0MgMg0`1iNGT307MgM`@0P8200`1kNg/307moO`@0NWYj0`1lO7`307]k
N`L0OWin1038h=P309RHV0@0P8200`1oOgl308B4Q0@0NGUi0`1gMgL304A4A0<0Shn?1021PH4307If
MP<0PH611027QhL307YjNP<0Ph>3101nOWh30:>SX`<0Z:RX1020P80309JFUP<0P8200`1hN7P407Ad
M0<0N7Qh0`1[Jf/407AdM0<0R8R80`20P80407QhN0<0PH610`1oOgl30861P@@0NGUi5038h=P001<0
b>3H0`1`L70403Hf=PH0O7al102BTY8307EeM@<0OGem101jNWX307AdM0<0L71`0`3:b/X406QXJ0<0
OGem0`27QhL407emO@<0R8R80`1hN7P408F5Q@<0PX:20`20P8070861P@<0MGEe0`2<S8`407]kN`<0
R8R80`1lO7`407YjNP<0PX:20`21PH4408:2PP<0Ng]k1038h=P30861P@@0Ng]k0`1mOGd308V9R@@0
QXJ60`2:RXX307alO0@0PH610`25QHD304a<C0<0Ng]k102b/[8308R8R0<0P8201023Ph<308Z:RP<0
VYZJ100_;bl308N7Q`<0OWin101dM7@30820P0<0Q8B40`1jNWX4071`L0<0TY:B0`1_Kfl408Z:RP<0
NGUi0`1mOGd40820P0<0QHF53`38h=P308F5Q@@0PH610`1kNg/308B4Q0@0Ng]k0`1lO7`308F5Q@@0
NGUi0`23Ph<307emO@<0OWin1`23Ph<70820P0<0O7al0`24Q8@407=cL`<0NGUi0`1mOGd307]kN`L0
PH610`25QHD408:2PP<0Ogmo0`1mOGd407inOP<0P8200`1oOgl408>3P`<0PH611038h=P3092@T0@0
R8R80`1jNWX307EeM@@0Lg=c0`2/[:`3071`L0<0NWYj101aLG43096AT@<0MWIf101mOGd307YjNP<0
P820101nOWh307alO0<0W9bL1031`L4308N7Q`<0O7al0`28R8P408>3P`<0QhN70`1lO7`407QhN0<0
MgMg0`2<S8`408B4Q0<0P8200`22PX8308B4Q0@0NWYj5038h=P001<0b>3H0`1`L70403Hf=PH0O7al
102BTY8307EeM@<0OGem101jNWX307AdM0<0L71`0`3:b/X406QXJ0<0OGem0`27QhL407emO@<0R8R8
0`1hN7P408F5Q@<0PX:20`20P8070861P@<0MGEe0`2<S8`407]kN`<0R8R80`1lO7`407YjNP<0PX:2
0`21PH4408:2PP<0Ng]k1038h=P30861P@@0Ng]k0`1mOGd308V9R@@0QXJ60`2:RXX307alO0@0PH61
0`25QHD304a<C0<0Ng]k102b/[8308R8R0<0P8201023Ph<308Z:RP<0VYZJ100_;bl308N7Q`<0OWin
101dM7@30820P0<0Q8B40`1jNWX4071`L0<0TY:B0`1_Kfl408Z:RP<0NGUi0`1mOGd40820P0<0QHF5
3`38h=P308F5Q@@0PH610`1kNg/308B4Q0@0Ng]k0`1lO7`308F5Q@@0NGUi0`23Ph<307emO@<0OWin
1`23Ph<70820P0<0O7al0`24Q8@407=cL`<0NGUi0`1mOGd307]kN`L0PH610`25QHD408:2PP<0Ogmo
0`1mOGd407inOP<0P8200`1oOgl408>3P`<0PH611038h=P3092@T0@0R8R80`1jNWX307EeM@@0Lg=c
0`2/[:`3071`L0<0NWYj101aLG43096AT@<0MWIf101mOGd307YjNP<0P820101nOWh307alO0<0W9bL
1031`L4308N7Q`<0O7al0`28R8P408>3P`<0QhN70`1lO7`407QhN0<0MgMg0`2<S8`408B4Q0<0P820
0`22PX8308B4Q0@0NWYj5038h=P001<0b>3H0`1`L70403Hf=PH0O7al102BTY8307EeM@<0OGem101j
NWX307AdM0<0L71`0`3:b/X406QXJ0<0OGem0`27QhL407emO@<0R8R80`1hN7P408F5Q@<0PX:20`20
P8070861P@<0MGEe0`2<S8`407]kN`<0R8R80`1lO7`407YjNP<0PX:20`21PH4408:2PP<0Ng]k1038
h=P30861P@@0Ng]k0`1mOGd308V9R@@0QXJ60`2:RXX307alO0@0PH610`25QHD304a<C0<0Ng]k102b
/[8308R8R0<0P8201023Ph<308Z:RP<0VYZJ100_;bl308N7Q`<0OWin101dM7@30820P0<0Q8B40`1j
NWX4071`L0<0TY:B0`1_Kfl408Z:RP<0NGUi0`1mOGd40820P0<0QHF53`38h=P308F5Q@@0PH610`1k
Ng/308B4Q0@0Ng]k0`1lO7`308F5Q@@0NGUi0`23Ph<307emO@<0OWin1`23Ph<70820P0<0O7al0`24
Q8@407=cL`<0NGUi0`1mOGd307]kN`L0PH610`25QHD408:2PP<0Ogmo0`1mOGd407inOP<0P8200`1o
Ogl408>3P`<0PH611038h=P3092@T0@0R8R80`1jNWX307EeM@@0Lg=c0`2/[:`3071`L0<0NWYj101a
LG43096AT@<0MWIf101mOGd307YjNP<0P820101nOWh307alO0<0W9bL1031`L4308N7Q`<0O7al0`28
R8P408>3P`<0QhN70`1lO7`407QhN0<0MgMg0`2<S8`408B4Q0<0P8200`22PX8308B4Q0@0NWYj5038
h=P001<0b>3H0`2DU9@404e=C@<0OWin0`2<S8`405QHF0<0RXZ:0`21PH4407YjNP<0PH610`2QXJ43
03lo?`@0S8b<0`2=SHd30861P@@0O7al0`21PH4308R8R0@0O7al0`24Q8@307inOP@0NWYj0`20P806
0861P@@0QHF50`24Q8@3092@T0@0MgMg0`1lO7`307inOP@0P8200`1nOWh40<SPf0<0SHf=101kNg/3
0820P0<0O7al101hN7P309:BTP<0Ng]k1024Q8@305ADE0<0T92@0`2HV9P404Q8B0<0Ng]k0`24Q8@7
07alO0<0R8R8102LW9`3034a<@<0Q8B4101mOGd307inOP<0MGEe0`1hN7P406e]K@<0LW9b0`2@T904
08^;R`<0NWYj0`1mOGd408J6QP<0OWin3`38h=P30820P0@0OWin0`23Ph<307YjNP@0MWIf0`1jNWX3
07]kN`@0QHF50`1jNWX308B4Q0<0QHF5101iNGT307alO0<0OWin1`20P80307]kN`@0QXJ60`1mOGd3
07]kN`<0P8201022PX830820P0<0OGem102:RXX307]kN`<0Ogmo1020P8060861P@L0OWin1038h=P3
075aL@@0MWIf0`27QhL3075aL@@0TY:B0`2?Shl307UiN@<0MGEe102YZJT308n?S`<0OGem1026QXH3
07AdM0<0Ph>31029RHT60820P0@0/[:b0`2PX:0307=cL`<0UYJF1023Ph<308f=S@<0OWin102JVYX3
07alO0<0PX:21021PH430820P0<0OGem0`1fMWH407=cLa@0b>3H000C0<SPf0<0U9BD101=CDd307in
OP<0S8b<101HF5P308Z:RP<0PH61101jNWX30861P@<0XJ6Q0`0o?cl408b<S0<0SHf=0`21PH4407al
O0<0PH610`28R8P407alO0<0Q8B40`1nOWh407YjNP<0P8201P21PH4408F5Q@<0Q8B40`2@T90407Mg
M`<0O7al0`1nOWh40820P0<0OWin1038h=P308f=S@@0Ng]k0`20P80307alO0@0N7Qh0`2BTY8307]k
N`@0Q8B40`1DE5@3092@T0<0V9RH1018B4P307]kN`<0Q8B41`1lO7`308R8R0@0W9bL0`0a<C4308B4
Q0@0OGem0`1nOWh307EeM@<0N7Qh101]KFd3079bLP<0T92@102;Rh/307YjNP<0OGem1026QXH307in
OPl0b>3H0`20P80407inOP<0Ph>30`1jNWX407IfMP<0NWYj0`1kNg/408F5Q@<0NWYj0`24Q8@308F5
Q@@0NGUi0`1lO7`307inOPL0P8200`1kNg/408J6QP<0OGem0`1kNg/30820P0@0PX:20`20P80307em
O@@0RXZ:0`1kNg/307moO`@0P8201P21PH4707inOP@0b>3H0`1aLG4407IfMP<0QhN70`1aLG4409:B
TP<0Shn?0`1iNGT307EeM@@0ZJVY0`2?Shl307emO@@0QXJ60`1dM7@308>3P`@0RHV91P20P8040;:b
/P<0X:2P0`1cLg<309JFUP@0Ph>30`2=SHd307inOP@0VYZJ0`1lO7`308:2PP@0PH610`20P80307em
O@<0MWIf101cLg<D0<SPf0004`38h=P309BDU0@0CDe=0`1nOWh308b<S0@0F5QH0`2:RXX30861P@@0
NWYj0`21PH430:6QX@<0?clo102<S8`308f=S@<0PH61101lO7`30861P@<0R8R8101lO7`308B4Q0<0
OWin101jNWX30820P0H0PH611025QHD308B4Q0<0T92@101gMgL307alO0<0OWin1020P80307inOP@0
b>3H0`2=SHd407]kN`<0P8200`1lO7`407QhN0<0TY:B0`1kNg/408B4Q0<0E5AD0`2@T90309RHV0@0
B4Q80`1kNg/308B4Q0L0O7al0`28R8P409bLW0<0<C4a0`24Q8@407emO@<0OWin0`1eMGD307QhN0@0
KFe]0`1bLW83092@T0@0Rh^;0`1jNWX307emO@@0QXJ60`1nOWh?0<SPf0<0P820101nOWh308>3P`<0
NWYj101fMWH307YjNP<0Ng]k1025QHD307YjNP<0Q8B40`25QHD407UiN@<0O7al0`1nOWh70820P0<0
Ng]k1026QXH307emO@<0Ng]k0`20P80408:2PP<0P8200`1mOGd408Z:RP<0Ng]k0`1oOgl40820P0H0
PH611`1nOWh40<SPf0<0LG5a101fMWH308N7Q`<0LG5a102BTY8308n?S`<0NGUi0`1eMGD40:VYZ@<0
Shn?0`1mOGd408J6QP<0M7Ad0`23Ph<408V9R@H0P820102b/[830:2PX0<0Lg=c0`2FUYH408>3P`<0
SHf=0`1nOWh409ZJVP<0O7al0`22PX840861P@<0P8200`1mOGd307IfMP@0Lg=c5038h=P001<0b>3H
0`27QhL406=SH`<0Ogmo0`1mOGd409JFUPH0NWYj1024Q8@3079bLP<0NGUi0`2FUYH409>CT`<0H61P
0`2?Shl407moO`<0MWIf0`29RHT407]kN`<0P8200`28R8P407alO0<0Ph>30`1/K6`306IVIP@0W9bL
0`2:RXX3071`L0@0MWIf0`22PX8307emO@@0Ph>30`1nOWh40<SPf0<0R8R8101cLg<3075aL@<0OWin
1026QXH308:2PP<0QHF5101UIFD307=cL`<0]KFe0`1gMgL40;Bd]0<0IFEU0`1EEED407emO@<0Ph>3
0`1fMWH408J6QP<0OWin0`1:BTX409ZJVP<0QHF50`1jNWX308J6QP@0R8R80`2DU9@307EeM@@0OWin
0`1cLg<308:2PP@0Ng]k0`1nOWh?0<SPf0<0P820101nOWh308>3P`<0NWYj101fMWH307YjNP<0Ng]k
1025QHD307YjNP<0Q8B40`25QHD407UiN@<0O7al0`1nOWh70820P0<0Ng]k1026QXH307emO@<0Ng]k
0`20P80408:2PP<0P8200`1mOGd408Z:RP<0Ng]k0`1oOgl40820P0H0PH611`1nOWh40<SPf0<0LG5a
101fMWH308N7Q`<0LG5a102BTY8308n?S`<0NGUi0`1eMGD40:VYZ@<0Shn?0`1mOGd408J6QP<0M7Ad
0`23Ph<408V9R@H0P820102b/[830:2PX0<0Lg=c0`2FUYH408>3P`<0SHf=0`1nOWh409ZJVP<0O7al
0`22PX840861P@<0P8200`1mOGd307IfMP@0Lg=c5038h=P001<0b>3H0`27QhL406=SH`<0Ogmo0`1m
OGd409JFUPH0NWYj1024Q8@3079bLP<0NGUi0`2FUYH409>CT`<0H61P0`2?Shl407moO`<0MWIf0`29
RHT407]kN`<0P8200`28R8P407alO0<0Ph>30`1/K6`306IVIP@0W9bL0`2:RXX3071`L0@0MWIf0`22
PX8307emO@@0Ph>30`1nOWh40<SPf0<0R8R8101cLg<3075aL@<0OWin1026QXH308:2PP<0QHF5101U
IFD307=cL`<0]KFe0`1gMgL40;Bd]0<0IFEU0`1EEED407emO@<0Ph>30`1fMWH408J6QP<0OWin0`1:
BTX409ZJVP<0QHF50`1jNWX308J6QP@0R8R80`2DU9@307EeM@@0OWin0`1cLg<308:2PP@0Ng]k0`1n
OWh?0<SPf0<0PX:21020P8030861P@<0PX:21020P80308>3P`<0QHF5101dM7@308R8R0<0MgMg0`1o
Ogl408F5Q@<0Q8B41`1mOGd307alO0<0PX:2101kNg/30820P0<0QHF50`1nOWh408>3P`<0PX:20`21
PH4407alO0<0Ph>30`1nOWh40820P0<0QHF50`20P80408:2PP<0O7al1038h=P308Z:RP@0Ogmo0`25
QHD308b<S0@0PH610`20P80307YjNP<0Vi^K102b/[8306MWI`<0Lg=c1022PX8308f=S@<0S8b<1024
Q8@307UiN@<0NWYj101nOWh308R8R0<0FEUI0`1TI6@40861P@<0Shn?0`2<S8`408B4Q0<0QHF50`21
PH4407moO`<0QHF50`22PX8307moO`@0NWYj5038h=P001<0b>3H0`27QhL406=SH`<0Ogmo0`1mOGd4
09JFUPH0NWYj1024Q8@3079bLP<0NGUi0`2FUYH409>CT`<0H61P0`2?Shl407moO`<0MWIf0`29RHT4
07]kN`<0P8200`28R8P407alO0<0Ph>30`1/K6`306IVIP@0W9bL0`2:RXX3071`L0@0MWIf0`22PX83
07emO@@0Ph>30`1nOWh40<SPf0<0R8R8101cLg<3075aL@<0OWin1026QXH308:2PP<0QHF5101UIFD3
07=cL`<0]KFe0`1gMgL40;Bd]0<0IFEU0`1EEED407emO@<0Ph>30`1fMWH408J6QP<0OWin0`1:BTX4
09ZJVP<0QHF50`1jNWX308J6QP@0R8R80`2DU9@307EeM@@0OWin0`1cLg<308:2PP@0Ng]k0`1nOWh?
0<SPf0<0PX:21020P8030861P@<0PX:21020P80308>3P`<0QHF5101dM7@308R8R0<0MgMg0`1oOgl4
08F5Q@<0Q8B41`1mOGd307alO0<0PX:2101kNg/30820P0<0QHF50`1nOWh408>3P`<0PX:20`21PH44
07alO0<0Ph>30`1nOWh40820P0<0QHF50`20P80408:2PP<0O7al1038h=P308Z:RP@0Ogmo0`25QHD3
08b<S0@0PH610`20P80307YjNP<0Vi^K102b/[8306MWI`<0Lg=c1022PX8308f=S@<0S8b<1024Q8@3
07UiN@<0NWYj101nOWh308R8R0<0FEUI0`1TI6@40861P@<0Shn?0`2<S8`408B4Q0<0QHF50`21PH44
07moO`<0QHF50`22PX8307moO`@0NWYj5038h=P001<0b>3H0`27QhL406=SH`<0Ogmo0`1mOGd409JF
UPH0NWYj1024Q8@3079bLP<0NGUi0`2FUYH409>CT`<0H61P0`2?Shl407moO`<0MWIf0`29RHT407]k
N`<0P8200`28R8P407alO0<0Ph>30`1/K6`306IVIP@0W9bL0`2:RXX3071`L0@0MWIf0`22PX8307em
O@@0Ph>30`1nOWh40<SPf0<0R8R8101cLg<3075aL@<0OWin1026QXH308:2PP<0QHF5101UIFD307=c
L`<0]KFe0`1gMgL40;Bd]0<0IFEU0`1EEED407emO@<0Ph>30`1fMWH408J6QP<0OWin0`1:BTX409ZJ
VP<0QHF50`1jNWX308J6QP@0R8R80`2DU9@307EeM@@0OWin0`1cLg<308:2PP@0Ng]k0`1nOWh?0<SP
f0<0PX:21020P8030861P@<0PX:21020P80308>3P`<0QHF5101dM7@308R8R0<0MgMg0`1oOgl408F5
Q@<0Q8B41`1mOGd307alO0<0PX:2101kNg/30820P0<0QHF50`1nOWh408>3P`<0PX:20`21PH4407al
O0<0Ph>30`1nOWh40820P0<0QHF50`20P80408:2PP<0O7al1038h=P308Z:RP@0Ogmo0`25QHD308b<
S0@0PH610`20P80307YjNP<0Vi^K102b/[8306MWI`<0Lg=c1022PX8308f=S@<0S8b<1024Q8@307Ui
N@<0NWYj101nOWh308R8R0<0FEUI0`1TI6@40861P@<0Shn?0`2<S8`408B4Q0<0QHF50`21PH4407mo
O`<0QHF50`22PX8307moO`@0NWYj5038h=P001<0b>3H0`24Q8@407IfMP<0Ogmo0`1YJFT40861P@<0
PX:20`2;Rh/406a/K0<0L71`0`1^KVh308n?S`@0F5QH0`2l_;`3069RHP@0PH610`1oOgl308J6QP@0
OGem0`20P80307alO0@0R8R80`1jNWX308N7Q`<0O7al1`1oOgl30820P0@0Ph>30`21PH4307inOP@0
P8200`1mOGd40<SPf0<0Q8B4101^KVh3071`L0<0RHV9101lO7`308B4Q0<0L71`101lO7`307QhN0<0
IfMW0`1lO7`405EEE@<0MgMg0`2][Jd4071`L0<0Ng]k0`23Ph<407QhN0<0R8R80`1`L70408F5Q@<0
Ti>C0`1oOgl307]kN`@0Ogmo0`1bLW8707UiN@<0Ogmo0`1iNGT408>3P`<0OGem3`38h=P307emO@@0
QhN70`23Ph<30861P@L0OWin0`25QHD407YjNP<0NGUi0`20P80307QhN0@0PH610`1kNg/30820P0@0
OWin0`1oOgl308:2PP@0PH610`1nOWh307moO`<0OWin1020P80307UiN@<0OWin101mOGd307]kN`<0
OGem1021PH430820P0<0Ogmo1021PH4308>3P`@0b>3H0`26QXH408:2PP<0O7al0`2>SXh4075aL@<0
QHF50`1NGUh30:JVYP@0XZ:R0`1nOWh308>3P`@0T92@0`23Ph<308Z:RP@0S8b<1P1gMgL407emO@<0
NGUi0`1gMgL303hn?P@0NWYj0`2CTi<3092@T0@0QhN70`1eMGD307IfMP@0N7Qh0`1mOGd308>3P`<0
P8201023Ph<D0<SPf0004`38h=P308B4Q0@0MWIf0`1oOgl306UYJ@@0PH610`22PX8308^;R`@0K6a/
0`1`L70306i^KP<0Shn?101HF5P30;bl_0<0HV9R1021PH4307moO`<0QXJ6101mOGd30820P0<0O7al
1028R8P307YjNP<0QhN70`1lO7`707moO`<0P8201023Ph<30861P@<0OWin1020P80307emO@@0b>3H
0`24Q8@406i^KP<0L71`0`29RHT407alO0<0Q8B40`1`L70407alO0<0N7Qh0`1WIfL307alO0@0EEEE
0`1gMgL30:f][@@0L71`0`1kNg/308>3P`@0N7Qh0`28R8P3071`L0@0QHF50`2CTi<307moO`<0Ng]k
101oOgl3079bLPL0NGUi0`1oOgl307UiN@@0Ph>30`1mOGd?0<SPf0<0OGem1027QhL308>3P`<0PH61
1`1nOWh308F5Q@@0NWYj0`1iNGT30820P0<0N7Qh1021PH4307]kN`<0P820101nOWh307moO`<0PX:2
1021PH4307inOP<0Ogmo0`1nOWh40820P0<0NGUi0`1nOWh407emO@<0Ng]k0`1mOGd40861P@<0P820
0`1oOgl40861P@<0Ph>31038h=P308J6QP@0PX:20`1lO7`308j>SP@0LG5a0`25QHD305iNGP<0YZJV
102RXZ8307inOP<0Ph>3102@T90308>3P`<0RXZ:102<S8`607MgM`@0OGem0`1iNGT307MgM`<0?Shn
101jNWX309>CT`<0T92@1027QhL307EeM@<0MWIf101hN7P307emO@<0Ph>30`20P80408>3Pa@0b>3H
000C0<SPf0<0Q8B4101fMWH307moO`<0JFUY1021PH4308:2PP<0Rh^;101/K6`3071`L0<0KVi^0`2?
Shl405QHF0<0_;bl0`1RHV840861P@<0Ogmo0`26QXH407emO@<0P8200`1lO7`408R8R0<0NWYj0`27
QhL307alO0L0Ogmo0`20P80408>3P`<0PH610`1nOWh40820P0<0OGem1038h=P308B4Q0@0KVi^0`1`
L70308V9R@@0O7al0`24Q8@3071`L0@0O7al0`1hN7P306MWI`<0O7al101EEED307MgM`<0[Jf]101`
L70307]kN`<0Ph>3101hN7P308R8R0<0L71`1025QHD309>CT`<0Ogmo0`1kNg/407moO`<0LW9b1`1i
NGT307moO`<0NGUi1023Ph<307emO@l0b>3H0`1mOGd408N7Q`<0Ph>30`21PH4707inOP<0QHF5101j
NWX307UiN@<0P8200`1hN7P40861P@<0Ng]k0`20P80407inOP<0Ogmo0`22PX840861P@<0OWin0`1o
Ogl307inOP@0P8200`1iNGT307inOP@0OGem0`1kNg/307emO@@0PH610`20P80307moO`@0PH610`23
Ph<40<SPf0<0QXJ61022PX8307alO0<0SXj>101aLG4308F5Q@<0GUiN0`2VYZH40::RXP<0OWin0`23
Ph<4092@T0<0Ph>30`2:RXX408b<S0H0MgMg101mOGd307UiN@<0MgMg0`0n?Sh407YjNP<0Ti>C0`2@
T90408N7Q`<0MGEe0`1fMWH407QhN0<0OGem0`23Ph<30820P0@0Ph>35038h=P001<0b>3H0`1`L704
07]kN`<0Rh^;0`1jNWX408B4Q0<0QXJ60`2=SHd408J6QP<0Kfm_0`2j^[X308j>SP@0ZJVY0`1=CDd3
09jNWP@0MgMg0`25QHD307=cL`@0PX:20`1fMWH308F5Q@@0NGUi0`28R8P307inOP<0Ogmo101iNGT3
07moO`<0Ph>31021PH430820P0<0Ph>3101nOWh308>3P`@0b>3H0`1jNWX408^;R`<0M7Ad1`22PX83
08N7Q`<0P820101jNWX309>CT`<0N7Qh0`1OGel40820P0<0VYZJ0`1CDe<40;Ng]`<0QHF50`1mOGd4
07inOP<0OGem0`20P80406UYJ@<0];Bd0`1GEeL308N7Q`L0O7al0`25QHD407inOP<0OGem0`1oOgl4
08:2PP<0Ph>33`38h=P30820P0@0Ng]k0`26QXH308:2PP@0PH610`1mOGd308R8R0@0OGem0`1oOgl3
0820P0<0O7al1024Q8@308F5Q@<0OGem1022PX8607inOP@0PH610`20P80307moO`<0PX:21025QHD3
08b<S0<0PX:2101mOGd307moO`L0Ph>30`20P80308:2PP@0Ph>30`24Q8@40<SPf0<0Ng]k102FUYH3
07AdM0<0Ng]k101lO7`30861P@<0QHF50`1mOGd40820P0<0MgMg0`2QXJ4407IfMP<0RHV90`2@T904
06i^KP<0LG5a0`1hN7P707inOP<0OGem0`20P8040::RXP<0Z:RX0`1cLg<407emO@<0MGEe0`23Ph<4
07YjNP<0Q8B41P23Ph<40820P1@0b>3H000C0<SPf0<0L71`101kNg/308^;R`<0NWYj1024Q8@308J6
QP<0SHf=1026QXH306m_K`<0^[Zj0`2>SXh40:VYZ@<0CDe=0`2NWYh407MgM`<0QHF50`1cLg<408:2
PP<0MWIf0`25QHD407UiN@<0R8R80`1nOWh307moO`@0NGUi0`1oOgl308>3P`@0PH610`20P80308>3
P`@0OWin0`23Ph<40<SPf0<0NWYj102;Rh/307AdM0L0PX:20`27QhL30820P0@0NWYj0`2CTi<307Qh
N0<0GemO1020P80309ZJVP<0De=C102g]kL308F5Q@<0OGem101nOWh307emO@<0P820101YJFT30;Bd
]0<0EeMG0`27QhL707alO0<0QHF5101nOWh307emO@<0Ogmo1022PX8308>3P`l0b>3H0`20P80407]k
N`<0QXJ60`22PX840861P@<0OGem0`28R8P407emO@<0Ogmo0`20P80307alO0@0Q8B40`25QHD307em
O@@0PX:21P1nOWh40861P@<0P8200`1oOgl308:2PP@0QHF50`2<S8`308:2PP@0OGem0`1oOgl708>3
P`<0P8200`22PX8408>3P`<0Q8B41038h=P307]kN`@0UYJF0`1dM7@307]kN`@0O7al0`21PH4308F5
Q@<0OGem1020P80307MgM`<0XJ6Q101fMWH308V9R@<0T92@101^KVh3075aL@<0N7Qh1`1nOWh307em
O@<0P820102RXZ830:RXZ0<0Lg=c101mOGd307EeM@<0Ph>3101jNWX308B4Q0H0Ph>31020P80D0<SP
f0004`38h=P3071`L0@0Ng]k0`2;Rh/307YjNP@0Q8B40`26QXH308f=S@@0QXJ60`1_Kfl30;Zj^P<0
SXj>102YZJT304e=C@<0WYjN101gMgL308F5Q@<0Lg=c1022PX8307IfMP<0QHF5101iNGT308R8R0<0
OWin0`1oOgl407UiN@<0Ogmo0`23Ph<40861P@<0P8200`23Ph<407inOP<0Ph>31038h=P307YjNP@0
Rh^;0`1dM7@708:2PP<0QhN70`20P80407YjNP<0Ti>C0`1hN7P305mOG`@0P8200`2JVYX305=CD`@0
]kNg0`25QHD307emO@@0OWin0`1mOGd30820P0@0JFUY0`2d];@305MGE`<0QhN71`1lO7`308F5Q@@0
OWin0`1mOGd307moO`@0PX:20`23Ph<?0<SPf0<0P820101kNg/308J6QP<0PX:21021PH4307emO@<0
R8R8101mOGd307moO`<0P8200`1lO7`408B4Q0<0QHF50`1mOGd408:2PPH0OWin1021PH430820P0<0
Ogmo0`22PX8408F5Q@<0S8b<0`22PX8407emO@<0Ogmo1`23Ph<30820P0<0PX:21023Ph<308B4Q0@0
b>3H0`1kNg/409JFUP<0M7Ad0`1kNg/407alO0<0PH610`25QHD307emO@@0P8200`1gMgL30:6QX@@0
MWIf0`29RHT3092@T0@0KVi^0`1aLG4307QhN0L0OWin0`1mOGd30820P0@0XZ:R0`2XZ:P307=cL`@0
OGem0`1eMGD308>3P`@0NWYj0`24Q8@608>3P`@0P8205038h=P001<0b>3H0`1nOWh408V9R@<0P820
0`24Q8@408:2PP<0OGem0`2QXJ4407UiN@<0Q8B40`2/[:`3051@D0@0Kfm_0`2SXj<307]kN`@0L71`
0`2>SXh307YjNP@0Q8B40`1nOWh308:2PP@0Ogmo0`1fMWH308N7Q`<0OGem101oOgl30820P0X0Ogmo
0`1nOWh40861P@<0Ng]k1038h=P306][J`@0QHF50`1DE5@306i^KP@0SXj>0`21PH4307alO0@0PH61
0`1kNg/309BDU0<0Y:BT101gMgL30861P@<0[:b/101IFET308j>SP<0RXZ:101nOWh307alO0<0Ph>3
1020P80308b<S0<0M7Ad0`1fMWH408N7Q`H0OGem101lO7`308:2PP<0OGem1022PX8308B4Q0l0b>3H
0`24Q8@407YjNP<0OGem0`21PH4407moO`<0NWYj0`1hN7P407YjNP<0P8200`22PX8308>3P`@0PH61
0`1bLW8308>3P`@0NWYj0`1iNGT307emO@@0Ogmo2@21PH440820P0<0O7al1`1kNg/30861P@<0OWin
1021PH4307moO`L0O7al0`1nOWh40<SPf0<0UiNG101_Kfl306ATI0<0>3Ph101`L70307YjNP<0OWin
0`1cLg<40861P@<0M7Ad0`2OWil407inOP<0Lg=c0`2EUID407UiN@<0K6a/0`1gMgL407QhN0<0PH61
0`1oOgl308>3P`@0PX:20`2;Rh/3075aL@@0RHV90`26QXH308N7Q`@0QHF50`24Q8@307emO@<0OWin
101mOGdD0<SPf0004`38h=P307inOP@0RHV90`20P80308B4Q0@0PX:20`1mOGd30:6QX@@0NGUi0`24
Q8@30:b/[0<0D51@101_Kfl30:>SX`<0Ng]k101`L70308j>SP<0NWYj1024Q8@307inOP<0PX:2101o
Ogl307IfMP<0QhN70`1mOGd407moO`<0P8202P1oOgl307inOP@0PH610`1kNg/40<SPf0<0Jf][1025
QHD305ADE0<0KVi^102>SXh30861P@<0O7al1021PH4307]kN`<0U9BD0`2TY:@407MgM`<0PH610`2/
[:`405UIF@<0SXj>0`2:RXX407inOP<0O7al0`23Ph<40820P0<0S8b<0`1dM7@307IfMP@0QhN71P1m
OGd407alO0<0PX:20`1mOGd408:2PP<0Q8B43`38h=P308B4Q0@0NWYj0`1mOGd30861P@@0Ogmo0`1j
NWX307QhN0@0NWYj0`20P80308:2PP<0Ph>31021PH43079bLP<0Ph>3101jNWX307UiN@<0OGem101o
Ogl90861P@@0P8200`1lO7`707]kN`<0PH610`1nOWh40861P@<0Ogmo1`1lO7`307inOP@0b>3H0`2G
UiL406m_K`<0I6AT0`0h>3P4071`L0<0NWYj0`1nOWh307=cL`@0PH610`1dM7@309nOW`@0OWin0`1c
Lg<309FEU@@0NGUi0`1/K6`307MgM`@0N7Qh0`21PH4307moO`<0Ph>31022PX8308^;R`<0LG5a1029
RHT308J6QP<0QhN71025QHD308B4Q0<0OGem0`1nOWh407emOA@0b>3H000C0<SPf0<0OWin1029RHT3
0820P0<0Q8B41022PX8307emO@<0XJ6Q101iNGT308B4Q0<0[:b/0`1@D50406m_K`<0Xj>S0`1kNg/4
071`L0<0SXj>0`1jNWX408B4Q0<0OWin0`22PX8407moO`<0MWIf0`27QhL307emO@@0Ogmo0`20P80:
07moO`<0OWin1021PH4307]kN`@0b>3H0`1[Jf/408F5Q@<0E5AD0`1^KVh408j>SP<0PH610`1lO7`4
0861P@<0Ng]k0`2DU9@30:BTY0@0MgMg0`21PH430:b/[0@0FEUI0`2>SXh308Z:RP@0OWin0`1lO7`3
08>3P`@0P8200`2<S8`307AdM0<0MWIf1027QhL607emO@@0O7al0`22PX8307emO@@0PX:20`24Q8@?
0<SPf0<0Q8B4101jNWX307emO@<0PH61101oOgl307YjNP<0N7Qh101jNWX30820P0<0PX:20`23Ph<4
0861P@<0LW9b0`23Ph<407YjNP<0NGUi0`1mOGd407moO`T0PH611020P80307alO0L0Ng]k0`21PH43
07inOP@0PH610`1oOgl707alO0<0OWin1038h=P309NGU`@0Kfm_0`1TI6@303Ph>0@0L71`0`1jNWX3
07inOP<0Lg=c1021PH4307AdM0<0WinO101nOWh307=cL`<0UIFE101iNGT306a/K0<0MgMg101hN7P3
0861P@<0Ogmo0`23Ph<408:2PP<0Rh^;0`1aLG4408V9R@<0QXJ60`27QhL408F5Q@<0Q8B40`1mOGd3
07inOP@0OGem5038h=P001<0b>3H0`1mOGd407EeM@<0R8R80`21PH4408N7Q`<0OWin0`2?Shl404a<
C0<0J6QX0`24Q8@309BDU0@0Y:BT0`1oOgl306YZJP@0Rh^;0`1]KFd308V9R@@0Ogmo0`1nOWh308>3
P`@0Lg=c0`2KVi/307UiN@<0Ogmo1021PH4307alO0<0Ogmo1022PX8307inOP<0Ogmo101nOWh307Ui
N@@0b>3H0`2IVIT408N7Q`<0SHf=0`1=CDd407emO@<0QhN70`26QXH407inOP<0UYJF0`1mOGd30:2P
X0@0PH610`1lO7`308J6QP@0X:2P0`1UIFD307IfMP@0PX:20`28R8P307inOP@0QHF50`1iNGT308f=
S@<0MgMg1020P80307YjNP<0QHF51024Q8@307inOP<0Q8B41021PH4308:2PPl0b>3H0`28R8P40861
P@<0Ogmo0`20P8070861P@<0PX:21024Q8@30820P0<0OGem0`21PH440820P0<0PH611`1lO7`60820
P0@0PX:20`21PH430820P0<0PH611022PX8308>3P`L0PH610`1kNg/307inOP@0P8200`22PX830861
P@L0P8201038h=P308n?S`@0N7Qh0`1^KVh306EUI@@0Ogmo0`1VIVH30861P@<0Ph>31029RHT307al
O0<0LG5a101gMgL307UiN@<0P820101aLG43079bLP<0P820101lO7`307inOP<0OGem0`22PX8707in
OP<0PX:2102?Shl308j>SPL0OWin0`20P80307inOP<0PH61101kNg/D0<SPf0004`38h=P307emO@@0
MGEe0`28R8P30861P@@0QhN70`1nOWh308n?S`@0C4a<0`1XJ6P308B4Q0<0U9BD102TY:@307moO`<0
JVYZ102;Rh/306e]K@<0RHV9101oOgl307inOP<0Ph>3101cLg<309^KV`<0NGUi0`1oOgl40861P@<0
O7al0`1oOgl408:2PP<0OWin0`1oOgl407inOP<0NGUi1038h=P309VIV@@0QhN70`2=SHd304e=C@@0
OGem0`27QhL308J6QP@0OWin0`2FUYH307emO@<0X:2P1021PH4307alO0<0QXJ6102PX:0306EUI@<0
MWIf1022PX8308R8R0<0OWin1025QHD307UiN@<0SHf=0`1gMgL40820P0<0NWYj0`25QHD408B4Q0<0
OWin0`24Q8@40861P@<0PX:23`38h=P308R8R0@0PH610`1oOgl30820P0L0PH610`22PX8408B4Q0<0
P8200`1mOGd30861P@@0P8200`21PH4707alO0H0P8201022PX830861P@<0P8200`21PH4408:2PP<0
Ph>31`21PH4307]kN`<0OWin1020P80308:2PP<0PH611`20P8040<SPf0<0Shn?101hN7P306i^KP<0
IFEU101oOgl306IVIP<0PH610`23Ph<408V9R@<0O7al0`1aLG4407MgM`<0NGUi0`20P804075aL@<0
LW9b0`20P80407alO0<0OWin0`1mOGd308:2PPL0OWin0`22PX8408n?S`<0SXj>1`1nOWh30820P0<0
OWin0`21PH4407]kNa@0b>3H000C0<SPf0<0OGem101eMGD308R8R0<0PH611027QhL307inOP<0Shn?
101<C4`306QXJ0<0Q8B40`2DU9@40:BTY0<0Ogmo0`1ZJVX408^;R`<0KFe]0`29RHT407moO`<0OWin
0`23Ph<407=cL`<0Vi^K0`1iNGT307moO`@0PH610`1lO7`307moO`@0PX:20`1nOWh307moO`@0OWin
0`1iNGT40<SPf0<0VIVI1027QhL308f=S@<0CDe=101mOGd308N7Q`<0QXJ6101nOWh309JFUP<0OGem
0`2PX:040861P@<0O7al0`26QXH40:2PX0<0IFEU0`1fMWH408:2PP<0R8R80`1nOWh408F5Q@<0NGUi
0`2=SHd307MgM`@0P8200`1jNWX308F5Q@@0Q8B40`1nOWh308B4Q0@0PH610`22PX8?0<SPf0<0R8R8
1021PH4307moO`<0P8201`21PH4308:2PP@0Q8B40`20P80307emO@<0PH611020P8030861P@L0O7al
1P20P80408:2PP<0PH610`20P8030861P@@0PX:20`23Ph<70861P@<0Ng]k0`1nOWh40820P0<0PX:2
0`21PH470820P0@0b>3H0`2?Shl407QhN0<0KVi^0`1UIFD407moO`<0IVIV0`21PH4308>3P`@0RHV9
0`1lO7`3075aL@@0MgMg0`1iNGT30820P0@0LG5a0`1bLW830820P0@0O7al0`1nOWh307emO@<0PX:2
1`1nOWh308:2PP@0Shn?0`2>SXh707inOP<0P8200`1nOWh30861P@@0Ng]k5038h=P001<0b>3H0`1m
OGd407EeM@<0R8R80`21PH4408N7Q`<0OWin0`2?Shl404a<C0<0J6QX0`24Q8@309BDU0@0Y:BT0`1o
Ogl306YZJP@0Rh^;0`1]KFd308V9R@@0Ogmo0`1nOWh308>3P`@0Lg=c0`2KVi/307UiN@<0Ogmo1021
PH4307alO0<0Ogmo1022PX8307inOP<0Ogmo101nOWh307UiN@@0b>3H0`2IVIT408N7Q`<0SHf=0`1=
CDd407emO@<0QhN70`26QXH407inOP<0UYJF0`1mOGd30:2PX0@0PH610`1lO7`308J6QP@0X:2P0`1U
IFD307IfMP@0PX:20`28R8P307inOP@0QHF50`1iNGT308f=S@<0MgMg1020P80307YjNP<0QHF51024
Q8@307inOP<0Q8B41021PH4308:2PPl0b>3H0`28R8P40861P@<0Ogmo0`20P8070861P@<0PX:21024
Q8@30820P0<0OGem0`21PH440820P0<0PH611`1lO7`60820P0@0PX:20`21PH430820P0<0PH611022
PX8308>3P`L0PH610`1kNg/307inOP@0P8200`22PX830861P@L0P8201038h=P308n?S`@0N7Qh0`1^
KVh306EUI@@0Ogmo0`1VIVH30861P@<0Ph>31029RHT307alO0<0LG5a101gMgL307UiN@<0P820101a
LG43079bLP<0P820101lO7`307inOP<0OGem0`22PX8707inOP<0PX:2102?Shl308j>SPL0OWin0`20
P80307inOP<0PH61101kNg/D0<SPf0004`38h=P307=cL`@0Ti>C0`1WIfL3092@T0@0I6AT0`27QhL3
0820P0@0JFUY0`1dM7@308:2PP<0UYJF1023Ph<30:JVYP<0UYJF101FEUH309^KV`<0KFe]1027QhL3
08:2PP<0QhN7101fMWH3096AT@<0PH610`1oOgl408>3P`<0Ng]k0`22PX8408>3P`<0P8200`1oOgl4
08:2PP<0Ng]k1038h=P308:2PP@0OWin0`1KFe/30861P@@0Q8B40`21PH4307emO@@0M7Ad1P1oOgl3
08f=S@@0SXj>0`2LW9`3079bLP@0E5AD0`1kNg/307AdM0@0H61P0`2:RXX308N7Q`@0P8200`22PX83
07YjNP<0R8R81025QHD307alO0<0KVi^1023Ph<307moO`<0P8201023Ph<30861P@l0b>3H0`1oOgl4
07inOP<0QhN70`22PX8407QhN0<0OWin0`24Q8@407inOP<0P8200`22PX8307]kN`@0O7al0`1nOWh3
07]kN`L0O7al0`1oOgl407YjNP<0Ogmo0`22PX8707moO`<0OWin0`21PH4407moO`<0Ph>32P20P80:
07inOP@0b>3H0`1fMWH407inOP<0PX:20`1ZJVX407=cL`<0Ph>30`22PX8307]kN`@0NGUi0`1lO7`3
0820P0@0Lg=c0`1ZJVX30820P0@0QHF50`1lO7`308J6QP@0R8R80`20P80307MgM`L0P8200`28R8P3
07UiN@@0P8200`2:RXX308F5Q@@0NGUi0`22PX8308N7Q`<0Ogmo1020P80D0<SPf0004`38h=P307=c
L`@0Ti>C0`1WIfL3092@T0@0I6AT0`27QhL30820P0@0JFUY0`1dM7@308:2PP<0UYJF1023Ph<30:JV
YP<0UYJF101FEUH309^KV`<0KFe]1027QhL308:2PP<0QhN7101fMWH3096AT@<0PH610`1oOgl408>3
P`<0Ng]k0`22PX8408>3P`<0P8200`1oOgl408:2PP<0Ng]k1038h=P308:2PP@0OWin0`1KFe/30861
P@@0Q8B40`21PH4307emO@@0M7Ad1P1oOgl308f=S@@0SXj>0`2LW9`3079bLP@0E5AD0`1kNg/307Ad
M0@0H61P0`2:RXX308N7Q`@0P8200`22PX8307YjNP<0R8R81025QHD307alO0<0KVi^1023Ph<307mo
O`<0P8201023Ph<30861P@l0b>3H0`1oOgl407inOP<0QhN70`22PX8407QhN0<0OWin0`24Q8@407in
OP<0P8200`22PX8307]kN`@0O7al0`1nOWh307]kN`L0O7al0`1oOgl407YjNP<0Ogmo0`22PX8707mo
O`<0OWin0`21PH4407moO`<0Ph>32P20P80:07inOP@0b>3H0`1fMWH407inOP<0PX:20`1ZJVX407=c
L`<0Ph>30`22PX8307]kN`@0NGUi0`1lO7`30820P0@0Lg=c0`1ZJVX30820P0@0QHF50`1lO7`308J6
QP@0R8R80`20P80307MgM`L0P8200`28R8P307UiN@@0P8200`2:RXX308F5Q@@0NGUi0`22PX8308N7
Q`<0Ogmo1020P80D0<SPf0004`38h=P307=cL`@0Ti>C0`1WIfL3092@T0@0I6AT0`27QhL30820P0@0
JFUY0`1dM7@308:2PP<0UYJF1023Ph<30:JVYP<0UYJF101FEUH309^KV`<0KFe]1027QhL308:2PP<0
QhN7101fMWH3096AT@<0PH610`1oOgl408>3P`<0Ng]k0`22PX8408>3P`<0P8200`1oOgl408:2PP<0
Ng]k1038h=P308:2PP@0OWin0`1KFe/30861P@@0Q8B40`21PH4307emO@@0M7Ad1P1oOgl308f=S@@0
SXj>0`2LW9`3079bLP@0E5AD0`1kNg/307AdM0@0H61P0`2:RXX308N7Q`@0P8200`22PX8307YjNP<0
R8R81025QHD307alO0<0KVi^1023Ph<307moO`<0P8201023Ph<30861P@l0b>3H0`1oOgl407inOP<0
QhN70`22PX8407QhN0<0OWin0`24Q8@407inOP<0P8200`22PX8307]kN`@0O7al0`1nOWh307]kN`L0
O7al0`1oOgl407YjNP<0Ogmo0`22PX8707moO`<0OWin0`21PH4407moO`<0Ph>32P20P80:07inOP@0
b>3H0`1fMWH407inOP<0PX:20`1ZJVX407=cL`<0Ph>30`22PX8307]kN`@0NGUi0`1lO7`30820P0@0
Lg=c0`1ZJVX30820P0@0QHF50`1lO7`308J6QP@0R8R80`20P80307MgM`L0P8200`28R8P307UiN@@0
P8200`2:RXX308F5Q@@0NGUi0`22PX8308N7Q`<0Ogmo1020P80D0<SPf0004`38h=P308:2PP@0UYJF
0`2XZ:P307]kN`@0SXj>0`2<S8`307QhN0@0SHf=1P1nOWh307emO@@0MgMg0`1iNGT30:RXZ0@0T92@
0`1LG5`309nOW`@0IFEU1P23Ph<406a/K0<0MWIf0`25QHD307QhN0@0Rh^;1P1nOWh70861P@<0P820
101mOGd307alO0@0b>3H0`1jNWX408Z:RP<0Q8B40`1bLW8407EeM@<0Q8B40`1jNWX407moO`<0RXZ:
0`1NGUh309FEU@@0KFe]0`1lO7`307=cL`@0UiNG0`1/K6`306=SH`@0RXZ:0`1KFe/308>3P`@0Ogmo
0`1nOWh308J6QP<0P820101oOgl307emO@<0O7al101dM7@308b<S0<0OGem101oOgl307inOPl0b>3H
0`1hN7P708B4Q0<0Ogmo101jNWX307inOP<0Ogmo101lO7`308B4Q0<0OGem0`2;Rh/40820P0<0QXJ6
0`1lO7`408>3P`H0P8201025QHD307emO@<0PX:20`24Q8@40820P0<0Q8B40`1kNg/40861P@H0OWin
1020P8030861P@<0Ng]k1`20P8040<SPf0<0QhN71021PH4307alO0<0PX:2101gMgL30820P0<0QHF5
0`22PX8407YjNP<0OGem0`1fMWH407QhN0<0QHF50`1oOgl408>3P`<0YJFU0`2?Shl408j>SP<0UYJF
0`1nOWh307QhN0@0QhN70`20P80307IfMP@0PH610`1hN7P307inOP@0Ogmo0`1]KFd307moO`<0Ph>3
1024Q8@D0<SPf0004`38h=P308:2PP@0UYJF0`2XZ:P307]kN`@0SXj>0`2<S8`307QhN0@0SHf=1P1n
OWh307emO@@0MgMg0`1iNGT30:RXZ0@0T92@0`1LG5`309nOW`@0IFEU1P23Ph<406a/K0<0MWIf0`25
QHD307QhN0@0Rh^;1P1nOWh70861P@<0P820101mOGd307alO0@0b>3H0`1jNWX408Z:RP<0Q8B40`1b
LW8407EeM@<0Q8B40`1jNWX407moO`<0RXZ:0`1NGUh309FEU@@0KFe]0`1lO7`307=cL`@0UiNG0`1/
K6`306=SH`@0RXZ:0`1KFe/308>3P`@0Ogmo0`1nOWh308J6QP<0P820101oOgl307emO@<0O7al101d
M7@308b<S0<0OGem101oOgl307inOPl0b>3H0`1hN7P708B4Q0<0Ogmo101jNWX307inOP<0Ogmo101l
O7`308B4Q0<0OGem0`2;Rh/40820P0<0QXJ60`1lO7`408>3P`H0P8201025QHD307emO@<0PX:20`24
Q8@40820P0<0Q8B40`1kNg/40861P@H0OWin1020P8030861P@<0Ng]k1`20P8040<SPf0<0QhN71021
PH4307alO0<0PX:2101gMgL30820P0<0QHF50`22PX8407YjNP<0OGem0`1fMWH407QhN0<0QHF50`1o
Ogl408>3P`<0YJFU0`2?Shl408j>SP<0UYJF0`1nOWh307QhN0@0QhN70`20P80307IfMP@0PH610`1h
N7P307inOP@0Ogmo0`1]KFd307moO`<0Ph>31024Q8@D0<SPf0004`38h=P308:2PP@0UYJF0`2XZ:P3
07]kN`@0SXj>0`2<S8`307QhN0@0SHf=1P1nOWh307emO@@0MgMg0`1iNGT30:RXZ0@0T92@0`1LG5`3
09nOW`@0IFEU1P23Ph<406a/K0<0MWIf0`25QHD307QhN0@0Rh^;1P1nOWh70861P@<0P820101mOGd3
07alO0@0b>3H0`1jNWX408Z:RP<0Q8B40`1bLW8407EeM@<0Q8B40`1jNWX407moO`<0RXZ:0`1NGUh3
09FEU@@0KFe]0`1lO7`307=cL`@0UiNG0`1/K6`306=SH`@0RXZ:0`1KFe/308>3P`@0Ogmo0`1nOWh3
08J6QP<0P820101oOgl307emO@<0O7al101dM7@308b<S0<0OGem101oOgl307inOPl0b>3H0`1hN7P7
08B4Q0<0Ogmo101jNWX307inOP<0Ogmo101lO7`308B4Q0<0OGem0`2;Rh/40820P0<0QXJ60`1lO7`4
08>3P`H0P8201025QHD307emO@<0PX:20`24Q8@40820P0<0Q8B40`1kNg/40861P@H0OWin1020P803
0861P@<0Ng]k1`20P8040<SPf0<0QhN71021PH4307alO0<0PX:2101gMgL30820P0<0QHF50`22PX84
07YjNP<0OGem0`1fMWH407QhN0<0QHF50`1oOgl408>3P`<0YJFU0`2?Shl408j>SP<0UYJF0`1nOWh3
07QhN0@0QhN70`20P80307IfMP@0PH610`1hN7P307inOP@0Ogmo0`1]KFd307moO`<0Ph>31024Q8@D
0<SPf0004`38h=P307QhN0@0TI6A0`2IVIT308>3P`@0MWIf0`1gMgL307moO`@0R8R80`1hN7P308Z:
RP<0Vi^K102PX:03034a<@<0TY:B101eMGD309jNWP<0FEUI102TY:@307AdM0<0SHf=101_Kfl307=c
L`<0T92@0`1hN7P407inOP<0Ogmo0`23Ph<407alO0<0R8R80`1mOGd408>3P`<0Ng]k1038h=P308J6
QP@0MGEe0`1jNWX308:2PP@0P8200`26QXH308^;R`@0Shn?0`1_Kfl309ZJVP<0OGem1022PX8307Qh
N0<0OWin101oOgl309RHV0<0QHF5101GEeL309bLW0<0H61P1022PX8307=cL`<0S8b<0`29RHT408R8
R0<0PH610`20P80407UiN@<0M7Ad0`2>SXh407inOP<0Ng]k3`38h=P307moO`@0P8200`1mOGd307in
OP@0QXJ60`21PH4307moO`@0OWin0`1lO7`307moO`L0P8200`21PH4308:2PP@0P8200`1mOGd308R8
R0@0O7al0`21PH4307alO0<0Ogmo1020P80307]kN`<0OWin1`1mOGd30820P0@0PX:20`1jNWX307mo
O`@0P8200`1oOgl40<SPf0<0TI6A101`L70608N7Q`@0Ogmo0`23Ph<308Z:RP<0P8201025QHD308:2
PP<0MWIf101dM7@307inOP<0O7al1020P80308j>SP<0V9RH102=SHd308B4Q0<0V9RH0`1nOWh409FE
U@<0P8200`24Q8@408:2PP<0Q8B41`1oOgl306ATI0<0PH610`25QHD408:2PQ@0b>3H000C0<SPf0<0
N7Qh102ATI4309VIV@<0Ph>3101fMWH307MgM`<0Ogmo1028R8P307QhN0<0RXZ:0`2KVi/40:2PX0<0
<C4a0`2BTY8407EeM@<0WYjN0`1IFET40:BTY0<0M7Ad0`2=SHd406m_K`<0Lg=c0`2@T90307QhN0@0
OWin0`1oOgl308>3P`@0O7al0`28R8P307emO@@0Ph>30`1kNg/40<SPf0<0QXJ6101eMGD307YjNP<0
PX:21020P80308J6QP<0Rh^;102?Shl306m_K`<0VYZJ0`1mOGd408:2PP<0N7Qh0`1nOWh407moO`<0
V9RH0`25QHD405MGE`<0W9bL0`1PH60408:2PP<0Lg=c0`2<S8`308V9R@@0R8R80`21PH430820P0@0
NGUi0`1dM7@308j>SP@0OWin0`1kNg/?0<SPf0<0Ogmo1020P80307emO@<0OWin1026QXH30861P@<0
Ogmo101nOWh307alO0<0Ogmo1`20P8030861P@<0PX:21020P80307emO@<0R8R8101lO7`30861P@<0
O7al0`1oOgl40820P0<0Ng]k0`1nOWh707emO@<0P8201022PX8307YjNP<0Ogmo1020P80307moO`@0
b>3H0`2ATI44071`L0H0QhN7101oOgl308>3P`<0RXZ:0`20P80408F5Q@<0PX:20`1fMWH407AdM0<0
OWin0`1lO7`40820P0<0SXj>0`2HV9P408f=S@<0Q8B40`2HV9P307inOP@0UIFE0`20P80308B4Q0@0
PX:20`24Q8@707moO`<0I6AT0`21PH4308F5Q@@0PX:25038h=P001<0b>3H0`1hN7P4096AT@<0VIVI
0`23Ph<407IfMP<0MgMg0`1oOgl408R8R0<0N7Qh0`2:RXX309^KV`@0X:2P0`0a<C4309:BTP@0MGEe
0`2NWYh305UIF@@0Y:BT0`1dM7@308f=S@@0Kfm_0`1cLg<3092@T0<0N7Qh101nOWh307moO`<0Ph>3
101lO7`308R8R0<0OGem1023Ph<307]kN`@0b>3H0`26QXH407EeM@<0NWYj0`22PX840820P0<0QXJ6
0`2;Rh/408n?S`<0Kfm_0`2JVYX307emO@@0PX:20`1hN7P307inOP@0Ogmo0`2HV9P308F5Q@@0EeMG
0`2LW9`3061PH0@0PX:20`1cLg<308b<S0<0RHV91028R8P30861P@<0P820101iNGT307AdM0<0SXj>
101nOWh307]kN`l0b>3H0`1oOgl40820P0<0OGem0`1nOWh408J6QP<0PH610`1oOgl407inOP<0O7al
0`1oOgl70820P0<0PH610`22PX840820P0<0OGem0`28R8P407alO0<0PH610`1lO7`307moO`@0P820
0`1kNg/307inOPL0OGem0`20P80408:2PP<0NWYj0`1oOgl40820P0<0Ogmo1038h=P3096AT@@0L71`
1P27QhL407moO`<0Ph>30`2:RXX30820P0@0QHF50`22PX8307IfMP@0M7Ad0`1nOWh307alO0@0P820
0`2>SXh309RHV0@0SHf=0`24Q8@309RHV0<0OWin102EUID30820P0<0Q8B41022PX8308B4Q0L0Ogmo
0`1TI6@30861P@<0QHF51022PX8D0<SPf0004`38h=P308B4Q0@0SXj>0`1^KVh307emO@@0NWYj0`1h
N7P308B4Q0@0MgMg0`1eMGD30:6QX@<0Vi^K102NWYh30492@P<0OWin102;Rh/307AdM0<0V9RH101T
I6@309bLW0<0MGEe101jNWX3079bLP<0S8b<0`1fMWH407UiN@<0PH610`1oOgl408:2PP<0NWYj0`26
QXH40820P0<0Ng]k1038h=P307MgM`L0QhN70`1oOgl407UiN@<0QXJ60`1lO7`406IVIP<0R8R80`1_
Kfl308>3P`@0K6a/0`1eMGD307moO`@0LW9b0`1jNWX309FEU@@0VIVI0`1WIfL309NGU`@0IfMW0`2H
V9P307YjNP<0NGUi101oOgl307YjNP<0OGem101oOgl307]kN`<0R8R81023Ph<307]kN`l0b>3H0`27
QhL40820P0<0R8R80`1nOWh407IfMP<0OGem0`23Ph<407inOP<0QHF50`1hN7P30820P0@0Ph>30`25
QHD307]kN`@0PX:20`21PH4308:2PP@0RHV90`1oOgl308B4Q0<0QHF51024Q8@30820P0<0PH611022
PX8307moO`<0OGem1020P80308J6QP<0Ph>31020P80307emO@@0b>3H0`2NWYh4079bLP<0QhN70`1d
M7@407MgM`<0RHV90`28R8P309ZJVP@0OWin0`1kNg/307YjNP@0OWin0`1ZJVX308J6QP@0Jf][0`25
QHD307QhN0@0SXj>0`1lO7`309bLW0<0WinO101mOGd307UiN@<0P8201026QXH307]kN`L0PX:20`21
PH4307emO@<0QHF5101nOWhD0<SPf0004`38h=P308B4Q0@0SXj>0`1^KVh307emO@@0NWYj0`1hN7P3
08B4Q0@0MgMg0`1eMGD30:6QX@<0Vi^K102NWYh30492@P<0OWin102;Rh/307AdM0<0V9RH101TI6@3
09bLW0<0MGEe101jNWX3079bLP<0S8b<0`1fMWH407UiN@<0PH610`1oOgl408:2PP<0NWYj0`26QXH4
0820P0<0Ng]k1038h=P307MgM`L0QhN70`1oOgl407UiN@<0QXJ60`1lO7`406IVIP<0R8R80`1_Kfl3
08>3P`@0K6a/0`1eMGD307moO`@0LW9b0`1jNWX309FEU@@0VIVI0`1WIfL309NGU`@0IfMW0`2HV9P3
07YjNP<0NGUi101oOgl307YjNP<0OGem101oOgl307]kN`<0R8R81023Ph<307]kN`l0b>3H0`27QhL4
0820P0<0R8R80`1nOWh407IfMP<0OGem0`23Ph<407inOP<0QHF50`1hN7P30820P0@0Ph>30`25QHD3
07]kN`@0PX:20`21PH4308:2PP@0RHV90`1oOgl308B4Q0<0QHF51024Q8@30820P0<0PH611022PX83
07moO`<0OGem1020P80308J6QP<0Ph>31020P80307emO@@0b>3H0`2NWYh4079bLP<0QhN70`1dM7@4
07MgM`<0RHV90`28R8P309ZJVP@0OWin0`1kNg/307YjNP@0OWin0`1ZJVX308J6QP@0Jf][0`25QHD3
07QhN0@0SXj>0`1lO7`309bLW0<0WinO101mOGd307UiN@<0P8201026QXH307]kN`L0PX:20`21PH43
07emO@<0QHF5101nOWhD0<SPf0004`38h=P308B4Q0@0SXj>0`1^KVh307emO@@0NWYj0`1hN7P308B4
Q0@0MgMg0`1eMGD30:6QX@<0Vi^K102NWYh30492@P<0OWin102;Rh/307AdM0<0V9RH101TI6@309bL
W0<0MGEe101jNWX3079bLP<0S8b<0`1fMWH407UiN@<0PH610`1oOgl408:2PP<0NWYj0`26QXH40820
P0<0Ng]k1038h=P307MgM`L0QhN70`1oOgl407UiN@<0QXJ60`1lO7`406IVIP<0R8R80`1_Kfl308>3
P`@0K6a/0`1eMGD307moO`@0LW9b0`1jNWX309FEU@@0VIVI0`1WIfL309NGU`@0IfMW0`2HV9P307Yj
NP<0NGUi101oOgl307YjNP<0OGem101oOgl307]kN`<0R8R81023Ph<307]kN`l0b>3H0`27QhL40820
P0<0R8R80`1nOWh407IfMP<0OGem0`23Ph<407inOP<0QHF50`1hN7P30820P0@0Ph>30`25QHD307]k
N`@0PX:20`21PH4308:2PP@0RHV90`1oOgl308B4Q0<0QHF51024Q8@30820P0<0PH611022PX8307mo
O`<0OGem1020P80308J6QP<0Ph>31020P80307emO@@0b>3H0`2NWYh4079bLP<0QhN70`1dM7@407Mg
M`<0RHV90`28R8P309ZJVP@0OWin0`1kNg/307YjNP@0OWin0`1ZJVX308J6QP@0Jf][0`25QHD307Qh
N0@0SXj>0`1lO7`309bLW0<0WinO101mOGd307UiN@<0P8201026QXH307]kN`L0PX:20`21PH4307em
O@<0QHF5101nOWhD0<SPf0004`38h=P308B4Q0@0SXj>0`1^KVh307emO@@0NWYj0`1hN7P308B4Q0@0
MgMg0`1eMGD30:6QX@<0Vi^K102NWYh30492@P<0OWin102;Rh/307AdM0<0V9RH101TI6@309bLW0<0
MGEe101jNWX3079bLP<0S8b<0`1fMWH407UiN@<0PH610`1oOgl408:2PP<0NWYj0`26QXH40820P0<0
Ng]k1038h=P307MgM`L0QhN70`1oOgl407UiN@<0QXJ60`1lO7`406IVIP<0R8R80`1_Kfl308>3P`@0
K6a/0`1eMGD307moO`@0LW9b0`1jNWX309FEU@@0VIVI0`1WIfL309NGU`@0IfMW0`2HV9P307YjNP<0
NGUi101oOgl307YjNP<0OGem101oOgl307]kN`<0R8R81023Ph<307]kN`l0b>3H0`27QhL40820P0<0
R8R80`1nOWh407IfMP<0OGem0`23Ph<407inOP<0QHF50`1hN7P30820P0@0Ph>30`25QHD307]kN`@0
PX:20`21PH4308:2PP@0RHV90`1oOgl308B4Q0<0QHF51024Q8@30820P0<0PH611022PX8307moO`<0
OGem1020P80308J6QP<0Ph>31020P80307emO@@0b>3H0`2NWYh4079bLP<0QhN70`1dM7@407MgM`<0
RHV90`28R8P309ZJVP@0OWin0`1kNg/307YjNP@0OWin0`1ZJVX308J6QP@0Jf][0`25QHD307QhN0@0
SXj>0`1lO7`309bLW0<0WinO101mOGd307UiN@<0P8201026QXH307]kN`L0PX:20`21PH4307emO@<0
QHF5101nOWhD0<SPf0004`38h=P309JFUPL0LG5a0`2:RXX407inOP<0PH610`1WIfL409>CT`<0I6AT
0`2>SXh309bLW0@0M7Ad0`1lO7`307]kN`L0Ogmo0`1kNg/408R8R0<0OGem0`2GUiL409RHV0<0T92@
0`25QHD30820P0@0OGem0`1nOWh30861P@@0OGem0`22PX8307inOP@0R8R80`1gMgL40<SPf0<0QHF5
101dM7@305mOG`<0Rh^;1`20P80306UYJ@@0SHf=0`1VIVH307inOP<0IFEU101jNWX306=SH`<0Q8B4
101iNGT307MgM`<0LG5a102GUiL308R8R0<0QXJ61020P80306YZJP<0OWin0`25QHD407moO`<0O7al
0`22PX840820P0<0QHF50`1lO7`407YjNP<0Lg=c3`38h=P307inOP@0Ogmo0`22PX8308>3P`@0OWin
0`20P80308>3P`L0P8200`22PX8307inOP@0OGem0`23Ph<307emO@@0PH610`20P8030861P@@0NWYj
0`1iNGT30861P@<0Ogmo1021PH430820P0L0Ogmo0`21PH4307moO`@0P8200`1oOgl308:2PP@0Ogmo
0`1nOWh40<SPf0<0UIFE102=SHd307EeM@<0LW9b101iNGT307moO`<0Vi^K0`26QXH408N7Q`<0RXZ:
0`2<S8`408J6QP<0Jf][0`1mOGd408^;R`<0N7Qh0`2<S8`406e]K@<0VIVI0`1[Jf/30::RXP@0KFe]
0`25QHD308:2PP@0QXJ60`1lO7`3071`L0@0PH610`1iNGT307MgM`<0MWIf101hN7PD0<SPf0004`38
h=P309JFUPL0LG5a0`2:RXX407inOP<0PH610`1WIfL409>CT`<0I6AT0`2>SXh309bLW0@0M7Ad0`1l
O7`307]kN`L0Ogmo0`1kNg/408R8R0<0OGem0`2GUiL409RHV0<0T92@0`25QHD30820P0@0OGem0`1n
OWh30861P@@0OGem0`22PX8307inOP@0R8R80`1gMgL40<SPf0<0QHF5101dM7@305mOG`<0Rh^;1`20
P80306UYJ@@0SHf=0`1VIVH307inOP<0IFEU101jNWX306=SH`<0Q8B4101iNGT307MgM`<0LG5a102G
UiL308R8R0<0QXJ61020P80306YZJP<0OWin0`25QHD407moO`<0O7al0`22PX840820P0<0QHF50`1l
O7`407YjNP<0Lg=c3`38h=P307inOP@0Ogmo0`22PX8308>3P`@0OWin0`20P80308>3P`L0P8200`22
PX8307inOP@0OGem0`23Ph<307emO@@0PH610`20P8030861P@@0NWYj0`1iNGT30861P@<0Ogmo1021
PH430820P0L0Ogmo0`21PH4307moO`@0P8200`1oOgl308:2PP@0Ogmo0`1nOWh40<SPf0<0UIFE102=
SHd307EeM@<0LW9b101iNGT307moO`<0Vi^K0`26QXH408N7Q`<0RXZ:0`2<S8`408J6QP<0Jf][0`1m
OGd408^;R`<0N7Qh0`2<S8`406e]K@<0VIVI0`1[Jf/30::RXP@0KFe]0`25QHD308:2PP@0QXJ60`1l
O7`3071`L0@0PH610`1iNGT307MgM`<0MWIf101hN7PD0<SPf0004`38h=P309JFUPL0LG5a0`2:RXX4
07inOP<0PH610`1WIfL409>CT`<0I6AT0`2>SXh309bLW0@0M7Ad0`1lO7`307]kN`L0Ogmo0`1kNg/4
08R8R0<0OGem0`2GUiL409RHV0<0T92@0`25QHD30820P0@0OGem0`1nOWh30861P@@0OGem0`22PX83
07inOP@0R8R80`1gMgL40<SPf0<0QHF5101dM7@305mOG`<0Rh^;1`20P80306UYJ@@0SHf=0`1VIVH3
07inOP<0IFEU101jNWX306=SH`<0Q8B4101iNGT307MgM`<0LG5a102GUiL308R8R0<0QXJ61020P803
06YZJP<0OWin0`25QHD407moO`<0O7al0`22PX840820P0<0QHF50`1lO7`407YjNP<0Lg=c3`38h=P3
07inOP@0Ogmo0`22PX8308>3P`@0OWin0`20P80308>3P`L0P8200`22PX8307inOP@0OGem0`23Ph<3
07emO@@0PH610`20P8030861P@@0NWYj0`1iNGT30861P@<0Ogmo1021PH430820P0L0Ogmo0`21PH43
07moO`@0P8200`1oOgl308:2PP@0Ogmo0`1nOWh40<SPf0<0UIFE102=SHd307EeM@<0LW9b101iNGT3
07moO`<0Vi^K0`26QXH408N7Q`<0RXZ:0`2<S8`408J6QP<0Jf][0`1mOGd408^;R`<0N7Qh0`2<S8`4
06e]K@<0VIVI0`1[Jf/30::RXP@0KFe]0`25QHD308:2PP@0QXJ60`1lO7`3071`L0@0PH610`1iNGT3
07MgM`<0MWIf101hN7PD0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf000o`38
h=SW0<SPf000o`38h=SW0<SPf000o`38h=SW0<SPf0004`38h=P305QHF0@0UIFE0`0U9BD303Xj>P@0
=cLg0`0c<c<303@d=0@0ADE50`0e=CD302`/;0<0HF5Q101OGel306MWI`<0MgMg1`1oOgl308>3P`@0
R8R81P2<S8`408^;R`<0S8b<0`2>SXh309>CT`@0TI6A0`2DU9@709>CT`<0UYJF0`2KVi/40:^[Z`<0
c<c<1038h=P308n?S`@0Kfm_0`23Ph<307alO0@0NWYj0`20P80307inOPL0PX:20`20P80308:2PP@0
P8200`1lO7`30861P@@0Ogmo0`1nOWh307moO`@0P8200`1nOWh308:2PPL0OWin0`20P80307emO@@0
Ogmo1P1mOGd40820P0H0Ogmo1`1nOWh?0<SPf0<0Ph>3101kNg/30861P@<0QHF51020P8030861P@<0
PX:2101oOgl30820P0<0PH610`20P80407inOP<0PX:20`1oOgl408:2PP<0PH610`1oOgl407inOPH0
P8200`1nOWh707moO`<0OWin1021PH4607inOPh0Ogmo0`20P8040<SPf0<0Rh^;101jNWX307]kN`<0
Ph>31024Q8@307]kN`X0O7al0`1hN7P307moO`@0PX:20`1oOgl307inOP@0Ogmo0`1nOWh:07moO`<0
P8201`22PX8307inOP<0P8201`21PH430820P0@0Ogmo0`1mOGd307alO0@0Ogmo0`20P80D0<SPf000
4`38h=P305QHF0@0UIFE0`0U9BD303Xj>P@0=cLg0`0c<c<303@d=0@0ADE50`0e=CD302`/;0<0HF5Q
101OGel306MWI`<0MgMg1`1oOgl308>3P`@0R8R81P2<S8`408^;R`<0S8b<0`2>SXh309>CT`@0TI6A
0`2DU9@709>CT`<0UYJF0`2KVi/40:^[Z`<0c<c<1038h=P308n?S`@0Kfm_0`23Ph<307alO0@0NWYj
0`20P80307inOPL0PX:20`20P80308:2PP@0P8200`1lO7`30861P@@0Ogmo0`1nOWh307moO`@0P820
0`1nOWh308:2PPL0OWin0`20P80307emO@@0Ogmo1P1mOGd40820P0H0Ogmo1`1nOWh?0<SPf0<0Ph>3
101kNg/30861P@<0QHF51020P8030861P@<0PX:2101oOgl30820P0<0PH610`20P80407inOP<0PX:2
0`1oOgl408:2PP<0PH610`1oOgl407inOPH0P8200`1nOWh707moO`<0OWin1021PH4607inOPh0Ogmo
0`20P8040<SPf0<0Rh^;101jNWX307]kN`<0Ph>31024Q8@307]kN`X0O7al0`1hN7P307moO`@0PX:2
0`1oOgl307inOP@0Ogmo0`1nOWh:07moO`<0P8201`22PX8307inOP<0P8201`21PH430820P0@0Ogmo
0`1mOGd307alO0@0Ogmo0`20P80D0<SPf0004`38h=P305QHF0@0UIFE0`0U9BD303Xj>P@0=cLg0`0c
<c<303@d=0@0ADE50`0e=CD302`/;0<0HF5Q101OGel306MWI`<0MgMg1`1oOgl308>3P`@0R8R81P2<
S8`408^;R`<0S8b<0`2>SXh309>CT`@0TI6A0`2DU9@709>CT`<0UYJF0`2KVi/40:^[Z`<0c<c<1038
h=P308n?S`@0Kfm_0`23Ph<307alO0@0NWYj0`20P80307inOPL0PX:20`20P80308:2PP@0P8200`1l
O7`30861P@@0Ogmo0`1nOWh307moO`@0P8200`1nOWh308:2PPL0OWin0`20P80307emO@@0Ogmo1P1m
OGd40820P0H0Ogmo1`1nOWh?0<SPf0<0Ph>3101kNg/30861P@<0QHF51020P8030861P@<0PX:2101o
Ogl30820P0<0PH610`20P80407inOP<0PX:20`1oOgl408:2PP<0PH610`1oOgl407inOPH0P8200`1n
OWh707moO`<0OWin1021PH4607inOPh0Ogmo0`20P8040<SPf0<0Rh^;101jNWX307]kN`<0Ph>31024
Q8@307]kN`X0O7al0`1hN7P307moO`@0PX:20`1oOgl307inOP@0Ogmo0`1nOWh:07moO`<0P8201`22
PX8307inOP<0P8201`21PH430820P0@0Ogmo0`1mOGd307alO0@0Ogmo0`20P80D0<SPf0004`38h=P3
05QHF0@0Ng]k0`1]KFd302DU9@@0<c<c0`0_;bl303<c<`@0@4100`0c<c<302h^;P<0J6QX101NGUh3
06e]K@<0MgMg101nOWh30861P@<0PX:21028R8P608^;R`@0SHf=0`2>SXh309FEU@L0UYJF0`2JVYX3
09JFUP@0U9BD0`2EUID309NGU`@0YZJV0`39bLT40<SPf0<0LG5a102ATI4307IfMP<0Shn?1025QHD3
0861P@<0Ogmo101mOGd307alO0<0PX:20`1lO7`:07inOP@0P8200`23Ph<307moO`@0PH610`1oOgl3
0861P@@0Ph>30`21PH4307moO`<0P8201022PX860820P0@0Ogmo2P22PX830820P0l0b>3H0`1oOgl4
08>3P`<0Ogmo0`23Ph<407moO`<0OGem0`1fMWH407UiN@H0NWYj0`1nOWh40861P@H0Ogmo101nOWh6
07emO@L0OWin1P20P80407moO`<0OWin1`1oOgl30861P@<0OGem1`20P80307moO`@0OWin0`20P804
0<SPf0<0P820101gMgL30861P@<0OGem101iNGT308N7Q`<0SXj>0`29RHT408Z:RP<0Shn?0`26QXH4
08V9R@<0P8200`24Q8@40820P0<0QHF50`20P80408:2PP<0OGem0`1nOWh307moO`@0P8200`21PH43
07moO`@0OWin0`24Q8@70861P@<0PX:20`1mOGd407inOP<0Ogmo5038h=P001<0b>3H0`1HF5P407]k
N`<0KFe]0`0U9BD403<c<`<0;bl_0`0c<c<40410@0<0<c<c0`0^;Rh306QXJ0@0GUiN0`1]KFd307Mg
M`@0OWin0`21PH4308:2PP@0R8R81P2;Rh/408f=S@<0SXj>0`2EUID709JFUP<0VYZJ0`2FUYH409BD
U0<0UIFE0`2GUiL40:JVYP<0bLW91038h=P3075aL@@0TI6A0`1fMWH308n?S`@0QHF50`21PH4307mo
O`@0OGem0`1lO7`308:2PP<0O7al2P1nOWh40820P0<0Ph>30`1oOgl40861P@<0Ogmo0`21PH4408>3
P`<0PH610`1oOgl30820P0@0PX:21P20P80407moO`X0PX:20`20P80?0<SPf0<0Ogmo1023Ph<307mo
O`<0Ph>3101oOgl307emO@<0MWIf101iNGT607YjNP<0OWin1021PH4607moO`@0OWin1P1mOGd707in
OPH0P820101oOgl307inOPL0Ogmo0`21PH4307emO@L0P8200`1oOgl407inOP<0P8201038h=P30820
P0@0MgMg0`21PH4307emO@@0NGUi0`27QhL308j>SP<0RHV9102:RXX308n?S`<0QXJ61029RHT30820
P0<0Q8B41020P80308F5Q@<0P8201022PX8307emO@<0OWin0`1oOgl40820P0<0PH610`1oOgl407in
OP<0Q8B41`21PH4308:2PP<0OGem101nOWh307moOa@0b>3H000C0<SPf0<0F5QH101kNg/306e]K@<0
9BDU100c<c<302l_;`<0<c<c1010@40303<c<`<0;Rh^0`1XJ6P405iNGP<0KFe]0`1gMgL407inOP<0
PH610`22PX8408R8R0H0Rh^;102=SHd308j>SP<0UIFE1`2FUYH309ZJVP<0UYJF102DU9@309FEU@<0
UiNG102VYZH30<W9b@@0b>3H0`1aLG44096AT@<0MWIf0`2?Shl408F5Q@<0PH610`1oOgl407emO@<0
O7al0`22PX8307alO0X0OWin1020P80308>3P`<0Ogmo1021PH4307moO`<0PH611023Ph<30861P@<0
Ogmo0`20P80408:2PPH0P820101oOgl:08:2PP<0P8203`38h=P307moO`@0Ph>30`1oOgl308>3P`@0
Ogmo0`1mOGd307IfMP@0NGUi1P1jNWX307inOP@0PH611P1oOgl407inOPH0OGem1`1nOWh60820P0@0
Ogmo0`1nOWh707moO`<0PH610`1mOGd70820P0<0Ogmo101nOWh30820P0@0b>3H0`20P80407MgM`<0
PH610`1mOGd407UiN@<0QhN70`2>SXh308V9R@@0RXZ:0`2?Shl308J6QP@0RHV90`20P80308B4Q0@0
P8200`25QHD30820P0@0PX:20`1mOGd307inOP<0Ogmo1020P8030861P@<0Ogmo101nOWh308B4Q0L0
PH610`22PX8307emO@@0OWin0`1oOglD0<SPf0004`38h=P305QHF0@0Ng]k0`1]KFd302DU9@@0<c<c
0`0_;bl303<c<`@0@4100`0c<c<302h^;P<0J6QX101NGUh306e]K@<0MgMg101nOWh30861P@<0PX:2
1028R8P608^;R`@0SHf=0`2>SXh309FEU@L0UYJF0`2JVYX309JFUP@0U9BD0`2EUID309NGU`@0YZJV
0`39bLT40<SPf0<0LG5a102ATI4307IfMP<0Shn?1025QHD30861P@<0Ogmo101mOGd307alO0<0PX:2
0`1lO7`:07inOP@0P8200`23Ph<307moO`@0PH610`1oOgl30861P@@0Ph>30`21PH4307moO`<0P820
1022PX860820P0@0Ogmo2P22PX830820P0l0b>3H0`1oOgl408>3P`<0Ogmo0`23Ph<407moO`<0OGem
0`1fMWH407UiN@H0NWYj0`1nOWh40861P@H0Ogmo101nOWh607emO@L0OWin1P20P80407moO`<0OWin
1`1oOgl30861P@<0OGem1`20P80307moO`@0OWin0`20P8040<SPf0<0P820101gMgL30861P@<0OGem
101iNGT308N7Q`<0SXj>0`29RHT408Z:RP<0Shn?0`26QXH408V9R@<0P8200`24Q8@40820P0<0QHF5
0`20P80408:2PP<0OGem0`1nOWh307moO`@0P8200`21PH4307moO`@0OWin0`24Q8@70861P@<0PX:2
0`1mOGd407inOP<0Ogmo5038h=P001<0b>3H0`1PH604069RHP<0];Bd0`1ADE4403@d=0<0=cLg0`0h
>3P403/k>`H0=3@d0`1/K6`405]KF`<0Kfm_0`1jNWX407inOP<0Ogmo0`24Q8@408Z:RP<0S8b<0`2=
SHd408n?S`<0U9BD0`2IVIT309ZJVP@0WIfM0`2LW9`309RHV0@0UiNG0`2CTi<3092@T0@0VYZJ0`2j
^[X40<SPf0<0T92@101oOgl30861P@<0NWYj1020P80307emO@<0PH61101oOgl307]kN`<0OGem0`1n
OWh70861P@<0Ogmo1021PH4308B4Q0<0P8201022PX8307moO`<0OWin1021PH4308B4Q0<0Ogmo1`1n
OWh30820P0<0OGem1020P80307moO`<0OGem1021PH4307YjNPl0b>3H0`23Ph<407moO`<0OWin0`27
QhL408J6QP<0Q8B40`23Ph<407alO0H0OGem0`21PH4407emO@<0PH610`1mOGd407inOP<0OGem0`20
P80707moO`<0OWin1`20P80607moO`@0OWin0`20P80307moO`@0P8200`22PX830861P@@0OWin0`1o
Ogl40<SPf0<0OGem101eMGD308B4Q0<0OGem1020P8030861P@<0NWYj0`26QXH408:2PP<0Ogmo0`1k
Ng/407inOP<0OGem0`21PH440820P0<0PH611`1lO7`307inOP<0PX:20`1oOgl40861P@<0P8200`1l
O7`407inOP<0Ogmo0`20P80407moO`<0OGem0`1nOWh408J6QP<0Q8B45038h=P001<0b>3H0`1PH604
069RHP<0];Bd0`1ADE4403@d=0<0=cLg0`0h>3P403/k>`H0=3@d0`1/K6`405]KF`<0Kfm_0`1jNWX4
07inOP<0Ogmo0`24Q8@408Z:RP<0S8b<0`2=SHd408n?S`<0U9BD0`2IVIT309ZJVP@0WIfM0`2LW9`3
09RHV0@0UiNG0`2CTi<3092@T0@0VYZJ0`2j^[X40<SPf0<0T92@101oOgl30861P@<0NWYj1020P803
07emO@<0PH61101oOgl307]kN`<0OGem0`1nOWh70861P@<0Ogmo1021PH4308B4Q0<0P8201022PX83
07moO`<0OWin1021PH4308B4Q0<0Ogmo1`1nOWh30820P0<0OGem1020P80307moO`<0OGem1021PH43
07YjNPl0b>3H0`23Ph<407moO`<0OWin0`27QhL408J6QP<0Q8B40`23Ph<407alO0H0OGem0`21PH44
07emO@<0PH610`1mOGd407inOP<0OGem0`20P80707moO`<0OWin1`20P80607moO`@0OWin0`20P803
07moO`@0P8200`22PX830861P@@0OWin0`1oOgl40<SPf0<0OGem101eMGD308B4Q0<0OGem1020P803
0861P@<0NWYj0`26QXH408:2PP<0Ogmo0`1kNg/407inOP<0OGem0`21PH440820P0<0PH611`1lO7`3
07inOP<0PX:20`1oOgl40861P@<0P8200`1lO7`407inOP<0Ogmo0`20P80407moO`<0OGem0`1nOWh4
08J6QP<0Q8B45038h=P001<0b>3H0`1PH604069RHP<0];Bd0`1ADE4403@d=0<0=cLg0`0h>3P403/k
>`H0=3@d0`1/K6`405]KF`<0Kfm_0`1jNWX407inOP<0Ogmo0`24Q8@408Z:RP<0S8b<0`2=SHd408n?
S`<0U9BD0`2IVIT309ZJVP@0WIfM0`2LW9`309RHV0@0UiNG0`2CTi<3092@T0@0VYZJ0`2j^[X40<SP
f0<0T92@101oOgl30861P@<0NWYj1020P80307emO@<0PH61101oOgl307]kN`<0OGem0`1nOWh70861
P@<0Ogmo1021PH4308B4Q0<0P8201022PX8307moO`<0OWin1021PH4308B4Q0<0Ogmo1`1nOWh30820
P0<0OGem1020P80307moO`<0OGem1021PH4307YjNPl0b>3H0`23Ph<407moO`<0OWin0`27QhL408J6
QP<0Q8B40`23Ph<407alO0H0OGem0`21PH4407emO@<0PH610`1mOGd407inOP<0OGem0`20P80707mo
O`<0OWin1`20P80607moO`@0OWin0`20P80307moO`@0P8200`22PX830861P@@0OWin0`1oOgl40<SP
f0<0OGem101eMGD308B4Q0<0OGem1020P8030861P@<0NWYj0`26QXH408:2PP<0Ogmo0`1kNg/407in
OP<0OGem0`21PH440820P0<0PH611`1lO7`307inOP<0PX:20`1oOgl40861P@<0P8200`1lO7`407in
OP<0Ogmo0`20P80407moO`<0OGem0`1nOWh408J6QP<0Q8B45038h=P001<0b>3H0`2@T90406UYJ@<0
MgMg0`2b/[8402TY:@<0;Rh^0`0l?3`403Hf=P<0;bl_0`0b<S8306m_K`@0E5AD0`1_Kfl307IfMP@0
O7al0`1oOgl308:2PP@0QhN70`2=SHd3092@T0@0TI6A0`2DU9@309VIV@<0VYZJ1`2MWId309ZJVP@0
U9BD0`2>SXh308F5Q@@0QXJ60`2@T9040<SPf0<0NGUi1021PH4308R8R0<0Ti>C102FUYH307]kN`<0
KFe]101fMWH308:2PP<0NWYj0`1nOWh407moO`<0PH610`1oOgl407emO@<0P8200`1oOgl40820P0H0
OWin1021PH4308:2PP<0PH610`20P80407inOP<0P8200`21PH4707moO`<0QHF5101nOWh308:2PPl0
b>3H0`1hN7P708>3P`<0OWin1021PH4307alO0<0Ogmo1022PX830861P@<0Ogmo0`1nOWh40820P0d0
Ogmo0`21PH4407moO`<0P8200`1oOgl30820P0@0Ogmo0`1nOWh707moO`<0OWin1`20P80307moO`<0
P8201`21PH440<SPf0<0SXj>101gMgL308f=S@<0JVYZ101`L70307YjNP<0Lg=c0`1eMGD408:2PP<0
O7al0`22PX8407emO@<0Ogmo0`1nOWh408>3P`<0Ng]k0`1nOWh707moO`<0PX:20`1lO7`407YjNP<0
O7al0`1nOWh407moO`<0OWin1`20P80307alO0<0Q8B41022PX8308B4Q1@0b>3H000C0<SPf0<0T92@
101YJFT307MgM`<0/[:b100Y:BT302h^;P<0?3`l100f=SH302l_;`<0<S8b0`1_Kfl405ADE0<0Kfm_
0`1fMWH407alO0<0Ogmo0`22PX8408N7Q`<0SHf=0`2@T904096AT@<0U9BD0`2IVIT309ZJVPL0WIfM
0`2JVYX409BDU0<0SXj>0`25QHD408J6QP<0T92@1038h=P307UiN@@0PH610`28R8P309>CT`@0UYJF
0`1kNg/306e]K@@0MWIf0`22PX8307YjNP<0OWin101oOgl30861P@<0Ogmo101mOGd30820P0<0Ogmo
1020P80607inOP@0PH610`22PX830861P@<0P820101nOWh30820P0<0PH611`1oOgl308F5Q@@0OWin
0`22PX8?0<SPf0<0N7Qh1`23Ph<307inOP@0PH610`1lO7`307moO`@0PX:20`21PH4307moO`<0OWin
1020P80=07moO`<0PH61101oOgl30820P0<0Ogmo0`20P80407moO`<0OWin1`1oOgl307inOPL0P820
0`1oOgl30820P0L0PH611038h=P308j>SP@0MgMg0`2=SHd306YZJP@0L71`0`1jNWX307=cL`<0MGEe
1022PX8307alO0<0PX:2101mOGd307moO`<0OWin1023Ph<307]kN`<0OWin1`1oOgl308:2PP<0O7al
101jNWX307alO0<0OWin101oOgl307inOPL0P8200`1lO7`308B4Q0@0PX:20`24Q8@D0<SPf0004`38
h=P3092@T0@0JFUY0`1gMgL30;:b/P@0:BTY0`0^;Rh303`l?0@0=SHf0`0_;bl3038b<P<0Kfm_101D
E5@306m_K`<0MWIf101lO7`307moO`<0PX:21027QhL308f=S@<0T92@102ATI4309BDU0<0VIVI0`2J
VYX709fMW@<0VYZJ102DU9@308j>SP<0QHF51026QXH3092@T0@0b>3H0`1iNGT40861P@<0R8R80`2C
Ti<409JFUP<0Ng]k0`1]KFd407IfMP<0PX:20`1jNWX307inOP@0Ogmo0`21PH4307moO`@0OGem0`20
P80307moO`@0P8201P1nOWh40861P@<0PX:20`21PH430820P0@0OWin0`20P8030861P@L0Ogmo0`25
QHD407inOP<0PX:23`38h=P307QhN0L0Ph>30`1nOWh40861P@<0O7al0`1oOgl408:2PP<0PH610`1o
Ogl307inOP@0P8203@1oOgl30861P@@0Ogmo0`20P80307moO`<0P820101oOgl307inOPL0Ogmo0`1n
OWh70820P0<0Ogmo0`20P8070861P@@0b>3H0`2>SXh407MgM`<0SHf=0`1ZJVX4071`L0<0NWYj0`1c
Lg<307EeM@@0PX:20`1lO7`308:2PP@0OGem0`1oOgl307inOP@0Ph>30`1kNg/307inOPL0Ogmo0`22
PX8307alO0@0NWYj0`1lO7`307inOP@0Ogmo0`1nOWh70820P0<0O7al0`24Q8@408:2PP<0Q8B45038
h=P001<0b>3H0`0h>3P407YjNP<0WIfM0`2`/;0408^;R`<08B4Q0`0d=3@402h^;P<0;bl_0`0b<S83
06UYJ@@0De=C0`1/K6`307EeM@@0O7al0`20P80308B4Q0@0RXZ:0`2@T90309:BTP@0UIFE0`2FUYH3
09ZJVP<0W9bL102NWYh309bLW0<0U9BD102:RXX307alO0<0NGUi101fMWH307EeM@@0b>3H0`2>SXh7
07]kN`<0N7Qh101lO7`309JFUP<0NWYj1020P80307]kN`<0Ph>30`1lO7`407inOP<0PX:20`21PH44
0820P0<0Ogmo0`22PX840861P@X0Ogmo0`21PH4607inOPL0P8200`1mOGd40861P@<0O7al0`2?Shl7
09NGU`l0b>3H0`22PX840861P@<0OWin1`21PH4608:2PP@0Ph>30`20P80308:2PP<0PH611020P80:
0861P@<0P8201`1oOgl30820P0<0OWin0`21PH470820P0<0Ogmo101nOWh30861P@<0P8201`1oOgl3
08>3P`@0P8200`1nOWh40<SPf0<0S8b<101lO7`308R8R0<0OGem1024Q8@307YjNP<0Ph>30`21PH44
08:2PP<0QXJ60`1fMWH407inOPX0Ogmo0`21PH430820P0@0O7al0`1mOGd307moO`<0PH611024Q8@3
07emO@<0P820101oOgl30861P@<0OGem1024Q8@308:2PP<0LW9b101TI6@3075aLA@0b>3H000C0<SP
f0<0>3Ph101jNWX309fMW@<0/;2`102;Rh/3024Q8@<0=3@d100^;Rh302l_;`<0<S8b0`1YJFT405=C
D`<0K6a/0`1eMGD407alO0<0P8200`24Q8@408Z:RP<0T92@0`2BTY8409FEU@<0UYJF0`2JVYX309bL
W0@0WYjN0`2LW9`309BDU0@0RXZ:0`1lO7`307UiN@@0MWIf0`1eMGD40<SPf0<0SXj>1`1kNg/307Qh
N0@0O7al0`2FUYH307YjNP@0P8200`1kNg/308>3P`<0O7al101nOWh308:2PP<0PH611020P80307mo
O`<0PX:21021PH4:07moO`<0PH611P1nOWh70820P0<0OGem1021PH4307alO0<0Shn?1`2GUiL?0<SP
f0<0PX:21021PH4307inOPL0PH611P22PX8408>3P`<0P8200`22PX830861P@@0P8202P21PH430820
P0L0Ogmo0`20P80307inOP<0PH611`20P80307moO`@0OWin0`21PH430820P0L0Ogmo0`23Ph<40820
P0<0OWin1038h=P308b<S0@0O7al0`28R8P307emO@@0Q8B40`1jNWX308>3P`<0PH611022PX8308J6
QP<0MWIf101nOWh:07moO`<0PH610`20P80407alO0<0OGem0`1oOgl30861P@@0Q8B40`1mOGd30820
P0@0Ogmo0`21PH4307emO@@0Q8B40`22PX83079bLP@0I6AT0`1aLG4D0<SPf0004`38h=P303Ph>0@0
NWYj0`2MWId30;2`/0@0Rh^;0`0Q8B4303@d=0@0;Rh^0`0_;bl3038b<P<0JFUY101CDe<306a/K0<0
MGEe101lO7`30820P0<0Q8B4102:RXX3092@T0<0TY:B102EUID309JFUP<0VYZJ0`2LW9`409jNWP<0
W9bL0`2DU9@408Z:RP<0O7al0`1iNGT407IfMP<0MGEe1038h=P308j>SPL0Ng]k0`1hN7P407alO0<0
UYJF0`1jNWX40820P0<0Ng]k0`23Ph<307alO0@0OWin0`22PX830861P@@0P8200`1oOgl308:2PP@0
PH612P1oOgl30861P@H0OWin1`20P80307emO@@0PH610`1lO7`308n?S`L0UiNG3`38h=P308:2PP@0
PH610`1nOWh70861P@H0PX:21023Ph<30820P0<0PX:20`21PH440820P0X0PH610`20P80707moO`<0
P8200`1nOWh30861P@L0P8200`1oOgl407inOP<0PH610`20P80707moO`<0Ph>31020P80307inOP@0
b>3H0`2<S8`407alO0<0R8R80`1mOGd408B4Q0<0NWYj0`23Ph<30861P@@0PX:20`26QXH307IfMP@0
OWin2P1oOgl30861P@<0P820101lO7`307emO@<0Ogmo0`21PH4408B4Q0<0OGem0`20P80407moO`<0
PH610`1mOGd408B4Q0<0PX:20`1bLW8406ATI0<0LG5a5038h=P001<0b>3H0`0L71`405IFEPH0/[:b
102h^;P306a/K0L09bLW0`0_;bl302h^;P<0H61P101>CTh306IVIP<0MWIf101lO7`30820P0<0QHF5
102;Rh/308n?S`<0U9BD1`2GUiL309^KV`L0WIfM0`2KVi/3096AT@@0OGem0`23Ph<3079bLP@0Cdm?
0`1_Kfl40<SPf0<0Ogmo1023Ph<308Z:RP<0Ng]k101WIfL3061PH0<0R8R81`1mOGd307moO`<0PX:2
1024Q8@307emO@<0P820101lO7`307moO`<0PH611020P80307inOP<0PX:21020P80308>3P`H0P820
101oOgl30861P@<0OWin1020P8030861P@<0LW9b101GEeL3079bLPl0b>3H0`1lO7`407moO`<0PX:2
0`20P80407emO@<0MWIf0`24Q8@40820P0<0PH610`1oOgl307]kN`@0OWin2P20P80307moO`<0P820
101oOgl30861P@<0P8200`1nOWh70820P0<0Ogmo101mOGd307inOP<0Ogmo1022PX830820P0<0O7al
101dM7@307inOP@0b>3H0`1hN7P407emO@<0MWIf0`28R8P409BDU0<0RXZ:0`1hN7P308:2PP@0P820
0`1jNWX30861P@@0OWin0`23Ph<307inOP@0P8200`1oOgl30820P0@0OGem0`22PX8307inOP<0PX:2
1020P80307moO`<0P8201021PH4308:2PP<0QHF51026QXH30861P@<0NWYj101_Kfl307alO1@0b>3H
000C0<SPf0<071`L101FEUH60;:b/P@0^;Rh0`1/K6`702LW9`<0;bl_0`0^;Rh3061PH0@0CTi>0`1V
IVH307IfMP@0O7al0`20P80308F5Q@@0Rh^;0`2?Shl309BDU0L0UiNG0`2KVi/709fMW@<0Vi^K0`2A
TI4407emO@<0Ph>30`1bLW8404m?C`<0Kfm_1038h=P307moO`@0Ph>30`2:RXX307]kN`@0IfMW0`1P
H60308R8R0L0OGem0`1oOgl308:2PP@0Q8B40`1mOGd30820P0@0O7al0`1oOgl30861P@@0P8200`1n
OWh308:2PP@0P8200`23Ph<60820P0@0Ogmo0`21PH4307inOP@0P8200`21PH43079bLP@0EeMG0`1b
LW8?0<SPf0<0O7al101oOgl308:2PP<0P820101mOGd307IfMP<0Q8B41020P8030861P@<0Ogmo0`1k
Ng/407inOPX0P8200`1oOgl30820P0@0Ogmo0`21PH430820P0<0OWin1`20P80307moO`@0OGem0`1n
OWh307moO`@0PX:20`20P80307alO0@0M7Ad0`1nOWh40<SPf0<0N7Qh101mOGd307IfMP<0R8R8102D
U9@308Z:RP<0N7Qh0`22PX840820P0<0NWYj0`21PH4407inOP<0Ph>30`1nOWh40820P0<0Ogmo0`20
P80407emO@<0PX:20`1nOWh308:2PP@0P8200`1oOgl30820P0@0PH610`22PX8308F5Q@@0QXJ60`21
PH4307YjNP@0Kfm_0`1lO7`D0<SPf0004`38h=P301`L70@0EUIF1P2b/[840;Rh^0<0K6a/1`0W9bL3
02l_;`<0;Rh^0`1PH60404i>CP<0IVIV0`1fMWH407alO0<0P8200`25QHD408^;R`<0Shn?0`2DU9@7
09NGU`<0Vi^K1`2MWId309^KV`<0TI6A101mOGd308>3P`<0LW9b101?Cdl306m_K`@0b>3H0`1oOgl4
08>3P`<0RXZ:0`1kNg/406MWI`<0H61P0`28R8P707emO@<0Ogmo0`22PX8408B4Q0<0OGem0`20P804
07alO0<0Ogmo0`21PH440820P0<0OWin0`22PX840820P0<0Ph>31P20P80407moO`<0PH610`1nOWh4
0820P0<0PH610`1bLW8405MGE`<0LW9b3`38h=P307alO0@0Ogmo0`22PX830820P0@0OGem0`1fMWH3
08B4Q0@0P8200`21PH4307moO`<0Ng]k101nOWh:0820P0<0Ogmo0`20P80407moO`<0PH610`20P803
07inOPL0P8200`1oOgl407emO@<0OWin0`1oOgl408:2PP<0P8200`1lO7`407AdM0<0OWin1038h=P3
07QhN0@0OGem0`1fMWH308R8R0@0U9BD0`2:RXX307QhN0<0PX:21020P80307YjNP<0PH61101nOWh3
08>3P`<0OWin1020P80307moO`<0P820101mOGd308:2PP<0OWin0`22PX840820P0<0Ogmo0`20P804
0861P@<0PX:20`25QHD408J6QP<0PH610`1jNWX406m_K`<0O7al5038h=P001<0b>3H0`0L71`405IF
EPH0/[:b102h^;P306a/K0L09bLW0`0_;bl302h^;P<0H61P101>CTh306IVIP<0MWIf101lO7`30820
P0<0QHF5102;Rh/308n?S`<0U9BD1`2GUiL309^KV`L0WIfM0`2KVi/3096AT@@0OGem0`23Ph<3079b
LP@0Cdm?0`1_Kfl40<SPf0<0Ogmo1023Ph<308Z:RP<0Ng]k101WIfL3061PH0<0R8R81`1mOGd307mo
O`<0PX:21024Q8@307emO@<0P820101lO7`307moO`<0PH611020P80307inOP<0PX:21020P80308>3
P`H0P820101oOgl30861P@<0OWin1020P8030861P@<0LW9b101GEeL3079bLPl0b>3H0`1lO7`407mo
O`<0PX:20`20P80407emO@<0MWIf0`24Q8@40820P0<0PH610`1oOgl307]kN`@0OWin2P20P80307mo
O`<0P820101oOgl30861P@<0P8200`1nOWh70820P0<0Ogmo101mOGd307inOP<0Ogmo1022PX830820
P0<0O7al101dM7@307inOP@0b>3H0`1hN7P407emO@<0MWIf0`28R8P409BDU0<0RXZ:0`1hN7P308:2
PP@0P8200`1jNWX30861P@@0OWin0`23Ph<307inOP@0P8200`1oOgl30820P0@0OGem0`22PX8307in
OP<0PX:21020P80307moO`<0P8201021PH4308:2PP<0QHF51026QXH30861P@<0NWYj101_Kfl307al
O1@0b>3H000C0<SPf0<0;Rh^100/;2`309RHV0<0Shn?1023Ph<30:NWY`<0GEeM100U9BD302`/;0<0
<30`0`1NGUh404I6AP<0IVIV0`1fMWH407inOP<0PH610`26QXH408f=S@<0Shn?0`2EUID409NGU`<0
Vi^K0`2MWId709nOW`<0VIVI0`2@T90407IfMP<0O7al0`2<S8`4096AT@<0QhN71038h=P308:2PP@0
QHF50`1oOgl309>CT`@0P8200`2MWId307UiN@@0MgMg0`21PH4307moO`<0QHF5101mOGd30861P@L0
P8200`21PH4307inOP@0OGem0`20P80307alO0@0Ogmo0`22PX860861P@@0OWin0`1oOgl30820P0@0
Ph>30`1oOgl308>3P`L0PX:23`38h=P30820P0@0Ogmo0`1lO7`307moO`@0Ph>30`26QXH308^;R`@0
Q8B40`1oOgl307YjNP<0P8201023Ph<307inOP<0P820101nOWh30820P0L0Ogmo0`21PH4307inOP<0
P820101nOWh30820P0<0Ogmo1021PH430820P0X0Ogmo0`21PH4408:2PP<0P8201038h=P307YjNP@0
PX:20`1hN7P308Z:RP@0QhN70`2CTi<306ATI0L0Ng]k0`1hN7P30861P@@0P8200`24Q8@307alO0@0
Ogmo0`20P80307emO@@0P8200`1nOWh308>3P`<0PH61101mOGd308:2PP<0PH611020P80308:2PP<0
Q8B41021PH4:07inOP<0Ogmo5038h=P001<0b>3H0`0^;Rh402`/;0<0V9RH0`2?Shl408>3P`<0YjNW
0`1MGEd402DU9@<0;2`/0`0`<30305iNGP@0ATI60`1VIVH307IfMP@0OWin0`21PH4308J6QP@0SHf=
0`2?Shl309FEU@@0UiNG0`2KVi/309fMW@L0WinO0`2IVIT3092@T0@0MWIf0`1lO7`308b<S0@0TI6A
0`27QhL40<SPf0<0PX:21025QHD307moO`<0Ti>C1020P80309fMW@<0NGUi101gMgL30861P@<0Ogmo
0`25QHD407emO@<0PH611`20P8030861P@<0OWin101mOGd30820P0<0O7al101oOgl308:2PPH0PH61
101nOWh307moO`<0P8201023Ph<307moO`<0Ph>31`22PX8?0<SPf0<0P820101oOgl307alO0<0Ogmo
1023Ph<308J6QP<0Rh^;1024Q8@307moO`<0NWYj0`20P80408>3P`<0OWin0`20P80407inOP<0P820
1`1oOgl30861P@<0OWin0`20P80407inOP<0P8200`1oOgl40861P@<0P8202P1oOgl30861P@@0PX:2
0`20P8040<SPf0<0NWYj1022PX8307QhN0<0RXZ:1027QhL309>CT`<0I6AT1`1kNg/307QhN0<0PH61
1020P80308B4Q0<0O7al101oOgl30820P0<0OGem1020P80307inOP<0Ph>30`21PH4407emO@<0PX:2
0`21PH440820P0<0PX:20`24Q8@40861P@X0OWin0`1oOglD0<SPf0004`38h=P302h^;P@0;2`/0`2H
V9P308n?S`@0Ph>30`2WYjL305eMG@@09BDU0`0/;2`3030`<0<0GUiN1016ATH306IVIP<0MWIf101n
OWh30861P@<0QXJ6102=SHd308n?S`<0UIFE102GUiL309^KV`<0WIfM1`2OWil309VIV@<0T92@101f
MWH307alO0<0S8b<102ATI4308N7Q`@0b>3H0`22PX8408F5Q@<0Ogmo0`2CTi<40820P0<0WIfM0`1i
NGT407MgM`<0PH610`1oOgl308F5Q@@0OGem0`21PH470820P0<0PH610`1nOWh407emO@<0P8200`1l
O7`407moO`<0PX:21P21PH4407inOP<0Ogmo0`20P80408>3P`<0Ogmo0`23Ph<708:2PPl0b>3H0`20
P80407moO`<0O7al0`1oOgl408>3P`<0QXJ60`2;Rh/408B4Q0<0Ogmo0`1jNWX30820P0@0Ph>30`1n
OWh30820P0@0OWin0`20P80707moO`<0PH610`1nOWh30820P0@0OWin0`20P80307moO`@0PH610`20
P80:07moO`<0PH611022PX830820P0@0b>3H0`1jNWX408:2PP<0N7Qh0`2:RXX408N7Q`<0Ti>C0`1T
I6@707]kN`<0N7Qh0`21PH440820P0<0Q8B40`1lO7`407moO`<0P8200`1mOGd40820P0<0OWin0`23
Ph<30861P@@0OGem0`22PX830861P@@0P8200`22PX8308B4Q0@0PH612P1nOWh307moOa@0b>3H000C
0<SPf0L0:RXZ0`0e=CD307EeM@@0NGUi0`2i^KT308B4Q0@0820P0`0/;2`302h^;P<0E5AD1018B4P3
06=SH`<0MGEe101nOWh308>3P`<0QhN7102<S8`309BDU0L0UiNG0`2KVi/30:2PX0<0XZ:R102QXJ43
09^KV`<0TI6A1021PH4307UiN@<0QHF5101oOgl307]kN`@0b>3H0`25QHD408R8R0<0PX:20`1iNGT4
08N7Q`<0N7Qh0`1]KFd408Z:RP<0NGUi0`22PX8:07inOP<0P820101oOgl30820P0<0OWin101mOGd3
0820P0<0PX:21`20P80308:2PP<0P8201023Ph<30820P0L0PH610`1nOWh30820P0L0Ogmo3`38h=P3
0861P@@0Ogmo0`20P80707moO`<0O7al0`1oOgl40820P0<0PX:20`1nOWh307moO`@0Q8B40`21PH43
07moO`@0OWin1P1oOgl40820P0<0Ogmo0`20P80307inOP@0PH610`1oOgl30820P0@0OGem1P1nOWh7
0820P0<0PH61101oOgl30820P0@0b>3H0`24Q8@4075aL@<0P8200`1mOGd407UiN@<0OGem0`1jNWX3
07alO0@0PX:20`1lO7`308B4Q0@0O7al1P20P80407emO@H0P8201021PH490820P0@0PX:20`1kNg/3
0820P0@0OGem0`22PX8307moO`@0P8200`22PX8307inOP@0PX:20`20P80D0<SPf0004`38h=P702XZ
:P<0=CDe0`1eMGD407UiN@<0^KVi0`24Q8@4020P80<0;2`/0`0^;Rh305ADE0@0B4Q80`1SHf<307Ee
M@@0OWin0`23Ph<308N7Q`@0S8b<0`2DU9@709NGU`<0Vi^K0`2PX:030::RXP@0XJ6Q0`2KVi/3096A
T@@0PH610`1iNGT308F5Q@@0Ogmo0`1kNg/40<SPf0<0QHF51028R8P308:2PP<0NGUi1027QhL307Qh
N0<0KFe]102:RXX307UiN@<0PX:22P1nOWh30820P0@0Ogmo0`20P80307inOP@0OGem0`20P80308:2
PPL0P8200`22PX830820P0@0Ph>30`20P8070861P@<0OWin0`20P80707moO`l0b>3H0`21PH4407mo
O`<0P8201`1oOgl307alO0<0Ogmo1020P80308:2PP<0OWin0`1oOgl408B4Q0<0PH610`1oOgl407in
OPH0Ogmo1020P80307moO`<0P8200`1nOWh40861P@<0Ogmo0`20P80407emO@H0OWin1`20P8030861
P@@0Ogmo0`20P8040<SPf0<0Q8B4101aLG430820P0<0OGem101iNGT307emO@<0NWYj0`1lO7`408:2
PP<0O7al0`24Q8@407alO0H0P820101mOGd60820P0@0PH612@20P80408:2PP<0Ng]k0`20P80407em
O@<0PX:20`1oOgl40820P0<0PX:20`1nOWh408:2PP<0P8205038h=P001<0b>3H1`0Z:RX303De=@<0
MGEe101iNGT30;Vi^@<0Q8B4100P820302`/;0<0;Rh^0`1DE5@404Q8B0<0Hf=S0`1eMGD407inOP<0
Ph>30`27QhL408b<S0<0U9BD1`2GUiL309^KV`<0X:2P0`2RXZ840:6QX@<0Vi^K0`2ATI440861P@<0
NGUi0`25QHD407moO`<0Ng]k1038h=P308F5Q@@0R8R80`22PX8307UiN@@0QhN70`1hN7P306e]K@@0
RXZ:0`1iNGT308:2PPX0OWin0`20P80407moO`<0P8200`1nOWh407emO@<0P8200`22PX870820P0<0
PX:20`20P80408>3P`<0P8201`21PH4307inOP<0P8201`1oOgl?0<SPf0<0PH61101oOgl30820P0L0
Ogmo0`1lO7`307moO`@0P8200`22PX8307inOP<0Ogmo1024Q8@30861P@<0Ogmo101nOWh607moO`@0
P8200`1oOgl30820P0<0OWin1021PH4307moO`<0P820101mOGd607inOPL0P8200`21PH4407moO`<0
P8201038h=P308B4Q0@0LG5a0`20P80307emO@@0NGUi0`1mOGd307YjNP<0O7al1022PX8307alO0<0
Q8B4101lO7`60820P0@0OGem1P20P8040861P@T0P8201022PX8307]kN`<0P820101mOGd308:2PP<0
Ogmo1020P80308:2PP<0OWin1022PX830820P1@0b>3H000C0<SPf0<0=SHf101:BTX301PH60<0F5QH
101hN7P309nOW`<0d=3@101CDe<302HV9P<0:b/[0`19BDT404I6AP<0IfMW0`1hN7P407moO`<0PX:2
0`29RHT4092@T0<0UIFE0`2JVYX40:2PX0<0WinO0`2UYJD30:JVYP@0Y:BT0`2RXZ8309FEU@@0RHV9
1P22PX8407alO0<0NWYj1038h=P308R8R0@0Ph>31P1oOgl407emO@<0PH610`28R8P407YjNP<0R8R8
0`20P80307inOP@0PH610`1nOWh30820P0@0OWin0`21PH470820P0<0OWin0`20P80707moO`<0OWin
1`1oOgl308:2PP<0Ogmo1`20P80307inOP@0OGem0`1oOgl?0<SPf0<0OWin101mOGd307moO`X0OWin
0`22PX840861P@<0Ogmo0`21PH4:07moO`<0P8201021PH4:07moO`T0PH611020P80307emO@L0P820
0`1oOgl307inOPL0Ogmo0`1nOWh707moO`@0b>3H0`21PH4406YZJP<0Ph>30`22PX8407inOP<0PX:2
0`1oOgl308R8R0L0OWin0`22PX8407alO0<0P8200`21PH4407emO@<0PX:20`20P80407moO`<0O7al
0`1oOgl308>3P`@0P8200`1lO7`307inOP@0PX:21P23Ph<407UiN@<0PH611`20P80307moOa@0b>3H
000C0<SPf0<0=SHf101:BTX301PH60<0F5QH101hN7P309nOW`<0d=3@101CDe<302HV9P<0:b/[0`19
BDT404I6AP<0IfMW0`1hN7P407moO`<0PX:20`29RHT4092@T0<0UIFE0`2JVYX40:2PX0<0WinO0`2U
YJD30:JVYP@0Y:BT0`2RXZ8309FEU@@0RHV91P22PX8407alO0<0NWYj1038h=P308R8R0@0Ph>31P1o
Ogl407emO@<0PH610`28R8P407YjNP<0R8R80`20P80307inOP@0PH610`1nOWh30820P0@0OWin0`21
PH470820P0<0OWin0`20P80707moO`<0OWin1`1oOgl308:2PP<0Ogmo1`20P80307inOP@0OGem0`1o
Ogl?0<SPf0<0OWin101mOGd307moO`X0OWin0`22PX840861P@<0Ogmo0`21PH4:07moO`<0P8201021
PH4:07moO`T0PH611020P80307emO@L0P8200`1oOgl307inOPL0Ogmo0`1nOWh707moO`@0b>3H0`21
PH4406YZJP<0Ph>30`22PX8407inOP<0PX:20`1oOgl308R8R0L0OWin0`22PX8407alO0<0P8200`21
PH4407emO@<0PX:20`20P80407moO`<0O7al0`1oOgl308>3P`@0P8200`1lO7`307inOP@0PX:21P23
Ph<407UiN@<0PH611`20P80307moOa@0b>3H000C0<SPf0<0=SHf101:BTX301PH60<0F5QH101hN7P3
09nOW`<0d=3@101CDe<302HV9P<0:b/[0`19BDT404I6AP<0IfMW0`1hN7P407moO`<0PX:20`29RHT4
092@T0<0UIFE0`2JVYX40:2PX0<0WinO0`2UYJD30:JVYP@0Y:BT0`2RXZ8309FEU@@0RHV91P22PX84
07alO0<0NWYj1038h=P308R8R0@0Ph>31P1oOgl407emO@<0PH610`28R8P407YjNP<0R8R80`20P803
07inOP@0PH610`1nOWh30820P0@0OWin0`21PH470820P0<0OWin0`20P80707moO`<0OWin1`1oOgl3
08:2PP<0Ogmo1`20P80307inOP@0OGem0`1oOgl?0<SPf0<0OWin101mOGd307moO`X0OWin0`22PX84
0861P@<0Ogmo0`21PH4:07moO`<0P8201021PH4:07moO`T0PH611020P80307emO@L0P8200`1oOgl3
07inOPL0Ogmo0`1nOWh707moO`@0b>3H0`21PH4406YZJP<0Ph>30`22PX8407inOP<0PX:20`1oOgl3
08R8R0L0OWin0`22PX8407alO0<0P8200`21PH4407emO@<0PX:20`20P80407moO`<0O7al0`1oOgl3
08>3P`@0P8200`1lO7`307inOP@0PX:21P23Ph<407UiN@<0PH611`20P80307moOa@0b>3H000C0<SP
f0<0L71`101oOgl301lO7`<0;Rh^1021PH4307alO0<0a<C41030`<03038b<P<0;bl_0`0n?Sh404M7
A`<0IfMW0`1fMWH40861P@<0Q8B40`2:RXX409:BTP<0VIVI0`2NWYh40::RXP<0Zj^[0`2ZZZX30:^[
Z`@0Z:RX0`2SXj<309VIV@@0RXZ:1P25QHD407inOP<0O7al1038h=P3079bLP@0M7Ad0`1oOgl307]k
N`@0P8200`25QHD307inOP@0NWYj0`27QhL307YjNP<0Ogmo101lO7`30820P0<0OWin1020P80307mo
O`<0OWin1`1oOgl30820P0@0NWYj0`1nOWh307emO@<0PH611`20P8030861P@@0Ogmo0`21PH4307in
OP@0P8200`1nOWh?0<SPf0<0P8201021PH430820P0<0Ogmo1020P80307inOPX0Ogmo0`22PX830820
P0L0PX:21`20P80307inOP<0Ogmo1021PH4907moO`h0P8200`1oOgl30861P@@0Ogmo0`1nOWh70820
P0<0Ogmo1038h=P308V9R@@0OGem0`1kNg/30861P@L0P8200`1oOgl30861P@@0Q8B40`23Ph<307em
O@@0NWYj0`25QHD308:2PP@0Ogmo1P22PX8407inOP<0OGem0`25QHD30820P0L0Ogmo0`22PX840820
P0<0PH610`22PX8708B4Q0<0OWin101oOgl30861PA@0b>3H000C0<SPf0<0L71`101oOgl301lO7`<0
;Rh^1021PH4307alO0<0a<C41030`<03038b<P<0;bl_0`0n?Sh404M7A`<0IfMW0`1fMWH40861P@<0
Q8B40`2:RXX409:BTP<0VIVI0`2NWYh40::RXP<0Zj^[0`2ZZZX30:^[Z`@0Z:RX0`2SXj<309VIV@@0
RXZ:1P25QHD407inOP<0O7al1038h=P3079bLP@0M7Ad0`1oOgl307]kN`@0P8200`25QHD307inOP@0
NWYj0`27QhL307YjNP<0Ogmo101lO7`30820P0<0OWin1020P80307moO`<0OWin1`1oOgl30820P0@0
NWYj0`1nOWh307emO@<0PH611`20P8030861P@@0Ogmo0`21PH4307inOP@0P8200`1nOWh?0<SPf0<0
P8201021PH430820P0<0Ogmo1020P80307inOPX0Ogmo0`22PX830820P0L0PX:21`20P80307inOP<0
Ogmo1021PH4907moO`h0P8200`1oOgl30861P@@0Ogmo0`1nOWh70820P0<0Ogmo1038h=P308V9R@@0
OGem0`1kNg/30861P@L0P8200`1oOgl30861P@@0Q8B40`23Ph<307emO@@0NWYj0`25QHD308:2PP@0
Ogmo1P22PX8407inOP<0OGem0`25QHD30820P0L0Ogmo0`22PX840820P0<0PH610`22PX8708B4Q0<0
OWin101oOgl30861PA@0b>3H000C0<SPf0<0L71`101oOgl301lO7`<0;Rh^1021PH4307alO0<0a<C4
1030`<03038b<P<0;bl_0`0n?Sh404M7A`<0IfMW0`1fMWH40861P@<0Q8B40`2:RXX409:BTP<0VIVI
0`2NWYh40::RXP<0Zj^[0`2ZZZX30:^[Z`@0Z:RX0`2SXj<309VIV@@0RXZ:1P25QHD407inOP<0O7al
1038h=P3079bLP@0M7Ad0`1oOgl307]kN`@0P8200`25QHD307inOP@0NWYj0`27QhL307YjNP<0Ogmo
101lO7`30820P0<0OWin1020P80307moO`<0OWin1`1oOgl30820P0@0NWYj0`1nOWh307emO@<0PH61
1`20P8030861P@@0Ogmo0`21PH4307inOP@0P8200`1nOWh?0<SPf0<0P8201021PH430820P0<0Ogmo
1020P80307inOPX0Ogmo0`22PX830820P0L0PX:21`20P80307inOP<0Ogmo1021PH4907moO`h0P820
0`1oOgl30861P@@0Ogmo0`1nOWh70820P0<0Ogmo1038h=P308V9R@@0OGem0`1kNg/30861P@L0P820
0`1oOgl30861P@@0Q8B40`23Ph<307emO@@0NWYj0`25QHD308:2PP@0Ogmo1P22PX8407inOP<0OGem
0`25QHD30820P0L0Ogmo0`22PX840820P0<0PH610`22PX8708B4Q0<0OWin101oOgl30861PA@0b>3H
000C0<SPf0<0L71`101oOgl301lO7`<0;Rh^1021PH4307alO0<0a<C41030`<03038b<P<0;bl_0`0n
?Sh404M7A`<0IfMW0`1fMWH40861P@<0Q8B40`2:RXX409:BTP<0VIVI0`2NWYh40::RXP<0Zj^[0`2Z
ZZX30:^[Z`@0Z:RX0`2SXj<309VIV@@0RXZ:1P25QHD407inOP<0O7al1038h=P3079bLP@0M7Ad0`1o
Ogl307]kN`@0P8200`25QHD307inOP@0NWYj0`27QhL307YjNP<0Ogmo101lO7`30820P0<0OWin1020
P80307moO`<0OWin1`1oOgl30820P0@0NWYj0`1nOWh307emO@<0PH611`20P8030861P@@0Ogmo0`21
PH4307inOP@0P8200`1nOWh?0<SPf0<0P8201021PH430820P0<0Ogmo1020P80307inOPX0Ogmo0`22
PX830820P0L0PX:21`20P80307inOP<0Ogmo1021PH4907moO`h0P8200`1oOgl30861P@@0Ogmo0`1n
OWh70820P0<0Ogmo1038h=P308V9R@@0OGem0`1kNg/30861P@L0P8200`1oOgl30861P@@0Q8B40`23
Ph<307emO@@0NWYj0`25QHD308:2PP@0Ogmo1P22PX8407inOP<0OGem0`25QHD30820P0L0Ogmo0`22
PX840820P0<0PH610`22PX8708B4Q0<0OWin101oOgl30861PA@0b>3H000C0<SPf0<0S8b<100h>3P3
02LW9`<08R8R101UIFD307=cL`<0[Jf]1035aLD309>CT`<09bLW0`0i>CT404Y:BP<0KFe]0`1iNGT4
0861P@<0QHF50`2=SHd409>CT`<0V9RH0`2NWYh40:RXZ0<0[jn_0`2`/;030:f][@@0Zj^[0`2TY:@3
09^KV`@0Shn?1P2:RXX40820P0<0Ogmo1038h=P309>CT`@0Rh^;0`22PX8308>3P`@0OWin0`22PX83
07inOP@0R8R80`1fMWH30861P@<0NWYj1021PH4307inOP<0PX:2101lO7`30820P0<0OWin1024Q8@3
0820P0L0PH610`1nOWh308>3P`<0OGem101lO7`30861P@<0OWin1025QHD307moO`<0P8201021PH43
07moO`l0b>3H0`21PH4707moO`<0O7al1`1oOgl307inOP@0P8200`1lO7`307moO`<0OWin1022PX83
0820P0<0Ogmo1021PH4307emO@L0P8200`21PH430820P0<0PH61101oOgl308:2PPL0Ogmo1P21PH44
07moO`X0P8200`1oOgl40<SPf0<0P820101iNGT307inOP<0P820101oOgl307AdM0<0Ph>30`21PH44
07UiN@<0O7al1`23Ph<307emO@<0P820101nOWh308:2PP<0P820101mOGd307moO`<0Q8B40`1oOgl4
08:2PP<0NGUi0`1nOWh408>3P`<0PX:20`1nOWh40820P0<0Ogmo1`20P80307inOQ@0b>3H000C0<SP
f0<0S8b<100h>3P302LW9`<08R8R101UIFD307=cL`<0[Jf]1035aLD309>CT`<09bLW0`0i>CT404Y:
BP<0KFe]0`1iNGT40861P@<0QHF50`2=SHd409>CT`<0V9RH0`2NWYh40:RXZ0<0[jn_0`2`/;030:f]
[@@0Zj^[0`2TY:@309^KV`@0Shn?1P2:RXX40820P0<0Ogmo1038h=P309>CT`@0Rh^;0`22PX8308>3
P`@0OWin0`22PX8307inOP@0R8R80`1fMWH30861P@<0NWYj1021PH4307inOP<0PX:2101lO7`30820
P0<0OWin1024Q8@30820P0L0PH610`1nOWh308>3P`<0OGem101lO7`30861P@<0OWin1025QHD307mo
O`<0P8201021PH4307moO`l0b>3H0`21PH4707moO`<0O7al1`1oOgl307inOP@0P8200`1lO7`307mo
O`<0OWin1022PX830820P0<0Ogmo1021PH4307emO@L0P8200`21PH430820P0<0PH61101oOgl308:2
PPL0Ogmo1P21PH4407moO`X0P8200`1oOgl40<SPf0<0P820101iNGT307inOP<0P820101oOgl307Ad
M0<0Ph>30`21PH4407UiN@<0O7al1`23Ph<307emO@<0P820101nOWh308:2PP<0P820101mOGd307mo
O`<0Q8B40`1oOgl408:2PP<0NGUi0`1nOWh408>3P`<0PX:20`1nOWh40820P0<0Ogmo1`20P80307in
OQ@0b>3H000C0<SPf0<0S8b<100h>3P302LW9`<08R8R101UIFD307=cL`<0[Jf]1035aLD309>CT`<0
9bLW0`0i>CT404Y:BP<0KFe]0`1iNGT40861P@<0QHF50`2=SHd409>CT`<0V9RH0`2NWYh40:RXZ0<0
[jn_0`2`/;030:f][@@0Zj^[0`2TY:@309^KV`@0Shn?1P2:RXX40820P0<0Ogmo1038h=P309>CT`@0
Rh^;0`22PX8308>3P`@0OWin0`22PX8307inOP@0R8R80`1fMWH30861P@<0NWYj1021PH4307inOP<0
PX:2101lO7`30820P0<0OWin1024Q8@30820P0L0PH610`1nOWh308>3P`<0OGem101lO7`30861P@<0
OWin1025QHD307moO`<0P8201021PH4307moO`l0b>3H0`21PH4707moO`<0O7al1`1oOgl307inOP@0
P8200`1lO7`307moO`<0OWin1022PX830820P0<0Ogmo1021PH4307emO@L0P8200`21PH430820P0<0
PH61101oOgl308:2PPL0Ogmo1P21PH4407moO`X0P8200`1oOgl40<SPf0<0P820101iNGT307inOP<0
P820101oOgl307AdM0<0Ph>30`21PH4407UiN@<0O7al1`23Ph<307emO@<0P820101nOWh308:2PP<0
P820101mOGd307moO`<0Q8B40`1oOgl408:2PP<0NGUi0`1nOWh408>3P`<0PX:20`1nOWh40820P0<0
Ogmo1`20P80307inOQ@0b>3H000C0<SPf0<0?3`l1`0X:2P302XZ:P@0<c<c1P26QXH40;fm_@<0`/;2
0`1HF5P302l_;`@0C4a<0`1_Kfl307UiN@@0Ogmo0`25QHD308f=S@@0UIFE0`2KVi/30:RXZ0@0[Zj^
0`2b/[830;Fe]@<0[Zj^102/[:`30:RXZ0<0WYjN102EUID309:BTP<0SHf=1024Q8@30861P@@0b>3H
0`1]KFd40861P@<0OWin0`1mOGd408:2PP<0N7Qh0`23Ph<407YjNP<0QHF50`1nOWh307moO`@0PH61
0`1nOWh30820P0@0Q8B40`1oOgl307inOP@0OGem0`20P80307inOP@0Ogmo0`1nOWh308B4Q0L0Ogmo
0`20P80307inOPL0Ogmo0`1mOGd407inOP<0PH613`38h=P30861P@@0NGUi0`1oOgl30820P0@0OWin
0`1mOGd30861P@@0Ogmo0`20P8030861P@<0Ogmo1020P80D07moO`<0PH612P1oOgl60820P0@0Ogmo
0`20P8030861P@@0P8200`21PH4307moO`L0P8201038h=P308>3P`@0O7al0`24Q8@307emO@@0NWYj
0`1hN7P307alO0<0OWin101lO7`308B4Q0<0OGem101nOWh:0820P0<0OGem0`1jNWX407moO`<0PX:2
0`1mOGd30820P0@0Ogmo0`1jNWX30820P0@0OWin0`1mOGd307]kN`@0Ph>30`1kNg/307emO@@0Ng]k
0`1nOWhD0<SPf0004`38h=P303`l?0L0:2PX0`0Z:RX403<c<`H0QXJ6102m_Kd30<;2`P<0F5QH0`0_
;bl404a<C0<0Kfm_0`1iNGT407moO`<0QHF50`2=SHd409FEU@<0Vi^K0`2XZ:P40:j^[P<0/[:b0`2e
]KD30:j^[P@0[:b/0`2XZ:P309jNWP@0UIFE0`2BTY8308f=S@@0Q8B40`21PH440<SPf0<0KFe]1021
PH4307inOP<0OGem1022PX8307QhN0<0Ph>3101jNWX308F5Q@<0OWin0`1oOgl40861P@<0OWin0`20
P80408B4Q0<0Ogmo0`1nOWh407emO@<0P8200`1nOWh407moO`<0OWin0`24Q8@707moO`<0P8200`1n
OWh707moO`<0OGem101nOWh30861P@l0b>3H0`21PH4407UiN@<0Ogmo0`20P80407inOP<0OGem0`21
PH4407moO`<0P8200`21PH4307moO`@0P820501oOgl30861P@X0Ogmo1P20P80407moO`<0P8200`21
PH440820P0<0PH610`1oOgl70820P0@0b>3H0`23Ph<407alO0<0Q8B40`1mOGd407YjNP<0N7Qh0`1l
O7`307inOP@0O7al0`24Q8@307emO@@0OWin2P20P80307emO@<0NWYj101oOgl308:2PP<0OGem0`20
P80407moO`<0NWYj0`20P80407inOP<0OGem0`1kNg/408>3P`<0Ng]k0`1mOGd407]kN`<0OWin5038
h=P001<0b>3H0`0l?3`702PX:0<0:RXZ100c<c<608J6QP@0_Kfm0`32`/8305QHF0<0;bl_101<C4`3
06m_K`<0NGUi101oOgl308F5Q@<0SHf=102EUID309^KV`<0Z:RX102^[Zh30;:b/P<0]KFe0`2^[Zh4
0:b/[0<0Z:RX0`2NWYh409FEU@<0TY:B0`2=SHd408B4Q0<0PH611038h=P306e]K@@0PH610`1nOWh3
07emO@@0PX:20`1hN7P308>3P`@0NWYj0`25QHD307inOP<0Ogmo1021PH4307inOP<0P8201024Q8@3
07moO`<0OWin101mOGd30820P0<0OWin101oOgl307inOP<0Q8B41`1oOgl30820P0<0OWin1`1oOgl3
07emO@@0OWin0`21PH4?0<SPf0<0PH61101iNGT307moO`<0P820101nOWh307emO@<0PH61101oOgl3
0820P0<0PH610`1oOgl40820P1@0Ogmo0`21PH4:07moO`H0P820101oOgl30820P0<0PH611020P803
0861P@<0Ogmo1`20P8040<SPf0<0Ph>3101lO7`308B4Q0<0OGem101jNWX307QhN0<0O7al0`1nOWh4
07alO0<0Q8B40`1mOGd407inOPX0P8200`1mOGd307YjNP@0Ogmo0`22PX8307emO@<0P820101oOgl3
07YjNP<0P820101nOWh307emO@<0Ng]k1023Ph<307]kN`<0OGem101kNg/307inOQ@0b>3H000C0<SP
f0<0>c/k100];Bd302h^;P<0;bl_100X:2P306][J`<0N7Qh102WYjL30;Rh^0<0_kno0`0c<c<404U9
B@<0JVYZ0`1iNGT407inOP<0QhN70`2BTY8409RHV0<0XJ6Q0`2ZZZX40:n_[`d0/;2`0`2/[:`30:>S
X`@0UiNG0`2CTi<308f=S@@0QHF50`21PH440<SPf0<0NGUi1`1mOGd307inOP@0Ogmo1P23Ph<407Ui
N@<0PX:20`1jNWX308R8R0@0O7al0`23Ph<30820P0@0PH610`1oOgl70820P0<0PH611`1nOWh308B4
Q0<0Ogmo0`1lO7`70820P0<0Ng]k1021PH4307alO0<0Ogmo1`1nOWh?0<SPf0<0O7al1023Ph<:07mo
O`<0Ng]k0`1nOWh:07moOa@0P8202P1oOgl60820P0@0Ogmo3@21PH4307moO`L0P8201`21PH4307mo
O`@0b>3H0`28R8P70820P0<0Ph>3101iNGT307moO`<0O7al0`20P80407moO`<0P8200`21PH4408>3
P`<0P8200`24Q8@707emO@L0OWin0`21PH4307inOP<0PH61101oOgl308B4Q0<0O7al1022PX8307]k
N`<0OWin1021PH4307]kN`<0P820101nOWh30820P1@0b>3H000C0<SPf0<0>c/k100];Bd302h^;P<0
;bl_100X:2P306][J`<0N7Qh102WYjL30;Rh^0<0_kno0`0c<c<404U9B@<0JVYZ0`1iNGT407inOP<0
QhN70`2BTY8409RHV0<0XJ6Q0`2ZZZX40:n_[`d0/;2`0`2/[:`30:>SX`@0UiNG0`2CTi<308f=S@@0
QHF50`21PH440<SPf0<0NGUi1`1mOGd307inOP@0Ogmo1P23Ph<407UiN@<0PX:20`1jNWX308R8R0@0
O7al0`23Ph<30820P0@0PH610`1oOgl70820P0<0PH611`1nOWh308B4Q0<0Ogmo0`1lO7`70820P0<0
Ng]k1021PH4307alO0<0Ogmo1`1nOWh?0<SPf0<0O7al1023Ph<:07moO`<0Ng]k0`1nOWh:07moOa@0
P8202P1oOgl60820P0@0Ogmo3@21PH4307moO`L0P8201`21PH4307moO`@0b>3H0`28R8P70820P0<0
Ph>3101iNGT307moO`<0O7al0`20P80407moO`<0P8200`21PH4408>3P`<0P8200`24Q8@707emO@L0
OWin0`21PH4307inOP<0PH61101oOgl308B4Q0<0O7al1022PX8307]kN`<0OWin1021PH4307]kN`<0
P820101nOWh30820P1@0b>3H000C0<SPf0<0>c/k100];Bd302h^;P<0;bl_100X:2P306][J`<0N7Qh
102WYjL30;Rh^0<0_kno0`0c<c<404U9B@<0JVYZ0`1iNGT407inOP<0QhN70`2BTY8409RHV0<0XJ6Q
0`2ZZZX40:n_[`d0/;2`0`2/[:`30:>SX`@0UiNG0`2CTi<308f=S@@0QHF50`21PH440<SPf0<0NGUi
1`1mOGd307inOP@0Ogmo1P23Ph<407UiN@<0PX:20`1jNWX308R8R0@0O7al0`23Ph<30820P0@0PH61
0`1oOgl70820P0<0PH611`1nOWh308B4Q0<0Ogmo0`1lO7`70820P0<0Ng]k1021PH4307alO0<0Ogmo
1`1nOWh?0<SPf0<0O7al1023Ph<:07moO`<0Ng]k0`1nOWh:07moOa@0P8202P1oOgl60820P0@0Ogmo
3@21PH4307moO`L0P8201`21PH4307moO`@0b>3H0`28R8P70820P0<0Ph>3101iNGT307moO`<0O7al
0`20P80407moO`<0P8200`21PH4408>3P`<0P8200`24Q8@707emO@L0OWin0`21PH4307inOP<0PH61
101oOgl308B4Q0<0O7al1022PX8307]kN`<0OWin1021PH4307]kN`<0P820101nOWh30820P1@0b>3H
000C0<SPf0<0<C4a100`<30302`/;0<0;Rh^100_;bl303Ph>0<0Q8B41022PX830;Ng]`<0`<300`2O
Wil403/k>`<0IVIV0`1dM7@407moO`<0R8R80`2CTi<409ZJVP<0Xj>S0`2XZ:P40:f][@<0[:b/0`2^
[Zh30:^[Z`@0ZZZZ0`2^[Zh30::RXP@0U9BD0`2>SXh308^;R`@0PX:20`20P8040<SPf0<0OGem101j
NWX307moO`<0P820101lO7`308B4Q0<0NWYj101lO7`307inOP<0PH610`1hN7P408f=S@<0MgMg1`20
P80307emO@<0PH611020P80307moO`<0Ph>3101nOWh30861P@<0QHF50`1mOGd408B4Q0<0Ph>31`21
PH430820P0<0Q8B41020P80307inOPl0b>3H0`20P80707moO`<0OWin101mOGd60820P0@0PH610`1n
OWh30861P@<0Ogmo1021PH460820P0@0OWin0`1oOgl30820P0@0OWin2@20P80407moO`<0OGem0`20
P8040861P@<0P8200`22PX8407inOP<0P8200`1nOWh40861P@<0P8201038h=P308>3P`@0OWin1P1l
O7`40861P@<0Q8B40`1nOWh:07moO`<0PH61101mOGd307moO`L0P8200`21PH4308>3P`@0Ng]k3@21
PH4307moO`<0PX:2101lO7`307emO@<0O7al1020P80307moO`<0PH611023Ph<308:2PQ@0b>3H000C
0<SPf0<0<C4a100`<30302`/;0<0;Rh^100_;bl303Ph>0<0Q8B41022PX830;Ng]`<0`<300`2OWil4
03/k>`<0IVIV0`1dM7@407moO`<0R8R80`2CTi<409ZJVP<0Xj>S0`2XZ:P40:f][@<0[:b/0`2^[Zh3
0:^[Z`@0ZZZZ0`2^[Zh30::RXP@0U9BD0`2>SXh308^;R`@0PX:20`20P8040<SPf0<0OGem101jNWX3
07moO`<0P820101lO7`308B4Q0<0NWYj101lO7`307inOP<0PH610`1hN7P408f=S@<0MgMg1`20P803
07emO@<0PH611020P80307moO`<0Ph>3101nOWh30861P@<0QHF50`1mOGd408B4Q0<0Ph>31`21PH43
0820P0<0Q8B41020P80307inOPl0b>3H0`20P80707moO`<0OWin101mOGd60820P0@0PH610`1nOWh3
0861P@<0Ogmo1021PH460820P0@0OWin0`1oOgl30820P0@0OWin2@20P80407moO`<0OGem0`20P804
0861P@<0P8200`22PX8407inOP<0P8200`1nOWh40861P@<0P8201038h=P308>3P`@0OWin1P1lO7`4
0861P@<0Q8B40`1nOWh:07moO`<0PH61101mOGd307moO`L0P8200`21PH4308>3P`@0Ng]k3@21PH43
07moO`<0PX:2101lO7`307emO@<0O7al1020P80307moO`<0PH611023Ph<308:2PQ@0b>3H000C0<SP
f0<0<C4a100`<30302`/;0<0;Rh^100_;bl303Ph>0<0Q8B41022PX830;Ng]`<0`<300`2OWil403/k
>`<0IVIV0`1dM7@407moO`<0R8R80`2CTi<409ZJVP<0Xj>S0`2XZ:P40:f][@<0[:b/0`2^[Zh30:^[
Z`@0ZZZZ0`2^[Zh30::RXP@0U9BD0`2>SXh308^;R`@0PX:20`20P8040<SPf0<0OGem101jNWX307mo
O`<0P820101lO7`308B4Q0<0NWYj101lO7`307inOP<0PH610`1hN7P408f=S@<0MgMg1`20P80307em
O@<0PH611020P80307moO`<0Ph>3101nOWh30861P@<0QHF50`1mOGd408B4Q0<0Ph>31`21PH430820
P0<0Q8B41020P80307inOPl0b>3H0`20P80707moO`<0OWin101mOGd60820P0@0PH610`1nOWh30861
P@<0Ogmo1021PH460820P0@0OWin0`1oOgl30820P0@0OWin2@20P80407moO`<0OGem0`20P8040861
P@<0P8200`22PX8407inOP<0P8200`1nOWh40861P@<0P8201038h=P308>3P`@0OWin1P1lO7`40861
P@<0Q8B40`1nOWh:07moO`<0PH61101mOGd307moO`L0P8200`21PH4308>3P`@0Ng]k3@21PH4307mo
O`<0PX:2101lO7`307emO@<0O7al1020P80307moO`<0PH611023Ph<308:2PQ@0b>3H000C0<SPf0<0
<C4a100`<30302`/;0<0;Rh^100_;bl303Ph>0<0Q8B41022PX830;Ng]`<0`<300`2OWil403/k>`<0
IVIV0`1dM7@407moO`<0R8R80`2CTi<409ZJVP<0Xj>S0`2XZ:P40:f][@<0[:b/0`2^[Zh30:^[Z`@0
ZZZZ0`2^[Zh30::RXP@0U9BD0`2>SXh308^;R`@0PX:20`20P8040<SPf0<0OGem101jNWX307moO`<0
P820101lO7`308B4Q0<0NWYj101lO7`307inOP<0PH610`1hN7P408f=S@<0MgMg1`20P80307emO@<0
PH611020P80307moO`<0Ph>3101nOWh30861P@<0QHF50`1mOGd408B4Q0<0Ph>31`21PH430820P0<0
Q8B41020P80307inOPl0b>3H0`20P80707moO`<0OWin101mOGd60820P0@0PH610`1nOWh30861P@<0
Ogmo1021PH460820P0@0OWin0`1oOgl30820P0@0OWin2@20P80407moO`<0OGem0`20P8040861P@<0
P8200`22PX8407inOP<0P8200`1nOWh40861P@<0P8201038h=P308>3P`@0OWin1P1lO7`40861P@<0
Q8B40`1nOWh:07moO`<0PH61101mOGd307moO`L0P8200`21PH4308>3P`@0Ng]k3@21PH4307moO`<0
PX:2101lO7`307emO@<0O7al1020P80307moO`<0PH611023Ph<308:2PQ@0b>3H000C0<SPf0<0;Rh^
100_;bl302XZ:P<0<S8b100c<c<302LW9`<0IfMW101bLW830:JVYP<0]KFe0`38b<P408N7Q`<0E5AD
0`1dM7@407emO@<0RHV90`2DU9@409ZJVP<0Xj>S0`2RXZ840:NWY`<0XJ6Q0`2RXZ870:VYZ@H0YZJV
102FUYH308V9R@<0Rh^;1`22PX840<SPf0<0PH611022PX860820P0X0PH612P1mOGd308N7Q`@0KFe]
0`2ATI4307UiN@@0PX:20`20P80307inOP@0Ph>30`1oOgl307]kN`@0QXJ60`25QHD30861P@<0P820
101oOgl307emO@<0P820101nOWh308B4Q0<0Ogmo1022PX8307inOPl0b>3H1`20P8030861P@<0P820
1`1nOWh70820P0<0Ogmo1P20P80407emO@X0Ogmo0`20P80707moO`<0P8200`1oOgl30861P@@0P820
0`22PX8307inOP@0Ogmo0`20P8030861P@@0P8202P1oOgl308:2PP@0b>3H0`1nOWh408B4Q0<0P820
0`24Q8@407emO@H0OWin0`1oOgl408J6QP<0NWYj0`20P80408:2PP<0Ng]k0`21PH4407alO0<0P820
0`22PX8407alO0<0OGem0`23Ph<30820P0@0NGUi0`1jNWX307MgM`@0Ng]k0`21PH430820P0@0Ogmo
0`22PX8307inOPL0Ogmo5038h=P001<0b>3H0`0^;Rh402l_;`<0:RXZ0`0b<S8403<c<`<09bLW0`1W
IfL4079bLP<0YZJV0`2e]KD30<S8b0@0QhN70`1DE5@307AdM0@0OGem0`29RHT309BDU0@0VYZJ0`2S
Xj<30::RXP@0YjNW0`2QXJ430::RXPL0ZJVY1P2VYZH409JFUP<0RHV90`2;Rh/708:2PP@0b>3H0`21
PH4408:2PPH0P8202P21PH4:07emO@<0QhN7101]KFd3096AT@<0NGUi1022PX830820P0<0OWin1023
Ph<307moO`<0Ng]k1026QXH308F5Q@<0PH610`20P80407moO`<0OGem0`20P80407inOP<0Q8B40`1o
Ogl408:2PP<0OWin3`38h=P70820P0<0PH610`20P80707inOPL0P8200`1oOgl60820P0@0OGem2P1o
Ogl30820P0L0Ogmo0`20P80307moO`<0PH611020P80308:2PP<0OWin101oOgl30820P0<0PH611020
P80:07moO`<0PX:21038h=P307inOP@0Q8B40`20P80308B4Q0@0OGem1P1nOWh307moO`@0QXJ60`1j
NWX30820P0@0PX:20`1kNg/30861P@@0O7al0`20P80308:2PP@0O7al0`1mOGd308>3P`<0P820101i
NGT307YjNP<0MgMg101kNg/30861P@<0P820101oOgl308:2PP<0OWin1`1oOglD0<SPf0004`38h=P3
02h^;P@0;bl_0`0Z:RX3038b<P@0<c<c0`0W9bL306MWI`@0LW9b0`2VYZH30;Fe]@<0b<S81027QhL3
05ADE0<0M7Ad101mOGd308V9R@<0U9BD102JVYX30:>SX`<0XZ:R102WYjL30:6QX@<0XZ:R1`2YZJT6
0:JVYP@0UYJF0`29RHT308^;R`L0PX:21038h=P30861P@@0PX:21P20P80:0861P@X0OGem0`27QhL4
06e]K@<0TI6A0`1iNGT408:2PP<0P8200`1nOWh408>3P`<0Ogmo0`1kNg/408J6QP<0QHF50`21PH43
0820P0@0Ogmo0`1mOGd30820P0@0OWin0`24Q8@307moO`@0PX:20`1nOWh?0<SPf0L0P8200`21PH43
0820P0L0OWin1`20P80307moO`H0P820101mOGd:07moO`<0P8201`1oOgl30820P0<0Ogmo0`21PH44
0820P0<0PX:20`1nOWh407moO`<0P8200`21PH440820P0X0Ogmo0`22PX840<SPf0<0OWin1024Q8@3
0820P0<0Q8B4101mOGd607inOP<0Ogmo1026QXH307YjNP<0P8201022PX8307]kN`<0PH61101lO7`3
0820P0<0PX:2101lO7`307emO@<0Ph>30`20P80407UiN@<0NWYj0`1gMgL407]kN`<0PH610`20P804
07moO`<0PX:20`1nOWh707moOa@0b>3H000C0<SPf0<0;2`/100_;bl302d];@<0<C4a100^;Rh602XZ
:PL0Q8B40`2][Jd30;>c/`@0bLW90`1hN7P3069RHP@0O7al0`28R8P309BDU0@0UYJF0`2GUiL309FE
U@@0TY:B0`2@T90308j>SP<0TY:B102JVYX30::RXP<0Vi^K102JVYX30820P0<0R8R81`21PH440<SP
f0<0OWin101lO7`307moO`<0P820101lO7`307emO@<0Q8B4101hN7P308J6QP<0Ph>30`1nOWh408Z:
RP<0Kfm_0`2CTi<407]kN`<0Ph>30`20P80408:2PP<0OWin0`25QHD407alO0<0NWYj0`1iNGT307mo
O`@0MGEe0`1lO7`308b<S0@0QhN70`1oOgl:0820P0l0b>3H1`1lO7`30861P@<0O7al101oOgl308:2
PP<0P820101oOgl307inOP<0PH611`1oOgl307inOP<0PH611`1oOgl=0820P0L0OWin0`1oOgl307al
O0@0NWYj0`1mOGd30861PA40P8201038h=P308^;R`@0OWin0`21PH4307MgM`@0NWYj0`22PX830861
P@<0OGem1`22PX8308>3P`@0Ogmo0`21PH4307emO@@0Ogmo0`21PH4307inOP@0P8200`1lO7`308B4
Q0<0P820101mOGd30820P0<0R8R8102ATI4308B4Q0<0MgMg101kNg/30861P@<0P820101lO7`30861
PA@0b>3H000C0<SPf0<0;2`/100_;bl302d];@<0<C4a100^;Rh602XZ:PL0Q8B40`2][Jd30;>c/`@0
bLW90`1hN7P3069RHP@0O7al0`28R8P309BDU0@0UYJF0`2GUiL309FEU@@0TY:B0`2@T90308j>SP<0
TY:B102JVYX30::RXP<0Vi^K102JVYX30820P0<0R8R81`21PH440<SPf0<0OWin101lO7`307moO`<0
P820101lO7`307emO@<0Q8B4101hN7P308J6QP<0Ph>30`1nOWh408Z:RP<0Kfm_0`2CTi<407]kN`<0
Ph>30`20P80408:2PP<0OWin0`25QHD407alO0<0NWYj0`1iNGT307moO`@0MGEe0`1lO7`308b<S0@0
QhN70`1oOgl:0820P0l0b>3H1`1lO7`30861P@<0O7al101oOgl308:2PP<0P820101oOgl307inOP<0
PH611`1oOgl307inOP<0PH611`1oOgl=0820P0L0OWin0`1oOgl307alO0@0NWYj0`1mOGd30861PA40
P8201038h=P308^;R`@0OWin0`21PH4307MgM`@0NWYj0`22PX830861P@<0OGem1`22PX8308>3P`@0
Ogmo0`21PH4307emO@@0Ogmo0`21PH4307inOP@0P8200`1lO7`308B4Q0<0P820101mOGd30820P0<0
R8R8102ATI4308B4Q0<0MgMg101kNg/30861P@<0P820101lO7`30861PA@0b>3H000C0<SPf0<0;2`/
100_;bl302d];@<0<C4a100^;Rh602XZ:PL0Q8B40`2][Jd30;>c/`@0bLW90`1hN7P3069RHP@0O7al
0`28R8P309BDU0@0UYJF0`2GUiL309FEU@@0TY:B0`2@T90308j>SP<0TY:B102JVYX30::RXP<0Vi^K
102JVYX30820P0<0R8R81`21PH440<SPf0<0OWin101lO7`307moO`<0P820101lO7`307emO@<0Q8B4
101hN7P308J6QP<0Ph>30`1nOWh408Z:RP<0Kfm_0`2CTi<407]kN`<0Ph>30`20P80408:2PP<0OWin
0`25QHD407alO0<0NWYj0`1iNGT307moO`@0MGEe0`1lO7`308b<S0@0QhN70`1oOgl:0820P0l0b>3H
1`1lO7`30861P@<0O7al101oOgl308:2PP<0P820101oOgl307inOP<0PH611`1oOgl307inOP<0PH61
1`1oOgl=0820P0L0OWin0`1oOgl307alO0@0NWYj0`1mOGd30861PA40P8201038h=P308^;R`@0OWin
0`21PH4307MgM`@0NWYj0`22PX830861P@<0OGem1`22PX8308>3P`@0Ogmo0`21PH4307emO@@0Ogmo
0`21PH4307inOP@0P8200`1lO7`308B4Q0<0P820101mOGd30820P0<0R8R8102ATI4308B4Q0<0MgMg
101kNg/30861P@<0P820101lO7`30861PA@0b>3H000C0<SPf0<0;2`/100];Bd302l_;`<0;Bd]100c
<c<302XZ:P<08B4Q101DE5@307=cL`<0ZZZZ0`2YZJT40;^k^`<0alO70`1fMWH407=cL`<0QHF50`29
RHT408f=S@<0Shn?0`2<S8`408^;R`<0MgMg0`1`L70308B4Q0@0NGUi0`2CTi<30:6QX@@0UYJF0`1k
Ng/70820P0<0QHF51038h=P70820P0<0O7al0`26QXH408:2PP<0P8200`1mOGd408N7Q`<0OWin0`1k
Ng/30861P@@0O7al0`26QXH3079bLP@0S8b<0`1mOGd70861P@<0Ogmo0`22PX8407IfMP<0T92@0`2F
UYH3092@T0@0P8200`1nOWh306YZJP@0JFUY0`1nOWh30820P0@0PH610`1nOWh?0<SPf0<0Ogmo101m
OGd60820P0@0Ogmo1P1nOWh408:2PP<0P8200`21PH430820P0@0OWin0`20P80307]kN`@0PH610`20
P8030861P@@0Ogmo0`1nOWh307moO`<0OWin1024Q8@307moO`<0QHF5102<S8`307moO`<0Ng]k1020
P8030861P@<0P820101nOWh30861P@@0b>3H0`1kNg/40820P0<0PX:20`1lO7`407moO`<0N7Qh0`23
Ph<307alO0@0Ng]k0`1mOGd308>3P`@0P8200`1nOWh308:2PP@0P8201P1nOWh40861P@<0Ogmo0`1m
OGd308>3P`@0MGEe0`29RHT308F5Q@@0S8b<0`2ATI4308:2PP@0Ng]k0`21PH4707alO0<0Ng]k5038
h=P001<0b>3H0`0/;2`402d];@<0;bl_0`0];Bd403<c<`<0:RXZ0`0Q8B4405ADE0<0Lg=c0`2ZZZX3
0:VYZ@@0^k^k0`37alL307IfMP@0Lg=c0`25QHD308V9R@@0SHf=0`2?Shl308b<S0@0Rh^;0`1gMgL3
071`L0<0Q8B4101iNGT309>CT`<0XJ6Q102FUYH307]kN`L0P8200`25QHD40<SPf0L0P8200`1lO7`3
08J6QP@0PX:20`20P80307emO@@0QhN70`1nOWh307]kN`<0PH61101lO7`308J6QP<0LW9b102<S8`3
07emO@L0PH610`1oOgl308:2PP@0MWIf0`2@T90309JFUP<0T92@1020P80307inOP<0JVYZ101YJFT3
07inOP<0P8201021PH4307inOPl0b>3H0`1oOgl407emO@H0P820101oOgl607inOP@0PX:20`20P803
0861P@<0P820101nOWh30820P0<0Ng]k1021PH430820P0<0PH61101oOgl307inOP<0Ogmo0`1nOWh4
08B4Q0<0Ogmo0`25QHD408b<S0<0Ogmo0`1kNg/40820P0<0PH610`20P80407inOP<0PH611038h=P3
07]kN`@0P8200`22PX8307alO0@0Ogmo0`1hN7P308>3P`<0O7al101kNg/307emO@<0Ph>31020P803
07inOP<0PX:21020P80607inOP@0PH610`1oOgl307emO@<0Ph>3101eMGD308V9R@<0QHF5102<S8`3
096AT@<0PX:2101kNg/30861P@L0O7al0`1kNg/D0<SPf0004`38h=P302`/;0@0;Bd]0`0_;bl302d]
;@@0<c<c0`0Z:RX3024Q8@@0E5AD0`1cLg<30:ZZZP<0ZJVY102k^k/30<O7a`<0MWIf101cLg<308F5
Q@<0RHV9102=SHd308n?S`<0S8b<102;Rh/307MgM`<0L71`0`24Q8@407UiN@<0Ti>C0`2QXJ4409JF
UP<0Ng]k1`20P80308F5Q@@0b>3H1`20P80307alO0<0QXJ61022PX830820P0<0OGem1027QhL307in
OP<0Ng]k0`21PH4407alO0<0QXJ60`1bLW8408b<S0<0OGem1`21PH4307moO`<0PX:2101fMWH3092@
T0<0UYJF0`2@T9040820P0<0OWin0`1ZJVX406UYJ@<0OWin0`20P8040861P@<0OWin3`38h=P307mo
O`@0OGem1P20P80407moO`H0OWin1022PX830820P0<0PH610`20P80407inOP<0P8200`1kNg/40861
P@<0P8200`21PH4407moO`<0OWin0`1oOgl307inOP@0Q8B40`1oOgl308F5Q@@0S8b<0`1oOgl307]k
N`@0P8200`21PH430820P0@0OWin0`21PH440<SPf0<0Ng]k1020P80308:2PP<0O7al101oOgl307Qh
N0<0Ph>30`1lO7`407]kN`<0OGem0`23Ph<40820P0<0OWin0`22PX840820P0H0OWin1021PH4307mo
O`<0OGem0`23Ph<407EeM@<0RHV90`25QHD408b<S0<0TI6A0`22PX8407]kN`<0PH611`1lO7`307]k
Na@0b>3H000C0<SPf0<0:BTY100Z:RX3030`<0<0=SHf100^;Rh303<c<`<0:2PX100V9RH307QhN0<0
QhN70`2_[jl40;>c/`<0`/;20`33`l<407emO@<0Ng]k0`1nOWh708Z:RP<0L71`101VIVH30820P0<0
RXZ:0`2/[:`40;Zj^P<0][Jf0`2JVYX408F5Q@<0PH610`1gMgL40820P0<0QhN71038h=P307emO@@0
NGUi0`2<S8`30820P0@0Q8B40`26QXH70820P0<0MGEe0`25QHD307QhN0@0NGUi0`1mOGd308J6QP@0
Kfm_0`29RHT30820P0@0OGem0`1lO7`308V9R@@0MgMg0`1_Kfl308F5Q@<0GEeM1025QHD307YjNP<0
R8R8101eMGD:07moO`<0PX:23`38h=P307alO0@0Q8B40`1nOWh30820P0@0O7al0`24Q8@308:2PP@0
P8200`1lO7`307inOP<0Ogmo101nOWh30820P0<0Ogmo1020P80307inOPd0P8200`1nOWh407emO@<0
Ogmo0`1jNWX407inOP<0NWYj0`20P80407inOPH0P8201`1oOgl40<SPf0L0QHF50`1fMWH307emO@@0
OWin0`25QHD307YjNP<0Q8B41023Ph<307moO`<0SXj>102=SHd308:2PP<0PH611024Q8@307inOP<0
Ph>3101oOgl308:2PP<0MGEe0`1jNWX40861P@<0J6QX0`23Ph<4079bLP<0MgMg0`22PX8407alO0<0
OWin0`26QXH407alO0<0Q8B45038h=P001<0b>3H0`0Y:BT402XZ:P<0<30`0`0f=SH402h^;P<0<c<c
0`0X:2P402HV9P<0N7Qh0`27QhL30:n_[`@0/k>c0`32`/830<?3``@0OGem0`1kNg/307inOPL0RXZ:
0`1`L70406IVIP<0P8200`2:RXX30:b/[0@0^[Zj0`2f][H309ZJVP@0QHF50`21PH4307MgM`@0P820
0`27QhL40<SPf0<0OGem101iNGT308b<S0<0P8201024Q8@308J6QPL0P8200`1eMGD308F5Q@<0N7Qh
101iNGT307emO@<0QXJ6101_Kfl308V9R@<0P820101mOGd307alO0<0RHV9101gMgL306m_K`<0QHF5
0`1MGEd408F5Q@<0NWYj0`28R8P407EeM@X0Ogmo0`22PX8?0<SPf0<0O7al1024Q8@307inOP<0P820
101lO7`308B4Q0<0PX:21020P80307alO0<0OWin0`1oOgl407inOP<0P8200`1oOgl40820P0<0OWin
3@20P80307inOP@0OGem0`1oOgl307YjNP@0OWin0`1jNWX30820P0@0OWin1P20P80707moO`@0b>3H
1`25QHD307IfMP<0OGem101nOWh308F5Q@<0NWYj0`24Q8@408>3P`<0Ogmo0`2>SXh408f=S@<0PX:2
0`21PH4408B4Q0<0OWin0`23Ph<407moO`<0PX:20`1eMGD307YjNP@0PH610`1XJ6P308>3P`@0LW9b
0`1gMgL308:2PP@0O7al0`1nOWh308J6QP@0O7al0`24Q8@D0<SPf0004`38h=P302TY:@@0:RXZ0`0`
<30303Hf=P@0;Rh^0`0c<c<302PX:0@09RHV0`1hN7P308N7Q`<0[jn_102c/k<30<;2`P<0`l?3101m
OGd307]kN`<0OWin1`2:RXX3071`L0@0IVIV0`20P80308Z:RP<0[:b/102j^[X30;Jf]P<0VYZJ1025
QHD30861P@<0MgMg1020P80308N7Q`@0b>3H0`1mOGd407UiN@<0S8b<0`20P80408B4Q0<0QXJ61`20
P80307EeM@<0QHF50`1hN7P407UiN@<0OGem0`26QXH406m_K`<0RHV90`20P80407emO@<0O7al0`29
RHT407MgM`<0Kfm_0`25QHD305eMG@@0QHF50`1jNWX308R8R0@0MGEe2P1oOgl308:2PPl0b>3H0`1l
O7`408B4Q0<0OWin0`20P80407alO0<0Q8B40`22PX840820P0<0O7al0`1nOWh307moO`@0OWin0`20
P80307moO`@0P8200`1nOWh=0820P0<0OWin101mOGd307moO`<0NWYj101nOWh307YjNP<0P820101n
OWh60820P0L0Ogmo1038h=P708F5Q@<0MWIf0`1mOGd407inOP<0QHF50`1jNWX308B4Q0@0Ph>30`1o
Ogl308j>SP@0SHf=0`22PX830861P@@0Q8B40`1nOWh308>3P`@0Ogmo0`22PX8307EeM@<0NWYj1021
PH4306QXJ0<0Ph>3101bLW8307MgM`<0PX:2101lO7`307inOP<0QXJ6101lO7`308B4Q1@0b>3H000C
0<SPf0<0:BTY100Z:RX3030`<0<0=SHf100^;Rh303<c<`<0:2PX100V9RH307QhN0<0QhN70`2_[jl4
0;>c/`<0`/;20`33`l<407emO@<0Ng]k0`1nOWh708Z:RP<0L71`101VIVH30820P0<0RXZ:0`2/[:`4
0;Zj^P<0][Jf0`2JVYX408F5Q@<0PH610`1gMgL40820P0<0QhN71038h=P307emO@@0NGUi0`2<S8`3
0820P0@0Q8B40`26QXH70820P0<0MGEe0`25QHD307QhN0@0NGUi0`1mOGd308J6QP@0Kfm_0`29RHT3
0820P0@0OGem0`1lO7`308V9R@@0MgMg0`1_Kfl308F5Q@<0GEeM1025QHD307YjNP<0R8R8101eMGD:
07moO`<0PX:23`38h=P307alO0@0Q8B40`1nOWh30820P0@0O7al0`24Q8@308:2PP@0P8200`1lO7`3
07inOP<0Ogmo101nOWh30820P0<0Ogmo1020P80307inOPd0P8200`1nOWh407emO@<0Ogmo0`1jNWX4
07inOP<0NWYj0`20P80407inOPH0P8201`1oOgl40<SPf0L0QHF50`1fMWH307emO@@0OWin0`25QHD3
07YjNP<0Q8B41023Ph<307moO`<0SXj>102=SHd308:2PP<0PH611024Q8@307inOP<0Ph>3101oOgl3
08:2PP<0MGEe0`1jNWX40861P@<0J6QX0`23Ph<4079bLP<0MgMg0`22PX8407alO0<0OWin0`26QXH4
07alO0<0Q8B45038h=P001<0b>3H0`0d=3@402TY:@<0D51@0`0];Bd402`/;0<0<S8b0`0Y:BT402PX
:0<0@4100`1ZJVX309NGU`@0X:2P0`2e]KD30<?3``@0aLG50`23Ph<307IfMP@0MgMg0`1TI6@303Hf
=P@0KFe]0`1LG5`304];B`<0NGUi103<c<`30<O7a`<0UiNG101]KFd3075aL@<0MWIf101mOGd308^;
R`@0b>3H1`21PH4307IfMP<0PH611020P80307alO0<0OWin1026QXH308^;R`<0P8200`1hN7P408R8
R0<0TI6A0`1mOGd408R8R0<0Lg=c0`26QXH40861P@<0R8R80`1jNWX407IfMP<0RHV90`1ADE4309NG
U`@0Ng]k0`22PX8307EeM@@0RXZ:0`23Ph<308B4Q0@0Ph>30`21PH4?0<SPf0<0Ph>31`21PH4307in
OP@0P8200`1mOGd30820P0@0OWin0`1mOGd30861P@<0OWin1023Ph<30820P0<0Ogmo101nOWh30820
P0<0Ogmo101nOWh30820P0<0O7al0`1oOgl408:2PP<0NWYj1`1oOgl30861P@<0OWin3P20P80307in
OP@0b>3H0`20P80407emO@<0MGEe0`23Ph<407alO0<0Ogmo0`26QXH30861P@@0RXZ:0`2FUYH30820
P0@0SXj>0`2;Rh/30861P@@0OWin0`21PH4308B4Q0@0P8200`1kNg/307emO@<0Ng]k1029RHT307em
O@<0VYZJ101nOWh307alO0<0OWin1020P80308>3P`<0OWin1020P80307inOQ@0b>3H000C0<SPf0<0
=3@d100Y:BT3051@D0<0;Bd]100/;2`3038b<P<0:BTY100X:2P30410@0<0JVYZ0`2GUiL40:2PX0<0
]KFe0`33`l<40<G5a@<0Ph>30`1fMWH407MgM`<0I6AT0`0f=SH406e]K@<0G5aL0`1;Bd/307UiN@@0
c<c<0`37alL309NGU`@0KFe]0`1aLG4307IfMP@0OGem0`2;Rh/40<SPf0L0PH610`1fMWH30861P@@0
P8200`1lO7`307inOP@0QXJ60`2;Rh/30820P0<0N7Qh1028R8P3096AT@<0OGem1028R8P307=cL`<0
QXJ61021PH4308R8R0<0NWYj101fMWH308V9R@<0DE5A0`2GUiL407]kN`<0PX:20`1eMGD408Z:RP<0
Ph>30`24Q8@408>3P`<0PH613`38h=P308>3P`L0PH610`1nOWh40820P0<0OGem0`20P80407inOP<0
OGem0`21PH4307inOP@0Ph>30`20P80307moO`@0OWin0`20P80307moO`@0OWin0`20P80307alO0<0
Ogmo1022PX8307YjNPL0Ogmo0`21PH4307inOPh0P8200`1nOWh40<SPf0<0P820101mOGd307EeM@<0
Ph>3101lO7`307moO`<0QXJ60`21PH4408Z:RP<0UYJF0`20P80408j>SP<0Rh^;0`21PH4407inOP<0
PH610`24Q8@40820P0<0Ng]k0`1mOGd307]kN`@0RHV90`1mOGd309ZJVP@0OWin0`1lO7`307inOP@0
P8200`23Ph<307inOP@0P8200`1nOWhD0<SPf0004`38h=P303@d=0@0:BTY0`1@D50302d];@@0;2`/
0`0b<S8302TY:@@0:2PX0`10@40306YZJP<0UiNG102PX:030;Fe]@<0`l?31035aLD308>3P`<0MWIf
101gMgL306ATI0<0=SHf101]KFd305aLG0<0Bd];0`1iNGT40<c<c0<0alO70`2GUiL406e]K@<0LG5a
0`1fMWH407emO@<0Rh^;1038h=P70861P@<0MWIf0`21PH440820P0<0O7al0`1nOWh408J6QP<0Rh^;
0`20P80307QhN0@0R8R80`2ATI4307emO@@0R8R80`1cLg<308J6QP@0PH610`28R8P307YjNP@0MWIf
0`29RHT3055AD@<0UiNG101kNg/308:2PP<0MGEe102:RXX308>3P`<0Q8B41023Ph<30861P@l0b>3H
0`23Ph<70861P@<0OWin1020P80307emO@<0P820101nOWh307emO@<0PH610`1nOWh408>3P`<0P820
0`1oOgl407inOP<0P8200`1oOgl407inOP<0P8200`1lO7`307moO`@0PX:20`1jNWX707moO`<0PH61
0`1nOWh>0820P0<0OWin1038h=P30820P0@0OGem0`1eMGD308>3P`@0O7al0`1oOgl308J6QP<0PH61
102:RXX309JFUP<0P820102>SXh308^;R`<0PH61101nOWh30861P@<0Q8B41020P80307]kN`<0OGem
0`1kNg/408V9R@<0OGem0`2JVYX407inOP<0O7al0`1nOWh40820P0<0Ph>30`1nOWh40820P0<0OWin
5038h=P001<0b>3H0`0^;Rh403De=@<0EEEE0`0Y:BT402d];@<0<30`0`0/;2`403Ph>0<0;Bd]0`1Z
JVX30820P0@0];Bd0`2/[:`30;^k^`L0aLG50`1`L70405EEE@<0=cLg0`0d=3@405IFEP<0B4Q80`12
@T8304U9B@@0/k>c0`32`/8306MWI`@0HF5Q0`1[Jf/307EeM@@0Ph>30`2=SHd40<SPf0<0R8R81`25
QHD307inOP@0N7Qh0`2GUiL308b<S0@0Hf=S0`2ATI4308>3P`<0QhN7101oOgl308F5Q@<0Ph>31020
P80308>3P`<0Ng]k101nOWh307IfMP<0Q8B41022PX8308R8R0<0Q8B40`1`L70406QXJ0<0Jf][0`2=
SHd408>3P`<0PX:20`20P80407moO`<0OWin3`38h=P307inOP@0PH610`20P80308:2PPL0PH611`1m
OGd308B4Q0<0O7al0`20P80707inOP<0P8201021PH4307inOP<0P820101nOWh30861P@H0Ogmo101m
OGd308:2PP<0QHF51021PH4307emO@<0OWin101oOgl30820P0<0OWin1023Ph<307moO`@0b>3H0`1l
O7`407emO@<0O7al0`21PH4407alO0<0OWin0`2DU9@308J6QP@0RHV90`21PH4307emO@@0Q8B40`20
P80307moO`L0O7al0`24Q8@407QhN0<0QHF50`22PX8307IfMP@0O7al0`2:RXX308n?S`@0SXj>0`1l
O7`307EeM@@0Kfm_1P1nOWh407emO@<0OWin5038h=P001<0b>3H0`0^;Rh403De=@<0EEEE0`0Y:BT4
02d];@<0<30`0`0/;2`403Ph>0<0;Bd]0`1ZJVX30820P0@0];Bd0`2/[:`30;^k^`L0aLG50`1`L704
05EEE@<0=cLg0`0d=3@405IFEP<0B4Q80`12@T8304U9B@@0/k>c0`32`/8306MWI`@0HF5Q0`1[Jf/3
07EeM@@0Ph>30`2=SHd40<SPf0<0R8R81`25QHD307inOP@0N7Qh0`2GUiL308b<S0@0Hf=S0`2ATI43
08>3P`<0QhN7101oOgl308F5Q@<0Ph>31020P80308>3P`<0Ng]k101nOWh307IfMP<0Q8B41022PX83
08R8R0<0Q8B40`1`L70406QXJ0<0Jf][0`2=SHd408>3P`<0PX:20`20P80407moO`<0OWin3`38h=P3
07inOP@0PH610`20P80308:2PPL0PH611`1mOGd308B4Q0<0O7al0`20P80707inOP<0P8201021PH43
07inOP<0P820101nOWh30861P@H0Ogmo101mOGd308:2PP<0QHF51021PH4307emO@<0OWin101oOgl3
0820P0<0OWin1023Ph<307moO`@0b>3H0`1lO7`407emO@<0O7al0`21PH4407alO0<0OWin0`2DU9@3
08J6QP@0RHV90`21PH4307emO@@0Q8B40`20P80307moO`L0O7al0`24Q8@407QhN0<0QHF50`22PX83
07IfMP@0O7al0`2:RXX308n?S`@0SXj>0`1lO7`307EeM@@0Kfm_1P1nOWh407emO@<0OWin5038h=P0
01<0b>3H0`0^;Rh403De=@<0EEEE0`0Y:BT402d];@<0<30`0`0/;2`403Ph>0<0;Bd]0`1ZJVX30820
P0@0];Bd0`2/[:`30;^k^`L0aLG50`1`L70405EEE@<0=cLg0`0d=3@405IFEP<0B4Q80`12@T8304U9
B@@0/k>c0`32`/8306MWI`@0HF5Q0`1[Jf/307EeM@@0Ph>30`2=SHd40<SPf0<0R8R81`25QHD307in
OP@0N7Qh0`2GUiL308b<S0@0Hf=S0`2ATI4308>3P`<0QhN7101oOgl308F5Q@<0Ph>31020P80308>3
P`<0Ng]k101nOWh307IfMP<0Q8B41022PX8308R8R0<0Q8B40`1`L70406QXJ0<0Jf][0`2=SHd408>3
P`<0PX:20`20P80407moO`<0OWin3`38h=P307inOP@0PH610`20P80308:2PPL0PH611`1mOGd308B4
Q0<0O7al0`20P80707inOP<0P8201021PH4307inOP<0P820101nOWh30861P@H0Ogmo101mOGd308:2
PP<0QHF51021PH4307emO@<0OWin101oOgl30820P0<0OWin1023Ph<307moO`@0b>3H0`1lO7`407em
O@<0O7al0`21PH4407alO0<0OWin0`2DU9@308J6QP@0RHV90`21PH4307emO@@0Q8B40`20P80307mo
O`L0O7al0`24Q8@407QhN0<0QHF50`22PX8307IfMP@0O7al0`2:RXX308n?S`@0SXj>0`1lO7`307Ee
M@@0Kfm_1P1nOWh407emO@<0OWin5038h=P001<0b>3H0`0i>CT404e=C@<0?3`l0`0/;2`402LW9`<0
G5aL0`1?Cdl4038b<P<0:2PX0`0_;bl30861P@@0VYZJ0`2][Jd30;:b/P@0aLG50`2n_[h30;^k^`@0
GEeM0`13@d<3034a<@@0=3@d0`0c<c<3030`<0<0?clo102?Shl305UIF@<0:RXZ100k>c/307moO`<0
OGem1028R8P309:BTP@0b>3H0`1fMWH408F5Q@<0PH610`22PX8408b<S0<0HF5Q0`2HV9P408>3P`<0
N7Qh0`25QHD307MgM`@0QHF50`1lO7`307inOP@0PX:21P21PH4407UiN@<0Rh^;0`23Ph<707]kN`<0
O7al0`25QHD409BDU0<0Q8B40`21PH4407inOP<0Ng]k0`23Ph<407moO`<0PH613`38h=P308>3P`@0
PH610`1mOGd30861P@@0Ph>30`1kNg/307moO`@0PH611P1nOWh307moO`L0P8200`1nOWh407moO`<0
P8200`1oOgl40861P@<0OGem0`20P80307moO`@0P8200`1oOgl307QhN0@0O7al0`1oOgl70861P@<0
Ogmo2P1nOWh40<SPf0<0QhN71024Q8@608>3P`@0Ogmo0`2:RXX307inOP<0P820101lO7`308B4Q0<0
P8201025QHD308>3P`<0PX:21020P80307alO0<0NWYj101oOgl307YjNP<0Ogmo0`20P80407UiN@<0
PX:20`21PH4708V9R@<0MgMg102>SXh307alO0<0PH611020P80307emOA@0b>3H000C0<SPf0<0>CTi
101=CDd303`l?0<0;2`/100W9bL305aLG0<0Cdm?100b<S8302PX:0<0;bl_0`21PH4409ZJVP<0[Jf]
0`2b/[840<G5a@<0_[jn0`2k^k/405eMG@<0@d=30`0a<C4403@d=0<0<c<c0`0`<30303lo?`@0Shn?
0`1IFET302XZ:P@0>c/k0`1oOgl307emO@@0R8R80`2BTY840<SPf0<0MWIf1025QHD30861P@<0PX:2
102<S8`3065QH@<0V9RH1023Ph<307QhN0<0QHF50`1gMgL408F5Q@<0O7al0`1nOWh408:2PPH0PH61
101iNGT308^;R`<0Ph>31`1kNg/307alO0<0QHF5102DU9@308B4Q0<0PH61101nOWh307]kN`<0Ph>3
101oOgl30861P@l0b>3H0`23Ph<40861P@<0OGem0`21PH4408>3P`<0Ng]k0`1oOgl40861P@H0OWin
0`1oOgl70820P0<0OWin101oOgl30820P0<0Ogmo1021PH4307emO@<0P8200`1oOgl40820P0<0Ogmo
0`1hN7P407alO0<0Ogmo1`21PH4307moO`X0OWin1038h=P308N7Q`@0Q8B41P23Ph<407moO`<0RXZ:
0`1nOWh30820P0@0O7al0`24Q8@30820P0@0QHF50`23Ph<308:2PP@0P8200`1lO7`307YjNP@0Ogmo
0`1jNWX307moO`<0P820101iNGT308:2PP<0PH611`29RHT307MgM`@0SXj>0`1lO7`30861P@@0P820
0`1mOGdD0<SPf0004`38h=P303Ti>@@0CDe=0`0l?3`302`/;0@09bLW0`1LG5`304m?C`@0<S8b0`0X
:2P302l_;`<0PH61102JVYX30:f][@<0/[:b1035aLD30;jn_P<0^k^k101MGEd304=3@`<0<C4a100d
=3@303<c<`<0<30`0`0o?cl408n?S`<0FEUI0`0Z:RX403/k>`<0Ogmo0`1mOGd408R8R0<0TY:B1038
h=P307IfMP@0QHF50`21PH4308:2PP@0S8b<0`1QHF4309RHV0@0Ph>30`1hN7P308F5Q@<0MgMg1025
QHD307alO0<0OWin1022PX860861P@@0NGUi0`2;Rh/308>3P`L0Ng]k0`1lO7`308F5Q@@0U9BD0`24
Q8@30861P@@0OWin0`1kNg/308>3P`@0Ogmo0`21PH4?0<SPf0<0Ph>31021PH4307emO@<0PH611023
Ph<307]kN`<0Ogmo1021PH4607inOP<0Ogmo1`20P80307inOP@0Ogmo0`20P80307moO`@0PH610`1m
OGd30820P0<0Ogmo1020P80307moO`<0N7Qh101lO7`307moO`L0PH610`1oOgl:07inOP@0b>3H0`27
QhL408B4Q0H0Ph>3101oOgl308Z:RP<0OWin0`20P80407alO0<0Q8B40`20P80408F5Q@<0Ph>30`22
PX840820P0<0O7al0`1jNWX407moO`<0NWYj0`1oOgl30820P0@0NGUi0`22PX830861P@L0RHV90`1g
MgL408j>SP<0O7al0`21PH440820P0<0OGem5038h=P001<0b>3H0`0f=SH403lo?`<0=3@d0`0V9RH7
04i>CP<0:2PX100_;bl302XZ:P<092@T0`1KFe/407moO`<0[jn_0`2ZZZX40<30`0<0aLG50`2c/k<4
0;Vi^@<0G5aL0`1=CDd40492@P<0>c/k0`0e=CD3038b<P@0=SHf0`0/;2`303hn?P@0MGEe0`20P803
07inOP@0Rh^;0`2IVIT40<SPf0<0QHF5101lO7`307YjNP<0P820101mOGd308Z:RP<0N7Qh101mOGd3
08N7Q`<0NWYj0`27QhL407inOP<0OGem0`25QHD407inOP<0OGem0`1oOgl40861P@<0M7Ad0`2:RXX4
071`L0H0RXZ:0`29RHT408:2PP<0TY:B0`1YJFT408j>SP<0N7Qh0`1nOWh408F5Q@<0Ogmo3`38h=P3
08:2PP@0Ogmo1P21PH4408:2PP<0Q8B40`1mOGd40861P@T0P8203P1oOgl307inOP<0PH61101nOWh3
08:2PP<0P8200`23Ph<407emO@<0P8200`23Ph<40820P0H0OWin101mOGd30820P0<0PH61101oOgl3
0820P0@0b>3H0`26QXH407alO0<0R8R80`1jNWX408B4Q0<0PH610`1iNGT308R8R0@0M7Ad0`1oOgl3
08>3P`@0Q8B40`1nOWh307moO`@0Q8B40`1oOgl308>3P`@0NWYj0`27QhL307QhN0L0OGem0`2:RXX3
0820P0@0TY:B0`26QXH307moO`@0OWin0`23Ph<307emO@@0P8200`1oOglD0<SPf0004`38h=P303Hf
=P@0?clo0`0d=3@302HV9PL0CTi>0`0X:2P402l_;`<0:RXZ0`0T92@305]KF`@0Ogmo0`2_[jl30:ZZ
ZP@0`<300`35aLD30;>c/`@0^KVi0`1LG5`304e=C@@0@T920`0k>c/303De=@<0<S8b100f=SH302`/
;0<0?Shn101eMGD30820P0<0OWin102;Rh/309VIV@@0b>3H0`25QHD407alO0<0NWYj0`20P80407em
O@<0RXZ:0`1hN7P407emO@<0QhN70`1jNWX308N7Q`@0OWin0`1mOGd308F5Q@@0OWin0`1mOGd307mo
O`@0PH610`1dM7@308Z:RP@0L71`1P2:RXX308V9R@@0PX:20`2BTY8306UYJ@@0SXj>0`1hN7P307in
OP@0QHF50`1oOgl?0<SPf0<0PX:2101oOgl60861P@@0PX:20`24Q8@307emO@@0PH612@20P80>07mo
O`<0OWin0`21PH4407inOP<0PX:20`20P80308>3P`@0OGem0`20P80308>3P`@0P8201P1nOWh407em
O@<0P8200`21PH4407moO`<0P8201038h=P308J6QP@0O7al0`28R8P307YjNP@0Q8B40`21PH4307Ui
N@<0R8R8101dM7@307moO`<0Ph>31024Q8@307inOP<0Ogmo1024Q8@307moO`<0Ph>3101jNWX308N7
Q`<0N7Qh1`1mOGd308Z:RP<0P820102BTY8308J6QP<0Ogmo101nOWh308>3P`<0OGem1020P80307mo
Oa@0b>3H000C0<SPf0<0=SHf100o?cl303@d=0<09RHV1`1>CTh302PX:0@0;bl_0`0Z:RX302@T90<0
Fe]K101oOgl30:n_[`<0ZZZZ1030`<030<G5a@<0/k>c102i^KT305aLG0<0CDe=1012@T8303/k>`<0
=CDe0`0b<S8403Hf=P<0;2`/0`0n?Sh407EeM@<0P8200`1nOWh408^;R`<0VIVI1038h=P308F5Q@@0
O7al0`1jNWX30820P0@0OGem0`2:RXX307QhN0@0OGem0`27QhL307YjNP<0QhN7101nOWh307emO@<0
QHF5101nOWh307emO@<0Ogmo1021PH4307AdM0<0RXZ:101`L70608Z:RP<0RHV91022PX8309:BTP<0
JFUY102>SXh307QhN0<0OWin1025QHD307moO`l0b>3H0`22PX8407moO`H0PH611022PX8308B4Q0<0
OGem1021PH490820P0h0Ogmo0`1nOWh30861P@@0OWin0`22PX830820P0<0Ph>3101mOGd30820P0<0
Ph>31020P80607inOP@0OGem0`20P8030861P@@0Ogmo0`20P8040<SPf0<0QXJ6101lO7`308R8R0<0
NWYj1024Q8@30861P@<0NGUi0`28R8P407AdM0<0Ogmo0`23Ph<408B4Q0<0OWin0`1oOgl408B4Q0<0
Ogmo0`23Ph<407YjNP<0QhN70`1hN7P707emO@<0RXZ:0`20P80409:BTP<0QXJ60`1oOgl407inOP<0
Ph>30`1mOGd40820P0<0Ogmo5038h=P001<0b>3H0`0W9bL403dm?@<0<S8b0`0_;bl405aLG0<092@T
0`0_;bl402TY:@<0?3`l0`0o?cl3028R8P@0OGem0`26QXH30;6a/@@0[jn_0`34a<@30;6a/@@0YZJV
0`30`<0307UiN@L0LG5a0`1gMgL305IFEP@0S8b<0`1YJFT306m_K`@0J6QX0`1RHV8306m_K`@0VIVI
0`2QXJ440<SPf0<0Ogmo1020P80308:2PP<0OGem101kNg/307moO`<0OGem1027QhL3069RHP<0QHF5
1`1mOGd307moO`<0MWIf1024Q8@60820P0@0PX:20`26QXH306a/K0@0SXj>0`1fMWH308>3P`<0MWIf
101iNGT306YZJP<0MgMg101kNg/309:BTP<0T92@101kNg/307inOPl0b>3H0`22PX8407emO@<0OWin
0`1lO7`40820P0H0OWin1024Q8@30820P0<0PX:20`21PH4408>3P`<0PX:20`1nOWh40820P0<0Ogmo
0`1nOWh407moO`<0OWin0`1mOGd30861P@@0P8201P1nOWh707]kN`<0OWin1021PH4307moO`<0PH61
1`20P8040<SPf0<0P820102HV9P308>3P`<0X:2P101dM7@308J6QP<0PH610`1fMWH408^;R`<0PX:2
0`23Ph<407YjNP<0PX:20`20P80408>3P`<0PH610`1nOWh40861P@<0OWin0`24Q8@307EeM@@0PX:2
0`1kNg/307UiN@@0OGem0`24Q8@308f=S@@0Q8B40`1]KFd:07emOA@0b>3H000C0<SPf0<09bLW100m
?Cd3038b<P<0;bl_101LG5`302@T90<0;bl_100Y:BT303`l?0<0?clo0`0R8R8407emO@<0QXJ60`2a
/K440:n_[`<0a<C40`2a/K440:JVYP<0`<300`1iNGT7075aL@<0MgMg0`1FEUH408b<S0<0JFUY0`1_
Kfl406QXJ0<0HV9R0`1_Kfl409VIV@<0XJ6Q1038h=P307moO`@0P8200`22PX8307emO@@0Ng]k0`1o
Ogl307emO@@0QhN70`1RHV8308F5Q@L0OGem0`1oOgl307IfMP@0Q8B41P20P80408:2PP<0QXJ60`1/
K6`408j>SP<0MWIf0`23Ph<307IfMP@0NGUi0`1ZJVX307MgM`@0Ng]k0`2BTY83092@T0@0Ng]k0`1n
OWh?0<SPf0<0PX:2101mOGd307inOP<0O7al1020P80607inOP@0Q8B40`20P80308:2PP<0PH611023
Ph<308:2PP<0OWin1020P80307moO`<0OWin101oOgl307inOP<0OGem0`21PH440820P0H0OWin1`1k
Ng/307inOP@0PH610`1oOgl30861P@L0P8201038h=P30820P0@0V9RH0`23Ph<30:2PX0@0M7Ad0`26
QXH30861P@<0MWIf102;Rh/308:2PP<0Ph>3101jNWX308:2PP<0P8201023Ph<30861P@<0OWin1021
PH4307inOP<0Q8B40`1eMGD408:2PP<0Ng]k0`1iNGT407emO@<0Q8B40`2=SHd408B4Q0<0KFe]2P1m
OGdD0<SPf0004`38h=P302LW9`@0?Cdm0`0b<S8302l_;`@0G5aL0`0T92@302l_;`@0:BTY0`0l?3`3
03lo?`<08R8R101mOGd308J6QP<0/K6a102_[jl30<C4a0<0/K6a102VYZH30<30`0<0NGUi1`1aLG43
07MgM`<0EUIF102<S8`306UYJ@<0Kfm_101XJ6P3069RHP<0Kfm_102IVIT30:6QX@@0b>3H0`1oOgl4
0820P0<0PX:20`1mOGd407]kN`<0Ogmo0`1mOGd408N7Q`<0HV9R0`25QHD707emO@<0Ogmo0`1fMWH4
08B4Q0H0P8201022PX8308J6QP<0K6a/102>SXh307IfMP<0Ph>30`1fMWH407UiN@<0JVYZ0`1gMgL4
07]kN`<0TY:B0`2@T90407]kN`<0OWin3`38h=P308:2PP@0OGem0`1nOWh307alO0@0P8201P1nOWh4
08B4Q0<0P8200`22PX830861P@@0Ph>30`22PX8307inOP@0P8200`1oOgl307inOP@0Ogmo0`1nOWh3
07emO@<0PH611020P80607inOPL0Ng]k0`1nOWh40861P@<0Ogmo0`21PH470820P0@0b>3H0`20P804
09RHV0<0Ph>30`2PX:0407AdM0<0QXJ60`21PH4307IfMP@0Rh^;0`22PX8308>3P`@0NWYj0`22PX83
0820P0@0Ph>30`21PH4307inOP@0PH610`1nOWh308B4Q0<0MGEe1022PX8307]kN`<0NGUi101mOGd3
08B4Q0<0SHf=1024Q8@306e]K@X0OGem5038h=P001<0b>3H0`0W9bL403dm?@<0<S8b0`0_;bl405aL
G0<092@T0`0_;bl402TY:@<0?3`l0`0o?cl3028R8P@0OGem0`26QXH30;6a/@@0[jn_0`34a<@30;6a
/@@0YZJV0`30`<0307UiN@L0LG5a0`1gMgL305IFEP@0S8b<0`1YJFT306m_K`@0J6QX0`1RHV8306m_
K`@0VIVI0`2QXJ440<SPf0<0Ogmo1020P80308:2PP<0OGem101kNg/307moO`<0OGem1027QhL3069R
HP<0QHF51`1mOGd307moO`<0MWIf1024Q8@60820P0@0PX:20`26QXH306a/K0@0SXj>0`1fMWH308>3
P`<0MWIf101iNGT306YZJP<0MgMg101kNg/309:BTP<0T92@101kNg/307inOPl0b>3H0`22PX8407em
O@<0OWin0`1lO7`40820P0H0OWin1024Q8@30820P0<0PX:20`21PH4408>3P`<0PX:20`1nOWh40820
P0<0Ogmo0`1nOWh407moO`<0OWin0`1mOGd30861P@@0P8201P1nOWh707]kN`<0OWin1021PH4307mo
O`<0PH611`20P8040<SPf0<0P820102HV9P308>3P`<0X:2P101dM7@308J6QP<0PH610`1fMWH408^;
R`<0PX:20`23Ph<407YjNP<0PX:20`20P80408>3P`<0PH610`1nOWh40861P@<0OWin0`24Q8@307Ee
M@@0PX:20`1kNg/307UiN@@0OGem0`24Q8@308f=S@@0Q8B40`1]KFd:07emOA@0b>3H000C0<SPf0<0
9BDU100g=cL30451@@L0?clo0`0^;Rh302LW9`@0?clo0`1EEED30451@@<0=3@d100m?Cd308R8R0<0
T92@102/[:`30;Ng]`<0_Kfm102JVYX30;6a/@<0`/;2102CTi<308B4Q0<0VIVI0`2EUID408n?S`<0
K6a/0`1=CDd404U9B@<0HV9R0`2HV9P70:^[Z`@0b>3H0`1mOGd408b<S0<0M7Ad0`1nOWh407alO0<0
OWin0`20P80406EUI@<0S8b<0`1oOgl308>3P`@0QHF50`1dM7@309:BTP@0N7Qh0`22PX8307emO@L0
OWin0`2;Rh/406e]K@<0VYZJ0`1QHF4307YjNP@0RHV90`2HV9P309ZJVP@0Q8B40`1XJ6P307]kN`L0
OGem3`38h=P30861P@@0O7al0`1iNGT307]kN`@0OWin0`22PX830820P0@0OWin0`26QXH307emO@<0
Ogmo101mOGd307inOP<0P820101nOWh607moO`@0P8200`1nOWh307moO`<0OGem1021PH4307alO0<0
P820101nOWh30861P@<0Ogmo1`1nOWh70820P0<0Ogmo1038h=P307moO`@0OWin0`1cLg<308f=S@@0
Ng]k0`20P80308R8R0<0S8b<1026QXH307]kN`<0NGUi1025QHD307moO`<0P8201023Ph<307emO@d0
Ogmo0`22PX84079bLP<0SXj>1`1kNg/307alO0<0SHf=1029RHT307YjNP<0PH61101kNg/307inOQ@0
b>3H000C0<SPf0<09BDU100g=cL30451@@L0?clo0`0^;Rh302LW9`@0?clo0`1EEED30451@@<0=3@d
100m?Cd308R8R0<0T92@102/[:`30;Ng]`<0_Kfm102JVYX30;6a/@<0`/;2102CTi<308B4Q0<0VIVI
0`2EUID408n?S`<0K6a/0`1=CDd404U9B@<0HV9R0`2HV9P70:^[Z`@0b>3H0`1mOGd408b<S0<0M7Ad
0`1nOWh407alO0<0OWin0`20P80406EUI@<0S8b<0`1oOgl308>3P`@0QHF50`1dM7@309:BTP@0N7Qh
0`22PX8307emO@L0OWin0`2;Rh/406e]K@<0VYZJ0`1QHF4307YjNP@0RHV90`2HV9P309ZJVP@0Q8B4
0`1XJ6P307]kN`L0OGem3`38h=P30861P@@0O7al0`1iNGT307]kN`@0OWin0`22PX830820P0@0OWin
0`26QXH307emO@<0Ogmo101mOGd307inOP<0P820101nOWh607moO`@0P8200`1nOWh307moO`<0OGem
1021PH4307alO0<0P820101nOWh30861P@<0Ogmo1`1nOWh70820P0<0Ogmo1038h=P307moO`@0OWin
0`1cLg<308f=S@@0Ng]k0`20P80308R8R0<0S8b<1026QXH307]kN`<0NGUi1025QHD307moO`<0P820
1023Ph<307emO@d0Ogmo0`22PX84079bLP<0SXj>1`1kNg/307alO0<0SHf=1029RHT307YjNP<0PH61
101kNg/307inOQ@0b>3H000C0<SPf0<09BDU100g=cL30451@@L0?clo0`0^;Rh302LW9`@0?clo0`1E
EED30451@@<0=3@d100m?Cd308R8R0<0T92@102/[:`30;Ng]`<0_Kfm102JVYX30;6a/@<0`/;2102C
Ti<308B4Q0<0VIVI0`2EUID408n?S`<0K6a/0`1=CDd404U9B@<0HV9R0`2HV9P70:^[Z`@0b>3H0`1m
OGd408b<S0<0M7Ad0`1nOWh407alO0<0OWin0`20P80406EUI@<0S8b<0`1oOgl308>3P`@0QHF50`1d
M7@309:BTP@0N7Qh0`22PX8307emO@L0OWin0`2;Rh/406e]K@<0VYZJ0`1QHF4307YjNP@0RHV90`2H
V9P309ZJVP@0Q8B40`1XJ6P307]kN`L0OGem3`38h=P30861P@@0O7al0`1iNGT307]kN`@0OWin0`22
PX830820P0@0OWin0`26QXH307emO@<0Ogmo101mOGd307inOP<0P820101nOWh607moO`@0P8200`1n
OWh307moO`<0OGem1021PH4307alO0<0P820101nOWh30861P@<0Ogmo1`1nOWh70820P0<0Ogmo1038
h=P307moO`@0OWin0`1cLg<308f=S@@0Ng]k0`20P80308R8R0<0S8b<1026QXH307]kN`<0NGUi1025
QHD307moO`<0P8201023Ph<307emO@d0Ogmo0`22PX84079bLP<0SXj>1`1kNg/307alO0<0SHf=1029
RHT307YjNP<0PH61101kNg/307inOQ@0b>3H000C0<SPf0<0;Bd]100a<C4303Lg=`<0=3@d100^;Rh6
034a<@@0ADE50`0b<S8304i>CP<0?clo100W9bL306=SH`<0LG5a102SXj<30:ZZZP<0^[Zj102RXZ83
0:>SX`<0_;bl1032`/8309ZJVP<0HV9R0`1VIVH406MWI`<0IVIV0`1eMGD409FEU@<0[Jf]0`2d];@7
0;2`/0@0b>3H0`20P80407IfMP<0NWYj0`2BTY8708J6QP<0PX:21024Q8@30861P@<0PX:20`1oOgl4
06=SH`<0Shn?0`1]KFd40820P0<0OGem0`20P8040861P@<0PX:20`20P80408B4Q0<0JFUY0`2<S8`3
096AT@@0Ng]k0`1^KVh307IfMP@0O7al0`25QHD30861P@@0PX:20`20P80?0<SPf0<0P820101oOgl3
08B4Q0L0Ogmo0`21PH430820P0@0PH610`1mOGd308>3P`<0OWin1024Q8@:07moO`<0PH611`20P803
0861P@<0Ogmo0`22PX840820P0<0QHF51`20P80307emO@<0O7al101oOgl30820P0X0Ogmo1038h=P3
08N7Q`@0MGEe0`2ATI4307UiN@@0NWYj0`1oOgl307emO@<0QhN7101lO7`307QhN0<0NWYj1020P803
08B4Q0<0PH61101nOWh308:2PP<0QHF5101nOWh308:2PP<0OWin0`20P80407MgM`<0UiNG0`1`L704
0820P0<0NWYj0`23Ph<407emO@<0PX:21`1nOWh30820P1@0b>3H000C0<SPf0<0;Bd]100a<C4303Lg
=`<0=3@d100^;Rh6034a<@@0ADE50`0b<S8304i>CP<0?clo100W9bL306=SH`<0LG5a102SXj<30:ZZ
ZP<0^[Zj102RXZ830:>SX`<0_;bl1032`/8309ZJVP<0HV9R0`1VIVH406MWI`<0IVIV0`1eMGD409FE
U@<0[Jf]0`2d];@70;2`/0@0b>3H0`20P80407IfMP<0NWYj0`2BTY8708J6QP<0PX:21024Q8@30861
P@<0PX:20`1oOgl406=SH`<0Shn?0`1]KFd40820P0<0OGem0`20P8040861P@<0PX:20`20P80408B4
Q0<0JFUY0`2<S8`3096AT@@0Ng]k0`1^KVh307IfMP@0O7al0`25QHD30861P@@0PX:20`20P80?0<SP
f0<0P820101oOgl308B4Q0L0Ogmo0`21PH430820P0@0PH610`1mOGd308>3P`<0OWin1024Q8@:07mo
O`<0PH611`20P8030861P@<0Ogmo0`22PX840820P0<0QHF51`20P80307emO@<0O7al101oOgl30820
P0X0Ogmo1038h=P308N7Q`@0MGEe0`2ATI4307UiN@@0NWYj0`1oOgl307emO@<0QhN7101lO7`307Qh
N0<0NWYj1020P80308B4Q0<0PH61101nOWh308:2PP<0QHF5101nOWh308:2PP<0OWin0`20P80407Mg
M`<0UiNG0`1`L7040820P0<0NWYj0`23Ph<407emO@<0PX:21`1nOWh30820P1@0b>3H000C0<SPf0<0
;Bd]100a<C4303Lg=`<0=3@d100^;Rh6034a<@@0ADE50`0b<S8304i>CP<0?clo100W9bL306=SH`<0
LG5a102SXj<30:ZZZP<0^[Zj102RXZ830:>SX`<0_;bl1032`/8309ZJVP<0HV9R0`1VIVH406MWI`<0
IVIV0`1eMGD409FEU@<0[Jf]0`2d];@70;2`/0@0b>3H0`20P80407IfMP<0NWYj0`2BTY8708J6QP<0
PX:21024Q8@30861P@<0PX:20`1oOgl406=SH`<0Shn?0`1]KFd40820P0<0OGem0`20P8040861P@<0
PX:20`20P80408B4Q0<0JFUY0`2<S8`3096AT@@0Ng]k0`1^KVh307IfMP@0O7al0`25QHD30861P@@0
PX:20`20P80?0<SPf0<0P820101oOgl308B4Q0L0Ogmo0`21PH430820P0@0PH610`1mOGd308>3P`<0
OWin1024Q8@:07moO`<0PH611`20P8030861P@<0Ogmo0`22PX840820P0<0QHF51`20P80307emO@<0
O7al101oOgl30820P0X0Ogmo1038h=P308N7Q`@0MGEe0`2ATI4307UiN@@0NWYj0`1oOgl307emO@<0
QhN7101lO7`307QhN0<0NWYj1020P80308B4Q0<0PH61101nOWh308:2PP<0QHF5101nOWh308:2PP<0
OWin0`20P80407MgM`<0UiNG0`1`L7040820P0<0NWYj0`23Ph<407emO@<0PX:21`1nOWh30820P1@0
b>3H000C0<SPf0<09bLW100^;Rh304Q8B0<0EEEE100g=cL302/[:`<0<30`1013@d<302/[:`<0De=C
0`0i>CT403lo?`<0:2PX0`1kNg/406IVIP<0[Jf]0`2UYJD40:NWY`<0XJ6Q0`2l_;`40;Vi^@<0]kNg
0`2WYjL308J6QP@0UIFE0`2QXJ430:BTY0@0Z:RX0`2][Jd70;6a/@<0/[:b1038h=P308V9R@@0Ng]k
0`20P80307QhN0@0S8b<0`1oOgl308:2PP@0P8200`1mOGd307MgM`<0NWYj1028R8P307inOP<0Ph>3
102BTY8307inOP<0QXJ61`21PH4307inOP@0PX:20`1nOWh308>3P`<0LW9b101oOgl307inOP<0Ph>3
1`21PH430820P0@0PH610`24Q8@?0<SPf0<0OGem1020P80307UiN@<0Ogmo101kNg/308:2PP<0P820
101mOGd30861P@<0OGem0`1nOWh408>3P`<0OGem0`1oOgl408B4Q0<0Ogmo0`21PH4707moO`<0P820
0`1oOgl408>3P`<0O7al0`1mOGd407moO`<0P8200`1oOgl>0820P0<0Ogmo1038h=P308:2PP@0MgMg
0`21PH4307QhN0@0PX:20`20P80307inOP<0PH61101oOgl308Z:RP<0P8201029RHT307UiN@<0Ng]k
101aLG4307moO`<0OWin1020P80907inOP@0NWYj0`22PX8307MgM`@0Ng]k0`21PH4307emO@@0PH61
0`1nOWh307moO`@0PX:20`20P80D0<SPf0004`38h=P302LW9`@0;Rh^0`18B4P305EEE@@0=cLg0`0[
:b/3030`<0@0@d=30`0[:b/305=CD`<0>CTi100o?cl302PX:0<0Ng]k101VIVH30:f][@<0YJFU102W
YjL30:6QX@<0_;bl102i^KT30;Ng]`<0YjNW0`26QXH409FEU@<0XJ6Q0`2TY:@40:RXZ0<0[Jf]1`2a
/K430;:b/P@0b>3H0`29RHT407]kN`<0P8200`1hN7P408b<S0<0Ogmo0`22PX840820P0<0OGem0`1g
MgL307YjNP@0R8R80`1nOWh308>3P`@0TY:B0`1nOWh308J6QPL0PH610`1nOWh408:2PP<0OWin0`23
Ph<3079bLP@0Ogmo0`1nOWh308>3P`L0PH610`20P8040861P@<0Q8B43`38h=P307emO@@0P8200`1i
NGT307moO`@0Ng]k0`22PX830820P0@0OGem0`21PH4307emO@<0OWin1023Ph<307emO@<0Ogmo1024
Q8@307moO`<0PH611`1oOgl30820P0<0Ogmo1023Ph<307alO0<0OGem101oOgl30820P0<0Ogmo3P20
P80307moO`@0b>3H0`22PX8407MgM`<0PH610`1hN7P408:2PP<0P8200`1nOWh30861P@@0Ogmo0`2:
RXX30820P0@0RHV90`1iNGT307]kN`@0LG5a0`1oOgl307inOP@0P8202@1nOWh407YjNP<0PX:20`1g
MgL407]kN`<0PH610`1mOGd40861P@<0OWin0`1oOgl408:2PP<0P8205038h=P001<0b>3H0`0W9bL4
02h^;P<0B4Q80`1EEED403Lg=`<0:b/[0`0`<30404=3@`<0:b/[0`1CDe<303Ti>@@0?clo0`0X:2P3
07]kN`@0IVIV0`2][Jd30:FUY@@0YjNW0`2QXJ430;bl_0@0^KVi0`2g]kL30:NWY`<0QXJ6102EUID3
0:6QX@<0Y:BT102XZ:P30:f][@L0/K6a0`2b/[840<SPf0<0RHV9101kNg/30820P0<0N7Qh102<S8`3
07moO`<0PX:21020P80307emO@<0MgMg0`1jNWX408R8R0<0OWin0`23Ph<409:BTP<0OWin0`26QXH7
0861P@<0OWin1022PX8307inOP<0Ph>30`1bLW8407moO`<0OWin0`23Ph<70861P@<0P8201021PH43
08B4Q0l0b>3H0`1mOGd40820P0<0NGUi0`1oOgl407]kN`<0PX:20`20P80407emO@<0PH610`1mOGd3
07inOP@0Ph>30`1mOGd307moO`@0Q8B40`1oOgl30861P@L0Ogmo0`20P80307moO`@0Ph>30`1lO7`3
07emO@@0Ogmo0`20P80307moO`h0P8200`1oOgl40<SPf0<0PX:2101gMgL30861P@<0N7Qh1022PX83
0820P0<0OWin0`21PH4407moO`<0RXZ:0`20P80408V9R@<0NGUi0`1kNg/4075aL@<0Ogmo0`1nOWh4
0820P0T0OWin101jNWX308:2PP<0MgMg101kNg/30861P@<0OGem1021PH4307inOP<0Ogmo1022PX83
0820P1@0b>3H000C0<SPf0<0@D51100b<S8302XZ:P<0ATI6101@D50302XZ:P<0<S8b100k>c/303Ti
>@<0@T920`0];Bd405UIF@<07QhN0`0k>c/408J6QP<0NWYj0`2YZJT409fMW@<0YZJV1`2j^[X30::R
XP<0[Jf]0`2/[:`409bLW0H0WinO102SXj<30:^[Z`<0[Jf]102a/K430;Fe]@@0b>3H0`26QXH407Ui
N@<0QXJ60`1nOWh408F5Q@<0Ogmo1`21PH4307QhN0<0P8200`27QhL408R8R0<0O7al0`1jNWX406IV
IP<0RXZ:0`1jNWX408:2PP<0OGem0`21PH4407inOP<0R8R81P20P80408B4Q0<0QXJ60`21PH440820
P0<0Ogmo0`20P80407moO`<0P8203`38h=P30820P0@0NGUi0`21PH4307inOP@0P8200`23Ph<70820
P0<0OWin0`1oOgl307inOP@0PH610`1oOgl30861P@@0O7al0`23Ph<307moO`@0P8200`21PH4307mo
O`<0PH61101lO7`60820P0@0PH610`1nOWh307moO`@0P8200`1oOgl30820P0@0PH610`20P8040<SP
f0<0O7al101jNWX307inOP<0P820101fMWH308B4Q0<0OWin0`23Ph<407moO`<0Q8B40`1fMWH407in
OP<0Ph>30`21PH4407alO0<0OWin0`23Ph<407moO`<0Ph>30`1lO7`307moO`L0OWin0`20P80407em
O@<0Q8B40`1oOgl407emO@X0PH610`1lO7`D0<SPf0004`38h=P30451@@@0<S8b0`0Z:RX304I6AP@0
D51@0`0Z:RX3038b<P@0>c/k0`0i>CT30492@P<0;Bd]101IFET301hN7P<0>c/k1026QXH307YjNP<0
ZJVY102MWId30:JVYPL0^[Zj0`2RXZ830:f][@<0[:b/102LW9`609nOW`@0Xj>S0`2[Zj/30:f][@@0
/K6a0`2e]KD40<SPf0<0QXJ6101iNGT308J6QP<0OWin1025QHD307moO`L0PH610`1hN7P30820P0<0
QhN71028R8P307alO0<0NWYj101VIVH308Z:RP<0NWYj1022PX8307emO@<0PH61101nOWh308R8R0H0
P8201024Q8@308J6QP<0PH611020P80307moO`<0P820101oOgl30820P0l0b>3H0`20P80407UiN@<0
PH610`1nOWh40820P0<0Ph>31`20P80307inOP<0Ogmo0`1nOWh40861P@<0Ogmo0`21PH4407alO0<0
Ph>30`1oOgl40820P0<0PH610`1oOgl30861P@@0O7al1P20P8040861P@<0OWin0`1oOgl40820P0<0
Ogmo0`20P8040861P@<0P8201038h=P307alO0@0NWYj0`1nOWh30820P0@0MWIf0`24Q8@307inOP<0
Ph>3101oOgl308B4Q0<0MWIf101nOWh308>3P`<0PH61101lO7`307inOP<0Ph>3101oOgl308>3P`<0
O7al0`1oOgl707inOP<0P820101mOGd308B4Q0<0Ogmo101mOGd:0861P@<0O7al5038h=P001<0b>3H
0`11@D44038b<P<0:RXZ0`16ATH4051@D0<0:RXZ0`0b<S8403/k>`<0>CTi0`12@T8302d];@@0FEUI
0`0N7Qh303/k>`@0QXJ60`1jNWX30:VYZ@@0WIfM0`2VYZH70;Zj^P<0XZ:R0`2][Jd30:b/[0@0W9bL
1P2OWil40:>SX`<0Zj^[0`2][Jd40;6a/@<0]KFe1038h=P308J6QP@0NGUi0`26QXH307inOP@0QHF5
0`1oOgl70861P@<0N7Qh0`20P80308N7Q`@0R8R80`1lO7`307YjNP@0IVIV0`2:RXX307YjNP@0PX:2
0`1mOGd30861P@@0OWin0`28R8P60820P0@0Q8B40`26QXH30861P@@0P8200`1oOgl30820P0@0Ogmo
0`20P80?0<SPf0<0P820101iNGT30861P@<0OWin1020P80308>3P`L0P8200`1nOWh307moO`<0OWin
1021PH4307moO`<0PH61101lO7`308>3P`<0Ogmo1020P8030861P@<0Ogmo0`21PH4407alO0H0P820
1021PH4307inOP<0Ogmo1020P80307moO`<0P8201021PH430820P0@0b>3H0`1lO7`407YjNP<0OWin
0`20P80407IfMP<0Q8B40`1nOWh308>3P`@0Ogmo0`24Q8@307IfMP@0OWin0`23Ph<30861P@@0O7al
0`1nOWh308>3P`@0Ogmo0`23Ph<307alO0<0Ogmo1`1nOWh30820P0@0OGem0`24Q8@307moO`@0OGem
2P21PH4307alO1@0b>3H000C0<SPf0<0@D51100b<S8302XZ:P<0ATI6101@D50302XZ:P<0<S8b100k
>c/303Ti>@<0@T920`0];Bd405UIF@<07QhN0`0k>c/408J6QP<0NWYj0`2YZJT409fMW@<0YZJV1`2j
^[X30::RXP<0[Jf]0`2/[:`409bLW0H0WinO102SXj<30:^[Z`<0[Jf]102a/K430;Fe]@@0b>3H0`26
QXH407UiN@<0QXJ60`1nOWh408F5Q@<0Ogmo1`21PH4307QhN0<0P8200`27QhL408R8R0<0O7al0`1j
NWX406IVIP<0RXZ:0`1jNWX408:2PP<0OGem0`21PH4407inOP<0R8R81P20P80408B4Q0<0QXJ60`21
PH440820P0<0Ogmo0`20P80407moO`<0P8203`38h=P30820P0@0NGUi0`21PH4307inOP@0P8200`23
Ph<70820P0<0OWin0`1oOgl307inOP@0PH610`1oOgl30861P@@0O7al0`23Ph<307moO`@0P8200`21
PH4307moO`<0PH61101lO7`60820P0@0PH610`1nOWh307moO`@0P8200`1oOgl30820P0@0PH610`20
P8040<SPf0<0O7al101jNWX307inOP<0P820101fMWH308B4Q0<0OWin0`23Ph<407moO`<0Q8B40`1f
MWH407inOP<0Ph>30`21PH4407alO0<0OWin0`23Ph<407moO`<0Ph>30`1lO7`307moO`L0OWin0`20
P80407emO@<0Q8B40`1oOgl407emO@X0PH610`1lO7`D0<SPf0004`38h=P302/[:`@0:RXZ0`17AdL3
03dm?@@0?3`l0`0h>3P303De=@@0<c<c0`12@T8302l_;`L0@d=30`0Q8B4306IVIP@0ATI60`2=SHd3
08>3P`@0ZJVY0`2[Zj/30;Zj^P@0]kNg0`2@T9030:RXZ0<0_[jn102WYjL309nOW`<0W9bL102PX:03
0:NWY`<0[:b/102_[jl30;Ng]`@0b>3H0`1kNg/40820P0<0OWin0`1]KFd408V9R@<0Ph>31`1nOWh3
07UiN@<0QXJ60`1aLG4408V9R@<0N7Qh0`24Q8@4092@T0<0KVi^0`2CTi<4079bLP<0R8R80`1mOGd4
08:2PP<0NWYj0`26QXH307moO`X0P8201021PH4307moO`<0P820101nOWh307moO`l0b>3H0`1lO7`4
0820P0<0Ogmo0`21PH4407alO0<0P8200`1mOGd407moO`<0OWin0`1oOgl307emO@@0P8200`1oOgl3
0820P0@0PX:20`1oOgl308:2PP@0OWin0`21PH4307moO`<0OWin1022PX830820P0<0Ogmo1020P803
07inOP<0PH611`20P80307moO`@0PH610`20P8040<SPf0<0Ogmo1`22PX8307]kN`@0MGEe0`23Ph<3
07moO`<0QHF5101oOgl307QhN0<0RXZ:101eMGD30:VYZ@<0QhN71023Ph<307moO`<0Ph>31021PH43
07moO`<0OGem0`20P8040861P@H0OWin101oOgl30820P0<0O7al1022PX8307emO@<0Ogmo1020P803
07alO1@0b>3H000C0<SPf0<0:b/[100Z:RX304M7A`<0?Cdm100l?3`303Ph>0<0=CDe100c<c<30492
@P<0;bl_1`13@d<3024Q8@<0IVIV1016ATH308f=S@<0Ph>3102YZJT30:^[Z`<0^[Zj102g]kL3092@
T0<0Z:RX0`2n_[h40:NWY`<0WinO0`2LW9`40:2PX0<0YjNW0`2/[:`40:n_[`<0]kNg1038h=P307]k
N`@0P8200`1nOWh306e]K@@0RHV90`23Ph<707inOP<0NGUi0`26QXH3075aL@@0RHV90`1hN7P308B4
Q0@0T92@0`1^KVh309>CT`@0LW9b0`28R8P307emO@@0PX:20`1jNWX308J6QP<0Ogmo2P20P8040861
P@<0Ogmo0`20P80407inOP<0Ogmo3`38h=P307alO0@0P8200`1oOgl30861P@@0O7al0`20P80307em
O@@0Ogmo0`1nOWh307moO`<0OGem1020P80307moO`<0P8201022PX8307moO`<0PX:2101nOWh30861
P@<0Ogmo0`1nOWh408:2PP<0P8200`1oOgl40820P0<0OWin0`21PH470820P0<0Ogmo1021PH430820
P0@0b>3H0`1oOgl708:2PP<0Ng]k101eMGD308>3P`<0Ogmo0`25QHD407moO`<0N7Qh0`2:RXX407Ee
M@<0ZJVY0`27QhL408>3P`<0Ogmo0`23Ph<40861P@<0Ogmo0`1mOGd30820P0@0PH611P1nOWh407mo
O`<0P8200`1lO7`408:2PP<0OGem0`1oOgl40820P0<0O7al5038h=P001<0b>3H0`0[:b/402XZ:P<0
AdM70`0m?Cd403`l?0<0>3Ph0`0e=CD403<c<`<0@T920`0_;bl704=3@`<08B4Q0`1VIVH404I6AP<0
SHf=0`23Ph<40:VYZ@<0Zj^[0`2j^[X40;Ng]`<0T92@0`2XZ:P30;jn_P@0YjNW0`2OWil309bLW0@0
X:2P0`2WYjL30:b/[0@0[jn_0`2g]kL40<SPf0<0Ng]k1020P80307inOP<0KFe]1029RHT308>3P`L0
OWin0`1iNGT308J6QP<0LG5a1029RHT307QhN0<0Q8B4102@T90306i^KP<0Ti>C101bLW8308R8R0<0
OGem1022PX8307YjNP<0QXJ60`1oOgl:0820P0@0PH610`1oOgl30820P0@0OWin0`1oOgl?0<SPf0<0
O7al1020P80307moO`<0PH61101lO7`30820P0<0OGem101oOgl307inOP<0Ogmo0`1mOGd40820P0<0
Ogmo0`20P80408:2PP<0Ogmo0`22PX8407inOP<0PH610`1oOgl307inOP@0PX:20`20P80307moO`@0
P8200`1nOWh30861P@L0P8200`1oOgl40861P@<0P8201038h=P307moO`L0PX:20`1kNg/407EeM@<0
Ph>30`1oOgl308F5Q@@0Ogmo0`1hN7P308Z:RP@0MGEe0`2YZJT308N7Q`@0Ph>30`1oOgl308>3P`@0
PH610`1oOgl307emO@<0P8201021PH4607inOP@0Ogmo0`20P80307alO0@0PX:20`1mOGd307moO`@0
P8200`1lO7`D0<SPf0004`38h=P302/[:`@0:2PX0`1?Cdl302d];@@0>c/k0`0f=SH303<c<`@0=3@d
0`0j>SX3038b<P<0E5AD101OGel304Y:BP<0LG5a100I6AT305YJFP<0QhN7102ATI430;2`/0<0/k>c
102_[jl309VIV@<0YjNW0`2m_Kd40;Vi^@<0YjNW0`2UYJD409VIV@<0WIfM0`2XZ:P40:b/[0<0^[Zj
1038h=P3092@T0@0Ogmo0`1nOWh30861P@@0MGEe0`27QhL307emO@@0O7al0`25QHD607moO`@0JVYZ
0`2HV9P3096AT@@0NWYj0`2>SXh306EUI@@0T92@0`1cLg<308B4Q0@0Ph>30`21PH4307MgM`<0PX:2
101oOgl30820P0<0OGem101oOgl308N7Q`<0Ng]k1020P80307inOPl0b>3H0`22PX8:0820P0@0Ogmo
0`1mOGd308:2PP@0P8200`1oOgl30861P@<0P8201`1nOWh308B4Q0@0P8200`21PH4307inOP@0PH61
0`1oOgl30820P0<0PH611020P8030861P@L0Ogmo0`21PH430820P0@0PH610`1oOgl30861P@@0OWin
0`1oOgl40<SPf0<0IfMW101dM7@308F5Q@<0PX:2101jNWX307UiN@<0QhN70`26QXH407emO@<0P820
0`28R8P407emO@<0R8R80`26QXH408>3P`<0PH610`1oOgl40820P0<0QHF50`1jNWX308B4Q0@0P820
0`26QXH307moO`@0Q8B40`20P80307moO`@0QHF50`1lO7`308F5Q@@0OWin0`20P80D0<SPf0004`38
h=P302/[:`@0:2PX0`1?Cdl302d];@@0>c/k0`0f=SH303<c<`@0=3@d0`0j>SX3038b<P<0E5AD101O
Gel304Y:BP<0LG5a100I6AT305YJFP<0QhN7102ATI430;2`/0<0/k>c102_[jl309VIV@<0YjNW0`2m
_Kd40;Vi^@<0YjNW0`2UYJD409VIV@<0WIfM0`2XZ:P40:b/[0<0^[Zj1038h=P3092@T0@0Ogmo0`1n
OWh30861P@@0MGEe0`27QhL307emO@@0O7al0`25QHD607moO`@0JVYZ0`2HV9P3096AT@@0NWYj0`2>
SXh306EUI@@0T92@0`1cLg<308B4Q0@0Ph>30`21PH4307MgM`<0PX:2101oOgl30820P0<0OGem101o
Ogl308N7Q`<0Ng]k1020P80307inOPl0b>3H0`22PX8:0820P0@0Ogmo0`1mOGd308:2PP@0P8200`1o
Ogl30861P@<0P8201`1nOWh308B4Q0@0P8200`21PH4307inOP@0PH610`1oOgl30820P0<0PH611020
P8030861P@L0Ogmo0`21PH430820P0@0PH610`1oOgl30861P@@0OWin0`1oOgl40<SPf0<0IfMW101d
M7@308F5Q@<0PX:2101jNWX307UiN@<0QhN70`26QXH407emO@<0P8200`28R8P407emO@<0R8R80`26
QXH408>3P`<0PH610`1oOgl40820P0<0QHF50`1jNWX308B4Q0@0P8200`26QXH307moO`@0Q8B40`20
P80307moO`@0QHF50`1lO7`308F5Q@@0OWin0`20P80D0<SPf0004`38h=P302/[:`@0:2PX0`1?Cdl3
02d];@@0>c/k0`0f=SH303<c<`@0=3@d0`0j>SX3038b<P<0E5AD101OGel304Y:BP<0LG5a100I6AT3
05YJFP<0QhN7102ATI430;2`/0<0/k>c102_[jl309VIV@<0YjNW0`2m_Kd40;Vi^@<0YjNW0`2UYJD4
09VIV@<0WIfM0`2XZ:P40:b/[0<0^[Zj1038h=P3092@T0@0Ogmo0`1nOWh30861P@@0MGEe0`27QhL3
07emO@@0O7al0`25QHD607moO`@0JVYZ0`2HV9P3096AT@@0NWYj0`2>SXh306EUI@@0T92@0`1cLg<3
08B4Q0@0Ph>30`21PH4307MgM`<0PX:2101oOgl30820P0<0OGem101oOgl308N7Q`<0Ng]k1020P803
07inOPl0b>3H0`22PX8:0820P0@0Ogmo0`1mOGd308:2PP@0P8200`1oOgl30861P@<0P8201`1nOWh3
08B4Q0@0P8200`21PH4307inOP@0PH610`1oOgl30820P0<0PH611020P8030861P@L0Ogmo0`21PH43
0820P0@0PH610`1oOgl30861P@@0OWin0`1oOgl40<SPf0<0IfMW101dM7@308F5Q@<0PX:2101jNWX3
07UiN@<0QhN70`26QXH407emO@<0P8200`28R8P407emO@<0R8R80`26QXH408>3P`<0PH610`1oOgl4
0820P0<0QHF50`1jNWX308B4Q0@0P8200`26QXH307moO`@0Q8B40`20P80307moO`@0QHF50`1lO7`3
08F5Q@@0OWin0`20P80D0<SPf0004`38h=P304U9B@@0<C4a0`1GEeL302PX:0L0>CTi0`0a<C4403@d
=0<0?Shn0`0g=cL305=CD`@0C4a<0`15ADD304];B`@08R8R0`0P820306QXJ0@0PH610`2DU9@30:j^
[P@0YJFU0`2ATI430:VYZ@<0/k>c102g]kL30:VYZ@L0ZZZZ0`2OWil309jNWP@0Zj^[0`2e]KD40<SP
f0<0UIFE101hN7P30820P0<0Ogmo1023Ph<30820P0<0NGUi1026QXH307EeM@<0P8200`26QXH408F5
Q@<0KVi^0`2=SHd409>CT`<0Ng]k0`2CTi<406EUI@<0UIFE0`1/K6`408F5Q@<0OWin0`2:RXX30861
P@@0R8R80`1nOWh307moO`@0Ph>30`1gMgL308b<S0@0NWYj0`1nOWh?0<SPf0<0MgMg101kNg/307mo
O`<0OWin1021PH4307moO`<0OGem1022PX8307moO`<0PX:20`1oOgl407emO@<0Ogmo0`1mOGd408F5
Q@<0OGem0`23Ph<407inOP<0Ogmo0`1nOWh30820P0@0Ogmo2P20P80307inOP<0P820101nOWh30820
P0L0PH610`1oOgl40<SPf0<0IFEU101hN7P608B4Q0@0P8200`25QHD30820P0<0OGem1025QHD307em
O@<0Ph>31022PX8308V9R@<0NWYj101RHV830820P0<0OGem1024Q8@307QhN0<0Q8B40`22PX840820
P0<0QXJ60`20P80408>3P`<0OGem0`1nOWh408B4Q0<0PX:20`1oOgl408B4Q0<0PX:25038h=P001<0
b>3H0`19BDT4034a<@<0EeMG0`0X:2P703Ti>@<0<C4a100d=3@303hn?P<0=cLg0`1CDe<404a<C0<0
ADE50`1;Bd/4028R8P<0820P0`1XJ6P40861P@<0U9BD0`2^[Zh40:FUY@<0TI6A0`2YZJT30;>c/`@0
]kNg0`2YZJT70:ZZZP<0WinO0`2NWYh40:^[Z`<0]KFe1038h=P309FEU@@0N7Qh0`20P80307moO`@0
Ph>30`20P80307UiN@@0QXJ60`1eMGD30820P0<0QXJ61025QHD306i^KP<0SHf=102CTi<307]kN`<0
Ti>C101UIFD309FEU@<0K6a/1025QHD307inOP<0RXZ:0`21PH4408R8R0<0OWin0`1oOgl408>3P`<0
MgMg0`2<S8`407YjNP<0OWin3`38h=P307MgM`@0Ng]k0`1oOgl307inOP@0PH610`1oOgl307emO@@0
PX:20`1oOgl308:2PP<0Ogmo101mOGd307moO`<0OGem1025QHD307emO@<0Ph>3101nOWh307moO`<0
OWin0`20P80407moO`X0P8200`1nOWh30820P0@0OWin0`20P8070861P@<0Ogmo1038h=P306EUI@@0
N7Qh1P24Q8@40820P0<0QHF50`20P80307emO@@0QHF50`1mOGd308>3P`@0PX:20`29RHT307YjNP@0
HV9R0`20P80307emO@@0Q8B40`1hN7P308B4Q0<0PX:21020P80308J6QP<0P8201023Ph<307emO@<0
OWin1024Q8@308:2PP<0Ogmo1024Q8@308:2PQ@0b>3H000C0<SPf0<0BDU9100a<C4305MGE`<0:2PX
1`0i>CT3034a<@@0=3@d0`0n?Sh303Lg=`<0De=C101<C4`304E5A@<0Bd];100R8R83020P80<0J6QX
1021PH4309BDU0<0[Zj^102UYJD3096AT@<0ZJVY0`2c/k<40;Ng]`<0ZJVY1`2ZZZX309nOW`<0WYjN
102[Zj/30;Fe]@@0b>3H0`2EUID407QhN0<0P8200`1oOgl408>3P`<0P8200`1iNGT408J6QP<0MGEe
0`20P80308J6QP@0QHF50`1^KVh308f=S@@0Ti>C0`1kNg/309>CT`@0IFEU0`2EUID306a/K0@0QHF5
0`1nOWh308Z:RP<0PH611028R8P307inOP<0Ogmo1023Ph<307MgM`<0S8b<101jNWX307inOPl0b>3H
0`1gMgL407]kN`<0Ogmo0`1nOWh40861P@<0Ogmo0`1mOGd408:2PP<0Ogmo0`22PX8307moO`@0OGem
0`1oOgl307emO@@0QHF50`1mOGd308>3P`@0OWin0`1oOgl307inOP<0P820101oOgl:0820P0<0OWin
0`20P80407inOP<0P8201`21PH4307moO`@0b>3H0`1UIFD407QhN0H0Q8B41020P80308F5Q@<0P820
0`1mOGd408F5Q@<0OGem0`23Ph<408:2PP<0RHV90`1jNWX4069RHP<0P8200`1mOGd408B4Q0<0N7Qh
0`24Q8@308:2PP@0P8200`26QXH30820P0@0Ph>30`1mOGd307inOP@0Q8B40`22PX8307moO`@0Q8B4
0`22PX8D0<SPf0004`38h=P305iNGP@0:RXZ0`1>CTh3034a<@@0;Bd]1P0`<30404M7A`<0ATI60`10
@40304Y:BP@0;2`/0`1TI6@305=CD`@0@4100`0W9bL3020P80@0MgMg0`1jNWX309BDU0@0ZJVY0`27
QhL60;>c/`@0_Kfm0`2_[jl30:BTY0@0X:2P0`2c/k<30:RXZ0@0Xj>S0`2`/;040<SPf0<0QHF5102:
RXX308F5Q@<0Ogmo1020P80307emO@<0Ph>3101iNGT308:2PP<0P8200`1oOgl408Z:RP<0PH610`1D
E5@4075aL@<0QXJ60`1iNGT409:BTP<0HF5Q0`2GUiL406MWI`<0Q8B40`1jNWX307emO@@0Ng]k0`1m
OGd30820P0@0OWin0`22PX8307YjNP@0Ogmo0`1kNg/?0<SPf0<0P820101mOGd307moO`<0PX:2101o
Ogl308:2PP<0Ogmo101mOGd607inOPL0PH610`1lO7`30820P0@0MgMg3@1oOgl307emO@L0PH611P1o
Ogl407inOP<0PX:20`21PH470820P0<0Ogmo1020P80307inOP@0b>3H0`1bLW8407UiN@<0QXJ60`1j
NWX407emO@<0QHF50`1jNWX308B4Q0@0Ogmo0`1kNg/308:2PP@0QhN70`24Q8@307alO0@0Fe]K0`24
Q8@307emO@@0Ogmo0`24Q8@30861P@L0QXJ60`22PX8307emO@@0Ogmo0`25QHD307moO`@0OWin0`25
QHD707inOP<0Q8B45038h=P001<0b>3H0`1NGUh402XZ:P<0CTi>0`0a<C4402d];@H0<30`1017AdL3
04I6AP<0@4100`1:BTX402`/;0<0I6AT0`1CDe<40410@0<09bLW0`0P820407MgM`<0NWYj0`2DU9@4
0:VYZ@<0QhN71P2c/k<40;fm_@<0[jn_0`2TY:@40:2PX0<0/k>c0`2XZ:P40:>SX`<0/;2`1038h=P3
08F5Q@@0RXZ:0`25QHD307moO`@0P8200`1mOGd308>3P`@0NGUi0`22PX830820P0<0Ogmo102:RXX3
0861P@<0E5AD101aLG4308J6QP<0NGUi102BTY83065QH@<0UiNG101WIfL308B4Q0<0NWYj0`1mOGd4
07]kN`<0OGem0`20P80407inOP<0PX:20`1jNWX407moO`<0Ng]k3`38h=P30820P0@0OGem0`1oOgl3
08:2PP@0Ogmo0`22PX8307moO`@0OGem1P1nOWh70861P@<0O7al0`20P80407MgM`d0Ogmo0`1mOGd7
0861P@H0Ogmo101nOWh308:2PP<0PH611`20P80307moO`@0P8200`1nOWh40<SPf0<0LW9b101iNGT3
08J6QP<0NWYj101mOGd308F5Q@<0NWYj0`24Q8@407moO`<0Ng]k0`22PX8408N7Q`<0Q8B40`1lO7`4
05]KF`<0Q8B40`1mOGd407moO`<0Q8B40`21PH4708J6QP<0PX:20`1mOGd407moO`<0QHF50`1oOgl4
07inOP<0QHF51`1nOWh308B4Q1@0b>3H000C0<SPf0<0GUiN100Z:RX304i>CP<0<C4a100];Bd6030`
<0@0AdM70`16ATH30410@0<0BTY:100/;2`306ATI0<0De=C1010@40302LW9`<0820P101gMgL307Yj
NP<0U9BD102YZJT308N7Q`H0/k>c102m_Kd30:n_[`<0Y:BT102PX:030;>c/`<0Z:RX102SXj<30;2`
/0@0b>3H0`25QHD408Z:RP<0QHF50`1oOgl40820P0<0OGem0`23Ph<407UiN@<0PX:20`20P80307mo
O`@0RXZ:0`21PH4305ADE0@0LG5a0`26QXH307UiN@@0TY:B0`1QHF4309NGU`@0IfMW0`24Q8@307Yj
NP<0OGem101kNg/307emO@<0P820101nOWh308:2PP<0NWYj101oOgl307]kN`l0b>3H0`20P80407em
O@<0Ogmo0`22PX8407moO`<0PX:20`1oOgl407emO@H0OWin1`21PH4307alO0<0P820101gMgL=07mo
O`<0OGem1`21PH4607moO`@0OWin0`22PX830861P@L0P8200`1oOgl40820P0<0OWin1038h=P3079b
LP@0NGUi0`26QXH307YjNP@0OGem0`25QHD307YjNP<0Q8B4101oOgl307]kN`<0PX:21027QhL308B4
Q0<0O7al101KFe/308B4Q0<0OGem101oOgl308B4Q0<0PH611`26QXH308:2PP<0OGem101oOgl308F5
Q@<0Ogmo101nOWh308F5Q@L0OWin0`24Q8@D0<SPf0004`38h=P305iNGP@0:RXZ0`1>CTh3034a<@@0
;Bd]1P0`<30404M7A`<0ATI60`10@40304Y:BP@0;2`/0`1TI6@305=CD`@0@4100`0W9bL3020P80@0
MgMg0`1jNWX309BDU0@0ZJVY0`27QhL60;>c/`@0_Kfm0`2_[jl30:BTY0@0X:2P0`2c/k<30:RXZ0@0
Xj>S0`2`/;040<SPf0<0QHF5102:RXX308F5Q@<0Ogmo1020P80307emO@<0Ph>3101iNGT308:2PP<0
P8200`1oOgl408Z:RP<0PH610`1DE5@4075aL@<0QXJ60`1iNGT409:BTP<0HF5Q0`2GUiL406MWI`<0
Q8B40`1jNWX307emO@@0Ng]k0`1mOGd30820P0@0OWin0`22PX8307YjNP@0Ogmo0`1kNg/?0<SPf0<0
P820101mOGd307moO`<0PX:2101oOgl308:2PP<0Ogmo101mOGd607inOPL0PH610`1lO7`30820P0@0
MgMg3@1oOgl307emO@L0PH611P1oOgl407inOP<0PX:20`21PH470820P0<0Ogmo1020P80307inOP@0
b>3H0`1bLW8407UiN@<0QXJ60`1jNWX407emO@<0QHF50`1jNWX308B4Q0@0Ogmo0`1kNg/308:2PP@0
QhN70`24Q8@307alO0@0Fe]K0`24Q8@307emO@@0Ogmo0`24Q8@30861P@L0QXJ60`22PX8307emO@@0
Ogmo0`25QHD307moO`@0OWin0`25QHD707inOP<0Q8B45038h=P001<0b>3H0`1MGEd403hn?P<0?3`l
0`1:BTX702l_;`<0?3`l101;Bd/3055AD@<0=cLg0`14A4@403Ti>@<0MGEe0`0m?Cd403De=@H0:b/[
100X:2P306QXJ0<0HV9R1022PX8309>CT`<0/K6a0`2d];@40;^k^`<0^;Rh0`2XZ:P40::RXP<0Z:RX
0`2d];@40:FUY@<0YZJV1038h=P307MgM`@0E5AD0`1XJ6P307]kN`@0MGEe0`22PX8307inOP@0Q8B4
0`21PH4307alO0<0QHF5101VIVH309VIV@<0RXZ:101iNGT307moO`<0N7Qh101aLG430;2`/0<0I6AT
102`/;0308R8R0<0QXJ60`22PX8408B4Q0<0OWin0`1hN7P407emO@<0N7Qh0`23Ph<407MgM`<0O7al
3`38h=P30820P0@0OWin0`1oOgl307inOP@0OGem0`20P8030861P@@0QHF50`1mOGd30820P0<0PX:2
1`1nOWh30820P0L0PX:20`1oOgl40820P0<0Q8B41P1oOgl40820P0<0PX:21`21PH430820P0<0PH61
101nOWh30861P@L0P8200`1nOWh40<SPf0<0SHf=102>SXh309ZJVP<0KVi^102>SXh307moO`<0S8b<
0`1nOWh4071`L0H0PH611029RHT3075aL@<0PH61101nOWh308R8R0<0PX:21027QhL307AdM0H0PX:2
101eMGD307QhN0<0OGem101iNGT307moO`<0P8201021PH4308F5Q@<0P8201022PX8308N7Qa@0b>3H
000C0<SPf0<0GEeM100n?Sh303`l?0<0BTY:1`0_;bl303`l?0@0Bd];0`1ADE4303Lg=`<0A4A4100i
>CT307EeM@<0?Cdm100e=CD602/[:`@0:2PX0`1XJ6P3069RHP@0PX:20`2CTi<30;6a/@<0];Bd102k
^k/30;Rh^0<0Z:RX102RXZ830:RXZ0<0];Bd102UYJD30:JVYP@0b>3H0`1gMgL405ADE0<0J6QX0`1k
Ng/407EeM@<0PX:20`1nOWh408B4Q0<0PH610`1lO7`308F5Q@@0IVIV0`2IVIT308Z:RP@0NGUi0`1o
Ogl307QhN0@0LG5a0`2`/;0306ATI0@0/;2`0`28R8P308J6QP<0PX:21024Q8@307inOP<0N7Qh101m
OGd307QhN0<0Ph>3101gMgL307alO0l0b>3H0`20P80407inOP<0Ogmo0`1nOWh407emO@<0P8200`21
PH4408F5Q@<0OGem0`20P80308:2PPL0OWin0`20P80708:2PP<0Ogmo1020P80308B4Q0H0Ogmo1020
P80308:2PPL0PH610`20P8030861P@@0OWin0`21PH470820P0<0OWin1038h=P308f=S@@0SXj>0`2J
VYX306i^KP@0SXj>0`1oOgl308b<S0<0OWin101`L7060861P@@0RHV90`1aLG430861P@@0OWin0`28
R8P308:2PP@0QhN70`1dM7@608:2PP@0MGEe0`1hN7P307emO@@0NGUi0`1oOgl30820P0@0PH610`25
QHD30820P0@0PX:20`27QhLD0<SPf0004`38h=P305eMG@@0?Shn0`0l?3`304Y:BPL0;bl_0`0l?3`4
04];B`<0DE5A0`0g=cL304A4A0@0>CTi0`1eMGD303dm?@@0=CDe1P0[:b/402PX:0<0J6QX0`1RHV84
08:2PP<0Ti>C0`2a/K430;Bd]0@0^k^k0`2h^;P30:RXZ0@0XZ:R0`2XZ:P30;Bd]0@0YJFU0`2VYZH4
0<SPf0<0MgMg101DE5@306QXJ0<0Ng]k101eMGD308:2PP<0OWin1024Q8@30861P@<0O7al0`25QHD4
06IVIP<0VIVI0`2:RXX407UiN@<0Ogmo0`1hN7P4075aL@<0/;2`0`1TI6@40;2`/0<0R8R80`26QXH3
08:2PP@0Q8B40`1nOWh307QhN0@0OGem0`1hN7P308>3P`@0MgMg0`1lO7`?0<SPf0<0P820101nOWh3
07moO`<0OWin101mOGd30820P0<0PH611025QHD307emO@<0P8200`22PX8707inOP<0P8201`22PX83
07moO`@0P8200`24Q8@607moO`@0P8200`22PX870861P@<0P8200`21PH4407inOP<0PH611`20P803
07inOP@0b>3H0`2=SHd408j>SP<0VYZJ0`1^KVh408j>SP<0Ogmo0`2<S8`307inOP@0L71`1P21PH44
08V9R@<0LG5a0`21PH4407inOP<0R8R80`22PX8408N7Q`<0M7Ad1P22PX8407EeM@<0N7Qh0`1mOGd4
07UiN@<0Ogmo0`20P8040861P@<0QHF50`20P80408:2PP<0QhN75038h=P00?l0b>3Hi`38h=P00?l0
b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0
b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0
b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0
b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00?l0b>3Hi`38h=P00001\
\>"],
  ImageRangeCache->{{{0, 485}, {485, 0}} -> {-0.0500105, -0.0500105, \
0.00432994, 0.00432994}, {{11.5, 242.5}, {473.438, 242.5}} -> {-0.15487, \
-0.155154, 0.00909347, 0.00909347}, {{17, 127}, {467.938, 357.938}} -> \
{-5.99295, -6.01204, 0.305458, 0.305458}, {{127, 236.938}, {467.938, \
357.938}} -> {-39.6153, -6.02455, 0.305631, 0.305631}, {{17, 127}, {357.938, \
248}} -> {-6.00545, -39.6344, 0.305631, 0.305631}, {{127, 236.938}, {357.938, \
248}} -> {-39.6153, -39.6344, 0.305631, 0.305631}, {{242.5, 473.438}, \
{473.438, 242.5}} -> {-2.25518, -0.155154, 0.00909347, 0.00909347}, {{248, \
357.938}, {467.938, 357.938}} -> {-76.5967, -6.02455, 0.305631, 0.305631}, \
{{357.938, 467.938}, {467.938, 357.938}} -> {-110.135, -6.01204, 0.305458, \
0.305458}, {{248, 357.938}, {357.938, 248}} -> {-76.5967, -39.6344, 0.305631, \
0.305631}, {{357.938, 467.938}, {357.938, 248}} -> {-110.207, -39.6344, \
0.305631, 0.305631}, {{11.5, 242.5}, {242.5, 11.5}} -> {-0.154557, -2.25458, \
0.00909101, 0.00909101}, {{17, 127}, {237, 127}} -> {-5.99295, -76.5537, \
0.305458, 0.305458}, {{127, 237}, {237, 127}} -> {-39.5933, -76.5537, \
0.305458, 0.305458}, {{17, 127}, {127, 17}} -> {-5.99295, -110.154, 0.305458, \
0.305458}, {{127, 237}, {127, 17}} -> {-39.5933, -110.154, 0.305458, \
0.305458}, {{242.5, 473.438}, {242.5, 11.5}} -> {-2.25518, -2.25546, \
0.00909347, 0.00909347}, {{248, 357.938}, {236.938, 127}} -> {-76.5967, \
-76.6158, 0.305631, 0.305631}, {{357.938, 467.938}, {236.938, 127}} -> \
{-110.207, -76.6158, 0.305631, 0.305631}, {{248, 357.938}, {127, 17}} -> \
{-76.5967, -110.226, 0.305631, 0.305631}, {{357.938, 467.938}, {127, 17}} -> \
{-110.135, -110.154, 0.305458, 0.305458}}]
}, Open  ]],

Cell["\<\
We can see that the LH*, HL* and HH* subbands appear to be quite \
uninformative. It's time to try to understand what wavelet transform is \
really about. The low-pass filter is a kind of a predictor: what can we say \
about the average value of a group of pixels. The high-pass filters, on the \
other hand, store the errors we make with the low-pass predictors. LH and HL \
store the errors we make when we try to get to average values of \
column-errors across rows, or vice versa, whereas HH stores LH's and HL's \
errors. 

We see that the LL pass over LH,HL,HH subbands is tending towards the average \
of 0. This is a good indicator of noise as those irregularities that appear \
merely in the highest resolution, but cannot be generalized to a wider area. \
However, we must note that people do recognize the absence of noise. The main \
difference between the original and the compressed image is that the \
compressed one is too smooth.

In the following experiments, we will try to capture the regularities of \
noise. To do this, we will need a different kind of a transform.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Describing quantization noise", "Section"],

Cell["\<\
Let's examine the error introduced by quantization. We notice that the error \
is pretty much random, with the exception of a few features in the HH band. \
The idea we will now pursue is to try to describe this error and re-introduce \
it in the decompressed image.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mcomp = decomp - qdecomp; 
    Show[GraphicsArray[
        Map[Graphics[Raster[\((# + 128)\)/256], AspectRatio \[Rule] 1] &, 
          mcomp, {2}], GraphicsSpacing \[Rule] 0]];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
88777C727C8771838388757972817582847E8E847E8A757C838577817C7C808480808180
7E8683828180837E83817D817E847D837F7C838183817E80897A7D71
7F8F78857683807F85857A867371858A797D8C8D7F7C8D81837B81807E817D827D7A827F
83828282847D7F7D7A827F807C8180867E8484807D82817C87788288
84817284777D817C80817B807D8D86817B818C817C8B7C808081817B7F7B81817C7C7E7B
827A8283827D7C7B7F817F807B807C818182827E84807C7986797E8D
707E8E707A84877A7A827D817A7482867D79738C82757D837F8282797F7F837F7C818179
7E7E817F817B7D8181817E837A7F7E81807B81807E7F8082807D7D8B
76888270788378807C7D7C7B877C7F8478797275748A78818181837B7D817C7F817D837C
7E817F81807D7B7B7D807F818381817E828081827E7F7F7E847D7974
848C827F8A85887581808480858084837F7C737879897B7B807E807F81807F7C80827A7E
8381807F837C7E7E7F7D7D817B7F828181847E8184807D7E8285758B
8973827988767E797A84817F86877B8483797978748F80807F7E84817E817E827D847E81
847F7D7D8080837981827E80817D83827E7A82837E82788082847D7C
7E8C777E887E8B72807F7F838187877F8B76787684837D7B7F7F8280807F7B7E7C7F7A7F
7D7E7B7E7B7C847C85837F807A7F7F7F7F827D7E7E817D81837F7E7B
777D8B7E7C82827D8B7C7E807F798081887D7A7C798078837B85847E7E82827E7C817F81
83817F817F79817C81827D7C7F7F817E7F8384817F8481817C7F7E7E
7C7F7083868C7F85858A7F818081857F807D747C747F7D81807E7E83808080817D807D7D
807A7B7F827F837C818283807F81847D7F8082808378818582828377
7F888E8D88857D7F878482847E80827B8777767076797C808186827D818080818081817E
817E827A817B807C7B7F7E7E7E7E7F83867B87758078837C7D7F8378
837780747F797A7E837A83897F7C8489807F8E76788179817E837E8084817B7F857E8383
87787F86807F7F81807F7F808082817D867F857A7D837D847B847E86
757D8386808778798077797F717B7E7A887075717D7D81897F8082847E817C807F7C7C81
817E7F818279818181807A80837F817C8181897F7D7E7D7F857F8182
85847F807C7F897680858B8C717F82848576758D89797F7C8184827B848381827D7F8081
8378807F7D837C7C7A83827E8081828081837E80818281817B7D827D
7C758A808C7C8B738D8E758586757F7A828076738F787F85807B827E7F81817D847B7F83
7E7C7F7E82818181817E877D81807E7B828080847F7E7A82817B7F7C
85767F7C7C8F8986827E858E7775787F817B74718E767E7F82817F7E83817B8081757A83
7B7D7E807D81847D818180807F837E807B7E817D7F7B7B84827D8476
877E737C7C8F738D70748E7E897A807F817C728B8F7A847C80837B847E79807F7F827783
8181798083807F827D8480827B80857E7F817D7E817E7C818080807F
7C8E797F7D7A8A8B7A867A8483717A7680808B8D827F7A7680807D7B8081817F7D7D7E79
7D84817D808383807D827F827F837D7E7E81807F7F7C81837F817E7B
817677807A80778C897D85737F8880847781728786847F7C7C82797D857F7E7F817C7E80
82817C8280847C7F7B7E817F82837B7F7E80817D827E7A808182827E
877D717280827F808F867E838A7E8C82827F8770847F848084847C7F8482807E807E8080
7D81857E7C8482808281807E847D80807F7E7D7C808281847E7E827B
7C847E817C7E7777717A7671897D83747F76878E8382868083807E7F818280837E848581
857D7F80797E7F7F83817F7E7E817E7E7C7F8082828581817D797B7E
7D7F8081817B82847981797481857C8A768080707B8580808280817E83847F807E828081
817C82837F7E797F80847D847F7D7E807D7A7F837D837E7E81808481
8C7D7E7E83737C7F8E737473808777808379827A827B7F848584817C8783807C7E7E8280
817F818182807D8280837D7D8084837F817E827B7C8380837C807D7C
7478787D827B808282767785797C85818A8C7E7778827C807F7F7D7E85817F7E83818282
7E82818180807C7E8086848182857D7D8081837C827C807D7C7E7F82
7B7E7B80817D80837D8F8F797487747A7F86808077817E848380827E8187837D837F7E84
82817E837F81827D7E8280817D7E80807D7C7A807D787C867F807E7B
8D7C7D787F7F817B807F7F7A82758781838487878C7E7F807C827F818080807B7F807D7D
7E7E7E7D7C7F7E7C817C807E7E7D7D7D7E7D8180817E7B817E877D7C
8C817F84797F7E83817B738E727A76757C827E80817D7C827D817F86817F7F827F868181
8082857C7B7E7F7F7D827B847D7C7C7E827F7D8483837D7B80898579
7D827B817E7C867E8376847C707F8E89787D83858D77738283827C858278807C7F848084
7D84847F7880847F807F807C7F817E797E7E7F82818180817D858475
857D847A7A81737F827F79708D7080728D807D7C86837876827C7F827F7C7D7A7F808680
7F7C7F807D7C7E8083817D837F827D87767B83817D7E847F80808073
7E7E817E7A7C837A7F7F81807D8D888E8F7A80807F8A877E7880817D7E7E7B7B7F7E827D
7C7B7B82807D7E837C827B81827E7E807B7985817E7E8382807F8076
8181827E8279808285817E7C757A8288758C7C7F877E88728E7C8081807B7F8082807E7B
837C7E847F7C81807E7F7D818181827B817F7D8282837E7D7D7A7F75
83747E837D82827D847F82837982898D727085777F81828475867A847C808280867D7C7E
7C7C80807B877E83787D7C73788986807F827C7E7F8081867D827E77
807E847F807A807C807D7B807C8C787D8C8E86777B80847C7E7B8A7F7C81847E8582817E
827A8282818C78808B808E8F758A877F8483817E7F807E84807E7E7E
827B7E787F81807D838E807E807A70867586708A7F7D817C7F7E8382787D86767985837F
7F7C857B7F858782778778897A788382827981817B79808280837E7D
817C7E84817E817E7E7884817F847D818D867F7C7C7D7C7C7E81807E887F837E7D7F7E83
7A7E82708E7F8083807C81827E7F83817F7F83838283817C81837C7A
828184797E897384818472857C7D778A718F73868F78807E827D807C7D867D84797F8B80
797C857F7D827E827E7B7E80818079837D8F8678837A7D7F7C7D8279
867C8587857E85847E7F8079817D797E748974797B8080777F8281807C7F8982807E8382
7684827B837A898282847A7F807C7F82828674807C81837C807E8077
887F86847A8482827F81857F7D7F7C7C84807A848E8B80857E7C7C7D847E8388777D807D
7C817388738D798580787584897C7F7B7F8F8D8A76847E81807C8178
777E7B887780828280858480847B838B7079888E83738F7D7A7E817C8282798778817D80
7B80817E707278868B76708288827B7685807E867C7D87827D858474
7A7A7A757A81807B817F788B88768B7F7C83788D8E708A7B7C877E78818385758A7C7E80
7D7E7D867785797F747485767F85887F82738D787D7F80787F7F837B
898D8778787F847E7E8A7783897B817D7E7E70778B878D8C7E807C7C7C83818270717384
76807E7E83867F837F81797A86857E817D7D84817F807D7E827F7E7C
878576867983807F75787D7E7E7D807986757D857E8D8474847B7B827F837B7F8E8D707C
77827D81807A817B7D7F7384818383817A848081847C7D827E7C847E
717B8B7E7C827A82878182817F7680848377738E897B7087717C7F8081837F8082838D8E
7B8782817B867A85837E7B7E82827E8173828084857E857C7D817D7C
8085747A7A817F77728C78827D798182797275798E88728A8E8A7B8180807B8286838772
8E857E807D8A7C79757F8771778C758076788A7F7F817F8080817C82
7F878F8B7E7A8E7D7181817E7E847F7985738978867275837C74847E7F827F7E807F7685
7688887C8181788679737C79737B8687837E85827981807B7F837C7F
828C8C7D81738F7F7379807D8080708B797B7379778A757F8A797F7D80807C7F817B787C
857B7E88797F817E7A897C827A8A74788784807A7A7F837C82807C7D
7D858E808B7D8D8D8D8E7F7987867C80868C72718F7D8770878671897984817E84827E80
7C85807B867B7F7E808B7B817D7D82827B80837E847980827D847F7B
8087798E7F7D76827E76878577878F7C887B83708C788D7E89868A758881827E7A837A7C
79847E847A878080837E827F7E808281807F7E807F7C7F817D7D8080
88887F82797F76848180807F7971787A71888974847B7D7771788682728780857F7E7C7D
7C7F807E857B808481807D857A7A7A8180807F7D7D7E7E807F83807B
867C857E818B8E84817C817F75797A7C727F897075857C7F8971878076817E7E82838384
818280858181837A858276787C81837D7E7E7E847C807F7C80817C7A
827084818673897F837E7F797B738C83877475818E87797D85827382897784787A7D7C7C
7F7C807F7A817D8080817B7D84817E818379827F817E807E7C848180
7787727C7D888D8188887A768388787585767B707E82707C828D768881898F897D7F8280
81797D82797B867683827C827E7C7E8182827F7E7B83807E8081827B
7A8D8E84807980768D77827D837D7D79868E7E7B7A7E837E7F7F8376827D85728B7A8281
7E78828080828A727E89808180817D808182838183807F827E83807B
868677818A8784827785827B73798D847F798F857384847E7D8E798F8F83818E74818580
7B7B7F7B7E867286837E7E7F807C7C7E837D7D7D7C8281818281847D
81797D868E7183837B84827E737C8B8A828B7F7680717D7B7D7C737778778D777F7C7B7D
817D857E787A728583817C7F7F8177898185847C817F8283827A8379
8083808D76787586847381827D7983798984837B8C8F72828979887C8D798C837E7A7F81
85837A7B7875848F84837F807D7D8480817D7B7A7B8181837F7E817C
827F7E7A707A877C8884837E817D808C7B858270797D808080777982798B76797C887980
81858580817E857D83817D7982827C837B7E8580817F807F81818080
87887B8E8A787A7E7C8872847C787F8177857B8475847386807376757C7C837386808771
8576838278828A778484817D7D857C7F83797C80807D7F8483807D84
7C848371877C8085778779857F8A8185887D877A8D7777767A84847E7E7C798C8D7F8080
74818281807D877A837B7D7C7A857F8080807E7E8378848180857F84
7E878076718481837E857B8481807B85847481718F8D82728E7D77868080827C8A8F8984
8179837E80868D797C8B768187847A828786878476877F817A827A7B
788B7A8279747D87827D847E7B867984807E758C8F84738B80887B7878827E7C80807B80
7D88738E7A878174868A7D857E7E81877F7E847D80847F7F7D838176
7E81837581887F7E8283818186747985867C83728F817583758F85797E837A827F858177
8682877B76708A79827D808081807C7E7C817E7F837E7E82827E8379
85857883868D87867987827D8681867E88837B817C778888728E7B817F7E7F7B807C867F
7D8E8C82898989858583837E817E81827B8082817E808180867A827D
7B717E84857882897E7F8480807D728376818E7A7D8E7576718880807E7E7E8085867A7E
83768A7D8D757E7586867D7F807E807C7D807C81837E7A837C877C81
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7D6668887C83748687788782897A817E7A897A857D7F748181807F8880777B807F7E7E84
857D7F7B7C817D7E8482807D7D7E7E7C7D7E84817A8584857E7B7C81
7C8C7374988380897181818288858284847E7D7D8185817A83798279837D7786837D8181
7D7E7D86818285827F7E7E7D808377807B847982827C79808582817D
728C8A7C898B837678847C7F7A7F7C8482847C848383847F7D7C7E7D8181858382848679
837B857F8185807F7C857B7A827E83807C7F7F7E87837B7C8082807E
8B817B7F9A697F7B7C847D8584847F858281817A7B7C7A817D8084737D827F76827D7C7E
7E817E818483817D7D7F8381837B808281807D837E817B817B7D7E7E
8279827E816D947E798084867B7483827A7B7D8488838A7C7A7E8180818182817E7E817E
7B8284857B7B7E7F877F7F817C827F7D81847E7C7E7E7C8580848080
86807787716A7A8E787E7B84698A807E897C7B837A7E818982847D7F7F787C7B887C7D7D
7C897E837E7B81867C827F817F7B7E7E857E7B7F88807A7E7F7C7F81
76699079878C7F957F787C83816A8C787C76858B81807A827D7F828780807978817F8080
82857D7E817C7F807F7D847E7A7D838683808483877C7B817E81817F
858C7F827D80786B62847D7D9181877B7F83847E85797B8489827F797A80797D7F827A86
887C798083847C817F7D82827B867A797E8381827B7F80867F7C7F7E
7D8B78857B7D7B7F8F7D7B808179817F86857C7B7B7E7D7B7C7A7C83817F7F838085847C
7D7C818485797D827C807E82818189797E7C7D857F7783827B7F8283
837E877B8A7F8588698387808581808E7E7B7F817B728B7F867E85847E807F80827F8381
7B88817E7B807C7E7A7C81817C7A7F847D7E7E7E7F80758783847789
7C7D8B887C84827C7F6E9779848278837F8482797B877B79827B7E83807E84797F778385
7F7B8179827F7D8084817E80817B7A7881898381857888778082877A
7D856D748679817A80817E76827F7B6E7E808477778A8D838081747C8A807C8184807D7E
7D777A83837977857D7D87807C7F80878885827F787F7C7D79877D80
877D8890787E82808678807F7B817F7B746282887E7A84787D7C858A7B817C8285847D7D
808786817F7F82827B81828183817B7E858281807F7F817F7A7A7F7C
787F7A6D7885797A837B829A82857D897B7D767D87867F7D7D83807E7F827E7980838082
817A7F7F817F807880817E7E837F7D7E82828081808282817B888184
76887196808A7E807F847A7A8387797F8A7F857C8B8A85867D7D7C7E7C807C797D7C8582
817E847C83837D847C7D7E7F8581857D7B7D7C80817F847B7E807B7B
877C807881797D8480817F867B8A7F8684767C8B7E7E8081817B7C79837F7D807C787983
817A7D807B7D827E7F7B7C837E7A7D82818A7F7F8083817A827C7F79
76787B817F857C788A818B8280667D7D887882777C817F817E767D7C8183778079818280
807E858379817E807C837C7E807E807F877F8183807D808280837E80
807F817F867F7480857F7F7480736F917C838B83838777797E807F7E80818480857F827E
838C7D7D87877E7C7E827E808685817B7A77848283807B8381817B85
797E7E7685788386728B7B85808374617A837C7C7E7E7F80837D7A787D7D81847F7B7D7E
817F797A77857A7D807D857B8186807D7F7F80828080897C7D7A8481
778485737E777F8887818582797E8285837A727A7F80827F8485817E8882817E8577777F
81818382817D7E7E837E7C7E7D82837F787E81808189827C7981847E
877B85827B867A827E767C76827E7C7C60947985777C867C7D7D8381797F7F7E7C7E8382
757D847C7A857D827E7F83808281807E8980807F7C827E7B7F8D7C89
7F827F7F7F887B7D888B8A7D8C7B85817985877D7F7D7C8280807B81867F817F7D867E83
817E7D86847F787D857D7F868286797F857D7C7F7C797780787B837E
7C878980827F75827F7A798B7C838384799A807A7D8A7E7F7D847D7D8083817E7F7F817B
85807E82858285847F7D7C7D827F7786837B847D808783827F797E7D
7D828880797B7C878181877E88867E7D7D7363937989817D7E7780827D7E837D7C7C807E
7D817C80818383787D83857D827D807C7D7D867F807F808077857C82
7E7B7C79807C81807C887A7180787D7D84816B9C82787F837D7C817E8C7E7D80837C7982
7D7E7E7D818680837A7D817B82807F7D7F837C7B8182817E7F7F7C7F
7E8489757E7F7D7B8083768983848C827E8182838D7D818B85817D807B7D8082817D7D7C
84797D888180807E7E7E818282847F7F837E858185817E7A87808380
837D7E887F8379797A8677806E7C71777981827D6D8878778586817B807F7E7D7F807983
84818483807F817D817F81837F847A878083827E7E7587807F7C7A84
7E7F85837F7D7F827D84897F8F7E7B8E8982817E6D6F95777C7F7C807480807C7F7F887A
7F7D7A81827C7C8986817D8485847D84838780847B81817F85877F74
827F7B867B7D7F807E8A818681768A74727C8284816B87977F857E7F818085807B7C8486
7A7E867E7F8382807D797E7E7A7B857B7F82807E7C81817E7A7D8387
85817E7E827B837F83837F837A8880798F817D7F80847461917B83877B848179807E798B
8480817E7E7E85847F7C737F7D7D7B827F7F81818080848082878082
7B837D887D787A867D8A748482898B857A78807A7C7D81889B857687867B84808086817D
767F818383767F827B7D86837681807B7A8084827F85847C7A818081
809C7F887C82857B887A7A847D6E7178888278827F7E7D818F9590847A7C7D7C787A807D
857D7D80827F7C7C847C86797E7A79847C82868280858083857F8083
79837B7A8180827E91858D8281838B9186848B83818680847A9467897B7E83807F817E7D
7F8086807F8C86737A7E7C80787E8476807F7E7E878082877F7D8187
7D837D828278818F86738A79768183736A837E7880827E81807C9B63897D8080807D7F80
7E837A7C8782827A7D7A8986807B878580848381807A7984807A807C
818581867E80807E7C768C80788062747E877A827F81877F8080799664847D827F82827A
84808177937E8782808880807E7F82837A78818184777E8580868688
8B8C89857E8285837B77827F7F7B7B8887848C817885817C8180787D90638C8680818180
7C8478847982837686897C7F7C7F7A7C7D797E7A7F807B8388838380
7F8482798181777F89767B85867D837C81826C898A7E797F80827E7E809C65797C7B7D83
82807C768C85798877758679807E807C8289807C7B7F7B7D7D7D8083
6F7B7E8C80757A81728D828488797A85888691787E8081788781868080789F697F828C77
797D8680806C7E8571837A837E817D837C877E7F817E83828180827E
8679817876787D808B807C887B8083777E7E7D74798B787A8380798184796E6879847E7C
887D7D847E868A809083768C7A7B827C85937E827B8183867E797A83
7F837677827B837E7B838F6D6992897E83817D808975868F817C7D7F8289826C637F7E85
7D85787F837D77787D6E807087877D788278807F807E837E76777E7A
6F7287777F81838C8A95728D6D8B7C828A777A8A867784747A817F8483807F816B618A7F
748278848082897F7E7E9B82877E847C768381817C7E827F7B857E81
86888A82767C798A89777E85857B85827F857F76698A80878284787E81827D7D826E9B87
71858180827B81848578878D756C838B6E857E7B84748A8E7A7B817F
7E8280807D7D7E727E767D827F797C7775869189968D8C88828C85817E8180857C86699B
8C78827B8B7C81767A7F877C84807F7364807E7E868482817A7E8184
7981937F7D82817B8182727A847C727C8770627E7B756581847691827C7D7B80817B846E
646C7B8082897B7A797379888B778E988490867C7F75847B827A7E80
798483847D8E8B877D7F797E767E8A7D806A8F858577897D7D84757D80817D7E8487807F
78996383827E88837B9087798679787C82817C837D7D757C7F7D8282
7981867A869574847B847E7E8279808A698D7D7F86858D8987838480797A7C827C777F7F
7C7C85618A837D7B7F717E87808383847A7B867B84877E7F787B817C
83896F7398687E7689857F7F8075909F887A808A7E6F756F7083777C897E857E7E7A7F8C
83787D7874887C7F7D867D817D7C857173818C7F7E80837E837F8380
7C8F8484776D8589887B7C7F8B887F86777C87807F8281808F7F7E876F8981807E807E82
88827F8176877C80847C7F7B807A8A808183847B8085827B81808478
7F7A887C778582777D7876877B87768277757D877A80848C9F94787694747B87817E7B7D
7B827E8284749B97868276877D7C7780877C7887807C7C808580847D
897584768A7A888B8082817E858271798394897E8E8B8C796F727A887D88768481828B81
7E7A7F7D81797A80868086827F7F857C7F7A857F7A8082777C7F8180
817D758A758164957B8088788382858C7F717E756E9986847F786C798573817F797C827F
83827B8182827E897D80757E817E84807E80837A78807E7C7C837B7D
7C7F7E7179898A8F81777785887E6D7D7F7E6F85848C6D7F867F8372847E757B817C8184
80827F797E827E7E83807C7D7F7D837C8686827E83857E8280817E80
796D8281827F828D847C877A807C79867F767A788D7287827C7D8D96918A838578827F81
7E837F7E82828A8478837D7E867F807B807B8587827E7C8386807E7C
7A8979856C7075768C77757885877E777B80816C76838782817E866A717E817A9F6F8481
817C7F7B817B7D81837F8188827A7F857883877E817E7C7B837C837A
7A828574877E8076798D84818F808383808D80847B89808086868A8A716A6C88759B7482
8086797F807C857E858085797E8276867E7F847B7E7D7C817684787A
7E8E817B7D7D797D88767586778F7D7F82807A7E7E7F7988856F857F8A74736E87688C70
7E7E8483837E86867F7F817E8081877B93788280807E7F7D7F787F80
78808B79857E8A807F8C8A7E88797185896F838D7D897C857D8D797D80907D837D7D7985
847F7D81777B827B77857F807C80837F818679857E8281817F7E837A
8088757C8A837B7A80817F847571707F7D838383746A7A8076807F8381838C89867B8480
8A837D77747E7F807F7E7C8A7F7F817E7D80887983787E7E7D7B7F7B
7C7F7A6E8983817B84858D867F7E898178887986747E80868781887E827C7D8A83888089
7C8D8480837F827D7A81807F8C7E7E7E80807C827D837D827B817C78
8D8282877886858281827B7B88888C77837A847B7F86828C7D7F75817F7A7E7D7682837C
7D80888A7C7B807B8683847C79827E7D7C7F817D808884867F7E7E86
736E7C7E8C7F8A797A80858783796E75818485787A7F8375877D717F8D7D88857F768B8C
77877F7F8C846F7E7B8C87807F7A807D7D79797E88808A7D81858185
7B7F797B807E8C7E7D837F81817A777E81907D848C83717E7C8389777978767B7E8B6C77
76867D73837E807E80807F7C7F817A7E857D81817F807E7B82787F76
797D8C7D7A877E7986827D877B7886937D8E887D788F97897A787F7C89787F7B7F7F816A
80777C827F7B82897F7E7A87837D7D7F7F817F827B7F7F7E847D7E7B
81817C7B92737D7F87847E778589637B6E8083807883757E84807C947B7F8874858E747D
849C877785868E79827F837D817E837B7D7B77817B807686757C8185
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
828A888A7783898584807F817F817B7E7E7E7E7D837C7E83837B817F857C82837D7F7E7E
7F80817E7F81827C7F7F7C81837F7E7F7D807F7E7D817D7B80817F82
7D7B88788B7D84827A7C81837A827C7E808183817C857D7D8380837E828080817D7E7E7E
80807F7F7D7F7E7D7F817D81817C817D7C807E828180817E817D827F
83807F847889837B7F7F7B7C797480757D81777F7D8482867C80807C7F7D807C7D7E7E7F
7D7E80808181807E7D7E807E7F8283817E7E827F81807C7E7C81807E
7E86887B807E8B8787867B757372767372778E757C7B797D827B7B7E7D797A7A7F7C7E7D
80837F80827F817E7F7C807F7F7E7D7F7D7E817C817F837F7F81807F
8E747C7F83798E81858B86888882827F80828281827F7E817F817F7B807E7E82807C7F82
7C7F7D807C85807F807F7C7F7B8080807E827E848183807F807E7F80
778A82847D827E8A7D8380828A7D7B7F7E7F808184817D83817F7D7B7F817D7D84857F84
7D807C7E807E7F7D7F7E827E7D837D7F7F808081848081817A7D7E7D
868F86818987767183787C788072878281847D77807E827B7D837C80827A827D80817C7F
7E81817D807F7D7E7C7F7F7B817E7E7C7E857F7C807A828384848285
737C8A7E7B7E8E8D8D828481878D8A817F8387777E83827D80857F7E7C848283817E7F81
817A7E817F8A8084827E80807F7F817F7F80807D82807F7E7F7E7C7A
848B797F887B7C7A7B857D7E80808182847D8780807D807F80837E848081807E817E807D
817B80807F837F7F7E807E7F7F7D837F807F807F7D81837C7C787A7E
777D837D7B7E8181848B877F837B82817F7C7B848381807F82818082827F7E7F7F808282
83807F817D7E7D7F82837E7D7E7C7F82837D807E817C8C89868B8681
7D7B7D7F847E84847F858C818281847E84827F7B767B7B817F82807E817E807E80827C7F
827F807F7C8380817F7F807F7D7D80807F82858480817885888E797D
8282847B85877A72798F768D8D81867981817C7F7C79847F7D7E837E7F7F817E7F81807E
817E837C807C7F82817D807E7F7D807A7D7D7D7F817B80867F817F80
7B807D7D757C8586887A7674888D7D867E717582827E877F837D7F7F7D80817E7F807C81
837C8081827F7D7E80827E8183818084828182817F807F817E7E807D
85817E7C867A797D807372727270828482827E807E8583807B847E837E7C7F8180807E83
817F7C807E8081817C807D817E7D7E7D7B807F7C83808482847F8180
7F837D777D897D81817B8576747D7D7C847F7A7F7D858381857E7F7C7F7C7F807F7E8280
7F7F81827E7E82817D81817D7C7E7F807F7F817F80838080807F8080
7D808882827E828281837D828578897E817C837E7D7D85847E817F7F80837D7D807D817E
837C82827E807E80807F817F817E7D7E7F7D817D807D837D7D807F7E
7C7E8D7D817D807B7E787F81837D85807D857F7D81807B807C837E857D807F7E7F817D81
7F827F828283827B79807F807F83817E807E7E7E817E7D7F7F7F7E80
7F848E807D7F7E7A827F7C7C808373857B8682817D7F837F8280808182807C807F7D8083
827F837B7F81807E827C847F7F7B7E7D7C8283817D7E7F7D7E827E7F
89797E7C7F837E857E7E807D7F80847D827F85817F807F8184838181817D80827C857F7C
7E7F827F80807E817D827F80827F8182847F7F7E81807F81817B8181
77807F8282817D7D7F827E7C80807E7F797982798387887C7F7F807C80837A7E7E7E8281
817F7C7E8080807F82807B807E818081817C7C7C7C7F8280817E7C80
84828076807F7A80807B7E7D7E81808175867D7A817E8185817C8282817D7F8181807F7D
8181847E8281807E847D7F827E838184817F82808181817D80837C7F
80848179837D7C7F7F7F88817E7B7E828381887A7E7F7F7D81847E7D847B7D807D83817F
837D7C81807D7C8384837F807C7C81808381817F82807D817F7F817F
7E808D837E7D847C7F79777E837C827C807B877B82817F827E7E817D7E827E7D7E7F7E7F
81837F7D817C827D7D7D80807E808080807D8282807C7F7D7F7F7E81
7C7E807F7B7F828580807C867E847F818082758C7D7F83807F80807F7F7F808481827E81
7D7F81827E7E808284837D848080838381817C838184818382847F7F
817D8682817E807F797D78787E7D807D7F7E8578857C81827F8082817F7F7E807D7C8080
8081807E81807C827F827E8281807F7E7C80827F7B817F817D827E7D
75807F847B8078818180807C847E817E7E7F7F817B837F7983807B827F7E81837F817F7F
7E7F80827E8081787F7E83857E8084817F827D818181807F847E8080
887D80807D7F7C7F79807E867A83817E7E807F82798C7E7E827E847E7E7D7E81827D7C80
827E8180827F7F7F7E7F808081837B8080817E7E7F7D7D837E847E81
7D817E86808382817A7D7A817E838080827C818085728C798382807D7D7F7E7D7D7F817F
7F807D7F817F7E7F807E7D7D8581808582847C82807D7D807C80807C
847D83817F847F827B807E7D827A838081807F7D8084728B787C7E847B808080827C7F7C
8081807F81827E7E837D7B827C7D837E817F817F7F807D817F818284
7D807B7A857B7B7E7E82827F82817F7D798183847F7D82738B7A828180827D7F7D808380
837F7F7C7F818284838481837E7B7D817F7F7F837A82807F80828280
78847A7E857A7D7A7C8080867D817C828081817D80817D8276897D7F7F7C7F84827B8083
7D7F84817F7C7D7A7F7C7C7A7D7D807B7E827E7E8182807F7F80817F
7C727E837C868184847D7D7F7D81837F7D807E817D7B807F8079847E827F7F8181837F7E
817F7E7D7E7E81847D7E7A7B7D767F8284808582817B807F80817C83
837F7C7E82827C7B7F7C7E7C8180827D80837F8480807E7C827D77817E84807F827F827D
7D7E817E7E83827D848289767473857A797B7F8083807E7F7B7B8182
877D83807B80827D7A8984837A8480867B887F7E7F7E7D8180807C78867D837F82827E7E
7F827E817B7C8985747A7F7B807E718C7E83817D7F857F867C85847F
78848683798079847485848382807E85777D7E7C888282817F81817E7F8977817E818084
807F7C7E80777C7D7C787C7D7C7A768C81757E80807F837D7E807D81
76837E808880837E7D817C7E86847B7B7C7784817279787C807F7E807D79857B807D7E83
7D7F86827E877D7E8D8776828584877D8081827F837D7C80837C7C7C
8784837E7C7E7F7D817D7D81807E827D7E89897E84888B888580807E7F7F808281807B83
7B827676827B8B7C8E7E8C787D7C7E7D7F7E817F8082827E7F80807C
817F85818B7E7C86817E7E807D74817E7E70717982797C75797C7F82827C7C83797F7B80
897C81817C86747E817275817F80817F7E7F7D807D7F7E877E808080
7E7B827B7B838480827B828481878472738B827B818282807F84807E808182758A7D7D7E
857C847C7F777D897D748C748080797C7B7A78837E807B8182827D80
7C89817E7F848083857F82777E7B87807B7D807A82817C7F807E808382817D88718C807F
75837B828781837C7B7979707A778088828A8C867F7F7D818281807D
8E7B877C7B83827F81867B7B838D7E837D7F7F7F7D83837F82807F7D7F7F7F7E8671867D
7C7E81807A7F7C80847D7B7E81847F7D7B7E81807C7C7F7F7F797E7F
7C8179807D7B8081867C708F797D848282777B837F787F7D7D7C7E7E7F7F838282877077
79837E817E84808080807C7B7F717D7F8381707C83817E7E7C81817F
87837E84867F7E897E8C8A797986827C7B7F8579868180837B847D80807D7D7F81808689
717E7C8785787E7D867F838B8C7A8585797A83808180827F7F817D82
857B877C7C82877D7B897C84807C7F7E837279867E7B7D85837C80807A817C807C7F7C8B
8F8A807F838C7D79778081788F7C777A7F81817F7D7D8580817C827E
858282848380847F807B84797F7D828A868A8A8D7E85847F877D7F7F83817E827D7D807D
84777D827B80827F84787F7B827D7F7C8383817E7D7881807F7E7D84
807C8B8F7A8E837987837B7B807F85708F887B768282867E7D847B827B7F7D7E817C817E
7D7F7F72707E817E7C887E837C7F797B747C7C848B87818381808280
82828675777E8D7C7982838481837F7F757D7D7F7A847B787F82827C827D7E817D81817F
7C807D83708B777D7D7F7F797D7E80888388817C767B817F7E7D807C
7F837E848D7B777E817C838681857989728C7C81818477827E7E7F8178838180837E837F
817D8080878E767F797E7F877D86807A78737C7A847E7E80837F827E
827E7B808A8383797D80808181848A7E807A827E7B7D8A81847A837F817F7F857E837E80
82827D828085777F7E77837B807C7880807F8281807E807C807C827C
7D7B838A8E748683818080858082797E8184887E7E7084787A827884847B817C7E7E807F
7F7F817F818581858986867F7F82837A7D80847D7F817F827F817F7D
85797D7F78827284748080857B827A867E7D7C8082758C8377867D75828877887C837B80
7E7E807E7F7D847E887775817A817F7F807F8180817F7F837F827E80
7A828178817C7087897B858380807F7B827D79757B85787E8382808C8587827D857F817D
8381817F8282847E7B84837F83847B827D837C80808280807F807F7F
8C70777E7D84718A788184877E7E847F7F7E83857A7B85827C818179748180867D807F82
827E7E80827C7A7B837C8080817A83807E7F807E807D818182818080
7F827F808678847B85868275847E7F7E7C7F7B80877F837F807E7F82807E857F7F807F7F
7F7F827F80807F7F827F8080818276817F80827F7F7D807E80838281
7A7C7F837F7D808070817E837B7A83827E7D7E7C7B817789878C7D8481837A8783807D83
80807D7D7E8083827F80807E807E8379837F7F81807F808182817C7F
7F7E807C8080897C868079817F7E7D7D817F887D777F8973888683867D82817E7E817D82
8082817B827F81818183807F817F7F8381837F7E82817E847C7F8182
78827D7C857F808076817880858482837D7C7E8787777B868C898988827E867B827E877A
857D7E80847F8181857B7D857E7F83817E8283817B8081827D7D7F7E
858E827F7E7A7D838580847E7A7D7B82817F827F7F75837D7E7D7D80827D788D7B807E80
75868080807B7F7F7C7E827E7D7F7F7E817E7D7E837C7E8180817E80
8A8A778081837F7F837C817E807F84837E83818281827982837F7D7D817E807B8B76847F
8178817F8183807C85867E8382807B807F81827D7B8D7E828380817F
878680777E7D7B827E7F7D7E7B82807E7A807F857D7C82757A7983888F867B827F837881
857F77837E7D8084787F7E807C808086807F7D7D837685807E7E7D7F
808B7C84837986817989838180787F7D84797A857F8583817F807D707F72837D807D8774
828083758C7E897C83817F7D817F858380828181837F7F7D837E8081
828E81798080857E82807B86847F79877A7B8482817C7D7A7E718373737E8182827B8284
7B7B7A8474837979817E83807F807D7D8185807F7E7F827F82817A7B
867A83868A7F767C7E838081877F8D7A7B7B817F8484837E78827E7C788087847F7E8188
80818180867682837F7F8080807F828280817D7F84847F8080818084
717C70768E788E797478837A7587868786877C807E8173858B7D827F7F867D787C817A80
89787C8E7D70857F898981848486807F84787F7E7F7E837D82797C78
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf0002P38h=P208R8R080MgMg0P1lO7`2079bLP80O7al0P27QhL2075aL@@0
Ph>30P28R8P207EeM@80NGUi0P1bLW820861P@80MGEe0P22PX8308B4Q080OWin0P2>SXh208B4Q080
OWin0P2:RXX207EeM@80O7al0P23Ph<208F5Q@80MgMg0P21PH4407alO080P8200P24Q8@40820P080
PH610P20P80207inOP80QXJ60P23Ph<208:2PP80PH610P20P80208>3P`80OWin0P23Ph<20861P@80
OGem0P21PH4307inOP80Q8B40P1mOGd208>3P`80Ogmo0P1lO7`208>3P`80PH610P23Ph<20861P@80
OWin0P20P80208V9R@80NWYj0P1mOGd2075aL@H0b>3H0P1mOGd206IVIP80J6QX0P28R8P207alO080
Ph>30P1dM7@208J6QP80QhN70P1hN7P208N7Q`80PX:20P29RHT207YjNP80PH610P1nOWh307YjNP80
RHV90P1jNWX208F5Q@80OGem0P1oOgl207AdM0@0PH610P20P80207moO`80R8R80P20P80207MgM`80
Ng]k0P20P80207moO`@0OWin0P24Q8@208F5Q@80OGem0P1oOgl207]kN`80O7al0P21PH4207emO@80
OWin0P24Q8@208:2PP80P8201@1mOGd407inOP80O7al0P1mOGd207inOP80Q8B40P21PH4207YjNP80
QHF50P24Q8@208F5Q@80OWin0P1kNg/207alO080PH613038h=P000X0b>3H0P28R8P207MgM`80O7al
0P1bLW8207alO080QhN70P1aLG4408>3P`80R8R80P1eMGD207UiN@80LW9b0P21PH4207EeM@80PX:2
0`24Q8@207inOP80SXj>0P24Q8@207inOP80RXZ:0P1eMGD207alO080Ph>30P25QHD207MgM`80PH61
101lO7`20820P080Q8B41020P8020861P@80P8200P1nOWh208J6QP80Ph>30P22PX820861P@80P820
0P23Ph<207inOP80Ph>30P21PH4207emO@80PH610`1nOWh208B4Q080OGem0P23Ph<207moO`80O7al
0P23Ph<20861P@80Ph>30P21PH4207inOP80P8200P29RHT207YjNP80OGem0P1aLG460<SPf080OGem
0P1VIVH206QXJ080R8R80P1lO7`208>3P`80M7Ad0P26QXH208N7Q`80N7Qh0P27QhL208:2PP80RHV9
0P1jNWX20861P@80OWin0`1jNWX208V9R@80NWYj0P25QHD207emO@80Ogmo0P1dM7@40861P@80P820
0P1oOgl208R8R080P8200P1gMgL207]kN`80P8200P1oOgl407inOP80Q8B40P25QHD207emO@80Ogmo
0P1kNg/207alO080PH610P1mOGd207inOP80Q8B40P22PX820820P0D0OGem101nOWh207alO080OGem
0P1nOWh208B4Q080PH610P1jNWX208F5Q@80Q8B40P25QHD207inOP80Ng]k0P1lO7`20861P@`0b>3H
000:0<SPf080Ogmo0P2?Shl207QhN080QHF50P1fMWH208>3P`80P8200P1oOgl408F5Q@80NWYj0P26
QXH207=cL`80LG5a0P25QHD208Z:RP<0NGUi0P1mOGd208b<S080SHf=0P1oOgl207alO080SHf=0P21
PH4208>3P`80Ng]k0P21PH420820P080OWin0P21PH4207emO@80PX:20P1mOGd207YjNP80PX:20P1o
Ogl208>3P`H0PX:20P24Q8@207emO@80Ogmo0P1mOGd207YjNP80PX:20P1oOgl20820P0<0O7al0P21
PH420820P080QXJ60P1nOWh408B4Q080P8200P1mOGd208:2PP80PH610P1lO7`208N7Q`80N7Qh0P22
PX8208R8R0H0b>3H0P1lO7`208b<S080Lg=c0P1dM7@209RHV080Ph>30P20P80208V9R@80LG5a1021
PH4208:2PP80R8R80P25QHD208:2PPD0Q8B40P1nOWh407emO@80PH610P25QHD20861P@80NWYj0P23
Ph<207UiN@80PX:20P1iNGT208>3P`80OGem0P1gMgL208J6QP80Ph>30P1mOGd40861P@80OGem0P1n
OWh207emO@80QXJ60P21PH4208:2PP80QHF50P22PX8207moO`@0OWin0P1mOGd30820P080Ph>30P1g
MgL20820P080Ng]k0P24Q8@207UiN@@0PX:20P1lO7`207UiN@80P8200P25QHD208:2PP80PH610P1m
OGd<0<SPf0002P38h=P207moO`80Shn?0P1hN7P208F5Q@80MWIf0P23Ph<20820P080Ogmo1025QHD2
07YjNP80QXJ60P1cLg<2075aL@80QHF50P2:RXX307UiN@80OGem0P2<S8`208f=S@80Ogmo0P1lO7`2
08f=S@80PH610P23Ph<207]kN`80PH610P20P80207inOP80PH610P1mOGd208:2PP80OGem0P1jNWX2
08:2PP80Ogmo0P23Ph<608:2PP80Q8B40P1mOGd207moO`80OGem0P1jNWX208:2PP80Ogmo0P20P803
07alO080PH610P20P80208J6QP80OWin1024Q8@20820P080OGem0P22PX820861P@80O7al0P27QhL2
07QhN080PX:20P28R8P60<SPf080O7al0P2<S8`207=cL`80M7Ad0P2HV9P208>3P`80P8200P29RHT2
075aL@@0PH610P22PX8208R8R080QHF50P22PX8508B4Q080OWin101mOGd20861P@80QHF50P21PH42
07YjNP80Ph>30P1iNGT208:2PP80NGUi0P23Ph<207emO@80MgMg0P26QXH208>3P`80OGem1021PH42
07emO@80OWin0P1mOGd208J6QP80PH610P22PX8208F5Q@80PX:20P1oOgl407inOP80OGem0`20P802
08>3P`80MgMg0P20P80207]kN`80Q8B40P1iNGT408:2PP80O7al0P1iNGT20820P080QHF50P22PX82
0861P@80OGem3038h=P000X0b>3H0P24Q8@20861P@80LW9b0P24Q8@207MgM`80OGem0P21PH4207al
O080P8200P21PH4207]kN`80P8200P1mOGd208f=S@80QXJ60P21PH4307]kN`80PH610P2<S8`20861
P@80O7al0P2;Rh/207alO0@0P8201021PH4207]kN`80Ogmo0P1kNg/40861P@@0O7al0P1nOWh207]k
N`80PX:20P1jNWX208:2PP80Ph>30P22PX8207emO@80O7al0P1kNg/207moO`80PH610P1oOgl20820
P0<0Ng]k0P20P80207alO0@0PH611022PX8207inOP80Q8B40P20P80207alO080NGUi0P26QXH207Ui
N@80OWin0P2=SHd60<SPf080LW9b0P2<S8`208Z:RP80O7al0P29RHT208^;R`80Ph>30P1fMWH207Qh
N080Q8B40P1lO7`207moO`80NWYj0P1oOgl207alO080Q8B40`22PX8208B4Q080O7al0P24Q8@408>3
P`80Q8B40P1oOgl207emO@80O7al0P1nOWh207emO@@0PH610P25QHD208>3P`80PX:20P24Q8@208J6
QP80NGUi0P23Ph<207]kN`80QHF50P1oOgl20861P@80QHF50P20P80207moO`80O7al0P25QHD207]k
N`80NWYj0`22PX8207inOP80Ph>30P20P80207alO0@0Ogmo0P1nOWh208N7Q`80Ph>30P1kNg/207al
O080P8200P22PX820820P080OWin3038h=P000X0b>3H0P24Q8@20861P@80LW9b0P24Q8@207MgM`80
OGem0P21PH4207alO080P8200P21PH4207]kN`80P8200P1mOGd208f=S@80QXJ60P21PH4307]kN`80
PH610P2<S8`20861P@80O7al0P2;Rh/207alO0@0P8201021PH4207]kN`80Ogmo0P1kNg/40861P@@0
O7al0P1nOWh207]kN`80PX:20P1jNWX208:2PP80Ph>30P22PX8207emO@80O7al0P1kNg/207moO`80
PH610P1oOgl20820P0<0Ng]k0P20P80207alO0@0PH611022PX8207inOP80Q8B40P20P80207alO080
NGUi0P26QXH207UiN@80OWin0P2=SHd60<SPf080LW9b0P2<S8`208Z:RP80O7al0P29RHT208^;R`80
Ph>30P1fMWH207QhN080Q8B40P1lO7`207moO`80NWYj0P1oOgl207alO080Q8B40`22PX8208B4Q080
O7al0P24Q8@408>3P`80Q8B40P1oOgl207emO@80O7al0P1nOWh207emO@@0PH610P25QHD208>3P`80
PX:20P24Q8@208J6QP80NGUi0P23Ph<207]kN`80QHF50P1oOgl20861P@80QHF50P20P80207moO`80
O7al0P25QHD207]kN`80NWYj0`22PX8207inOP80Ph>30P20P80207alO0@0Ogmo0P1nOWh208N7Q`80
Ph>30P1kNg/207alO080P8200P22PX820820P080OWin3038h=P000X0b>3H0P1`L70207inOP80SXj>
0P1`L70207YjNP80Q8B40P27QhL407YjNP80PX:20P1mOGd20861P@80NWYj0P1dM7@208:2PP80QXJ6
0`1mOGd207UiN@80Lg=c0P2<S8`208:2PP80MGEe0P1mOGd208>3P`80Ogmo1022PX8207UiN@@0Ogmo
0P23Ph<207moO`80O7al1021PH4207UiN@@0OWin0P21PH4207moO`80PH610P1kNg/207emO@H0PH61
0P1nOWh208>3P`<0NWYj0P1oOgl207inOP80PH610P20P80207]kN`80PH610P20P80207inOP80Ogmo
0P20P80208:2PP80P820101mOGd208^;R`H0b>3H0P2;Rh/20861P@80Ng]k0P1oOgl209ZJVP80JFUY
0P1oOgl207]kN`80O7al0P24Q8@207emO@80QHF51024Q8@207moO`80QHF50`22PX840861P@80NWYj
0P1kNg/207alO080NWYj0P21PH4207emO@80P8200P24Q8@207=cL`80OGem0P22PX8207moO`80MWIf
0P22PX8207emO@80O7al101nOWh20861P@80OWin0P21PH4208B4Q080Ph>30P21PH4407emO@80Ogmo
0P23Ph<20861P@<0Ph>30P1kNg/20820P080PX:20P21PH420820P080OGem0P23Ph<207inOP80PH61
0P1kNg/20861P@80Ng]k0P1mOGd407inOP`0b>3H000:0<SPf080L71`0P1nOWh208j>SP80L71`0P1j
NWX208B4Q080QhN7101jNWX208:2PP80OGem0P21PH4207YjNP80M7Ad0P22PX8208J6QP<0OGem0P1i
NGT207=cL`80S8b<0P22PX8207EeM@80OGem0P23Ph<207moO`@0PX:20P1iNGT407moO`80Ph>30P1o
Ogl207alO0@0PH610P1iNGT407inOP80PH610P1oOgl20861P@80Ng]k0P1mOGd60861P@80OWin0P23
Ph<307YjNP80Ogmo0P1nOWh20861P@80P8200P1kNg/20861P@80P8200P1nOWh207moO`80P8200P22
PX820820P0@0OGem0P2;Rh/60<SPf080Rh^;0P21PH4207]kN`80Ogmo0P2JVYX206UYJ@80Ogmo0P1k
Ng/207alO080Q8B40P1mOGd208F5Q@@0Q8B40P1oOgl208F5Q@<0PX:21021PH4207YjNP80Ng]k0P1l
O7`207YjNP80PH610P1mOGd20820P080Q8B40P1cLg<207emO@80PX:20P1oOgl207IfMP80PX:20P1m
OGd207alO0@0OWin0P21PH4207inOP80PH610P24Q8@208>3P`80PH61101mOGd207moO`80Ph>30P21
PH4308>3P`80Ng]k0P20P80208:2PP80PH610P20P80207emO@80Ph>30P1nOWh20861P@80Ng]k0P21
PH4207]kN`80OGem101nOWh<0<SPf0002P38h=P207IfMP80R8R80P22PX82071`L080N7Qh0P23Ph<2
07QhN080P8200P1lO7`207emO@80O7al0P1kNg/208N7Q`80O7al0P1oOgl208B4Q0<0N7Qh0P1iNGT2
079bLP80MGEe0P1dM7@208Z:RP80N7Qh1P21PH4208>3P`80Ng]k0P1mOGd20861P@80O7al0P1oOgl2
0861P@80OGem0P23Ph<207alO080OWin0P21PH4207moO`80PH610P20P80207emO@@0Ng]k0P1mOGd2
0820P080Ogmo0P21PH4308>3P`@0PH610P1nOWh208:2PP80P8200P21PH4208:2PP80OWin101oOgl2
07inOP80Q8B40P1mOGd207UiN@80M7Ad1P38h=P208:2PP80NGUi0P22PX8207inOP80PH610P1]KFd2
09BDU080OWin0P1iNGT20820P080Q8B40P26QXH207]kN`80M7Ad0P23Ph<208:2PP<0NWYj0P1kNg/2
07emO@80Q8B40P28R8P208>3P`80RXZ:0P1lO7`207YjNP80OWin0P21PH420820P0@0PH610P22PX82
0861P@@0OWin0P21PH4207inOP80Ng]k0P22PX8208B4Q080QHF5101kNg/207inOP80Ogmo0P27QhL4
07moO`80PH610`1lO7`208:2PP80Ogmo0P1mOGd20861P@80Q8B40P1nOWh207alO0@0OWin0P1lO7`2
08F5Q@80P8200P24Q8@40820P0`0b>3H000:0<SPf080MWIf0P28R8P208:2PP80L71`0P1hN7P208>3
P`80N7Qh0P20P80207alO080OGem0P1lO7`207]kN`80QhN70P1lO7`207moO`80Q8B40`1hN7P207Ui
N@80LW9b0P1eMGD207AdM080RXZ:0P1hN7P60861P@80Ph>30P1kNg/207emO@80PH610P1lO7`207mo
O`80PH610P1mOGd208>3P`80O7al0P1nOWh20861P@80Ogmo0P21PH420820P080OGem101kNg/207em
O@80P8200P1oOgl20861P@<0Ph>31021PH4207inOP80PX:20P20P8020861P@80PX:20P1nOWh407mo
O`80OWin0P24Q8@207emO@80NGUi0P1dM7@60<SPf080PX:20P1iNGT208:2PP80OWin0P21PH4206e]
K@80U9BD0P1nOWh207UiN@80P8200P24Q8@208J6QP80Ng]k0P1dM7@208>3P`80PX:20`1jNWX207]k
N`80OGem0P24Q8@208R8R080Ph>30P2:RXX207alO080NWYj0P1nOWh20861P@80P8201021PH4208:2
PP80PH61101nOWh20861P@80OWin0P1kNg/208:2PP80Q8B40P25QHD407]kN`80OWin0P1oOgl208N7
Q`@0Ogmo0P21PH4307alO080PX:20P1oOgl207emO@80PH610P24Q8@207inOP80O7al101nOWh207al
O080QHF50P20P80208B4Q0@0P8203038h=P000X0b>3H0P24Q8@208b<S080PX:20P1oOgl208Z:RP80
QHF50P28R8P207EeM@80PH610P20P80208B4Q080P8200P25QHD20820P080Q8B40P23Ph<307moO`80
O7al0P1cLg<207QhN080NGUi0P29RHT407]kN`80P8200P1nOWh20820P080Ogmo0P21PH420820P080
Ogmo0P1lO7`20820P080PX:20P1jNWX207inOP80Ph>30P21PH420820P080Ogmo0P23Ph<207alO0@0
OWin0P1oOgl407emO@80PH610`1kNg/207moO`80PX:21021PH4208B4Q080OWin0P21PH4208B4Q080
P8200P1mOGd207inOP80PX:20P25QHD207EeM@80Rh^;1P38h=P208J6QP80P8200P1gMgL208N7Q`80
LG5a0P1ZJVX207YjNP80SXj>0P1hN7P207inOP80Ng]k0P24Q8@206UYJ@80RXZ:0P20P80207inOP<0
RHV90P1lO7`207]kN`80Ph>30P1jNWX207inOP80PH610P29RHT208:2PP80Q8B40P1mOGd407moO`80
N7Qh0P1lO7`207]kN`80R8R80P1lO7`407emO@80O7al0P29RHT207inOP80Ph>30P1nOWh207]kN`80
PH610P26QXH207alO080PX:20P1oOgl20861P@<0Ogmo0P1kNg/407inOP80QHF50P1nOWh207]kN`80
Ogmo0P28R8P20820P080NWYj0P1nOWh207moO`80O7al0P1oOgl20861P@`0b>3H000:0<SPf080Q8B4
0P2<S8`208:2PP80Ogmo0P2:RXX208F5Q@80R8R80P1eMGD20861P@80P8200P24Q8@20820P080QHF5
0P20P80208B4Q080Ph>30`1oOgl207alO080Lg=c0P1hN7P207UiN@80RHV9101kNg/20820P080OWin
0P20P80207moO`80PH610P20P80207moO`80O7al0P20P80208:2PP80NWYj0P1nOWh208>3P`80PH61
0P20P80207moO`80Ph>30P1lO7`407inOP80Ogmo101mOGd20861P@<0Ng]k0P1oOgl208:2PP@0PH61
0P24Q8@207inOP80PH610P24Q8@20820P080OGem0P1nOWh208:2PP80QHF50P1eMGD208^;R`H0b>3H
0P26QXH20820P080MgMg0P27QhL2075aL@80JVYZ0P1jNWX208j>SP80N7Qh0P1nOWh207]kN`80Q8B4
0P1YJFT208Z:RP80P8200P1nOWh308V9R@80O7al0P1kNg/208>3P`80NWYj0P1nOWh20861P@80RHV9
0P22PX8208B4Q080OGem101oOgl207QhN080O7al0P1kNg/208R8R080O7al101mOGd207alO080RHV9
0P1nOWh208>3P`80OWin0P1kNg/20861P@80QXJ60P1lO7`208:2PP80Ogmo0P21PH4307moO`80Ng]k
101nOWh208F5Q@80OWin0P1kNg/207moO`80R8R80P20P80207YjNP80OWin0P1oOgl207alO080Ogmo
0P21PH4<0<SPf0002P38h=P208V9R@80Lg=c0P22PX8207UiN@80R8R80P1fMWH207inOP80NGUi0P1j
NWX208B4Q080PH610P1oOgl208J6QP80QhN70P1kNg/208B4Q0<0Ph>3101iNGT207QhN080M7Ad0P2?
Shl40820P080Ogmo0P1nOWh208B4Q080PH610P1nOWh20861P@80OWin0P22PX8207emO@80Q8B40P1n
OWh20861P@80Q8B40P1oOgl407emO@@0P8200P23Ph<207UiN@80PH610P22PX8207inOP80P8200`21
PH4207emO@80Ph>30P22PX8207inOP80NWYj0P22PX8208>3P`80OWin0P22PX8207QhN080P8200P22
PX8208B4Q080OGem0P1lO7`60<SPf080MWIf0P1YJFT2092@T080NGUi0P27QhL208b<S080Ogmo0P2E
UID207moO`80N7Qh0P1lO7`208>3P`80PH610P1ZJVX208b<S080N7Qh0`1lO7`207IfMP80QHF50P2;
Rh/20861P@80P8200P1jNWX208:2PP80OGem0P1oOgl208:2PP80QhN71020P80207UiN@80N7Qh0P21
PH4207moO`@0P8200P22PX8208F5Q@80OGem0P1nOWh20861P@80O7al0P1oOgl20820P080Ogmo0P1m
OGd208B4Q080OWin0`1jNWX207emO@80Ph>30P26QXH208>3P`80P8200P24Q8@208>3P`80QhN70P1l
O7`207]kN`80PH610P1nOWh40861P@80Ogmo3038h=P000X0b>3H0P29RHT207=cL`80PX:20P1iNGT2
08R8R080MWIf0P1nOWh207UiN@80NWYj0P24Q8@20861P@80Ogmo0P26QXH208N7Q`80Ng]k0P24Q8@3
08>3P`@0NGUi0P1hN7P207AdM080Shn?1020P80207moO`80OWin0P24Q8@20861P@80OWin0P21PH42
07inOP80PX:20P1mOGd208B4Q080OWin0P21PH4208B4Q080Ogmo101mOGd40820P080Ph>30P1iNGT2
0861P@80PX:20P1nOWh20820P0<0PH610P1mOGd208>3P`80PX:20P1nOWh207YjNP80PX:20P23Ph<2
07inOP80PX:20P1hN7P20820P080PX:20P24Q8@207emO@80O7al1P38h=P207IfMP80JFUY0P2@T902
07UiN@80QhN70P2<S8`207moO`80UIFE0P1oOgl207QhN080O7al0P23Ph<20861P@80JVYZ0P2<S8`2
07QhN0<0O7al0P1fMWH208F5Q@80Rh^;0P21PH420820P080NWYj0P22PX8207emO@80Ogmo0P22PX82
08N7Q`@0P8200P1iNGT207QhN080PH610P1oOgl40820P080PX:20P25QHD207emO@80OWin0P21PH42
07alO080Ogmo0P20P80207moO`80OGem0P24Q8@207inOP<0NWYj0P1mOGd208>3P`80QXJ60P23Ph<2
0820P080Q8B40P23Ph<208N7Q`80O7al0P1kNg/20861P@80OWin1021PH4207moO``0b>3H000:0<SP
f080OWin0P2<S8`207MgM`80OWin0P28R8P207inOP80Rh^;0P1bLW820820P0@0Ogmo0P23Ph<20861
P@@0QhN70P1oOgl308^;R`80MWIf0P1hN7P207IfMP80Q8B40P23Ph<207emO@80Ng]k101oOgl208:2
PP@0P8200P1oOgl207]kN`80OWin0P1lO7`207moO`80NWYj0P1oOgl207emO@80OWin0P1kNg/207in
OP80Ng]k0P1lO7`208B4Q080O7al0P25QHD208>3P`80Ogmo0P20P80307YjNPP0Ogmo0P22PX8207em
O@@0OWin0P21PH4207emO@80PH610P23Ph<207moO`80OWin0P1kNg/60<SPf080QHF50P2<S8`207mo
O`80PX:20P1mOGd20820P080N7Qh0P1[Jf/2069RHP80Q8B4101mOGd2096AT@80PH610P27QhL207]k
N`<0Ogmo0P23Ph<208B4Q080OWin0P25QHD207UiN@80Ng]k0P24Q8@208V9R@80PX:20P1oOgl207Ui
N@80NWYj0P20P80207UiN@80OGem0P1oOgl208:2PP80NWYj0P26QXH208R8R080O7al0P1iNGT20820
P080Ph>30P24Q8@207alO080PH610P1oOgl207emO@@0PX:20`1kNg/208J6QP80NWYj0P1iNGT207in
OP80Ph>30P21PH4208:2PP80Ng]k0P1oOgl20820P080QXJ60P1oOgl207alO080Ogmo0P1nOWh<0<SP
f0002P38h=P207inOP80S8b<0P1gMgL207inOP80R8R80P1nOWh208^;R`80LW9b0P20P80407moO`80
Ph>30P21PH4408N7Q`80Ogmo0`2;Rh/207IfMP80N7Qh0P1fMWH208B4Q080Ph>30P1mOGd207]kN`@0
Ogmo0P22PX840820P080Ogmo0P1kNg/207inOP80O7al0P1oOgl207YjNP80Ogmo0P1mOGd207inOP80
Ng]k0P1nOWh207]kN`80O7al0P24Q8@207alO080QHF50P23Ph<207moO`80P8200`1jNWX807moO`80
PX:20P1mOGd407inOP80PH610P1mOGd20861P@80Ph>30P1oOgl207inOP80Ng]k1P38h=P208F5Q@80
S8b<0P1oOgl208:2PP80OGem0P20P80207QhN080Jf][0P1RHV8208B4Q0@0OGem0P2ATI420861P@80
QhN70P1kNg/307moO`80Ph>30P24Q8@207inOP80QHF50P1iNGT207]kN`80Q8B40P29RHT208:2PP80
Ogmo0P1iNGT207YjNP80P8200P1iNGT207emO@80Ogmo0P22PX8207YjNP80QXJ60P28R8P207alO080
NGUi0P20P80208>3P`80Q8B40P1lO7`20861P@80Ogmo0P1mOGd408:2PP<0Ng]k0P26QXH207YjNP80
NGUi0P1nOWh208>3P`80PH610P22PX8207]kN`80Ogmo0P20P80208J6QP80Ogmo0P1lO7`207moO`80
OWin3038h=P000X0b>3H0P1gMgL207emO@80Rh^;0P1nOWh207alO0@0PX:20P1mOGd208^;R`80O7al
0P1nOWh20820P080Ogmo0P1iNGT20820P080PH610`28R8P207emO@80NWYj0P1lO7`207UiN@80P820
0P1hN7P208>3P`80Ng]k0P25QHD208B4Q0@0OWin1022PX8207inOP80O7al0P21PH4207moO`80PH61
0P23Ph<20861P@80Ogmo0P21PH4207moO`80NGUi0P21PH4207alO080PH610P22PX8207emO@80O7al
1@1oOgl20861P@80OWin0P1oOgl208>3P`80Q8B40P21PH4207moO`80Q8B41021PH4207alO080Ogmo
101nOWh60<SPf080OGem0P2;Rh/207QhN080QHF50P1kNg/207emO@80Ng]k0P1oOgl208n?S`80OGem
0P1kNg/20820P080PH610P1iNGT20861P@80Ogmo0`26QXH208F5Q@80O7al101kNg/207inOP80OGem
0P1kNg/207alO080NWYj0P1lO7`208>3P`80PH61101oOgl208>3P`80P8200P25QHD208B4Q080O7al
0P1mOGd207alO080PH610P24Q8@208F5Q@80NGUi0P1mOGd208:2PP80O7al0P20P80207inOP80PX:2
1@21PH4208V9R@80NGUi0P1nOWh207alO080OGem0P25QHD207moO`80MgMg0P23Ph<208:2PP80Ng]k
0P1oOgl208:2PP80Ph>33038h=P000X0b>3H0P1gMgL207emO@80Rh^;0P1nOWh207alO0@0PX:20P1m
OGd208^;R`80O7al0P1nOWh20820P080Ogmo0P1iNGT20820P080PH610`28R8P207emO@80NWYj0P1l
O7`207UiN@80P8200P1hN7P208>3P`80Ng]k0P25QHD208B4Q0@0OWin1022PX8207inOP80O7al0P21
PH4207moO`80PH610P23Ph<20861P@80Ogmo0P21PH4207moO`80NGUi0P21PH4207alO080PH610P22
PX8207emO@80O7al1@1oOgl20861P@80OWin0P1oOgl208>3P`80Q8B40P21PH4207moO`80Q8B41021
PH4207alO080Ogmo101nOWh60<SPf080OGem0P2;Rh/207QhN080QHF50P1kNg/207emO@80Ng]k0P1o
Ogl208n?S`80OGem0P1kNg/20820P080PH610P1iNGT20861P@80Ogmo0`26QXH208F5Q@80O7al101k
Ng/207inOP80OGem0P1kNg/207alO080NWYj0P1lO7`208>3P`80PH61101oOgl208>3P`80P8200P25
QHD208B4Q080O7al0P1mOGd207alO080PH610P24Q8@208F5Q@80NGUi0P1mOGd208:2PP80O7al0P20
P80207inOP80PX:21@21PH4208V9R@80NGUi0P1nOWh207alO080OGem0P25QHD207moO`80MgMg0P23
Ph<208:2PP80Ng]k0P1oOgl208:2PP80Ph>33038h=P000X0b>3H0P1lO7`207moO`80L71`0P23Ph<2
08J6QP80S8b<0P1oOgl408F5Q@80RXZ:0P1oOgl20861P@80P8200P21PH4208F5Q@80Ogmo0`20P802
07emO@80M7Ad0P1lO7`207AdM080Ogmo0P1mOGd20861P@80P820101nOWh208>3P`H0P8200P21PH42
07emO@80P820101mOGd20820P080NWYj0P1kNg/207moO`80PX:20P1oOgl208>3P`80O7al0P21PH42
08:2PP80Ph>30P20P80307moO`80PH610P24Q8@207emO@80Ogmo0P20P80208:2PP80P8200P23Ph<2
07QhN080PH610P25QHD408:2PP80Ph>30P1gMgL60<SPf080Ph>30P1nOWh208N7Q`80Ng]k0P2:RXX2
07moO`80QHF50P28R8P206UYJ@80Ph>30P27QhL20820P080QHF50P21PH420820P080SXj>0`1nOWh2
07]kN`80Ogmo0P21PH4207]kN`80LW9b0P2;Rh/207moO`80QXJ60P1nOWh208F5Q@80Q8B40P1nOWh2
0820P080Ogmo0P20P80208:2PP80Ogmo0P23Ph<20861P@80Ng]k0P28R8P20861P@80OWin0P1kNg/2
0820P080O7al0P1nOWh207YjNP80O7al1021PH4307alO080NWYj0P1oOgl208B4Q080OGem1P1nOWh2
07moO`80P8200P1eMGD208N7Q`80Ph>30P24Q8@207MgM`80RHV93038h=P000X0b>3H0P1lO7`207mo
O`80L71`0P23Ph<208J6QP80S8b<0P1oOgl408F5Q@80RXZ:0P1oOgl20861P@80P8200P21PH4208F5
Q@80Ogmo0`20P80207emO@80M7Ad0P1lO7`207AdM080Ogmo0P1mOGd20861P@80P820101nOWh208>3
P`H0P8200P21PH4207emO@80P820101mOGd20820P080NWYj0P1kNg/207moO`80PX:20P1oOgl208>3
P`80O7al0P21PH4208:2PP80Ph>30P20P80307moO`80PH610P24Q8@207emO@80Ogmo0P20P80208:2
PP80P8200P23Ph<207QhN080PH610P25QHD408:2PP80Ph>30P1gMgL60<SPf080Ph>30P1nOWh208N7
Q`80Ng]k0P2:RXX207moO`80QHF50P28R8P206UYJ@80Ph>30P27QhL20820P080QHF50P21PH420820
P080SXj>0`1nOWh207]kN`80Ogmo0P21PH4207]kN`80LW9b0P2;Rh/207moO`80QXJ60P1nOWh208F5
Q@80Q8B40P1nOWh20820P080Ogmo0P20P80208:2PP80Ogmo0P23Ph<20861P@80Ng]k0P28R8P20861
P@80OWin0P1kNg/20820P080O7al0P1nOWh207YjNP80O7al1021PH4307alO080NWYj0P1oOgl208B4
Q080OGem1P1nOWh207moO`80P8200P1eMGD208N7Q`80Ph>30P24Q8@207MgM`80RHV93038h=P000X0
b>3H0P1oOgl208R8R080SXj>0P2=SHd208R8R080QHF50P1mOGd207moO`80QhN70P24Q8@208:2PP80
Q8B40P1nOWh20820P080PX:20P1kNg/308N7Q`80MgMg0P1fMWH2071`L080MWIf0P1iNGT207alO080
P8200P21PH4208J6QP80PX:20P1mOGd20861P@@0P8200P21PH420820P0@0PH610P1nOWh20861P@80
OWin0P22PX8207YjNP80PH610P1kNg/20820P080O7al0P1kNg/207moO`T0OWin0P1oOgl208>3P`80
QXJ60P1kNg/208N7Q`80MGEe0P20P80207QhN080Ph>30P1lO7`207emO@80Ogmo0P23Ph<207QhN0H0
b>3H0P1lO7`207emO@80Rh^;0P28R8P207alO080Q8B40P22PX8207alO080Ogmo0P1^KVh209NGU`80
NGUi0P24Q8@208:2PP80N7Qh0P23Ph<307moO`80Q8B40P22PX8207UiN@80Ng]k0P27QhL207]kN`80
NGUi0P22PX8207]kN`80OWin0P23Ph<20820P080OWin0P24Q8@207UiN@80Ogmo0P1gMgL208>3P`80
QHF50P1oOgl207]kN`80PH610P1iNGT208:2PP80Ogmo0P1mOGd20820P080Q8B40P21PH4207inOP80
P8200`21PH4207]kN`80NWYj0P1hN7P20861P@80RHV90P23Ph<20861P@80QHF50P1hN7P208R8R080
MgMg0P20P80208:2PP80QhN70P1jNWX<0<SPf0002P38h=P207moO`80R8R80P2>SXh208f=S@80R8R8
0P25QHD207emO@80Ogmo0P27QhL208B4Q080PX:20P24Q8@207inOP80P8200P22PX8207]kN`<0QhN7
0P1gMgL207IfMP80L71`0P1fMWH207UiN@80O7al0P20P8020861P@80QXJ60P22PX8207emO@80PH61
1020P8020861P@80P8201021PH4207inOP80PH610P1nOWh208:2PP80NWYj0P21PH4207]kN`80P820
0P1lO7`207]kN`80Ogmo2@1nOWh207moO`80Ph>30P26QXH207]kN`80QhN70P1eMGD20820P080N7Qh
0P23Ph<207alO080OGem0P1oOgl208>3P`80N7Qh1P38h=P207alO080OGem0P2;Rh/208R8R080O7al
0P24Q8@208:2PP80O7al0P1oOgl206i^KP80UiNG0P1iNGT208B4Q080PX:20P1hN7P208>3P`<0Ogmo
0P24Q8@208:2PP80NGUi0P1kNg/208N7Q`80Ng]k0P1iNGT208:2PP80Ng]k0P1nOWh208>3P`80P820
0P1nOWh208B4Q080NGUi0P1oOgl207MgM`80Ph>30P25QHD207moO`80Ng]k0P21PH4207UiN@80PX:2
0P1oOgl207emO@80P8200P24Q8@20861P@80OWin0P20P8030861P@80Ng]k0P1jNWX207QhN080PH61
0P29RHT208>3P`80PH610P25QHD207QhN080R8R80P1gMgL20820P080PX:20P27QhL207YjNP`0b>3H
000:0<SPf080Ph>30P1gMgL20820P080M7Ad0P1oOgl207UiN@80NWYj0P1nOWh208>3P`80NWYj0P23
Ph<208V9R@80Ogmo0P1lO7`208B4Q080RHV90`20P80207moO`80SXj>0P1fMWH207QhN080PH610P1i
NGT20861P@80OWin0P23Ph<207inOP80P8200P24Q8@20861P@80Ng]k0P1oOgl208F5Q@80OWin1023
Ph<208N7Q`80N7Qh0P1oOgl208J6QP80P820101oOgl20861P@80P820101oOgl50820P080PX:20P21
PH4207emO@80QXJ60P1oOgl208F5Q@80NWYj0P1mOGd208>3P`80OGem0P24Q8@207]kN`80Q8B40P1n
OWh208J6QPH0b>3H0P1mOGd208F5Q@80KFe]0P1dM7@208J6QP80NGUi0P21PH4207YjNP80P8200P21
PH4207inOP80MWIf0P22PX8207moO`80Ng]k0P1^KVh307inOP80P8200P24Q8@407MgM`80RXZ:0P2=
SHd208>3P`80P8200P21PH4207AdM080O7al0P2:RXX20820P080O7al0P21PH4208B4Q080P8200P1m
OGd207inOP80OGem0P1gMgL207YjNP@0Ph>30P1iNGT207MgM`80QHF5101mOGd208N7Q`80P8200`1l
O7`207moO`80P8200P27QhL208R8R080QHF50P22PX8207moO`80N7Qh0P1oOgl207alO080OGem0P1i
NGT208N7Q`80OGem0P20P80<0<SPf0002P38h=P208>3P`80MgMg0P20P80207AdM080Ogmo0P1iNGT2
07YjNP80OWin0P23Ph<207YjNP80Ph>30P29RHT207moO`80O7al0P24Q8@208V9R@<0P8200P1oOgl2
08j>SP80MWIf0P1hN7P20861P@80NGUi0P21PH4207inOP80Ph>30P1nOWh20820P080Q8B40P21PH42
07]kN`80Ogmo0P25QHD207inOP@0Ph>30P27QhL207QhN080Ogmo0P26QXH20820P0@0Ogmo0P21PH42
0820P0@0Ogmo1@20P80208:2PP80PH610P1mOGd208J6QP80Ogmo0P25QHD207YjNP80OGem0P23Ph<2
07emO@80Q8B40P1kNg/208B4Q080OWin0P26QXH60<SPf080OGem0P25QHD206e]K@80M7Ad0P26QXH2
07UiN@80PH610P1jNWX20820P080PH610P1nOWh207IfMP80PX:20P1oOgl207]kN`80KVi^0`1nOWh2
0820P080Q8B4101gMgL208Z:RP80SHf=0P23Ph<20820P080PH610P1dM7@207alO080RXZ:0P20P802
07alO080PH610P24Q8@20820P080OGem0P1nOWh207emO@80MgMg0P1jNWX408>3P`80NGUi0P1gMgL2
08F5Q@@0OGem0P27QhL20820P0<0O7al0P1oOgl20820P080QhN70P28R8P208F5Q@80PX:20P1oOgl2
07QhN080Ogmo0P1lO7`207emO@80NGUi0P27QhL207emO@80P8203038h=P000X0b>3H0P1eMGD207em
O@80Ph>30P26QXH20820P080QhN70P1hN7P207UiN@80P8200P1gMgL207UiN@80Ogmo0P1aLG4207]k
N`80OWin0P1jNWX308R8R080L71`0P1eMGD2075aL@@0OGem0P21PH4208V9R@80Ogmo0P20P80208:2
PP80Q8B40P1nOWh20861P@80O7al0P20P80207moO`@0O7al1021PH4207inOP80Ogmo0P21PH4208:2
PP80NGUi1P21PH420820P080NWYj0P20P80308>3P`80Ogmo0P21PH4207alO0@0PH610P29RHT207mo
O`80OGem0P1nOWh207emO@80Ogmo0P25QHD207moO`80PH610P22PX860<SPf080QhN70P1mOGd208R8
R080T92@0P1hN7P207inOP80PX:20P20P80208J6QP80N7Qh0P20P80207moO`80Ng]k0P21PH4207mo
O`80Ng]k0`1dM7@2069RHP80PX:20P28R8P207inOP80NWYj0P24Q8@207QhN080OGem0P1lO7`208F5
Q@80RXZ:0P1kNg/20861P@80O7al0P22PX8208F5Q@80Q8B4101mOGd20820P080QhN70P26QXH20861
P@@0Ogmo1022PX8207]kN`80PH610P22PX820861P@<0Ph>30P21PH4207]kN`80OWin0P25QHD208:2
PP80PH610P20P80407moO`80PH610P1oOgl407YjNP80Ogmo0P1lO7`<0<SPf0002P38h=P207EeM@80
OGem0P23Ph<208J6QP80P8200P27QhL207QhN080NGUi0P20P80207MgM`80NGUi0P1oOgl2075aL@80
Ng]k0P1nOWh207YjNP<0R8R80P1`L70207EeM@80LG5a101mOGd20861P@80RHV90P1oOgl20820P080
PX:20P24Q8@207inOP80PH610P1lO7`20820P080Ogmo101lO7`40861P@80OWin0P1oOgl20861P@80
PX:20P1iNGT60861P@80P8200P1jNWX20820P0<0Ph>30P1oOgl20861P@80O7al1021PH4208V9R@80
Ogmo0P1mOGd207inOP80OGem0P1oOgl208F5Q@80Ogmo0P21PH4208:2PPH0b>3H0P27QhL207emO@80
R8R80P2@T90207QhN080OWin0P22PX820820P080QXJ60P1hN7P20820P080Ogmo0P1kNg/20861P@80
Ogmo0P1kNg/307AdM080HV9R0P22PX8208R8R080OWin0P1jNWX208B4Q080N7Qh0P1mOGd207alO080
QHF50P2:RXX207]kN`80PH610P1lO7`208:2PP80QHF50P24Q8@407emO@80P8200P27QhL208J6QP80
PH61101oOgl408:2PP80Ng]k0P21PH4208:2PP80PH610`23Ph<20861P@80Ng]k0P1nOWh208F5Q@80
PX:20P21PH420820P0@0Ogmo0P21PH4207moO`@0NWYj0P1oOgl207alO0`0b>3H000:0<SPf080QHF5
0P24Q8@207moO`80P8200P1lO7`207moO`80RHV90P1fMWH20820P080QHF50P2;Rh/208b<S080LG5a
0P1oOgl208:2PP80Q8B40`25QHD207IfMP80MGEe0P2=SHd208V9R@80NGUi0P1oOgl207alO080PH61
0P24Q8@208:2PP80Ng]k0P24Q8@208>3P`80PH610P22PX8207emO@80Ogmo0P20P8020861P@80Ph>3
0P1hN7P20820P080Ogmo0P1mOGd208>3P`@0O7al0P1jNWX208>3P`80PX:20P1nOWh30820P080PH61
0P22PX820820P080PH610P23Ph<207inOP80P8200P21PH4208:2PP@0PH610P1kNg/207emO@80PX:2
0P1mOGd60<SPf080N7Qh0P1oOgl207YjNP80KFe]0P1hN7P208F5Q@80NGUi0P1jNWX208>3P`80Ng]k
0P22PX8209ZJVP80PX:20P25QHD207emO@80RHV90`1kNg/207emO@80MWIf0P1mOGd208N7Q`80QXJ6
0P1oOgl407emO@80Ph>30P20P80207inOP80Ogmo0P22PX8207inOP80NGUi0P20P80208>3P`80P820
0P22PX820861P@80NWYj101oOgl20861P@80Ogmo0P20P80207QhN080P8200P21PH4407inOP<0Ph>3
0P1oOgl207emO@80OWin1022PX820820P080PH610P20P80408:2PP80PH610P1kNg/208R8R080PH61
0P24Q8@<0<SPf0002P38h=P208F5Q@80Q8B40P1oOgl20820P080O7al0P1oOgl208V9R@80MWIf0P20
P80208F5Q@80Rh^;0P2<S8`2075aL@80Ogmo0P22PX8208B4Q0<0QHF50P1fMWH207EeM@80SHf=0P29
RHT207UiN@80Ogmo0P1lO7`20861P@80Q8B40P22PX8207]kN`80Q8B40P23Ph<20861P@80PX:20P1m
OGd207moO`80P8200P21PH4208>3P`80N7Qh0P20P80207moO`80OGem0P23Ph<407alO080NWYj0P23
Ph<208:2PP80OWin0`20P8020861P@80PX:20P20P8020861P@80Ph>30P1nOWh20820P080PH610P22
PX840861P@80Ng]k0P1mOGd208:2PP80OGem1P38h=P207QhN080Ogmo0P1jNWX206e]K@80N7Qh0P25
QHD207UiN@80NWYj0P23Ph<207]kN`80PX:20P2JVYX208:2PP80QHF50P1mOGd208V9R@<0Ng]k0P1m
OGd207IfMP80OGem0P27QhL208J6QP80Ogmo101mOGd208>3P`80P8200P1nOWh207moO`80PX:20P1n
OWh207UiN@80P8200P23Ph<20820P080PX:20P21PH4207YjNP@0Ogmo0P21PH4207moO`80P8200P1h
N7P20820P080PH61101nOWh308>3P`80Ogmo0P1mOGd207inOP@0PX:20P20P8020861P@80P8201022
PX820861P@80Ng]k0P28R8P20861P@80Q8B43038h=P000X0b>3H0P1lO7`207EeM@80RXZ:0P20P802
08b<S080O7al0P2;Rh/207=cL`80SHf=0P2>SXh207EeM@80QHF50P26QXH207EeM@80Ogmo0P1jNWX3
08:2PP80P8200P1fMWH207=cL`80Shn?0P1hN7P207moO`80QHF50P20P80207]kN`80PX:20P1nOWh2
07moO`@0PH610P1mOGd208B4Q080Ng]k0P1oOgl208>3P`80OWin0P1lO7`207moO`80OWin0P22PX88
0861P@80OWin0P27QhL207emO@<0PH610P20P80207inOP80Ng]k0P22PX840820P080Q8B40P1oOgl2
07inOP80NWYj0P22PX820861P@80Ng]k0P1oOgl207alO0H0b>3H0P1fMWH208R8R080LG5a0P2FUYH2
0820P080RXZ:0P1nOWh20820P080Ogmo0P24Q8@407YjNP80Ph>30P27QhL207UiN@80Ogmo0`2:RXX2
07moO`80QHF50P1lO7`208^;R`80RXZ:0P25QHD208J6QP@0OGem0P1lO7`207inOP80O7al0P20P802
07alO080NGUi0P1mOGd207alO080QHF50P22PX820861P@80OWin0P24Q8@207alO0@0Ph>30P1mOGd2
08B4Q080O7al0P1mOGd207inOP80Ogmo0`25QHD20861P@80QHF50P1mOGd207]kN`80OGem0P1lO7`2
0820P080PH610P1oOgl208B4Q080Ng]k0P1nOWh20820P0@0Ng]k3038h=P000X0b>3H0P1lO7`207Ee
M@80RXZ:0P20P80208b<S080O7al0P2;Rh/207=cL`80SHf=0P2>SXh207EeM@80QHF50P26QXH207Ee
M@80Ogmo0P1jNWX308:2PP80P8200P1fMWH207=cL`80Shn?0P1hN7P207moO`80QHF50P20P80207]k
N`80PX:20P1nOWh207moO`@0PH610P1mOGd208B4Q080Ng]k0P1oOgl208>3P`80OWin0P1lO7`207mo
O`80OWin0P22PX880861P@80OWin0P27QhL207emO@<0PH610P20P80207inOP80Ng]k0P22PX840820
P080Q8B40P1oOgl207inOP80NWYj0P22PX820861P@80Ng]k0P1oOgl207alO0H0b>3H0P1fMWH208R8
R080LG5a0P2FUYH20820P080RXZ:0P1nOWh20820P080Ogmo0P24Q8@407YjNP80Ph>30P27QhL207Ui
N@80Ogmo0`2:RXX207moO`80QHF50P1lO7`208^;R`80RXZ:0P25QHD208J6QP@0OGem0P1lO7`207in
OP80O7al0P20P80207alO080NGUi0P1mOGd207alO080QHF50P22PX820861P@80OWin0P24Q8@207al
O0@0Ph>30P1mOGd208B4Q080O7al0P1mOGd207inOP80Ogmo0`25QHD20861P@80QHF50P1mOGd207]k
N`80OGem0P1lO7`20820P080PH610P1oOgl208B4Q080Ng]k0P1nOWh20820P0@0Ng]k3038h=P000X0
b>3H0P25QHD207IfMP80Ogmo101lO7`208n?S`80RHV90P26QXH208:2PP80OWin0P25QHD208j>SP80
MgMg0P1eMGD207QhN080Ogmo0`21PH4207]kN`80M7Ad0P1aLG4208j>SP80MWIf0P1nOWh207moO`80
PX:20P21PH4207moO`80OWin0P23Ph<20861P@80Ng]k0P20P8020861P@80MGEe0P1jNWX208>3P`80
Ng]k0P1mOGd207inOP80P8200P1mOGd20861P@80Q8B40P1mOGd40861P@@0P8200`1oOgl208>3P`80
OWin0P20P80207]kN`80OWin0P21PH4207emO@80Ogmo101kNg/208B4Q080PX:20P1mOGd208B4Q080
MWIf1P38h=P208N7Q`80O7al0P20P80207QhN080PH610P1iNGT207emO@80Q8B40P20P8020861P@80
Ogmo0P26QXH207]kN`80RXZ:0P1oOgl208J6QP<0Q8B40P1fMWH207alO080Rh^;101nOWh20820P0@0
PH610P1kNg/207alO080NGUi0P23Ph<207moO`80OGem0P20P80207alO080N7Qh0P1iNGT208>3P`80
PH610P1jNWX207emO@80P8200P1kNg/207emO@80PX:20P1nOWh207moO`80Ng]k0P1lO7`208>3P`<0
OWin0P1jNWX207emO@80PX:20P21PH4208Z:RP@0Ogmo0P20P80208>3P`80PH610P1jNWX208:2PP80
O7al0P1oOgl207UiN@`0b>3H000:0<SPf080QHF50P1fMWH207moO`@0O7al0P2?Shl208V9R@80QXJ6
0P22PX8207inOP80QHF50P2>SXh207MgM`80MGEe0P1hN7P207moO`<0PH610P1kNg/207AdM080LG5a
0P2>SXh207IfMP80OWin0P1oOgl208:2PP80PH610P1oOgl207inOP80Ph>30P21PH4207]kN`80P820
0P21PH4207EeM@80NWYj0P23Ph<207]kN`80OGem0P1nOWh20820P080OGem0P21PH4208B4Q080OGem
1021PH440820P0<0Ogmo0P23Ph<207inOP80P8200P1kNg/207inOP80PH610P1mOGd207moO`@0Ng]k
0P24Q8@208:2PP80OGem0P24Q8@207IfMPH0b>3H0P27QhL207alO080P8200P1hN7P20861P@80NGUi
0P1mOGd208B4Q080P8200P21PH4207moO`80QXJ60P1kNg/208Z:RP80Ogmo0P26QXH308B4Q080MWIf
0P1lO7`208^;R`@0OWin0P20P8040861P@80Ng]k0P1lO7`207UiN@80Ph>30P1oOgl207emO@80P820
0P1lO7`207QhN080NGUi0P23Ph<20861P@80NWYj0P1mOGd20820P080Ng]k0P1mOGd208:2PP80OWin
0P1oOgl207]kN`80O7al0P23Ph<307inOP80NWYj0P1mOGd208:2PP80PH610P2:RXX407moO`80P820
0P23Ph<20861P@80NWYj0P22PX8207alO080Ogmo0P1iNGT<0<SPf0002P38h=P208F5Q@80MWIf0P1o
Ogl407alO080Shn?0P29RHT208J6QP80PX:20P1nOWh208F5Q@80SXj>0P1gMgL207EeM@80N7Qh0P1o
Ogl30861P@80Ng]k0P1dM7@2075aL@80SXj>0P1fMWH207inOP80Ogmo0P22PX820861P@80Ogmo0P1n
OWh208>3P`80PH610P1kNg/20820P080PH610P1eMGD207YjNP80Ph>30P1kNg/207emO@80OWin0P20
P80207emO@80PH610P24Q8@207emO@@0PH611020P80307moO`80Ph>30P1nOWh20820P080Ng]k0P1n
OWh20861P@80OGem0P1oOgl407]kN`80Q8B40P22PX8207emO@80Q8B40P1fMWH60<SPf080QhN70P1l
O7`20820P080N7Qh0P21PH4207UiN@80OGem0P24Q8@20820P080PH610P1oOgl208J6QP80Ng]k0P2:
RXX207moO`80QXJ60`24Q8@207IfMP80O7al0P2;Rh/407inOP80P8201021PH4207]kN`80O7al0P1i
NGT208>3P`80Ogmo0P1mOGd20820P080O7al0P1hN7P207UiN@80Ph>30P21PH4207YjNP80OGem0P20
P80207]kN`80OGem0P22PX8207inOP80Ogmo0P1kNg/207alO080Ph>30`1nOWh207YjNP80OGem0P22
PX820861P@80RXZ:101oOgl20820P080Ph>30P21PH4207YjNP80PX:20P1lO7`207moO`80NGUi3038
h=P000X0b>3H0P27QhL207inOP80Lg=c101lO7`208n?S`80Lg=c0P2=SHd2071`L080M7Ad0P2>SXh2
07inOP80RHV90P1jNWX20820P080Ogmo0`21PH4207alO080LW9b0P2;Rh/208n?S`80NWYj0P24Q8@2
07alO080P8200P23Ph<207]kN`80Q8B40P1nOWh207UiN@80P820101oOgl208:2PP80MgMg0P23Ph<4
0861P@80NGUi0P20P80208>3P`80P8200P1oOgl208:2PP80OGem0P24Q8@20820P080PX:20`1kNg/2
0820P080QHF50P1nOWh207moO`80PH610P1mOGd207inOP80PH610P1nOWh207alO080PH611P20P802
07moO`H0b>3H0P1fMWH207QhN080Ng]k0P21PH4207moO`80QHF50P1lO7`207QhN080RXZ:0P21PH42
08^;R`80PX:20P20P80206IVIP@0OGem0`28R8P207QhN080PX:20P1gMgL207alO080PH610P1oOgl2
0861P@80OWin0P1fMWH207emO@80O7al0P21PH4208>3P`80MgMg0P20P80207UiN@80PH610P22PX84
0820P080OWin0P25QHD208>3P`80NGUi0P21PH4207inOP80P8200P1lO7`208>3P`80O7al0P1nOWh3
0820P080OWin0P20P80207moO`80QhN70P1oOgl20861P@80Ph>30P20P80207emO@80P8200P22PX82
0820P080Ph>30P1nOWh20820P0`0b>3H000:0<SPf080QhN70P1nOWh207=cL`@0O7al0P2?Shl207=c
L`80SHf=0P1`L70207AdM080SXj>0P1nOWh208V9R@80NWYj0P20P80207moO`<0PH610P1lO7`2079b
LP80Rh^;0P2?Shl207YjNP80Q8B40P1lO7`20820P080Ph>30P1kNg/208B4Q080OWin0P1iNGT20820
P0@0Ogmo0P22PX8207MgM`80Ph>31021PH4207UiN@80P8200P23Ph<20820P080Ogmo0P22PX8207em
O@80Q8B40P20P80208:2PP<0Ng]k0P20P80208F5Q@80OWin0P1oOgl20861P@80OGem0P1nOWh20861
P@80OWin0P1lO7`20861P@H0P8200P1oOgl60<SPf080MWIf0P1hN7P207]kN`80PH610P1oOgl208F5
Q@80O7al0P1hN7P208Z:RP80PH610P2;Rh/208:2PP80P8200P1VIVH407emO@<0R8R80P1hN7P208:2
PP80MgMg0P1lO7`20861P@80Ogmo0P21PH4207inOP80MWIf0P1mOGd207alO080PH610P23Ph<207Mg
M`80P8200P1iNGT20861P@80PX:21020P80207inOP80QHF50P23Ph<207UiN@80PH610P1nOWh20820
P080O7al0P23Ph<207alO080OWin0`20P80207inOP80P8200P1oOgl208N7Q`80Ogmo0P21PH4208>3
P`80P8200P1mOGd20820P080PX:20P20P80208>3P`80OWin0P20P80<0<SPf0002P38h=P207alO080
SXj>0P1iNGT207moO`80OGem0P1jNWX208Z:RP80Rh^;0P1jNWX208J6QP80NWYj0P24Q8@208>3P`80
LG5a0P1jNWX207IfMPD0P8200P2;Rh/208f=S@80PX:20P1oOgl207YjNP80MWIf1020P80207emO@80
Ng]k0P20P8040861P@80Ogmo101mOGd207inOP80NGUi0P1mOGd208B4Q080PH610P1mOGd20820P0@0
Ph>30P20P80207emO@80PX:20P1oOgl208:2PP<0Ogmo0P23Ph<207emO@@0OWin0P21PH420820P0@0
Ogmo0P1lO7`20861P@80Ph>30P1oOgl20861P@80OWin0P1kNg/60<SPf080P8200P1oOgl20861P@80
Ogmo0P26QXH207moO`80M7Ad0P20P80208F5Q@@0Ogmo0P1dM7@20820P080Lg=c0P1_Kfl2096AT@<0
O7al0P23Ph<208^;R`@0Ph>30P27QhL207MgM`80NGUi0P1nOWh20820P080Ogmo0P1nOWh20820P080
PH610P24Q8@20820P080QHF50P1oOgl208:2PP80OWin0P23Ph<208b<S0@0OGem1027QhL207inOP80
O7al0P1nOWh208:2PP80OWin0P20P80308J6QP80QHF50P21PH4207]kN`80NWYj0P1gMgL208B4Q080
PX:20P23Ph<20820P080Ng]k0P23Ph<40861P@80Ng]k0P25QHD<0<SPf0002P38h=P207alO080SXj>
0P1iNGT207moO`80OGem0P1jNWX208Z:RP80Rh^;0P1jNWX208J6QP80NWYj0P24Q8@208>3P`80LG5a
0P1jNWX207IfMPD0P8200P2;Rh/208f=S@80PX:20P1oOgl207YjNP80MWIf1020P80207emO@80Ng]k
0P20P8040861P@80Ogmo101mOGd207inOP80NGUi0P1mOGd208B4Q080PH610P1mOGd20820P0@0Ph>3
0P20P80207emO@80PX:20P1oOgl208:2PP<0Ogmo0P23Ph<207emO@@0OWin0P21PH420820P0@0Ogmo
0P1lO7`20861P@80Ph>30P1oOgl20861P@80OWin0P1kNg/60<SPf080P8200P1oOgl20861P@80Ogmo
0P26QXH207moO`80M7Ad0P20P80208F5Q@@0Ogmo0P1dM7@20820P080Lg=c0P1_Kfl2096AT@<0O7al
0P23Ph<208^;R`@0Ph>30P27QhL207MgM`80NGUi0P1nOWh20820P080Ogmo0P1nOWh20820P080PH61
0P24Q8@20820P080QHF50P1oOgl208:2PP80OWin0P23Ph<208b<S0@0OGem1027QhL207inOP80O7al
0P1nOWh208:2PP80OWin0P20P80308J6QP80QHF50P21PH4207]kN`80NWYj0P1gMgL208B4Q080PX:2
0P23Ph<20820P080Ng]k0P23Ph<40861P@80Ng]k0P25QHD<0<SPf0002P38h=P20861P@80MWIf0P1g
MgL20820P080NWYj0P20P80207MgM`80S8b<0P29RHT207emO@80QHF50P1cLg<207moO`80R8R80P20
P80208B4Q0<0MgMg0P21PH42079bLP80QhN70P26QXH208B4Q080Ogmo101lO7`208:2PP80NGUi0P1m
OGd208F5Q@80Ogmo0P1nOWh207moO`80PH610P1lO7`207inOP80P8200P22PX820861P@80O7al0P22
PX820820P080Q8B40P1lO7`207moO`80Ng]k0P1nOWh20861P@80Ogmo0`22PX8208>3P`80Ng]k0P1o
Ogl207inOP80P8200P21PH4207emO@80PX:20P1nOWh207YjNP80P8200P21PH4408:2PP80OWin1P38
h=P207UiN@@0OWin0P1fMWH208F5Q@80N7Qh0P23Ph<208J6QP80LW9b0P2;Rh/207]kN`80QHF50P20
P80208>3P`80M7Ad0P1QHF4307YjNP80Ph>3101lO7`407inOP80Ogmo0P20P80208>3P`80OGem0P1j
NWX207QhN0@0OGem0P21PH4208B4Q080Ogmo0P1kNg/207emO@80OWin0P21PH4207moO`80NGUi0P1j
NWX207MgM`80QHF50P1jNWX207emO@80P8200P1mOGd208F5Q@80Ng]k0`21PH4208J6QP80P8200P1m
OGd407moO`80P8200P22PX840820P080RHV90P1lO7`207emO@80NWYj0P24Q8@20861P@`0b>3H000:
0<SPf080PH610P1fMWH207MgM`80P8200P1jNWX20820P080MgMg0P2<S8`208V9R@80OGem0P25QHD2
07=cL`80Ogmo0P28R8P20820P080Q8B40`1gMgL20861P@80LW9b0P27QhL208J6QP80Q8B40P1oOgl4
07alO080PX:20P1iNGT207emO@80QHF50P1oOgl207inOP80Ogmo0P21PH4207alO080OWin0P20P802
08:2PP80PH610P1lO7`208:2PP80P8200P24Q8@207alO080Ogmo0P1kNg/207inOP80PH610P1oOgl3
08:2PP80Ph>30P1kNg/207moO`80OWin0P20P8020861P@80OGem0P22PX8207inOP80NWYj0P20P802
0861P@@0PX:20P1nOWh60<SPf080NGUi101nOWh207IfMP80QHF50P1hN7P208>3P`80QXJ60P1bLW82
08^;R`80Ng]k0P25QHD20820P080Ph>30P1dM7@2065QH@<0NWYj0P23Ph<407alO0@0OWin0P1oOgl2
0820P080Ph>30P1mOGd207YjNP80N7Qh101mOGd20861P@80Q8B40P1oOgl207]kN`80OGem0P1nOWh2
0861P@80Ogmo0P1iNGT207YjNP80MgMg0P25QHD207YjNP80OGem0P20P80207emO@80QHF50P1kNg/3
0861P@80QXJ60P20P80207emO@@0Ogmo0P20P80208:2PP@0P8200P29RHT207alO080OGem0P1jNWX2
08B4Q080PH613038h=P000X0b>3H0P27QhL207emO@80LG5a0P1bLW820820P080PX:20P1oOgl20820
P080Shn?0P26QXH207inOP80Ph>30P2:RXX207inOP80S8b<1@22PX8207moO`80QhN70P1`L70208B4
Q080Ogmo0P24Q8@20820P0@0Q8B40P1lO7`207moO`80Q8B40P22PX820820P080OWin0P20P80207in
OP@0P8200P1mOGd20861P@80QHF50P1nOWh207alO080Q8B40P22PX820820P080PX:20P21PH420820
P080OWin0`24Q8@207emO@@0P8200P1oOgl207inOP80OGem0P1lO7`20820P080PX:20P21PH4208B4
Q0@0OWin0P22PX8207]kN`H0b>3H0P1gMgL208B4Q080QHF50P1cLg<207inOP80MgMg0P1oOgl208R8
R080QhN70P21PH4208F5Q@80PX:20P1iNGT207inOP80PX:20P25QHD308>3P`80NWYj0P1bLW8207Yj
NP80Ogmo0P20P80208:2PP80Ogmo0P24Q8@208F5Q@80PH610P1nOWh208R8R080PX:20P21PH4207in
OP80QHF5101gMgL207moO`@0PH610P23Ph<208:2PP80PH610P1mOGd407inOP80Ph>30P1nOWh207al
O080OWin0`1mOGd208:2PP80Ph>30P1oOgl207QhN080OWin0P21PH420820P080PH610P29RHT208:2
PP80O7al0P1iNGT20861P@80Q8B40P1nOWh<0<SPf0002P38h=P208N7Q`80OGem0P1aLG42079bLP80
P8200P22PX8207moO`80P8200P2?Shl208J6QP80OWin0P23Ph<208Z:RP80OWin0P2<S8`508:2PP80
Ogmo0P27QhL2071`L080Q8B40P1oOgl208B4Q080P8201024Q8@207alO080Ogmo0P24Q8@208:2PP80
P8200P1nOWh20820P080OWin1020P80207emO@80PH610P25QHD207inOP80O7al0P24Q8@208:2PP80
P8200P22PX820861P@80P8200P1nOWh308B4Q080OGem1020P80207moO`80OWin0P1mOGd207alO080
P8200P22PX820861P@80Q8B4101nOWh208:2PP80Ng]k1P38h=P207MgM`80Q8B40P25QHD207=cL`80
OWin0P1gMgL207moO`80R8R80P27QhL20861P@80QHF50P22PX8207UiN@80OWin0P22PX8208F5Q@<0
Ph>30P1jNWX2079bLP80NWYj0P1oOgl20820P080PX:20P1oOgl208B4Q080QHF50P21PH4207inOP80
R8R80P22PX820861P@80OWin0P25QHD407MgM`80Ogmo1021PH4208>3P`80PX:20P21PH4207emO@@0
OWin0P23Ph<207inOP80O7al0P1nOWh307emO@80PX:20P23Ph<207moO`80N7Qh0P1nOWh20861P@80
P8200P21PH4208V9R@80PX:20P1lO7`207UiN@80PH610P24Q8@207inOP`0b>3H000:0<SPf080O7al
0P24Q8@207inOP80PH610P1lO7`207inOP@0MgMg0P1aLG4207YjNP80MWIf0P1aLG4208V9R@80OGem
0P23Ph<207AdM0<0Ogmo0P1fMWH208N7Q`80SXj>0P23Ph<208:2PP80QXJ60P20P80208>3P`80P820
0P1nOWh207moO`80PH610P22PX820820P080Ph>30P1nOWh208B4Q080QHF50P21PH4208F5Q@80OGem
0P1oOgl20820P080NGUi0P1nOWh407moO`80Ph>30P21PH4207moO`D0OWin0P21PH4407inOP80O7al
0P1oOgl20820P0@0PX:20P25QHD40861P@80OGem0P1iNGT207]kN`80OWin1P38h=P208N7Q`80Ng]k
0P25QHD208:2PP80Ng]k0P26QXH207YjNP80PX:20P1nOWh207IfMP80O7al0P1fMWH208:2PP80OWin
101lO7`3061PH080U9BD0P1iNGT208F5Q@80MgMg0P1lO7`208J6QP80O7al101mOGd208>3P`80PH61
0P1iNGT407moO`80OWin0P1lO7`207inOP80Ph>30P22PX8207EeM@80OGem0P24Q8@207alO080NWYj
0P25QHD207emO@80PX:20P1nOWh207moO`80Ph>30P20P80308:2PP80PH610P20P80207inOP80RHV9
1020P80207moO`80O7al0P22PX8207inOP80Ng]k0P1oOgl208f=S@80O7al0P29RHT<0<SPf0002P38
h=P207alO080Q8B40P1nOWh20861P@80O7al0P1nOWh407MgM`80LG5a0P1jNWX207IfMP80LG5a0P29
RHT207emO@80Ph>30P1dM7@307moO`80MWIf0P27QhL208j>SP80Ph>30P22PX8208J6QP80P8200P23
Ph<20820P080OWin0P1oOgl20861P@80PX:20P20P80208>3P`80OWin0P24Q8@208F5Q@80PH610P25
QHD207emO@80Ogmo0P20P80207UiN@80OWin101oOgl208>3P`80PH610P1oOgl507inOP80PH61101n
OWh207alO080Ogmo0P20P80408:2PP80QHF51021PH4207emO@80NGUi0P1kNg/207inOPH0b>3H0P27
QhL207]kN`80QHF50P22PX8207]kN`80QXJ60P1jNWX208:2PP80OWin0P1fMWH207alO080MWIf0P22
PX8207inOP@0O7al0`1PH60209BDU080NGUi0P25QHD207MgM`80O7al0P26QXH207alO0@0OGem0P23
Ph<20861P@80NGUi101oOgl207inOP80O7al0P1nOWh208>3P`80PX:20P1eMGD207emO@80Q8B40P1l
O7`207YjNP80QHF50P1mOGd208:2PP80OWin0P1oOgl208>3P`80P8200`22PX820861P@80P8200P1n
OWh208V9R@@0P8200P1oOgl207alO080PX:20P1nOWh207]kN`80Ogmo0P2=SHd207alO080RHV93038
h=P000X0b>3H0P1mOGd207moO`80P8201021PH4207]kN`80PX:20P24Q8@207UiN@80PH610P1iNGT2
07AdM080PH610P25QHD207alO080RXZ:0`1fMWH40820P080L71`0P1kNg/208F5Q@@0P8200P22PX82
0820P080PH610P1nOWh208>3P`80Q8B40P1oOgl20820P080OWin0P22PX820820P0@0PH610P1lO7`2
08:2PP80Ph>30P1oOgl207inOP80NGUi0P1oOgl20820P080Q8B40P1mOGd208B4Q0<0Ogmo0P1mOGd2
07inOP80P8200P1mOGd207YjNP80Ogmo0P23Ph<207emO@80Ph>3101nOWh20861P@80P8200P24Q8@2
0861P@H0b>3H0P1oOgl208:2PPH0Ogmo0P28R8P207]kN`80OGem0P28R8P208^;R`80RXZ:0P1mOGd2
08b<S080Ng]k0P25QHD20861P@<0NGUi0P25QHD208N7Q`80OGem0P1oOgl207emO@80O7al0P22PX84
0820P080Ng]k0P21PH4208J6QP80Ogmo0P21PH4207moO`80OGem0P26QXH207inOP80Ph>30P21PH42
07inOP80OGem0P26QXH208B4Q080Ogmo0P1hN7P207emO@80QHF50P1mOGd207moO`80QXJ60`22PX82
08J6QP80NGUi0P1oOgl208F5Q@80OGem0P1lO7`207moO`80O7al0P1iNGT207MgM`80P8200P1hN7P2
07]kN`80Ph>30P1nOWh<0<SPf0002P38h=P207emO@80Ogmo0P20P8040861P@80Ng]k0P22PX8208B4
Q080NGUi0P21PH4207UiN@80M7Ad0P21PH4208F5Q@80O7al0P2:RXX307IfMP@0P8200P1`L70207]k
N`80QHF51020P80208:2PP80P8200P21PH4207inOP80Ph>30P24Q8@207moO`80P8200P1nOWh208:2
PP80P8201021PH4207alO080PX:20P23Ph<207moO`80OWin0P1iNGT207moO`80P8200P24Q8@207em
O@80Q8B40`1oOgl207emO@80OWin0P20P80207emO@80NWYj0P1oOgl208>3P`80OGem0P23Ph<407in
OP80PH610P20P80208B4Q080PH611P38h=P207moO`80PX:21P1oOgl208R8R080Ng]k0P1mOGd208R8
R080Rh^;0P2:RXX207emO@80S8b<0P1kNg/208F5Q@80PH610`1iNGT208F5Q@80QhN70P1mOGd207mo
O`80OGem0P1lO7`208:2PP@0P8200P1kNg/20861P@80QXJ60P1oOgl20861P@80Ogmo0P1mOGd208J6
QP80OWin0P23Ph<20861P@80OWin0P1mOGd208J6QP80Q8B40P1oOgl207QhN080OGem0P25QHD207em
O@80Ogmo0P26QXH308:2PP80QXJ60P1iNGT207moO`80QHF50P1mOGd207alO080Ogmo0P1lO7`207Ui
N@80MgMg0P20P80207QhN080Ng]k0P23Ph<207inOP`0b>3H000:0<SPf080S8b<0P1mOGd407inOP80
Ph>30P1cLg<207alO080Ogmo0P2>SXh207=cL`80M7Ad0P1cLg<20820P080QhN70P1gMgL20820P0<0
Ph>30P1iNGT208:2PP80NWYj0P22PX8207]kN`80Ogmo0P24Q8@208F5Q@80Q8B40P21PH4207alO080
QhN70P23Ph<20820P080O7al101nOWh208:2PP80P8200P21PH4207moO`@0PH610P22PX820820P080
OGem0P22PX820820P080Ph>3101mOGd30820P080Q8B40P23Ph<207moO`80PH610P1nOWh208:2PP80
Ng]k0P1lO7`208>3P`80P8200P23Ph<207alO080P8200P1mOGd207alO0H0b>3H0P1lO7`208N7Q`80
RHV90P20P80208:2PP80Ogmo0P1eMGD208:2PP80Ogmo0P1jNWX207UiN@80Rh^;0P1lO7`408>3P`80
Q8B40`1iNGT209ZJVP80P8200P1jNWX207emO@80RXZ:0P1nOWh207moO`80OGem0P24Q8@407emO@80
P8200P23Ph<20861P@80OWin101oOgl20861P@80Ng]k0P25QHD20820P080OWin0P22PX8208F5Q@80
PX:20P25QHD208B4Q080Ogmo0P1mOGd207alO080OGem0`22PX8207moO`80MgMg0P26QXH208>3P`80
Ng]k0P24Q8@207emO@80P8200P27QhL208>3P`80PX:20P1oOgl207UiN@80OWin0P1mOGd<0<SPf000
2P38h=P208b<S080OGem101nOWh208>3P`80Lg=c0P1lO7`207moO`80SXj>0P1cLg<207AdM080Lg=c
0P20P80208N7Q`80MgMg0P20P80308>3P`80NGUi0P22PX8207YjNP80PX:20P1kNg/207moO`80Q8B4
0P25QHD208B4Q080PH610P1lO7`208N7Q`80Ph>30P20P80207alO0@0OWin0P22PX820820P080PH61
0P1oOgl40861P@80PX:20P20P80207emO@80PX:20P20P80208>3P`@0OGem0`20P80208B4Q080Ph>3
0P1oOgl20861P@80OWin0P22PX8207]kN`80O7al0P23Ph<20820P080Ph>30P1lO7`20820P080OGem
0P1lO7`60<SPf080O7al0P27QhL208V9R@80P8200P22PX8207moO`80MGEe0P22PX8207moO`80NWYj
0P1iNGT208^;R`80O7al1023Ph<208B4Q0<0NGUi0P2JVYX20820P080NWYj0P1mOGd208Z:RP80OWin
0P1oOgl207emO@80Q8B4101mOGd20820P080Ph>30P21PH4207inOP@0Ogmo0P21PH4207]kN`80QHF5
0P20P80207inOP80PX:20P25QHD208:2PP80QHF50P24Q8@207moO`80OGem0P1lO7`207emO@<0PX:2
0P1oOgl207MgM`80QXJ60P23Ph<207]kN`80Q8B40P1mOGd20820P080QhN70P23Ph<208:2PP80Ogmo
0P1iNGT207inOP80OGem3038h=P000X0b>3H0P1dM7@407QhN080OGem0P22PX8207]kN`80P8201022
PX8207IfMP80MgMg0P25QHD207UiN@80O7al0P25QHD20861P@<0RXZ:0P2<S8`207inOP80MgMg0P1h
N7P208:2PP80O7al0P20P80407moO`80OGem0P1nOWh208F5Q@80PH610P1oOgl207inOP80Ph>30P21
PH4408:2PP80OWin0P22PX840861P@@0P8200P1lO7`207inOP80P8200P26QXH208B4Q080PH610`22
PX8208F5Q@@0OGem0P20P8020861P@80Ph>30P1lO7`208:2PP80O7al0P20P80207emO@80O7al0P1n
OWh207moO`80PX:21P38h=P207emO@80PX:20P28R8P20820P080NGUi0P1kNg/207alO080QhN71021
PH4208N7Q`80OWin0P28R8P208J6QP80OWin1@1mOGd207=cL`80Hf=S0P2CTi<207UiN@80RHV90P21
PH4207emO@80OWin0P1gMgL20820P080PX:20P1mOGd207inOP80Ph>30P1mOGd407alO080P8200P1n
OWh207emO@80PH610P1lO7`20820P080PH611023Ph<207QhN080OGem0P23Ph<208F5Q@80OGem0`22
PX8207emO@80P8200P1lO7`407emO@80QXJ60P1oOgl20820P080Ogmo1020P80207MgM`80QHF50P1l
O7`208:2PP`0b>3H000:0<SPf080M7Ad101hN7P207emO@80PX:20P1kNg/20820P0@0PX:20P1fMWH2
07MgM`80QHF50P1iNGT207alO080QHF50P21PH4308Z:RP80S8b<0P1nOWh207MgM`80N7Qh0P22PX82
07alO080P820101oOgl207emO@80OWin0P25QHD20861P@80Ogmo0P1nOWh208>3P`80PH611022PX82
07inOP80PX:21021PH440820P080O7al0P1nOWh20820P080QXJ60P24Q8@20861P@<0PX:20P25QHD4
07emO@80P8200P21PH4208>3P`80O7al0P22PX8207alO080P8200P1mOGd207alO080OWin0P1oOgl2
08:2PPH0b>3H0P1mOGd208:2PP80R8R80P20P80207UiN@80Ng]k0P1lO7`208N7Q`@0PH610P27QhL2
07inOP80R8R80P26QXH207inOPD0OGem0P1cLg<206=SH`80Ti>C0P1iNGT208V9R@80PH610P1mOGd2
07inOP80MgMg0P20P80208:2PP80OGem0P1nOWh208>3P`80OGem101lO7`20820P080OWin0P1mOGd2
0861P@80O7al0P20P8020861P@@0Ph>30P1hN7P207emO@80Ph>30P25QHD207emO@<0PX:20P1mOGd2
0820P080O7al101mOGd208J6QP80Ogmo0P20P80207moO`@0P8200P1gMgL208F5Q@80O7al0P22PX8<
0<SPf0002P38h=P207]kN`80OWin0P1kNg/20820P080PH610P1mOGd20820P080Ph>30P1mOGd408n?
S`80NGUi0P1dM7@208N7Q`80M7Ad0P1jNWX307moO`80QXJ61020P80207MgM`80PH610P1nOWh208B4
Q080Ph>30P20P80208:2PP80OWin0P21PH4208N7Q`80Ph>30P1mOGd208>3P`80Ogmo0P1nOWh208B4
Q080PX:20P21PH4207inOP80Ph>30P1oOgl20861P@80PX:20P1mOGd207inOP80PX:20P20P8020861
P@<0OGem0P1nOWh40820P080OGem0P1lO7`207YjNP80P8200P1mOGd207QhN080O7al0P26QXH207mo
O`80P8200P1nOWh207]kN`H0b>3H0P1nOWh207]kN`80O7al0P1iNGT20820P080O7al0P21PH420820
P080O7al0P28R8P207YjNP80LG5a0P20P80207QhN0@0OGem0`24Q8@20861P@80Jf][0P2LW9`208:2
PP80N7Qh0P1oOgl208>3P`80OGem0P1lO7`20861P@80OWin0P2<S8`207inOP80OGem0P20P80208>3
P`80O7al0P1iNGT208:2PP80OGem101nOWh207emO@80PH610P26QXH20820P080Ph>30P1jNWX207em
O@80PH610P1kNg/308:2PP80P8200P1oOgl207emO@80Ogmo0P23Ph<207alO080Ng]k0P21PH4208:2
PP80PH610P1nOWh407moO`80O7al0P1oOgl<0<SPf0002P38h=P207]kN`80OWin0P1kNg/20820P080
PH610P1mOGd20820P080Ph>30P1mOGd408n?S`80NGUi0P1dM7@208N7Q`80M7Ad0P1jNWX307moO`80
QXJ61020P80207MgM`80PH610P1nOWh208B4Q080Ph>30P20P80208:2PP80OWin0P21PH4208N7Q`80
Ph>30P1mOGd208>3P`80Ogmo0P1nOWh208B4Q080PX:20P21PH4207inOP80Ph>30P1oOgl20861P@80
PX:20P1mOGd207inOP80PX:20P20P8020861P@<0OGem0P1nOWh40820P080OGem0P1lO7`207YjNP80
P8200P1mOGd207QhN080O7al0P26QXH207moO`80P8200P1nOWh207]kN`H0b>3H0P1nOWh207]kN`80
O7al0P1iNGT20820P080O7al0P21PH420820P080O7al0P28R8P207YjNP80LG5a0P20P80207QhN0@0
OGem0`24Q8@20861P@80Jf][0P2LW9`208:2PP80N7Qh0P1oOgl208>3P`80OGem0P1lO7`20861P@80
OWin0P2<S8`207inOP80OGem0P20P80208>3P`80O7al0P1iNGT208:2PP80OGem101nOWh207emO@80
PH610P26QXH20820P080Ph>30P1jNWX207emO@80PH610P1kNg/308:2PP80P8200P1oOgl207emO@80
Ogmo0P23Ph<207alO080Ng]k0P21PH4208:2PP80PH610P1nOWh407moO`80O7al0P1oOgl<0<SPf000
2P38h=P208f=S@80O7al0P1mOGd207QhN0@0Ogmo0P21PH4207]kN`80P820101oOgl207YjNP80PX:2
0P1eMGD208N7Q`80PH610`23Ph<208B4Q0@0QhN70P2<S8`207inOP80Ogmo0P20P80207alO080PX:2
0P1oOgl20861P@H0P8200P1kNg/207moO`80P820101mOGd607inOP80OGem0P1lO7`207moO`80OWin
0P1lO7`20861P@80O7al0P20P80507inOPH0OGem0P1nOWh207emO@80PH610P20P8020861P@80OWin
0P1kNg/20861P@80OWin0P27QhL207emO@80O7al1P38h=P207inOP80Q8B40P29RHT207EeM@80OWin
0P1oOgl207emO@80Ng]k0P20P80208>3P`80MWIf0P29RHT208>3P`80Q8B40P2<S8`208:2PP<0OWin
0P21PH4208:2PP80Ph>30P2=SHd207emO@80PH610P2;Rh/208F5Q@80PH610P1mOGd20820P080Ng]k
0P1mOGd20820P080PX:20P21PH4407emO@80O7al0P24Q8@207UiN@80OGem0P28R8P20861P@@0P820
1P1nOWh20861P@D0PX:20P24Q8@407moO`80Ph>30P1nOWh208F5Q@80PH610P25QHD20861P@80OWin
0P1jNWX208N7Q`80P8200P23Ph<20820P0`0b>3H000:0<SPf080SHf=0P1lO7`207emO@80N7Qh101o
Ogl20861P@80Ng]k0P20P80407moO`80NWYj0P22PX8207EeM@80QhN70P21PH4308>3P`80Q8B41027
QhL208b<S080OWin0P1oOgl20820P080O7al0P22PX8207moO`80PH611P20P80207]kN`80Ogmo0P20
P80407emO@H0OWin0P1mOGd207alO080Ogmo0P1nOWh207alO080PH610P1lO7`20820P0D0OWin1P1m
OGd207inOP80OGem0P21PH420820P080PH610P1nOWh207]kN`80PH610P1nOWh208N7Q`80OGem0P1l
O7`60<SPf080OWin0P24Q8@208V9R@80MGEe0P1nOWh207moO`80OGem0P1kNg/20820P080Ph>30P1f
MWH208V9R@80Ph>30P24Q8@208b<S080PX:20`1nOWh20861P@80PX:20P23Ph<208f=S@80OGem0P21
PH4208^;R`80QHF50P21PH4207emO@80P8200P1kNg/207emO@80P8200P22PX820861P@@0OGem0P1l
O7`208B4Q080NGUi0P1mOGd208R8R080PH611020P80607inOP80PH611@22PX8208B4Q0@0Ogmo0P23
Ph<207inOP80QHF50P21PH4208F5Q@80PH610P1nOWh207YjNP80QhN70P20P80208>3P`80P8203038
h=P000X0b>3H0P2<S8`20861P@80Ogmo0P24Q8@207UiN@80Ogmo0P1nOWh208>3P`80PH610P1kNg/2
07=cL`80SXj>0P1bLW8207YjNP80MWIf0P1eMGD307alO080PX:20P1nOWh20820P080PH610P1mOGd2
07alO080PX:20P1mOGd20861P@80Ogmo0P26QXH20861P@@0Ogmo0P22PX8207moO`80QXJ61021PH42
0820P080PX:20P25QHD207alO080Ng]k0P1nOWh407moO`80OGem0P22PX8207]kN`80Q8B40`1mOGd4
07alO080OWin0P22PX8207moO`80OGem0P24Q8@408>3P`80OGem0P1kNg/20820P080RHV90P25QHD2
07UiN@H0b>3H0P23Ph<207emO@80OWin0P28R8P207moO`80Ph>3101iNGT207YjNP80QXJ60P1gMgL2
0820P080KVi^0P1lO7`2075aL@80MgMg0`1iNGT20861P@80PX:20P1mOGd206e]K@80R8R80P1hN7P2
07MgM`80QHF50P26QXH20861P@80Ng]k0P20P80207moO`80OWin0P1mOGd207moO`80P8200P1iNGT2
08>3P`80Q8B40P21PH4208B4Q080Ph>30P20P80207moO`80PH610P1mOGd20861P@80Ogmo0P21PH42
08>3P`<0Ogmo0P24Q8@207YjNP80QhN70P20P80208>3P`80PX:2101nOWh207EeM@80QhN70P20P802
07moO`80O7al0P1jNWX208B4Q0`0b>3H000:0<SPf080S8b<0P21PH4207moO`80Q8B40P1iNGT207mo
O`80OWin0P23Ph<20861P@80Ng]k0P1cLg<208j>SP80LW9b0P1jNWX207IfMP80MGEe0`1lO7`208:2
PP80OWin0P20P8020861P@80OGem0P1lO7`208:2PP80OGem0P21PH4207moO`80QXJ60P21PH4407mo
O`80PX:20P1oOgl208J6QP@0PH610P20P80208:2PP80QHF50P1lO7`207]kN`80OWin101oOgl207em
O@80PX:20P1kNg/208B4Q0<0OGem101lO7`207inOP80PX:20P1oOgl207emO@80Q8B41023Ph<207em
O@80Ng]k0P20P80208V9R@80QHF50P1iNGT60<SPf080Ph>30P1mOGd207inOP80R8R80P1oOgl208>3
P`@0NGUi0P1jNWX208J6QP80MgMg0P20P80206i^KP80O7al0P1aLG4207MgM`<0NGUi0P21PH4208:2
PP80OGem0P1]KFd208R8R080N7Qh0P1gMgL208F5Q@80QXJ60P21PH4207]kN`80P8200P1oOgl207in
OP80OGem0P1oOgl20820P080NGUi0P23Ph<208B4Q080PH610P24Q8@208>3P`80P8200P1oOgl20861
P@80OGem0P21PH4207moO`80PH610P23Ph<307moO`80Q8B40P1jNWX208N7Q`80P8200P23Ph<208:2
PP@0OWin0P1eMGD208N7Q`80P8200P1oOgl207alO080NWYj0P24Q8@<0<SPf0002P38h=P207emO@80
PX:20P1kNg/20861P@80OWin0P1lO7`208J6QP80OWin0P23Ph<207IfMP80Q8B40P1lO7`2071`L080
Ogmo0P2>SXh208V9R@<0N7Qh0P1mOGd208>3P`80QHF50P2=SHd207MgM`80Lg=c0P22PX8208>3P`80
PX:20P1lO7`208F5Q@80PX:20P1hN7P20820P080O7al0P1oOgl208B4Q080P8200P24Q8@207emO@@0
Q8B40P1oOgl207QhN080P8200P24Q8@207moO`80P8200P1oOgl20820P080O7al0`1oOgl20861P@80
OWin0P1iNGT407inOP80Ogmo0P22PX840861P@80P8200P21PH4207emO@80QHF50P24Q8@207EeM@H0
b>3H0P1nOWh207moO`80QHF50P23Ph<207moO`80OGem0P1oOgl208:2PP80OGem0P24Q8@208V9R@80
Ogmo0P2?Shl207inOP80Ng]k0P2>SXh308V9R@80PX:20P21PH4207inOP80KFe]0P1_Kfl209FEU@80
MgMg0P1lO7`207moO`80O7al0P20P80207AdM0@0P8200P1lO7`407moO`80R8R80P1jNWX207moO`80
OGem0P1jNWX20861P@80PX:2101lO7`208V9R@80QXJ60P21PH4207emO@80Q8B40`25QHD208B4Q080
OGem0P24Q8@208>3P`80QhN70P20P80208B4Q080Ng]k1021PH4207moO`80QHF50P27QhL207moO`80
M7Ad3038h=P000X0b>3H0P1mOGd208:2PP80Ng]k0P21PH4207inOP80O7al0P26QXH207inOP80Ph>3
0P1fMWH208B4Q080O7al0P1`L70207moO`80SXj>0P29RHT307QhN080OGem0P23Ph<208F5Q@80SHf=
0P1gMgL207=cL`80PX:20P23Ph<208:2PP80O7al0P25QHD208:2PP80N7Qh0P20P80207alO080Ogmo
0P24Q8@20820P080Q8B40P1mOGd408B4Q080Ogmo0P1hN7P20820P080Q8B40P1oOgl20820P080Ogmo
0P20P80207alO0<0Ogmo0P21PH4207inOP80NGUi101nOWh207moO`80PX:21021PH420820P080PH61
0P1mOGd208F5Q@80Q8B40P1eMGD60<SPf080OWin0P1oOgl208F5Q@80Ph>30P1oOgl207emO@80Ogmo
0P22PX8207emO@80Q8B40P29RHT207moO`80Shn?0P1nOWh207]kN`80SXj>0`29RHT208:2PP80PH61
0P1nOWh206e]K@80Kfm_0P2EUID207MgM`80O7al0P1oOgl207alO080P8200P1dM7@40820P080O7al
101oOgl208R8R080NWYj0P1oOgl207emO@80NWYj0P21PH4208:2PP@0O7al0P29RHT208J6QP80PH61
0P1mOGd208B4Q0<0QHF50P24Q8@207emO@80Q8B40P23Ph<208N7Q`80P8200P24Q8@207]kN`@0PH61
0P1oOgl208F5Q@80QhN70P1oOgl207AdM0`0b>3H000:0<SPf080QHF50P1mOGd208B4Q0@0NWYj0P21
PH4207=cL`80Ogmo0P22PX8207moO`80NGUi0P1`L70208f=S@80L71`0P20P802079bLP<0SHf=0P20
P80207emO@80O7al0P26QXH208>3P`80N7Qh0P1fMWH208:2PP80O7al0P1oOgl208:2PP80Ogmo0P1l
O7`207emO@80NWYj0P1oOgl20820P080QXJ60P20P80207moO`80O7al0P1oOgl20820P080OGem0P1l
O7`207inOP80P8200P23Ph<20861P@80OGem0P23Ph<307moO`80PX:20P1mOGd208N7Q`80MWIf0P1k
Ng/208>3P`80PH610P1mOGd207inOP80Q8B40P1oOgl60820P080Lg=c1P38h=P208:2PP80Ogmo0P1k
Ng/208J6QP80Ng]k0P1mOGd207moO`80P8200P1nOWh208Z:RP80PH610P26QXH20861P@80MWIf0P2:
RXX207AdM0<0LW9b0P1lO7`208:2PP80Q8B40P21PH4206][J`80QhN70P2GUiL207moO`80QHF50P1n
OWh207moO`80PH610P20P80208F5Q@80P8200P1kNg/207alO080Q8B40P26QXH207YjNP80OWin0P26
QXH207inOP80Ogmo0P23Ph<208:2PP80P8200P1mOGd207UiN@@0OWin0`1jNWX207]kN`80QHF50P1k
Ng/207moO`80PX:20P20P80207inOP80O7al1021PH4207inOP80NWYj0P1mOGd208>3P`80QhN73038
h=P000X0b>3H0P25QHD207emO@80Q8B4101jNWX20861P@80Lg=c0P1oOgl208:2PP80Ogmo0P1iNGT2
071`L080SHf=0P1`L7020820P080LW9b0`2=SHd20820P080OGem0P1lO7`208J6QP80Ph>30P1hN7P2
07IfMP80PX:20P1lO7`207moO`80PX:20P1oOgl207alO080OGem0P1jNWX207moO`80P8200P26QXH2
0820P080Ogmo0P1lO7`207moO`80P8200P1mOGd207alO080OWin0P20P80208>3P`80PH610P1mOGd2
08>3P`<0Ogmo0P22PX8207emO@80QhN70P1fMWH207]kN`80Ph>30P21PH4207emO@80OWin0P24Q8@2
07moO`H0P8200P1cLg<60<SPf080PX:20P1oOgl207]kN`80QXJ60P1kNg/207emO@80Ogmo0P20P802
07inOP80RXZ:0P21PH4208J6QP80PH610P1fMWH208Z:RP80M7Ad0`1bLW8207alO080PX:20P24Q8@2
0861P@80Jf][0P27QhL209NGU`80Ogmo0P25QHD207inOP80Ogmo0P21PH420820P080QHF50P20P802
07]kN`80O7al0P24Q8@208J6QP80NWYj0P1nOWh208J6QP80OWin0P1oOgl208>3P`80PX:20P20P802
07emO@80NGUi101nOWh307YjNP80Ng]k0P25QHD207]kN`80Ogmo0P22PX820820P080OWin0P1lO7`4
0861P@80OWin0P1jNWX207emO@80Ph>30P27QhL<0<SPf0002P38h=P407inOP80PH610P1nOWh207Yj
NP80O7al0P23Ph<207YjNP@0Ogmo0P21PH420820P080OGem0P2=SHd208R8R080SXj>0`2?Shl207Yj
NP@0P8200P1oOgl208Z:RP80QhN70P1nOWh207QhN080P8200P21PH4207emO@@0OWin101kNg/207mo
O`80OWin0P22PX8207emO@80O7al101kNg/208:2PP80P8200P1mOGd207inOP80Ph>30P1lO7`208:2
PP80Ng]k0P21PH4308:2PP@0OWin0P20P80207]kN`80NGUi0P25QHD20861P@@0OWin0P23Ph<208:2
PP80P8200P1oOgl20820P080MWIf1P38h=P208F5Q@80PH61101nOWh208:2PP80Ng]k0P23Ph<207mo
O`@0Ph>30P1oOgl208>3P`80NWYj0P28R8P20820P080NGUi0`2?Shl20861P@80OGem0P1oOgl20820
P080Q8B40P1dM7@2065QH@80TI6A0P1kNg/208>3P`80QhN70P1kNg/208B4Q080PH610P1iNGT20820
P080OWin0P1iNGT208^;R`80Q8B40P20P8020861P@H0OWin0P25QHD208B4Q080Ogmo0P1lO7`207=c
L`80Ogmo1@1mOGd207]kN`80PX:2101oOgl40861P@@0P8200P24Q8@20820P080PX:20P27QhL20820
P080PX:23038h=P000X0b>3H101nOWh20861P@80OWin0P1jNWX207alO080Ph>30P1jNWX407moO`80
PH610P20P80207emO@80SHf=0P28R8P208j>SP<0Shn?0P1jNWX40820P080Ogmo0P2:RXX208N7Q`80
OWin0P1hN7P20820P080PH610P1mOGd407inOP@0Ng]k0P1oOgl207inOP80PX:20P1mOGd207alO0@0
Ng]k0P22PX820820P080OGem0P1nOWh208>3P`80O7al0P22PX8207]kN`80PH610`22PX8407inOP80
P8200P1kNg/207UiN@80QHF50P21PH4407inOP80Ph>30P22PX820820P080Ogmo0P20P80207IfMPH0
b>3H0P25QHD20861P@@0OWin0P22PX8207]kN`80Ph>30P1oOgl408>3P`80Ogmo0P23Ph<207YjNP80
R8R80P20P80207UiN@<0Shn?0P21PH4207emO@80Ogmo0P20P80208B4Q080M7Ad0P1QHF42096AT@80
Ng]k0P23Ph<208N7Q`80Ng]k0P24Q8@20861P@80NGUi0P20P80207inOP80NGUi0P2;Rh/208B4Q080
P8200P21PH4607inOP80QHF50P24Q8@207moO`80O7al0P1cLg<207moO`D0OGem0P1kNg/208:2PP@0
Ogmo1021PH440820P080Q8B40P20P80208:2PP80QhN70P20P80208:2PP`0b>3H000:0<SPf0@0PH61
0P22PX8207inOP80PX:20P1iNGT20820P080PX:20P25QHD20861P@80OWin0P1lO7`207EeM@80NWYj
0P22PX8208R8R0<0MGEe0P2<S8`207alO080Ogmo0P27QhL207inOP80R8R80P1bLW8208j>SP80O7al
0P20P8020861P@80P8200P1kNg/207moO`80P8200P22PX820820P080OWin0P1kNg/208>3P`80O7al
0P1nOWh208B4Q080Ogmo0P1lO7`20861P@80P8200P1nOWh207moO`80OGem1`21PH4208:2PP80Ng]k
0P21PH4207moO`80OGem1022PX8208>3P`80OWin101mOGd207YjNP80Ogmo0P1eMGD60<SPf080Ng]k
0P23Ph<207emO@80R8R80P1mOGd207QhN080NWYj0P26QXH207emO@80RXZ:0P1dM7@208B4Q080PX:2
0P29RHT208^;R`80QHF50`1jNWX207QhN080P8200P1jNWX207alO080OGem0P21PH4208R8R080Vi^K
0P25QHD207IfMP80QhN70P26QXH207]kN`80Q8B41020P80208J6QP80PH610P1mOGd207IfMP80Ogmo
0P21PH4408>3P`80MWIf0P1oOgl208:2PP80Ng]k0P1mOGd208J6QP80Ph>30`1fMWH20861P@80P820
0P1kNg/207YjNP80P8200P24Q8@208:2PP80Ogmo0P25QHD208B4Q080O7al0P1jNWX20861P@80P820
0P21PH4<0<SPf0002P38h=P40861P@80PX:20P1nOWh208:2PP80NGUi0P20P80208:2PP80QHF50P21
PH4207inOP80O7al0P1eMGD207YjNP80PX:20P28R8P307EeM@80S8b<0P1lO7`207moO`80QhN70P1n
OWh208R8R080LW9b0P2>SXh207alO080P8200P21PH420820P080Ng]k0P1oOgl20820P080PX:20P20
P80207inOP80Ng]k0P23Ph<207alO080OWin0P24Q8@207moO`80O7al0P21PH420820P080OWin0P1o
Ogl207emO@L0PH610P22PX8207]kN`80PH610P1oOgl207emO@@0PX:20P23Ph<207inOP@0OGem0P1j
NWX207moO`80MGEe1P38h=P207]kN`80Ph>30P1mOGd208R8R080OGem0P1hN7P207YjNP80QXJ60P1m
OGd208Z:RP80M7Ad0P24Q8@208:2PP80RHV90P2;Rh/208F5Q@<0NWYj0P1hN7P20820P080NWYj0P1l
O7`207emO@80PH610P28R8P209^KV`80QHF50P1fMWH208N7Q`80QXJ60P1kNg/208B4Q0@0P8200P26
QXH20861P@80OGem0P1fMWH207moO`80PH611023Ph<207IfMP80Ogmo0P22PX8207]kN`80OGem0P26
QXH208>3P`<0MWIf0P21PH420820P080Ng]k0P1jNWX20820P080Q8B40P22PX8207moO`80QHF50P24
Q8@207alO080NWYj0P21PH420820P080PH613038h=P000X0b>3H0P23Ph<207AdM080OWin0P23Ph<2
07emO@@0PX:20P1mOGd208B4Q080Ogmo0P22PX8208>3P`80NGUi0P22PX8208V9R@80SHf=0`1bLW82
071`L080QHF50P1gMgL207moO`80PH610P22PX8208B4Q080MGEe0P26QXH207YjNP80Q8B40P1lO7`2
0820P080PX:20P20P80208J6QP80OGem0P1lO7`207inOP@0O7al1020P80207]kN`80QhN70P1nOWh2
08>3P`80N7Qh0P1mOGd207alO080Lg=c0`1hN7P208V9R@80QXJ60P20P80207moO`80PX:20P1lO7`2
07inOP80Ogmo0P20P8020861P@80QXJ60P1mOGd208:2PP80OWin0P1gMgL60<SPf080P8200P2LW9`2
07moO`80R8R80P1lO7`208:2PP80QHF50P1kNg/208R8R0@0NWYj0P24Q8@207emO@80KVi^0P1aLG42
07QhN0<0R8R80P22PX8207QhN080PX:20P1oOgl207inOP80OGem0P21PH4208n?S`80UIFE0P2@T902
08B4Q080NWYj0P1lO7`207emO@80O7al0P1hN7P207YjNP80P8200P1mOGd208F5Q@@0OGem0P20P802
08:2PP80Ogmo101lO7`208B4Q080O7al0P26QXH207UiN@<0OWin0P1jNWX207UiN@80Q8B40P1lO7`2
08:2PP80QXJ60P22PX820820P080QHF50P20P80208>3P`80QHF50P1oOgl20820P080Ph>33038h=P0
00X0b>3H0P23Ph<207AdM080OWin0P23Ph<207emO@@0PX:20P1mOGd208B4Q080Ogmo0P22PX8208>3
P`80NGUi0P22PX8208V9R@80SHf=0`1bLW82071`L080QHF50P1gMgL207moO`80PH610P22PX8208B4
Q080MGEe0P26QXH207YjNP80Q8B40P1lO7`20820P080PX:20P20P80208J6QP80OGem0P1lO7`207in
OP@0O7al1020P80207]kN`80QhN70P1nOWh208>3P`80N7Qh0P1mOGd207alO080Lg=c0`1hN7P208V9
R@80QXJ60P20P80207moO`80PX:20P1lO7`207inOP80Ogmo0P20P8020861P@80QXJ60P1mOGd208:2
PP80OWin0P1gMgL60<SPf080P8200P2LW9`207moO`80R8R80P1lO7`208:2PP80QHF50P1kNg/208R8
R0@0NWYj0P24Q8@207emO@80KVi^0P1aLG4207QhN0<0R8R80P22PX8207QhN080PX:20P1oOgl207in
OP80OGem0P21PH4208n?S`80UIFE0P2@T90208B4Q080NWYj0P1lO7`207emO@80O7al0P1hN7P207Yj
NP80P8200P1mOGd208F5Q@@0OGem0P20P80208:2PP80Ogmo101lO7`208B4Q080O7al0P26QXH207Ui
N@<0OWin0P1jNWX207UiN@80Q8B40P1lO7`208:2PP80QXJ60P22PX820820P080QHF50P20P80208>3
P`80QHF50P1oOgl20820P080Ph>33038h=P000X0b>3H0P20P80207inOP80Q8B40P1oOgl20820P080
NWYj0P20P80207alO080P8200P1mOGd207]kN`80P8200P1lO7`208b<S080N7Qh0P1mOGd308b<S080
SXj>0P26QXH207MgM`80Ng]k0P20P80208B4Q080O7al0P1nOWh207]kN`80RXZ:0P1oOgl207alO080
PH610P24Q8@207inOP80QHF50P22PX820861P@80OWin0P22PX8207YjNP@0PX:20P21PH4208b<S080
N7Qh0P20P80208^;R`80P8200P2>SXh208n?S`<0MGEe0P2:RXX208N7Q`80Ogmo0P24Q8@208>3P`80
PH610P1nOWh207moO`80P8200P1nOWh208B4Q080P8201P1nOWh60<SPf080NGUi0P23Ph<207]kN`80
NWYj0P21PH420820P080PX:20P1nOWh2096AT@80QHF50P2=SHd208:2PP80PH610P23Ph<208^;R`80
TI6A0`26QXH208B4Q080Rh^;0P23Ph<20861P@80QXJ60P20P80208B4Q080NWYj0P2DU9@206MWI`80
RHV90P1kNg/207inOP80Ph>30P20P80207moO`80PH610P1nOWh207emO@80Ogmo0P20P80208J6QP80
P8200P1oOgl208b<S080QXJ60P1cLg<207YjNP80OWin0P1lO7`20820P0<0N7Qh0P1nOWh208B4Q080
MWIf0P20P80207moO`@0OWin0P27QhL20820P080PX:20P27QhL207moO`80OGem0P21PH4208N7Q``0
b>3H000:0<SPf080P8200P1nOWh208B4Q080Ogmo0P20P80207YjNP80P8200P1lO7`20820P080OGem
0P1kNg/20820P080O7al0P2<S8`207QhN080OGem0`2<S8`208j>SP80QXJ60P1gMgL207]kN`80P820
0P24Q8@207alO080OWin0P1kNg/208Z:RP80Ogmo0P1lO7`20861P@80Q8B40P1nOWh208F5Q@80PX:2
0P21PH4207inOP80PX:20P1jNWX408:2PP80PH610P2<S8`207QhN080P8200P2;Rh/20820P080SXj>
0P2?Shl307EeM@80RXZ:0P27QhL207moO`80Q8B40P23Ph<20861P@80OWin0P1oOgl20820P080OWin
0P24Q8@20820P0H0OWin1P38h=P207UiN@80Ph>30P1kNg/207YjNP80PH610P20P80208:2PP80OWin
0P2ATI4208F5Q@80SHf=0P22PX820861P@80Ph>30P2;Rh/2096AT@<0QXJ60P24Q8@208^;R`80Ph>3
0P21PH4208J6QP80P8200P24Q8@207YjNP80U9BD0P1WIfL208V9R@80Ng]k0P1nOWh208>3P`80P820
0P1oOgl20861P@80OWin0P1mOGd207moO`80P8200P26QXH20820P080Ogmo0P2<S8`208J6QP80Lg=c
0P1jNWX207inOP80O7al0P20P80307QhN080OWin0P24Q8@207IfMP80P8200P1oOgl407inOP80QhN7
0P20P80208:2PP80QhN70P1oOgl207emO@80PH610P27QhL<0<SPf0002P38h=P208:2PP80Ng]k0P1n
OWh207QhN080Ogmo0P21PH420820P080OGem0P23Ph<208j>SP80P8200P1nOWh20820P080NWYj0P1`
L70208J6QP<0MGEe0P26QXH2071`L080RXZ:0P1oOgl207emO@80PH610P1lO7`207moO`80OWin0P23
Ph<208:2PP80N7Qh0P1mOGd208J6QP80MWIf0P1iNGT208F5Q@80Ph>3101oOgl207alO080QHF50P1k
Ng/207moO`80QHF50P27QhL208:2PP80MgMg0P27QhL207QhN080RHV90`1jNWX207QhN080Ph>31022
PX8207UiN@@0PH610P1kNg/207UiN@80P8200P22PX820820P080Ph>30P1nOWh207emO@H0b>3H0P1m
OGd208>3P`80OGem1022PX8207QhN080PH610P2?Shl208J6QP80Lg=c0P2:RXX207UiN@80MWIf0P21
PH4208>3P`80Lg=c0`1ZJVX208>3P`80OWin0P1hN7P20820P080PX:20P1nOWh20861P@80P8200P1l
O7`209^KV`80Hf=S0P29RHT207emO@H0P8200P1mOGd207moO`80P8200P1nOWh208>3P`80NWYj0P1l
O7`208N7Q`@0PX:20P1jNWX207emO@80NWYj0P29RHT208J6QP<0P8200P1kNg/208N7Q`80QHF50P20
P80208B4Q080Ph>30P21PH420820P080NWYj0P1iNGT208B4Q080P8200P1jNWX20820P080O7al3038
h=P000X0b>3H0P22PX8207]kN`80OWin0P1hN7P207moO`80PH610P20P80207emO@80Ph>30P2>SXh2
0820P080OWin0P20P80207YjNP80L71`0P26QXH307EeM@80QXJ60P1`L70208Z:RP80Ogmo0P1mOGd2
0861P@80O7al0P1oOgl207inOP80Ph>30P22PX8207QhN080OGem0P26QXH207IfMP80NGUi0P25QHD2
08>3P`@0Ogmo0P1lO7`208F5Q@80Ng]k0P1oOgl208F5Q@80QhN70P22PX8207MgM`80QhN70P1hN7P2
08V9R@<0NWYj0P1hN7P208>3P`@0PX:20P1iNGT40861P@80Ng]k0P1iNGT20820P080PX:20P20P802
08>3P`80OWin0P1mOGd60<SPf080OGem0P23Ph<207emO@@0PX:20P1hN7P20861P@80Shn?0P26QXH2
07=cL`80RXZ:0P1iNGT207IfMP80PH610P23Ph<207=cL`<0JVYZ0P23Ph<207inOP80N7Qh0P20P802
08:2PP80OWin0P21PH420820P080O7al0P2KVi/206=SH`80RHV90P1mOGd60820P080OGem0P1oOgl2
0820P080OWin0P23Ph<207YjNP80O7al0P27QhL408:2PP80NWYj0P1mOGd207YjNP80RHV90P26QXH3
0820P080Ng]k0P27QhL208F5Q@80P8200P24Q8@208>3P`80PH610P20P80207YjNP80NGUi0P24Q8@2
0820P080NWYj0P20P80207alO0`0b>3H000:0<SPf080PH610P1lO7`207inOP80Q8B40P21PH4207in
OP80PH61101nOWh207QhN080Q8B40P21PH4207moO`80Q8B40P1mOGd20861P@<0SHf=0P26QXH207mo
O`@0O7al0P1mOGd407alO080OWin0P21PH420820P080OWin0P28R8P207moO`80Ph>30P1nOWh207em
O@80Ogmo0P1nOWh208>3P`80NWYj0P1nOWh208:2PP80L71`0P2>SXh207moO`80P8200P23Ph<20820
P080O7al0P21PH4208:2PP<0OWin0P1oOgl208>3P`80PH61101oOgl408>3P`80PX:20P23Ph<20861
P@80O7al0P21PH4208>3P`80O7al0P1jNWX60<SPf080PH610P25QHD20861P@80QXJ60P1nOWh40820
P080OWin0P1lO7`207IfMP80S8b<0P20P80207QhN080P8200P1RHV8207AdM0<0OWin0P27QhL207Yj
NP80PX:20P1oOgl20861P@80QhN70P1oOgl40820P080NGUi0P2FUYH206ATI080Q8B40P1mOGd208:2
PP80Ogmo1022PX8207YjNP80Q8B40P20P8020861P@80MgMg0P2CTi<207inOP80QhN70P22PX820820
P080R8R81020P80307inOP80Ogmo0P22PX8208>3P`80NWYj0P1hN7P40861P@80Q8B40P1gMgL207in
OP80QHF50P20P80408J6QP80R8R83038h=P000X0b>3H0P21PH4207alO080OWin0P24Q8@20861P@80
OWin0P21PH4407inOP80N7Qh0P24Q8@20861P@80Ogmo0P24Q8@207emO@80PH610`2=SHd208J6QP80
Ogmo101lO7`207emO@@0O7al0P1nOWh20861P@80P8200P1nOWh208R8R080Ogmo0P23Ph<207inOP80
OGem0P1oOgl207inOP80Ph>30P1jNWX207inOP80PX:20P1`L70208j>SP80Ogmo0P20P80208>3P`80
P8200P1lO7`20861P@80PX:20`1nOWh207moO`80Ph>30P21PH4407moO`@0Ph>30P22PX8208>3P`80
PH610P1lO7`20861P@80Ph>30P1lO7`207YjNPH0b>3H0P21PH4208F5Q@80PH610P26QXH207inOP@0
P8200P1nOWh207alO080MWIf0P2<S8`20820P080N7Qh0P20P802069RHP80M7Ad0`1nOWh208N7Q`80
NWYj0P22PX8207moO`80PH610P27QhL207moO`@0P8200P1iNGT209JFUP80I6AT0P24Q8@207emO@80
PX:20P1oOgl408:2PP80NWYj0P24Q8@20820P080PH610P1gMgL209>CT`80OWin0P27QhL208:2PP80
P8200P28R8P40820P0<0OWin0P1oOgl208:2PP80Ph>30P1jNWX207QhN0@0PH610P24Q8@207MgM`80
OWin0P25QHD20820P0@0QXJ60P28R8P<0<SPf0002P38h=P208:2PP80PH610P24Q8@207UiN@80OWin
0P29RHT207=cL`80Q8B40P21PH4208B4Q080LW9b0P25QHD207alO080OGem0P1gMgL208Z:RP<0LG5a
0P2?Shl207=cL`80QXJ60P2?Shl207QhN080P8200P1nOWh208:2PP80OGem0P20P80207alO080OGem
0P26QXH207emO@80Q8B40P1iNGT207moO`80Rh^;0P20P80207UiN@80O7al0P25QHD207moO`80OGem
0P22PX8207inOP80PX:20P1nOWh207]kN`80OWin0P20P8030861P@80P8200P1iNGT208>3P`80OGem
0P2?Shl208J6QP80N7Qh0P23Ph<207YjNP80OGem0P1oOgl207alO080OGem0P22PX8207UiN@H0b>3H
0P2;Rh/208b<S080RHV90P25QHD207inOP80PX:20P25QHD208>3P`80Ng]k0P1gMgL208:2PP@0Ogmo
101kNg/208R8R0<0QhN70P24Q8@208b<S080PH610P1hN7P208F5Q@80PH610P1lO7`20861P@80P820
0P1hN7P207emO@80T92@0P1SHf<208b<S080QXJ60P20P8040861P@80P8200P1lO7`208B4Q080N7Qh
0P24Q8@207UiN@80PX:20P23Ph<207IfMP80QXJ60P29RHT207alO080Ogmo0`1lO7`207moO`80NWYj
0P1lO7`207emO@80NGUi0P1nOWh207YjNP80Ogmo0P20P80207]kN`80Ph>30P28R8P408>3P`80P820
3038h=P000X0b>3H0P22PX820861P@80Q8B40P1iNGT207inOP80RHV90P1cLg<208B4Q080PH610P24
Q8@2079bLP80QHF50P1lO7`207emO@80MgMg0P2:RXX3075aL@80Shn?0P1cLg<208J6QP80Shn?0P1h
N7P20820P080OWin0P22PX8207emO@80P8200P1lO7`207emO@80QXJ60P1mOGd208B4Q080NGUi0P1o
Ogl208^;R`80P8200P1iNGT207alO080QHF50P1oOgl207emO@80PX:20P1nOWh208:2PP80OWin0P1k
Ng/207inOP80P8200`21PH420820P080NGUi0P23Ph<207emO@80Shn?0P26QXH207QhN080Ph>30P1j
NWX207emO@80Ogmo0P1lO7`207emO@80PX:20P1iNGT60<SPf080Rh^;0P2<S8`208V9R@80QHF50P1n
OWh208:2PP80QHF50P23Ph<207]kN`80MgMg0P22PX8407moO`@0Ng]k0P28R8P308N7Q`80Q8B40P2<
S8`20861P@80N7Qh0P25QHD20861P@80O7al0P21PH420820P080N7Qh0P1mOGd2092@T080Hf=S0P2<
S8`208J6QP80P8201021PH420820P080O7al0P24Q8@207QhN080Q8B40P1iNGT208:2PP80Ph>30P1f
MWH208J6QP80RHV90P1lO7`207moO`<0O7al0P1oOgl207YjNP80O7al0P1mOGd207UiN@80OWin0P1j
NWX207moO`80P8200P1kNg/208>3P`80R8R81023Ph<20820P0`0b>3H000:0<SPf080QXJ60P1lO7`2
08F5Q@80QhN70P25QHD207inOP80QHF50P24Q8@207inOP80Ogmo0P20P80207UiN@80PH610P1mOGd2
07UiN@80OWin0`1dM7@208V9R@80M7Ad0P1iNGT207]kN`@0P8200P1gMgL207moO`80PX:20P21PH42
0820P080O7al0P1oOgl208V9R@80PX:20P20P80207inOP80Ph>30P22PX8207IfMP80Q8B40P22PX82
07]kN`80Ph>30P1jNWX208V9R@@0PX:20P24Q8@207YjNP80Ogmo0`20P80207alO080Ogmo1022PX82
08J6QP80M7Ad0P20P80207alO080PH610P23Ph<207alO080P8200P1nOWh20820P080MgMg1P38h=P2
07moO`80Q8B40P22PX8207UiN@@0PH610P1gMgL207moO`80RHV90P1fMWH207]kN`80QHF50P26QXH2
07emO@80Ph>30P1lO7`30861P@80PX:20P1/K6`208V9R@80RXZ:0P1nOWh207UiN@80Ogmo0P20P802
08:2PP@0OWin0P20P80209bLW080IFEU0P1iNGT207alO080Ng]k0P1mOGd208>3P`80PX:20P20P802
07alO080MWIf0P2<S8`208F5Q@80NGUi0P28R8P207MgM`80MGEe0P26QXH207UiN@<0P8200P1nOWh2
0820P080O7al0P22PX8208V9R@80P8200P1lO7`207]kN`80Ogmo0P1kNg/607emO@80P8200P23Ph<<
0<SPf0002P38h=P208J6QP80O7al0P25QHD208N7Q`80QHF50P1nOWh208F5Q@80Q8B40P1nOWh207mo
O`80P8200P1iNGT20861P@80OGem0P1iNGT207inOP<0M7Ad0P29RHT207AdM080NGUi0P1kNg/40820
P080MgMg0P1oOgl208:2PP80PH610P20P80207alO080Ogmo0P29RHT208:2PP80P8200P1nOWh208>3
P`80PX:20P1fMWH208B4Q080PX:20P1kNg/208>3P`80NWYj0P29RHT408:2PP80Q8B40P1jNWX207mo
O`<0P8200P1lO7`207moO`@0PX:20P26QXH207AdM080P8200P1lO7`20861P@80Ph>30P1lO7`20820
P080OWin0P20P80207MgM`H0b>3H0P1oOgl208B4Q080PX:20P1iNGT40861P@80MgMg0P1oOgl208V9
R@80MWIf0P1kNg/208F5Q@80QXJ60P1mOGd208>3P`80O7al0`21PH4208:2PP80K6a/0P29RHT208Z:
RP80OWin0P1iNGT207moO`80P8200P22PX8407inOP80P8200P2LW9`206EUI@80NGUi0P1lO7`207]k
N`80OGem0P23Ph<208:2PP80P8200P1lO7`207IfMP80S8b<0P25QHD207UiN@80R8R80P1gMgL207Ee
M@80QXJ60P1iNGT30820P080OWin0P20P80207alO080PX:20P29RHT20820P080O7al0P1kNg/207mo
O`80Ng]k1P1mOGd20820P080Ph>33038h=P000X0b>3H0P28R8P207moO`80QXJ60P24Q8@207YjNP80
Q8B41022PX8207moO`80PH610P25QHD207moO`80OGem0P1oOgl407alO0<0Q8B40P20P80207YjNP80
Q8B40P2>SXh208^;R`80P8200P25QHD207inOP@0O7al0P1mOGd208B4Q080OWin0P23Ph<208R8R080
MgMg0P1mOGd20820P080OGem0P1lO7`20861P@80Lg=c0P28R8P207=cL`80SHf=0P1iNGT208F5Q@80
P8200P1hN7P207EeM@80Q8B40`29RHT207alO080Ogmo0P1kNg/207moO`80Shn?0P2=SHd208Z:RP80
MWIf0P24Q8@207inOP80PH610P20P80207alO080PH610P1hN7P60<SPf080Kfm_0P1kNg/207inOP80
S8b<0P20P80207EeM@80NWYj0P21PH42079bLP80SHf=0P22PX8208B4Q080R8R80P1iNGT207YjNP80
QHF50`28R8P208J6QP80TI6A0P1hN7P207inOP80P8200P21PH4207QhN080QhN70P21PH4208J6QP@0
P8200P1hN7P209nOW`80JFUY0P1oOgl208:2PP80S8b<0P1gMgL207UiN@80OGem0P26QXH40820P080
K6a/0P1nOWh208F5Q@80LG5a0P23Ph<207YjNP80Ph>30`1nOWh20861P@80OGem0P23Ph<207alO080
QhN70P1nOWh207moO`80PH610P1nOWh208>3P`80PX:20P21PH420820P080PX:20P1nOWh<0<SPf000
2P38h=P208R8R080Ogmo0P26QXH208B4Q080NWYj0P24Q8@408:2PP80Ogmo0P21PH4208F5Q@80Ogmo
0P1mOGd207moO`@0O7al0`24Q8@20820P080NWYj0P24Q8@208j>SP80Rh^;0P20P80208F5Q@80OWin
101lO7`207emO@80Q8B40P1nOWh208>3P`80R8R80P1gMgL207emO@80P8200P1mOGd207alO080PH61
0P1cLg<208R8R080Lg=c0P2=SHd207UiN@80QHF50P20P80207QhN080MGEe0P24Q8@308V9R@80O7al
0P1oOgl207]kN`80Ogmo0P2?Shl208f=S@80RXZ:0P1fMWH208B4Q080OWin0P21PH420820P080O7al
0P21PH4207QhN0H0b>3H0P1_Kfl207]kN`80OWin0P2<S8`20820P080MGEe0P1jNWX20861P@80LW9b
0P2=SHd208:2PP80Q8B40P28R8P207UiN@80NWYj0P25QHD308R8R080QXJ60P2ATI4207QhN080OWin
0P20P8020861P@80N7Qh0P27QhL20861P@80QXJ61020P80207QhN080WinO0P1YJFT207moO`80PX:2
0P2<S8`207MgM`80NGUi0P1mOGd208J6QP@0P8200P1/K6`207inOP80QHF50P1aLG4208>3P`80NWYj
0P23Ph<307inOP80PH610P1mOGd208>3P`80O7al0P27QhL207inOP80Ogmo0P21PH4207inOP80Ph>3
0P22PX820861P@80P8200P22PX8207inOP`0b>3H000:0<SPf080MgMg0P1nOWh207]kN`80R8R80P1g
MgL20820P0@0PX:20P20P80208F5Q@80Q8B40P20P80208B4Q080Ng]k0P23Ph<208^;R`<0L71`0P1i
NGT208R8R080SXj>0P23Ph<207=cL`80Shn?0P1mOGd207YjNP80OWin0P21PH4207alO0@0PX:20P1i
NGT208N7Q`80N7Qh0P21PH4207emO@80P8200P1kNg/20820P080PH610P1nOWh2071`L080LW9b0P1h
N7P208J6QP80Rh^;0P1fMWH2071`L080PX:20`28R8P208:2PP80Ng]k0P1fMWH208F5Q@80P8200P1n
OWh208J6QP80O7al0P1mOGd208N7Q`80PX:20P1mOGd208F5Q@80Q8B40P1dM7@60<SPf080QXJ60P1i
NGT20861P@80N7Qh0P1fMWH207QhN080OGem0P20P80208^;R`80P8200P1lO7`208R8R080Ng]k0P20
P80208>3P`80MgMg1@1nOWh207emO@80M7Ad0P1iNGT208^;R`80N7Qh0P1jNWX208>3P`80P8200P1i
NGT20861P@80Q8B40P1iNGT206i^KP80J6QX0P1iNGT208B4Q080OWin0P1lO7`208R8R0@0OGem0P24
Q8@207inOP80QXJ60P2:RXX20820P080T92@0P23Ph<207IfMP80S8b<0`1jNWX207]kN`80PX:20P1l
O7`208F5Q@80Ti>C0P1nOWh208:2PP80Ng]k0P21PH4208>3P`80QXJ60P1nOWh207UiN@80NWYj0P23
Ph<<0<SPf0002P38h=P207MgM`80OWin0P1kNg/208R8R080MgMg0P20P80408:2PP80P8200P25QHD2
08B4Q080P8200P24Q8@207]kN`80Ph>30P2;Rh/3071`L080NGUi0P28R8P208j>SP80Ph>30P1cLg<2
08n?S`80OGem0P1jNWX207inOP80PH610P1lO7`408:2PP80NGUi0P27QhL207QhN080PH610P1mOGd2
0820P080Ng]k0P20P8020861P@80OWin0P1`L702079bLP80N7Qh0P26QXH208^;R`80MWIf0P1`L702
08:2PP<0R8R80P22PX8207]kN`80MWIf0P25QHD20820P080OWin0P26QXH207alO080OGem0P27QhL2
08:2PP80OGem0P25QHD208B4Q080M7Ad1P38h=P208J6QP80NGUi0P21PH4207QhN080MWIf0P1hN7P2
07emO@80P8200P2;Rh/20820P080O7al0P28R8P207]kN`80P8200P23Ph<207MgM`D0OWin0P1mOGd2
07AdM080NGUi0P2;Rh/207QhN080NWYj0P23Ph<20820P080NGUi0P21PH4208B4Q080NGUi0P1^KVh2
06QXJ080NGUi0P24Q8@207inOP80O7al0P28R8P407emO@80Q8B40P1nOWh208J6QP80RXZ:0P20P802
092@T080Ph>30P1fMWH208b<S0<0NWYj0P1kNg/208:2PP80O7al0P25QHD209>CT`80OWin0P22PX82
07]kN`80PH610P23Ph<208J6QP80OWin0P1iNGT207YjNP80Ph>33038h=P000X0b>3H1P1jNWX207Ee
M@80NWYj0P21PH420820P080Ng]k0P21PH4207moO`80N7Qh0P2;Rh/208R8R080MWIf0P2;Rh/207mo
O`<0O7al0P23Ph<207QhN080SHf=0P2>SXh2071`L080RXZ:0P1kNg/207alO080QhN70P1nOWh207Qh
N080PH610P23Ph<208F5Q@80MGEe0P2:RXX207alO080OWin0P20P80207emO@80OWin0P1mOGd208J6
QP80MgMg0P25QHD207UiN@80Ogmo101dM7@208F5Q@80MWIf0`1oOgl208F5Q@80R8R80P1oOgl208:2
PP80Lg=c0P2=SHd207QhN080OGem0P1oOgl20820P080N7Qh101oOgl208>3P`80Ng]k1P38h=P207mo
O`80Ph>30P1fMWH207MgM`80PX:20P1kNg/208>3P`80OWin0P1kNg/208>3P`80Shn?0P1]KFd206UY
J@80TY:B0P29RHT207inOP<0Ph>30P21PH4207emO@80P8200P29RHT207EeM@80QXJ60P2?Shl20861
P@80O7al0P1mOGd207moO`80PX:20P29RHT208:2PP80K6a/0P1SHf<207moO`80OWin0P25QHD207em
O@80QHF50P1hN7P207moO`80Ph>30P1mOGd207MgM`80N7Qh0P1mOGd206i^KP80P8200P1`L70508N7
Q`80OGem0P1hN7P208:2PP80N7Qh0P20P80207moO`80P8200P1nOWh208>3P`80OWin0P1fMWH207Mg
M`80OWin0P1jNWX<0<SPf0002P38h=P607YjNP80MGEe0P1jNWX20861P@80P8200P1kNg/20861P@80
Ogmo0P1hN7P208^;R`80R8R80P1fMWH208^;R`80Ogmo0`1lO7`208>3P`80N7Qh0P2=SHd208j>SP80
L71`0P2:RXX207]kN`80O7al0P27QhL207inOP80N7Qh0P21PH4208>3P`80QHF50P1eMGD208Z:RP80
O7al0P1nOWh20820P080OGem0P1nOWh207emO@80QXJ60P1gMgL208F5Q@80NGUi0P1oOgl407AdM080
QHF50P1fMWH307moO`80QHF50P28R8P207moO`80PX:20P1cLg<208f=S@80N7Qh0P1mOGd207moO`80
P8200P1hN7P407moO`80Ph>30P1kNg/60<SPf080Ogmo0P23Ph<207IfMP80MgMg0P22PX8207]kN`80
Ph>30P1nOWh207]kN`80Ph>30P2?Shl206e]K@80JFUY0P2BTY8208V9R@80OWin0`23Ph<20861P@80
OGem0P20P80208V9R@80MGEe0P26QXH208n?S`80PH610P1lO7`207emO@80Ogmo0P22PX8208V9R@80
PX:20P1/K6`206=SH`80Ogmo0P1nOWh208F5Q@80OGem0P25QHD207QhN080Ogmo0P23Ph<207emO@80
MgMg0P1hN7P207emO@80KVi^0P20P802071`L0D0QhN70P1mOGd207QhN080PX:20P1hN7P20820P080
Ogmo0P20P80207inOP80Ph>30P1nOWh207IfMP80MgMg0P1nOWh207YjNP`0b>3H000:0<SPf080RHV9
0P2=SHd208N7Q`@0N7Qh0P1oOgl208B4Q0@0OWin0P2:RXX207MgM`80Ph>30P29RHT207]kN`80PH61
0P1mOGd507inOP80L71`0P1gMgL208^;R`80QhN70P2=SHd208b<S080OWin0P20P80607alO080Ph>3
0P21PH4208:2PP80L71`0P1aLG4207=cL`80Q8B40P1fMWH20820P0@0OWin0P23Ph<208J6QP80Ogmo
0P23Ph<207moO`80PH610P1iNGT207YjNP<0QXJ60P25QHD207inOP80PH61101mOGd208B4Q080PH61
0P1oOgl20820P080OGem0P1nOWh208:2PP80Ogmo0P1nOWh207alO0H0b>3H0P1_Kfl2079bLP80QhN7
0P1gMgL207moO`80PH610P23Ph<208b<S080RXZ:0P2EUID2079bLP80SHf=0P1]KFd208^;R`80O7al
0P22PX8308Z:RP80MgMg0P1jNWX208Z:RP80QXJ60P1gMgL208B4Q080M7Ad0P1jNWX20861P@80Ogmo
0P24Q8@208>3P`80P8200P1oOgl20861P@80Jf][0P1QHF4208Z:RP80Ogmo0P1dM7@208:2PP80N7Qh
0P24Q8@20820P080PX:20P29RHT207moO`@0OWin0P2KVi/208:2PP<0QhN70P1nOWh208B4Q080O7al
0P1fMWH208>3P`@0PH610P1lO7`207inOP80PX:20P1oOgl207]kN`80QHF50P1nOWh20861P@`0b>3H
000:0<SPf080RHV90P2=SHd208N7Q`@0N7Qh0P1oOgl208B4Q0@0OWin0P2:RXX207MgM`80Ph>30P29
RHT207]kN`80PH610P1mOGd507inOP80L71`0P1gMgL208^;R`80QhN70P2=SHd208b<S080OWin0P20
P80607alO080Ph>30P21PH4208:2PP80L71`0P1aLG4207=cL`80Q8B40P1fMWH20820P0@0OWin0P23
Ph<208J6QP80Ogmo0P23Ph<207moO`80PH610P1iNGT207YjNP<0QXJ60P25QHD207inOP80PH61101m
OGd208B4Q080PH610P1oOgl20820P080OGem0P1nOWh208:2PP80Ogmo0P1nOWh207alO0H0b>3H0P1_
Kfl2079bLP80QhN70P1gMgL207moO`80PH610P23Ph<208b<S080RXZ:0P2EUID2079bLP80SHf=0P1]
KFd208^;R`80O7al0P22PX8308Z:RP80MgMg0P1jNWX208Z:RP80QXJ60P1gMgL208B4Q080M7Ad0P1j
NWX20861P@80Ogmo0P24Q8@208>3P`80P8200P1oOgl20861P@80Jf][0P1QHF4208Z:RP80Ogmo0P1d
M7@208:2PP80N7Qh0P24Q8@20820P080PX:20P29RHT207moO`@0OWin0P2KVi/208:2PP<0QhN70P1n
OWh208B4Q080O7al0P1fMWH208>3P`@0PH610P1lO7`207inOP80PX:20P1oOgl207]kN`80QHF50P1n
OWh20861P@`0b>3H000:0<SPf080QhN70P25QHD207IfMP80QXJ60P1iNGT208>3P`80P8200P1oOgl2
07EeM@80N7Qh0P1mOGd407inOP80OGem0P20P80207UiN@<0QXJ60P1eMGD207emO@80QHF50P1nOWh2
08f=S@80Q8B40P1dM7@208B4Q0@0Ng]k0P22PX8207moO`80Ph>30P1kNg/207moO`80SXj>0P2=SHd2
071`L080O7al0P1gMgL208:2PP80OGem0P21PH420820P080NWYj0P21PH4207]kN`80OGem0P1oOgl2
07=cL`80Q8B40`21PH4408>3P`80PH610P1jNWX208B4Q080P8200P21PH4208B4Q080O7al0P1mOGd2
08:2PP80OWin0P1lO7`208B4Q080OWin1P38h=P208J6QP80R8R80P2:RXX208:2PP80MWIf0P1lO7`2
07UiN@80RXZ:0P29RHT207MgM`80OWin1025QHD207]kN`80QHF50P22PX8307moO`80QHF50P1oOgl2
07IfMP80JFUY0P2:RXX20820P080QhN70P22PX8208B4Q080N7Qh0P1nOWh20861P@80PX:2101mOGd2
08:2PP80KVi^0P2KVi/208N7Q`80LG5a0P25QHD20861P@80P8200P22PX8207]kN`80PH610P24Q8@2
08F5Q@80N7Qh0P27QhL208f=S@<0MGEe0P1/K6`208>3P`80Rh^;0P1^KVh208F5Q@80OWin0P1kNg/2
08B4Q080M7Ad0P2:RXX208j>SP80NWYj0P1kNg/20861P@80Ogmo3038h=P000X0b>3H0P27QhL208F5
Q@80MWIf0P26QXH207UiN@80Ph>30P20P80207moO`80MGEe0P1hN7P207emO@@0OWin0P1mOGd20820
P080NGUi0`26QXH207EeM@80OGem0P25QHD207inOP80SHf=0P24Q8@207AdM080Q8B4101kNg/208:2
PP80Ogmo0P23Ph<207]kN`80Ogmo0P2>SXh208f=S@80L71`0P1lO7`207MgM`80PX:20P1mOGd20861
P@80P8200P1jNWX20861P@80Ng]k0P1mOGd207moO`80Lg=c0P24Q8@30861P@@0Ph>30P21PH4207Yj
NP80Q8B40P20P8020861P@80Q8B40P1lO7`207emO@80PX:20P1nOWh207alO080Q8B40P1nOWh60<SP
f080QXJ60P28R8P208Z:RP80PX:20P1fMWH207alO080NGUi0P2:RXX208V9R@80MgMg0P1nOWh408F5
Q@80Ng]k0P25QHD208:2PP<0Ogmo0P25QHD207moO`80MWIf0P1YJFT208Z:RP80P8200P27QhL208:2
PP80Q8B40P1hN7P207inOP80PH610P22PX8407emO@80PX:20P1^KVh209^KV`80QhN70P1aLG4208F5
Q@80PH610P20P80208:2PP80Ng]k0P21PH4208B4Q080QHF50P1hN7P208N7Q`80SHf=0`1eMGD206a/
K080Ph>30P2;Rh/206i^KP80QHF50P1nOWh207]kN`80Q8B40P1dM7@208Z:RP80SXj>0P1jNWX207]k
N`80PH610P1oOgl<0<SPf0002P38h=P2075aL@80Ng]k0P2;Rh/207inOP80O7al0P22PX8207YjNP80
PX:20P27QhL20861P@80PX:20P21PH4207moO`80MWIf0P20P80208B4Q0<0Ph>30P1gMgL207=cL`80
SXj>0P29RHT207]kN`80L71`0P27QhL2075aL@80O7al0P1oOgl20820P080PH610P23Ph<207moO`80
P8200P22PX8208>3P`80SHf=0P2>SXh207]kN`80QhN70P22PX820861P@80Ng]k0P26QXH207YjNP80
QHF50P23Ph<207inOP80Ng]k0P1nOWh508:2PP80OWin0P21PH4207=cL`80PX:20P20P80208B4Q080
QHF50P1nOWh208F5Q@80O7al0P1mOGd20861P@80OGem0P1lO7`60<SPf080OWin0P22PX840820P0@0
OGem0P1nOWh2079bLP80OWin0P1fMWH207emO@80PX:20P1oOgl207UiN@80O7al0P1gMgL307EeM@80
QXJ60P2ATI4208V9R@80UYJF0P2=SHd208b<S080R8R80P22PX8208b<S080QHF50P21PH4207inOP80
PH610P20P80208F5Q@80O7al0P26QXH206UYJ@80Vi^K0P2<S8`207QhN080PX:20P1kNg/208^;R`80
O7al0P21PH4207IfMP80NWYj0P1oOgl208N7Q`80O7al0`24Q8@20820P080Ogmo0P1cLg<206ATI080
P820101nOWh208J6QP80Q8B40P22PX820861P@80NWYj0P1nOWh20861P@80Q8B43038h=P000X0b>3H
0P1aLG4207]kN`80Rh^;0P1nOWh207alO080PX:20P1jNWX208:2PP80QhN70P21PH4208:2PP80PH61
0P1oOgl207IfMP80P8200P24Q8@308>3P`80MgMg0P1cLg<208j>SP80RHV90P1kNg/2071`L080QhN7
0P1aLG4207alO080Ogmo0P20P8020861P@80Ph>30P1oOgl20820P080PX:20P23Ph<208f=S@80SXj>
0P1kNg/208N7Q`80PX:20P21PH4207]kN`80QXJ60P1jNWX208F5Q@80Ph>30P1nOWh207]kN`80OWin
1@22PX8207inOP80PH610P1cLg<208:2PP80P8200P24Q8@208F5Q@80OWin0P25QHD207alO080OGem
0P21PH4207emO@80O7al1P38h=P207inOP80PX:21020P80407emO@80OWin0P1bLW8207inOP80MWIf
0P1mOGd208:2PP80Ogmo0P1iNGT207alO080MgMg0`1eMGD208J6QP80TI6A0P29RHT209JFUP80SHf=
0P2<S8`208R8R080PX:20P2<S8`208F5Q@80PH610P1nOWh20861P@80P8200P25QHD207alO080QXJ6
0P1YJFT209^KV`80S8b<0P1hN7P208:2PP80Ng]k0P2;Rh/207alO080PH610P1fMWH207YjNP80Ogmo
0P27QhL207alO0<0Q8B40P20P80207moO`80Lg=c0P1TI6@20820P0@0OWin0P26QXH208B4Q080PX:2
0P21PH4207YjNP80OWin0P21PH4208B4Q0`0b>3H000:0<SPf080P8200P25QHD207AdM0@0NWYj0P21
PH4207moO`80MgMg0P1bLW8208b<S080N7Qh0P22PX8207emO@80NGUi0P21PH4208:2PP<0NGUi0P1b
LW8207EeM@80NGUi0P2>SXh208R8R080LW9b0P2:RXX208j>SP80RXZ:0P1kNg/20861P@@0P8200P1k
Ng/208:2PP80QXJ60P23Ph<208N7Q`80LW9b0P2>SXh208F5Q@80OWin0P20P80207emO@80RXZ:0P1l
O7`207UiN@80MGEe0P1oOgl208N7Q`80LG5a0`1gMgL208b<S080MGEe0P20P80207IfMP80N7Qh0P2:
RXX407moO`80PH610P1oOgl40820P080PH610P1lO7`208:2PPH0b>3H0P1iNGT20861P@80Ti>C0P1o
Ogl207emO@80PX:20P21PH4207]kN`80PH610P22PX82079bLP80NWYj0P24Q8@207alO080LW9b0P1l
O7`308N7Q`80L71`0P1RHV8207inOP80Ng]k0P1eMGD206EUI@80PH610P24Q8@207IfMP80TI6A0P22
PX8207alO080OGem0P1kNg/20820P080PH610P1kNg/208B4Q080KVi^0P1TI6@206a/K080Ng]k0P20
P80208:2PP80RHV90P1kNg/207YjNP80NGUi0P1cLg<207UiN@80R8R80`2;Rh/207MgM`80SXj>0P2H
V9P208B4Q080T92@0P26QXH207alO080Ogmo0P1eMGD208B4Q080Ng]k0P22PX8207YjNP80OWin0P20
P80<0<SPf0002P38h=P20820P080QHF50P1dM7@407YjNP80PH610P1oOgl207MgM`80LW9b0P2<S8`2
07QhN080PX:20P1mOGd207UiN@80PH610P22PX8307UiN@80LW9b0P1eMGD207UiN@80SXj>0P28R8P2
079bLP80RXZ:0P2>SXh208Z:RP80Ng]k0P21PH440820P080Ng]k0P22PX8208J6QP80Ph>30P27QhL2
079bLP80SXj>0P25QHD207inOP80P8200P1mOGd208Z:RP80O7al0P1iNGT207EeM@80Ogmo0P27QhL2
075aL@<0MgMg0P2<S8`207EeM@80P8200P1fMWH207QhN080RXZ:101oOgl20861P@80Ogmo1020P802
0861P@80O7al0P22PX860<SPf080NGUi0P21PH4209>CT`80Ogmo0P1mOGd208:2PP80PH610P1kNg/2
0861P@80PX:20P1bLW8207YjNP80Q8B40P1lO7`2079bLP80O7al0`27QhL2071`L080HV9R0P1nOWh2
07]kN`80MGEe0P1UIFD20861P@80Q8B40P1fMWH2096AT@80PX:20P1lO7`207emO@80Ng]k0P20P802
0861P@80Ng]k0P24Q8@206i^KP80I6AT0P1/K6`207]kN`80P8200P22PX8208V9R@80Ng]k0P1jNWX2
07UiN@80Lg=c0P1iNGT208R8R0<0Rh^;0P1gMgL208j>SP80V9RH0P24Q8@2092@T080QXJ60P1lO7`2
07moO`80MGEe0P24Q8@207]kN`80PX:20P1jNWX207inOP80P8203038h=P000X0b>3H0P1oOgl208N7
Q`80Shn?0P2;Rh/207inOP80NWYj0P2>SXh207emO@80LG5a1021PH4407inOP80Q8B40P1oOgl207Ui
N@<0QHF50P1cLg<208V9R@80N7Qh0P26QXH2079bLP80MGEe0P23Ph<207alO080M7Ad0P24Q8@207in
OP80Ogmo0P22PX8207moO`80OWin0P20P80207moO`80MWIf0P25QHD207IfMP@0R8R80P1lO7`40861
P@80N7Qh0P26QXH207UiN@80Lg=c0P1lO7`207UiN@<0Lg=c0P1kNg/208J6QP80QhN70P23Ph<207in
OP80QHF50P22PX8207UiN@80PH610P20P80207]kN`80Ogmo0P23Ph<207alO080Ogmo1P38h=P207Ui
N@80Q8B40P23Ph<208B4Q080OGem0P2>SXh208^;R`80QhN70P1mOGd207moO`80NGUi0P1nOWh207If
MP80OWin0P2:RXX207emO@<0P8200P1ZJVX208n?S`@0QHF50P1gMgL208V9R@@0OGem0P24Q8@207Ee
M@80OGem0P20P8020861P@80OGem0P1nOWh208B4Q080QhN70P20P80207moO`80N7Qh0P2IVIT206=S
H`80Ph>30P22PX8207inOP80R8R80P23Ph<207]kN`80T92@0P27QhL207UiN@<0QXJ60P1iNGT207Qh
N080O7al0P22PX820861P@80O7al0P23Ph<407emO@80MGEe0P1lO7`207moO`80OGem1022PX8<0<SP
f0002P38h=P207moO`80QhN70P2?Shl208^;R`80OWin0P1jNWX208j>SP80OGem0P1aLG440861P@@0
OWin0P24Q8@207moO`80NGUi0`25QHD207=cL`80RHV90P1hN7P208J6QP80LW9b0P1eMGD208>3P`80
O7al0P1dM7@208B4Q080OWin0P1oOgl208:2PP80Ogmo0P1nOWh20820P080Ogmo0P1fMWH208F5Q@80
MWIf1028R8P207alO0@0PH610P1hN7P208J6QP80NGUi0P1cLg<207alO080NGUi0`1cLg<207]kN`80
QXJ60P27QhL208>3P`80OWin0P25QHD208:2PP80NGUi0P21PH420820P080Ng]k0P1oOgl208>3P`80
O7al0P1oOgl60<SPf080NGUi0P24Q8@208>3P`80Q8B40P1mOGd208j>SP80Rh^;0P27QhL207emO@80
Ogmo0P1iNGT207inOP80MWIf0P1nOWh208Z:RP80OGem0`20P80206YZJP80Shn?1025QHD207MgM`80
RHV9101mOGd208B4Q080MGEe0P1mOGd20820P080PH610P1mOGd207inOP80Q8B40P27QhL20820P080
Ogmo0P1hN7P209VIV@80Hf=S0P23Ph<208:2PP80OWin0P28R8P208>3P`80Ng]k0P2@T90208N7Q`80
NGUi0`26QXH207UiN@80N7Qh0P1lO7`208:2PP80PH610P1lO7`208>3P`@0OGem0P1eMGD207alO080
Ogmo0P1mOGd408:2PP`0b>3H000:0<SPf080PX:2102<S8`207emO@80PH610P1cLg<208n?S`80Ogmo
0P1cLg<207UiN@80P8200P1mOGd40820P080L71`0P2;Rh/307UiN@80Ng]k0P1cLg<207UiN@80MgMg
0P2:RXX207EeM@80Ogmo0P2:RXX207UiN@80Ogmo0P1mOGd40820P080O7al0P1oOgl20861P@80Ng]k
0P1hN7P207alO080QHF50P1kNg/207inOP80R8R80P1iNGT207moO`80PH610P1nOWh207YjNP80RHV9
0P1lO7`208:2PP<0NWYj0P2:RXX207AdM080N7Qh0P27QhL208B4Q080P820101jNWX207moO`80Ph>3
0P1lO7`208:2PP80P8200P1lO7`207emO@H0b>3H0P1iNGT20861P@80QXJ60P1jNWX208J6QP80UIFE
0P1dM7@208B4Q080Ng]k0P24Q8@407inOP80PX:20P1iNGT20820P080RXZ:0`1YJFT208f=S@80OGem
0P1oOgl208J6QP80QHF50P2=SHd208V9R@80QhN70P23Ph<208B4Q080P8200P1iNGT207YjNP80O7al
0P22PX8207alO080MgMg101oOgl407alO080QHF50P1QHF4208Z:RP80Ph>30P1mOGd207]kN`80Ogmo
0P1aLG4207inOP80QhN70`20P80408>3P`80Q8B40P1jNWX207]kN`80QXJ60P1kNg/208B4Q080QhN7
0P1nOWh207moO`80N7Qh0P1kNg/20861P@80O7al3038h=P000X0b>3H0P22PX8408b<S080OGem0P21
PH4207=cL`80Shn?0P1oOgl207=cL`80NGUi0P20P80207emO@@0P8200P1`L70208^;R`<0NGUi0P1k
Ng/207=cL`80NGUi0P1gMgL208Z:RP80MGEe0P1oOgl208Z:RP80NGUi0P1oOgl207emO@@0P8200P1l
O7`207moO`80PH610P1kNg/207QhN080O7al0P25QHD207]kN`80OWin0P28R8P207UiN@80Ogmo0P21
PH4207inOP80NWYj0P29RHT207alO080PX:20`1jNWX208Z:RP80M7Ad0P1hN7P208N7Q`80Q8B40P20
P80407YjNP80Ogmo0P23Ph<207alO080PX:20P20P80207alO080OGem1P38h=P207UiN@80PH610P26
QXH207YjNP80QXJ60P2EUID207AdM080Q8B40P1kNg/208B4Q0@0OWin0P22PX8207UiN@80P8200P2:
RXX306UYJ@80SHf=0P1mOGd207moO`80QXJ60P25QHD208f=S@80RHV90P27QhL208>3P`80Q8B40P20
P80207UiN@80NWYj0P1lO7`208:2PP80O7al0P1gMgL407moO`@0O7al0P25QHD2065QH@80RXZ:0P23
Ph<207emO@80Ng]k0P1oOgl2075aL@80OWin0P27QhL30820P0@0Ph>30P24Q8@207YjNP80Ng]k0P26
QXH207]kN`80Q8B40P27QhL207inOP80Ogmo0P1hN7P207]kN`80PH610P1lO7`<0<SPf0002P38h=P2
07emO@80QHF50P2>SXh20820P080Rh^;0P1mOGd608f=S@80SXj>0P1oOgl207UiN@80QhN70P26QXH2
07alO080P8200`26QXH208b<S080LW9b0P1aLG4208n?S`80OGem0P27QhL2071`L080QhN70P26QXH2
075aL@80RHV90P1iNGT208B4Q080PH610P1nOWh208B4Q080PX:20P1nOWh20820P080O7al0P25QHD2
0820P080Ng]k0P26QXH207]kN`80Ogmo0P1nOWh20820P080Rh^;0P1kNg/20861P@D0OGem1022PX82
07]kN`80P8200P23Ph<207inOP80Q8B40P1iNGT20820P080PX:20P1mOGd208B4Q080Ogmo0P1kNg/6
0<SPf080Ph>30P29RHT206m_K`80Lg=c0P2HV9P206QXJ080OWin0P1fMWH208V9R@80QHF5101oOgl2
0820P080MGEe0P2@T90209nOW`<0R8R80P1jNWX20820P080RXZ:0P1nOWh206m_K`80MGEe0P1_Kfl2
071`L080Ph>30P1gMgL207alO080RHV90P1nOWh208F5Q@@0OWin0P1jNWX207moO`80S8b<0P23Ph<2
07QhN080OGem0P1hN7P207AdM080R8R80P1lO7`207moO`80OGem0P26QXH207emO@80PH610`1mOGd2
07alO080QHF50P1aLG4207=cL`80PH610P2<S8`207moO`80OWin0P20P80208>3P`80OWin0P23Ph<2
07moO`80Ph>30P20P80<0<SPf0002P38h=P207emO@80QHF50P2>SXh20820P080Rh^;0P1mOGd608f=
S@80SXj>0P1oOgl207UiN@80QhN70P26QXH207alO080P8200`26QXH208b<S080LW9b0P1aLG4208n?
S`80OGem0P27QhL2071`L080QhN70P26QXH2075aL@80RHV90P1iNGT208B4Q080PH610P1nOWh208B4
Q080PX:20P1nOWh20820P080O7al0P25QHD20820P080Ng]k0P26QXH207]kN`80Ogmo0P1nOWh20820
P080Rh^;0P1kNg/20861P@D0OGem1022PX8207]kN`80P8200P23Ph<207inOP80Q8B40P1iNGT20820
P080PX:20P1mOGd208B4Q080Ogmo0P1kNg/60<SPf080Ph>30P29RHT206m_K`80Lg=c0P2HV9P206QX
J080OWin0P1fMWH208V9R@80QHF5101oOgl20820P080MGEe0P2@T90209nOW`<0R8R80P1jNWX20820
P080RXZ:0P1nOWh206m_K`80MGEe0P1_Kfl2071`L080Ph>30P1gMgL207alO080RHV90P1nOWh208F5
Q@@0OWin0P1jNWX207moO`80S8b<0P23Ph<207QhN080OGem0P1hN7P207AdM080R8R80P1lO7`207mo
O`80OGem0P26QXH207emO@80PH610`1mOGd207alO080QHF50P1aLG4207=cL`80PH610P2<S8`207mo
O`80OWin0P20P80208>3P`80OWin0P23Ph<207moO`80Ph>30P20P80<0<SPf0002P38h=P20820P080
QhN70P1iNGT208j>SP80Ogmo0P1mOGd207IfMP80PX:20P1nOWh207IfMP80QhN70P25QHD207MgM`80
QhN70P2?Shl207alO0<0R8R80P1kNg/208>3P`80L71`0P2<S8`207QhN080SHf=0P1nOWh208V9R@80
QXJ60P2:RXX207EeM@80R8R80P21PH4208:2PP80OWin0P1jNWX208>3P`80NWYj0P1lO7`207UiN@80
Q8B40P1nOWh208B4Q080NWYj0P27QhL40820P080Ph>30P1nOWh208:2PP80Ogmo0`1nOWh20820P080
PX:20P21PH420820P080Ogmo0P1nOWh20820P080Ogmo0P1lO7`207moO`80PH61101mOGd40820P0H0
b>3H0P1lO7`208n?S`@0Q8B40P1gMgL206e]K@80QHF50P29RHT208R8R080Ng]k0P1lO7`207moO`80
Rh^;0P28R8P207moO`80QXJ60`1gMgL207alO080QhN70P20P80207moO`80PX:20P21PH420820P080
Shn?0P1oOgl207inOP80QhN70P1_Kfl208V9R@80PH610P20P80207inOP80P8200P1nOWh208:2PP80
R8R80P22PX8207moO`80PH610P1fMWH208N7Q`80O7al0P20P80208B4Q080O7al0P1oOgl207]kN`<0
P8200P1jNWX208Z:RP80P8200P21PH4208>3P`80Q8B40P1kNg/20820P080QHF50P22PX8207]kN`80
PH610P20P80208B4Q080N7Qh3038h=P000X0b>3H0P20P80208N7Q`80NGUi0P2>SXh207moO`80OGem
0P1fMWH208:2PP80OWin0P1fMWH208N7Q`80QHF50P1gMgL208N7Q`80Shn?0P1lO7`308R8R080Ng]k
0P23Ph<2071`L080S8b<0P1hN7P208f=S@80OWin0P29RHT208J6QP80RXZ:0P1eMGD208R8R080PH61
0P22PX8207inOP80NWYj0P23Ph<207YjNP80O7al0P1iNGT208B4Q080OWin0P24Q8@207YjNP80QhN7
1020P80208>3P`80OWin0P22PX8207moO`<0OWin0P20P80208:2PP80PH610P20P80207moO`80OWin
0P20P80207moO`80O7al0P1oOgl20861P@@0OGem1020P8060<SPf080O7al0P2?Shl408B4Q080MgMg
0P1]KFd208F5Q@80RHV90P28R8P207]kN`80O7al0P1oOgl208^;R`80R8R80P1oOgl208J6QP<0MgMg
0P1lO7`208N7Q`80P8200P1oOgl208:2PP80PH610P20P80208n?S`80Ogmo0P1nOWh208N7Q`80Kfm_
0P29RHT20861P@80P8200P1nOWh20820P080OWin0P22PX8208R8R080PX:20P1oOgl20861P@80MWIf
0P27QhL207alO080P8200P24Q8@207alO080Ogmo0P1kNg/30820P080NWYj0P2:RXX20820P080PH61
0P23Ph<208B4Q080Ng]k0P20P80208F5Q@80PX:20P1kNg/20861P@80P8200P24Q8@207QhN0`0b>3H
000:0<SPf080P8200P27QhL207UiN@80SXj>0P1oOgl207emO@80MWIf0P22PX8207inOP80MWIf0P27
QhL208F5Q@80MgMg0P27QhL208n?S`80O7al0`28R8P207]kN`80Ph>30P1`L70208b<S080N7Qh0P2=
SHd207inOP80RHV90P26QXH208Z:RP80MGEe0P28R8P20861P@80PX:20P1nOWh207YjNP80Ph>30P1j
NWX207alO080NGUi0P24Q8@207inOP80Q8B40P1jNWX208N7Q`@0P8200P23Ph<207inOP80PX:20P1o
Ogl307inOP80P8200P22PX820861P@80P8200P1oOgl207inOP80P8200P1oOgl207alO080Ogmo0P21
PH4407emO@@0P8201P38h=P207alO080Shn?1024Q8@207MgM`80KFe]0P25QHD208V9R@80R8R80P1k
Ng/207alO080Ogmo0P2;Rh/208R8R080Ogmo0P26QXH307MgM`80O7al0P27QhL20820P080Ogmo0P22
PX820861P@80P8200P2?Shl207moO`80OWin0P27QhL206m_K`80RHV90P21PH420820P080OWin0P20
P80207inOP80PX:20P28R8P208:2PP80Ogmo0P21PH4207IfMP80QhN70P1lO7`20820P080Q8B40P1l
O7`207moO`80Ng]k0`20P80207YjNP80RXZ:0P20P8020861P@80Ph>30P24Q8@207]kN`80P8200P25
QHD208:2PP80Ng]k0P21PH420820P080Q8B40P1hN7P<0<SPf0002P38h=P408R8R080Ogmo0P22PX82
07UiN@80Ogmo0P1fMWH208B4Q080PH611020P80207moO`80NGUi0P1aLG4207QhN080NWYj0`1aLG42
08R8R080RHV90P1dM7@208B4Q080Ng]k0P1mOGd207MgM`80LG5a0P1hN7P208J6QP80PX:20P1bLW82
08N7Q`80P8200P25QHD207moO`80OWin0P1lO7`207emO@80O7al0P1oOgl20820P080OWin0P25QHD2
07]kN`80P8200P24Q8@20861P@80P8200P1mOGd208F5Q@L0NWYj0P21PH440820P080Ogmo101mOGd4
07inOP80P8200P1oOgl208>3P`80P8200P1kNg/60<SPf080Ogmo0P1jNWX208R8R080O7al0P1gMgL2
08F5Q@80PX:20P1gMgL207emO@80N7Qh0P1fMWH208N7Q`80Ng]k0P27QhL207IfMP80PX:20`1gMgL2
07EeM@80OGem0P27QhL207YjNP80P8200P24Q8@208b<S080WinO0P2DU9@207QhN080MWIf0P2DU9@2
07AdM080Ng]k0P27QhL20861P@80OWin0P1kNg/207emO@80Ng]k0P22PX8207inOP80PX:20P24Q8@2
07AdM080Vi^K0P2GUiL208J6QP80PX:20P1fMWH208N7Q`<0OGem0P1lO7`207MgM`80P8200P27QhL2
07alO080N7Qh0P27QhL20820P0@0O7al0P20P80208F5Q@80P8200P24Q8@207emO@`0b>3H000:0<SP
f0@0R8R80P1oOgl208:2PP80NGUi0P1oOgl207IfMP80Q8B40P21PH440820P080Ogmo0P1iNGT2075a
L@80N7Qh0P1jNWX3075aL@80R8R80P29RHT207AdM080Q8B40P1kNg/207emO@80MgMg0P1aLG4207Qh
N080QXJ60P22PX82079bLP80QhN70P20P80208F5Q@80Ogmo0P1nOWh207alO080OGem0P1lO7`207mo
O`80P8200P1nOWh208F5Q@80Ng]k0P20P80208B4Q080PH610P20P80207emO@80QHF51`1jNWX20861
P@@0P8200P1oOgl407emO@@0OWin0P20P80207moO`80Ph>30P20P80207]kN`H0b>3H0P1oOgl207Yj
NP80R8R80P1lO7`207MgM`80QHF50P22PX8207MgM`80OGem0P1hN7P207IfMP80QhN70P1kNg/208N7
Q`80MWIf0P22PX8307MgM`80MGEe0P1mOGd208N7Q`80NWYj0P20P80208B4Q080S8b<0P2OWil209BD
U080N7Qh0P1fMWH209BDU080M7Ad0P1kNg/208N7Q`80PH610P1nOWh207]kN`80OGem0P1kNg/208:2
PP80OWin0P22PX8208B4Q080M7Ad0P2KVi/209NGU`80QXJ60P22PX8207IfMP80QhN70`1mOGd207al
O080MgMg0P20P80208N7Q`80O7al0P1hN7P208N7Q`80P820101lO7`20820P080QHF50P20P80208B4
Q080OGem3038h=P000X0b>3H0P26QXH207alO080QHF50P1nOWh20861P@80Rh^;0P2>SXh208B4Q080
PH610P1lO7`20861P@80Ogmo0P1eMGD207UiN@80NWYj0P1lO7`3079bLP80Ogmo0P29RHT2071`L080
MGEe0P25QHD207alO080Ogmo0P29RHT2075aL@80QhN70P20P80207IfMP80PH61101nOWh208:2PP@0
Ph>30P24Q8@20861P@80PX:20P20P80208F5Q@@0PH610P23Ph<207YjNP80QHF50P22PX8207IfMP80
N7Qh0`1lO7`20861P@80Ph>30P1mOGd607inOP80Q8B40P1lO7`20820P080Ogmo0P1lO7`20820P080
PH610P1lO7`207YjNPH0b>3H0P29RHT207EeM@80Q8B40P1fMWH208Z:RP80NWYj0P28R8P208^;R`80
P8200P22PX820861P@80OWin0P25QHD208:2PP80LG5a0P1iNGT308>3P`80U9BD0P29RHT207inOP80
SXj>0P2;Rh/208b<S080NGUi0P1_Kfl2079bLP80NWYj0P28R8P207emO@80R8R80P1fMWH208B4Q080
PH610P22PX8208^;R`80PH610P1nOWh207YjNP80Ogmo0P1mOGd20861P@80NGUi0P1jNWX20820P080
QXJ60P20P80208J6QP80PX:21@1oOgl208F5Q@80O7al0P1oOgl207YjNP80QHF50P1oOgl207YjNP80
P8200P22PX8207MgM`80O7al0P1oOgl20861P@80P8203038h=P000X0b>3H0P26QXH207alO080QHF5
0P1nOWh20861P@80Rh^;0P2>SXh208B4Q080PH610P1lO7`20861P@80Ogmo0P1eMGD207UiN@80NWYj
0P1lO7`3079bLP80Ogmo0P29RHT2071`L080MGEe0P25QHD207alO080Ogmo0P29RHT2075aL@80QhN7
0P20P80207IfMP80PH61101nOWh208:2PP@0Ph>30P24Q8@20861P@80PX:20P20P80208F5Q@@0PH61
0P23Ph<207YjNP80QHF50P22PX8207IfMP80N7Qh0`1lO7`20861P@80Ph>30P1mOGd607inOP80Q8B4
0P1lO7`20820P080Ogmo0P1lO7`20820P080PH610P1lO7`207YjNPH0b>3H0P29RHT207EeM@80Q8B4
0P1fMWH208Z:RP80NWYj0P28R8P208^;R`80P8200P22PX820861P@80OWin0P25QHD208:2PP80LG5a
0P1iNGT308>3P`80U9BD0P29RHT207inOP80SXj>0P2;Rh/208b<S080NGUi0P1_Kfl2079bLP80NWYj
0P28R8P207emO@80R8R80P1fMWH208B4Q080PH610P22PX8208^;R`80PH610P1nOWh207YjNP80Ogmo
0P1mOGd20861P@80NGUi0P1jNWX20820P080QXJ60P20P80208J6QP80PX:21@1oOgl208F5Q@80O7al
0P1oOgl207YjNP80QHF50P1oOgl207YjNP80P8200P22PX8207MgM`80O7al0P1oOgl20861P@80P820
3038h=P000X0b>3H0P22PX82071`L080Q8B40P21PH4208J6QP80Lg=c0P29RHT207moO`80Ph>30P1n
OWh207moO`80NGUi0P1kNg/207=cL`80S8b<0P23Ph<308N7Q`80M7Ad0P1eMGD20861P@80SXj>0P27
QhL207UiN@80OGem0P25QHD208:2PP80Lg=c0P22PX8208V9R@80MgMg0P24Q8@207QhN080NWYj0P1m
OGd407alO080Ogmo0P1lO7`20820P080Ogmo0P1jNWX20861P@80OGem1020P8020861P@80Ng]k0P1m
OGd308B4Q080PH610P1nOWh20861P@80Ph>30P1iNGT208:2PP80Ogmo0P21PH4207inOP80P8200P1n
OWh207alO080Q8B40P21PH420820P0H0b>3H0P21PH4207emO@80MGEe0P2:RXX207EeM@80PH610P1T
I6@209FEU@80Ng]k0P20P80208R8R080N7Qh0P23Ph<208:2PP80QHF50P2<S8`307moO`80LG5a0P1n
OWh207EeM@80KVi^0P2IVIT208J6QP80Q8B40P1oOgl207QhN080K6a/0P1iNGT208F5Q@80Lg=c0P21
PH4207moO`80NGUi0P1lO7`208:2PP80Ogmo0P23Ph<208:2PP80Ng]k0P21PH4408:2PP80OWin0P29
RHT207emO@80P8200P1eMGD207inOP<0PH610P1nOWh208B4Q080P8200P1nOWh20820P080Ph>30P1j
NWX207QhN080P8200P1nOWh407alO080Ph>30P1kNg/207emO@`0b>3H000:0<SPf080PX:20P1`L702
08B4Q080PH610P26QXH207=cL`80RHV90P1oOgl208>3P`80OWin0P1oOgl207UiN@80Ng]k0P1cLg<2
08b<S080Ph>30`27QhL207AdM080MGEe0P21PH4208j>SP80QhN70P1iNGT207emO@80QHF50P22PX82
07=cL`80PX:20P29RHT207MgM`80Q8B40P1hN7P207YjNP80OGem101lO7`207moO`80O7al0P20P802
07moO`80NWYj0P21PH4207emO@@0P8200P21PH4207]kN`80OGem0`24Q8@20861P@80OWin0P21PH42
08>3P`80NGUi0P22PX8207moO`80PH610P1nOWh20820P080OWin0P1lO7`208B4Q080PH610P20P806
0<SPf080PH610P1mOGd207EeM@80RXZ:0P1eMGD20861P@80I6AT0P2EUID207]kN`80P8200P28R8P2
07QhN080Ph>30P22PX8208F5Q@80S8b<0`1oOgl2075aL@80OWin0P1eMGD206i^KP80VIVI0P26QXH2
08B4Q080Ogmo0P1hN7P206a/K080NGUi0P25QHD207=cL`80PH610P1oOgl207UiN@80O7al0P22PX82
07moO`80Ph>30P22PX8207]kN`80PH611022PX8207inOP80RHV90P1mOGd20820P080MGEe0P1nOWh3
0861P@80OWin0P24Q8@20820P080OWin0P20P80208>3P`80NWYj0P1hN7P20820P080OWin101lO7`2
08>3P`80Ng]k0P1mOGd<0<SPf0002P38h=P207MgM`80QhN70P1bLW8207alO080OGem0P28R8P208f=
S@80PH611028R8P207YjNP80MWIf0P23Ph<208R8R080N7Qh0P1eMGD308F5Q@80MWIf0P1kNg/2071`
L080OWin0P22PX82071`L080O7al0P22PX8208f=S@80MWIf0P28R8P20861P@80RHV90P2?Shl208V9
R@80OGem0P1oOgl208:2PP80P8200P21PH4207UiN@80OGem0P22PX8207UiN@80Ng]k0P26QXH207If
MP80Ph>30P22PX8207alO080PX:20`1nOWh207alO080OWin0P21PH4408:2PP80Ogmo0P1nOWh207]k
N`80Ph>30P20P80207inOP80P8200P21PH4208:2PP80Ng]k1P38h=P207alO080Ogmo0P1nOWh2075a
L@80NGUi0P29RHT208Z:RP80Shn?0P21PH4407MgM`80QHF50P28R8P207inOP80KFe]0P1mOGd307mo
O`80OWin0P1_Kfl208F5Q@80Q8B40P2<S8`206e]K@80Ogmo0P26QXH207moO`80Ph>30P1bLW8208B4
Q080OWin0P1eMGD207]kN`80PH610P1lO7`20861P@80Q8B40P20P80208:2PP80Ogmo0P1iNGT207in
OP80PX:2101nOWh208>3P`80P8200P1lO7`207emO@<0Ogmo0P1mOGd208>3P`80O7al1026QXH208:2
PP80OWin0P23Ph<208F5Q@80OWin0P22PX820820P080PH610P1nOWh20820P0`0b>3H000:0<SPf080
MgMg0P27QhL2079bLP80O7al0P1mOGd208R8R080SHf=0P21PH4408R8R080NWYj0P1fMWH208>3P`80
R8R80P1hN7P207EeM@<0QHF50P1fMWH207]kN`80L71`0P1nOWh208:2PP80L71`0P1lO7`208:2PP80
SHf=0P1fMWH208R8R080PH610P29RHT208n?S`80RHV90P1mOGd207moO`80PX:20P20P8020861P@80
NGUi0P1mOGd208:2PP80NGUi0P1kNg/208J6QP80MWIf0P23Ph<208:2PP80O7al0P22PX8307inOP80
O7al0P1nOWh20861P@@0PX:20P1oOgl207inOP80Ng]k0P23Ph<20820P080OWin0P20P8020861P@80
PX:20P1kNg/60<SPf080O7al0P1oOgl207inOP80LG5a0P1iNGT208V9R@80RXZ:0P2?Shl20861P@@0
MgMg0P25QHD208R8R080OWin0P1]KFd207emO@<0Ogmo0P1nOWh206m_K`80QHF50P24Q8@208b<S080
KFe]0P1oOgl208J6QP80Ogmo0P23Ph<2079bLP80Q8B40P1nOWh207EeM@80Ng]k0P21PH4207alO080
PH610P24Q8@20820P080PX:20P1oOgl207UiN@80OWin0P22PX8407inOP80Ph>30P20P80207alO080
OGem0`1oOgl207emO@80Ph>30P1lO7`408J6QP80PX:20P1nOWh208>3P`80QHF50P1nOWh208:2PP80
P8200P21PH4207inOP80P8203038h=P000X0b>3H0P1jNWX208f=S@80SXj>0P24Q8@20820P080NGUi
0P20P80207IfMP80SHf=0P1gMgL208:2PP80OGem0P23Ph<407emO@80NGUi0`26QXH208j>SP80OWin
0P1kNg/207YjNP80OWin0P23Ph<207inOP@0Ogmo0P23Ph<207IfMP80PX:20P1mOGd208F5Q@80LW9b
0P2;Rh/207YjNP80PX:20P21PH4207inOP80N7Qh0P22PX840820P080PX:20P2:RXX2079bLP80OWin
0P29RHT20820P080PH610`20P8020861P@80OGem0P20P8020861P@80PX:20P23Ph<20861P@80Ph>3
0P20P80207moO`80PX:20P1nOWh208>3P`80P8200P1kNg/60<SPf080NGUi0P1]KFd208:2PP80PH61
0P22PX8207moO`80PX:20P2=SHd208B4Q080O7al0P27QhL207YjNP80P8200P1lO7`207UiN@80QXJ6
0`1oOgl207IfMP80NWYj0P1hN7P208f=S@80LW9b0P27QhL208:2PP80O7al0P1mOGd208f=S@80UYJF
0P2ATI4208Z:RP80Ph>30P25QHD207QhN080PX:20P1oOgl20861P@80OWin0P23Ph<207moO`80OWin
1022PX8208Z:RP80Q8B40P1hN7P208>3P`80OGem0P1nOWh308J6QP80Ogmo0P20P80207]kN`80P820
0P1kNg/208F5Q@80QhN70P22PX8207inOP80O7al0P23Ph<208J6QP80P8200P1nOWh207alO0`0b>3H
000:0<SPf080NWYj0P2=SHd208j>SP80Q8B40P20P80207UiN@80P8200P1fMWH208f=S@80MgMg0P22
PX8207emO@80Ph>3101mOGd207UiN@<0QXJ60P2>SXh207inOP80Ng]k0P1jNWX207inOP80Ph>30P1n
OWh407moO`80Ph>30P1fMWH208:2PP80OGem0P25QHD2079bLP80Rh^;0P1jNWX208:2PP80PH610P1n
OWh207QhN080PX:21020P80208:2PP80RXZ:0P1bLW8207inOP80RHV90P20P8020861P@<0P8200P21
PH4207emO@80P8200P21PH4208:2PP80Ph>30P21PH4208>3P`80P8200P1oOgl208:2PP80OWin0P23
Ph<20820P080Ng]k1P38h=P207UiN@80KFe]0P22PX820861P@80PX:20P1oOgl208:2PP80SHf=0P24
Q8@207alO080QhN70P1jNWX20820P080O7al0P1iNGT208J6QP<0Ogmo0P1fMWH207YjNP80N7Qh0P2=
SHd2079bLP80QhN70P22PX8207alO080OGem0P2=SHd209JFUP80TI6A0P2:RXX208>3P`80QHF50P1h
N7P208:2PP80Ogmo0P21PH4207inOP80Ph>30P1oOgl207inOP@0PX:20P2:RXX208B4Q080N7Qh0P23
Ph<207emO@80OWin0`26QXH207moO`80P8200P1kNg/20820P080Ng]k0P25QHD208N7Q`80PX:20P1n
OWh207alO080Ph>30P26QXH20820P080OWin0P1lO7`<0<SPf0002P38h=P408J6QP80MgMg0P21PH42
08Z:RP80QhN70P24Q8@208:2PP80MgMg0P25QHD208:2PP80Ng]k0P1cLg<207UiN@80SHf=0P24Q8@3
07moO`80NGUi0P2?Shl208F5Q@80Lg=c1024Q8@207inOP80OGem0P2>SXh207UiN@@0Shn?0P23Ph<2
0861P@80SXj>0P1dM7@20861P@80QHF50P20P80407]kN`80Ogmo0P1kNg/207inOP80QXJ60P1bLW82
08J6QP80Ph>3101nOWh207moO`<0P820101lO7`207inOP80Ph>31P1mOGd207alO080PX:21021PH42
08:2PP80PH610P24Q8@207emO@H0b>3H0P1jNWX208V9R@80NGUi0P25QHD206a/K080L71`0P1eMGD2
07IfMP80S8b<0P1gMgL207EeM@80N7Qh0P25QHD208N7Q`80OWin0P1gMgL307]kN`80P8200P21PH42
06a/K080MWIf0P23Ph<208N7Q`80PX:20P21PH4207inOP80QXJ60P1ZJVX2075aL@80OWin0P21PH42
07YjNP80WinO0P1_Kfl208B4Q0@0PH610P1lO7`207moO`80Ng]k0P21PH4207]kN`80OGem0P21PH42
08>3P`80Ogmo0P21PH4208R8R0<0PX:20P1jNWX207moO`80QHF50P1hN7P208>3P`80QhN70P1nOWh2
0861P@80OWin0P1lO7`207]kN`80Ph>30P1lO7`208>3P`80NWYj3038h=P000X0b>3H1026QXH207Mg
M`80PH610P2:RXX208N7Q`80Q8B40P22PX8207MgM`80QHF50P22PX8207]kN`80Lg=c0P1iNGT208f=
S@80Q8B40`1oOgl207UiN@80Shn?0P25QHD207=cL`@0Q8B40P1nOWh207emO@80SXj>0P1iNGT408n?
S`80Ph>30P21PH4208j>SP80M7Ad0P21PH4208F5Q@80P820101kNg/207moO`80Ng]k0P1nOWh208J6
QP80LW9b0P26QXH208>3P`@0OWin0P1oOgl30820P0@0O7al0P1nOWh208>3P`H0OGem0P1lO7`208:2
PP@0PH610P22PX820861P@80Q8B40P1mOGd60<SPf080NWYj0P29RHT207UiN@80QHF50P1/K6`2071`
L080MGEe0P1fMWH208b<S080MgMg0P1eMGD207QhN080QHF50P27QhL207inOP80MgMg0`1kNg/20820
P080PH610P1/K6`207IfMP80Ph>30P27QhL208:2PP80PH610P1nOWh208J6QP80JVYZ0P1aLG4207in
OP80PH610P1jNWX209nOW`80Kfm_0P24Q8@40861P@80O7al0P1oOgl207]kN`80PH610P1kNg/207em
O@80PH610P23Ph<207moO`80PH610P28R8P308:2PP80NWYj0P1oOgl208F5Q@80N7Qh0P23Ph<208N7
Q`80OWin0P21PH4207inOP80O7al0P1kNg/208>3P`80O7al0P23Ph<207YjNP`0b>3H000:0<SPf080
PH610P1iNGT207emO@80QXJ60P2>SXh2075aL@@0Ph>30P1kNg/208B4Q080PX:20P1nOWh207=cL`80
O7al0P2;Rh/208Z:RP<0PX:20P2;Rh/207moO`80MWIf0P20P802075aL@80OGem0P1kNg/207emO@80
O7al0P1cLg<207MgM`80N7Qh0P1gMgL208f=S@80MgMg0P1oOgl207alO080Ng]k0P1mOGd20861P@80
OGem0P25QHD207inOP80N7Qh0P1jNWX2079bLP80QHF50P23Ph<20861P@80O7al1@1oOgl20861P@80
MgMg0P29RHT20861P@80QHF50P24Q8@207alO080PH610P1oOgl208:2PP80Ph>30P22PX8207YjNP80
Ph>30P1iNGT60<SPf080NWYj0P22PX8208F5Q@80M7Ad0P27QhL207inOP80P8200P1fMWH207UiN@80
SHf=0P24Q8@20861P@80Shn?0P20P80408>3P`<0P8200P2=SHd20820P080Q8B40P1kNg/208V9R@@0
P8201026QXH408Z:RP80LG5a0P1ZJVX206a/K080R8R80P1eMGD209^KV`80M7Ad0P22PX820820P080
QXJ60P1iNGT207moO`80P8200P1lO7`208F5Q@80OWin0P25QHD20820P080QHF50P1iNGT307inOP80
PX:20P1fMWH208J6QP80OWin0P1oOgl208B4Q080Ng]k0P1nOWh207emO@80O7al0P21PH4207IfMP80
Q8B40P1hN7P207YjNP`0b>3H000:0<SPf080PH610P1iNGT207emO@80QXJ60P2>SXh2075aL@@0Ph>3
0P1kNg/208B4Q080PX:20P1nOWh207=cL`80O7al0P2;Rh/208Z:RP<0PX:20P2;Rh/207moO`80MWIf
0P20P802075aL@80OGem0P1kNg/207emO@80O7al0P1cLg<207MgM`80N7Qh0P1gMgL208f=S@80MgMg
0P1oOgl207alO080Ng]k0P1mOGd20861P@80OGem0P25QHD207inOP80N7Qh0P1jNWX2079bLP80QHF5
0P23Ph<20861P@80O7al1@1oOgl20861P@80MgMg0P29RHT20861P@80QHF50P24Q8@207alO080PH61
0P1oOgl208:2PP80Ph>30P22PX8207YjNP80Ph>30P1iNGT60<SPf080NWYj0P22PX8208F5Q@80M7Ad
0P27QhL207inOP80P8200P1fMWH207UiN@80SHf=0P24Q8@20861P@80Shn?0P20P80408>3P`<0P820
0P2=SHd20820P080Q8B40P1kNg/208V9R@@0P8201026QXH408Z:RP80LG5a0P1ZJVX206a/K080R8R8
0P1eMGD209^KV`80M7Ad0P22PX820820P080QXJ60P1iNGT207moO`80P8200P1lO7`208F5Q@80OWin
0P25QHD20820P080QHF50P1iNGT307inOP80PX:20P1fMWH208J6QP80OWin0P1oOgl208B4Q080Ng]k
0P1nOWh207emO@80O7al0P21PH4207IfMP80Q8B40P1hN7P207YjNP`0b>3H000:0<SPf080P8200P23
Ph<20820P080SHf=0P1fMWH207QhN080MGEe0P26QXH208B4Q080Lg=c0P21PH4208:2PP80OGem0P1i
NGT208>3P`80NGUi0`29RHT208B4Q080Ph>30P1kNg/208b<S080Shn?0P1bLW8208:2PP80RHV90P1i
NGT208R8R080O7al0P2=SHd207UiN@80S8b<0P23Ph<207inOP80NWYj0P1oOgl20861P@80QHF50P23
Ph<207YjNP80Ng]k0P1hN7P207EeM@80Q8B40P2?Shl208B4Q080Ph>30P1oOgl20820P0D0OGem0P24
Q8@20820P080PH610P1mOGd207]kN`80NWYj0P1kNg/40861P@80Ph>30P1oOgl207inOP80PH610P1l
O7`60<SPf080OWin0P2>SXh20861P@80Ng]k101mOGd207UiN@80OGem0P28R8P207IfMP80MGEe0P26
QXH207MgM`80Shn?0P1mOGd207moO`<0PX:20P20P80207YjNP@0OWin0P1oOgl207UiN@80R8R80P25
QHD206m_K`80QHF50P1oOgl208Z:RP80M7Ad0P1cLg<206i^KP80QhN70P1XJ6P208b<S080L71`101n
OWh208B4Q0@0Ph>30P1nOWh408J6QP@0Ogmo0P21PH4207inOP<0P8200P21PH4208N7Q`80Ng]k0P2C
Ti<207QhN080PX:21020P80207inOP80Ogmo0P1mOGd207moO`80N7Qh0P1oOgl20820P0`0b>3H000:
0<SPf080P8200P23Ph<20820P080SHf=0P1fMWH207QhN080MGEe0P26QXH208B4Q080Lg=c0P21PH42
08:2PP80OGem0P1iNGT208>3P`80NGUi0`29RHT208B4Q080Ph>30P1kNg/208b<S080Shn?0P1bLW82
08:2PP80RHV90P1iNGT208R8R080O7al0P2=SHd207UiN@80S8b<0P23Ph<207inOP80NWYj0P1oOgl2
0861P@80QHF50P23Ph<207YjNP80Ng]k0P1hN7P207EeM@80Q8B40P2?Shl208B4Q080Ph>30P1oOgl2
0820P0D0OGem0P24Q8@20820P080PH610P1mOGd207]kN`80NWYj0P1kNg/40861P@80Ph>30P1oOgl2
07inOP80PH610P1lO7`60<SPf080OWin0P2>SXh20861P@80Ng]k101mOGd207UiN@80OGem0P28R8P2
07IfMP80MGEe0P26QXH207MgM`80Shn?0P1mOGd207moO`<0PX:20P20P80207YjNP@0OWin0P1oOgl2
07UiN@80R8R80P25QHD206m_K`80QHF50P1oOgl208Z:RP80M7Ad0P1cLg<206i^KP80QhN70P1XJ6P2
08b<S080L71`101nOWh208B4Q0@0Ph>30P1nOWh408J6QP@0Ogmo0P21PH4207inOP<0P8200P21PH42
08N7Q`80Ng]k0P2CTi<207QhN080PX:21020P80207inOP80Ogmo0P1mOGd207moO`80N7Qh0P1oOgl2
0820P0`0b>3H000:0<SPf080PX:20P1oOgl207inOP80NWYj0P1`L70207YjNP80QhN70P1lO7`208R8
R080Q8B40P23Ph<207inOP80PH610P1mOGd20820P080S8b<0`1kNg/208F5Q@80PX:20P1`L70207Ui
N@80OGem1P20P80207MgM`80NGUi0P22PX8207UiN@80Rh^;0P1fMWH207UiN@80O7al0P28R8P207Ui
N@80P8200P21PH4408F5Q@80P8200P21PH4207inOP80QHF50P1mOGd208>3P`80PH610P1mOGd207Ui
N@D0PX:20P1lO7`208>3P`80Ng]k0P1nOWh208F5Q@80P8200P21PH4207moO`80P8200P1oOgl40861
P@@0P8201P38h=P207QhN080P8200P2;Rh/207UiN@80QHF50P1nOWh208Z:RP80P8200P1oOgl208b<
S080RXZ:0P1nOWh208R8R080NGUi0P1aLG4208F5Q@<0RHV90P1_Kfl208>3P`80SHf=0P1mOGd208V9
R@80O7al0P25QHD207emO@80SHf=0P1iNGT207emO@80P8200P2@T90207emO@80Ph>3101mOGd207Ui
N@80QHF50P24Q8@207moO`80OGem0P21PH4207MgM`80Ng]k0P22PX8207]kN`80MgMg0P25QHD207mo
O`80P8200`1lO7`20820P080Ph>30P1oOgl20861P@80QXJ60P1iNGT208F5Q@80OWin0P22PX840861
P@80Ogmo0P1nOWh208>3P`80NWYj3038h=P000X0b>3H0P22PX8207moO`80OWin0P1jNWX2071`L080
NWYj0P27QhL207alO080R8R80P24Q8@208>3P`80OWin0P21PH4207emO@80P8200P2<S8`307]kN`80
QHF50P22PX82071`L080NGUi0P1mOGd60820P080MgMg0P1iNGT208:2PP80NGUi0P2;Rh/207IfMP80
NGUi0P1lO7`208R8R080NGUi0P20P8020861P@@0QHF50P20P8020861P@80OWin0P25QHD207emO@80
Ph>30P21PH4207emO@80NGUi1@22PX8207alO080Ph>30P1kNg/207inOP80QHF50P20P8020861P@80
Ogmo0P20P80207moO`@0PH611020P8060<SPf080N7Qh0P20P80208^;R`80NGUi0P25QHD207inOP80
RXZ:0P20P80207moO`80S8b<0P2:RXX207inOP80R8R80P1iNGT2075aL@80QHF50`29RHT206m_K`80
Ph>30P2=SHd207emO@80RHV90P1lO7`208F5Q@80OGem0P2=SHd207UiN@80OGem0P20P802092@T080
OGem0P23Ph<407emO@80NGUi0P25QHD208B4Q080Ogmo0P1mOGd20861P@80MgMg0P1kNg/208:2PP80
Ng]k0P1gMgL208F5Q@80Ogmo0P20P80307alO080P8200P23Ph<207moO`80PH610P26QXH207UiN@80
QHF50P1nOWh208:2PP@0PH610P1oOgl207inOP80Ph>30P1jNWX<0<SPf0002P38h=P208N7Q`80R8R8
0P1kNg/208j>SP80RXZ:0P1hN7P207YjNP80OWin0P1lO7`208R8R080LW9b0P24Q8@207alO080N7Qh
0P1oOgl20861P@<0MgMg0P25QHD207]kN`80Q8B40P1eMGD208B4Q080Lg=c0P26QXH20820P080Lg=c
0P1fMWH207EeM@@0O7al0P23Ph<207=cL`80QXJ60P20P80208N7Q`80LG5a0P25QHD207IfMP80Ph>3
0P22PX8207QhN080PX:20P2:RXX207MgM`@0Q8B40P21PH4507emO@80QHF50P1lO7`207moO`80Ph>3
0P1iNGT207alO0@0P8200P1mOGd207moO`80Q8B40P23Ph<20820P080OGem0P24Q8@60<SPf080P820
0P28R8P207EeM@80O7al0P2:RXX208>3P`80Ng]k0P1jNWX20820P080PH610P1oOgl208B4Q080MGEe
0P1aLG42071`L080Ogmo0`1mOGd608>3P`80M7Ad0P1ZJVX207YjNP80P8200P1fMWH20820P080Ogmo
0P23Ph<20861P@80Ph>30P2<S8`208V9R@80QXJ60P1kNg/208B4Q080P8200P2:RXX208>3P`80OGem
0P1gMgL207AdM080OWin0P1oOgl20820P080Ogmo0P1nOWh207alO080RXZ:1@1oOgl20861P@80OWin
0P1mOGd20820P080R8R80P1iNGT208>3P`80N7Qh101nOWh207emO@80Ng]k0P1oOgl207]kN``0b>3H
000:0<SPf080QhN70P28R8P207]kN`80SXj>0P2:RXX207QhN080NWYj0P1nOWh207alO080R8R80P1b
LW8208B4Q080O7al0P1hN7P207moO`80PH610`1gMgL208F5Q@80Ng]k0P24Q8@207EeM@80Q8B40P1c
Lg<208J6QP80P8200P1cLg<207IfMP80MGEe101lO7`208>3P`80Lg=c0P26QXH20820P080QhN70P1a
LG4208F5Q@80MWIf0P23Ph<208:2PP80N7Qh0P22PX8208Z:RP80MgMg1024Q8@20861P@D0OGem0P25
QHD207alO080Ogmo0P23Ph<207UiN@80O7al1020P80207emO@80Ogmo0P24Q8@208>3P`80P8200P1m
OGd208B4Q0H0b>3H0P20P80208R8R080MGEe0P1lO7`208Z:RP80Ph>30P1kNg/207YjNP80P8200P21
PH4207moO`80Q8B40P1eMGD2075aL@80L71`0P1oOgl307emO@H0Ph>30P1dM7@206YZJP80NWYj0P20
P80207IfMP80P8200P1oOgl208>3P`80PH610P23Ph<208b<S080RHV90P26QXH207]kN`80Q8B40P20
P80208Z:RP80Ph>30P1mOGd207MgM`80M7Ad0P1nOWh207moO`80P8200P1oOgl207inOP80O7al0P2:
RXX507moO`80PH610P1nOWh207emO@80P8200P28R8P207UiN@80Ph>30P1hN7P407inOP80OGem0P1k
Ng/207moO`80Ng]k3038h=P000X0b>3H0P1lO7`208B4Q080Ph>30P1aLG4208N7Q`80O7al0P20P802
08F5Q@80MgMg0P27QhL207UiN@80QHF50P1oOgl208Z:RP80PH610P25QHD308R8R080OGem0P27QhL2
07YjNP80SHf=101gMgL207IfMP80NWYj1024Q8@407inOP80O7al0P1iNGT208b<S080SHf=0P1oOgl4
0820P080M7Ad0P21PH4208:2PP80PH610P20P80207emO@80QhN70P1jNWX208>3P`80Ng]k0P1mOGd2
07alO0<0NWYj0P25QHD207moO`H0P820101nOWh208>3P`80N7Qh0P24Q8@20861P@80P8200P25QHD2
07moO`80Q8B41P38h=P207alO080Ogmo0P1jNWX206i^KP80RHV90P23Ph<20861P@80Ng]k0P24Q8@2
08F5Q@80SHf=0P26QXH207moO`80OWin0P29RHT20861P@<0N7Qh0P28R8P207UiN@80QXJ60P1dM7@2
07inOP80P8200P26QXH208N7Q`80PH610P28R8P207inOP80PX:20P1lO7`207emO@80RXZ:0P23Ph<2
08R8R080P8200P29RHT207alO080SHf=0P24Q8@20820P080Ph>30P1oOgl208:2PP80OGem0P1jNWX2
0861P@80P8200P1oOgl308b<S0H0OWin1020P80207alO080PX:20P1mOGd208>3P`80OGem0P22PX82
07]kN`80PH610P1lO7`207QhN0`0b>3H000:0<SPf080O7al0P24Q8@208>3P`80LG5a0P27QhL207al
O080P8200P25QHD207MgM`80QhN70P1iNGT208F5Q@80Ogmo0P2:RXX20861P@80QHF50`28R8P207em
O@80QhN70P1jNWX208f=S@@0MgMg0P1fMWH207YjNP@0Q8B4101nOWh207alO080NGUi0P2<S8`208f=
S@80Ogmo1020P80207AdM080PH610P22PX820861P@80P8200P1mOGd208N7Q`80NWYj0P23Ph<207]k
N`80OGem0P1lO7`307YjNP80QHF50P1oOgl60820P0@0OWin0P23Ph<207QhN080Q8B40P21PH420820
P080QHF50P1oOgl208B4Q0H0b>3H0P1lO7`207moO`80NWYj0P1^KVh208V9R@80Ph>30P21PH4207]k
N`80Q8B40P25QHD208f=S@80QXJ60P1oOgl207inOP80RHV90P21PH4307QhN080R8R80P1iNGT208J6
QP80M7Ad0P1nOWh20820P080QXJ60P27QhL20861P@80R8R80P1nOWh208:2PP80O7al0P1mOGd208Z:
RP80Ph>30P28R8P20820P080RHV90P1lO7`208f=S@80Q8B40P20P80208>3P`80Ogmo0P22PX8207em
O@80NWYj0P21PH420820P080Ogmo0`2<S8`607inOP@0P8200P1lO7`208:2PP80OGem0P23Ph<207em
O@80PX:20P1kNg/20861P@80O7al0P1hN7P<0<SPf0002P38h=P207inOP80QhN70P20P80207IfMP80
LG5a0P24Q8@20861P@80Ph>30P1nOWh208F5Q@80Ng]k0P24Q8@20861P@80P8200P1kNg/208F5Q@<0
Q8B40P1dM7@20861P@80LG5a0P2?Shl208f=S@80PX:20P1bLW8208j>SP80OGem0P1gMgL208J6QP@0
P8200P22PX8207alO080RXZ:0P2?Shl208V9R@80Q8B40P21PH4207UiN@80Ph>30P1nOWh20820P080
QXJ60P2=SHd207UiN@80O7al0P2;Rh/207IfMP80PH610`27QhL208B4Q080NWYj0P22PX8208N7Q`80
QXJ60P27QhL208B4Q080MWIf0P27QhL207moO`80PH610P1jNWX208:2PP80NWYj0P1kNg/60<SPf080
SHf=1022PX8208N7Q`80N7Qh0P26QXH208F5Q@80PX:20P21PH4208:2PP@0Ng]k1028R8P208b<S080
MgMg0`23Ph<207YjNP80Q8B40P1kNg/207moO`80QXJ60P22PX8208b<S080OGem0P1oOgl207EeM@80
PH610P1oOgl207YjNP80OWin0P1mOGd207IfMP80PX:20P23Ph<207alO080OGem0P20P80208R8R080
RXZ:0P1lO7`207]kN`80P8200P1kNg/208J6QP80Ph>30P24Q8@207alO0<0NGUi0P22PX8207inOP80
OGem0P1lO7`207moO`80PH610P1mOGd20820P080R8R80P24Q8@208J6QP80Ogmo101nOWh208J6QP`0
b>3H000:0<SPf080OWin0P27QhL20820P080MWIf0P1aLG4208B4Q080PH610P23Ph<207inOP80QHF5
0P1kNg/208B4Q080PH610P20P80207]kN`80QHF50`24Q8@207AdM080PH610P1aLG4208n?S`80SHf=
0P22PX82079bLP80SXj>0P1mOGd207MgM`80QXJ61020P80208:2PP80O7al0P2:RXX208n?S`80RHV9
0P24Q8@20861P@80NGUi0P23Ph<207inOP80P8200P26QXH208f=S@80NGUi0P1lO7`208^;R`80MWIf
0P21PH4308N7Q`80Q8B40P1jNWX208:2PP80QhN70P26QXH208N7Q`80Q8B40P1fMWH208N7Q`80Ogmo
0P21PH4207YjNP80PX:20P1jNWX207]kN`H0b>3H0P2=SHd408:2PP80QhN70P1hN7P208J6QP80QHF5
0P22PX820861P@80PX:2101kNg/408R8R080S8b<0P1gMgL308>3P`80NWYj0P24Q8@207]kN`80Ogmo
0P26QXH208:2PP80S8b<0P1mOGd207moO`80MGEe0P21PH4207moO`80NWYj0P1nOWh207emO@80MWIf
0P22PX8208>3P`80O7al0P1mOGd20820P080R8R80P2:RXX207alO080Ng]k0P20P80207]kN`80QXJ6
0P23Ph<208B4Q080O7al0`1iNGT208:2PP80OWin0P1mOGd207alO080Ogmo0P21PH4207emO@80P820
0P28R8P208B4Q080QXJ60P1oOgl407inOP80QXJ63038h=P000X0b>3H0P1hN7P208^;R`80NWYj0P22
PX8207UiN@80M7Ad0P1mOGd208N7Q`80PX:20P1mOGd208B4Q080OWin0P1kNg/208J6QP80NGUi0P24
Q8@30820P080OWin0P1eMGD208b<S080Shn?0P24Q8@207=cL`80Rh^;0P20P80208R8R080Ng]k101h
N7P208:2PP80OWin0P1lO7`40820P080Ng]k0P20P80207emO@80R8R80P1cLg<208j>SP80NWYj0P27
QhL20861P@80M7Ad0P26QXH208Z:RP80OGem0P25QHD507inOP80PH610P27QhL207moO`80OWin0P24
Q8@207emO@80P8200P24Q8@407moO`80OGem0P23Ph<20861P@80MWIf1P38h=P207=cL`80KVi^0P1l
O7`207inOP80S8b<0P1oOgl208Z:RP80NGUi0P1jNWX20820P080QHF50P27QhL208>3P`80NGUi0P1^
KVh207EeM@<0PH610P24Q8@208F5Q@80N7Qh0P1jNWX207moO`80Ph>30P1eMGD208N7Q`80OGem0P1a
LG4207moO`80SHf=0P1mOGd208R8R080QHF50P1oOgl207IfMP80Rh^;0P2<S8`207MgM`80QhN7101o
Ogl208b<S080Q8B40P1_Kfl207inOP80Ng]k0P2<S8`208N7Q`80P8200`1oOgl207YjNP80P820101m
OGd407UiN@80OWin0P28R8P20820P080RXZ:0P1mOGd20861P@80QHF50P21PH4208F5Q@`0b>3H000:
0<SPf080N7Qh0P2;Rh/207YjNP80PX:20P1iNGT207AdM080OGem0P27QhL208:2PP80OGem0P24Q8@2
07inOP80Ng]k0P26QXH207UiN@80Q8B40`20P80207inOP80MGEe0P2<S8`208n?S`80Q8B40P1cLg<2
08^;R`80P8200P28R8P207]kN`@0N7Qh0P22PX8207inOP80O7al1020P80207]kN`80P8200P1mOGd2
08R8R080Lg=c0P2>SXh207YjNP80QhN70P21PH4207AdM080QXJ60P2:RXX207emO@80QHF51@1nOWh2
0861P@80QhN70P1oOgl207inOP80Q8B40P1mOGd20820P080Q8B4101oOgl207emO@80Ph>30P21PH42
07IfMPH0b>3H0P1cLg<206i^KP80O7al0P1nOWh208b<S080Ogmo0P2:RXX207UiN@80NWYj0P20P802
08F5Q@80QhN70P23Ph<207UiN@80KVi^0P1eMGD30861P@80Q8B40P25QHD207QhN080NWYj0P1oOgl2
08>3P`80MGEe0P27QhL207emO@80LG5a0P1oOgl208f=S@80OGem0P28R8P208F5Q@80Ogmo0P1fMWH2
08^;R`80S8b<0P1gMgL208N7Q`@0Ogmo0P2<S8`208B4Q080Kfm_0P1nOWh207]kN`80S8b<0P27QhL2
0820P0<0Ogmo0P1jNWX20820P0@0OGem101iNGT207inOP80R8R80P20P80208Z:RP80OGem0P21PH42
08F5Q@80PH610P25QHD<0<SPf0002P38h=P207inOP80PH610P23Ph<207EeM@80PH610P28R8P207mo
O`80OWin0P22PX8208>3P`@0PH610P26QXH207AdM080NGUi0P25QHD308J6QP80O7al0P23Ph<2079b
LP80Shn?0P21PH4207EeM@80Ph>30P1eMGD208n?S`80QHF50P1iNGT207inOP80Ph>30P1jNWX208:2
PP80Ogmo0P25QHD20861P@80MgMg0P26QXH208:2PP80QhN70P1kNg/207IfMP80L71`0P2:RXX207Ui
N@80PX:20P1mOGd40820P0<0PH610P20P80207alO080OWin0P1lO7`20861P@80OWin0P1oOgl208>3
P`@0OWin1022PX8207inOP80Ph>30P1iNGT60<SPf080Ng]k0P1oOgl207UiN@80Ng]k0P20P80207in
OP80S8b<0P1nOWh207emO@80Ph>30P1oOgl40861P@80NWYj0P1gMgL207inOP<0PH610P2@T90207em
O@80Q8B40P2<S8`208>3P`80LG5a0P1nOWh207alO080Ph>30P29RHT207MgM`80NGUi0P1hN7P207If
MP80Ng]k0P1nOWh208^;R`80K6a/0P1gMgL207IfMP80QXJ60P1mOGd207=cL`80Ph>30P1nOWh20820
P080OWin1020P80207moO`80O7al0`1oOgl20861P@80NWYj0P1nOWh208F5Q@80OGem1021PH4207mo
O`80P8200P1nOWh207]kN`80PX:20P1hN7P207moO`80MWIf3038h=P000X0b>3H0P1nOWh20861P@80
Ph>30P1eMGD20861P@80R8R80P1oOgl207inOP80PX:20P23Ph<40861P@80QXJ60P1dM7@207UiN@80
QHF50`26QXH207alO080Ph>30P1bLW8208n?S`80PH610P1eMGD208>3P`80MGEe0P2?Shl208F5Q@80
NGUi0P1nOWh208>3P`80NWYj0P22PX8207moO`80QHF50P21PH4207MgM`80QXJ60P22PX8208N7Q`80
Ng]k0P1fMWH2071`L080RXZ:0P1iNGT208:2PP80OGem1020P8030861P@80P8200P1lO7`207inOP80
O7al0P21PH4207inOP80Ogmo0P23Ph<407inOP@0PX:20P1nOWh208>3P`80NGUi1P38h=P207]kN`80
Ogmo0P1iNGT207]kN`80P8200P1nOWh208b<S080OWin0P1mOGd208>3P`80Ogmo1021PH4207YjNP80
MgMg0P1nOWh30861P@80T92@0P1mOGd208B4Q080S8b<0P23Ph<2075aL@80OWin0P1lO7`208>3P`80
RHV90P1gMgL207UiN@80N7Qh0P1fMWH207]kN`80OWin0P2;Rh/206a/K080MgMg0P1fMWH208J6QP80
OGem0P1cLg<208>3P`80OWin0P20P80207inOP@0P8200P1oOgl207alO0<0Ogmo0P21PH4207YjNP80
OWin0P25QHD207emO@@0PH610P1oOgl20820P080OWin0P1kNg/208:2PP80N7Qh0P1oOgl207IfMP`0
b>3H000:0<SPf0@0QHF50P1hN7P208>3P`80QXJ60P2=SHd208N7Q`80QXJ60P1iNGT208N7Q`80PX:2
0P1mOGd208J6QP80PH610P26QXH207inOP<0R8R80P23Ph<207]kN`80PH610P1lO7`207MgM`@0R8R8
0P1bLW8208j>SP80Ng]k0P21PH4207moO`80OWin0P1oOgl207]kN`80P8200P1lO7`208J6QP80Ogmo
0P1mOGd208j>SP80S8b<0P22PX8608V9R@@0QHF51023Ph<207inOP<0PH610P1nOWh20861P@80PX:2
0P1kNg/20820P080PX:20P21PH4207inOP80P8200P21PH420820P080QXJ60P1jNWX208:2PP80OGem
1P38h=P207UiN@80OGem0P2<S8`207emO@80NWYj0P27QhL207inOP80NGUi0P26QXH208:2PP80OGem
0P27QhL207]kN`80N7Qh0P26QXH209>CT`<0OGem0P2>SXh208R8R080OGem0P1hN7P208n?S`80UiNG
0P29RHT207YjNP80N7Qh0P1oOgl207alO080RHV90P1hN7P207moO`80Ng]k101oOgl20861P@80JVYZ
0P20P80207MgM`80O7al0P22PX8207moO`80Ng]k0P22PX8208V9R@80Ogmo0P1nOWh207YjNP80QhN7
0`23Ph<407emO@@0Ogmo0P21PH4207moO`80PX:20P1kNg/407moO`80OWin0P24Q8@207emO@80OWin
0P1kNg/<0<SPf0002P38h=P408F5Q@80N7Qh0P23Ph<208J6QP80SHf=0P27QhL208J6QP80NGUi0P27
QhL208:2PP80OGem0P26QXH20861P@80QXJ60P1nOWh308R8R080Ph>30P1kNg/20861P@80O7al0P1g
MgL408R8R080LW9b0P2>SXh207]kN`80PH610P1oOgl207inOP80Ogmo0P1kNg/20820P080O7al0P26
QXH207moO`80OGem0P2>SXh208b<S080PX:21P29RHT408F5Q@@0Ph>30P1nOWh30861P@80OWin0P21
PH4208:2PP80Ng]k0P20P80208:2PP80PH610P1nOWh20820P080PH610P20P80208J6QP80NWYj0P22
PX8207emO@H0b>3H0P1iNGT207emO@80S8b<0P1mOGd207YjNP80QhN70P1nOWh207UiN@80QXJ60P22
PX8207emO@80QhN70P1kNg/207QhN080QXJ60P2CTi<307emO@80SXj>0P28R8P207emO@80N7Qh0P2?
Shl209NGU`80RHV90P1jNWX207QhN080Ogmo0P1lO7`208V9R@80N7Qh0P1oOgl207]kN`@0Ogmo0P21
PH4206YZJP80P8200P1gMgL207alO080PX:20P1oOgl207]kN`80PX:20P29RHT207moO`80OWin0P1j
NWX208N7Q`<0Ph>3101mOGd407moO`80PH610P1oOgl208:2PP80Ng]k101oOgl207inOP80Q8B40P1m
OGd207inOP80Ng]k3038h=P000X0b>3H0P1kNg/2075aL@80OWin0P24Q8@208F5Q@80N7Qh0P22PX82
08V9R@80OWin0P1oOgl208B4Q0@0P8200P1mOGd2079bLP80Ph>30`1fMWH20861P@80SXj>0P1jNWX2
07emO@80SXj>0P1eMGD207IfMP80LG5a0P28R8P40820P0H0OWin0P20P80208F5Q@80QXJ60P1jNWX2
07inOP80Ph>30P1fMWH208Z:RP80OGem0P2=SHd207EeM@80OWin0P1eMGD408J6QP80OGem0P1oOgl3
0820P080OWin0P20P80207alO080OGem0P20P80207alO080PH610P23Ph<207inOP80NWYj0P23Ph<2
07alO080QhN70P1lO7`20861P@H0b>3H1021PH4207alO080Ng]k0P2BTY8207=cL`80OGem0P1oOgl2
08N7Q`80Q8B40P1nOWh207MgM`80QHF50P29RHT206=SH`80Ng]k0`1^KVh20820P080Ph>30P20P802
07QhN080Ph>30P1eMGD207inOP80Q8B40P20P80207alO080U9BD0P1kNg/207moO`80R8R80P1dM7@2
08F5Q@80SXj>0P1dM7@207emO@80Q8B40P2LW9`208N7Q`80MgMg0P25QHD208J6QP80SXj>0P1iNGT2
08:2PP80Ogmo0P23Ph<207emO@<0PH610P1nOWh208>3P`80Ng]k0P1mOGd207]kN`80MgMg0P21PH42
07]kN`80P8200P1fMWH208J6QP80MGEe0P1lO7`20861P@80QHF53038h=P000X0b>3H0P1kNg/2075a
L@80OWin0P24Q8@208F5Q@80N7Qh0P22PX8208V9R@80OWin0P1oOgl208B4Q0@0P8200P1mOGd2079b
LP80Ph>30`1fMWH20861P@80SXj>0P1jNWX207emO@80SXj>0P1eMGD207IfMP80LG5a0P28R8P40820
P0H0OWin0P20P80208F5Q@80QXJ60P1jNWX207inOP80Ph>30P1fMWH208Z:RP80OGem0P2=SHd207Ee
M@80OWin0P1eMGD408J6QP80OGem0P1oOgl30820P080OWin0P20P80207alO080OGem0P20P80207al
O080PH610P23Ph<207inOP80NWYj0P23Ph<207alO080QhN70P1lO7`20861P@H0b>3H1021PH4207al
O080Ng]k0P2BTY8207=cL`80OGem0P1oOgl208N7Q`80Q8B40P1nOWh207MgM`80QHF50P29RHT206=S
H`80Ng]k0`1^KVh20820P080Ph>30P20P80207QhN080Ph>30P1eMGD207inOP80Q8B40P20P80207al
O080U9BD0P1kNg/207moO`80R8R80P1dM7@208F5Q@80SXj>0P1dM7@207emO@80Q8B40P2LW9`208N7
Q`80MgMg0P25QHD208J6QP80SXj>0P1iNGT208:2PP80Ogmo0P23Ph<207emO@<0PH610P1nOWh208>3
P`80Ng]k0P1mOGd207]kN`80MgMg0P21PH4207]kN`80P8200P1fMWH208J6QP80MGEe0P1lO7`20861
P@80QHF53038h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P00?l0b>3H8@38h=P0
0?l0b>3H8@38h=P00?l0b>3H8@38h=P000X0b>3HPP20P8060<SPf080PX:20P2:RXX208R8R080RXZ:
0P1gMgL208>3P`80RHV90P25QHD208B4Q080P8200P1oOgl20861P@80Ogmo0P21PH4207]kN`T0OWin
0P1mOGd208>3P`80O7al0P1nOWh408>3P`80Ng]k0P21PH4207moO`80QHF50P1lO7`208:2PP80Ph>3
0P1mOGd207moO`@0OWin0P1oOgl20820P080PH610P1nOWh207moO`80PH610P22PX8207alO0@0Ogmo
0P1lO7`20861P@<0Ph>30P1oOgl207inOP80Ogmo0P1mOGd20820P080Ogmo0P1nOWh207emO@80PH61
0P1mOGd207]kN`80P8200P21PH4207moO`80PX:23038h=P000X0b>3HPP20P8060<SPf080PX:20P2:
RXX208R8R080RXZ:0P1gMgL208>3P`80RHV90P25QHD208B4Q080P8200P1oOgl20861P@80Ogmo0P21
PH4207]kN`T0OWin0P1mOGd208>3P`80O7al0P1nOWh408>3P`80Ng]k0P21PH4207moO`80QHF50P1l
O7`208:2PP80Ph>30P1mOGd207moO`@0OWin0P1oOgl20820P080PH610P1nOWh207moO`80PH610P22
PX8207alO0@0Ogmo0P1lO7`20861P@<0Ph>30P1oOgl207inOP80Ogmo0P1mOGd20820P080Ogmo0P1n
OWh207emO@80PH610P1mOGd207]kN`80P8200P21PH4207moO`80PX:23038h=P000X0b>3HPP20P806
0<SPf080OGem0P1kNg/208R8R080N7Qh0P2;Rh/207emO@80Q8B40P22PX8207YjNP80O7al0P21PH42
08>3P`80NWYj0P22PX8207alO080OWin0`20P8020861P@80Ph>30P21PH4207alO080QHF5101mOGd2
08>3P`80P8200P23Ph<207inOP80PX:21020P8020861P@80OGem1P1nOWh40820P0@0Ogmo0P1mOGd2
07moO`80OWin0P1mOGd207moO`80PH610P1mOGd50861P@80O7al0P21PH4207emO@80O7al0P20P802
07inOP80PX:20P21PH420820P080PH610P1nOWh20861P@80OGem0P22PX8207moO``0b>3H000:0<SP
f880P8201P38h=P207emO@80Ng]k0P28R8P207QhN080Rh^;0P1mOGd208B4Q080PX:20P1jNWX207al
O080PH610P23Ph<207YjNP80PX:20P1lO7`207inOP<0P8200P21PH4208>3P`80PH610P1lO7`208F5
Q@@0OGem0P23Ph<20820P080Ph>30P1nOWh208:2PP@0P8200P21PH4207emO@H0OWin1020P80407mo
O`80OGem0P1oOgl207inOP80OGem0P1oOgl20861P@80OGem1@21PH4207alO080PH610P1mOGd207al
O080P8200P1nOWh208:2PP80PH610P20P8020861P@80OWin0P21PH4207emO@80PX:20P1oOgl<0<SP
f0002P38h=R20820P0H0b>3H0P23Ph<20820P080Ogmo0P24Q8@207QhN080RHV90P23Ph<207]kN`@0
Ogmo0P1kNg/207alO080NGUi0P1dM7@20820P080MGEe0`1mOGd20861P@80MgMg0P1oOgl207emO@80
Q8B40P22PX8208J6QP80O7al1020P80207alO080Ogmo0P1mOGd20820P080O7al0P1mOGd407inOP80
Ogmo0P1mOGd207inOP@0P8201021PH420820P080OWin0P1mOGd207inOP80P8200P1nOWh307moO`80
PX:20P23Ph<20861P@@0OWin0P22PX8207moO`80PH610P20P80207alO080OWin0P1lO7`20861P@80
P8200P1nOWh<0<SPf0002P38h=R20820P0H0b>3H0P23Ph<20820P080Ogmo0P24Q8@207QhN080RHV9
0P23Ph<207]kN`@0Ogmo0P1kNg/207alO080NGUi0P1dM7@20820P080MGEe0`1mOGd20861P@80MgMg
0P1oOgl207emO@80Q8B40P22PX8208J6QP80O7al1020P80207alO080Ogmo0P1mOGd20820P080O7al
0P1mOGd407inOP80Ogmo0P1mOGd207inOP@0P8201021PH420820P080OWin0P1mOGd207inOP80P820
0P1nOWh307moO`80PX:20P23Ph<20861P@@0OWin0P22PX8207moO`80PH610P20P80207alO080OWin
0P1lO7`20861P@80P8200P1nOWh<0<SPf0002P38h=R20820P0H0b>3H0P1nOWh208J6QP80R8R80P1k
Ng/20820P080OWin0P2;Rh/408N7Q`80QXJ60P1kNg/207EeM@80Lg=c0P1bLW8207IfMP80Lg=c0`1b
LW8207MgM`80SXj>0P1eMGD207alO080Ng]k0P1iNGT207emO@80PX:2101kNg/207inOP80OGem0P1i
NGT407YjNP80Ogmo0P1lO7`207inOP80OGem0P20P80208>3P`80Ogmo0P20P80208:2PP80Ogmo0P21
PH4207inOP80Ogmo0P1lO7`20820P0D0Ogmo0P1nOWh207emO@80Ogmo0P1mOGd207inOP80PH610P1l
O7`20861P@80Ogmo0P23Ph<407moO`80PH610P20P80207moO``0b>3H000:0<SPf880P8201P38h=P2
07inOP80QXJ60P28R8P207]kN`80P8200P1nOWh208^;R`@0QhN70P26QXH207]kN`80MGEe0P1cLg<2
079bLP80MWIf0P1cLg<3079bLP80MgMg0P2>SXh207EeM@80O7al0P1kNg/207UiN@80OGem0P22PX84
07]kN`80OWin0P1mOGd207UiN@@0NWYj0P1oOgl207alO080OWin0P1mOGd20820P080Ph>30P1oOgl2
0820P080PX:20P1oOgl20861P@80OWin0P1oOgl207alO080P8201@1oOgl207inOP80OGem0P1oOgl2
07emO@80OWin0P21PH4207alO080PH610P1oOgl208>3P`@0Ogmo0P21PH420820P080Ogmo3038h=P0
00X0b>3HPP20P8060<SPf080SXj>0P1dM7@207alO080Ogmo0P23Ph<207UiN@80SXj>0P21PH4208F5
Q@80Rh^;0P26QXH408R8R0@0PX:20P1oOgl30820P0@0PX:20P21PH4208:2PP80Ogmo0P1nOWh20861
P@80Ogmo0P21PH4207moO`80Ng]k0P20P80407inOP80PX:20P20P80207alO080Ogmo0P22PX8207al
O080Ogmo0P1mOGd20820P080O7al0P25QHD20820P080Ogmo0P20P80207moO`80O7al0P1oOgl307]k
N`H0P8200P1nOWh208:2PP80OWin0P24Q8@20861P@80Ph>30P20P80207moO`80P8200P1nOWh207mo
O`80P8203038h=P000X0b>3HPP20P8060<SPf080SXj>0P1dM7@207alO080Ogmo0P23Ph<207UiN@80
SXj>0P21PH4208F5Q@80Rh^;0P26QXH408R8R0@0PX:20P1oOgl30820P0@0PX:20P21PH4208:2PP80
Ogmo0P1nOWh20861P@80Ogmo0P21PH4207moO`80Ng]k0P20P80407inOP80PX:20P20P80207alO080
Ogmo0P22PX8207alO080Ogmo0P1mOGd20820P080O7al0P25QHD20820P080Ogmo0P20P80207moO`80
O7al0P1oOgl307]kN`H0P8200P1nOWh208:2PP80OWin0P24Q8@20861P@80Ph>30P20P80207moO`80
P8200P1nOWh207moO`80P8203038h=P000X0b>3HPP20P8060<SPf080MgMg0P2:RXX208:2PP80Q8B4
0P1mOGd208:2PP80OWin0P2:RXX207emO@80Ph>30P20P80208:2PP80RXZ:0P1mOGd207]kN`80Ogmo
0`1nOWh207moO`80P8200P21PH4208B4Q080PH610P1mOGd208>3P`80PH610P1oOgl207emO@80Ng]k
0P1oOgl20861P@@0OGem0P24Q8@208F5Q@80Ogmo0P24Q8@207emO@80P8200P1lO7`207inOP80P820
0P1nOWh207moO`80OGem0P1oOgl207inOP80PX:20P1nOWh307emO@80Ph>30P1mOGd407moO`@0P820
0P21PH4208B4Q080P8201021PH4207YjNP80OGem0P1nOWh207emO@`0b>3H000:0<SPf880P8201P38
h=P207MgM`80RXZ:0P22PX8208B4Q080OGem0P22PX8207inOP80RXZ:0P1mOGd208>3P`80P8200P22
PX8208Z:RP80OGem0P1kNg/207moO`<0OWin0P1oOgl20820P080PH610P24Q8@20861P@80OGem0P23
Ph<20861P@80Ogmo0P1mOGd207]kN`80Ogmo0P21PH4407emO@80Q8B40P25QHD207moO`80Q8B40P1m
OGd20820P080O7al0P1nOWh20820P080OWin0P1oOgl207emO@80Ogmo0P1nOWh208:2PP80OWin0`1m
OGd208>3P`80OGem101oOgl40820P080PH610P24Q8@20820P0@0PH610P1jNWX207emO@80OWin0P1m
OGd<0<SPf0002P38h=R20820P0H0b>3H0P26QXH208n?S`80QXJ60P21PH4208V9R@80QhN70P1fMWH2
075aL@80Ph>30P1hN7P207alO080N7Qh0P20P802079bLP80QhN70P22PX830861P@80Q8B40P1mOGd2
07MgM`80P8200P1nOWh208:2PP80Ng]k0P1mOGd208>3P`80O7al0P20P80208:2PP80NWYj0P22PX82
07emO@80P8200P21PH4207alO080Ogmo0P1nOWh40861P@80OGem0P20P80207moO`80OGem0P1nOWh2
07alO0@0Ogmo0P1kNg/30861P@@0OWin0P1lO7`207inOP80QHF50P1oOgl207alO080P8200P1jNWX2
08:2PP80Ph>31024Q8@208:2PP80QHF53038h=P000X0b>3HPP20P8060<SPf080QXJ60P2?Shl208J6
QP80PH610P29RHT208N7Q`80MWIf0P1aLG4208>3P`80N7Qh0P1lO7`207QhN080P8200P1bLW8208N7
Q`80PX:20`21PH4208B4Q080OGem0P1gMgL20820P080OWin0P22PX8207]kN`80OGem0P23Ph<207al
O080P8200P22PX8207YjNP80PX:20P1mOGd20820P080PH610P1lO7`207moO`80OWin1021PH4207em
O@80P8200P1oOgl207emO@80OWin0P1lO7`407moO`80Ng]k0`21PH4407inOP80O7al0P1nOWh208F5
Q@80Ogmo0P1lO7`20820P080NWYj0P22PX8208>3P`@0Q8B40P22PX8208F5Q@`0b>3H000:0<SPf880
P8201P38h=P207=cL`80O7al0P2:RXX207inOP80Ng]k0P1nOWh208j>SP@0SHf=0P22PX8208B4Q080
PH610P27QhL208f=S@80RXZ:0P21PH4307moO`80Ph>30P27QhL207MgM`80OWin0P23Ph<208:2PP80
OGem0P20P80208F5Q@80Ogmo0P1nOWh207alO080Q8B40P22PX8208>3P`80PH610P1nOWh207moO`@0
PH610P1jNWX207inOP80PH610P1oOgl208Z:RP80P8200P24Q8@208:2PP80OWin1020P80507moO`80
PH61101oOgl40820P080OGem0P22PX820820P080Ogmo0P1nOWh207moO`80OWin0P1lO7`207YjNP`0
b>3H000:0<SPf880P8201P38h=P207=cL`80O7al0P2:RXX207inOP80Ng]k0P1nOWh208j>SP@0SHf=
0P22PX8208B4Q080PH610P27QhL208f=S@80RXZ:0P21PH4307moO`80Ph>30P27QhL207MgM`80OWin
0P23Ph<208:2PP80OGem0P20P80208F5Q@80Ogmo0P1nOWh207alO080Q8B40P22PX8208>3P`80PH61
0P1nOWh207moO`@0PH610P1jNWX207inOP80PH610P1oOgl208Z:RP80P8200P24Q8@208:2PP80OWin
1020P80507moO`80PH61101oOgl40820P080OGem0P22PX820820P080Ogmo0P1nOWh207moO`80OWin
0P1lO7`207YjNP`0b>3H000:0<SPf880P8201P38h=P208B4Q080Rh^;0P1iNGT207moO`80R8R80P1k
Ng/207alO080NWYj0P1kNg/208F5Q@80OGem0P1nOWh40820P080PH610P22PX8308B4Q080OGem0P27
QhL40820P080OGem0P20P80207moO`80P8200P23Ph<207inOP80Q8B40P20P8020861P@80P8200P1n
OWh20861P@80OWin0P20P80207emO@80PH610P1kNg/40820P080Ogmo0P23Ph<407moO`80OWin0P20
P80207inOPD0Ogmo0P1mOGd208>3P`80Ogmo0P20P80207moO`80P8200P1oOgl207emO@80PH610P23
Ph<407alO080N7Qh0P1jNWX207inOP`0b>3H000:0<SPf880P8201P38h=P208B4Q080Rh^;0P1iNGT2
07moO`80R8R80P1kNg/207alO080NWYj0P1kNg/208F5Q@80OGem0P1nOWh40820P080PH610P22PX83
08B4Q080OGem0P27QhL40820P080OGem0P20P80207moO`80P8200P23Ph<207inOP80Q8B40P20P802
0861P@80P8200P1nOWh20861P@80OWin0P20P80207emO@80PH610P1kNg/40820P080Ogmo0P23Ph<4
07moO`80OWin0P20P80207inOPD0Ogmo0P1mOGd208>3P`80Ogmo0P20P80207moO`80P8200P1oOgl2
07emO@80PH610P23Ph<407alO080N7Qh0P1jNWX207inOP`0b>3H000:0<SPf880P8201P38h=P207Mg
M`80OGem0P23Ph<207emO@80Ng]k0P1nOWh40861P@80Q8B40P2;Rh/208N7Q`80Ogmo0P23Ph<207]k
N`80PX:20P21PH4307moO`80O7al0P1kNg/208B4Q080Ph>30P21PH420820P080Ogmo0P22PX820861
P@80P8201022PX8207moO`80OWin101oOgl20820P0@0PX:20P23Ph<20820P080Ogmo0P21PH4207em
O@80OWin0P1mOGd207moO`80PX:20P23Ph<207inOP80OGem0`1nOWh207alO080Ogmo0P22PX8208>3
P`80OGem0P20P80207inOP80PH610P1lO7`208b<S080RHV90P26QXH208^;R`80QXJ60P21PH4<0<SP
f0002P38h=R20820P0H0b>3H0P1gMgL207emO@80Ph>30P1mOGd207]kN`80OWin1021PH4208B4Q080
Rh^;0P27QhL207moO`80Ph>30P1kNg/208:2PP80PH610`1oOgl207alO080Ng]k0P24Q8@208>3P`80
PH610P20P80207moO`80PX:20P21PH420820P0@0PX:20P1oOgl207inOP@0Ogmo0P20P80408:2PP80
Ph>30P20P80207moO`80PH610P1mOGd207inOP80OGem0P1oOgl208:2PP80Ph>30P1nOWh207emO@<0
OWin0P1lO7`207moO`80PX:20P23Ph<207emO@80P8200P1nOWh20861P@80O7al0P2<S8`208V9R@80
QXJ60P2;Rh/208J6QP80PH613038h=P000X0b>3HPP20P8060<SPf080OGem0P1kNg/207emO@80Ogmo
0P24Q8@207inOP@0Q8B40P1oOgl208F5Q@80S8b<0P21PH4208:2PP80PH610P24Q8@207inOP<0Q8B4
0P22PX8207moO`80Ng]k0P1fMWH407]kN`80PH610P1oOgl208:2PP80P8200P1nOWh20861P@80OWin
0P20P80207inOP80P8200P22PX8207alO080Ogmo0P22PX8207moO`80P8200P1oOgl207alO080Ph>3
0P20P8020861P@@0Ogmo0P20P80207moO`D0OGem1020P80207moO`80PX:20P25QHD208B4Q080P820
0P21PH4207QhN080QHF50P28R8P208j>SP80NGUi0P1mOGd<0<SPf0002P38h=R20820P0H0b>3H0P1m
OGd207]kN`80OGem0P1oOgl208B4Q080OWin1024Q8@207moO`80QHF50P2<S8`20861P@80PX:20P21
PH4208B4Q080OWin0`24Q8@208:2PP80Ogmo0P1kNg/207IfMP@0Ng]k0P21PH4207moO`80PX:20P20
P80207inOP80PH610P1nOWh20820P080OWin0P20P80208:2PP80O7al0P1oOgl208:2PP80Ogmo0P20
P80207moO`80O7al0P23Ph<20820P080PH61101oOgl20820P080Ogmo1@1mOGd40820P080Ogmo0P22
PX8208F5Q@80Q8B40P20P8020861P@80N7Qh0P25QHD208R8R080SXj>0P1iNGT207emO@`0b>3H000:
0<SPf880P8201P38h=P408:2PP80Q8B40P1kNg/208F5Q@80QhN70P1jNWX2079bLP80NGUi0P2?Shl2
07IfMP@0SHf=0P21PH4208J6QP80NGUi1@21PH4207alO080Ogmo0P1lO7`207UiN@80Q8B40P1oOgl2
07emO@80OWin0P23Ph<207inOP@0Ogmo0P21PH4207inOP80Ogmo0P21PH420820P080OWin0P21PH42
07inOP80Ph>30P1lO7`20820P080O7al0P1oOgl208:2PP80PH610P1mOGd20820P080OWin0`1oOgl2
07emO@80P8200P1jNWX607emO@80Ogmo0P21PH4207]kN`80P8200P26QXH207moO`80PH610P1oOgl2
0820P0`0b>3H000:0<SPf880P8201P38h=P408:2PP80Q8B40P1kNg/208F5Q@80QhN70P1jNWX2079b
LP80NGUi0P2?Shl207IfMP@0SHf=0P21PH4208J6QP80NGUi1@21PH4207alO080Ogmo0P1lO7`207Ui
N@80Q8B40P1oOgl207emO@80OWin0P23Ph<207inOP@0Ogmo0P21PH4207inOP80Ogmo0P21PH420820
P080OWin0P21PH4207inOP80Ph>30P1lO7`20820P080O7al0P1oOgl208:2PP80PH610P1mOGd20820
P080OWin0`1oOgl207emO@80P8200P1jNWX607emO@80Ogmo0P21PH4207]kN`80P8200P26QXH207mo
O`80PH610P1oOgl20820P0`0b>3H000:0<SPf880P8201P38h=P207]kN`80P820101mOGd207EeM@80
O7al0P25QHD208J6QP80R8R80P1jNWX207IfMP80M7Ad0P28R8P208f=S@80OGem0P26QXH307inOP80
LG5a0P1eMGD408:2PP80OWin0P27QhL207moO`80Ph>30P1mOGd407moO`80OGem0P20P8020861P@80
OWin0P1oOgl20820P080O7al0P21PH4208>3P`80O7al0P20P8020861P@80PX:20P1oOgl207emO@80
OWin0P20P80208:2PP80OWin0P21PH4308>3P`80PH610P20P80208B4Q080PX:20P21PH4208:2PP80
PH610P1oOgl20820P080Ogmo0P21PH4407inOP80P8200P1mOGd<0<SPf0002P38h=R20820P0H0b>3H
0P1kNg/20820P0@0OGem0P1eMGD207alO080QHF50P26QXH208R8R080NWYj0P1fMWH207AdM080R8R8
0P2=SHd207emO@80QXJ60`1nOWh2075aL@80MGEe1022PX8207inOP80QhN70P1oOgl208>3P`80OGem
101oOgl207emO@80P8200P21PH4207inOP80Ogmo0P20P80207alO080PH610P23Ph<207alO080P820
0P21PH4208:2PP80Ogmo0P1mOGd207inOP80P8200P22PX8207inOP80PH610`23Ph<20861P@80P820
0P24Q8@208:2PP80PH610P22PX820861P@80Ogmo0P20P80207moO`80PH61101nOWh20820P080OGem
3038h=P000X0b>3HPP20P8060<SPf080QHF50P21PH4207inOP80O7al0P26QXH207YjNP80NGUi0P1m
OGd20820P080Lg=c1P1bLW82071`L080PX:20P24Q8@508:2PP80OWin0P20P80207inOP80QHF50P23
Ph<20820P080Ng]k0P24Q8@207inOP80Ph>30P1nOWh207alO080Ogmo0P21PH440820P080OWin0P23
Ph<20861P@80Ogmo0P1lO7`20820P080OWin0P20P8040861P@80O7al0P20P80207emO@80PH610`1n
OWh207emO@80OWin0P1mOGd207]kN`80P8200P1oOgl207alO080Ph>30P20P80208B4Q080PX:20P24
Q8@207moO`80PH610P20P80<0<SPf0002P38h=R20820P0H0b>3H0P25QHD20861P@80OWin0P1lO7`2
08J6QP80NWYj0P1iNGT207emO@80P8200P1cLg<6079bLP80L71`0P22PX8208B4Q0D0PX:20P1nOWh2
0820P080OWin0P25QHD208>3P`80P8200P1kNg/208B4Q080OWin0P23Ph<207inOP80O7al0P1oOgl2
0861P@@0P8200P1nOWh208>3P`80PH610P1oOgl207alO080P8200P1nOWh20820P0@0PH610P1lO7`2
0820P080OGem0P21PH4307inOP80OGem0P1nOWh207emO@80Ng]k0P20P80207moO`80O7al0P23Ph<2
0820P080Q8B40P22PX8208B4Q080Ogmo0P21PH420820P0`0b>3H000:0<SPf880P8201P38h=P207mo
O`80Ph>30P1mOGd207MgM`80OGem0P29RHT207emO@@0PH610P1kNg/208F5Q@80MWIf0P1dM7@407em
O@80O7al0`24Q8@207moO`80NWYj0P1oOgl207emO@80QHF50P23Ph<20861P@80QHF50P1nOWh207mo
O`80O7al0P1oOgl207alO080Ogmo0P20P80207moO`80OWin0P22PX820820P0@0Ogmo0P21PH4208:2
PP@0OWin0P22PX820861P@80OGem1021PH4207emO@<0O7al0P1nOWh207moO`80P820101oOgl20861
P@80Ogmo0P20P80208>3P`H0P8200P1oOgl40820P0`0b>3H000:0<SPf880P8201P38h=P207moO`80
Ph>30P1mOGd207MgM`80OGem0P29RHT207emO@@0PH610P1kNg/208F5Q@80MWIf0P1dM7@407emO@80
O7al0`24Q8@207moO`80NWYj0P1oOgl207emO@80QHF50P23Ph<20861P@80QHF50P1nOWh207moO`80
O7al0P1oOgl207alO080Ogmo0P20P80207moO`80OWin0P22PX820820P0@0Ogmo0P21PH4208:2PP@0
OWin0P22PX820861P@80OGem1021PH4207emO@<0O7al0P1nOWh207moO`80P820101oOgl20861P@80
Ogmo0P20P80208>3P`H0P8200P1oOgl40820P0`0b>3H000:0<SPf880P8201P38h=P207emO@80P820
0P28R8P408:2PP80OWin1022PX820861P@80Ph>30P1mOGd208:2PP80QHF50P1hN7P208V9R@80OWin
0`21PH4207alO080Ph>30P1nOWh407emO@80QHF50P24Q8@207inOP80PH61101oOgl20820P080Ph>3
101mOGd20820P080OGem0P21PH4207inOP80Ph>30P1lO7`408:2PP80OWin0P20P80207inOP@0P820
0P1oOgl20861P@80Ogmo0`21PH4207inOP80OGem0P1nOWh207moO`80OGem0P21PH4207emO@80P820
0P1mOGd208>3P`@0OGem0P20P80207moO`80OWin3038h=P000X0b>3HPP20P8060<SPf080OGem0P20
P80208R8R0@0PX:20P1nOWh408:2PP80PH610P23Ph<207emO@80PX:20P25QHD207QhN080RHV90P1n
OWh30861P@80O7al0P23Ph<207inOP@0OGem0P25QHD208B4Q080OWin0P21PH4407moO`80P8200P23
Ph<407emO@80P8200P1mOGd20861P@80OWin0P23Ph<207alO0@0PX:20P1nOWh20820P080OWin1020
P80207moO`80PH610P1oOgl30861P@80OWin0P1mOGd207inOP80Ogmo0P1mOGd20861P@80OGem0P20
P80207emO@80Ph>3101mOGd20820P080Ogmo0P1nOWh<0<SPf0002P38h=R20820P0H0b>3H0P1mOGd2
0820P080R8R81022PX8207inOP@0PX:20P21PH4208>3P`80OGem0P22PX8208F5Q@80N7Qh0P29RHT2
07inOP<0PH610P1lO7`208>3P`80OWin101mOGd208F5Q@80Q8B40P1nOWh20861P@@0Ogmo0P20P802
08>3P`@0OGem0P20P80207emO@80PH610P1nOWh208>3P`80O7al1022PX8207inOP80P8200P1nOWh4
0820P080Ogmo0P21PH4207moO`<0PH610P1nOWh207emO@80OWin0P1oOgl207emO@80PH610P1mOGd2
0820P080OGem0P23Ph<407emO@80P8200P1oOgl207inOP`0b>3H000:0<SPf880P8201P38h=P207al
O080OWin0P2=SHd207emO@80PH610P1mOGd20820P080Ng]k0P1nOWh207QhN080Ogmo0P21PH4208>3
P`80OGem0P25QHD20820P0<0OGem0P25QHD207moO`80OGem0P21PH420820P080Ng]k0P20P80207al
O080Ph>30P1nOWh208F5Q@80OGem0P20P80207moO`80OWin0P1oOgl20861P@80OGem0P21PH4207mo
O`80PX:20P1oOgl408:2PP80Ph>30P22PX8207]kN`80NGUi0P20P80207moO`80P8200`1oOgl208>3
P`80PH610P1nOWh20820P0H0OWin0P21PH4207inOP80OGem1P1oOgl207inOP80P8203038h=P000X0
b>3HPP20P8060<SPf080O7al0P1nOWh208f=S@80OGem0P21PH4207emO@80P8200P1kNg/207inOP80
N7Qh0P1oOgl20861P@80Ph>30P1mOGd208F5Q@80P8200`1mOGd208F5Q@80Ogmo0P1mOGd20861P@80
P8200P1kNg/20820P080O7al0P23Ph<207inOP80QHF50P1mOGd20820P080Ogmo0P1nOWh207moO`80
PH610P1mOGd20861P@80Ogmo0P22PX8207moO`@0PX:20P23Ph<208:2PP80Ng]k0P1iNGT20820P080
Ogmo0P20P80307moO`80Ph>30P21PH4207inOP80P8201P1nOWh20861P@80OWin0P1mOGd607moO`80
OWin0P20P80<0<SPf0002P38h=R20820P0H0b>3H0P1oOgl208B4Q080SXj>0P20P80207emO@80Ogmo
0P1nOWh207YjNP80PX:20P1oOgl407alO080P8200P23Ph<207=cL`80QHF50`1kNg/208J6QP80PX:2
0P21PH4207emO@80Ogmo0P23Ph<207moO`80PX:21020P8020861P@80PX:20P20P80207alO080P820
0P1oOgl207emO@80P8200P23Ph<208:2PP80Ogmo0P23Ph<207]kN`80Ogmo0P21PH420820P080OWin
0P22PX8207alO080Q8B41@1oOgl207]kN`80OWin0P1mOGd207alO080PX:20P23Ph<20861P@80OGem
0P1nOWh207moO`80OGem0P1nOWh208:2PP80OWin0P1oOgl<0<SPf0002P38h=R20820P0H0b>3H0P1o
Ogl208B4Q080SXj>0P20P80207emO@80Ogmo0P1nOWh207YjNP80PX:20P1oOgl407alO080P8200P23
Ph<207=cL`80QHF50`1kNg/208J6QP80PX:20P21PH4207emO@80Ogmo0P23Ph<207moO`80PX:21020
P8020861P@80PX:20P20P80207alO080P8200P1oOgl207emO@80P8200P23Ph<208:2PP80Ogmo0P23
Ph<207]kN`80Ogmo0P21PH420820P080OWin0P22PX8207alO080Q8B41@1oOgl207]kN`80OWin0P1m
OGd207alO080PX:20P23Ph<20861P@80OGem0P1nOWh207moO`80OGem0P1nOWh208:2PP80OWin0P1o
Ogl<0<SPf0002P38h=R20820P0H0b>3H0P29RHT207UiN@80OWin0P1lO7`207moO`80Ph>30P1nOWh2
08F5Q@@0OWin0P20P80207emO@80Ogmo0P20P80208B4Q080OGem0`22PX8207moO`80QHF50P21PH42
07moO`80P8200P1oOgl20861P@80Q8B40P23Ph<60861P@80OGem0P20P80208:2PP80O7al0P25QHD2
07moO`80O7al0P1nOWh207moO`80PX:20P1oOgl40820P080OWin0P21PH4207emO@80PX:20P1oOgl2
0820P0<0PX:20P1oOgl20861P@80PX:20P24Q8@407moO`80OWin0P21PH420820P080Ogmo1021PH42
07]kN`@0PH613038h=P000X0b>3HPP20P8060<SPf080RHV90P1iNGT207inOP80O7al0P1oOgl208>3
P`80OWin0P25QHD407inOP80P8200P1mOGd207moO`80P8200P24Q8@207emO@<0PX:20P1oOgl208F5
Q@80PH610P1oOgl20820P080Ogmo0P21PH4208B4Q080Ph>31P21PH4207emO@80P8200P22PX8207al
O080QHF50P1oOgl207alO080OWin0P1oOgl208:2PP80Ogmo1020P80207inOP80PH610P1mOGd208:2
PP80Ogmo0P20P80308:2PP80Ogmo0P21PH4208:2PP80Q8B4101oOgl207inOP80PH610P20P80207mo
O`@0PH610P1kNg/40861P@`0b>3H000:0<SPf880P8201P38h=P207MgM`80P8200P1oOgl408:2PP80
PH61101mOGd207moO`80PX:20P1nOWh207alO0@0P8200P1nOWh207moO`D0NGUi0P22PX8207UiN@80
Ph>30P27QhL208R8R080O7al101oOgl20820P080O7al0P20P80208>3P`80NWYj1P1nOWh208:2PP@0
PH610P1oOgl207alO080OWin1P20P80207moO`80PX:20P20P80207]kN`80P8200`1nOWh20861P@80
P8201021PH4807alO080Ogmo0P22PX820820P080PH610P1nOWh207alO080P8203038h=P000X0b>3H
PP20P8060<SPf080MgMg0P20P80207moO`@0PX:20P21PH4407emO@80Ogmo0P22PX8207inOP80O7al
1020P80207inOP80Ogmo1@1iNGT208:2PP80NGUi0P23Ph<208N7Q`80R8R80P1lO7`407moO`80P820
0P1lO7`20820P080Ph>30P1jNWX607inOP80PX:21021PH4207moO`80O7al0P1nOWh60820P080Ogmo
0P22PX820820P080Ng]k0P20P80307inOP80PH610P20P8040861P@P0O7al0P1oOgl208:2PP80P820
0P21PH4207inOP80O7al0P20P80<0<SPf0002P38h=R20820P0H0b>3H0P24Q8@208:2PP80P8200P1f
MWH20820P080Ogmo0P1jNWX40820P080Ng]k0P1nOWh207emO@80OWin0P21PH420820P080PH610`1e
MGD208J6QP80OGem0P1jNWX20861P@80OWin0P21PH4208F5Q@80PH610P1lO7`408:2PP80PH610P1m
OGd207moO`@0PH610P20P80207moO`80OGem1021PH4208B4Q080OWin0P22PX820861P@80P8200P1n
OWh208B4Q080OGem0P1oOgl208:2PP<0OWin0P23Ph<20861P@80Q8B40P21PH4207moO`80PX:20P20
P8060861P@80OGem0P20P80208>3P`80O7al0P1oOgl<0<SPf0002P38h=R20820P0H0b>3H0P24Q8@2
08:2PP80P8200P1fMWH20820P080Ogmo0P1jNWX40820P080Ng]k0P1nOWh207emO@80OWin0P21PH42
0820P080PH610`1eMGD208J6QP80OGem0P1jNWX20861P@80OWin0P21PH4208F5Q@80PH610P1lO7`4
08:2PP80PH610P1mOGd207moO`@0PH610P20P80207moO`80OGem1021PH4208B4Q080OWin0P22PX82
0861P@80P8200P1nOWh208B4Q080OGem0P1oOgl208:2PP<0OWin0P23Ph<20861P@80Q8B40P21PH42
07moO`80PX:20P20P8060861P@80OGem0P20P80208>3P`80O7al0P1oOgl<0<SPf0002P38h=R20820
P0H0b>3H0P20P80208B4Q080PH610P1iNGT208>3P`80OGem0P1lO7`607moO`80R8R80P21PH4207in
OP80Ng]k0P1nOWh208:2PP<0Ph>30P21PH4208R8R080NWYj0P1nOWh407moO`80OGem0P21PH4208B4
Q080OWin0P1mOGd208B4Q080Ng]k0P1mOGd20820P080OGem0P23Ph<20861P@80Ogmo0P23Ph<207em
O@80O7al0P21PH420820P080OGem0P1lO7`208>3P`80Q8B40P23Ph<207moO`80P8201@1lO7`20861
P@80P8200P23Ph<40861P@80Ogmo0P22PX820820P080OGem0P21PH4407moO`80PH610P1oOgl<0<SP
f0002P38h=R20820P0H0b>3H0P20P80208B4Q080PH610P1iNGT208>3P`80OGem0P1lO7`607moO`80
R8R80P21PH4207inOP80Ng]k0P1nOWh208:2PP<0Ph>30P21PH4208R8R080NWYj0P1nOWh407moO`80
OGem0P21PH4208B4Q080OWin0P1mOGd208B4Q080Ng]k0P1mOGd20820P080OGem0P23Ph<20861P@80
Ogmo0P23Ph<207emO@80O7al0P21PH420820P080OGem0P1lO7`208>3P`80Q8B40P23Ph<207moO`80
P8201@1lO7`20861P@80P8200P23Ph<40861P@80Ogmo0P22PX820820P080OGem0P21PH4407moO`80
PH610P1oOgl<0<SPf0002P38h=R20820P0H0b>3H0P1nOWh20820P080SHf=0P23Ph<207inOP80OGem
0P24Q8@207alO080Ogmo0P1iNGT207MgM`80OWin0P23Ph<207alO080PX:20P1lO7`30820P080Ng]k
0P27QhL207]kN`80PX:20P21PH4207moO`80PX:2101nOWh20861P@80OGem0P1nOWh208:2PP80OWin
0P1mOGd207inOP80Ogmo0P1nOWh207moO`80PH610P23Ph<207moO`80OGem0P21PH4207alO080PX:2
1P1mOGd40820P0<0OWin2020P80207emO@@0PX:20P20P80207alO080Ogmo0P1mOGd407moO`80OWin
0P21PH4<0<SPf0002P38h=R20820P0H0b>3H0P1nOWh20820P080SHf=0P23Ph<207inOP80OGem0P24
Q8@207alO080Ogmo0P1iNGT207MgM`80OWin0P23Ph<207alO080PX:20P1lO7`30820P080Ng]k0P27
QhL207]kN`80PX:20P21PH4207moO`80PX:2101nOWh20861P@80OGem0P1nOWh208:2PP80OWin0P1m
OGd207inOP80Ogmo0P1nOWh207moO`80PH610P23Ph<207moO`80OGem0P21PH4207alO080PX:21P1m
OGd40820P0<0OWin2020P80207emO@@0PX:20P20P80207alO080Ogmo0P1mOGd407moO`80OWin0P21
PH4<0<SPf0002P38h=R20820P0H0b>3H0P1lO7`207inOP80P8200P1oOgl207]kN`80Ogmo0P22PX82
08F5Q@@0P8200P1lO7`208J6QP80OWin0P24Q8@207moO`80PH610`20P80208:2PP80MGEe0P2<S8`2
07emO@80Ogmo0P23Ph<20820P080Ogmo1020P80607moO`80P8200P24Q8@20861P@80PX:20P1nOWh2
0861P@80OGem0P1oOgl20861P@80PX:2101nOWh20820P080PX:20P24Q8@208>3P`80OGem0P24Q8@5
0820P0@0Ph>31021PH4207alO080Ph>30P21PH4208B4Q080PH610P23Ph<208:2PP80Q8B4101oOgl<
0<SPf0002P38h=R20820P0H0b>3H0P1lO7`207inOP80P8200P1oOgl207]kN`80Ogmo0P22PX8208F5
Q@@0P8200P1lO7`208J6QP80OWin0P24Q8@207moO`80PH610`20P80208:2PP80MGEe0P2<S8`207em
O@80Ogmo0P23Ph<20820P080Ogmo1020P80607moO`80P8200P24Q8@20861P@80PX:20P1nOWh20861
P@80OGem0P1oOgl20861P@80PX:2101nOWh20820P080PX:20P24Q8@208>3P`80OGem0P24Q8@50820
P0@0Ph>31021PH4207alO080Ph>30P21PH4208B4Q080PH610P23Ph<208:2PP80Q8B4101oOgl<0<SP
f0002P38h=R20820P0H0b>3H0P21PH4207emO@80QXJ60P22PX820861P@80OWin0P20P80207moO`80
NGUi0P1mOGd407QhN080OWin0P1mOGd20820P080OGem0`1oOgl207inOP80QHF50P1hN7P208F5Q@80
O7al0P21PH4208:2PP80Ogmo0P20P80208:2PP80PH61101oOgl207inOP80P8200P1mOGd207alO0H0
P8200P21PH420820P080OWin0P21PH420820P080O7al0P22PX8207moO`80PX:20P1nOWh208:2PP<0
PH610P20P80207moO`80OWin0P1lO7`20820P080PX:20P1oOgl207]kN`80PH610P1oOgl20861P@80
OGem0P22PX8207inOP80OGem3038h=P000X0b>3HPP20P8060<SPf080PH610P1mOGd208J6QP80PX:2
0P21PH4207inOP80P8200P1oOgl207UiN@80OGem101hN7P207inOP80OGem0P20P80207emO@<0Ogmo
0P1nOWh208F5Q@80N7Qh0P25QHD207alO080PH610P22PX8207moO`80P8200P22PX820861P@@0Ogmo
0P1nOWh20820P080OGem0P1lO7`60820P080PH610P20P80207inOP80PH610P20P80207alO080PX:2
0P1oOgl208:2PP80OWin0P22PX830861P@80P8200P1oOgl207inOP80O7al0P20P80208:2PP80Ogmo
0P1kNg/20861P@80Ogmo0P21PH4207emO@80PX:20P1nOWh207emO@`0b>3H000:0<SPf880P8201P38
h=P207EeM@80P8200P1oOgl208B4Q080Ng]k0P20P80207QhN0@0PH611020P80207alO080Q8B40P1n
OWh20861P@D0OWin101oOgl20861P@80Ng]k0P23Ph<207moO`80NGUi0P23Ph<20820P080Ng]k0P22
PX8207moO`80OWin0P21PH4208>3P`80Ogmo0P21PH4407moO`80OWin0P1oOgl20820P080PX:20P1n
OWh20820P080PH610P1hN7P207moO`80OWin0P23Ph<208F5Q@<0OWin0P20P80208B4Q080PH610P1o
Ogl208:2PP80OGem1P21PH420820P080Ogmo0P24Q8@207inOP@0P8203038h=P000X0b>3HPP20P806
0<SPf080MGEe0P20P80207moO`80Q8B40P1kNg/20820P080N7Qh1021PH440820P080O7al0P24Q8@2
07inOP80PH611@1nOWh407moO`80PH610P1kNg/208>3P`80Ogmo0P1iNGT208>3P`80P8200P1kNg/2
08:2PP80Ogmo0P1nOWh20861P@80Ph>30P1oOgl20861P@@0Ogmo0P1nOWh207moO`80P8200P22PX82
07inOP80P8200P21PH4207QhN080Ogmo0P1nOWh208>3P`80QHF50`1nOWh20820P080Q8B40P21PH42
07moO`80PX:20P1mOGd60861P@80P8200P1oOgl208B4Q080OWin1020P80<0<SPf0002P38h=R20820
P0H0b>3H0P28R8P207emO@@0P8200P1mOGd207moO`80O7al0P1oOgl207UiN@80P8200P1nOWh208J6
QP80NWYj0P23Ph<20861P@D0OWin0P20P80207moO`80PX:20P1iNGT208b<S0@0OWin0P22PX8207in
OP80Q8B4101nOWh207emO@80OWin0P21PH4208:2PP80OGem0P1lO7`20820P080PX:20P1nOWh20861
P@80P8200P22PX8607moO`80OWin0P1oOgl40820P0<0PH610P23Ph<207]kN`@0P8200P21PH4407in
OP80Ogmo101mOGd208>3P`80OWin0P24Q8@207inOP80PH613038h=P000X0b>3HPP20P8060<SPf080
R8R80P1mOGd40820P080OGem0P1oOgl207alO080Ogmo0P1iNGT20820P080OWin0P26QXH207YjNP80
Ph>30P21PH4507inOP80P8200P1oOgl208:2PP80NGUi0P2<S8`407inOP80PX:20P1nOWh208B4Q0@0
OWin0P1mOGd207inOP80PH610P22PX8207emO@80O7al0P20P80208:2PP80OWin0P21PH420820P080
PX:21P1oOgl207inOP80Ogmo1020P8030861P@80Ph>30P1kNg/40820P080PH61101nOWh207moO`@0
OGem0P23Ph<207inOP80Q8B40P1nOWh20861P@`0b>3H000:0<SPf880P8201P38h=P207emO@80PH61
0P1nOWh208J6QP80P8200P23Ph<208:2PP80PH610P1jNWX207emO@80NWYj0P21PH4207inOP80Ph>3
1020P80308:2PP80O7al0P21PH420820P080QHF50P1bLW8208b<S080NGUi0P23Ph<208:2PP80P820
101mOGd207moO`80OWin101mOGd207moO`80PH61101oOgl20820P080OGem0P1oOgl20861P@80Ogmo
0P1nOWh207moO`80P8200P1nOWh407emO@<0QHF50P21PH420820P080QHF50P22PX8208B4Q080O7al
0P22PX820820P0@0OGem0P20P80207alO0@0P8200P1lO7`<0<SPf0002P38h=R20820P0H0b>3H0P1m
OGd20861P@80OWin0P26QXH20820P080Ph>30P22PX820861P@80NWYj0P1mOGd207YjNP80PH610P1n
OWh208>3P`@0P8200`22PX8207alO080PH610P20P80208F5Q@80LW9b0P2<S8`207UiN@80Ph>30P22
PX820820P0@0OGem0P1oOgl207inOP@0OGem0P1oOgl20861P@@0Ogmo0P20P80207emO@80Ogmo0P21
PH4207moO`80OWin0P1oOgl20820P080OWin101mOGd308F5Q@80PH610P20P80208F5Q@80PX:20P24
Q8@207alO080PX:20P20P80407emO@80P8200P1lO7`40820P080O7al3038h=P000X0b>3HPP20P806
0<SPf080Q8B40P1mOGd208>3P`80PH610P1oOgl208B4Q080Ogmo0P22PX8207]kN`80P8200P1nOWh2
07emO@80PX:20P1jNWX208>3P`80P8200`21PH420820P080Ogmo0P1mOGd20820P080Q8B40P1bLW82
08^;R`80N7Qh0P1lO7`207inOP80Q8B40P1kNg/60820P080PX:20P1lO7`207moO`80O7al0P20P802
0861P@80P8200P1oOgl20861P@80PX:2101nOWh208>3P`80OGem0P1kNg/208:2PP<0O7al0P1mOGd2
08>3P`80OWin0P21PH4207moO`80PH61101oOgl20820P080OGem0P21PH4207moO`80PH610P22PX82
08B4Q0`0b>3H000:0<SPf880P8201P38h=P208B4Q080OGem0P23Ph<20861P@80Ogmo0P24Q8@207mo
O`80PX:20P1kNg/20820P080OWin0P1mOGd208:2PP80NWYj0P23Ph<20820P0<0PH610P20P80207mo
O`80OGem0P20P80208B4Q080LW9b0P2;Rh/207QhN080O7al0P1nOWh208B4Q080Ng]k1P20P80208:2
PP80O7al0P1oOgl207alO080P8200P21PH420820P080Ogmo0P21PH4208:2PP@0OWin0P23Ph<207em
O@80Ng]k0P22PX8307alO080OGem0P23Ph<207inOP80PH610P1oOgl20861P@@0Ogmo0P20P80207em
O@80PH610P1oOgl20861P@80PX:20P24Q8@<0<SPf0002P38h=R20820P0H0b>3H0P1mOGd20820P080
Ng]k0P1jNWX208F5Q@@0Ng]k101nOWh408:2PP80Ogmo0P22PX820861P@80Ogmo0P1mOGd307UiN@80
PH610P23Ph<208B4Q080Ogmo0P1mOGd208:2PP80Lg=c0P2;Rh/207YjNP80PX:20P21PH420820P080
PX:20P1mOGd207moO`80OGem0P20P80208>3P`80P8200P23Ph<407moO`80O7al0P1oOgl20861P@80
PX:20P24Q8@208>3P`80Q8B40P21PH4208>3P`<0OWin0P1kNg/207emO@80PH611P1oOgl208>3P`80
NWYj0P22PX820820P080Ogmo0P20P80408:2PP80P8203038h=P000X0b>3HPP20P8060<SPf080OGem
0P20P80207]kN`80NWYj0P25QHD407]kN`@0OWin1022PX8207moO`80PX:20P21PH4207moO`80OGem
0`1iNGT20861P@80Ph>30P24Q8@207moO`80OGem0P22PX8207=cL`80Rh^;0P1jNWX208:2PP80PH61
0P20P80208:2PP80OGem0P1oOgl207emO@80P8200P23Ph<20820P080Ph>3101oOgl207alO080Ogmo
0P21PH4208:2PP80Q8B40P23Ph<208B4Q080PH610P23Ph<307inOP80Ng]k0P1mOGd20861P@H0Ogmo
0P23Ph<207YjNP80PX:20P20P80207moO`80P8201022PX820820P0`0b>3H000:0<SPf880P8201P38
h=P207QhN080Q8B40P1jNWX207inOP80QHF50P1jNWX207emO@80NWYj0P1lO7`40820P080QXJ60P1m
OGd20861P@80O7al0P22PX830820P0@0PH610P1mOGd20820P080PH610P1mOGd208:2PP80MWIf0P29
RHT207emO@@0Ogmo0P1lO7`207moO`80Q8B40P22PX8207]kN`80P8200P23Ph<207emO@80Ogmo0P24
Q8@20861P@80Ogmo0P1lO7`207emO@80NWYj0P1oOgl407alO080NWYj1@1mOGd20820P080Ng]k0P1n
OWh208:2PP@0OWin0P21PH4208:2PP80P820101oOgl20820P080PH610P1oOgl<0<SPf0002P38h=R2
0820P0H0b>3H0P1hN7P208B4Q080NWYj0P1nOWh208F5Q@80NWYj0P1mOGd207YjNP80O7al1020P802
08J6QP80OGem0P21PH4207alO080PX:20`20P8040861P@80OGem0P20P8020861P@80OGem0P22PX82
07IfMP80RHV90P1mOGd407moO`80O7al0P1oOgl208B4Q080PX:20P1kNg/20820P080Ph>30P1mOGd2
07moO`80Q8B40P21PH4207moO`80O7al0P1mOGd207YjNP80Ogmo101lO7`207YjNPD0OGem0P20P802
07]kN`80OWin0P22PX8407inOP80PH610P22PX820820P0@0Ogmo0P20P8020861P@80Ogmo3038h=P0
00X0b>3HPP20P8060<SPf080O7al0P1bLW8207inOP80Ph>30P1lO7`208J6QP80PH611024Q8@407em
O@80Ogmo0P1mOGd20861P@80Ph>30P1oOgl307emO@80P8200P1nOWh20861P@80OGem0P1kNg/20820
P080Ogmo0P20P80207UiN@80Q8B40P1nOWh208:2PP@0Ogmo1021PH4208>3P`80Ogmo0P1nOWh20861
P@80Ogmo0P1nOWh207emO@@0OWin0P21PH4208B4Q080OGem0P1nOWh207YjNP80Ng]k0`1mOGd207If
MP80Ogmo0P22PX8208B4Q080P8200P25QHD208:2PP80PH610P1kNg/20820P080Ogmo0P20P8020861
P@80O7al0P23Ph<<0<SPf0002P38h=R20820P0H0b>3H0P1lO7`2079bLP80OWin0P23Ph<207alO080
QXJ60P21PH4408B4Q0@0OGem0P1oOgl207emO@80PH610P23Ph<207moO`<0OGem0P20P80207inOP80
PH610P1mOGd207]kN`80P8200P1oOgl20820P080NGUi0P24Q8@207inOP80PX:2101oOgl40861P@80
Ph>30P1oOgl207inOP80PH610P1oOgl207inOP80OGem101nOWh20861P@80Q8B40P1mOGd207inOP80
NWYj0P1kNg/307emO@80MWIf0P1oOgl208:2PP80Q8B40P20P80208F5Q@80PX:20P21PH4207]kN`80
P8200P1oOgl20820P080PH610P1lO7`208>3P``0b>3H000:0<SPf880P8201P38h=P208>3P`80Ogmo
0P1lO7`207inOP@0PX:20P1lO7`207]kN`80Ogmo0P1lO7`207inOP80O7al0P21PH420820P080PX:2
0P1mOGd30820P080Ph>30P1oOgl208B4Q0@0P8200P1nOWh207alO080PX:20P1mOGd207MgM`80PH61
0P1nOWh208B4Q080P8200P1oOgl208:2PP80Ogmo0P22PX8407emO@80OWin0P21PH4407inOP80Ph>3
0P22PX8207emO@80Q8B40P22PX8208V9R@80MWIf0`1dM7@207=cL`80QHF50P1jNWX207UiN@80Ng]k
0P1oOgl20820P080Ph>30P20P80207inOP80Ogmo101kNg/20861P@80PX:23038h=P000X0b>3HPP20
P8060<SPf080Ph>30P1oOgl207alO080OWin1022PX8207alO080Ng]k0P1oOgl207alO080OWin0P1l
O7`20861P@80P8200P22PX8207emO@<0P8200P23Ph<207moO`80Q8B41020P80207inOP80O7al0P22
PX8207emO@80MgMg0P21PH4207inOP80Q8B40P20P80207moO`80PX:20P1oOgl208:2PP@0OGem0P1n
OWh20861P@@0OWin0P23Ph<208:2PP80OGem0P24Q8@208:2PP80RHV90P1fMWH307AdM080Lg=c0P25
QHD207YjNP80NGUi0P1kNg/207moO`80P8200P23Ph<20820P080OWin0P1oOgl407]kN`80PH610P22
PX8<0<SPf0002P38h=R20820P0H0b>3H0P27QhL207emO@80Ph>30P20P80207]kN`80P8200P22PX82
07emO@80NWYj0P29RHT208B4Q080Ph>30P1jNWX208B4Q080P8200P26QXH307]kN`80R8R80P1oOgl2
07inOP80Ogmo0P1nOWh207emO@80PH611020P80207alO080N7Qh0P26QXH207emO@80Ph>30P1oOgl4
08:2PP@0OWin0P1oOgl208:2PP80OWin0P21PH4207]kN`80O7al0P29RHT208F5Q@80M7Ad0P1jNWX2
07moO`80Ng]k0`20P80207inOP80LG5a0P2<S8`207inOP80Ph>30P21PH4207emO@80Ogmo0P25QHD2
07moO`80QXJ60P1lO7`208F5Q@80Q8B40P1oOgl<0<SPf0002P38h=R20820P0H0b>3H0P27QhL207em
O@80Ph>30P20P80207]kN`80P8200P22PX8207emO@80NWYj0P29RHT208B4Q080Ph>30P1jNWX208B4
Q080P8200P26QXH307]kN`80R8R80P1oOgl207inOP80Ogmo0P1nOWh207emO@80PH611020P80207al
O080N7Qh0P26QXH207emO@80Ph>30P1oOgl408:2PP@0OWin0P1oOgl208:2PP80OWin0P21PH4207]k
N`80O7al0P29RHT208F5Q@80M7Ad0P1jNWX207moO`80Ng]k0`20P80207inOP80LG5a0P2<S8`207in
OP80Ph>30P21PH4207emO@80Ogmo0P25QHD207moO`80QXJ60P1lO7`208F5Q@80Q8B40P1oOgl<0<SP
f0002P38h=R20820P0H0b>3H0P1hN7P208B4Q080QXJ60P23Ph<207UiN@80P8200P1iNGT208B4Q080
M7Ad0P25QHD208B4Q080Ph>30P22PX820820P080OWin0P25QHD307MgM`80OGem0P1nOWh207alO080
R8R81022PX820861P@80Ogmo1021PH4207inOP80Ogmo0P29RHT207MgM`80PH610P1nOWh20861P@80
P8200P24Q8@20820P080Ogmo0P1lO7`207inOP80P8200P1gMgL207alO080OGem0P1lO7`207QhN080
O7al0P1mOGd307alO080NWYj0P1fMWH208b<S080PH610P1eMGD207inOP@0P8200P1oOgl208>3P`80
OGem0P1nOWh20820P080OGem0P21PH4<0<SPf0002P38h=R20820P0H0b>3H0P1hN7P208B4Q080QXJ6
0P23Ph<207UiN@80P8200P1iNGT208B4Q080M7Ad0P25QHD208B4Q080Ph>30P22PX820820P080OWin
0P25QHD307MgM`80OGem0P1nOWh207alO080R8R81022PX820861P@80Ogmo1021PH4207inOP80Ogmo
0P29RHT207MgM`80PH610P1nOWh20861P@80P8200P24Q8@20820P080Ogmo0P1lO7`207inOP80P820
0P1gMgL207alO080OGem0P1lO7`207QhN080O7al0P1mOGd307alO080NWYj0P1fMWH208b<S080PH61
0P1eMGD207inOP@0P8200P1oOgl208>3P`80OGem0P1nOWh20820P080OGem0P21PH4<0<SPf0002P38
h=R20820P0H0b>3H0P1fMWH208>3P`80OWin0P20P80208R8R080P8200P23Ph<207inOP80OGem0P21
PH4207alO080OWin0P26QXH208B4Q0@0Ng]k0`1lO7`207MgM`80Q8B40P21PH42079bLP80NGUi0P1h
N7P207alO080P8200P1oOgl207inOP80P8200P1mOGd207UiN@80QHF50P1kNg/20820P080OGem0P1n
OWh208>3P`80OGem0P1oOgl208J6QP80PX:20P1nOWh208N7Q`80OGem0P1nOWh208f=S@80QhN70P1f
MWH208:2PP<0QHF50P24Q8@208N7Q`80OGem0P20P8020861P@80PX:20P1oOgl208>3P`80OGem0P1l
O7`20820P080Ph>31P1lO7`<0<SPf0002P38h=R20820P0H0b>3H0P1fMWH208>3P`80OWin0P20P802
08R8R080P8200P23Ph<207inOP80OGem0P21PH4207alO080OWin0P26QXH208B4Q0@0Ng]k0`1lO7`2
07MgM`80Q8B40P21PH42079bLP80NGUi0P1hN7P207alO080P8200P1oOgl207inOP80P8200P1mOGd2
07UiN@80QHF50P1kNg/20820P080OGem0P1nOWh208>3P`80OGem0P1oOgl208J6QP80PX:20P1nOWh2
08N7Q`80OGem0P1nOWh208f=S@80QhN70P1fMWH208:2PP<0QHF50P24Q8@208N7Q`80OGem0P20P802
0861P@80PX:20P1oOgl208>3P`80OGem0P1lO7`20820P080Ph>31P1lO7`<0<SPf0002P38h=R20820
P0H0b>3H0P27QhL208B4Q080Ph>30P1nOWh207alO080OWin0P1oOgl207emO@80PH61101mOGd20861
P@80P8200P1nOWh208:2PP80OGem0`1nOWh408V9R@80OWin0P24Q8@208R8R080Rh^;0P28R8P208F5
Q@@0P8200P1nOWh407moO`80P8200P22PX820861P@80P8200P1kNg/208>3P`80Ng]k0P22PX8407If
MP80PX:20P1kNg/208^;R`80O7al0P2>SXh207inOP80S8b<0P1hN7P307emO@80O7al0P1nOWh207em
O@80Ogmo0P1nOWh20861P@80Ogmo0P20P80408:2PP80OWin0P1oOgl40820P080O7al3038h=P000X0
b>3HPP20P8060<SPf080QhN70P24Q8@208>3P`80OWin0P1lO7`207inOP80Ogmo0P1mOGd20861P@@0
OGem0P21PH420820P080OWin0P22PX8207emO@<0OWin1029RHT207inOP80Q8B40P28R8P208^;R`80
R8R80P25QHD40820P080OWin101oOgl20820P080PX:20P21PH420820P080Ng]k0P23Ph<207]kN`80
PX:2101fMWH208:2PP80Ng]k0P2;Rh/207alO080SXj>0P1nOWh208b<S080N7Qh0`1mOGd207alO080
OWin0P1mOGd207moO`80OWin0P21PH4207moO`80P8201022PX8207inOP80Ogmo1020P80207alO0`0
b>3H000:0<SPf880P8201P38h=P20861P@80Ogmo0P25QHD20861P@80Rh^;0P1nOWh207alO080QXJ6
0P21PH4407inOP80P8200P1mOGd207AdM080PH611@1nOWh2071`L080LG5a0P1iNGT208:2PP80NGUi
0P1lO7`207EeM@80NGUi0P1lO7`207moO`@0PX:2101lO7`208>3P`80NGUi0P1oOgl207]kN`80P820
0P29RHT207alO0@0PH610P1lO7`208J6QP80M7Ad0P1nOWh20861P@80LW9b0P1eMGD20861P@<0Ogmo
0P20P8020861P@80Ogmo0P1nOWh207moO`80OGem0P20P80207emO@80Ogmo0P1nOWh208N7Q`80OWin
1P20P80<0<SPf0002P38h=R20820P0H0b>3H0P21PH4207moO`80QHF50P21PH4208^;R`80OWin0P1l
O7`208J6QP80PH61101nOWh20820P080OGem0P1dM7@20861P@D0OWin0P1`L702075aL@80NGUi0P22
PX8207UiN@80O7al0P1eMGD207UiN@80O7al0P1oOgl408:2PP@0O7al0P23Ph<207UiN@80Ogmo0P1k
Ng/20820P080RHV90P1lO7`40861P@80O7al0P26QXH207AdM080OWin0P21PH42079bLP80MGEe0P21
PH4307moO`80P8200P21PH4207moO`80OWin0P1oOgl207emO@80P8200P1mOGd207moO`80OWin0P27
QhL207inOPH0P8203038h=P000X0b>3HPP20P8060<SPf080OWin0P1kNg/208:2PP@0Ng]k0P23Ph<2
08B4Q080P8200P22PX8207]kN`80PX:20P24Q8@20861P@80QhN70P24Q8@2079bLP<0Lg=c0P2;Rh/2
08:2PP80Ng]k0P21PH4408:2PP80P8200P1oOgl208B4Q080P8200P1nOWh20820P080PH610P22PX82
07EeM@80RXZ:101mOGd207inOP80QHF50P1lO7`208B4Q080O7al0P1oOgl207MgM`80OGem0P29RHT2
07emO@80M7Ad0P2<S8`207AdM0D0P8200P1iNGT207alO080Ng]k0P1jNWX207QhN080Ph>30P1nOWh2
0820P080Ng]k0P21PH4408:2PP80OGem0P20P80<0<SPf0002P38h=R20820P0H0b>3H0P1nOWh207]k
N`80PX:2101kNg/208>3P`80Q8B40P20P80208:2PP80Ng]k0P22PX8208B4Q080PH610P27QhL208B4
Q080LW9b0`1cLg<208^;R`80PX:20P1kNg/20861P@@0PX:20P20P80207moO`80Q8B40P20P80207in
OP80P8200P21PH4208:2PP80MGEe0P2:RXX407emO@80OWin0P25QHD207alO080Q8B40P1lO7`207mo
O`80MgMg0P1mOGd208V9R@80OGem0P1dM7@208b<S080M7Ad1@20P80207UiN@80O7al0P1kNg/207Yj
NP80N7Qh0P23Ph<207inOP80P8200P1kNg/20861P@@0PX:20P1mOGd20820P0`0b>3H000:0<SPf880
P8201P38h=P207alO080RHV90P21PH4207inOP80Ogmo0P24Q8@20820P080Ph>30P25QHD207moO`80
PX:20P1gMgL207inOP80Ng]k0P27QhL20820P0<0Ng]k0P1mOGd20820P080NWYj0P22PX820861P@80
O7al0P1oOgl20820P080OWin0P20P80208>3P`80PX:20P21PH4207emO@80R8R80P1aLG4208b<S080
P8200P1oOgl207EeM@80Ph>30P1kNg/208:2PP80QhN70P21PH4208>3P`80O7al0P1kNg/407UiN@80
L71`0`1jNWX207MgM`80P8200P28R8P208:2PP80RXZ:0P2<S8`208J6QP@0Ogmo0P1mOGd20861P@80
PX:20P21PH420820P080OGem3038h=P000X0b>3HPP20P8060<SPf080O7al0P29RHT20861P@80OWin
0P1oOgl208B4Q080P8200P23Ph<208F5Q@80Ogmo0P22PX8207MgM`80OWin0P1kNg/208N7Q`80P820
0`1kNg/207emO@80P8200P1jNWX208:2PP80PH610P1lO7`207moO`80P8200P1nOWh20820P080Ph>3
0P22PX820861P@80OGem0P28R8P2075aL@80S8b<0P20P80207moO`80MGEe0P23Ph<207]kN`80PX:2
0P27QhL20861P@80Ph>30P1lO7`207]kN`@0NGUi0P1`L70307YjNP80MgMg0P20P80208R8R080PX:2
0P2:RXX208b<S080QXJ6101oOgl207emO@80PH610P22PX820861P@80P8200P1mOGd<0<SPf0002P38
h=R20820P0H0b>3H0P2>SXh207]kN`80QhN70P1lO7`207]kN`80Ph>30P22PX8207moO`80PH610P26
QXH407]kN`80Ph>30P2=SHd207inOP80Ph>30`1mOGd607moO`80OGem1023Ph<207moO`80PX:20P20
P80207moO`80OGem1P1oOgl207inOP80QXJ60P1aLG4208J6QP80OGem0P1lO7`207inOP80PH610P20
P80207YjNP80Ogmo0P1lO7`20820P080Q8B40P1mOGd207]kN`80OWin0`21PH4208B4Q080Ogmo0P1m
OGd207]kN`80OWin0P21PH420820P0@0O7al1P1oOgl207UiN@80OWin0P1oOgl<0<SPf0002P38h=R2
0820P0H0b>3H0P2>SXh207]kN`80QhN70P1lO7`207]kN`80Ph>30P22PX8207moO`80PH610P26QXH4
07]kN`80Ph>30P2=SHd207inOP80Ph>30`1mOGd607moO`80OGem1023Ph<207moO`80PX:20P20P802
07moO`80OGem1P1oOgl207inOP80QXJ60P1aLG4208J6QP80OGem0P1lO7`207inOP80PH610P20P802
07YjNP80Ogmo0P1lO7`20820P080Q8B40P1mOGd207]kN`80OWin0`21PH4208B4Q080Ogmo0P1mOGd2
07]kN`80OWin0P21PH420820P0@0O7al1P1oOgl207UiN@80OWin0P1oOgl<0<SPf0002P38h=R20820
P0H0b>3H0P1lO7`20861P@80NGUi0P20P80207emO@80Ng]k0P20P8020861P@80QXJ60P1lO7`2071`
L080Shn?0P1iNGT207emO@80Q8B41@22PX8207MgM`80Ng]k0P23Ph<207moO`80N7Qh0P1oOgl407em
O@80O7al101nOWh407moO`80Ph>31022PX8208N7Q`80L71`0P1gMgL207UiN@80Ph>30P1nOWh20861
P@80OWin0P24Q8@80820P080O7al0P1kNg/307moO`80LG5a0P1mOGd207moO`80Ph>30P21PH42071`
L080O7al0P23Ph<20861P@@0OWin0P1lO7`40861P@80Ogmo3038h=P000X0b>3HPP20P8060<SPf080
O7al0P21PH4207UiN@80P8200P1mOGd207]kN`80P8200P21PH4208J6QP80O7al0P1`L70208n?S`80
NGUi0P1mOGd208B4Q0D0PX:20P1gMgL207]kN`80Ph>30P1oOgl207QhN080Ogmo101mOGd207alO0@0
OWin101oOgl208>3P`@0PX:20P27QhL2071`L080MgMg0P1iNGT208>3P`80OWin0P21PH4207inOP80
Q8B42020P80207alO080Ng]k0`1oOgl2075aL@80OGem0P1oOgl208>3P`80PH610P1`L70207alO080
Ph>30P21PH4407inOP80O7al1021PH4207moO``0b>3H000:0<SPf880P8201P38h=P208N7Q`80Ph>3
0P1nOWh208B4Q080QXJ60P1oOgl207inOP80RHV90P1nOWh208b<S080RXZ:101iNGT208J6QP80PX:2
0P1lO7`307]kN`80Ogmo0P25QHD207UiN@80QXJ60P21PH420820P080Ph>30P1kNg/208B4Q080OGem
1020P80407emO@80Ogmo0P21PH420820P080QXJ60P29RHT2075aL@80OWin0P1lO7`208N7Q`80QHF5
0P1hN7P207inOP80OGem0P26QXH207moO`80Ph>30P2;Rh/308b<S080NWYj1025QHD207UiN@80NWYj
0P23Ph<20820P080PH610P20P80208:2PP@0Ogmo0P21PH4207emO@80PX:23038h=P000X0b>3HPP20
P8060<SPf080QhN70P23Ph<207inOP80Q8B40P26QXH207moO`80OWin0P29RHT207inOP80S8b<0P2:
RXX407UiN@80QXJ60P22PX8207alO0<0Ng]k0P1oOgl208F5Q@80NGUi0P26QXH20861P@80P8200P23
Ph<207]kN`80Q8B40P1mOGd40820P0@0OGem0P1oOgl20861P@80P8200P26QXH208V9R@80LG5a0P1n
OWh207alO080QhN70P25QHD207QhN080OWin0P1mOGd208J6QP80Ogmo0P23Ph<208^;R`<0S8b<0P1j
NWX408F5Q@80NGUi0P1jNWX208>3P`80P8200P21PH420820P080PX:2101oOgl20861P@80OGem0P22
PX8<0<SPf0002P38h=R20820P0H0b>3H0P25QHD207]kN`80QhN7101lO7`208:2PP80QhN70P1mOGd2
07]kN`80RHV90P1lO7`208B4Q080P8200P1lO7`207moO`80OWin0`23Ph<2079bLP80NGUi0P26QXH2
07inOP80Ng]k0P1mOGd208F5Q@80Ph>30P1lO7`40820P080NWYj0P21PH4207alO080P8200P1lO7`2
07moO`80O7al0P2;Rh/208n?S`80RXZ:0P20P80207moO`80Ph>30P2<S8`207emO@80NGUi0P1gMgL2
0820P080PH610P1hN7P308n?S`80O7al0P1gMgL207YjNP80Ogmo1021PH4207moO`@0OGem0P25QHD2
0820P080PH610P1lO7`208:2PP80OWin3038h=P000X0b>3HPP20P8060<SPf080QHF50P1kNg/208N7
Q`@0O7al0P22PX8208N7Q`80OGem0P1kNg/208V9R@80O7al0P24Q8@20820P080O7al0P1oOgl207in
OP<0Ph>30P1bLW8207UiN@80QXJ60P1nOWh207]kN`80OGem0P25QHD208>3P`80O7al1020P80207Yj
NP80PH610P1lO7`20820P080O7al0P1oOgl207alO080Rh^;0P2?Shl208Z:RP80P8200P1oOgl208>3
P`80S8b<0P1mOGd207UiN@80MgMg0P20P8020861P@80N7Qh0`2?Shl207alO080MgMg0P1jNWX207mo
O`@0PH610P1oOgl407emO@80QHF50P20P8020861P@80O7al0P22PX8207inOP`0b>3H000:0<SPf880
P8201P38h=P208F5Q@@0PX:20P24Q8@208>3P`80P8200P24Q8@207moO`80P8200P1kNg/208B4Q080
NGUi0P1oOgl207emO@80PX:20P2:RXX308J6QP@0RXZ:0P2=SHd207inOP80QHF50P24Q8@207moO`80
QhN70P1mOGd407moO`80Ph>30P21PH4207inOP80PX:2101mOGd20820P080OGem0P24Q8@207MgM`80
OGem0P22PX8207]kN`80P8200P22PX8207moO`80Q8B40P1hN7P207moO`80Ng]k0`22PX8207emO@80
Ogmo0P1lO7`408>3P`80PH610P1nOWh207emO@80N7Qh0P21PH420820P080Ogmo0P1nOWh207emO@80
Q8B43038h=P000X0b>3HPP20P8060<SPf080QHF51022PX8208B4Q080Ph>30P20P80208B4Q080Ogmo
0P20P80207]kN`80Q8B40P1iNGT207moO`80OGem0P22PX8208Z:RP<0QXJ6102:RXX208f=S@80OWin
0P25QHD208B4Q080Ogmo0P27QhL207emO@@0Ogmo0P23Ph<20861P@80OWin0P22PX8407emO@80P820
0P1mOGd208B4Q080MgMg0P1mOGd208:2PP80Ng]k0P20P80208:2PP80Ogmo0P24Q8@207QhN080Ogmo
0P1kNg/308:2PP80OGem0P1oOgl207alO0@0Ph>30P21PH4207inOP80OGem0P1hN7P20861P@80P820
0P1oOgl207inOP80OGem0P24Q8@<0<SPf0002P38h=R20820P0H0b>3H0P20P80207alO080Rh^;0P2?
Shl207YjNP80SXj>0P23Ph<207UiN@80QhN70P23Ph<407]kN`80P8200P1oOgl208F5Q@80L71`0`2?
Shl208R8R080Ng]k0P1fMWH408:2PP80QXJ60P1nOWh207emO@80Q8B40P1kNg/208:2PP80Ng]k0P1o
Ogl207emO@80OWin0P21PH4207alO080PH610P1nOWh207emO@@0Ogmo0P1bLW82071`L080OWin0P21
PH4207inOP80O7al0P28R8P207inOP80Ph>30`1lO7`207moO`80NGUi0P1kNg/207AdM0@0O7al0P24
Q8@208^;R`80QhN70P21PH4208>3P`80PH610P20P80208:2PP80P8203038h=P000X0b>3HPP20P806
0<SPf080P8200P1lO7`208^;R`80Shn?0P1jNWX208j>SP80Ph>30P1iNGT208N7Q`80Ph>3101kNg/2
0820P080Ogmo0P25QHD2071`L0<0Shn?0P28R8P207]kN`80MWIf1022PX8208J6QP80OWin0P1mOGd2
08B4Q080Ng]k0P22PX8207]kN`80Ogmo0P1mOGd207inOP80PH610P1lO7`20861P@80OWin0P1mOGd4
07moO`80LW9b0P1`L70207inOP80PH610P1nOWh207alO080R8R80P1nOWh208>3P`<0O7al0P1oOgl2
07UiN@80Ng]k0P1dM7@407alO080Q8B40P2;Rh/208N7Q`80PH610P23Ph<20861P@80P8200P22PX82
0820P0`0b>3H000:0<SPf880P8201P38h=P408:2PP80QXJ60P1eMGD207MgM`80OWin0P2=SHd207al
O080NGUi0P22PX8208>3P`80Q8B40P21PH4208>3P`@0Ogmo0`1eMGD407emO@80Ogmo0P1jNWX208B4
Q080Ng]k0P1hN7P207moO`@0PX:20P1lO7`208:2PP80OGem0P1nOWh20861P@80OGem1021PH4207mo
O`80O7al0P20P80207emO@80Ph>30P1`L70208^;R`80MgMg101mOGd407moO`80NGUi0`1mOGd207in
OP80P8200P28R8P208>3P`80R8R80P21PH4207alO080MWIf0P1kNg/20861P@80Ogmo0P1nOWh207em
O@80P8200P1lO7`<0<SPf0002P38h=R20820P0H0b>3H1022PX8208J6QP80MGEe0P1gMgL207inOP80
SHf=0P1lO7`207UiN@80PX:20P23Ph<208B4Q080PH610P23Ph<407moO`<0MGEe101mOGd207moO`80
NWYj0P24Q8@207]kN`80N7Qh0P1oOgl408:2PP80O7al0P22PX8207emO@80OWin0P21PH4207emO@@0
PH610P1oOgl207alO080P8200P1mOGd208>3P`80L71`0P2;Rh/207MgM`@0OGem101oOgl207UiN@<0
OGem0P1nOWh20820P080R8R80P23Ph<208R8R080PH610P1lO7`207IfMP80Ng]k0P21PH4207moO`80
OWin0P1mOGd20820P080O7al3038h=P000X0b>3HPP20P8060<SPf080Ogmo0P23Ph<207inOP80Q8B4
0P2=SHd207]kN`80MgMg0P1nOWh20861P@80O7al0P23Ph<208J6QP80PH610P25QHD207UiN@80RHV9
0`1bLW8208b<S080O7al1021PH4208B4Q080MgMg0P22PX8407inOP80Ogmo0P21PH4207QhN080Ph>3
0P21PH420820P080Ph>30P1nOWh208>3P`80Ogmo0P21PH4207emO@@0P8200P27QhL208j>SP80MWIf
0P1oOgl207UiN@80OWin0P1oOgl208N7Q`<0OGem0P26QXH20820P080NWYj0P1hN7P207=cL`80O7al
0P1jNWX208B4Q0@0OWin0P20P80208>3P`80Ogmo0P22PX8207inOP`0b>3H000:0<SPf880P8201P38
h=P207moO`80Ph>30P1nOWh208B4Q080SHf=0P1kNg/207MgM`80OWin0P21PH4207alO080Ph>30P26
QXH20861P@80QHF50P1iNGT208V9R@<0LW9b0P2<S8`207alO0@0PH610P24Q8@207MgM`80PX:2101n
OWh207moO`80PH610P1hN7P208>3P`80PH610P20P80208>3P`80OWin0P23Ph<207moO`80PH610P1m
OGd40820P080QhN70P2>SXh207IfMP80Ogmo0P1iNGT207inOP80Ogmo0P27QhL307emO@80QXJ60P20
P80207YjNP80N7Qh0P1cLg<207alO080NWYj0P24Q8@407inOP80P8200P23Ph<207moO`80PX:20P1n
OWh<0<SPf0002P38h=R20820P0H0b>3H0P1oOgl208>3P`80OWin0P24Q8@208f=S@80Ng]k0P1gMgL2
07inOP80PH610P1lO7`208>3P`80QXJ60P21PH4208F5Q@80NGUi0P29RHT3079bLP80S8b<0P1lO7`4
0861P@80Q8B40P1gMgL208:2PP@0OWin0P1oOgl20861P@80N7Qh0P23Ph<20861P@80P8200P23Ph<2
07inOP80Ph>30P1oOgl20861P@80OGem1020P80208N7Q`80SXj>0P1fMWH207moO`80NGUi0P1nOWh2
07moO`80QhN70`1mOGd208J6QP80P8200P1jNWX207QhN080Lg=c0P1lO7`207YjNP80Q8B4101nOWh2
0820P080Ph>30P1oOgl208:2PP80OWin3038h=P000X0b>3HPP20P8060<SPf080PX:20P1nOWh207]k
N`80P8200P2:RXX408>3P`80NGUi0P1mOGd40820P0@0PH610P24Q8@208Z:RP80OWin0`20P80207Yj
NP80PX:20P1nOWh207]kN`80OGem0P2:RXX20861P@80Q8B40P1jNWX208>3P`80Ogmo0P21PH4407mo
O`80QHF50P1nOWh208>3P`80OWin0P20P80408:2PP80OGem0P22PX820820P080QHF50P1gMgL207mo
O`80OWin0P1gMgL208>3P`80Ng]k0`20P80207alO080N7Qh1020P80207moO`80PX:20P21PH420820
P080OWin0P20P80207alO080P8200P1lO7`208:2PP80O7al3038h=P000X0b>3HPP20P8060<SPf080
PX:20P1nOWh207]kN`80P8200P2:RXX408>3P`80NGUi0P1mOGd40820P0@0PH610P24Q8@208Z:RP80
OWin0`20P80207YjNP80PX:20P1nOWh207]kN`80OGem0P2:RXX20861P@80Q8B40P1jNWX208>3P`80
Ogmo0P21PH4407moO`80QHF50P1nOWh208>3P`80OWin0P20P80408:2PP80OGem0P22PX820820P080
QHF50P1gMgL207moO`80OWin0P1gMgL208>3P`80Ng]k0`20P80207alO080N7Qh1020P80207moO`80
PX:20P21PH420820P080OWin0P20P80207alO080P8200P1lO7`208:2PP80O7al3038h=P000X0b>3H
PP20P8060<SPf080OGem0P1kNg/208>3P`80RXZ:0P2>SXh207AdM080QXJ60P23Ph<20861P@@0P820
0P25QHD20820P080PX:20P1iNGT207inOP<0PH610P24Q8@208R8R0@0OWin0P1`L70208B4Q080N7Qh
0P1jNWX208:2PP80N7Qh1024Q8@207]kN`80PH610P1lO7`407inOP80P8201P1oOgl20861P@80Ogmo
0P21PH4208F5Q@80PH610P25QHD208V9R@@0QXJ61@1oOgl208:2PP80Ph>30P1jNWX207emO@80P820
0P24Q8@207emO@80Ogmo0P21PH4207moO`80PX:20P1oOgl20861P@80Ogmo0P1mOGd<0<SPf0002P38
h=R20820P0H0b>3H0P1mOGd207]kN`80Ph>30P2:RXX208j>SP80M7Ad0P26QXH208>3P`80PH611020
P80208F5Q@80P8200P22PX8207UiN@80OWin0`21PH4208B4Q080R8R8101nOWh2071`L080Q8B40P1h
N7P207YjNP80PX:20P1hN7P408B4Q080Ng]k0P21PH4207alO0@0OWin0P20P80607moO`80PH610P1o
Ogl20861P@80QHF50P21PH4208F5Q@80RHV91026QXH507moO`80PX:20P23Ph<207YjNP80OGem0P20
P80208B4Q080OGem0P1oOgl20861P@80Ogmo0P22PX8207moO`80PH610P1oOgl207emO@`0b>3H000:
0<SPf880P8201P38h=P208F5Q@80NGUi0P1mOGd207moO`80N7Qh0P22PX82079bLP80Q8B40P1dM7@4
0820P080QHF50P1kNg/208:2PP80NWYj0P26QXH307inOP80OGem0P1lO7`20820P080PX:20P1eMGD2
08b<S080Ph>30P1gMgL208J6QP80OGem0P1eMGD208:2PP80R8R80P1gMgL208R8R080O7al0P23Ph<2
07]kN`80P820101nOWh20820P080OWin0P1oOgl207emO@80Q8B40P1nOWh208R8R080MgMg0P1eMGD2
0861P@<0NWYj0P21PH4407moO`80P8200P1oOgl20861P@80P8200P21PH4407moO`80Ph>30P1oOgl2
08:2PP80OWin0P20P80<0<SPf0002P38h=R20820P0H0b>3H0P25QHD207UiN@80OGem0P1oOgl207Qh
N080PX:20P1bLW8208B4Q080M7Ad1020P80208F5Q@80Ng]k0P22PX8207YjNP80QXJ60`1nOWh207em
O@80O7al0P20P80208:2PP80MGEe0P2<S8`208>3P`80MgMg0P26QXH207emO@80MGEe0P22PX8208R8
R080MgMg0P28R8P207alO080Ph>30P1kNg/20820P0@0OWin0P20P80207inOP80Ogmo0P1mOGd208B4
Q080OWin0P28R8P207MgM`80MGEe0P21PH4307YjNP80PH61101oOgl20820P080Ogmo0P21PH420820
P080PH61101oOgl208>3P`80Ogmo0P22PX8207inOP80P8203038h=P000X0b>3HPP20P8060<SPf080
NWYj0P22PX820861P@80N7Qh0P21PH4207alO080L71`0P27QhL208V9R@80Ng]k0P25QHD208>3P`@0
P8200P1oOgl207]kN`<0PX:20P1mOGd207UiN@80MGEe0P1kNg/208F5Q@80N7Qh0P1nOWh208>3P`80
PX:20P20P80208b<S080QHF50P27QhL208:2PP80OGem0P25QHD207moO`80PH610P1mOGd208>3P`@0
PH610P1oOgl408:2PP80Q8B40P1nOWh207]kN`80Q8B40P23Ph<207moO`<0Ph>30P24Q8@207]kN`80
PX:20P1mOGd208>3P`80O7al1020P80208:2PP@0P8200P1oOgl20820P0@0Ogmo3038h=P000X0b>3H
PP20P8060<SPf080NWYj0P22PX820861P@80N7Qh0P21PH4207alO080L71`0P27QhL208V9R@80Ng]k
0P25QHD208>3P`@0P8200P1oOgl207]kN`<0PX:20P1mOGd207UiN@80MGEe0P1kNg/208F5Q@80N7Qh
0P1nOWh208>3P`80PX:20P20P80208b<S080QHF50P27QhL208:2PP80OGem0P25QHD207moO`80PH61
0P1mOGd208>3P`@0PH610P1oOgl408:2PP80Q8B40P1nOWh207]kN`80Q8B40P23Ph<207moO`<0Ph>3
0P24Q8@207]kN`80PX:20P1mOGd208>3P`80O7al1020P80208:2PP@0P8200P1oOgl20820P0@0Ogmo
3038h=P000X0b>3HPP20P8060<SPf080S8b<0P1`L70207MgM`80OWin0P1mOGd208B4Q080LG5a0P2:
RXX207QhN080PH610P24Q8@208N7Q`@0OWin0P24Q8@507moO`80OWin0P23Ph<208F5Q@80NWYj0P1k
Ng/208F5Q@80PX:20P1lO7`40861P@80NGUi0P1dM7@20861P@80P8200P26QXH207emO@80P8200P1o
Ogl408:2PP@0OWin0P20P80208:2PP80O7al0P1jNWX207]kN`80Ph>30P1lO7`40820P0<0PH610P1j
NWX208>3P`80P8200P1nOWh207moO`80P8200P1nOWh20820P080OGem1021PH4208:2PP80PH611020
P80<0<SPf0002P38h=R20820P0H0b>3H0P2<S8`2071`L080MgMg0P1nOWh207emO@80Q8B40P1aLG42
08Z:RP80N7Qh0P21PH4208B4Q080QhN7101nOWh208B4Q0D0Ogmo0P1nOWh208>3P`80QHF50P1jNWX2
07]kN`80QHF50P22PX8207alO0@0PH610P1iNGT207AdM080PH610P20P80208J6QP80OGem0P20P802
07moO`@0PX:2101nOWh20820P080PX:20P1lO7`207YjNP80Ng]k0P23Ph<207alO0@0P8200`21PH42
07YjNP80Ph>30P20P80207inOP80Ogmo0P20P80207inOP80P8200P1mOGd40861P@80PX:20P21PH44
0820P0`0b>3H000:0<SPf880P8201P38h=P207moO`80PX:20P1oOgl20820P080QXJ60P1hN7P208B4
Q080Ng]k0P25QHD208J6QP80PX:20P1eMGD208B4Q080OWin0P1oOgl207inOP<0O7al0P1oOgl207]k
N`80P8200P27QhL207moO`80Ph>30P1oOgl20820P080OWin0P1oOgl208:2PP80P8200P1nOWh208F5
Q@@0Ogmo0P20P80807moO`80PX:20P1oOgl40820P0@0Ogmo0P22PX8207moO`@0P8200`21PH4208:2
PP80MWIf0P21PH4207moO`80P8200P22PX8407moO`80OGem0P20P80207inOP80P8200P23Ph<208:2
PP80PH613038h=P000X0b>3HPP20P8060<SPf080Ogmo0P22PX8207moO`80P8200P26QXH207QhN080
Q8B40P1kNg/208F5Q@80QXJ60P22PX8207EeM@80Q8B40P1nOWh207moO`80OWin0`1lO7`207moO`80
Ng]k0P20P80208N7Q`80Ogmo0P23Ph<207moO`80P8200P1nOWh207moO`80PX:20P20P80207inOP80
QHF5101oOgl20820P0P0Ogmo0P22PX8207moO`@0P820101oOgl208:2PP80Ogmo1020P8030861P@80
PX:20P1fMWH20861P@80Ogmo0P20P80208:2PP@0Ogmo0P1mOGd20820P080OWin0P20P80208>3P`80
PX:20P21PH4<0<SPf0002P38h=R20820P0H0b>3H0P1jNWX207alO080Ogmo0P23Ph<207moO`80OGem
1020P802071`L080PH610P1nOWh208>3P`80Ng]k0P1jNWX208>3P`80PX:20`1nOWh207emO@80OWin
0P1lO7`207]kN`80PH610P1gMgL208V9R@80QhN70P2<S8`207emO@80Q8B40P21PH4208>3P`80NWYj
0P27QhL208>3P`80P8200P1mOGd208>3P`@0P820101mOGd207inOP80P8200P23Ph<208:2PP80Ogmo
1020P80207inOP<0P8200P1nOWh208>3P`80NGUi0P23Ph<407moO`80PH610P20P80207moO`80P820
0P21PH4208:2PP80PH610P1lO7`207moO``0b>3H000:0<SPf880P8201P38h=P207YjNP80O7al0P1o
Ogl208>3P`80Ogmo0P1mOGd40820P080L71`0P21PH4207inOP80Ph>30P1kNg/207YjNP80Ph>30P22
PX8307inOP80OGem0P1nOWh207alO080Ng]k0P21PH4207MgM`80RHV90P27QhL208b<S080OGem0P24
Q8@20861P@80Ph>30P1jNWX208N7Q`80Ph>30P20P80207emO@80Ph>31020P80407emO@80OWin0P20
P80208>3P`80PX:20P1oOgl40820P080OWin0`20P80207inOP80Ph>30P1iNGT208>3P`@0Ogmo0P21
PH420820P080Ogmo0P20P8020861P@80PX:20P21PH4207alO080Ogmo3038h=P000X0b>3HPP20P806
0<SPf080Ogmo0P1nOWh20820P080O7al1020P80208V9R@80O7al0P26QXH20820P080NGUi0P21PH42
07moO`80OWin101mOGd30861P@80Ogmo0P28R8P207emO@80MgMg0P1oOgl208V9R@80Lg=c0P28R8P2
08J6QP80Ph>30P26QXH207emO@80PX:20P21PH4407inOP80PH610P1mOGd208:2PP80P8200P22PX82
0861P@80Ng]k0P22PX8207moO`H0PH610P23Ph<20820P080Ogmo0`21PH4407moO`80Ph>30P21PH42
08>3P`80Ogmo0P1nOWh208:2PP80PH610P1nOWh208B4Q080O7al0P1oOgl20861P@80PX:23038h=P0
00X0b>3HPP20P8060<SPf080Ogmo0P1nOWh20820P080O7al1020P80208V9R@80O7al0P26QXH20820
P080NGUi0P21PH4207moO`80OWin101mOGd30861P@80Ogmo0P28R8P207emO@80MgMg0P1oOgl208V9
R@80Lg=c0P28R8P208J6QP80Ph>30P26QXH207emO@80PX:20P21PH4407inOP80PH610P1mOGd208:2
PP80P8200P22PX820861P@80Ng]k0P22PX8207moO`H0PH610P23Ph<20820P080Ogmo0`21PH4407mo
O`80Ph>30P21PH4208>3P`80Ogmo0P1nOWh208:2PP80PH610P1nOWh208B4Q080O7al0P1oOgl20861
P@80PX:23038h=P000X0b>3HPP20P8060<SPf080N7Qh0P22PX8207emO@80O7al0P25QHD207moO`@0
P8200P1fMWH20861P@80N7Qh0P20P80208F5Q@80Q8B40P22PX8208>3P`<0OGem0P1lO7`207inOP@0
QhN70P1gMgL207]kN`80QXJ60P2<S8`408V9R@80R8R80P22PX8207inOP80QXJ60P1kNg/208:2PP80
OWin0P27QhL207YjNP80QHF50P1mOGd207inOP80P8200P24Q8@207moO`@0PH610P25QHD207]kN`80
OGem0P25QHD307inOP80Ogmo0P23Ph<20861P@80OWin0P22PX8208>3P`80PH610P1kNg/20820P080
PH610P22PX8407emO@80Ogmo0P1nOWh<0<SPf0002P38h=R20820P0H0b>3H0P1hN7P208:2PP80OGem
0P1lO7`208F5Q@80Ogmo1020P80207IfMP80PH610P1hN7P20820P080QHF50P24Q8@208:2PP80Ph>3
0`1mOGd207alO080OWin1027QhL207MgM`80Ng]k0P26QXH208b<S0@0RHV90P28R8P208:2PP80OWin
0P26QXH207]kN`80PX:20P1nOWh208N7Q`80NWYj0P25QHD207emO@80OWin0P20P80208B4Q080Ogmo
1021PH4208F5Q@80Ng]k0P1mOGd208F5Q@<0OWin0P1oOgl208>3P`80PH610P1nOWh208:2PP80Ph>3
0P21PH4207]kN`80P8200P21PH4208:2PP@0OGem0P1oOgl207inOP`0b>3H000:0<SPf880P8201P38
h=P208F5Q@80SXj>0P22PX8207moO`80OWin0P1jNWX207emO@80Ph>30P25QHD20820P080Q8B40P1n
OWh207YjNP80OGem0P1kNg/208:2PP<0PH610P1oOgl208:2PP@0Ogmo0P1eMGD208>3P`80OGem0P1n
OWh407emO@80P8200P22PX8207emO@80N7Qh0P2=SHd207]kN`80P8200P1nOWh20820P080MGEe0P26
QXH60820P080Ng]k101oOgl207alO080OWin0P22PX8207inOP<0OGem101oOgl207inOP80PH610P1n
OWh207emO@80OWin0P23Ph<207alO080OWin0P21PH420820P080PH610P1nOWh20820P0`0b>3H000:
0<SPf880P8201P38h=P208F5Q@80SXj>0P22PX8207moO`80OWin0P1jNWX207emO@80Ph>30P25QHD2
0820P080Q8B40P1nOWh207YjNP80OGem0P1kNg/208:2PP<0PH610P1oOgl208:2PP@0Ogmo0P1eMGD2
08>3P`80OGem0P1nOWh407emO@80P8200P22PX8207emO@80N7Qh0P2=SHd207]kN`80P8200P1nOWh2
0820P080MGEe0P26QXH60820P080Ng]k101oOgl207alO080OWin0P22PX8207inOP<0OGem101oOgl2
07inOP80PH610P1nOWh207emO@80OWin0P23Ph<207alO080OWin0P21PH420820P080PH610P1nOWh2
0820P0`0b>3H000:0<SPf880P8201P38h=P408Z:RP80MgMg0P20P8020861P@80Ph>3101oOgl208>3
P`80O7al0P21PH4207inOP80P8200P1oOgl208B4Q080Ph>30`1nOWh208>3P`80PH610P22PX820861
P@80PX:20P1iNGT208:2PP80Ph>30P1oOgl407emO@80PH610P1nOWh20820P080Ng]k0P2;Rh/207If
MP80Q8B40P1oOgl20861P@80N7Qh0P21PH4207moO`80PH610P23Ph<20820P080O7al0P25QHD208J6
QP80OWin0P23Ph<308:2PP80P8200P1kNg/20820P080Ogmo0P21PH4208:2PP80OGem0P1kNg/208f=
S@80OWin0P22PX8208>3P`80P8200P21PH4207moO``0b>3H000:0<SPf880P8201P38h=P408Z:RP80
MgMg0P20P8020861P@80Ph>3101oOgl208>3P`80O7al0P21PH4207inOP80P8200P1oOgl208B4Q080
Ph>30`1nOWh208>3P`80PH610P22PX820861P@80PX:20P1iNGT208:2PP80Ph>30P1oOgl407emO@80
PH610P1nOWh20820P080Ng]k0P2;Rh/207IfMP80Q8B40P1oOgl20861P@80N7Qh0P21PH4207moO`80
PH610P23Ph<20820P080O7al0P25QHD208J6QP80OWin0P23Ph<308:2PP80P8200P1kNg/20820P080
Ogmo0P21PH4208:2PP80OGem0P1kNg/208f=S@80OWin0P22PX8208>3P`80P8200P21PH4207moO``0
b>3H000:0<SPf880P8201P38h=P208N7Q`80QXJ60P20P80207MgM`80OWin0P1mOGd207]kN`80PX:2
0P1nOWh207moO`80OGem0P1nOWh207]kN`80PX:20P20P80207inOP<0NWYj0P20P80207moO`80QHF5
0P1mOGd207alO080PX:20P1eMGD207YjNP80NGUi0P23Ph<208R8R080Shn?0P26QXH207]kN`80PX:2
0P1oOgl208>3P`80N7Qh0P21PH4208F5Q@80Ogmo0P1gMgL208>3P`80OWin0P1mOGd20820P080Q8B4
0P1hN7P207moO`80OWin0P20P80307alO0@0P8200P26QXH20820P080Ogmo101mOGd208>3P`80MWIf
0P25QHD20820P0@0OWin0P1mOGd207moO``0b>3H000:0<SPf880P8201P38h=P208N7Q`80QXJ60P20
P80207MgM`80OWin0P1mOGd207]kN`80PX:20P1nOWh207moO`80OGem0P1nOWh207]kN`80PX:20P20
P80207inOP<0NWYj0P20P80207moO`80QHF50P1mOGd207alO080PX:20P1eMGD207YjNP80NGUi0P23
Ph<208R8R080Shn?0P26QXH207]kN`80PX:20P1oOgl208>3P`80N7Qh0P21PH4208F5Q@80Ogmo0P1g
MgL208>3P`80OWin0P1mOGd20820P080Q8B40P1hN7P207moO`80OWin0P20P80307alO0@0P8200P26
QXH20820P080Ogmo101mOGd208>3P`80MWIf0P25QHD20820P0@0OWin0P1mOGd207moO``0b>3H000:
0<SPf880P8201P38h=P20820P080Rh^;0P1lO7`208B4Q080Ph>30P1iNGT208J6QP80PH610P1iNGT2
08V9R@80Ph>30P21PH420820P080N7Qh0P1oOgl207emO@<0Q8B40P1iNGT207YjNP80QHF50P1oOgl2
08F5Q@80Ph>30P21PH4207moO`80P8200P1mOGd2071`L080Ogmo0P1bLW8208>3P`80OGem0P20P802
07emO@80QhN70P1dM7@208:2PP80P8200P23Ph<207EeM@80S8b<0P1nOWh208V9R@80O7al0P23Ph<2
0861P@80Ogmo0P1mOGd30861P@80Ogmo0P25QHD208>3P`80P8200P22PX840861P@80Ph>3101oOgl2
07emO@80Ph>30P1nOWh20820P080PH613038h=P000X0b>3HPP20P8060<SPf080P8200P2;Rh/207al
O080Q8B40P23Ph<207UiN@80QXJ60P21PH4207UiN@80RHV90P23Ph<20861P@80P8200P1hN7P207mo
O`80OGem0`24Q8@207UiN@80NWYj0P25QHD207moO`80QHF50P23Ph<20861P@80Ogmo0P20P80207em
O@80L71`0P1oOgl2079bLP80Ph>30P1mOGd20820P080OGem0P27QhL207AdM080PX:20P20P80208>3
P`80MGEe0P2<S8`207inOP80RHV90P1lO7`208>3P`80PH610P1oOgl207emO@<0PH610P1oOgl208F5
Q@80Ph>30P20P80208:2PP@0PH610P23Ph<407moO`80OGem0P23Ph<207inOP80P8200P21PH4<0<SP
f0002P38h=R20820P0H0b>3H0P22PX8208j>SP80PH610P1iNGT40820P080QHF50P1nOWh208:2PP80
P8200P1kNg/208J6QP80Q8B40P1oOgl207UiN@80QhN70`1jNWX207]kN`80Q8B40P22PX820861P@80
O7al0P1mOGd207YjNP80OWin0P1aLG4208>3P`@0Lg=c0P1nOWh20861P@@0PX:20P1kNg/208:2PP80
Q8B4101kNg/207YjNP80Q8B40P1dM7@208>3P`@0NGUi0P21PH4207inOP80Ph>30P20P80307moO`80
P820101mOGd20861P@80QHF50P20P80207moO`80OWin0P1oOgl208:2PP80Ogmo0P22PX820861P@80
NWYj0P1kNg/<0<SPf0002P38h=R20820P0H0b>3H0P22PX8208j>SP80PH610P1iNGT40820P080QHF5
0P1nOWh208:2PP80P8200P1kNg/208J6QP80Q8B40P1oOgl207UiN@80QhN70`1jNWX207]kN`80Q8B4
0P22PX820861P@80O7al0P1mOGd207YjNP80OWin0P1aLG4208>3P`@0Lg=c0P1nOWh20861P@@0PX:2
0P1kNg/208:2PP80Q8B4101kNg/207YjNP80Q8B40P1dM7@208>3P`@0NGUi0P21PH4207inOP80Ph>3
0P20P80307moO`80P820101mOGd20861P@80QHF50P20P80207moO`80OWin0P1oOgl208:2PP80Ogmo
0P22PX820861P@80NWYj0P1kNg/<0<SPf0002P38h=R20820P0H0b>3H0P26QXH207YjNP80Ph>30P26
QXH208Z:RP80Ogmo0P1fMWH207alO080OWin0P23Ph<20820P080PH610P27QhL207moO`80SHf=0P1j
NWX507]kN`80PH610P1oOgl408B4Q080Ph>30P1nOWh207QhN080PX:20P1nOWh207alO080N7Qh0P20
P80208N7Q`80Q8B40P1oOgl207inOP80PH610P28R8P20820P0@0PH610P20P80208J6QP80MWIf0P22
PX8208>3P`@0Ogmo1`20P80207moO`@0PX:20P20P8020861P@80OGem0P1oOgl408B4Q080Ogmo1020
P8020861P@80P8200P24Q8@<0<SPf0002P38h=R20820P0H0b>3H0P26QXH207YjNP80Ph>30P26QXH2
08Z:RP80Ogmo0P1fMWH207alO080OWin0P23Ph<20820P080PH610P27QhL207moO`80SHf=0P1jNWX5
07]kN`80PH610P1oOgl408B4Q080Ph>30P1nOWh207QhN080PX:20P1nOWh207alO080N7Qh0P20P802
08N7Q`80Q8B40P1oOgl207inOP80PH610P28R8P20820P0@0PH610P20P80208J6QP80MWIf0P22PX82
08>3P`@0Ogmo1`20P80207moO`@0PX:20P20P8020861P@80OGem0P1oOgl408B4Q080Ogmo1020P802
0861P@80P8200P24Q8@<0<SPf0002P38h=R20820P0H0b>3H0P1aLG4207alO080L71`0P1fMWH208j>
SP80N7Qh0P2>SXh207UiN@80M7Ad0P1hN7P208>3P`80NWYj0P1eMGD208N7Q`80QXJ60P27QhL308J6
QP80QhN70P1lO7`20820P080OWin0P21PH4207=cL`80QHF50P2;Rh/207emO@80PX:2101oOgl208J6
QP80OGem0P1hN7P207alO080PH610P1jNWX20820P080RHV90P1hN7P207alO080SXj>0P1mOGd2071`
L080QHF50P1oOgl408V9R@80PH611@24Q8@208J6QP80P8200P1oOgl208B4Q080N7Qh0P1oOgl207in
OP80Ogmo0P1nOWh208>3P`80OGem0P22PX8207UiN@80O7al0P1hN7P<0<SPf0002P38h=R20820P0H0
b>3H0P1aLG4207alO080L71`0P1fMWH208j>SP80N7Qh0P2>SXh207UiN@80M7Ad0P1hN7P208>3P`80
NWYj0P1eMGD208N7Q`80QXJ60P27QhL308J6QP80QhN70P1lO7`20820P080OWin0P21PH4207=cL`80
QHF50P2;Rh/207emO@80PX:2101oOgl208J6QP80OGem0P1hN7P207alO080PH610P1jNWX20820P080
RHV90P1hN7P207alO080SXj>0P1mOGd2071`L080QHF50P1oOgl408V9R@80PH611@24Q8@208J6QP80
P8200P1oOgl208B4Q080N7Qh0P1oOgl207inOP80Ogmo0P1nOWh208>3P`80OGem0P22PX8207UiN@80
O7al0P1hN7P<0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SP
f000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SP
f000o`38h=PQ0<SPf000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500105, -0.0500105, \
0.00731715, 0.00731715}, {{6.8125, 143.5}, {280.125, 143.5}} -> {-4.9665, \
-4.98187, 0.491861, 0.491861}, {{143.5, 280.125}, {280.125, 143.5}} -> \
{-72.1823, -4.98187, 0.491861, 0.491861}, {{6.8125, 143.5}, {143.5, 6.8125}} -> \
{-4.9496, -72.1501, 0.491636, 0.491636}, {{143.5, 280.125}, {143.5, 6.8125}} -> \
{-72.1823, -72.1977, 0.491861, 0.491861}}]
}, Open  ]],

Cell["Let us now examine the frequency distributions of error:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DisplayTogetherArray[{{Histogram[Flatten[\(mcomp[\([1]\)]\)[\([1]\)]]], 
          Histogram[Flatten[\(mcomp[\([1]\)]\)[\([2]\)]]]}, {Histogram[
            Flatten[\(mcomp[\([2]\)]\)[\([1]\)]]], 
          Histogram[Flatten[\(mcomp[\([2]\)]\)[\([2]\)]]]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.03125 0.0147151 0.0028435 [
[.03125 .00222 -12 -9 ]
[.03125 .00222 12 0 ]
[.1875 .00222 -12 -9 ]
[.1875 .00222 12 0 ]
[.34375 .00222 -9 -9 ]
[.34375 .00222 9 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65625 .00222 -6 -9 ]
[.65625 .00222 6 0 ]
[.8125 .00222 -9 -9 ]
[.8125 .00222 9 0 ]
[.96875 .00222 -9 -9 ]
[.96875 .00222 9 0 ]
[-0.0125 .15689 -12 -4.5 ]
[-0.0125 .15689 0 4.5 ]
[-0.0125 .29906 -18 -4.5 ]
[-0.0125 .29906 0 4.5 ]
[-0.0125 .44124 -18 -4.5 ]
[-0.0125 .44124 0 4.5 ]
[-0.0125 .58341 -18 -4.5 ]
[-0.0125 .58341 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03125 .01472 m
.03125 .02097 L
s
[(-15.)] .03125 .00222 0 1 Mshowa
.1875 .01472 m
.1875 .02097 L
s
[(-10.)] .1875 .00222 0 1 Mshowa
.34375 .01472 m
.34375 .02097 L
s
[(-5.)] .34375 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.)] .5 .00222 0 1 Mshowa
.65625 .01472 m
.65625 .02097 L
s
[(5.)] .65625 .00222 0 1 Mshowa
.8125 .01472 m
.8125 .02097 L
s
[(10.)] .8125 .00222 0 1 Mshowa
.96875 .01472 m
.96875 .02097 L
s
[(15.)] .96875 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .15689 m
.00625 .15689 L
s
[(50)] -0.0125 .15689 1 0 Mshowa
0 .29906 m
.00625 .29906 L
s
[(100)] -0.0125 .29906 1 0 Mshowa
0 .44124 m
.00625 .44124 L
s
[(150)] -0.0125 .44124 1 0 Mshowa
0 .58341 m
.00625 .58341 L
s
[(200)] -0.0125 .58341 1 0 Mshowa
.125 Mabswid
0 .04315 m
.00375 .04315 L
s
0 .07159 m
.00375 .07159 L
s
0 .10002 m
.00375 .10002 L
s
0 .12845 m
.00375 .12845 L
s
0 .18532 m
.00375 .18532 L
s
0 .21376 m
.00375 .21376 L
s
0 .24219 m
.00375 .24219 L
s
0 .27063 m
.00375 .27063 L
s
0 .3275 m
.00375 .3275 L
s
0 .35593 m
.00375 .35593 L
s
0 .38437 m
.00375 .38437 L
s
0 .4128 m
.00375 .4128 L
s
0 .46967 m
.00375 .46967 L
s
0 .49811 m
.00375 .49811 L
s
0 .52654 m
.00375 .52654 L
s
0 .55498 m
.00375 .55498 L
s
0 .61185 m
.00375 .61185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .06305 L
.01563 .06305 L
.01563 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .06305 L
.01563 .06305 L
.01563 .01472 L
0 .01472 L
s
1 0 0 r
.01563 .01472 m
.01563 .06305 L
.03125 .06305 L
.03125 .01472 L
F
0 g
.01563 .01472 m
.01563 .06305 L
.03125 .06305 L
.03125 .01472 L
.01563 .01472 L
s
1 0 0 r
.03125 .01472 m
.03125 .05737 L
.04688 .05737 L
.04688 .01472 L
F
0 g
.03125 .01472 m
.03125 .05737 L
.04688 .05737 L
.04688 .01472 L
.03125 .01472 L
s
1 0 0 r
.04688 .01472 m
.04688 .06021 L
.0625 .06021 L
.0625 .01472 L
F
0 g
.04688 .01472 m
.04688 .06021 L
.0625 .06021 L
.0625 .01472 L
.04688 .01472 L
s
1 0 0 r
.0625 .01472 m
.0625 .06305 L
.07813 .06305 L
.07813 .01472 L
F
0 g
.0625 .01472 m
.0625 .06305 L
.07813 .06305 L
.07813 .01472 L
.0625 .01472 L
s
1 0 0 r
.07813 .01472 m
.07813 .06021 L
.09375 .06021 L
.09375 .01472 L
F
0 g
.07813 .01472 m
.07813 .06021 L
.09375 .06021 L
.09375 .01472 L
.07813 .01472 L
s
1 0 0 r
.09375 .01472 m
.09375 .09149 L
.10938 .09149 L
.10938 .01472 L
F
0 g
.09375 .01472 m
.09375 .09149 L
.10938 .09149 L
.10938 .01472 L
.09375 .01472 L
s
1 0 0 r
.10938 .01472 m
.10938 .06874 L
.125 .06874 L
.125 .01472 L
F
0 g
.10938 .01472 m
.10938 .06874 L
.125 .06874 L
.125 .01472 L
.10938 .01472 L
s
1 0 0 r
.125 .01472 m
.125 .05452 L
.14063 .05452 L
.14063 .01472 L
F
0 g
.125 .01472 m
.125 .05452 L
.14063 .05452 L
.14063 .01472 L
.125 .01472 L
s
1 0 0 r
.14063 .01472 m
.14063 .07159 L
.15625 .07159 L
.15625 .01472 L
F
0 g
.14063 .01472 m
.14063 .07159 L
.15625 .07159 L
.15625 .01472 L
.14063 .01472 L
s
1 0 0 r
.15625 .01472 m
.15625 .07159 L
.17188 .07159 L
.17188 .01472 L
F
0 g
.15625 .01472 m
.15625 .07159 L
.17188 .07159 L
.17188 .01472 L
.15625 .01472 L
s
1 0 0 r
.17188 .01472 m
.17188 .10286 L
.1875 .10286 L
.1875 .01472 L
F
0 g
.17188 .01472 m
.17188 .10286 L
.1875 .10286 L
.1875 .01472 L
.17188 .01472 L
s
1 0 0 r
.1875 .01472 m
.1875 .09149 L
.20313 .09149 L
.20313 .01472 L
F
0 g
.1875 .01472 m
.1875 .09149 L
.20313 .09149 L
.20313 .01472 L
.1875 .01472 L
s
1 0 0 r
.20313 .01472 m
.20313 .11992 L
.21875 .11992 L
.21875 .01472 L
F
0 g
.20313 .01472 m
.20313 .11992 L
.21875 .11992 L
.21875 .01472 L
.20313 .01472 L
s
1 0 0 r
.21875 .01472 m
.21875 .09433 L
.23438 .09433 L
.23438 .01472 L
F
0 g
.21875 .01472 m
.21875 .09433 L
.23438 .09433 L
.23438 .01472 L
.21875 .01472 L
s
1 0 0 r
.23438 .01472 m
.23438 .10286 L
.25 .10286 L
.25 .01472 L
F
0 g
.23438 .01472 m
.23438 .10286 L
.25 .10286 L
.25 .01472 L
.23438 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .12277 L
.26563 .12277 L
.26563 .01472 L
F
0 g
.25 .01472 m
.25 .12277 L
.26563 .12277 L
.26563 .01472 L
.25 .01472 L
s
1 0 0 r
.26563 .01472 m
.26563 .1313 L
.28125 .1313 L
.28125 .01472 L
F
0 g
.26563 .01472 m
.26563 .1313 L
.28125 .1313 L
.28125 .01472 L
.26563 .01472 L
s
1 0 0 r
.28125 .01472 m
.28125 .17395 L
.29688 .17395 L
.29688 .01472 L
F
0 g
.28125 .01472 m
.28125 .17395 L
.29688 .17395 L
.29688 .01472 L
.28125 .01472 L
s
1 0 0 r
.29688 .01472 m
.29688 .19101 L
.3125 .19101 L
.3125 .01472 L
F
0 g
.29688 .01472 m
.29688 .19101 L
.3125 .19101 L
.3125 .01472 L
.29688 .01472 L
s
1 0 0 r
.3125 .01472 m
.3125 .1313 L
.32813 .1313 L
.32813 .01472 L
F
0 g
.3125 .01472 m
.3125 .1313 L
.32813 .1313 L
.32813 .01472 L
.3125 .01472 L
s
1 0 0 r
.32813 .01472 m
.32813 .23366 L
.34375 .23366 L
.34375 .01472 L
F
0 g
.32813 .01472 m
.32813 .23366 L
.34375 .23366 L
.34375 .01472 L
.32813 .01472 L
s
1 0 0 r
.34375 .01472 m
.34375 .23366 L
.35938 .23366 L
.35938 .01472 L
F
0 g
.34375 .01472 m
.34375 .23366 L
.35938 .23366 L
.35938 .01472 L
.34375 .01472 L
s
1 0 0 r
.35938 .01472 m
.35938 .24504 L
.375 .24504 L
.375 .01472 L
F
0 g
.35938 .01472 m
.35938 .24504 L
.375 .24504 L
.375 .01472 L
.35938 .01472 L
s
1 0 0 r
.375 .01472 m
.375 .33034 L
.39063 .33034 L
.39063 .01472 L
F
0 g
.375 .01472 m
.375 .33034 L
.39063 .33034 L
.39063 .01472 L
.375 .01472 L
s
1 0 0 r
.39063 .01472 m
.39063 .38721 L
.40625 .38721 L
.40625 .01472 L
F
0 g
.39063 .01472 m
.39063 .38721 L
.40625 .38721 L
.40625 .01472 L
.39063 .01472 L
s
1 0 0 r
.40625 .01472 m
.40625 .36447 L
.42188 .36447 L
.42188 .01472 L
F
0 g
.40625 .01472 m
.40625 .36447 L
.42188 .36447 L
.42188 .01472 L
.40625 .01472 L
s
1 0 0 r
.42188 .01472 m
.42188 .41849 L
.4375 .41849 L
.4375 .01472 L
F
0 g
.42188 .01472 m
.42188 .41849 L
.4375 .41849 L
.4375 .01472 L
.42188 .01472 L
s
1 0 0 r
.4375 .01472 m
.4375 .47821 L
.45313 .47821 L
.45313 .01472 L
F
0 g
.4375 .01472 m
.4375 .47821 L
.45313 .47821 L
.45313 .01472 L
.4375 .01472 L
s
1 0 0 r
.45313 .01472 m
.45313 .53507 L
.46875 .53507 L
.46875 .01472 L
F
0 g
.45313 .01472 m
.45313 .53507 L
.46875 .53507 L
.46875 .01472 L
.45313 .01472 L
s
1 0 0 r
.46875 .01472 m
.46875 .49811 L
.48438 .49811 L
.48438 .01472 L
F
0 g
.46875 .01472 m
.46875 .49811 L
.48438 .49811 L
.48438 .01472 L
.46875 .01472 L
s
1 0 0 r
.48438 .01472 m
.48438 .49242 L
.5 .49242 L
.5 .01472 L
F
0 g
.48438 .01472 m
.48438 .49242 L
.5 .49242 L
.5 .01472 L
.48438 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .5692 L
.51563 .5692 L
.51563 .01472 L
F
0 g
.5 .01472 m
.5 .5692 L
.51563 .5692 L
.51563 .01472 L
.5 .01472 L
s
1 0 0 r
.51563 .01472 m
.51563 .5891 L
.53125 .5891 L
.53125 .01472 L
F
0 g
.51563 .01472 m
.51563 .5891 L
.53125 .5891 L
.53125 .01472 L
.51563 .01472 L
s
1 0 0 r
.53125 .01472 m
.53125 .60332 L
.54688 .60332 L
.54688 .01472 L
F
0 g
.53125 .01472 m
.53125 .60332 L
.54688 .60332 L
.54688 .01472 L
.53125 .01472 L
s
1 0 0 r
.54688 .01472 m
.54688 .5038 L
.5625 .5038 L
.5625 .01472 L
F
0 g
.54688 .01472 m
.54688 .5038 L
.5625 .5038 L
.5625 .01472 L
.54688 .01472 L
s
1 0 0 r
.5625 .01472 m
.5625 .40427 L
.57813 .40427 L
.57813 .01472 L
F
0 g
.5625 .01472 m
.5625 .40427 L
.57813 .40427 L
.57813 .01472 L
.5625 .01472 L
s
1 0 0 r
.57813 .01472 m
.57813 .43555 L
.59375 .43555 L
.59375 .01472 L
F
0 g
.57813 .01472 m
.57813 .43555 L
.59375 .43555 L
.59375 .01472 L
.57813 .01472 L
s
1 0 0 r
.59375 .01472 m
.59375 .35593 L
.60938 .35593 L
.60938 .01472 L
F
0 g
.59375 .01472 m
.59375 .35593 L
.60938 .35593 L
.60938 .01472 L
.59375 .01472 L
s
1 0 0 r
.60938 .01472 m
.60938 .29906 L
.625 .29906 L
.625 .01472 L
F
0 g
.60938 .01472 m
.60938 .29906 L
.625 .29906 L
.625 .01472 L
.60938 .01472 L
s
1 0 0 r
.625 .01472 m
.625 .32181 L
.64063 .32181 L
.64063 .01472 L
F
0 g
.625 .01472 m
.625 .32181 L
.64063 .32181 L
.64063 .01472 L
.625 .01472 L
s
1 0 0 r
.64063 .01472 m
.64063 .23651 L
.65625 .23651 L
.65625 .01472 L
F
0 g
.64063 .01472 m
.64063 .23651 L
.65625 .23651 L
.65625 .01472 L
.64063 .01472 L
s
1 0 0 r
.65625 .01472 m
.65625 .20523 L
.67188 .20523 L
.67188 .01472 L
F
0 g
.65625 .01472 m
.65625 .20523 L
.67188 .20523 L
.67188 .01472 L
.65625 .01472 L
s
1 0 0 r
.67188 .01472 m
.67188 .17679 L
.6875 .17679 L
.6875 .01472 L
F
0 g
.67188 .01472 m
.67188 .17679 L
.6875 .17679 L
.6875 .01472 L
.67188 .01472 L
s
1 0 0 r
.6875 .01472 m
.6875 .18248 L
.70313 .18248 L
.70313 .01472 L
F
0 g
.6875 .01472 m
.6875 .18248 L
.70313 .18248 L
.70313 .01472 L
.6875 .01472 L
s
1 0 0 r
.70313 .01472 m
.70313 .10286 L
.71875 .10286 L
.71875 .01472 L
F
0 g
.70313 .01472 m
.70313 .10286 L
.71875 .10286 L
.71875 .01472 L
.70313 .01472 L
s
1 0 0 r
.71875 .01472 m
.71875 .13699 L
.73438 .13699 L
.73438 .01472 L
F
0 g
.71875 .01472 m
.71875 .13699 L
.73438 .13699 L
.73438 .01472 L
.71875 .01472 L
s
1 0 0 r
.73438 .01472 m
.73438 .11992 L
.75 .11992 L
.75 .01472 L
F
0 g
.73438 .01472 m
.73438 .11992 L
.75 .11992 L
.75 .01472 L
.73438 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .08012 L
.76563 .08012 L
.76563 .01472 L
F
0 g
.75 .01472 m
.75 .08012 L
.76563 .08012 L
.76563 .01472 L
.75 .01472 L
s
1 0 0 r
.76563 .01472 m
.76563 .09433 L
.78125 .09433 L
.78125 .01472 L
F
0 g
.76563 .01472 m
.76563 .09433 L
.78125 .09433 L
.78125 .01472 L
.76563 .01472 L
s
1 0 0 r
.78125 .01472 m
.78125 .0858 L
.79688 .0858 L
.79688 .01472 L
F
0 g
.78125 .01472 m
.78125 .0858 L
.79688 .0858 L
.79688 .01472 L
.78125 .01472 L
s
1 0 0 r
.79688 .01472 m
.79688 .07443 L
.8125 .07443 L
.8125 .01472 L
F
0 g
.79688 .01472 m
.79688 .07443 L
.8125 .07443 L
.8125 .01472 L
.79688 .01472 L
s
1 0 0 r
.8125 .01472 m
.8125 .0659 L
.82813 .0659 L
.82813 .01472 L
F
0 g
.8125 .01472 m
.8125 .0659 L
.82813 .0659 L
.82813 .01472 L
.8125 .01472 L
s
1 0 0 r
.82813 .01472 m
.82813 .06874 L
.84375 .06874 L
.84375 .01472 L
F
0 g
.82813 .01472 m
.82813 .06874 L
.84375 .06874 L
.84375 .01472 L
.82813 .01472 L
s
1 0 0 r
.84375 .01472 m
.84375 .08012 L
.85938 .08012 L
.85938 .01472 L
F
0 g
.84375 .01472 m
.84375 .08012 L
.85938 .08012 L
.85938 .01472 L
.84375 .01472 L
s
1 0 0 r
.85938 .01472 m
.85938 .04315 L
.875 .04315 L
.875 .01472 L
F
0 g
.85938 .01472 m
.85938 .04315 L
.875 .04315 L
.875 .01472 L
.85938 .01472 L
s
1 0 0 r
.875 .01472 m
.875 .06874 L
.89063 .06874 L
.89063 .01472 L
F
0 g
.875 .01472 m
.875 .06874 L
.89063 .06874 L
.89063 .01472 L
.875 .01472 L
s
1 0 0 r
.89063 .01472 m
.89063 .05168 L
.90625 .05168 L
.90625 .01472 L
F
0 g
.89063 .01472 m
.89063 .05168 L
.90625 .05168 L
.90625 .01472 L
.89063 .01472 L
s
1 0 0 r
.90625 .01472 m
.90625 .09149 L
.92188 .09149 L
.92188 .01472 L
F
0 g
.90625 .01472 m
.90625 .09149 L
.92188 .09149 L
.92188 .01472 L
.90625 .01472 L
s
1 0 0 r
.92188 .01472 m
.92188 .06021 L
.9375 .06021 L
.9375 .01472 L
F
0 g
.92188 .01472 m
.92188 .06021 L
.9375 .06021 L
.9375 .01472 L
.92188 .01472 L
s
1 0 0 r
.9375 .01472 m
.9375 .09149 L
.95313 .09149 L
.95313 .01472 L
F
0 g
.9375 .01472 m
.9375 .09149 L
.95313 .09149 L
.95313 .01472 L
.9375 .01472 L
s
1 0 0 r
.95313 .01472 m
.95313 .06874 L
.96875 .06874 L
.96875 .01472 L
F
0 g
.95313 .01472 m
.95313 .06874 L
.96875 .06874 L
.96875 .01472 L
.95313 .01472 L
s
1 0 0 r
.96875 .01472 m
.96875 .07727 L
.98438 .07727 L
.98438 .01472 L
F
0 g
.96875 .01472 m
.96875 .07727 L
.98438 .07727 L
.98438 .01472 L
.96875 .01472 L
s
1 0 0 r
.98438 .01472 m
.98438 .04031 L
1 .04031 L
1 .01472 L
F
0 g
.98438 .01472 m
.98438 .04031 L
1 .04031 L
1 .01472 L
.98438 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.015625 0.0147151 0.00175703 [
[.03125 .00222 -12 -9 ]
[.03125 .00222 12 0 ]
[.1875 .00222 -12 -9 ]
[.1875 .00222 12 0 ]
[.34375 .00222 -12 -9 ]
[.34375 .00222 12 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65625 .00222 -9 -9 ]
[.65625 .00222 9 0 ]
[.8125 .00222 -9 -9 ]
[.8125 .00222 9 0 ]
[.96875 .00222 -9 -9 ]
[.96875 .00222 9 0 ]
[-0.0125 .10257 -12 -4.5 ]
[-0.0125 .10257 0 4.5 ]
[-0.0125 .19042 -18 -4.5 ]
[-0.0125 .19042 0 4.5 ]
[-0.0125 .27827 -18 -4.5 ]
[-0.0125 .27827 0 4.5 ]
[-0.0125 .36612 -18 -4.5 ]
[-0.0125 .36612 0 4.5 ]
[-0.0125 .45397 -18 -4.5 ]
[-0.0125 .45397 0 4.5 ]
[-0.0125 .54182 -18 -4.5 ]
[-0.0125 .54182 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03125 .01472 m
.03125 .02097 L
s
[(-30.)] .03125 .00222 0 1 Mshowa
.1875 .01472 m
.1875 .02097 L
s
[(-20.)] .1875 .00222 0 1 Mshowa
.34375 .01472 m
.34375 .02097 L
s
[(-10.)] .34375 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.)] .5 .00222 0 1 Mshowa
.65625 .01472 m
.65625 .02097 L
s
[(10.)] .65625 .00222 0 1 Mshowa
.8125 .01472 m
.8125 .02097 L
s
[(20.)] .8125 .00222 0 1 Mshowa
.96875 .01472 m
.96875 .02097 L
s
[(30.)] .96875 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .10257 m
.00625 .10257 L
s
[(50)] -0.0125 .10257 1 0 Mshowa
0 .19042 m
.00625 .19042 L
s
[(100)] -0.0125 .19042 1 0 Mshowa
0 .27827 m
.00625 .27827 L
s
[(150)] -0.0125 .27827 1 0 Mshowa
0 .36612 m
.00625 .36612 L
s
[(200)] -0.0125 .36612 1 0 Mshowa
0 .45397 m
.00625 .45397 L
s
[(250)] -0.0125 .45397 1 0 Mshowa
0 .54182 m
.00625 .54182 L
s
[(300)] -0.0125 .54182 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .04986 m
.00375 .04986 L
s
0 .06743 m
.00375 .06743 L
s
0 .085 m
.00375 .085 L
s
0 .12014 m
.00375 .12014 L
s
0 .13771 m
.00375 .13771 L
s
0 .15528 m
.00375 .15528 L
s
0 .17285 m
.00375 .17285 L
s
0 .20799 m
.00375 .20799 L
s
0 .22556 m
.00375 .22556 L
s
0 .24313 m
.00375 .24313 L
s
0 .2607 m
.00375 .2607 L
s
0 .29584 m
.00375 .29584 L
s
0 .31341 m
.00375 .31341 L
s
0 .33098 m
.00375 .33098 L
s
0 .34855 m
.00375 .34855 L
s
0 .38369 m
.00375 .38369 L
s
0 .40126 m
.00375 .40126 L
s
0 .41883 m
.00375 .41883 L
s
0 .4364 m
.00375 .4364 L
s
0 .47154 m
.00375 .47154 L
s
0 .48911 m
.00375 .48911 L
s
0 .50668 m
.00375 .50668 L
s
0 .52425 m
.00375 .52425 L
s
0 .55939 m
.00375 .55939 L
s
0 .57696 m
.00375 .57696 L
s
0 .59453 m
.00375 .59453 L
s
0 .6121 m
.00375 .6121 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01647 L
.01563 .01647 L
.01563 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01647 L
.01563 .01647 L
.01563 .01472 L
0 .01472 L
s
1 0 0 r
.01563 .01472 m
.01563 .02174 L
.03125 .02174 L
.03125 .01472 L
F
0 g
.01563 .01472 m
.01563 .02174 L
.03125 .02174 L
.03125 .01472 L
.01563 .01472 L
s
1 0 0 r
.03125 .01472 m
.03125 .02174 L
.04688 .02174 L
.04688 .01472 L
F
0 g
.03125 .01472 m
.03125 .02174 L
.04688 .02174 L
.04688 .01472 L
.03125 .01472 L
s
1 0 0 r
.04688 .01472 m
.04688 .02526 L
.0625 .02526 L
.0625 .01472 L
F
0 g
.04688 .01472 m
.04688 .02526 L
.0625 .02526 L
.0625 .01472 L
.04688 .01472 L
s
1 0 0 r
.0625 .01472 m
.0625 .02174 L
.07813 .02174 L
.07813 .01472 L
F
0 g
.0625 .01472 m
.0625 .02174 L
.07813 .02174 L
.07813 .01472 L
.0625 .01472 L
s
1 0 0 r
.07813 .01472 m
.07813 .01823 L
.09375 .01823 L
.09375 .01472 L
F
0 g
.07813 .01472 m
.07813 .01823 L
.09375 .01823 L
.09375 .01472 L
.07813 .01472 L
s
1 0 0 r
.09375 .01472 m
.09375 .01823 L
.10938 .01823 L
.10938 .01472 L
F
0 g
.09375 .01472 m
.09375 .01823 L
.10938 .01823 L
.10938 .01472 L
.09375 .01472 L
s
1 0 0 r
.10938 .01472 m
.10938 .01647 L
.125 .01647 L
.125 .01472 L
F
0 g
.10938 .01472 m
.10938 .01647 L
.125 .01647 L
.125 .01472 L
.10938 .01472 L
s
1 0 0 r
.125 .01472 m
.125 .02174 L
.14063 .02174 L
.14063 .01472 L
F
0 g
.125 .01472 m
.125 .02174 L
.14063 .02174 L
.14063 .01472 L
.125 .01472 L
s
1 0 0 r
.14063 .01472 m
.14063 .03053 L
.15625 .03053 L
.15625 .01472 L
F
0 g
.14063 .01472 m
.14063 .03053 L
.15625 .03053 L
.15625 .01472 L
.14063 .01472 L
s
1 0 0 r
.15625 .01472 m
.15625 .02877 L
.17188 .02877 L
.17188 .01472 L
F
0 g
.15625 .01472 m
.15625 .02877 L
.17188 .02877 L
.17188 .01472 L
.15625 .01472 L
s
1 0 0 r
.17188 .01472 m
.17188 .02174 L
.1875 .02174 L
.1875 .01472 L
F
0 g
.17188 .01472 m
.17188 .02174 L
.1875 .02174 L
.1875 .01472 L
.17188 .01472 L
s
1 0 0 r
.1875 .01472 m
.1875 .03229 L
.20313 .03229 L
.20313 .01472 L
F
0 g
.1875 .01472 m
.1875 .03229 L
.20313 .03229 L
.20313 .01472 L
.1875 .01472 L
s
1 0 0 r
.20313 .01472 m
.20313 .03404 L
.21875 .03404 L
.21875 .01472 L
F
0 g
.20313 .01472 m
.20313 .03404 L
.21875 .03404 L
.21875 .01472 L
.20313 .01472 L
s
1 0 0 r
.21875 .01472 m
.21875 .04107 L
.23438 .04107 L
.23438 .01472 L
F
0 g
.21875 .01472 m
.21875 .04107 L
.23438 .04107 L
.23438 .01472 L
.21875 .01472 L
s
1 0 0 r
.23438 .01472 m
.23438 .03931 L
.25 .03931 L
.25 .01472 L
F
0 g
.23438 .01472 m
.23438 .03931 L
.25 .03931 L
.25 .01472 L
.23438 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .02526 L
.26563 .02526 L
.26563 .01472 L
F
0 g
.25 .01472 m
.25 .02526 L
.26563 .02526 L
.26563 .01472 L
.25 .01472 L
s
1 0 0 r
.26563 .01472 m
.26563 .0481 L
.28125 .0481 L
.28125 .01472 L
F
0 g
.26563 .01472 m
.26563 .0481 L
.28125 .0481 L
.28125 .01472 L
.26563 .01472 L
s
1 0 0 r
.28125 .01472 m
.28125 .03931 L
.29688 .03931 L
.29688 .01472 L
F
0 g
.28125 .01472 m
.28125 .03931 L
.29688 .03931 L
.29688 .01472 L
.28125 .01472 L
s
1 0 0 r
.29688 .01472 m
.29688 .04634 L
.3125 .04634 L
.3125 .01472 L
F
0 g
.29688 .01472 m
.29688 .04634 L
.3125 .04634 L
.3125 .01472 L
.29688 .01472 L
s
1 0 0 r
.3125 .01472 m
.3125 .07094 L
.32813 .07094 L
.32813 .01472 L
F
0 g
.3125 .01472 m
.3125 .07094 L
.32813 .07094 L
.32813 .01472 L
.3125 .01472 L
s
1 0 0 r
.32813 .01472 m
.32813 .07445 L
.34375 .07445 L
.34375 .01472 L
F
0 g
.32813 .01472 m
.32813 .07445 L
.34375 .07445 L
.34375 .01472 L
.32813 .01472 L
s
1 0 0 r
.34375 .01472 m
.34375 .11662 L
.35938 .11662 L
.35938 .01472 L
F
0 g
.34375 .01472 m
.34375 .11662 L
.35938 .11662 L
.35938 .01472 L
.34375 .01472 L
s
1 0 0 r
.35938 .01472 m
.35938 .14298 L
.375 .14298 L
.375 .01472 L
F
0 g
.35938 .01472 m
.35938 .14298 L
.375 .14298 L
.375 .01472 L
.35938 .01472 L
s
1 0 0 r
.375 .01472 m
.375 .17812 L
.39063 .17812 L
.39063 .01472 L
F
0 g
.375 .01472 m
.375 .17812 L
.39063 .17812 L
.39063 .01472 L
.375 .01472 L
s
1 0 0 r
.39063 .01472 m
.39063 .2361 L
.40625 .2361 L
.40625 .01472 L
F
0 g
.39063 .01472 m
.39063 .2361 L
.40625 .2361 L
.40625 .01472 L
.39063 .01472 L
s
1 0 0 r
.40625 .01472 m
.40625 .25718 L
.42188 .25718 L
.42188 .01472 L
F
0 g
.40625 .01472 m
.40625 .25718 L
.42188 .25718 L
.42188 .01472 L
.40625 .01472 L
s
1 0 0 r
.42188 .01472 m
.42188 .34679 L
.4375 .34679 L
.4375 .01472 L
F
0 g
.42188 .01472 m
.42188 .34679 L
.4375 .34679 L
.4375 .01472 L
.42188 .01472 L
s
1 0 0 r
.4375 .01472 m
.4375 .40477 L
.45313 .40477 L
.45313 .01472 L
F
0 g
.4375 .01472 m
.4375 .40477 L
.45313 .40477 L
.45313 .01472 L
.4375 .01472 L
s
1 0 0 r
.45313 .01472 m
.45313 .5102 L
.46875 .5102 L
.46875 .01472 L
F
0 g
.45313 .01472 m
.45313 .5102 L
.46875 .5102 L
.46875 .01472 L
.45313 .01472 L
s
1 0 0 r
.46875 .01472 m
.46875 .58223 L
.48438 .58223 L
.48438 .01472 L
F
0 g
.46875 .01472 m
.46875 .58223 L
.48438 .58223 L
.48438 .01472 L
.46875 .01472 L
s
1 0 0 r
.48438 .01472 m
.48438 .59278 L
.5 .59278 L
.5 .01472 L
F
0 g
.48438 .01472 m
.48438 .59278 L
.5 .59278 L
.5 .01472 L
.48438 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .60332 L
.51563 .60332 L
.51563 .01472 L
F
0 g
.5 .01472 m
.5 .60332 L
.51563 .60332 L
.51563 .01472 L
.5 .01472 L
s
1 0 0 r
.51563 .01472 m
.51563 .55237 L
.53125 .55237 L
.53125 .01472 L
F
0 g
.51563 .01472 m
.51563 .55237 L
.53125 .55237 L
.53125 .01472 L
.51563 .01472 L
s
1 0 0 r
.53125 .01472 m
.53125 .45221 L
.54688 .45221 L
.54688 .01472 L
F
0 g
.53125 .01472 m
.53125 .45221 L
.54688 .45221 L
.54688 .01472 L
.53125 .01472 L
s
1 0 0 r
.54688 .01472 m
.54688 .40477 L
.5625 .40477 L
.5625 .01472 L
F
0 g
.54688 .01472 m
.54688 .40477 L
.5625 .40477 L
.5625 .01472 L
.54688 .01472 L
s
1 0 0 r
.5625 .01472 m
.5625 .31692 L
.57813 .31692 L
.57813 .01472 L
F
0 g
.5625 .01472 m
.5625 .31692 L
.57813 .31692 L
.57813 .01472 L
.5625 .01472 L
s
1 0 0 r
.57813 .01472 m
.57813 .29935 L
.59375 .29935 L
.59375 .01472 L
F
0 g
.57813 .01472 m
.57813 .29935 L
.59375 .29935 L
.59375 .01472 L
.57813 .01472 L
s
1 0 0 r
.59375 .01472 m
.59375 .21502 L
.60938 .21502 L
.60938 .01472 L
F
0 g
.59375 .01472 m
.59375 .21502 L
.60938 .21502 L
.60938 .01472 L
.59375 .01472 L
s
1 0 0 r
.60938 .01472 m
.60938 .18866 L
.625 .18866 L
.625 .01472 L
F
0 g
.60938 .01472 m
.60938 .18866 L
.625 .18866 L
.625 .01472 L
.60938 .01472 L
s
1 0 0 r
.625 .01472 m
.625 .14825 L
.64063 .14825 L
.64063 .01472 L
F
0 g
.625 .01472 m
.625 .14825 L
.64063 .14825 L
.64063 .01472 L
.625 .01472 L
s
1 0 0 r
.64063 .01472 m
.64063 .12541 L
.65625 .12541 L
.65625 .01472 L
F
0 g
.64063 .01472 m
.64063 .12541 L
.65625 .12541 L
.65625 .01472 L
.64063 .01472 L
s
1 0 0 r
.65625 .01472 m
.65625 .10432 L
.67188 .10432 L
.67188 .01472 L
F
0 g
.65625 .01472 m
.65625 .10432 L
.67188 .10432 L
.67188 .01472 L
.65625 .01472 L
s
1 0 0 r
.67188 .01472 m
.67188 .0727 L
.6875 .0727 L
.6875 .01472 L
F
0 g
.67188 .01472 m
.67188 .0727 L
.6875 .0727 L
.6875 .01472 L
.67188 .01472 L
s
1 0 0 r
.6875 .01472 m
.6875 .08851 L
.70313 .08851 L
.70313 .01472 L
F
0 g
.6875 .01472 m
.6875 .08851 L
.70313 .08851 L
.70313 .01472 L
.6875 .01472 L
s
1 0 0 r
.70313 .01472 m
.70313 .05161 L
.71875 .05161 L
.71875 .01472 L
F
0 g
.70313 .01472 m
.70313 .05161 L
.71875 .05161 L
.71875 .01472 L
.70313 .01472 L
s
1 0 0 r
.71875 .01472 m
.71875 .03404 L
.73438 .03404 L
.73438 .01472 L
F
0 g
.71875 .01472 m
.71875 .03404 L
.73438 .03404 L
.73438 .01472 L
.71875 .01472 L
s
1 0 0 r
.73438 .01472 m
.73438 .03931 L
.75 .03931 L
.75 .01472 L
F
0 g
.73438 .01472 m
.73438 .03931 L
.75 .03931 L
.75 .01472 L
.73438 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .03229 L
.76563 .03229 L
.76563 .01472 L
F
0 g
.75 .01472 m
.75 .03229 L
.76563 .03229 L
.76563 .01472 L
.75 .01472 L
s
1 0 0 r
.76563 .01472 m
.76563 .03053 L
.78125 .03053 L
.78125 .01472 L
F
0 g
.76563 .01472 m
.76563 .03053 L
.78125 .03053 L
.78125 .01472 L
.76563 .01472 L
s
1 0 0 r
.78125 .01472 m
.78125 .01823 L
.79688 .01823 L
.79688 .01472 L
F
0 g
.78125 .01472 m
.78125 .01823 L
.79688 .01823 L
.79688 .01472 L
.78125 .01472 L
s
1 0 0 r
.79688 .01472 m
.79688 .02526 L
.8125 .02526 L
.8125 .01472 L
F
0 g
.79688 .01472 m
.79688 .02526 L
.8125 .02526 L
.8125 .01472 L
.79688 .01472 L
s
1 0 0 r
.8125 .01472 m
.8125 .02701 L
.82813 .02701 L
.82813 .01472 L
F
0 g
.8125 .01472 m
.8125 .02701 L
.82813 .02701 L
.82813 .01472 L
.8125 .01472 L
s
1 0 0 r
.82813 .01472 m
.82813 .02526 L
.84375 .02526 L
.84375 .01472 L
F
0 g
.82813 .01472 m
.82813 .02526 L
.84375 .02526 L
.84375 .01472 L
.82813 .01472 L
s
1 0 0 r
.84375 .01472 m
.84375 .02174 L
.85938 .02174 L
.85938 .01472 L
F
0 g
.84375 .01472 m
.84375 .02174 L
.85938 .02174 L
.85938 .01472 L
.84375 .01472 L
s
1 0 0 r
.85938 .01472 m
.85938 .02174 L
.875 .02174 L
.875 .01472 L
F
0 g
.85938 .01472 m
.85938 .02174 L
.875 .02174 L
.875 .01472 L
.85938 .01472 L
s
1 0 0 r
.875 .01472 m
.875 .01999 L
.89063 .01999 L
.89063 .01472 L
F
0 g
.875 .01472 m
.875 .01999 L
.89063 .01999 L
.89063 .01472 L
.875 .01472 L
s
1 0 0 r
.89063 .01472 m
.89063 .01823 L
.90625 .01823 L
.90625 .01472 L
F
0 g
.89063 .01472 m
.89063 .01823 L
.90625 .01823 L
.90625 .01472 L
.89063 .01472 L
s
1 0 0 r
.90625 .01472 m
.90625 .01999 L
.92188 .01999 L
.92188 .01472 L
F
0 g
.90625 .01472 m
.90625 .01999 L
.92188 .01999 L
.92188 .01472 L
.90625 .01472 L
s
1 0 0 r
.92188 .01472 m
.92188 .02701 L
.9375 .02701 L
.9375 .01472 L
F
0 g
.92188 .01472 m
.92188 .02701 L
.9375 .02701 L
.9375 .01472 L
.92188 .01472 L
s
1 0 0 r
.9375 .01472 m
.9375 .02174 L
.95313 .02174 L
.95313 .01472 L
F
0 g
.9375 .01472 m
.9375 .02174 L
.95313 .02174 L
.95313 .01472 L
.9375 .01472 L
s
1 0 0 r
.95313 .01472 m
.95313 .01472 L
.96875 .01472 L
.96875 .01472 L
F
0 g
.95313 .01472 m
.95313 .01472 L
.96875 .01472 L
.96875 .01472 L
.95313 .01472 L
s
1 0 0 r
.96875 .01472 m
.96875 .01472 L
.98438 .01472 L
.98438 .01472 L
F
0 g
.96875 .01472 m
.96875 .01472 L
.98438 .01472 L
.98438 .01472 L
.96875 .01472 L
s
1 0 0 r
.98438 .01472 m
.98438 .02174 L
1 .02174 L
1 .01472 L
F
0 g
.98438 .01472 m
.98438 .02174 L
1 .02174 L
1 .01472 L
.98438 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 4.49438e+014 0.0147151 3.59255e-021 [
[.22472 .00222 -21.75 -12.5 ]
[.22472 .00222 21.75 0 ]
[.44944 .00222 -21.75 -12.5 ]
[.44944 .00222 21.75 0 ]
[.67416 .00222 -24.75 -12.5 ]
[.67416 .00222 24.75 0 ]
[.89888 .00222 -21.75 -12.5 ]
[.89888 .00222 21.75 0 ]
[-0.0125 .10453 -45 -6.25 ]
[-0.0125 .10453 0 6.25 ]
[-0.0125 .19434 -33 -6.25 ]
[-0.0125 .19434 0 6.25 ]
[-0.0125 .28416 -45 -6.25 ]
[-0.0125 .28416 0 6.25 ]
[-0.0125 .37397 -33 -6.25 ]
[-0.0125 .37397 0 6.25 ]
[-0.0125 .46378 -51 -6.25 ]
[-0.0125 .46378 0 6.25 ]
[-0.0125 .5536 -45 -6.25 ]
[-0.0125 .5536 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22472 .01472 m
.22472 .02097 L
s
gsave
.22472 .00222 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5.) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-16) show
grestore
.44944 .01472 m
.44944 .02097 L
s
gsave
.44944 .00222 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.67416 .01472 m
.67416 .02097 L
s
gsave
.67416 .00222 -24.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.89888 .01472 m
.89888 .02097 L
s
gsave
.89888 .00222 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
0 .01472 m
1 .01472 L
s
0 .10453 m
.00625 .10453 L
s
gsave
-0.0125 .10453 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(19) show
grestore
0 .19434 m
.00625 .19434 L
s
gsave
-0.0125 .19434 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(19) show
grestore
0 .28416 m
.00625 .28416 L
s
gsave
-0.0125 .28416 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(19) show
grestore
0 .37397 m
.00625 .37397 L
s
gsave
-0.0125 .37397 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(20) show
grestore
0 .46378 m
.00625 .46378 L
s
gsave
-0.0125 .46378 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.25) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(20) show
grestore
0 .5536 m
.00625 .5536 L
s
gsave
-0.0125 .5536 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(20) show
grestore
.125 Mabswid
0 .03268 m
.00375 .03268 L
s
0 .05064 m
.00375 .05064 L
s
0 .0686 m
.00375 .0686 L
s
0 .08657 m
.00375 .08657 L
s
0 .12249 m
.00375 .12249 L
s
0 .14045 m
.00375 .14045 L
s
0 .15842 m
.00375 .15842 L
s
0 .17638 m
.00375 .17638 L
s
0 .21231 m
.00375 .21231 L
s
0 .23027 m
.00375 .23027 L
s
0 .24823 m
.00375 .24823 L
s
0 .26619 m
.00375 .26619 L
s
0 .30212 m
.00375 .30212 L
s
0 .32008 m
.00375 .32008 L
s
0 .33804 m
.00375 .33804 L
s
0 .35601 m
.00375 .35601 L
s
0 .39193 m
.00375 .39193 L
s
0 .4099 m
.00375 .4099 L
s
0 .42786 m
.00375 .42786 L
s
0 .44582 m
.00375 .44582 L
s
0 .48175 m
.00375 .48175 L
s
0 .49971 m
.00375 .49971 L
s
0 .51767 m
.00375 .51767 L
s
0 .53564 m
.00375 .53564 L
s
0 .57156 m
.00375 .57156 L
s
0 .58952 m
.00375 .58952 L
s
0 .60749 m
.00375 .60749 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60332 L
.01124 .60332 L
.01124 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60332 L
.01124 .60332 L
.01124 .01472 L
0 .01472 L
s
1 0 0 r
.01124 .01472 m
.01124 .01472 L
.02247 .01472 L
.02247 .01472 L
F
0 g
.01124 .01472 m
.01124 .01472 L
.02247 .01472 L
.02247 .01472 L
.01124 .01472 L
s
1 0 0 r
.02247 .01472 m
.02247 .01472 L
.03371 .01472 L
.03371 .01472 L
F
0 g
.02247 .01472 m
.02247 .01472 L
.03371 .01472 L
.03371 .01472 L
.02247 .01472 L
s
1 0 0 r
.03371 .01472 m
.03371 .01472 L
.04494 .01472 L
.04494 .01472 L
F
0 g
.03371 .01472 m
.03371 .01472 L
.04494 .01472 L
.04494 .01472 L
.03371 .01472 L
s
1 0 0 r
.04494 .01472 m
.04494 .01472 L
.05618 .01472 L
.05618 .01472 L
F
0 g
.04494 .01472 m
.04494 .01472 L
.05618 .01472 L
.05618 .01472 L
.04494 .01472 L
s
1 0 0 r
.05618 .01472 m
.05618 .01472 L
.06742 .01472 L
.06742 .01472 L
F
0 g
.05618 .01472 m
.05618 .01472 L
.06742 .01472 L
.06742 .01472 L
.05618 .01472 L
s
1 0 0 r
.06742 .01472 m
.06742 .01472 L
.07865 .01472 L
.07865 .01472 L
F
0 g
.06742 .01472 m
.06742 .01472 L
.07865 .01472 L
.07865 .01472 L
.06742 .01472 L
s
1 0 0 r
.07865 .01472 m
.07865 .01472 L
.08989 .01472 L
.08989 .01472 L
F
0 g
.07865 .01472 m
.07865 .01472 L
.08989 .01472 L
.08989 .01472 L
.07865 .01472 L
s
1 0 0 r
.08989 .01472 m
.08989 .01472 L
.10112 .01472 L
.10112 .01472 L
F
0 g
.08989 .01472 m
.08989 .01472 L
.10112 .01472 L
.10112 .01472 L
.08989 .01472 L
s
1 0 0 r
.10112 .01472 m
.10112 .01472 L
.11236 .01472 L
.11236 .01472 L
F
0 g
.10112 .01472 m
.10112 .01472 L
.11236 .01472 L
.11236 .01472 L
.10112 .01472 L
s
1 0 0 r
.11236 .01472 m
.11236 .01472 L
.1236 .01472 L
.1236 .01472 L
F
0 g
.11236 .01472 m
.11236 .01472 L
.1236 .01472 L
.1236 .01472 L
.11236 .01472 L
s
1 0 0 r
.1236 .01472 m
.1236 .01472 L
.13483 .01472 L
.13483 .01472 L
F
0 g
.1236 .01472 m
.1236 .01472 L
.13483 .01472 L
.13483 .01472 L
.1236 .01472 L
s
1 0 0 r
.13483 .01472 m
.13483 .01472 L
.14607 .01472 L
.14607 .01472 L
F
0 g
.13483 .01472 m
.13483 .01472 L
.14607 .01472 L
.14607 .01472 L
.13483 .01472 L
s
1 0 0 r
.14607 .01472 m
.14607 .01472 L
.1573 .01472 L
.1573 .01472 L
F
0 g
.14607 .01472 m
.14607 .01472 L
.1573 .01472 L
.1573 .01472 L
.14607 .01472 L
s
1 0 0 r
.1573 .01472 m
.1573 .01472 L
.16854 .01472 L
.16854 .01472 L
F
0 g
.1573 .01472 m
.1573 .01472 L
.16854 .01472 L
.16854 .01472 L
.1573 .01472 L
s
1 0 0 r
.16854 .01472 m
.16854 .01472 L
.17978 .01472 L
.17978 .01472 L
F
0 g
.16854 .01472 m
.16854 .01472 L
.17978 .01472 L
.17978 .01472 L
.16854 .01472 L
s
1 0 0 r
.17978 .01472 m
.17978 .01472 L
.19101 .01472 L
.19101 .01472 L
F
0 g
.17978 .01472 m
.17978 .01472 L
.19101 .01472 L
.19101 .01472 L
.17978 .01472 L
s
1 0 0 r
.19101 .01472 m
.19101 .01472 L
.20225 .01472 L
.20225 .01472 L
F
0 g
.19101 .01472 m
.19101 .01472 L
.20225 .01472 L
.20225 .01472 L
.19101 .01472 L
s
1 0 0 r
.20225 .01472 m
.20225 .01472 L
.21348 .01472 L
.21348 .01472 L
F
0 g
.20225 .01472 m
.20225 .01472 L
.21348 .01472 L
.21348 .01472 L
.20225 .01472 L
s
1 0 0 r
.21348 .01472 m
.21348 .01472 L
.22472 .01472 L
.22472 .01472 L
F
0 g
.21348 .01472 m
.21348 .01472 L
.22472 .01472 L
.22472 .01472 L
.21348 .01472 L
s
1 0 0 r
.22472 .01472 m
.22472 .01472 L
.23596 .01472 L
.23596 .01472 L
F
0 g
.22472 .01472 m
.22472 .01472 L
.23596 .01472 L
.23596 .01472 L
.22472 .01472 L
s
1 0 0 r
.23596 .01472 m
.23596 .01472 L
.24719 .01472 L
.24719 .01472 L
F
0 g
.23596 .01472 m
.23596 .01472 L
.24719 .01472 L
.24719 .01472 L
.23596 .01472 L
s
1 0 0 r
.24719 .01472 m
.24719 .01472 L
.25843 .01472 L
.25843 .01472 L
F
0 g
.24719 .01472 m
.24719 .01472 L
.25843 .01472 L
.25843 .01472 L
.24719 .01472 L
s
1 0 0 r
.25843 .01472 m
.25843 .01472 L
.26966 .01472 L
.26966 .01472 L
F
0 g
.25843 .01472 m
.25843 .01472 L
.26966 .01472 L
.26966 .01472 L
.25843 .01472 L
s
1 0 0 r
.26966 .01472 m
.26966 .01472 L
.2809 .01472 L
.2809 .01472 L
F
0 g
.26966 .01472 m
.26966 .01472 L
.2809 .01472 L
.2809 .01472 L
.26966 .01472 L
s
1 0 0 r
.2809 .01472 m
.2809 .01472 L
.29213 .01472 L
.29213 .01472 L
F
0 g
.2809 .01472 m
.2809 .01472 L
.29213 .01472 L
.29213 .01472 L
.2809 .01472 L
s
1 0 0 r
.29213 .01472 m
.29213 .01472 L
.30337 .01472 L
.30337 .01472 L
F
0 g
.29213 .01472 m
.29213 .01472 L
.30337 .01472 L
.30337 .01472 L
.29213 .01472 L
s
1 0 0 r
.30337 .01472 m
.30337 .01472 L
.31461 .01472 L
.31461 .01472 L
F
0 g
.30337 .01472 m
.30337 .01472 L
.31461 .01472 L
.31461 .01472 L
.30337 .01472 L
s
1 0 0 r
.31461 .01472 m
.31461 .01472 L
.32584 .01472 L
.32584 .01472 L
F
0 g
.31461 .01472 m
.31461 .01472 L
.32584 .01472 L
.32584 .01472 L
.31461 .01472 L
s
1 0 0 r
.32584 .01472 m
.32584 .01472 L
.33708 .01472 L
.33708 .01472 L
F
0 g
.32584 .01472 m
.32584 .01472 L
.33708 .01472 L
.33708 .01472 L
.32584 .01472 L
s
1 0 0 r
.33708 .01472 m
.33708 .01472 L
.34831 .01472 L
.34831 .01472 L
F
0 g
.33708 .01472 m
.33708 .01472 L
.34831 .01472 L
.34831 .01472 L
.33708 .01472 L
s
1 0 0 r
.34831 .01472 m
.34831 .01472 L
.35955 .01472 L
.35955 .01472 L
F
0 g
.34831 .01472 m
.34831 .01472 L
.35955 .01472 L
.35955 .01472 L
.34831 .01472 L
s
1 0 0 r
.35955 .01472 m
.35955 .01472 L
.37079 .01472 L
.37079 .01472 L
F
0 g
.35955 .01472 m
.35955 .01472 L
.37079 .01472 L
.37079 .01472 L
.35955 .01472 L
s
1 0 0 r
.37079 .01472 m
.37079 .01472 L
.38202 .01472 L
.38202 .01472 L
F
0 g
.37079 .01472 m
.37079 .01472 L
.38202 .01472 L
.38202 .01472 L
.37079 .01472 L
s
1 0 0 r
.38202 .01472 m
.38202 .01472 L
.39326 .01472 L
.39326 .01472 L
F
0 g
.38202 .01472 m
.38202 .01472 L
.39326 .01472 L
.39326 .01472 L
.38202 .01472 L
s
1 0 0 r
.39326 .01472 m
.39326 .01472 L
.40449 .01472 L
.40449 .01472 L
F
0 g
.39326 .01472 m
.39326 .01472 L
.40449 .01472 L
.40449 .01472 L
.39326 .01472 L
s
1 0 0 r
.40449 .01472 m
.40449 .01472 L
.41573 .01472 L
.41573 .01472 L
F
0 g
.40449 .01472 m
.40449 .01472 L
.41573 .01472 L
.41573 .01472 L
.40449 .01472 L
s
1 0 0 r
.41573 .01472 m
.41573 .01472 L
.42697 .01472 L
.42697 .01472 L
F
0 g
.41573 .01472 m
.41573 .01472 L
.42697 .01472 L
.42697 .01472 L
.41573 .01472 L
s
1 0 0 r
.42697 .01472 m
.42697 .01472 L
.4382 .01472 L
.4382 .01472 L
F
0 g
.42697 .01472 m
.42697 .01472 L
.4382 .01472 L
.4382 .01472 L
.42697 .01472 L
s
1 0 0 r
.4382 .01472 m
.4382 .01472 L
.44944 .01472 L
.44944 .01472 L
F
0 g
.4382 .01472 m
.4382 .01472 L
.44944 .01472 L
.44944 .01472 L
.4382 .01472 L
s
1 0 0 r
.44944 .01472 m
.44944 .01472 L
.46067 .01472 L
.46067 .01472 L
F
0 g
.44944 .01472 m
.44944 .01472 L
.46067 .01472 L
.46067 .01472 L
.44944 .01472 L
s
1 0 0 r
.46067 .01472 m
.46067 .01472 L
.47191 .01472 L
.47191 .01472 L
F
0 g
.46067 .01472 m
.46067 .01472 L
.47191 .01472 L
.47191 .01472 L
.46067 .01472 L
s
1 0 0 r
.47191 .01472 m
.47191 .01472 L
.48315 .01472 L
.48315 .01472 L
F
0 g
.47191 .01472 m
.47191 .01472 L
.48315 .01472 L
.48315 .01472 L
.47191 .01472 L
s
1 0 0 r
.48315 .01472 m
.48315 .01472 L
.49438 .01472 L
.49438 .01472 L
F
0 g
.48315 .01472 m
.48315 .01472 L
.49438 .01472 L
.49438 .01472 L
.48315 .01472 L
s
1 0 0 r
.49438 .01472 m
.49438 .01472 L
.50562 .01472 L
.50562 .01472 L
F
0 g
.49438 .01472 m
.49438 .01472 L
.50562 .01472 L
.50562 .01472 L
.49438 .01472 L
s
1 0 0 r
.50562 .01472 m
.50562 .01472 L
.51685 .01472 L
.51685 .01472 L
F
0 g
.50562 .01472 m
.50562 .01472 L
.51685 .01472 L
.51685 .01472 L
.50562 .01472 L
s
1 0 0 r
.51685 .01472 m
.51685 .01472 L
.52809 .01472 L
.52809 .01472 L
F
0 g
.51685 .01472 m
.51685 .01472 L
.52809 .01472 L
.52809 .01472 L
.51685 .01472 L
s
1 0 0 r
.52809 .01472 m
.52809 .01472 L
.53933 .01472 L
.53933 .01472 L
F
0 g
.52809 .01472 m
.52809 .01472 L
.53933 .01472 L
.53933 .01472 L
.52809 .01472 L
s
1 0 0 r
.53933 .01472 m
.53933 .01472 L
.55056 .01472 L
.55056 .01472 L
F
0 g
.53933 .01472 m
.53933 .01472 L
.55056 .01472 L
.55056 .01472 L
.53933 .01472 L
s
1 0 0 r
.55056 .01472 m
.55056 .01472 L
.5618 .01472 L
.5618 .01472 L
F
0 g
.55056 .01472 m
.55056 .01472 L
.5618 .01472 L
.5618 .01472 L
.55056 .01472 L
s
1 0 0 r
.5618 .01472 m
.5618 .01472 L
.57303 .01472 L
.57303 .01472 L
F
0 g
.5618 .01472 m
.5618 .01472 L
.57303 .01472 L
.57303 .01472 L
.5618 .01472 L
s
1 0 0 r
.57303 .01472 m
.57303 .01472 L
.58427 .01472 L
.58427 .01472 L
F
0 g
.57303 .01472 m
.57303 .01472 L
.58427 .01472 L
.58427 .01472 L
.57303 .01472 L
s
1 0 0 r
.58427 .01472 m
.58427 .01472 L
.59551 .01472 L
.59551 .01472 L
F
0 g
.58427 .01472 m
.58427 .01472 L
.59551 .01472 L
.59551 .01472 L
.58427 .01472 L
s
1 0 0 r
.59551 .01472 m
.59551 .01472 L
.60674 .01472 L
.60674 .01472 L
F
0 g
.59551 .01472 m
.59551 .01472 L
.60674 .01472 L
.60674 .01472 L
.59551 .01472 L
s
1 0 0 r
.60674 .01472 m
.60674 .01472 L
.61798 .01472 L
.61798 .01472 L
F
0 g
.60674 .01472 m
.60674 .01472 L
.61798 .01472 L
.61798 .01472 L
.60674 .01472 L
s
1 0 0 r
.61798 .01472 m
.61798 .01472 L
.62921 .01472 L
.62921 .01472 L
F
0 g
.61798 .01472 m
.61798 .01472 L
.62921 .01472 L
.62921 .01472 L
.61798 .01472 L
s
1 0 0 r
.62921 .01472 m
.62921 .01472 L
.64045 .01472 L
.64045 .01472 L
F
0 g
.62921 .01472 m
.62921 .01472 L
.64045 .01472 L
.64045 .01472 L
.62921 .01472 L
s
1 0 0 r
.64045 .01472 m
.64045 .01472 L
.65169 .01472 L
.65169 .01472 L
F
0 g
.64045 .01472 m
.64045 .01472 L
.65169 .01472 L
.65169 .01472 L
.64045 .01472 L
s
1 0 0 r
.65169 .01472 m
.65169 .01472 L
.66292 .01472 L
.66292 .01472 L
F
0 g
.65169 .01472 m
.65169 .01472 L
.66292 .01472 L
.66292 .01472 L
.65169 .01472 L
s
1 0 0 r
.66292 .01472 m
.66292 .01472 L
.67416 .01472 L
.67416 .01472 L
F
0 g
.66292 .01472 m
.66292 .01472 L
.67416 .01472 L
.67416 .01472 L
.66292 .01472 L
s
1 0 0 r
.67416 .01472 m
.67416 .01472 L
.68539 .01472 L
.68539 .01472 L
F
0 g
.67416 .01472 m
.67416 .01472 L
.68539 .01472 L
.68539 .01472 L
.67416 .01472 L
s
1 0 0 r
.68539 .01472 m
.68539 .01472 L
.69663 .01472 L
.69663 .01472 L
F
0 g
.68539 .01472 m
.68539 .01472 L
.69663 .01472 L
.69663 .01472 L
.68539 .01472 L
s
1 0 0 r
.69663 .01472 m
.69663 .01472 L
.70787 .01472 L
.70787 .01472 L
F
0 g
.69663 .01472 m
.69663 .01472 L
.70787 .01472 L
.70787 .01472 L
.69663 .01472 L
s
1 0 0 r
.70787 .01472 m
.70787 .01472 L
.7191 .01472 L
.7191 .01472 L
F
0 g
.70787 .01472 m
.70787 .01472 L
.7191 .01472 L
.7191 .01472 L
.70787 .01472 L
s
1 0 0 r
.7191 .01472 m
.7191 .01472 L
.73034 .01472 L
.73034 .01472 L
F
0 g
.7191 .01472 m
.7191 .01472 L
.73034 .01472 L
.73034 .01472 L
.7191 .01472 L
s
1 0 0 r
.73034 .01472 m
.73034 .01472 L
.74157 .01472 L
.74157 .01472 L
F
0 g
.73034 .01472 m
.73034 .01472 L
.74157 .01472 L
.74157 .01472 L
.73034 .01472 L
s
1 0 0 r
.74157 .01472 m
.74157 .01472 L
.75281 .01472 L
.75281 .01472 L
F
0 g
.74157 .01472 m
.74157 .01472 L
.75281 .01472 L
.75281 .01472 L
.74157 .01472 L
s
1 0 0 r
.75281 .01472 m
.75281 .01472 L
.76404 .01472 L
.76404 .01472 L
F
0 g
.75281 .01472 m
.75281 .01472 L
.76404 .01472 L
.76404 .01472 L
.75281 .01472 L
s
1 0 0 r
.76404 .01472 m
.76404 .01472 L
.77528 .01472 L
.77528 .01472 L
F
0 g
.76404 .01472 m
.76404 .01472 L
.77528 .01472 L
.77528 .01472 L
.76404 .01472 L
s
1 0 0 r
.77528 .01472 m
.77528 .01472 L
.78652 .01472 L
.78652 .01472 L
F
0 g
.77528 .01472 m
.77528 .01472 L
.78652 .01472 L
.78652 .01472 L
.77528 .01472 L
s
1 0 0 r
.78652 .01472 m
.78652 .01472 L
.79775 .01472 L
.79775 .01472 L
F
0 g
.78652 .01472 m
.78652 .01472 L
.79775 .01472 L
.79775 .01472 L
.78652 .01472 L
s
1 0 0 r
.79775 .01472 m
.79775 .01472 L
.80899 .01472 L
.80899 .01472 L
F
0 g
.79775 .01472 m
.79775 .01472 L
.80899 .01472 L
.80899 .01472 L
.79775 .01472 L
s
1 0 0 r
.80899 .01472 m
.80899 .01472 L
.82022 .01472 L
.82022 .01472 L
F
0 g
.80899 .01472 m
.80899 .01472 L
.82022 .01472 L
.82022 .01472 L
.80899 .01472 L
s
1 0 0 r
.82022 .01472 m
.82022 .01472 L
.83146 .01472 L
.83146 .01472 L
F
0 g
.82022 .01472 m
.82022 .01472 L
.83146 .01472 L
.83146 .01472 L
.82022 .01472 L
s
1 0 0 r
.83146 .01472 m
.83146 .01472 L
.8427 .01472 L
.8427 .01472 L
F
0 g
.83146 .01472 m
.83146 .01472 L
.8427 .01472 L
.8427 .01472 L
.83146 .01472 L
s
1 0 0 r
.8427 .01472 m
.8427 .01472 L
.85393 .01472 L
.85393 .01472 L
F
0 g
.8427 .01472 m
.8427 .01472 L
.85393 .01472 L
.85393 .01472 L
.8427 .01472 L
s
1 0 0 r
.85393 .01472 m
.85393 .01472 L
.86517 .01472 L
.86517 .01472 L
F
0 g
.85393 .01472 m
.85393 .01472 L
.86517 .01472 L
.86517 .01472 L
.85393 .01472 L
s
1 0 0 r
.86517 .01472 m
.86517 .01472 L
.8764 .01472 L
.8764 .01472 L
F
0 g
.86517 .01472 m
.86517 .01472 L
.8764 .01472 L
.8764 .01472 L
.86517 .01472 L
s
1 0 0 r
.8764 .01472 m
.8764 .01472 L
.88764 .01472 L
.88764 .01472 L
F
0 g
.8764 .01472 m
.8764 .01472 L
.88764 .01472 L
.88764 .01472 L
.8764 .01472 L
s
1 0 0 r
.88764 .01472 m
.88764 .01472 L
.89888 .01472 L
.89888 .01472 L
F
0 g
.88764 .01472 m
.88764 .01472 L
.89888 .01472 L
.89888 .01472 L
.88764 .01472 L
s
1 0 0 r
.89888 .01472 m
.89888 .01472 L
.91011 .01472 L
.91011 .01472 L
F
0 g
.89888 .01472 m
.89888 .01472 L
.91011 .01472 L
.91011 .01472 L
.89888 .01472 L
s
1 0 0 r
.91011 .01472 m
.91011 .01472 L
.92135 .01472 L
.92135 .01472 L
F
0 g
.91011 .01472 m
.91011 .01472 L
.92135 .01472 L
.92135 .01472 L
.91011 .01472 L
s
1 0 0 r
.92135 .01472 m
.92135 .01472 L
.93258 .01472 L
.93258 .01472 L
F
0 g
.92135 .01472 m
.92135 .01472 L
.93258 .01472 L
.93258 .01472 L
.92135 .01472 L
s
1 0 0 r
.93258 .01472 m
.93258 .01472 L
.94382 .01472 L
.94382 .01472 L
F
0 g
.93258 .01472 m
.93258 .01472 L
.94382 .01472 L
.94382 .01472 L
.93258 .01472 L
s
1 0 0 r
.94382 .01472 m
.94382 .01472 L
.95506 .01472 L
.95506 .01472 L
F
0 g
.94382 .01472 m
.94382 .01472 L
.95506 .01472 L
.95506 .01472 L
.94382 .01472 L
s
1 0 0 r
.95506 .01472 m
.95506 .01472 L
.96629 .01472 L
.96629 .01472 L
F
0 g
.95506 .01472 m
.95506 .01472 L
.96629 .01472 L
.96629 .01472 L
.95506 .01472 L
s
1 0 0 r
.96629 .01472 m
.96629 .01472 L
.97753 .01472 L
.97753 .01472 L
F
0 g
.96629 .01472 m
.96629 .01472 L
.97753 .01472 L
.97753 .01472 L
.96629 .01472 L
s
1 0 0 r
.97753 .01472 m
.97753 .01472 L
.98876 .01472 L
.98876 .01472 L
F
0 g
.97753 .01472 m
.97753 .01472 L
.98876 .01472 L
.98876 .01472 L
.97753 .01472 L
s
1 0 0 r
.98876 .01472 m
.98876 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.98876 .01472 m
.98876 .01472 L
1 .01472 L
1 .01472 L
.98876 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.03125 0.0147151 0.00214819 [
[.03125 .00222 -12 -9 ]
[.03125 .00222 12 0 ]
[.1875 .00222 -12 -9 ]
[.1875 .00222 12 0 ]
[.34375 .00222 -9 -9 ]
[.34375 .00222 9 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65625 .00222 -6 -9 ]
[.65625 .00222 6 0 ]
[.8125 .00222 -9 -9 ]
[.8125 .00222 9 0 ]
[.96875 .00222 -9 -9 ]
[.96875 .00222 9 0 ]
[-0.0125 .12212 -12 -4.5 ]
[-0.0125 .12212 0 4.5 ]
[-0.0125 .22953 -18 -4.5 ]
[-0.0125 .22953 0 4.5 ]
[-0.0125 .33694 -18 -4.5 ]
[-0.0125 .33694 0 4.5 ]
[-0.0125 .44435 -18 -4.5 ]
[-0.0125 .44435 0 4.5 ]
[-0.0125 .55176 -18 -4.5 ]
[-0.0125 .55176 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03125 .01472 m
.03125 .02097 L
s
[(-15.)] .03125 .00222 0 1 Mshowa
.1875 .01472 m
.1875 .02097 L
s
[(-10.)] .1875 .00222 0 1 Mshowa
.34375 .01472 m
.34375 .02097 L
s
[(-5.)] .34375 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.)] .5 .00222 0 1 Mshowa
.65625 .01472 m
.65625 .02097 L
s
[(5.)] .65625 .00222 0 1 Mshowa
.8125 .01472 m
.8125 .02097 L
s
[(10.)] .8125 .00222 0 1 Mshowa
.96875 .01472 m
.96875 .02097 L
s
[(15.)] .96875 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .12212 m
.00625 .12212 L
s
[(50)] -0.0125 .12212 1 0 Mshowa
0 .22953 m
.00625 .22953 L
s
[(100)] -0.0125 .22953 1 0 Mshowa
0 .33694 m
.00625 .33694 L
s
[(150)] -0.0125 .33694 1 0 Mshowa
0 .44435 m
.00625 .44435 L
s
[(200)] -0.0125 .44435 1 0 Mshowa
0 .55176 m
.00625 .55176 L
s
[(250)] -0.0125 .55176 1 0 Mshowa
.125 Mabswid
0 .0362 m
.00375 .0362 L
s
0 .05768 m
.00375 .05768 L
s
0 .07916 m
.00375 .07916 L
s
0 .10064 m
.00375 .10064 L
s
0 .14361 m
.00375 .14361 L
s
0 .16509 m
.00375 .16509 L
s
0 .18657 m
.00375 .18657 L
s
0 .20805 m
.00375 .20805 L
s
0 .25102 m
.00375 .25102 L
s
0 .2725 m
.00375 .2725 L
s
0 .29398 m
.00375 .29398 L
s
0 .31546 m
.00375 .31546 L
s
0 .35843 m
.00375 .35843 L
s
0 .37991 m
.00375 .37991 L
s
0 .40139 m
.00375 .40139 L
s
0 .42287 m
.00375 .42287 L
s
0 .46583 m
.00375 .46583 L
s
0 .48732 m
.00375 .48732 L
s
0 .5088 m
.00375 .5088 L
s
0 .53028 m
.00375 .53028 L
s
0 .57324 m
.00375 .57324 L
s
0 .59473 m
.00375 .59473 L
s
0 .61621 m
.00375 .61621 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .0319 L
.01563 .0319 L
.01563 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .0319 L
.01563 .0319 L
.01563 .01472 L
0 .01472 L
s
1 0 0 r
.01563 .01472 m
.01563 .0319 L
.03125 .0319 L
.03125 .01472 L
F
0 g
.01563 .01472 m
.01563 .0319 L
.03125 .0319 L
.03125 .01472 L
.01563 .01472 L
s
1 0 0 r
.03125 .01472 m
.03125 .0276 L
.04688 .0276 L
.04688 .01472 L
F
0 g
.03125 .01472 m
.03125 .0276 L
.04688 .0276 L
.04688 .01472 L
.03125 .01472 L
s
1 0 0 r
.04688 .01472 m
.04688 .02546 L
.0625 .02546 L
.0625 .01472 L
F
0 g
.04688 .01472 m
.04688 .02546 L
.0625 .02546 L
.0625 .01472 L
.04688 .01472 L
s
1 0 0 r
.0625 .01472 m
.0625 .0319 L
.07813 .0319 L
.07813 .01472 L
F
0 g
.0625 .01472 m
.0625 .0319 L
.07813 .0319 L
.07813 .01472 L
.0625 .01472 L
s
1 0 0 r
.07813 .01472 m
.07813 .0362 L
.09375 .0362 L
.09375 .01472 L
F
0 g
.07813 .01472 m
.07813 .0362 L
.09375 .0362 L
.09375 .01472 L
.07813 .01472 L
s
1 0 0 r
.09375 .01472 m
.09375 .0276 L
.10938 .0276 L
.10938 .01472 L
F
0 g
.09375 .01472 m
.09375 .0276 L
.10938 .0276 L
.10938 .01472 L
.09375 .01472 L
s
1 0 0 r
.10938 .01472 m
.10938 .02975 L
.125 .02975 L
.125 .01472 L
F
0 g
.10938 .01472 m
.10938 .02975 L
.125 .02975 L
.125 .01472 L
.10938 .01472 L
s
1 0 0 r
.125 .01472 m
.125 .0276 L
.14063 .0276 L
.14063 .01472 L
F
0 g
.125 .01472 m
.125 .0276 L
.14063 .0276 L
.14063 .01472 L
.125 .01472 L
s
1 0 0 r
.14063 .01472 m
.14063 .04049 L
.15625 .04049 L
.15625 .01472 L
F
0 g
.14063 .01472 m
.14063 .04049 L
.15625 .04049 L
.15625 .01472 L
.14063 .01472 L
s
1 0 0 r
.15625 .01472 m
.15625 .04909 L
.17188 .04909 L
.17188 .01472 L
F
0 g
.15625 .01472 m
.15625 .04909 L
.17188 .04909 L
.17188 .01472 L
.15625 .01472 L
s
1 0 0 r
.17188 .01472 m
.17188 .03405 L
.1875 .03405 L
.1875 .01472 L
F
0 g
.17188 .01472 m
.17188 .03405 L
.1875 .03405 L
.1875 .01472 L
.17188 .01472 L
s
1 0 0 r
.1875 .01472 m
.1875 .0362 L
.20313 .0362 L
.20313 .01472 L
F
0 g
.1875 .01472 m
.1875 .0362 L
.20313 .0362 L
.20313 .01472 L
.1875 .01472 L
s
1 0 0 r
.20313 .01472 m
.20313 .04694 L
.21875 .04694 L
.21875 .01472 L
F
0 g
.20313 .01472 m
.20313 .04694 L
.21875 .04694 L
.21875 .01472 L
.20313 .01472 L
s
1 0 0 r
.21875 .01472 m
.21875 .05338 L
.23438 .05338 L
.23438 .01472 L
F
0 g
.21875 .01472 m
.21875 .05338 L
.23438 .05338 L
.23438 .01472 L
.21875 .01472 L
s
1 0 0 r
.23438 .01472 m
.23438 .05983 L
.25 .05983 L
.25 .01472 L
F
0 g
.23438 .01472 m
.23438 .05983 L
.25 .05983 L
.25 .01472 L
.23438 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .06842 L
.26563 .06842 L
.26563 .01472 L
F
0 g
.25 .01472 m
.25 .06842 L
.26563 .06842 L
.26563 .01472 L
.25 .01472 L
s
1 0 0 r
.26563 .01472 m
.26563 .07272 L
.28125 .07272 L
.28125 .01472 L
F
0 g
.26563 .01472 m
.26563 .07272 L
.28125 .07272 L
.28125 .01472 L
.26563 .01472 L
s
1 0 0 r
.28125 .01472 m
.28125 .08346 L
.29688 .08346 L
.29688 .01472 L
F
0 g
.28125 .01472 m
.28125 .08346 L
.29688 .08346 L
.29688 .01472 L
.28125 .01472 L
s
1 0 0 r
.29688 .01472 m
.29688 .09849 L
.3125 .09849 L
.3125 .01472 L
F
0 g
.29688 .01472 m
.29688 .09849 L
.3125 .09849 L
.3125 .01472 L
.29688 .01472 L
s
1 0 0 r
.3125 .01472 m
.3125 .08346 L
.32813 .08346 L
.32813 .01472 L
F
0 g
.3125 .01472 m
.3125 .08346 L
.32813 .08346 L
.32813 .01472 L
.3125 .01472 L
s
1 0 0 r
.32813 .01472 m
.32813 .11353 L
.34375 .11353 L
.34375 .01472 L
F
0 g
.32813 .01472 m
.32813 .11353 L
.34375 .11353 L
.34375 .01472 L
.32813 .01472 L
s
1 0 0 r
.34375 .01472 m
.34375 .19301 L
.35938 .19301 L
.35938 .01472 L
F
0 g
.34375 .01472 m
.34375 .19301 L
.35938 .19301 L
.35938 .01472 L
.34375 .01472 L
s
1 0 0 r
.35938 .01472 m
.35938 .17368 L
.375 .17368 L
.375 .01472 L
F
0 g
.35938 .01472 m
.35938 .17368 L
.375 .17368 L
.375 .01472 L
.35938 .01472 L
s
1 0 0 r
.375 .01472 m
.375 .22953 L
.39063 .22953 L
.39063 .01472 L
F
0 g
.375 .01472 m
.375 .22953 L
.39063 .22953 L
.39063 .01472 L
.375 .01472 L
s
1 0 0 r
.39063 .01472 m
.39063 .29828 L
.40625 .29828 L
.40625 .01472 L
F
0 g
.39063 .01472 m
.39063 .29828 L
.40625 .29828 L
.40625 .01472 L
.39063 .01472 L
s
1 0 0 r
.40625 .01472 m
.40625 .36487 L
.42188 .36487 L
.42188 .01472 L
F
0 g
.40625 .01472 m
.40625 .36487 L
.42188 .36487 L
.42188 .01472 L
.40625 .01472 L
s
1 0 0 r
.42188 .01472 m
.42188 .42502 L
.4375 .42502 L
.4375 .01472 L
F
0 g
.42188 .01472 m
.42188 .42502 L
.4375 .42502 L
.4375 .01472 L
.42188 .01472 L
s
1 0 0 r
.4375 .01472 m
.4375 .45724 L
.45313 .45724 L
.45313 .01472 L
F
0 g
.4375 .01472 m
.4375 .45724 L
.45313 .45724 L
.45313 .01472 L
.4375 .01472 L
s
1 0 0 r
.45313 .01472 m
.45313 .47443 L
.46875 .47443 L
.46875 .01472 L
F
0 g
.45313 .01472 m
.45313 .47443 L
.46875 .47443 L
.46875 .01472 L
.45313 .01472 L
s
1 0 0 r
.46875 .01472 m
.46875 .55821 L
.48438 .55821 L
.48438 .01472 L
F
0 g
.46875 .01472 m
.46875 .55821 L
.48438 .55821 L
.48438 .01472 L
.46875 .01472 L
s
1 0 0 r
.48438 .01472 m
.48438 .60332 L
.5 .60332 L
.5 .01472 L
F
0 g
.48438 .01472 m
.48438 .60332 L
.5 .60332 L
.5 .01472 L
.48438 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .59473 L
.51563 .59473 L
.51563 .01472 L
F
0 g
.5 .01472 m
.5 .59473 L
.51563 .59473 L
.51563 .01472 L
.5 .01472 L
s
1 0 0 r
.51563 .01472 m
.51563 .52169 L
.53125 .52169 L
.53125 .01472 L
F
0 g
.51563 .01472 m
.51563 .52169 L
.53125 .52169 L
.53125 .01472 L
.51563 .01472 L
s
1 0 0 r
.53125 .01472 m
.53125 .53028 L
.54688 .53028 L
.54688 .01472 L
F
0 g
.53125 .01472 m
.53125 .53028 L
.54688 .53028 L
.54688 .01472 L
.53125 .01472 L
s
1 0 0 r
.54688 .01472 m
.54688 .40569 L
.5625 .40569 L
.5625 .01472 L
F
0 g
.54688 .01472 m
.54688 .40569 L
.5625 .40569 L
.5625 .01472 L
.54688 .01472 L
s
1 0 0 r
.5625 .01472 m
.5625 .37346 L
.57813 .37346 L
.57813 .01472 L
F
0 g
.5625 .01472 m
.5625 .37346 L
.57813 .37346 L
.57813 .01472 L
.5625 .01472 L
s
1 0 0 r
.57813 .01472 m
.57813 .34768 L
.59375 .34768 L
.59375 .01472 L
F
0 g
.57813 .01472 m
.57813 .34768 L
.59375 .34768 L
.59375 .01472 L
.57813 .01472 L
s
1 0 0 r
.59375 .01472 m
.59375 .3305 L
.60938 .3305 L
.60938 .01472 L
F
0 g
.59375 .01472 m
.59375 .3305 L
.60938 .3305 L
.60938 .01472 L
.59375 .01472 L
s
1 0 0 r
.60938 .01472 m
.60938 .21664 L
.625 .21664 L
.625 .01472 L
F
0 g
.60938 .01472 m
.60938 .21664 L
.625 .21664 L
.625 .01472 L
.60938 .01472 L
s
1 0 0 r
.625 .01472 m
.625 .22524 L
.64063 .22524 L
.64063 .01472 L
F
0 g
.625 .01472 m
.625 .22524 L
.64063 .22524 L
.64063 .01472 L
.625 .01472 L
s
1 0 0 r
.64063 .01472 m
.64063 .15005 L
.65625 .15005 L
.65625 .01472 L
F
0 g
.64063 .01472 m
.64063 .15005 L
.65625 .15005 L
.65625 .01472 L
.64063 .01472 L
s
1 0 0 r
.65625 .01472 m
.65625 .13287 L
.67188 .13287 L
.67188 .01472 L
F
0 g
.65625 .01472 m
.65625 .13287 L
.67188 .13287 L
.67188 .01472 L
.65625 .01472 L
s
1 0 0 r
.67188 .01472 m
.67188 .10279 L
.6875 .10279 L
.6875 .01472 L
F
0 g
.67188 .01472 m
.67188 .10279 L
.6875 .10279 L
.6875 .01472 L
.67188 .01472 L
s
1 0 0 r
.6875 .01472 m
.6875 .09849 L
.70313 .09849 L
.70313 .01472 L
F
0 g
.6875 .01472 m
.6875 .09849 L
.70313 .09849 L
.70313 .01472 L
.6875 .01472 L
s
1 0 0 r
.70313 .01472 m
.70313 .08561 L
.71875 .08561 L
.71875 .01472 L
F
0 g
.70313 .01472 m
.70313 .08561 L
.71875 .08561 L
.71875 .01472 L
.70313 .01472 L
s
1 0 0 r
.71875 .01472 m
.71875 .07701 L
.73438 .07701 L
.73438 .01472 L
F
0 g
.71875 .01472 m
.71875 .07701 L
.73438 .07701 L
.73438 .01472 L
.71875 .01472 L
s
1 0 0 r
.73438 .01472 m
.73438 .05768 L
.75 .05768 L
.75 .01472 L
F
0 g
.73438 .01472 m
.73438 .05768 L
.75 .05768 L
.75 .01472 L
.73438 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .04479 L
.76563 .04479 L
.76563 .01472 L
F
0 g
.75 .01472 m
.75 .04479 L
.76563 .04479 L
.76563 .01472 L
.75 .01472 L
s
1 0 0 r
.76563 .01472 m
.76563 .05768 L
.78125 .05768 L
.78125 .01472 L
F
0 g
.76563 .01472 m
.76563 .05768 L
.78125 .05768 L
.78125 .01472 L
.76563 .01472 L
s
1 0 0 r
.78125 .01472 m
.78125 .05553 L
.79688 .05553 L
.79688 .01472 L
F
0 g
.78125 .01472 m
.78125 .05553 L
.79688 .05553 L
.79688 .01472 L
.78125 .01472 L
s
1 0 0 r
.79688 .01472 m
.79688 .04479 L
.8125 .04479 L
.8125 .01472 L
F
0 g
.79688 .01472 m
.79688 .04479 L
.8125 .04479 L
.8125 .01472 L
.79688 .01472 L
s
1 0 0 r
.8125 .01472 m
.8125 .04479 L
.82813 .04479 L
.82813 .01472 L
F
0 g
.8125 .01472 m
.8125 .04479 L
.82813 .04479 L
.82813 .01472 L
.8125 .01472 L
s
1 0 0 r
.82813 .01472 m
.82813 .03405 L
.84375 .03405 L
.84375 .01472 L
F
0 g
.82813 .01472 m
.82813 .03405 L
.84375 .03405 L
.84375 .01472 L
.82813 .01472 L
s
1 0 0 r
.84375 .01472 m
.84375 .03405 L
.85938 .03405 L
.85938 .01472 L
F
0 g
.84375 .01472 m
.84375 .03405 L
.85938 .03405 L
.85938 .01472 L
.84375 .01472 L
s
1 0 0 r
.85938 .01472 m
.85938 .03835 L
.875 .03835 L
.875 .01472 L
F
0 g
.85938 .01472 m
.85938 .03835 L
.875 .03835 L
.875 .01472 L
.85938 .01472 L
s
1 0 0 r
.875 .01472 m
.875 .03835 L
.89063 .03835 L
.89063 .01472 L
F
0 g
.875 .01472 m
.875 .03835 L
.89063 .03835 L
.89063 .01472 L
.875 .01472 L
s
1 0 0 r
.89063 .01472 m
.89063 .0362 L
.90625 .0362 L
.90625 .01472 L
F
0 g
.89063 .01472 m
.89063 .0362 L
.90625 .0362 L
.90625 .01472 L
.89063 .01472 L
s
1 0 0 r
.90625 .01472 m
.90625 .02975 L
.92188 .02975 L
.92188 .01472 L
F
0 g
.90625 .01472 m
.90625 .02975 L
.92188 .02975 L
.92188 .01472 L
.90625 .01472 L
s
1 0 0 r
.92188 .01472 m
.92188 .03405 L
.9375 .03405 L
.9375 .01472 L
F
0 g
.92188 .01472 m
.92188 .03405 L
.9375 .03405 L
.9375 .01472 L
.92188 .01472 L
s
1 0 0 r
.9375 .01472 m
.9375 .02975 L
.95313 .02975 L
.95313 .01472 L
F
0 g
.9375 .01472 m
.9375 .02975 L
.95313 .02975 L
.95313 .01472 L
.9375 .01472 L
s
1 0 0 r
.95313 .01472 m
.95313 .03405 L
.96875 .03405 L
.96875 .01472 L
F
0 g
.95313 .01472 m
.95313 .03405 L
.96875 .03405 L
.96875 .01472 L
.95313 .01472 L
s
1 0 0 r
.96875 .01472 m
.96875 .02331 L
.98438 .02331 L
.98438 .01472 L
F
0 g
.96875 .01472 m
.96875 .02331 L
.98438 .02331 L
.98438 .01472 L
.96875 .01472 L
s
1 0 0 r
.98438 .01472 m
.98438 .02331 L
1 .02331 L
1 .01472 L
F
0 g
.98438 .01472 m
.98438 .02331 L
1 .02331 L
1 .01472 L
.98438 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756.625, 467.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0001db000`400?l00000o`00003oo`38h=So
0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H
003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0
b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P0
0?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38
h=Sf0<SPf000;@38h=P500000080b>3H0P0000040<SPf08000008`38h=P500000080b>3H0P000004
0<SPf08000009`38h=P2000000@0b>3H0P00000W0<SPf08000001038h=P2000002X0b>3H0P000004
0<SPf08000009P38h=P500000080b>3H0P0000040<SPf08000008`38h=P500000080b>3H0P000004
0<SPf0800000@@38h=P2000000@0b>3H0P0000040<SPf08000008`38h=P4000000<0b>3H0P000004
0<SPf08000009038h=P500000080b>3H0P0000040<SPf08000009038h=P2000000@0b>3H0P00000V
0<SPf0D000000P38h=P2000000@0b>3H0P00000S0<SPf0@000000`38h=P2000000@0b>3H0P00000T
0<SPf08000001038h=P2000000@0b>3H0P00000F0<SPf000;`38h=P01@000000b>3H0<SPf038h=P0
00000080b>3H00<000000<SPf038h=P0:038h=P01@000000b>3H0<SPf038h=P000000080b>3H00<0
00000<SPf038h=P0:@38h=P010000000b>3H0<SPf000000[0<SPf00400000038h=P0b>3H000002h0
b>3H00@000000<SPf038h=P00000;@38h=P01@000000b>3H0<SPf038h=P000000080b>3H00<00000
0<SPf038h=P0:038h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P0@`38
h=P010000000b>3H0<SPf00000020<SPf00400000038h=P0b>3H000002P0b>3H00<000000<SPf038
h=P00`38h=P010000000b>3H0<SPf000000[0<SPf00500000038h=P0b>3H0<SPf00000000P38h=P0
0`000000b>3H0<SPf00V0<SPf00400000038h=P0b>3H000002d0b>3H00D000000<SPf038h=P0b>3H
000000020<SPf00300000038h=P0b>3H02H0b>3H00<000000<SPf038h=P00`38h=P010000000b>3H
0<SPf000000X0<SPf00400000038h=P0b>3H00000080b>3H00@000000<SPf038h=P000006`38h=P0
02l0b>3H00<000000<SPf038h=P01038h=P00`000000b>3H0<SPf00X0<SPf00500000038h=P0b>3H
0<SPf00000000P38h=P00`000000b>3H0<SPf00/0<SPf00300000038h=P0b>3H02T0b>3H00@00000
0<SPf038h=P00000<@38h=P00`000000b>3H0<SPf00[0<SPf00500000038h=P0b>3H0<SPf0000000
0P38h=P00`000000b>3H0<SPf00X0<SPf00300000038h=P0b>3H00@0b>3H00<000000<SPf038h=P0
A@38h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P09`38h=P00`000000
b>3H0<SPf0020<SPf00400000038h=P0b>3H000002/0b>3H00D000000<SPf038h=P0b>3H00000002
0<SPf00300000038h=P0b>3H02H0b>3H00@000000<SPf038h=P00000;@38h=P01@000000b>3H0<SP
f038h=P000000080b>3H00<000000<SPf038h=P09`38h=P00`000000b>3H0<SPf0020<SPf0040000
0038h=P0b>3H000002X0b>3H00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H
01T0b>3H000W0<SPf0@000001038h=P00`000000b>3H0<SPf0020<SPf08000008`38h=P4000000@0
b>3H00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H02<0b>3H100000030<SP
f0800000;038h=P010000000b>3H0<SPf000000_0<SPf0800000;P38h=P01@000000b>3H0<SPf038
h=P000000080b>3H00<000000<SPf038h=P0:038h=P00`000000b>3H0<SPf0020<SPf0800000@038
h=P4000000D0b>3H00@000000<SPf038h=P000000P38h=P00`000000b>3H0<SPf00P0<SPf0@00000
1038h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P08@38h=P4000000@0
b>3H00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H02H0b>3H00@000000<SP
f038h=P00000;@38h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P0:038
h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P0:@38h=P010000000b>3H
0<SPf00000020<SPf00300000038h=P0b>3H01T0b>3H000_0<SPf00300000038h=P0b>3H0080b>3H
00<000000<SPf038h=P0:P38h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038
h=P0:P38h=P00`000000b>3H0<SPf00[0<SPf00400000038h=P0b>3H000002l0b>3H00<000000<SP
f038h=P0;@38h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P0:038h=P0
0`000000b>3H0<SPf0020<SPf00300000038h=P0b>3H04D0b>3H00@000000<SPf038h=P000000P38
h=P010000000b>3H0<SPf000000X0<SPf00400000038h=P0b>3H00000080b>3H00@000000<SPf038
h=P00000:`38h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P09P38h=P0
10000000b>3H0<SPf000000]0<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H
0<SPf00V0<SPf00400000038h=P0b>3H00000080b>3H00@000000<SPf038h=P00000:038h=P01000
0000b>3H0<SPf00000020<SPf00400000038h=P0b>3H000001/0b>3H000^0<SPf08000001038h=P3
000002T0b>3H0P0000040<SPf0800000;@38h=P3000002`0b>3H0P00000`0<SPf0<00000;038h=P2
000000@0b>3H0P00000Z0<SPf08000001038h=P3000004H0b>3H0P0000040<SPf0800000:P38h=P2
000000@0b>3H0P00000[0<SPf08000001038h=P2000002X0b>3H0P00000]0<SPf08000001038h=P2
000002X0b>3H0P0000040<SPf0800000:P38h=P2000000@0b>3H0P00000L0<SPf000o`38h=So0<SP
f?H0b>3H000X0<SPf00300000038h=P0b>3H0?l0b>3HMP38h=P00`000000b>3H0<SPf03o0<SPf580
b>3H000X0<SPf00300000038h=P0b>3H0?l0b>3HMP38h=P00`000000b>3H0<SPf03o0<SPf580b>3H
000X0<SPf00300000038h=P0b>3H0?l0b>3HMP38h=P00`000000b>3H0<SPf03o0<SPf580b>3H000X
0<SPf00300000038h=P0b>3H0?l0b>3HMP38h=P00`000000b>3H0<SPf03o0<SPf580b>3H000X0<SP
f00300000038h=P0b>3H0?l0b>3HMP38h=P00`000000b>3H0<SPf03o0<SPf300b>3H00<000000<SP
f038h=P00P38h=P00`000000b>3H0<SPf0020<SPf00300000038h=P0b>3H01D0b>3H000X0<SPf?l0
0000@P00000g0<SPf?l00000@`00000B0<SPf000:038h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
0038h=P0b>3H03D0b>3H00<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000/00000
1038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o0006000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o000@000000@0o`0000<000000?l0003o0000
0P3o00000`000000b>3H0<SPf0020<SPf00300000038h=P0b>3H0080b>3H00<000000?l0003o0000
0P3o00000`000000b>3H0<SPf00@0<SPf000:038h=P00`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H03D0b>3H00<000000<SPf038h=P00P38h=P;000000@0o`001P00000>0<SPf0H00000103o
00000`000000o`000?l000020?l000H00000103o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`002`00000>0<SPf0030000003o0000o`000080o`001P0000040<SPf00300000038
h=P0b>3H0080b>3H1P00000B0<SPf000:038h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H03D0b>3H00<000000<SPf038h=P03038h=P6000001P0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0006
000000D0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H0080b>3H1P0000040?l000H000006038h=P00`000000o`000?l000020?l0000300000038h=P0
b>3H02@0b>3H000X0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0=@38h=P00`00
0000b>3H0<SPf00Z0<SPf0030000003o0000o`000080o`001P0000040<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0070<SPf0H000007@38h=P60000
02H0b>3H000X0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0=@38h=P3000002X0
b>3H1P0000090<SPf0H00000103o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000030?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000/00000F038h=P002P0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000b>3H0<SPf00e0<SPf00300000038h=P0b>3H03h0b>3H
1P0000040?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`00
0?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`001P0000040?l0000300000038h=P0b>3H0600b>3H
000X0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0=@38h=P00`000000b>3H0<SP
f0130<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f0020<SPf0030000003o0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f0020<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P0H038h=P002P0b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`001P00000g
0<SPf00300000038h=P0b>3H04<0b>3H2`0000040<SPf0030000003o0000o`0000<0o`001P000004
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf002
0<SPf0H00000HP38h=P002P0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o0006000000@0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SP
f038h=P0>P38h=P00`000000b>3H0<SPf01B0<SPf0030000003o0000o`0000<0o`0000<000000<SP
f038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf01Z0<SPf000:038h=P00`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf00j0<SPf003
00000038h=P0b>3H0580b>3H1`0000040<SPf0H00000103o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H06X0b>3H000X0<SPf0030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0
0P38h=P00`000000o`000?l000020?l000H00000103o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
0038h=P0b>3H03X0b>3H0`00001R0<SPf0030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`001P00001/0<SPf000:038
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`001P0000040?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf00j0<SPf00300000038
h=P0b>3H0680b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf01_0<SPf000:038h=P0
0`000000o`000?l000020?l000030000003o0000o`000080o`001P0000040?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H0080b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf00j0<SPf00300000038h=P0
b>3H0680b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf01_0<SPf000:038h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P60000
00@0o`001P0000040?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`00
0000b>3H0<SPf0020<SPf0030000003o0000o`000080o`001P0000040?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf00j0<SPf00300000038h=P0b>3H
0680b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf01_0<SPf000:038h=P;000000T0
b>3H1P0000040<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000
o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000
b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H03X0b>3H00<000000<SPf038h=P0HP38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H06l0b>3H000X0<SPf00300000038h=P0b>3H01/0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o0006000000@0o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`00
0?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0>P38h=P00`000000b>3H
0<SPf01R0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0K`38h=P002P0b>3H00<0
00000<SPf038h=P06`38h=P00`000000o`000?l000020?l000H000001038h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l0000300000038h=P0b>3H0080b>3H1P0000040?l0000300000038h=P0b>3H0080b>3H1P00
00040<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l0
00020?l000H00000103o00000`000000b>3H0<SPf00j0<SPf0<00000HP38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l0000300000038h=P0b>3H06l0b>3H000X0<SPf08000007038h=P00`000000o`000?l00002
0?l0000300000038h=P0b>3H00L0b>3H2`0000040?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P01`38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H00`0b>3H00<00000
0?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<00000
0<SPf038h=P00P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H03X0b>3H00<00000
0<SPf038h=P0HP38h=P6000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`001P0000040?l0000300000038h=P0b>3H06l0b>3H000X0<SP
f00300000038h=P0b>3H01/0b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf00A0<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`001P0000090<SPf0030000003o0000o`000080o`0000<000000<SP
f038h=P03038h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0
003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SP
f038h=P0>P38h=P00`000000b>3H0<SPf01W0<SPf0H00000103o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l0
000300000038h=P0b>3H06l0b>3H000X0<SPf00300000038h=P0b>3H01/0b>3H00<000000?l0003o
00000P3o00000`000000b>3H0<SPf00A0<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P03038h=P00`000000o`000?l000020?l0000300000038h=P0b>3H00`0b>3H00<000000?l0003o
00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SPf038
h=P00P38h=P6000003`0b>3H00<000000<SPf038h=P0K038h=P00`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf003
0000003o0000o`000080o`0000<000000<SPf038h=P0K`38h=P002P0b>3H00<000000<SPf038h=P0
6`38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0140b>3H00<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o0006000000@0o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf00<0<SPf0H00000
3P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o0000
0P3o00000`000000b>3H0<SPf0140<SPf00300000038h=P0b>3H06`0b>3H00<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0
0P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H06l0b>3H000X0<SPf00300000038
h=P0b>3H01/0b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf00A0<SPf0030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000H000008P38
h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o
00000`000000b>3H0<SPf0140<SPf0<00000K038h=P00`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o
0000o`000080o`0000<000000<SPf038h=P0K`38h=P002P0b>3H00<000000<SPf038h=P06`38h=P0
0`000000o`000?l000020?l0000300000038h=P0b>3H0140b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P09@38h=P0
0`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o0000
0`000000b>3H0<SPf0140<SPf00300000038h=P0b>3H06`0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P6
00000740b>3H000X0<SPf00300000038h=P0b>3H01/0b>3H1P00000C0<SPf0030000003o0000o`00
0080o`001P0000040?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`00
0000o`000?l000020?l0000300000038h=P0b>3H02D0b>3H1P0000040<SPf0H00000AP38h=P00`00
0000b>3H0<SPf01/0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l0000300000038h=P0b>3H07T0b>3H000X0<SPf00300000038h=P0b>3H03@0
b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080
o`001P0000040?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf0020<SPf0H00000O@38h=P00`000000b>3H0<SPf01/0<SPf0030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H07T0
b>3H000X0<SPf00300000038h=P0b>3H03@0b>3H00<000000?l0003o00000P3o00000`000000b>3H
0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf01g0<SPf08000001038h=P2000000H0b>3H00<000000<SPf038h=P0K038h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf01i0<SPf000:038h=P2000003D0b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SP
f0020<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f01f0<SPf00400000038h=P0b>3H00000080b>3H00@000000<SPf038h=P000001@38h=P00`000000
b>3H0<SPf01/0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H07T0b>3H000X0<SPf00300000038h=P0b>3H03@0b>3H
1P0000040<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P6000000@0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o0006000000@0o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf01i0<SPf00400000038h=P0b>3H00000080b>3H00<000000<SPf038h=P00`38h=P3000006`0
b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000H00000N`38h=P002P0b>3H
00<000000<SPf038h=P0?P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H00L0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H07L0b>3H
0P0000030<SPf00400000038h=P0b>3H000000D0b>3H00<000000<SPf038h=P0K038h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0OP38h=P002P0b>3H
00<000000<SPf038h=P0?P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H00L0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H07L0b>3H
00<000000<SPf038h=P00P38h=P010000000b>3H0<SPf00000050<SPf00300000038h=P0b>3H06`0
b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H07h0
b>3H000X0<SPf00300000038h=P0b>3H03h0b>3H00<000000?l0003o00000P3o00000`000000b>3H
0<SPf0070<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf0020<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf01g0<SPf0<000000`38h=P2000000H0b>3H00<000000<SPf038h=P0K038h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0OP38h=P002P0b>3H00<0
00000<SPf038h=P0?P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H00L0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H08D0b>3H00<0
00000<SPf038h=P0K038h=P6000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0OP38h=P002P0b>3H00<00000
0<SPf038h=P0?P38h=P6000000T0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o0006000008L0b>3H0`00001a
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0OP38h=P002P0b>3H00<000000<SP
f038h=P0C@38h=P6000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l0
000300000038h=P0b>3H08X0b>3H00<000000<SPf038h=P0L@38h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H07h0b>3H000X0<SPf00300000038h=P0b>3H0580b>3H00<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SPf038
h=P0RP38h=P00`000000b>3H0<SPf01a0<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000H00000P038h=P002P0b>3H0P00001C0<SPf0030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000
0038h=P0b>3H08X0b>3H00<000000<SPf038h=P0L@38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0230<SPf000:038
h=P00`000000b>3H0<SPf01B0<SPf0H00000103o00000`000000o`000?l000020?l000H00000103o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38
h=P00`000000o`000?l000020?l0000300000038h=P0b>3H08X0b>3H00<000000<SPf038h=P0L@38
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf0230<SPf000:038h=P00`000000b>3H0<SPf01G0<SPf0030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H0080b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf02:0<SPf00300000038h=P0
b>3H0740b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000<SPf038h=P0P`38h=P002P0b>3H00<000000<SPf038h=P0E`38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf0020<SPf0H00000S038h=P300000740b>3H00<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0P`38h=P002P0
b>3H00<000000<SPf038h=P0E`38h=P00`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02D0<SPf00300000038h=P0b>3H0740
b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000<SPf038h=P0P`38h=P002P0b>3H00<000000<SPf038h=P0E`38h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02D0<SPf00300000038h=P0b>3H0740b>3H1P0000040?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0P`38h=P002P0b>3H00<000000<SPf038h=P0E`38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02D0<SPf00300000038h=P0b>3H07H0b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0006000008D0b>3H000J
0<SPf08000001038h=P2000000H0b>3H00<000000<SPf038h=P0E`38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02D
0<SPf00300000038h=P0b>3H07H0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf028
0<SPf0006@38h=P010000000b>3H0<SPf00000020<SPf00400000038h=P0b>3H000000D0b>3H00<0
00000<SPf038h=P0E`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf02D0<SPf00300000038h=P0b>3H07H0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf0280<SPf0007038h=P010000000b>3H0<SPf000
00020<SPf00300000038h=P0b>3H00<0b>3H0`00001G0<SPf0030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H09@0b>3H0`00
001f0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0R038h=P001X0b>3H0P000003
0<SPf00400000038h=P0b>3H000000D0b>3H00<000000<SPf038h=P0E`38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02D0<SPf00300000038h=P0b>3H07H0b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f0280<SPf0006P38h=P00`000000b>3H0<SPf0020<SPf00400000038h=P0b>3H000000D0b>3H00<0
00000<SPf038h=P0E`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf02D0<SPf00300000038h=P0b>3H07H0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf0280<SPf0006P38h=P3000000<0b>3H0P000006
0<SPf00300000038h=P0b>3H05L0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0U038h=P00`000000b>3H0<SPf01f
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0R038h=P002P0b>3H00<000000<SP
f038h=P0E`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SP
f038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf02D0<SPf00300000038h=P0b>3H07H0b>3H00<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf0280<SPf000:038h=P00`000000b>3H0<SPf01G0<SPf003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H09@0b>3H0`00001f0<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P0R038h=P002P0b>3H00<000000<SPf038h=P0E`38h=P6000000@0o`0000<000000<SPf038h=P0
0P38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000b>3H0<SPf02D0<SPf00300000038h=P0b>3H07H0b>3H00<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000b>3H0<SPf0280<SPf000:038h=P00`000000b>3H0<SPf01L0<SPf0030000003o
0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000H00000103o
00000`000000b>3H0<SPf02D0<SPf00300000038h=P0b>3H07H0b>3H1P0000040?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0280<SPf000:038h=P0
0`000000b>3H0<SPf01L0<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P0
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H1P00002F0<SPf00300000038h=P0
b>3H07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000<SPf038h=P0R038h=P002P0b>3H0P00001M0<SPf0030000003o0000o`00
0080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
08T0b>3H1@0000020<SPf08000001038h=P2000000H0b>3H00<000000<SPf038h=P0N`38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf0280<SPf000:038h=P00`000000b>3H0<SPf01L0<SPf0030000003o0000o`000080
o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H08/0
b>3H00D000000<SPf038h=P0b>3H000000020<SPf00400000038h=P0b>3H00000080b>3H00<00000
0<SPf038h=P00`38h=P00`000000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o0006000008X0b>3H000X0<SPf00300000038h=P0b>3H05`0b>3H1P0000040<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0R`38h=P01@000000b>3H0<SPf038h=P0
00000080b>3H00@000000<SPf038h=P000000P38h=P00`000000b>3H0<SPf0030<SPf0<00000N`38
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0S@38
h=P002P0b>3H00<000000<SPf038h=P0IP38h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H08/0b>3H00D000000<SPf038h=P0b>3H000000020<SPf00400000038h=P0b>3H00000080b>3H
00<000000<SPf038h=P00`38h=P00`000000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000b>3H0<SPf02=0<SPf000:038h=P00`000000b>3H0<SP
f01V0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0R`38h=P01@000000b>3H0<SP
f038h=P000000080b>3H00@000000<SPf038h=P000000P38h=P00`000000b>3H0<SPf0030<SPf003
00000038h=P0b>3H07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H08d0b>3H000X0<SPf00300000038h=P0b>3H06H0b>3H00<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000b>3H0<SPf02:0<SPf08000001038h=P2000000@0b>3H0P0000060<SPf0030000
0038h=P0b>3H07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
0038h=P0b>3H08d0b>3H000X0<SPf00300000038h=P0b>3H06H0b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf02N0<SPf00300000038h=P0b>3H07/0b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l0000300000038h=P0b>3H08d0b>3H000X0<SPf00300000038h=P0
b>3H06H0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`001P00002P0<SPf00300000038h=P0b>3H07/0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l0000300000038h=P0b>3H08d0b>3H000X0<SPf00300000038h=P0b>3H
06H0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0X`38h=P3000007/0b>3H00<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l0000300000038h=P0b>3H08d0b>3H000X0<SPf0800000I`38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf02S0<SPf00300000038h=P0b>3H07/0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H08d0b>3H000X0<SPf00300000038h=P0b>3H06H0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0X`38h=P00`000000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
1P00002?0<SPf000:038h=P00`000000b>3H0<SPf01V0<SPf0030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:<0b>3H00<0
00000<SPf038h=P0N`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0980b>3H000X
0<SPf00300000038h=P0b>3H06H0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X`38h=P00`000000b>3H0<SPf01k
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0TP38h=P002P0b>3H00<000000<SP
f038h=P0IP38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf02S0<SPf0<00000N`38h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H0980b>3H000X0<SPf00300000038h=P0b>3H06H0b>3H00<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P0X`38h=P00`000000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P0TP38h=P002P0b>3H00<000000<SPf038h=P0IP38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02S0<SPf0030000
0038h=P0b>3H07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02B0<SPf000:038
h=P00`000000b>3H0<SPf01V0<SPf0/00000103o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02S0<SPf00300000038
h=P0b>3H07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02B0<SPf000:038h=P0
0`000000b>3H0<SPf01`0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000H00000Y@38h=P00`000000b>3H0<SPf01k0<SPf0H00000103o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0TP38h=P0
02P0b>3H00<000000<SPf038h=P0L038h=P00`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02X0<SPf00300000038h=P0b>3H
0800b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0TP38h=P002P0b>3H0P00001a0<SPf0H00000103o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H0:P0b>3H0`0000200<SPf0030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0980
b>3H000X0<SPf00300000038h=P0b>3H07D0b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H0:P0b>3H00<000000<SPf038h=P0P038h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02B0<SPf000:038h=P00`000000b>3H0<SPf01e0<SPf0030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf02X0<SPf00300000038h=P0b>3H0800b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000<SPf038h=P0TP38h=P002P0b>3H00<000000<SPf038h=P0M@38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0Z038h=P00`000000b>3H0<SPf020
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0980b>3H000X0<SPf00300000038h=P0b>3H07D0b>3H00<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:P0b>3H00<000000<SP
f038h=P0P038h=P6000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02B0<SP
f000:038h=P00`000000b>3H0<SPf01e0<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000b>3H0<SPf02X0<SPf0<00000Q@38h=P00`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000<SPf038h=P0TP38h=P002P0b>3H00<000000<SPf038h=P0
M@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0
Z038h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000b>3H0<SPf02B0<SPf000:038h=P00`000000b>3H0<SPf01e0<SPf0030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02X0<SPf00300000038
h=P0b>3H08D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H0980b>3H000X0<SPf00300000038h=P0b>3H07D0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l0000300000038h=P0b>3H0:P0b>3H00<000000<SPf038h=P0Q@38h=P0
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0TP38h=P0
02P0b>3H0P00001f0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf02C0<SPf0D000000P38h=P2000000@0b>3H0P0000060<SPf00300000038h=P0b>3H
08D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
0980b>3H000X0<SPf00300000038h=P0b>3H07D0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H09D0b>3H00D000000<SPf038h=P0b>3H000000020<SP
f00400000038h=P0b>3H00000080b>3H00<000000<SPf038h=P00`38h=P00`000000b>3H0<SPf025
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02B
0<SPf000:038h=P00`000000b>3H0<SPf01e0<SPf0030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf02E0<SPf00300000038h=P0b>3H00@0b>3H00@000000<SP
f038h=P000000P38h=P00`000000b>3H0<SPf0030<SPf0<00000Q@38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0TP38h=P002P0b>3H00<000000<SP
f038h=P0M@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SP
f038h=P0U@38h=P00`000000b>3H0<SPf0020<SPf08000000`38h=P010000000b>3H0<SPf0000005
0<SPf00300000038h=P0b>3H08D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0980b>3H000X0<SPf00300000038h=P0b>3H07D0b>3H00<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H09D0b>3H00<000000<SP
f038h=P00P38h=P00`000000b>3H0<SPf0020<SPf00400000038h=P0b>3H000000D0b>3H00<00000
0<SPf038h=P0Q@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0TP38h=P002P0b>3H00<000000<SPf038h=P0M@38h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0U038h=P2000000@0b>3H0`0000030<SP
f08000001P38h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf02B0<SPf000:038h=P00`000000b>3H0<SPf01e0<SPf003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02X0<SPf003
00000038h=P0b>3H08D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H0980b>3H000C0<SPf0D000000P38h=P2000000@0b>3H0P0000060<SPf0030000
0038h=P0b>3H07D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
0038h=P0b>3H0:P0b>3H00<000000<SPf038h=P0Q@38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000<SPf038h=P0TP38h=P001D0b>3H00D000000<SPf038h=P0b>3H
000000020<SPf00400000038h=P0b>3H00000080b>3H00<000000<SPf038h=P00`38h=P00`000000
b>3H0<SPf01e0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf02X0<SPf0<00000Q@38h=P00`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000<SPf038h=P0TP38h=P001D0b>3H00D000000<SPf038h=P0b>3H000000020<SPf004
00000038h=P0b>3H00000080b>3H00<000000<SPf038h=P00`38h=P3000007D0b>3H00<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`001P0000040?l0
000300000038h=P0b>3H0:P0b>3H00<000000<SPf038h=P0Q@38h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00H00000U038h=P001D0b>3H00D000000<SPf038h=P0b>3H000000020<SPf00400000038h=P0b>3H
00000080b>3H00<000000<SPf038h=P00`38h=P00`000000b>3H0<SPf01e0<SPf0030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H0080b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf02X0<SPf00300000038h=P0
b>3H08D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02G0<SPf0005@38h=P01@00
0000b>3H0<SPf038h=P000000080b>3H00@000000<SPf038h=P000000P38h=P00`000000b>3H0<SP
f0030<SPf00300000038h=P0b>3H07D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l0
00020?l0000300000038h=P0b>3H0:P0b>3H00<000000<SPf038h=P0Q@38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l0000300000038h=P0b>3H09L0b>3H000D0<SPf08000001038h=P2000000@0b>3H0P000006
0<SPf00300000038h=P0b>3H07D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l00002
0?l0000300000038h=P0b>3H0:P0b>3H00<000000<SPf038h=P0Q@38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H09L0b>3H000X0<SPf00300000038h=P0b>3H07D0b>3H00<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SP
f038h=P00P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0:P0b>3H0`0000250<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0U`38h=P002P0b>3H00<000000<SPf038
h=P0M@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SPf038
h=P0Z038h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000H00000V@38h=P002P0b>3H00<000000<SPf038h=P0
M@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P0
Z038h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H09`0b>3H000X0<SPf00300000038
h=P0b>3H07D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000<SPf038h=P00P38h=P600000:X0b>3H00<000000<SPf038h=P0Q@38
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf02L0<SPf000:038h=P00`000000b>3H0<SPf01e0<SPf0030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H0;80b>3H00<000000<SPf038h=P0Q@38h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02L0<SPf000:038h=P20000
07H0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0/P38h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
09`0b>3H000X0<SPf00300000038h=P0b>3H07D0b>3H1P0000040?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000<SPf038h=P0/P38h=P3000008D0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0W038h=P002P0b>3H
00<000000<SPf038h=P0NP38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0/P38h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H09`0b>3H
000X0<SPf00300000038h=P0b>3H07X0b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l0000300000038h=P0b>3H0;80b>3H00<000000<SPf038h=P0Q@38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02L0<SPf000:038h=P00`000000b>3H0<SPf01j0<SPf0030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000b>3H0<SPf02b0<SPf00300000038h=P0b>3H08D0b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0W038h=P002P0b>3H00<000000<SPf038h=P0NP38h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0/P38h=P00`000000b>3H0<SPf0250<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H09`0b>3H000X0<SPf00300000038h=P0b>3H07X0b>3H00<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0;80b>3H00<000000<SPf038
h=P0Q@38h=P6000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02L0<SPf000
:038h=P00`000000b>3H0<SPf01j0<SPf0030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000b>3H0<SPf02b0<SPf0<00000RP38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000<SPf038h=P0W038h=P002P0b>3H00<000000<SPf038h=P0NP38
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0/P38
h=P00`000000b>3H0<SPf02:0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf02L0<SPf000:038h=P2000007/0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0006
00000;@0b>3H00<000000<SPf038h=P0RP38h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000<SPf038h=P0W038h=P002P0b>3H00<000000<SPf038h=P0NP38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l0000300000038h=P0b>3H0:80b>3H100000030<SPf08000001038h=P20000
00H0b>3H00<000000<SPf038h=P0RP38h=P00`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0W038h=P002P0b>3H00<000000<SPf038h=P0NP38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H0:80b>3H00<000000<SPf038h=P00`38h=P010000000
b>3H0<SPf00000020<SPf00400000038h=P0b>3H000000D0b>3H00<000000<SPf038h=P0RP38h=P0
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0W038h=P0
02P0b>3H00<000000<SPf038h=P0NP38h=P00`000000o`000?l000020?l000H00000103o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l0000300000038h=P0b>3H0:<0b>3H00<000000<SPf038h=P00P38h=P01000
0000b>3H0<SPf00000020<SPf00400000038h=P0b>3H000000D0b>3H0`00002:0<SPf0030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02L0<SPf000:038h=P0
0`000000b>3H0<SPf01j0<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P0
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0Y038h=P0
1@000000b>3H0<SPf038h=P000000080b>3H00@000000<SPf038h=P000000P38h=P00`000000b>3H
0<SPf0030<SPf00300000038h=P0b>3H08X0b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H09`0b>3H000X0<SPf00300000038h=P0b>3H07X0b>3H00<0
00000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf02R0<SPf00400000038h=P0b>3H00000080b>3H
00@000000<SPf038h=P000000P38h=P010000000b>3H0<SPf00000050<SPf00300000038h=P0b>3H
08X0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
09`0b>3H000X0<SPf00300000038h=P0b>3H07X0b>3H00<000000?l0003o00000P3o00000`000000
b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf02S0<SPf08000001038h=P2000000@0b>3H0P0000060<SPf00300000038h=P0b>3H08X0
b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H09`0
b>3H000X0<SPf00300000038h=P0b>3H07X0b>3H00<000000?l0003o00000P3o00000`000000b>3H
0<SPf0020<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02g0<SPf00300000038h=P0b>3H08X0b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H09`0b>3H000X0<SPf00300000038h=P0b>3H07X0b>3H00<0
00000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf02g0<SPf00300000038h=P0b>3H08X0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H09`0b>3H000X
0<SPf0800000N`38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0;L0b>3H0`00002:
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02L
0<SPf000:038h=P00`000000b>3H0<SPf01j0<SPf0H000001038h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0]`38h=P00`000000b>3H0<SPf02:0<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02L0<SP
f000:038h=P00`000000b>3H0<SPf0240<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000b>3H0<SPf02g0<SPf00300000038h=P0b>3H08X0b>3H00<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H09`0b>3H000X0<SPf0030000
0038h=P0b>3H08@0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
0038h=P0b>3H0;L0b>3H00<000000<SPf038h=P0RP38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000<SPf038h=P0W038h=P002P0b>3H00<000000<SPf038h=P0Q038
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0]`38
h=P00`000000b>3H0<SPf02:0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf02L0<SPf000:038h=P00`000000b>3H0<SPf0240<SPf0030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02g0<SPf00300000038h=P0
b>3H08X0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H09`0b>3H000X0<SPf00300000038h=P0b>3H08@0b>3H00<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`001P0000040?l0000300000038h=P0b>3H
0;L0b>3H0`00002:0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf02L0<SPf000:038h=P00`000000b>3H0<SPf0240<SPf0030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0080
b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf02g0<SPf00300000038h=P0b>3H08X0
b>3H1P0000040?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0006000009h0
b>3H000X0<SPf00300000038h=P0b>3H08@0b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`00
0?l000020?l0000300000038h=P0b>3H0;L0b>3H00<000000<SPf038h=P0S`38h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02Q0<SPf000:038h=P2000008D0b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l0
00020?l0000300000038h=P0b>3H0;L0b>3H00<000000<SPf038h=P0S`38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02Q0<SPf000:038h=P00`000000b>3H0<SPf0240<SPf0030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<00000
0?l0003o00000P3o00000`000000b>3H0<SPf02g0<SPf00300000038h=P0b>3H08l0b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0X@38h=P002P0b>3H00<000000<SPf038h=P0Q038h=P6000000@0o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SP
f038h=P0]`38h=P3000008l0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P002P0b>3H00<000000<SPf038
h=P0R@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P00P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0;L0b>3H00<000000<SPf038
h=P0S`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000b>3H0<SPf02Q0<SPf000:038h=P00`000000b>3H0<SPf0290<SPf0030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000
003o0000o`000080o`0000<000000<SPf038h=P0]`38h=P00`000000b>3H0<SPf02?0<SPf0030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
0038h=P0b>3H0:40b>3H000X0<SPf00300000038h=P0b>3H08T0b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o
00000`000000b>3H0<SPf02g0<SPf00300000038h=P0b>3H08l0b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38
h=P002P0b>3H00<000000<SPf038h=P0R@38h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l0000300000038h=P0
b>3H0;L0b>3H00<000000<SPf038h=P0S`38h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02Q0<SPf0004`38h=P50000
0080b>3H0P0000040<SPf08000001P38h=P00`000000b>3H0<SPf0290<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`00
0080o`0000<000000<SPf038h=P0]`38h=P00`000000b>3H0<SPf02?0<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
0:40b>3H000E0<SPf00500000038h=P0b>3H0<SPf00000000P38h=P010000000b>3H0<SPf0000002
0<SPf00300000038h=P0b>3H00<0b>3H00<000000<SPf038h=P0R@38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P600000;T0b>3H0`00002?
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0:40b>3H000E0<SPf00300000038h=P0b>3H00@0b>3H00@000000<SP
f038h=P000000P38h=P00`000000b>3H0<SPf0030<SPf0<00000R@38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0`@38h=P00`000000b>3H0<SPf02?
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0:40b>3H000E0<SPf00300000038h=P0b>3H0080b>3H0P0000030<SP
f00400000038h=P0b>3H000000D0b>3H00<000000<SPf038h=P0R@38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0`@38h=P00`000000b>3H0<SPf02?
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0:40b>3H000E0<SPf00300000038h=P0b>3H0080b>3H00<000000<SP
f038h=P00P38h=P010000000b>3H0<SPf00000050<SPf00300000038h=P0b>3H08T0b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:`0b>3H10000003
0<SPf08000001038h=P2000000H0b>3H00<000000<SPf038h=P0S`38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02Q
0<SPf0005038h=P2000000@0b>3H0`0000030<SPf08000001P38h=P00`000000b>3H0<SPf0290<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02/0<SP
f00300000038h=P0b>3H00<0b>3H00@000000<SPf038h=P000000P38h=P010000000b>3H0<SPf000
00050<SPf00300000038h=P0b>3H08l0b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P002P0b>3H00<00000
0<SPf038h=P0R@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0[@38h=P00`000000b>3H0<SPf0050<SPf00400000038h=P0b>3H00000080b>3H00<0
00000<SPf038h=P00`38h=P3000008l0b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000H00000X`38h=P002P0b>3H00<000000<SPf038h=P0R@38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0[P38h=P00`000000b>3H0<SPf002
0<SPf08000000`38h=P010000000b>3H0<SPf00000050<SPf00300000038h=P0b>3H08l0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:H0b>3H000X
0<SPf00300000038h=P0b>3H08T0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0:`0b>3H00@000000<SPf038h=P000000`38h=P00`000000b>3H0<SP
f0020<SPf00400000038h=P0b>3H000000D0b>3H00<000000<SPf038h=P0S`38h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0YP38h=P002P0b>3H00<0
00000<SPf038h=P0R@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000<SPf038h=P0[@38h=P2000000@0b>3H0`0000030<SPf08000001P38h=P00`000000b>3H0<SP
f02?0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02V0<SPf000:038h=P00`000000b>3H0<SPf0290<SPf0030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000b>3H0<SPf0310<SPf00300000038h=P0b>3H08l0b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:H0b>3H000X0<SP
f0800000RP38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SP
f038h=P0`@38h=P00`000000b>3H0<SPf02?0<SPf0030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf02V0<SPf000:038h=P00`000000b>3H0<SPf0290<SPf003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0310<SPf0<0
0000S`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P0YP38h=P002P0b>3H00<000000<SPf038h=P0R@38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000<SPf038h=P0`@38h=P00`000000b>3H0<SPf02?0<SPf0030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02V0<SPf000:038
h=P00`000000b>3H0<SPf0290<SPf0H00000103o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0310<SPf00300000038
h=P0b>3H08l0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H0:H0b>3H000X0<SPf00300000038h=P0b>3H08h0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000b>3H0<SPf0310<SPf00300000038h=P0b>3H08l0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l0000300000038h=P0b>3H0:H0b>3H000X0<SPf00300000038h=P0b>3H
08h0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0310<SPf00300000038h=P0b>3H
08l0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
0:H0b>3H000X0<SPf00300000038h=P0b>3H08h0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf0310<SPf00300000038h=P0b>3H08l0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H0:H0b>3H000X0<SPf00300000038h=P0b>3H08h0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000b>3H0<SPf0310<SPf0<00000S`38h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0YP38h=P002P0b>3H00<0
00000<SPf038h=P0SP38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`001P00
00040?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l0000300000038h=P0b>3H0<40b>3H00<000000<SPf038h=P0S`38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0YP38h=P002P0b>3H00<00000
0<SPf038h=P0SP38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0<40b>3H00<00000
0<SPf038h=P0S`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0YP38h=P002P0b>3H0P00002?0<SPf0030000003o0000o`000080o`001P0000040<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0`@38h=P00`000000b>3H0<SPf02?0<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02V0<SP
f000:038h=P00`000000b>3H0<SPf02>0<SPf0030000003o0000o`000080o`0000<000000<SPf038
h=P01`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o000600000<<0b>3H00<000000<SPf038h=P0S`38h=P00`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000<SPf038h=P0YP38h=P002P0b>3H00<000000<SPf038h=P0
SP38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H00L0b>3H00<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0
aP38h=P3000008l0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
0038h=P0b>3H0:H0b>3H000X0<SPf00300000038h=P0b>3H08h0b>3H00<000000?l0003o00000P3o
00000`000000b>3H0<SPf0070<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l0000300000038h=P0b>3H0<H0b>3H00<000000<SPf038h=P0S`38
h=P6000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000<SPf038h=P0YP38h=P002P0b>3H00<000000<SPf038h=P0SP38h=P0
0`000000o`000?l000020?l0000300000038h=P0b>3H00L0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0aP38h=P0
0`000000b>3H0<SPf02D0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0YP38h=P0
02P0b>3H00<000000<SPf038h=P0SP38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H
00L0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0aP38h=P00`000000b>3H0<SPf02D0<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0YP38h=P002P0b>3H00<000000<SPf038h=P0SP38h=P00`000000
o`000?l000020?l0000300000038h=P0b>3H00L0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0aP38h=P00`000000
b>3H0<SPf02D0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0YP38h=P002P0b>3H
00<000000<SPf038h=P0SP38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H00L0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0aP38h=P00`000000b>3H0<SPf02D0<SPf0030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0YP38h=P002P0b>3H00<000000<SPf038h=P0SP38h=P00`000000o`000?l0
00020?l0000300000038h=P0b>3H00L0b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0aP38h=P3000009@0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf02V0<SPf000:038h=P2000008l0b>3H00<00000
0?l0003o00000P3o00000`000000b>3H0<SPf0070<SPf0030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0<H0b>3H00<00000
0<SPf038h=P0U038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:H0b>3H000X0<SP
f00300000038h=P0b>3H08h0b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf0070<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H0<H0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H0:H0b>3H000X0<SPf00300000038h=P0b>3H08h0b>3H1P0000090<SPf003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H0<H0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H0:H0b>3H000X0<SPf00300000038h=P0b>3H09d0b>3H00<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0
/P38h=P2000000@0b>3H0P0000040<SPf08000001P38h=P00`000000b>3H0<SPf02D0<SPf0030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000<SPf038h=P0YP38h=P002P0b>3H00<000000<SPf038h=P0W@38
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf02a0<SPf00400000038h=P0b>3H00000080b>3H00@000000<SPf038h=P0
00000P38h=P010000000b>3H0<SPf00000050<SPf00300000038h=P0b>3H09@0b>3H00<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf02V0<SPf000:038h=P00`000000b>3H0<SPf02M0<SPf003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H0;<0b>3H00D000000<SPf038h=P0b>3H000000020<SPf00400000038h=P0b>3H
00000080b>3H00<000000<SPf038h=P00`38h=P3000009@0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000b>3H0<SPf02V0<SPf000:038h=P00`000000b>3H0<SPf02M0<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
0;@0b>3H00@000000<SPf038h=P000000P38h=P010000000b>3H0<SPf00000020<SPf00300000038
h=P0b>3H00<0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H0:H0b>3H000X0<SPf00300000038h=P0b>3H09d0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0/@38h=P0
10000000b>3H0<SPf00000020<SPf00400000038h=P0b>3H00000080b>3H00@000000<SPf038h=P0
00001@38h=P00`000000b>3H0<SPf02D0<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P0YP38h=P002P0b>3H00<000000<SPf038h=P0W@38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02b0<SPf0800000
1038h=P2000000@0b>3H0P0000060<SPf00300000038h=P0b>3H09@0b>3H00<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`001P00002X0<SPf000:038
h=P2000009h0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000<SPf038h=P0aP38h=P00`000000b>3H0<SPf02D0<SPf0030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H0:/0b>3H000X0<SPf00300000038h=P0b>3H09d0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0aP38h=P3
000009@0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000<SPf038h=P0Z`38h=P002P0b>3H00<000000<SPf038h=P0W@38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf0360<SPf00300000038h=P0b>3H09@0b>3H00<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0Z`38h=P002P0
b>3H00<000000<SPf038h=P0W@38h=P00`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0360<SPf00300000038h=P0b>3H09@0
b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000<SPf038h=P0Z`38h=P002P0b>3H00<000000<SPf038h=P0W@38h=P6000000@0o`00
00<000000?l0003o00000P3o00000`000000b>3H0<SPf0360<SPf00300000038h=P0b>3H09@0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0Z`38h=P002P0b>3H00<000000<SPf038h=P0XP38h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0aP38h=P00`000000b>3H0<SP
f02D0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l0000300000038h=P0b>3H0:/0b>3H000X0<SPf00300000038h=P0b>3H0:80b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0<H0b>3H00<00000
0<SPf038h=P0U038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000b>3H0<SPf02[0<SPf0004`38h=P4000000<0b>3H0P0000040<SP
f08000001P38h=P00`000000b>3H0<SPf02R0<SPf0030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf0360<SPf0<00000U038h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02[0<SP
f0004`38h=P00`000000b>3H0<SPf0030<SPf00400000038h=P0b>3H00000080b>3H00@000000<SP
f038h=P000001@38h=P00`000000b>3H0<SPf02R0<SPf0030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000b>3H0<SPf0360<SPf00300000038h=P0b>3H09@0b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0Z`38h=P001@0b>3H00<000000<SPf038h=P00P38h=P010000000b>3H0<SPf0000002
0<SPf00400000038h=P0b>3H000000D0b>3H0`00002R0<SPf0030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf0360<SPf00300000038h=P0b>3H09@0b>3H1P00
00040?l000030000003o0000o`000080o`0000<000000<SPf038h=P0Z`38h=P001D0b>3H00D00000
0<SPf038h=P0b>3H000000020<SPf00400000038h=P0b>3H00000080b>3H00<000000<SPf038h=P0
0`38h=P00`000000b>3H0<SPf02R0<SPf0030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000b>3H0<SPf0360<SPf00300000038h=P0b>3H09T0b>3H00<000000?l0003o0000
0P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:/0b>3H000C0<SPf00400000038
h=P0b>3H00000080b>3H00@000000<SPf038h=P000000P38h=P010000000b>3H0<SPf00000050<SP
f00300000038h=P0b>3H0:80b>3H1P0000040?l0000300000038h=P0b>3H0<H0b>3H00<000000<SP
f038h=P0V@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SP
f038h=P0Z`38h=P001@0b>3H0P0000040<SPf08000001038h=P2000000H0b>3H00<000000<SPf038
h=P0Y`38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0<H0b>3H0`00002I0<SPf0H0
0000103o00000`000000b>3H0<SPf02[0<SPf000:038h=P00`000000b>3H0<SPf02W0<SPf0030000
003o0000o`000080o`0000<000000<SPf038h=P0aP38h=P00`000000b>3H0<SPf02N0<SPf0030000
003o0000o`000080o`0000<000000<SPf038h=P0Z`38h=P002P0b>3H00<000000<SPf038h=P0Y`38
h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0<H0b>3H00<000000<SPf038h=P0WP38
h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0:/0b>3H000X0<SPf00300000038h=P0
b>3H0:L0b>3H1P0000380<SPf00300000038h=P0b>3H09h0b>3H1P00002]0<SPf000:038h=P00`00
0000b>3H0<SPf03o0<SPf7H0b>3H00<000000<SPf038h=P0o`38h=QB0<SPf000:038h=P00`000000
b>3H0<SPf03o0<SPf7H0b>3H00<000000<SPf038h=P0o`38h=QB0<SPf000:038h=P200000?l0b>3H
M`38h=P300000?l0b>3HDP38h=P002P0b>3H00<000000<SPf038h=P0o`38h=Qf0<SPf00300000038
h=P0b>3H0?l0b>3HDP38h=P002P0b>3H00<000000<SPf038h=P0o`38h=Qf0<SPf00300000038h=P0
b>3H0?l0b>3HDP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3H
mP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0
b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf
0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38
h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0
b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SP
f?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38
h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf:H0b>3H1@0000020<SPf080
00001038h=P2000002<0b>3H1@0000020<SPf08000001038h=P2000002P0b>3H0P0000040<SPf080
00009`38h=P2000000@0b>3H0P00000Z0<SPf08000001038h=P2000002H0b>3H1@0000020<SPf080
00001038h=P2000002<0b>3H1@0000020<SPf08000001038h=P2000001H0b>3H003o0<SPf:P0b>3H
00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H02P0b>3H00D000000<SPf038
h=P0b>3H000000020<SPf00300000038h=P0b>3H02X0b>3H00@000000<SPf038h=P00000:`38h=P0
10000000b>3H0<SPf000000^0<SPf00400000038h=P0b>3H000002d0b>3H00D000000<SPf038h=P0
b>3H000000020<SPf00300000038h=P0b>3H02P0b>3H00D000000<SPf038h=P0b>3H000000020<SP
f00300000038h=P0b>3H01T0b>3H003o0<SPf:P0b>3H00<000000<SPf038h=P01038h=P00`000000
b>3H0<SPf00X0<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00]0<SP
f00300000038h=P0b>3H02T0b>3H00@000000<SPf038h=P00000<@38h=P00`000000b>3H0<SPf00[
0<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00X0<SPf00300000038
h=P0b>3H00@0b>3H00<000000<SPf038h=P06@38h=P00?l0b>3HX038h=P4000000@0b>3H00<00000
0<SPf038h=P00P38h=P2000002<0b>3H100000040<SPf00500000038h=P0b>3H0<SPf00000000P38
h=P00`000000b>3H0<SPf00T0<SPf0@000000`38h=P2000002`0b>3H00@000000<SPf038h=P00000
;`38h=P2000002h0b>3H00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H02P0
b>3H00<000000<SPf038h=P00P38h=P2000001`0b>3H003o0<SPf:P0b>3H00<000000<SPf038h=P0
0P38h=P00`000000b>3H0<SPf00Z0<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000
b>3H0<SPf00[0<SPf00300000038h=P0b>3H02/0b>3H00@000000<SPf038h=P00000;`38h=P00`00
0000b>3H0<SPf00]0<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00X
0<SPf00300000038h=P0b>3H0080b>3H00<000000<SPf038h=P06`38h=P00?l0b>3HY`38h=P20000
00@0b>3H0`00000Y0<SPf08000001038h=P2000002h0b>3H0`00000/0<SPf0800000<038h=P30000
02`0b>3H0P0000040<SPf0800000:P38h=P2000000@0b>3H0`00000K0<SPf000o`38h=So0<SPf?H0
b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3HX@38h=P00`000000b>3H0<SPf03o0<SPf580b>3H003o
0<SPf:40b>3H00<000000<SPf038h=P0o`38h=QB0<SPf000o`38h=RQ0<SPf00300000038h=P0b>3H
0?l0b>3HDP38h=P007D0b>3H0P0000040<SPf08000000`38h=P01P000000b>3H0<SPf038h=P00000
0<SPf0D000000P38h=P2000002H0b>3H1@0000020<SPf08000000`38h=P01P000000b>3H0<SPf038
h=P000000<SPf0D000000P38h=P2000002<0b>3H1@0000020<SPf08000001038h=P2000000<0b>3H
00H000000<SPf038h=P0b>3H00000038h=P500000080b>3H0P00000R0<SPf0@000000`38h=P20000
00<0b>3H00H000000<SPf038h=P0b>3H00000038h=P500000080b>3H0P00001?0<SPf00300000038
h=P0b>3H0?l0b>3HDP38h=P007@0b>3H00@000000<SPf038h=P000002@38h=P00`000000b>3H0000
00040<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00U0<SPf0030000
0038h=P0b>3H00P0b>3H00<000000<SPf00000001038h=P01@000000b>3H0<SPf038h=P000000080
b>3H00<000000<SPf038h=P08P38h=P00`000000b>3H0<SPf0070<SPf00400000038h=P0b>3H0000
00<0b>3H00<000000<SPf00000001038h=P01@000000b>3H0<SPf038h=P000000080b>3H00<00000
0<SPf038h=P07`38h=P00`000000b>3H0<SPf00:0<SPf00300000038h=P0000000@0b>3H00D00000
0<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H04`0b>3Ho`00001300000180b>3H001g
0<SPf00300000038h=P0b>3H00P0b>3H00<000000<SPf038h=P00`38h=P01@000000b>3H0<SPf038
h=P000000080b>3H00<000000<SPf038h=P09@38h=P00`000000b>3H0<SPf0090<SPf00300000038
h=P0b>3H00<0b>3H00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H0280b>3H
00<000000<SPf038h=P02P38h=P00`000000b>3H0<SPf0020<SPf00300000038h=P0b>3H00<0b>3H
00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H0200b>3H00<000000<SPf038
h=P02P38h=P00`000000b>3H0<SPf0030<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`00
0000b>3H0<SPf01<0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P04038h=P007D0
b>3H0P00000:0<SPf00300000038h=P0000000@0b>3H00D000000<SPf038h=P0b>3H000000020<SP
f00300000038h=P0b>3H02D0b>3H00<000000<SPf038h=P02038h=P00`000000b>3H000000040<SP
f00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00R0<SPf00300000038h=P0
b>3H00P0b>3H0P0000040<SPf00300000038h=P0000000@0b>3H00D000000<SPf038h=P0b>3H0000
00020<SPf00300000038h=P0b>3H0240b>3H00<000000<SPf038h=P02038h=P00`000000b>3H0000
00040<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf01<0<SPf0030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000<SPf038h=P04038h=P007D0b>3H00<000000<SPf038h=P02038
h=P01@000000b>3H0<SPf038h=P0000000<0b>3H00D000000<SPf038h=P0b>3H000000020<SPf003
00000038h=P0b>3H02D0b>3H00<000000<SPf038h=P01`38h=P01@000000b>3H0<SPf038h=P00000
00<0b>3H00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H0280b>3H00<00000
0<SPf038h=P02038h=P00`000000b>3H0<SPf0020<SPf00500000038h=P0b>3H0<SPf00000000`38
h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P07`38h=P010000000b>3H
0<SPf00000080<SPf00500000038h=P0b>3H0<SPf00000000`38h=P01@000000b>3H0<SPf038h=P0
00000080b>3H00<000000<SPf038h=P0C038h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`002`00000B0<SPf000M@38h=P3000000l0b>3H0P0000040<SPf08000002038h=P00`2`
aKh0W:jX0;35_P020<SPf0030;35_P2Z_[L0W:jX01L0b>3H0P00000@0<SPf08000001038h=P20000
00P0b>3H00<0/<Fn09b^Z02`aKh00P38h=P00`2S]k00/<Fn0:>g/00D0<SPf08000002P38h=P30000
00T0b>3H0P0000040<SPf08000002038h=P00`2`aKh0W:jX0;35_P020<SPf0030:>g/02`aKh0XkN`
01<0b>3H0P00000@0<SPf08000001038h=P2000000P0b>3H00<0/<Fn09b^Z02`aKh00P38h=P00`2S
]k00/<Fn0:>g/00o0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000H00000103o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf00J0<SPf000V038h=P01`2`aKh0
b>3H0<SPf038h=P0XkN`0<SPf02`aKh0>P38h=P00`2`aKh0b>3H0<SPf0030<SPf0030:Zn]`38h=P0
b>3H03/0b>3H00<0/<Fn0<SPf038h=P00`38h=P00`2Z_[L0b>3H0<SPf00d0<SPf0030;35_P38h=P0
b>3H00<0b>3H00<0Z[jg0<SPf038h=P0?@38h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`001P0000040<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o000@
000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000030?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`001P0000040?l000H00000103o00000`000000b>3H0<SPf00J0<SPf000T@38h=P0102l
dl/0U:JP09BVX02DYZ030<SPf0070;35_P38h=P0b>3H0<SPf023Thd0W:jX0:>g/00c0<SPf0040;cC
b`2DYZ00U:JP09BVX0<0b>3H00@0/<Fn0<SPf038h=P0b>3H0P2`aKh00`2L[ZP0b>3H0<SPf00d0<SP
f0040;cCb`2DYZ00U:JP09BVX0<0b>3H00@0/<Fn0<SPf038h=P0b>3H0P2`aKh00`2L[ZP0b>3H0<SP
f00]0<SPf0040;cCb`2DYZ00U:JP09BVX0<0b>3H00@0/<Fn0<SPf038h=P0b>3H0P2`aKh00`2L[ZP0
b>3H0<SPf00m0<SPf0/000002@38h=P6000000@0o`0000<000000<SPf038h=P03038h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000
b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000<SPf038h=P06P38h=P009P0b>3H
00D0/<Fn0<SPf038h=P0b>3H0:>g/00l0<SPf0040;35_P38h=P0b>3H0<SPf080/<Fn?P38h=P0102`
aKh0b>3H0<SPf038h=P20;35_SL0b>3H00@0/<Fn0<SPf038h=P0b>3H0P2`aKi00<SPf0<000005P38
h=P6000000h0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000/00000103o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
000;000000@0o`0000<000000?l0003o00000P3o0006000000@0b>3H1P0000040<SPf0H000007038
h=P004P0b>3H00<000000<SPf038h=P0C038h=P20:Zn]`@0b>3H00<0XkN`0:Zn]`38h=P0>038h=P2
0:Zn]`<0b>3H0P2DYZ000`2Z_[L0b>3H0<SPf00j0<SPf080Z[jg0`38h=P209BVX0030:Zn]`38h=P0
b>3H03<0b>3H0P2Z_[L30<SPf080U:JP00<0Z[jg0<SPf038h=P0?@38h=P00`000000b>3H0<SPf00Z
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf007
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P01`38h=P;000003D0b>3H00180<SP
f00300000038h=P0b>3H0?l0b>3HEP38h=P00`000000b>3H0<SPf00Z0<SPf0H00000103o00000`00
0000b>3H0<SPf0070<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0A`38h=P004P0
b>3H00<000000<SPf038h=P0o`38h=QF0<SPf00300000038h=P0b>3H02l0b>3H00<000000?l0003o
00000P3o00000`000000b>3H0<SPf0070<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000`3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o0006000000@0o`0000<000000?l0003o00000P3o000;000004T0b>3H00180<SPf0030000
0038h=P0b>3H0?l0b>3HEP38h=P00`000000b>3H0<SPf00_0<SPf0H000002@38h=P6000000@0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`0000<0o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0D@38h=P004P0b>3Ho`00000R000003L0b>3H00<000000<SPf038h=P0@`38
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000020?l0000300000038h=P0b>3H0540b>3H00180<SPf0050000003o0000
o`000?l000000000?038h=P00`000000b>3H0<SPf00n0<SPf00300000038h=P0b>3H03d0b>3H00<0
00000<SPf038h=P0?P38h=P00`000000b>3H0<SPf01B0<SPf00300000038h=P0b>3H04<0b>3H1P00
00040?l000030000003o0000o`000080o`0000<000000?l0003o00000`3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f0020<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f01A0<SPf000B038h=P01@000000o`000?l0003o0000000003`0b>3H00<000000<SPf038h=P0?P38
h=P00`000000b>3H0<SPf00m0<SPf00300000038h=P0b>3H03h0b>3H00<000000<SPf038h=P0DP38
h=P3000004P0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000H000001038
h=P;000005<0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038
h=P0b>3H04P0b>3H1P0000040?l000030000003o0000o`0000<0o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l0000300000038h=P0b>3H06D0b>3H00180<SPf0050000003o0000
o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H04d0b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000030?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf01U0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038
h=P00`000000b>3H0<SPf01=0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000`3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0I@38
h=P004P0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0C@38
h=P6000000D0o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H06D0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038
h=P0b>3H0580b>3H1`0000040?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0I@38
h=P004P0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0F038
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000H00000I`38h=P004P0b>3H00D000000?l0003o0000o`000000
003o0<SPf5@0b>3H0`00001H0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0JP38
h=P004P0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0F038
h=P6000000@0o`001P0000040?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l0000300000038h=P0b>3H06X0b>3H00180<SPf0050000003o0000
o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H05d0b>3H00<000000?l0003o00000P3o
00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000H00000K038h=P004P0b>3H00D000000?l0003o0000o`000000
003o0<SPf5@0b>3H00<000000<SPf038h=P0G@38h=P00`000000o`000?l000020?l0000300000038
h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000<SPf038h=P0K`38h=P004P0b>3H00D000000?l0003o0000o`000000
003o0<SPf5@0b>3H00<000000<SPf038h=P0G@38h=P00`000000o`000?l000020?l0000300000038
h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000<SPf038h=P0K`38h=P004P0b>3H00D000000?l0003o0000o`000000
003o0<SPf5@0b>3H00<000000<SPf038h=P0G@38h=P00`000000o`000?l000020?l0000300000038
h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000<SPf038h=P0K`38h=P004P0b>3H00D000000?l0003o0000o`000000
003o0<SPf5@0b>3H00<000000<SPf038h=P0G@38h=P6000000@0b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000H00000L@38h=P004P0b>3H00D000000?l0003o0000o`000000
003o0<SPf5@0b>3H0`00001W0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf01d0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038
h=P00`000000b>3H0<SPf01W0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`001P00001f0<SPf000B038h=P0
1@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf01W0<SPf0030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000<SPf038h=P0N@38h=P004P0b>3H00D000000?l0003o0000o`000000
003o0<SPf5@0b>3H00<000000<SPf038h=P0I`38h=P00`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038
h=P0b>3H07T0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038
h=P0b>3H06L0b>3H1P0000040?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf01i0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HAP38
h=P2000000@0b>3H0P0000060<SPf00300000038h=P0b>3H06`0b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0N@38
h=P001T0b>3H100000030<SPf08000001038h=P2000000<0b>3H00H000000<SPf038h=P0b>3H0000
0038h=P500000080b>3H0P00000>0<SPf0050000003o0000o`000?l000000000o`38h=Q50<SPf004
00000038h=P0b>3H00000080b>3H00@000000<SPf038h=P000001@38h=P00`000000b>3H0<SPf01/
0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H07T0b>3H000I0<SPf00300000038h=P0b>3H00T0b>3H00@000000<SP
f038h=P000000`38h=P00`000000b>3H000000040<SPf00500000038h=P0b>3H0<SPf00000000P38
h=P00`000000b>3H0<SPf00;0<SPf0050000003o0000o`000?l000000000o`38h=Q80<SPf0040000
0038h=P0b>3H00000080b>3H00<000000<SPf038h=P00`38h=P3000006`0b>3H00<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P0N@38h=P001X0b>3H00<000000<SPf038h=P02`38h=P00`000000b>3H0<SPf0020<SPf0030000
0038h=P0b>3H00<0b>3H00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H00/0
b>3H00D000000?l0003o0000o`000000003o0<SPf4H0b>3H0P0000030<SPf00400000038h=P0b>3H
000000D0b>3H00<000000<SPf038h=P0K038h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf01i0<SPf0006`38h=P00`00
0000b>3H0<SPf0080<SPf08000001038h=P00`000000b>3H000000040<SPf00500000038h=P0b>3H
0<SPf00000000P38h=P00`000000b>3H0<SPf00;0<SPf0050000003o0000o`000?l000000000o`38
h=Q60<SPf00300000038h=P0b>3H0080b>3H00@000000<SPf038h=P000001@38h=P00`000000b>3H
0<SPf01/0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H07T0b>3H000I0<SPf00400000038h=P0b>3H000000T0b>3H
00<000000<SPf038h=P00P38h=P01@000000b>3H0<SPf038h=P0000000<0b>3H00D000000<SPf038
h=P0b>3H000000020<SPf00300000038h=P0b>3H00/0b>3H00D000000?l0003o0000o`000000003o
0<SPf4H0b>3H0`0000030<SPf08000001P38h=P00`000000b>3H0<SPf01/0<SPf0030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o0006000007/0b>3H000J0<SPf08000002P38h=P30000
00T0b>3H0P0000040<SPf08000003P38h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P0
0`000000b>3H0<SPf01/0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000b>3H0<SPf01n0<SPf000?@38h=P00`2`aKh0W:jX0;35_P020<SPf0030;35_P2Z_[L0Z[jg
00<0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0K038h=P0
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0OP38h=P0
03h0b>3H00<0/<Fn0<SPf038h=P00`38h=P01@2Z_[L0b>3H0<SPf038h=P0000000<0o`0000<00000
0<SPf038h=P0o`38h=QB0<SPf00300000038h=P0b>3H06`0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l0000300000038h=P0b>3H07h0b>3H000n0<SPf0070;35_P38h=P0b>3H
0<SPf02S]k00/<Fn08>CS@030<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf0<00000
K038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0
OP38h=P003h0b>3H00L0/<Fn0<SPf038h=P0b>3H09b^Z038h=P0XkN`00<0b>3H00D000000?l0003o
0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0K038h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0OP38h=P003d0b>3H0P2Z_[L30<SPf003
0:>g/02Z_[L0/<Fn00<0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SP
f038h=P0K038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000H00000P038h=P004P0b>3H00D000000?l0003o
0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0K038h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H08<0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SP
f00300000038h=P0b>3H06`0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0230<SP
f000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf01/0<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0P`38h=P004P0b>3H00D000000?l0003o
0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0K038h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H08<0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SP
f0<00000K038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H08<0b>3H00180<SPf005
0000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H06`0b>3H00<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf0230<SPf000B038h=P01@000000o`000?l0003o00000000
0?l0b>3HE038h=P00`000000b>3H0<SPf01/0<SPf0030000003o0000o`000080o`001P0000040?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0P`38h=P004P0b>3H00D000000?l0003o
0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0K038h=P00`000000o`000?l000020?l0
000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H08<0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SP
f00300000038h=P0b>3H06`0b>3H00<000000?l0003o00000P3o00000`000000b>3H0<SPf0020<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf0230<SP
f000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf01/0<SP
f0030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0P`38h=P004P0b>3H00D000000?l0003o
0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0K038h=P00`000000o`000?l000020?l0
000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H08<0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SP
f0<00000K038h=P00`000000o`000?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H08<0b>3H00180<SPf005
0000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H06`0b>3H00<000000?l0
003o00000P3o00000`000000b>3H0<SPf0020<SPf0030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000b>3H0<SPf0230<SPf000B038h=P01@000000o`000?l0003o00000000
0?l0b>3HE038h=P00`000000b>3H0<SPf01/0<SPf0H000001038h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0P`38h=P004P0b>3H00D000000?l0003o
0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0MP38h=P00`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000<SPf038h=P0P`38h=P002H0b>3H0P0000030<SPf006
00000038h=P0b>3H0<SPf0000000b>3H1@0000020<SPf08000003P38h=P01@000000o`000?l0003o
000000000?l0b>3HE038h=P00`000000b>3H0<SPf01f0<SPf0030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000b>3H0<SPf0230<SPf0009@38h=P010000000b>3H0<SPf000
00030<SPf00300000038h=P0000000@0b>3H00D000000<SPf038h=P0b>3H000000020<SPf0030000
0038h=P0b>3H00/0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038
h=P0MP38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038
h=P0P`38h=P002P0b>3H00<000000<SPf038h=P00P38h=P00`000000b>3H0<SPf0030<SPf0050000
0038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00;0<SPf0050000003o0000o`000?l0
00000000o`38h=QD0<SPf0<00000MP38h=P00`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0P`38h=P002H0b>3H0P0000040<SPf00300000038h=P0000000@0
b>3H00D000000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H00/0b>3H00D000000?l0
003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0MP38h=P00`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P0P`38h=P002H0b>3H00<000000<SP
f038h=P00P38h=P01@000000b>3H0<SPf038h=P0000000<0b>3H00D000000<SPf038h=P0b>3H0000
00020<SPf00300000038h=P0b>3H00/0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H
00<000000<SPf038h=P0MP38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0P`38h=P002H0b>3H0`0000090<SPf08000001038h=P2000000h0b>3H00D0
00000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0MP38h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0006000000@0o`00
00<000000<SPf038h=P0P`38h=P003d0b>3H00<0/<Fn09b^Z02`aKh00P38h=P00`2`aKh0Z[jg0:Zn
]`030<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H07H0b>3H
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P00P38h=P00`000000o`000?l000020?l0000300000038h=P0b>3H08<0b>3H
000n0<SPf0030;35_P38h=P0b>3H00<0b>3H00D0Z[jg0<SPf038h=P0b>3H000000030?l000030000
0038h=P0b>3H0?l0b>3H?@38h=P500000080b>3H0P0000040<SPf08000001P38h=P00`000000b>3H
0<SPf01f0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H0080b>3H00<000000?l0003o00000P3o00000`000000b>3H
0<SPf0230<SPf000?P38h=P01`2`aKh0b>3H0<SPf038h=P0XkN`0;35_P23Thd00`38h=P01@000000
o`000?l0003o000000000?l0b>3H@@38h=P01@000000b>3H0<SPf038h=P000000080b>3H00@00000
0<SPf038h=P000000P38h=P00`000000b>3H0<SPf0030<SPf00300000038h=P0b>3H07H0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000<SPf038h=P00P38h=P6000008D0b>3H000n0<SPf0070;35_P38h=P0b>3H0<SPf02L[ZP0b>3H
0:>g/0030<SPf0050000003o0000o`000?l000000000o`38h=Q10<SPf00500000038h=P0b>3H0<SP
f00000000P38h=P010000000b>3H0<SPf00000020<SPf00300000038h=P0b>3H00<0b>3H0`00001f
0<SPf0H00000103o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H08d0b>3H000m0<SP
f080Z[jg0`38h=P00`2S]k00Z[jg0;35_P030<SPf0050000003o0000o`000?l000000000o`38h=Q1
0<SPf00500000038h=P0b>3H0<SPf00000000P38h=P010000000b>3H0<SPf00000020<SPf0030000
0038h=P0b>3H00<0b>3H00<000000<SPf038h=P0N`38h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000<SPf038h=P0S@38h=P004P0b>3H00D000000?l0003o0000o`00
0000003o0<SPf440b>3H00D000000<SPf038h=P0b>3H000000020<SPf00400000038h=P0b>3H0000
0080b>3H00<000000<SPf038h=P00`38h=P00`000000b>3H0<SPf01k0<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02=0<SPf000B038h=P01@000000
o`000?l0003o000000000?l0b>3H@038h=P2000000@0b>3H0P0000040<SPf08000001P38h=P00`00
0000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf02=0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`00
0000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf02=0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`00
0000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf02=0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`00
0000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000b>3H0<SPf02=0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P30000
07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
08d0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H
07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
08d0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H
07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
08d0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H
07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
08d0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H
07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
08d0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H
07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
08d0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H
07/0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
08d0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf0<00000N`38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0S@38h=P004P0
b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0N`38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0S@38h=P004P0
b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0N`38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0S@38h=P001/0
b>3H00<000000<SPf038h=P00P38h=P2000000@0b>3H0P0000030<SPf00600000038h=P0b>3H0<SP
f0000000b>3H1@0000020<SPf08000003P38h=P01@000000o`000?l0003o000000000?l0b>3HE038
h=P00`000000b>3H0<SPf01k0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf02=0<SPf0006`38h=P00`000000b>3H0<SPf0070<SPf00400000038h=P0
b>3H000000<0b>3H00<000000<SPf00000001038h=P01@000000b>3H0<SPf038h=P000000080b>3H
00<000000<SPf038h=P02`38h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000
b>3H0<SPf01k0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf02=0<SPf0006`38h=P00`000000b>3H0<SPf00:0<SPf00300000038h=P0b>3H0080b>3H
00<000000<SPf038h=P00`38h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038
h=P02`38h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf01k0<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02=0<SP
f0007038h=P00`000000b>3H0<SPf0070<SPf08000001038h=P00`000000b>3H000000040<SPf005
00000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00;0<SPf0050000003o0000o`00
0?l000000000o`38h=QD0<SPf00300000038h=P0b>3H07/0b>3H00<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0000
0`000000o`000?l000020?l0000300000038h=P0b>3H08d0b>3H000I0<SPf00400000038h=P0b>3H
000000T0b>3H00<000000<SPf038h=P00P38h=P01@000000b>3H0<SPf038h=P0000000<0b>3H00D0
00000<SPf038h=P0b>3H000000020<SPf00300000038h=P0b>3H00/0b>3H00D000000?l0003o0000
o`000000003o0<SPf5@0b>3H0`00001k0<SPf0030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o
00000P3o00000`000000b>3H0<SPf02=0<SPf0006@38h=P4000000T0b>3H0`0000090<SPf0800000
1038h=P2000000<0b>3H00<0/<Fn09b^Z02`aKh00P38h=P00`2`aKh0Z[jg0:Zn]`030<SPf0050000
003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H07/0b>3H1P0000040?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H08d0b>3H000n0<SPf0030;35_P38h=P0b>3H00<0b>3H00D0Z[jg0<SPf038h=P0
b>3H000000030?l0000300000038h=P0b>3H0?l0b>3HDP38h=P00`000000b>3H0<SPf0200<SPf003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000<SPf038h=P0S@38h=P003h0b>3H00L0/<Fn0<SPf038h=P0
b>3H0:>g/02`aKh0Pi>=00<0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<00000
0<SPf038h=P0P038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H08d0b>3H000n0<SP
f0070;35_P38h=P0b>3H0<SPf02L[ZP0b>3H0:>g/0030<SPf0050000003o0000o`000?l000000000
o`38h=QD0<SPf00300000038h=P0b>3H0800b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02=0<SPf000?@38h=P20:Zn]`<0b>3H00<0XkN`0:Zn]`2`aKh00`38h=P01@000000o`000?l0
003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf0200<SPf0030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0S@38h=P004P0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H
00<000000<SPf038h=P0P038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H08d0b>3H
00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf0<00000P038h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H08d0b>3H00180<SPf0050000003o0000o`000?l000000000
o`38h=QD0<SPf00300000038h=P0b>3H0800b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02=0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H
0<SPf0200<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0S@38h=P004P0b>3H00D0
00000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0P038h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H08d0b>3H00180<SPf0050000003o0000o`000?l000000000
o`38h=QD0<SPf00300000038h=P0b>3H0800b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02=0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3H?`38h=P500000080b>3H
0P0000040<SPf08000001P38h=P00`000000b>3H0<SPf0200<SPf0030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000H00000S`38h=P004P0b>3H00D0
00000?l0003o0000o`000000003o0<SPf440b>3H00D000000<SPf038h=P0b>3H000000020<SPf004
00000038h=P0b>3H00000080b>3H00<000000<SPf038h=P00`38h=P00`000000b>3H0<SPf0200<SP
f0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
00030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0
000300000038h=P0b>3H0980b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=Q10<SP
f00300000038h=P0b>3H00@0b>3H00@000000<SPf038h=P000000P38h=P00`000000b>3H0<SPf003
0<SPf0<00000P038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000b>3H0<SPf02B0<SPf000B038h=P01@000000o`000?l0003o0000
00000?l0b>3H@@38h=P00`000000b>3H0<SPf0020<SPf08000000`38h=P010000000b>3H0<SPf000
00050<SPf00300000038h=P0b>3H0800b>3H00<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0TP38h=P004P0b>3H00D00000
0?l0003o0000o`000000003o0<SPf440b>3H00<000000<SPf038h=P00P38h=P00`000000b>3H0<SP
f0020<SPf00400000038h=P0b>3H000000D0b>3H00<000000<SPf038h=P0P038h=P00`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02B0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3H@038h=P2000000@0b>3H
0`0000030<SPf08000001P38h=P00`000000b>3H0<SPf0200<SPf0030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o0006000009@0b>3H00180<SPf0050000003o0000o`000?l000000000
o`38h=QD0<SPf00300000038h=P0b>3H0800b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H09L0b>3H00180<SPf0050000003o0000o`000?l000000000
o`38h=QD0<SPf00300000038h=P0b>3H0800b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H09L0b>3H00180<SPf0050000003o0000o`000?l000000000
o`38h=QD0<SPf00300000038h=P0b>3H0800b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H09L0b>3H00180<SPf0050000003o0000o`000?l000000000
o`38h=QD0<SPf0<00000P038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0U`38h=P002D0b>3H1@0000000`38h=P000000<SPf0020<SPf00300000038
h=P0000000@000000P38h=P2000000h0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H
00<000000<SPf038h=P0P038h=P00`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000<SPf038h=P0U`38h=P002L0b>3H00<000000<SPf038h=P00P38h=P00`000000b>3H0000
00040<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00;0<SPf0050000
003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H0800b>3H1P0000040?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H09L0b>3H000W0<SPf00300000038h=P0b>3H00<0b>3H00<000000<SPf038h=P0
0`38h=P01@000000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P02`38h=P01@000000
o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0U`38h=P002L0b>3H00<000000<SPf038h=P00P38h=P00`000000
b>3H000000040<SPf00500000038h=P0b>3H0<SPf00000000P38h=P00`000000b>3H0<SPf00;0<SP
f0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H08D0b>3H00<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`001P00002I
0<SPf0009`38h=P01@000000b>3H0<SPf038h=P0000000<0b>3H00D000000<SPf038h=P0b>3H0000
00030<SPf00400000038h=P0b>3H000000d0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0
b>3H00<000000<SPf038h=P0Q@38h=P00`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02L0<SPf0009P38h=P2000000X0b>3H
0P0000040<SPf08000000P38h=P0102fc<D0W:jX0;35_P2Z_[L20<SPf00309b^Z02`aKh0XkN`00<0
b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H0`0000250<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
09`0b>3H000m0<SPf0030;K<a@2ldl/0b>3H0080b>3H00<0Z[jg0<SPf02S]k000`38h=P01@000000
o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H
09`0b>3H000n0<SPf0070;K<a@2ldl/0b>3H0<SPf02`aKh0b>3H09BVX0030<SPf0050000003o0000
o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H08D0b>3H00<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0W038
h=P003l0b>3H00H0Z[jg0<SPf038h=P0Z[jg0<SPf02L[ZP30<SPf0050000003o0000o`000?l00000
0000o`38h=QD0<SPf00300000038h=P0b>3H08D0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0W038h=P003d0b>3H
00<0W:jX0:Zn]`2`aKh00P38h=P00`2S]k00Z[jg0:Zn]`030<SPf0050000003o0000o`000?l00000
0000o`38h=QD0<SPf00300000038h=P0b>3H08D0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0W038h=P004P0b>3H
00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0Q@38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf02L0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000
b>3H0<SPf0250<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H09`0b>3H00180<SPf0050000003o0000o`000?l00000
0000o`38h=QD0<SPf0<00000Q@38h=P00`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02L0<SPf000B038h=P01@000000o`00
0?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf0250<SPf0030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H09`0
b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H08D0
b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000H00000WP38h=P004P0b>3H
00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0Q@38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H
00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0Q@38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H
00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0Q@38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H
00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0Q@38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H
00D000000?l0003o0000o`000000003o0<SPf5@0b>3H0`0000250<SPf0030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02Q0<SPf000B038h=P01@000000o`00
0?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SPf0250<SPf0H00000103o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf02Q0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000
b>3H0<SPf02:0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H
00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0RP38h=P00`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l0000300000038h=P0b>3H0:40b>3H00180<SPf0050000003o0000o`000?l00000
0000o`38h=QD0<SPf00300000038h=P0b>3H08X0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf02Q0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3H?`38h=P4000000<0
b>3H0P0000040<SPf08000001P38h=P00`000000b>3H0<SPf02:0<SPf0030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080
o`0000<000000<SPf038h=P0X@38h=P004P0b>3H00D000000?l0003o0000o`000000003o0<SPf3l0
b>3H00<000000<SPf038h=P00`38h=P010000000b>3H0<SPf00000020<SPf00400000038h=P0b>3H
000000D0b>3H00<000000<SPf038h=P0RP38h=P00`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0
b>3H0:40b>3H000C0<SPf0D000000P38h=P2000000<0b>3H100000030<SPf08000000`38h=P01P00
0000b>3H0<SPf038h=P000000<SPf0D000000P38h=P2000000h0b>3H00D000000?l0003o0000o`00
0000003o0<SPf400b>3H00<000000<SPf038h=P00P38h=P010000000b>3H0<SPf00000020<SPf004
00000038h=P0b>3H000000D0b>3H0`00002:0<SPf0030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0
003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SP
f038h=P0X@38h=P001D0b>3H00<000000<SPf038h=P01`38h=P00`000000b>3H0<SPf0030<SPf004
00000038h=P0b>3H000000<0b>3H00<000000<SPf00000001038h=P01@000000b>3H0<SPf038h=P0
00000080b>3H00<000000<SPf038h=P02`38h=P01@000000o`000?l0003o000000000?l0b>3H@@38
h=P01@000000b>3H0<SPf038h=P000000080b>3H00@000000<SPf038h=P000000P38h=P00`000000
b>3H0<SPf0030<SPf00300000038h=P0b>3H08X0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000
b>3H0<SPf02Q0<SPf0005@38h=P00`000000b>3H0<SPf0080<SPf00300000038h=P0b>3H00D0b>3H
00<000000<SPf038h=P00P38h=P00`000000b>3H0<SPf0030<SPf00500000038h=P0b>3H0<SPf000
00000P38h=P00`000000b>3H0<SPf00;0<SPf0050000003o0000o`000?l000000000o`38h=Po0<SP
f00400000038h=P0b>3H00000080b>3H00@000000<SPf038h=P000000P38h=P010000000b>3H0<SP
f00000050<SPf00300000038h=P0b>3H08X0b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H
0<SPf02Q0<SPf0005@38h=P00`000000b>3H0<SPf0090<SPf00300000038h=P0b>3H0080b>3H0P00
00040<SPf00300000038h=P0000000@0b>3H00D000000<SPf038h=P0b>3H000000020<SPf0030000
0038h=P0b>3H00/0b>3H00D000000?l0003o0000o`000000003o0<SPf400b>3H0P0000040<SPf080
00001038h=P2000000H0b>3H00<000000<SPf038h=P0RP38h=P00`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l00003
00000038h=P0b>3H0:40b>3H000E0<SPf00300000038h=P0b>3H00L0b>3H00@000000<SPf038h=P0
00000`38h=P00`000000b>3H0<SPf0020<SPf00500000038h=P0b>3H0<SPf00000000`38h=P01@00
0000b>3H0<SPf038h=P000000080b>3H00<000000<SPf038h=P02`38h=P01@000000o`000?l0003o
000000000?l0b>3HE038h=P00`000000b>3H0<SPf02:0<SPf0H00000103o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P001@0b>3H0P00000:
0<SPf08000001038h=P3000000T0b>3H0P0000040<SPf08000000P38h=P0102fc<D0W:jX0;35_P2Z
_[L20<SPf00309b^Z02`aKh0XkN`00<0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H
00<000000<SPf038h=P0S`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000b>3H0<SPf02Q0<SPf000?@38h=P00`2fc<D0_=?;0<SP
f0020<SPf0030:Zn]`38h=P0XkN`00<0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H
00<000000<SPf038h=P0S`38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`00
00<000000?l0003o00000P3o00000`000000b>3H0<SPf02Q0<SPf000?P38h=P01`2fc<D0_=?;0<SP
f038h=P0/<Fn0<SPf02DYZ000`38h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P30000
08l0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000<SPf038h=P0X@38h=P003l0b>3H00H0Z[jg0<SPf038h=P0Z[jg0<SPf02L[ZP3
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H08l0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000<SPf038h=P0X@38h=P003d0b>3H00<0W:jX0:Zn]`2`aKh00P38h=P00`2S]k00Z[jg0:Zn]`03
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H08l0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000<SPf038h=P0X@38h=P004P0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<0
00000<SPf038h=P0S`38h=P6000000@0o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02Q0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SP
f02D0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02Q0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SP
f02D0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02Q0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H0<SP
f02D0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SP
f02Q0<SPf000B038h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P3000009@0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:40b>3H0018
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H09@0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:40b>3H0018
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H09@0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:40b>3H0018
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H09@0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:40b>3H0018
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H09@0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:40b>3H0018
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H09@0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:40b>3H0018
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0b>3H09@0b>3H00<0
00000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000o`000080o`0000<0
00000?l0003o00000P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:40b>3H0018
0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf0<00000U038h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H00D00000
0?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H00D00000
0?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H00D00000
0?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0X@38h=P004P0b>3H00D00000
0?l0003o0000o`000000003o0<SPf5@0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l0
00020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o0006000000@0o`0000<0
00000<SPf038h=P0X@38h=P001T0b>3H1@0000020<SPf08000001038h=P2000000<0b>3H00H00000
0<SPf038h=P0b>3H00000038h=P500000080b>3H0P00000>0<SPf0050000003o0000o`000?l00000
0000o`38h=QD0<SPf00300000038h=P0b>3H09@0b>3H00<000000?l0003o00000P3o00000`000000
o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000
o`000?l000020?l0000300000038h=P0b>3H0:40b>3H000K0<SPf00300000038h=P0b>3H00L0b>3H
00@000000<SPf038h=P000000`38h=P00`000000b>3H000000040<SPf00500000038h=P0b>3H0<SP
f00000000P38h=P00`000000b>3H0<SPf00;0<SPf0050000003o0000o`000?l000000000o`38h=QD
0<SPf00300000038h=P0b>3H09@0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l000030000003o0000o`000080o`0000<000000<SPf038h=P00P38h=P00`000000o`000?l00002
0?l0000300000038h=P0b>3H0:40b>3H000K0<SPf00300000038h=P0b>3H00X0b>3H00<000000<SP
f038h=P00P38h=P00`000000b>3H0<SPf0030<SPf00500000038h=P0b>3H0<SPf00000000P38h=P0
0`000000b>3H0<SPf00;0<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf0<00000U038
h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf0020<SPf0H00000X`38h=P001/0b>3H00<000000<SPf038h=P02038h=P2
000000@0b>3H00<000000<SPf00000001038h=P01@000000b>3H0<SPf038h=P000000080b>3H00<0
00000<SPf038h=P02`38h=P01@000000o`000?l0003o000000000?l0b>3HE038h=P00`000000b>3H
0<SPf02D0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H0:/0b>3H000K0<SPf00300000038h=P0b>3H00P0b>3H00<0
00000<SPf038h=P00P38h=P01@000000b>3H0<SPf038h=P0000000<0b>3H00D000000<SPf038h=P0
b>3H000000020<SPf00300000038h=P0b>3H00/0b>3H00D000000?l0003o0000o`000000003o0<SP
f5@0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l000020?l000030000003o0000o`00
0080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02[0<SPf0006P38h=P2000000X0
b>3H0`0000090<SPf08000001038h=P200000080b>3H00@0]/c509b^Z02`aKh0Z[jg0P38h=P00`2L
[ZP0/<Fn0:>g/0030<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0
b>3H09@0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000<SPf038h=P0Z`38h=P003d0b>3H00<0]/c50;cCb`38h=P00P38h=P00`2Z
_[L0b>3H0:>g/0030<SPf0050000003o0000o`000?l000000000o`38h=QD0<SPf00300000038h=P0
b>3H09@0b>3H00<000000?l0003o00000P3o00000`000000o`000?l000020?l000030000003o0000
o`000080o`0000<000000<SPf038h=P0Z`38h=P003h0b>3H00L0]/c50;cCb`38h=P0b>3H0;35_P38
h=P0U:JP00<0b>3H00D000000?l0003o0000o`000000003o0<SPf3l0b>3H100000030<SPf0800000
1038h=P2000000H0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l000020?l000030000
003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02[0<SPf000?`38
h=P01P2Z_[L0b>3H0<SPf02Z_[L0b>3H09b^Z0<0b>3H00D000000?l0003o0000o`000000003o0<SP
f3l0b>3H00<000000<SPf038h=P00`38h=P010000000b>3H0<SPf00000020<SPf00400000038h=P0
b>3H000000D0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l000020?l000030000003o
0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02[0<SPf000?@38h=P0
0`2L[ZP0Z[jg0;35_P020<SPf0030:>g/02Z_[L0Z[jg00<0b>3H00D000000?l0003o0000o`000000
003o0<SPf400b>3H00<000000<SPf038h=P01@38h=P010000000b>3H0<SPf00000020<SPf0030000
0038h=P0b>3H00<0b>3H0`00002D0<SPf0030000003o0000o`000080o`0000<000000?l0003o0000
0P3o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:/0b>3H00180<SPf0050000003o
0000o`000?l000000000o`38h=Q10<SPf00300000038h=P0b>3H0080b>3H0P0000030<SPf0040000
0038h=P0b>3H000000D0b>3H00<000000<SPf038h=P0U038h=P00`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000?l0003o00000P3o00000`000000b>3H0<SPf02[0<SPf000
B038h=P01@000000o`000?l0003o000000000?l0b>3H?`38h=P010000000b>3H0<SPf00000030<SP
f00300000038h=P0b>3H0080b>3H00@000000<SPf038h=P000001@38h=P00`000000b>3H0<SPf02D
0<SPf0H00000103o00000`000000o`000?l000020?l0000300000038h=P0b>3H0:/0b>3H00180<SP
f0050000003o0000o`000?l000000000o`38h=Q00<SPf08000001038h=P3000000<0b>3H0P000006
0<SPf00300000038h=P0b>3H09T0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0:/0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD
0<SPf00300000038h=P0b>3H09T0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0:/0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD
0<SPf00300000038h=P0b>3H09T0b>3H00<000000?l0003o00000P3o00000`000000o`000?l00002
0?l0000300000038h=P0b>3H0:/0b>3H00180<SPf0050000003o0000o`000?l000000000o`38h=QD
0<SPf0<00000V@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0Z`38h=P004P0b>3H00D000000?l0003o0000o`000000003o0<SPf5@0b>3H00<00000
0<SPf038h=P0V@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0Z`38h=P004P0b>3H1@00003o0<SPf5@0b>3H00<000000<SPf038h=P0V@38h=P00`00
0000o`000?l000020?l000030000003o0000o`000080o`0000<000000<SPf038h=P0Z`38h=P004P0
b>3H0P00003o0<SPf5L0b>3H00<000000<SPf038h=P0V@38h=P00`000000o`000?l000020?l00003
0000003o0000o`000080o`0000<000000<SPf038h=P0Z`38h=P004P0b>3H00<000000<SPf038h=P0
o`38h=QF0<SPf00300000038h=P0b>3H09T0b>3H00<000000?l0003o00000P3o00000`000000o`00
0?l000020?l0000300000038h=P0b>3H0:/0b>3H00180<SPf00300000038h=P0b>3H0?l0b>3HEP38
h=P00`000000b>3H0<SPf02I0<SPf0030000003o0000o`000080o`0000<000000?l0003o00000P3o
00000`000000b>3H0<SPf02[0<SPf000B038h=P00`000000b>3H0<SPf03o0<SPf5H0b>3H00<00000
0<SPf038h=P0V@38h=P00`000000o`000?l000020?l000030000003o0000o`000080o`0000<00000
0<SPf038h=P0Z`38h=P00?l0b>3HX@38h=P3000009T0b>3H00<000000?l0003o00000P3o00060000
0:d0b>3H003o0<SPf:40b>3H00<000000<SPf038h=P0V@38h=P00`000000o`000?l000020?l00003
00000038h=P0b>3H0;00b>3H003o0<SPf:40b>3H00<000000<SPf038h=P0V@38h=P00`000000o`00
0?l000020?l0000300000038h=P0b>3H0;00b>3H003o0<SPf:40b>3H00<000000<SPf038h=P0V@38
h=P600000;80b>3H003o0<SPf:40b>3H00<000000<SPf038h=P0o`38h=QB0<SPf000o`38h=RQ0<SP
f00300000038h=P0b>3H0?l0b>3HDP38h=P00?l0b>3HX@38h=P00`000000b>3H0<SPf03o0<SPf580
b>3H003o0<SPf:40b>3H0`00003o0<SPf580b>3H003o0<SPf:40b>3H00<000000<SPf038h=P0o`38
h=QB0<SPf000o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000
o`38h=So0<SPf?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SP
f?H0b>3H003o0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H003o
0<SPf?l0b>3HmP38h=P00?l0b>3Ho`38h=Sf0<SPf000o`38h=So0<SPf?H0b>3H0000\
\>"],
  ImageRangeCache->{{{0, 755.625}, {466.625, 0}} -> {-0.0508519, -0.0309082, \
0.00278141, 0.00278141}, {{18.25, 360.688}, {455.5, 243.875}} -> {-20.0203, \
-29.3914, 0.0998662, 1.09753}, {{394.875, 737.313}, {455.5, 243.875}} -> \
{-115.265, -47.5657, 0.199732, 1.77619}, {{18.25, 360.688}, {222.688, \
11.0625}} -> {-5.63132*^-16, -2.62043*^20, 7.73008*^-18, 9.67055*^17}, \
{{394.875, 737.313}, {222.688, 11.0625}} -> {-57.6324, -377.127, 0.0998662, \
1.45277}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The LH and HL band distributions are narrower because of the lower level of \
quantization, and are not very Gaussian: this is because noise got through \
quantization in those two bands.  We could have been more radical when \
quantizing - disposing with more than 4 bits without losing much information. \
But not to dawdle, let's now capture the noise (assuming it is Gaussian) and \
reintroduce it in the image. 

 There is an important consideration to be made: a part of the quantization \
noise is indeed noise, but a part is lost information. The lost information \
shouldn't be considered a part of noise - as we cannot reintroduce it. Thus \
not to overestimate the noise , we divide the estimated std. deviation by \
2.\
\>", "Text"],

Cell[BoxData[{
    \(<< Statistics`NormalDistribution`\), "\[IndentingNewLine]", 
    \(\(NoiseProp[array_] := {Mean[Flatten[array]], 
          StandardDeviation[Flatten[array]]/2};\)\), "\[IndentingNewLine]", 
    \(\(Noise[{mean_, stddev_}, dim_] := 
        Partition[RandomArray[NormalDistribution[mean, stddev], dim*dim], 
          dim];\)\)}], "Input"],

Cell["\<\
The noise description is very compact, and adds very little to the compressed \
file size. Especially considering the fact that the mean is always \
approximately 0, and does not need to be stored.\
\>", "Text"],

Cell[BoxData[
    \(\(noisedesc = Map[NoiseProp, decomp - qdecomp, {2}];\)\)], "Input"],

Cell["Here we add the noise to the compressed image:", "Text"],

Cell[BoxData[
    \(\(enhancedqdecomp\  = 
        Table[qdecomp[\([i, j]\)] + 
            Noise[noisedesc[\([i, j]\)], \(Dimensions[
                  qdecomp[\([i, j]\)]]\)[\([1]\)]], {i, 
            1, \(Dimensions[qdecomp]\)[\([1]\)]}, {j, 
            1, \(Dimensions[qdecomp]\)[\([2]\)]}];\)\)], "Input"],

Cell["\<\
And now we compare the \"en-noised\" compressed image to the original image \
and the normal \"de-noised\" compressed image:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{Graphics[
              Raster[\((ImgIDWT[Interleave2[qdecomp]] + 128)\)/255], 
              AspectRatio \[Rule] 1], 
            Graphics[Raster[\((sub + 128)\)/255], AspectRatio \[Rule] 1], 
            Graphics[
              Raster[\((ImgIDWT[Interleave2[enhancedqdecomp]] + 128)\)/255], 
              AspectRatio \[Rule] 1]}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
576883A7BC3329242E262231403F3A35323435323034373533343845504B423D38312C28
28303B6D63635A7C67466060646C7375767A7E7F7F80817F7E7E7F818386888A8A898889
8B8E908D8B8E908D8988898A8C8C8C8C8D8E8F909192929191909091929394918F919492
909498969496999A9B9DA0A3A8B5C3CACFD0D3B3
585F70A1BFA64621292526313B3833373A3733323132343434363B424C48403933302F29
272F3A6C62645C7B614F5D626B6E7174767A7E7E7F8082817F808081838587898A89888A
8C8E8F8D8A8B8C8D8D8A898B8E8D8C8D8E90929393939292939291929496979592939493
9193969695989A9A9B9DA0A3A9B6C4CCD1D0CFBE
5B575A7996B4983F28212A2F332F2C38423A313133312F3135393D4146423D342D2F322B
262F3A6B60666079575A5A6672716F72777A7C7E7F81828281818282828486888989898B
8D8E8E8C8A89888D918D898C908F8D8E909294969695949495949495979A9C9995959594
9293949596999B9A9A9C9FA3A8B6C4CFD4D0C9CA
5C57576A83A6B67C3A1D27282D2D2F363B342D2F33302D303436364D403F39332E30322A
2534407061666079545B5E687171717477797B7D7F80818283838281818488898889898B
8D8D8C8C8B8B8B8E908E8B8D8F8F8F91939495969696969595969797989B9D9A96949392
92959797969798999A9B9DA1A7B4C1CDD4CFC7C9
5E5A5A5F7082C4B6592A2522282D3333322E2A2F332F2B30343330573D3C373431313129
2537487563676077525B63696E71737678797A7D80808082848381807F858A8A8889898B
8C8C8B8B8C8D8E8E8D8E8E8E8E8F9194969696969697989695979999999B9C9A96939191
93979A9895949597999A9B9FA5B1BECAD2CDC6C5
635E59596375A8C4A63A3224262A2F2E2D2C2C3033312E323536354C3F3F3A373331302A
292B4A79676D646B565E676C6F7072777C7B7B7D7F7F808081808081838587888A8A8B8B
8C8C8C8C8C8C8C8C8C8D8F8E8E919497989897979897979797989A9A9A9B9B9997949394
95979795939495949597999CA1ADBAC8D1CBC2C4
65605B575A708AB8CE9633272A2A2B2B2B2D303233333234373A3D3E42413E3934312F29
2B1D4D7C6C70695F59606A6E717171787E7E7C7D7E7F807F7E7E8083868483878B8C8C8C
8C8E8E8D8B8A898B8C8E8F8F909397999A9998999A989697999A9A9B9C9B9A9998969596
9896949393939492909397999DA9B6C5CFC8BFBF
575E60585B7390A7D4B87E47272931302F33373736343435383B3E3D3F3D3A36332D2C39
4B32577171646D5E595F686D707274797D7E7E7D7D8082817F808183858687898C8D8D8D
8D8D8D8C8B8C8D8E8E8F91929497999A9999999A9A99999A9C9D9D9D9C9C9B9997969798
9997949494949391909194979DA6B1BFCAC6C1AF
505B655D5E779992C4CEC86D332D363434383D3B37363536393C3E3D3B383533322F2D27
2C29636B76566F60575C666B6F7377797B7D7F7E7D8082828182828283878B8B8C8C8D8D
8D8C8C8C8C8F92919091929597999A9A999A9A9A9A9B9B9D9F9F9F9E9D9D9D9A97979899
9997959596949291919090959DA3ABB9C4C2C1A0
7358616E5C708989A8C1C8C5542B302F3236393835353536383C3E3C3937363433302F2C
332D646F7C566A5C555B656A6E7376797A7C7E7D7D7E807E7D808383828588898A8B8C8C
8C8D8F8F8E8F90919191929294979A9A9A9A9B9B9B9C9E9FA19F9D9D9E9E9E9B999A9B9A
97969595959492908E8D8E91969CA4B2BEBAB5A3
995D5F795C69757D87B1D0CF9B3F2C262F31343331323436383B3E3B3736363534312F2E
362F647481596558535A656A6E7275787A7B7C7C7C7D7D7B797E83838182848688898A8B
8C8F9191908F8F8F919191909094999A9B9B9B9B9C9D9FA0A19E9C9D9E9E9E9C9B9C9D9A
969595949393928E8B8A8B8C8E939BA9B4AEA5A5
A98B67656A68676E779ABAD8C5823A222B2B2E2D2B2E3133343C413A31323333312D2A28
302E6875805564565159656C7072747678797A7B7C7D7E7D7D7F8181818385878988888A
8C8F9191908F8F9091929394949597999B9B9B9B9C9C9B9D9F9F9E9E9E9D9C9C9C9C9B98
969595939291908C88878787888D929DA59E9495
A9B06D50776A61647086A0CCE0C1532927252A27262A2E31343E443A2E2E30302F292522
2A2D6B757C5364565059666D7273737477787A7B7C7D7F8182807F80828486888A88868A
8E8F90909090909192939597989795999C9B9A9B9D9A989A9E9FA09F9E9C9B9C9C9A9797
96959391908E8C888483838385878B91958D8583
87A497706D6B7071757D8CB0CBCA961A3321262324272D3842484940352F2B2B2C2B2A29
312D65727B615F545059666B6F72737475787B7D7E7D7D7F81828181818486888988878C
919190919192929292929395969696989B99979A9C9B9A9D9F9F9D9E9E9D9B9A99979696
95928E8C8B8885817E808283848587898A837C7A
646C787066738283807F8299B0BCB9583121272324252B3D4D4E49433B3128282B2D3130
372D5F6F796D5A52505A65696C70747475797D7F7F7D7C7D80828483818487888988888E
939290919394959392909092959697999A9896999C9D9EA0A19E9B9D9E9E9C9895959594
928D888685827E7B7A7D818384848484837C7674
4850637277818A8E919397A3AFB7B4A7604C2322262527333E3D3937352F2A2A2C2D302D
332D626E7468544F515B676A6C70747474787D7D7D7D7D7F8082848484868889898B8D90
929190919294969594929194979899999999999A9C9D9FA0A09E9C9D9F9D9A9693949593
9088817E7D7D7D7D7E81848585868685827B7472
33374568888F9099A2AAB1B2B2BBC1B1AB852520272625282C2A292A2C2C2C2D2E2E2E29
2D2C656E70604F4D525C676A6C70747473787C7B7A7C7F808182838486888989898D9191
909091909194969796959396999B9B9A999B9C9C9B9D9F9F9E9D9D9E9F9C989593939492
8D837A77787B7E80818180808082848380797170
27242F4D8E959FA4A9B3BCBBB8BDC1C3B99F3E2720212527282725272A2C2F30302F2E28
2B28606D72604D4D545D6567686C707274777A7B7C7C7D8082828283858788898A8C8F91
91919191939597979696959697999A9B9B9D9E9E9D9E9E9E9E9E9E9F9F9B96959494928F
897F76787C80827C746A6260626A72706C666160
22191F30879AABADADB8C2C0BCBFC1C5B9AC5C371F20282828262526282C303232302E27
2A255C6B73604C4E555C626465696E727577797B7D7D7C8083828182848687898A8B8C90
9392919395979897969797969597999B9D9E9F9F9F9E9D9E9E9E9E9F9F9A94959594918B
857B757B838786796753423F43515E5E5A585656
221A1C275BA9ADB4ABB7C1BDB7BBBFBEB5C0A27B3329292624232324252A2F302F2C2A26
2B2661686A5C4D4E53596062646A707376787A7A7B7D7F808181818386888A8A8A8B8D90
9191909498979596979999989697999B9C9D9E9E9E9E9D9E9E9E9D9F9F9A959493908C87
817A777D8588877D6E5036313745555D62646566
231F1D232EAEABB5A8B3BCB6B0B6BBB8B2AEA29B523F31282221222223282D2D2C292724
2B2A656661574D4C50565D60646C737576797C7A797E82817E808284878A8C8B8A8C8E8F
8F8F90959A979395989A9A9997989A9B9B9C9D9D9D9D9E9E9F9D9C9E9F9A9593918D8983
7D79787F86888784795636313642516271767879
25211C1B218DB0A3AAADB1B0AFB2B5B7B8B5B3C0A2784B342625232222272D2D2C2B2A25
26365E64625547464B535C61656D7475767A7D7D7D8082807E80828486898B8C8D8D8D8F
91919093969696969798999796989A9C9D9B9A9C9F9F9E9F9F9D9C9D9D999492908F8D81
7674767C838789857F7C7978798188847E7D7D7C
27221D151F63AE93ABA7A6A9ADACACB2B7B7B4B2AD906E4C3028242223272C2D2D2E2D25
213F57646554424146505B61666D7375767A7E80808182807F8183848587898D8F8D8B8F
92929191929699989696979696989B9D9F9B989CA0A09F9F9F9D9C9C9A9794918F919080
706F73787F868B8B88858284858584898B847D7B
2B2723181E4397A5A8A7A5A4A39F9B9696A6B7B8B6AA966C4922232024272B2B2B2C2D23
28365D6468574441444E5960676D7274767B7E7F7E808281808183848687898C8F8E8E8F
90909191929698979697999A9A9B9C9E9E9D9B9EA0A09F9E9D9E9E9D9A96939190908E7F
716E6F767E858B8C8D8C8B8D8F8F8F8F8D857D7B
2C2B291E202A77B1A0A5A19C968F877D7577819CB6BCB38C6421251F24272A29282A2F1D
312A626768584743454D585F666C7174777B7E7D7C7F8181818283858788898B8E90908F
8E8F91939496979796989B9D9E9E9E9D9E9E9FA0A0A0A09E9D9FA19E9A9692918F8E8A7F
746E6D757E84898D8E8B888A8D8F8F8E8A837C7B
26292C2320204A839295928C847B736E6D757F848E9CA2A075363728232327292926203E
22235E725C504344494F565D646B727475797D7D7D7F81808082848687898B8C8D909290
8F9193959798989797989A9B9C9C9D9D9D9E9FA0A0A0A0A0A0A1A19D999795918D8D8B80
746F6D747C83888B8C8A898B8E8E8D8985817D7C
1F272E28221E234E7C807D7C776C64626B94BAB4A59A8DAB874F4A3021202526282B2F1C
2F27577651483E444D51555B616A727474787C7D7E7F80807F838686878A8C8C8C8F9291
91939597999A999897989A99999A9C9D9E9E9F9FA0A1A1A2A3A2A09C999898928C8D8C81
76706F747A8085888888888A8C8A8783807E7E7D
23292F2D29211A32506C62737E726A6A7391ADCAB79E7E8D79281C192324262626292C23
2B285C6D56483B424D51555B6269707274787B7D7E80818182848687878888898B8E9293
93949597999998979698999A9A9C9F9FA0A0A0A1A2A2A2A3A4A29F9D9A9896928E8F8E86
7C767274787E8386878888878683817E7C7C7D7D
282B2F3131261C212955466B877F74757B8A9AD6CBC5B3AEA4482C1F2224282625272926
292860605D4A39404C51565C63696E7275787B7D7E80828384858687888685878A8D9194
969695979898979697989A9B9C9EA1A1A1A2A2A3A4A3A2A3A4A19F9D9C98959291918F8A
837C7775767C8185868787837F7D7C7B7A7B7C7C
24292F2E30291E1F21342E5D84927475787F8BC4D1CCC1C2BB7A34192324292826262724
27265E5A5A493B414B52595E63696F7376787A7D7F8183838485868687898B8B8B8E9194
96969597989796989A9A9B9C9C9D9E9FA1A3A5A5A4A3A1A1A2A1A19F9D9A979492908D89
857F7B7A7B7C7E82858686817C7C7D7B79797A7A
21283131312A212123181B4D7B9E757573747FA7CED1CDD8D1B4502525242A2928262522
27245A5854483E424B535B60646B717578797A7D8082838383848686878C91908E8F9193
959696979897979A9D9D9C9C9D9D9D9EA0A4A7A6A4A2A1A0A0A2A3A19F9C9996938F8B88
8682807F807E7D80848584807B7D7F7C79797979
202E3D4E3E2023202115183E678D867A70717E8ABBD5C9D1CFD0A12F3026262627252423
2A20525E4A433C414A515960666C7074787C7E7E7D80848382848788898A8C8E91929293
94969898989A9C9EA09E9C9D9E9F9FA1A4A5A6A6A5A5A4A3A2A3A3A3A2A09D9994908D8A
88858382818181828382807E7C7B7B7A797A7B7B
23374C6D4C1A251E1F191A304F7696846F717F72A4D3C2C9CAD6D1822E24262526232324
2C204B64403D3B4149505760686D7074787E827F7B7F84828184888A8B88868C93949493
93979B99989CA1A2A2A09D9EA0A2A3A6A7A6A5A6A7A8A8A7A5A4A3A5A5A39F9B9692908C
8A87858382838584827F7D7D7D7A77787A7C7C7D
2D3E54907C43241B1D191B23376D98966D6E777393BDC4CBCAD0CBC66829212025242422
252A43613D3B393F48505961696D7074787D80807E818382818387898A89898D92949495
96999B9A9A9EA2A3A3A09EA0A3A6A7A7A6A8A9A8A7A8A9A8A7A5A3A4A5A29E9B9895918D
898786848284858583807E7F807C78797B7C7C7D
394D638D6D4E271E1D1B1C1B256090A46F6E707885A5C6CBC9CED2C0C142291D24252621
1E333F5C3B3A373E47515A63696D6F74797B7D8082838282828384878A8C8D8F91939598
9A9A9B9B9C9FA2A3A3A09FA2A6A9ABA8A5A9ADABA8A9A9A9A8A6A3A4A4A09C9B9A97928D
888787848384858585828081817D797A7B7C7D7D
4360819D8960281E1F1E1F1B223D77A27E756E727B9DC4C8CACED0CBC1A7471C24222723
2426415D3735343D48525B62686C6F74787A7C8083838383848484878A8D8F8F90949798
989B9D9D9E9FA0A1A1A1A2A6AAABACA9A7A9ACACABABAAAAAAA7A4A5A5A29E9C9A97948E
888786858485868584828181807D79797A7D7F7F
50739FA59A63291F2221231F251E5A958D7F6D6A7396BBC5CBCCCBD4D0C48B33251E2726
2B1A455B3432313C4A545C61666B707477797B7F83838385868585878B8E8F9091959998
979A9E9F9F9F9F9FA0A2A5AAADADABAAA9A9AAADAEACAAAAABA8A5A5A5A3A19D9997958F
8986858585878886848381807F7C79797A7D8182
6187B1A58D492A2024252724271F417D909166696F87A0CAC8CCC9D0CDD9B46B22202625
2826434A3835353F4C555C63686D7175787B7E81838282848787878A8D8E909193969898
989B9E9E9EA0A2A3A5A6A8ADB0AEACACADADADAEAEABA9AAABA9A7A5A4A3A19D99979690
8A88868686868688898581807F7E7C7B7B7F8283
7695B399732B2A222627292929282E618C9E656A6E7885C9C5CBC6C9CAD9D3A430262623
24333F3B3B3839424E565D656B6F7376797D81828181818487888A8C8E8F909396979798
999B9D9C9CA0A5A8A9AAABAFB2B0ADAFB1B1B0AFADAAA8A9ABAAA8A6A3A2A09C99979691
8C8A88878786858A8E878080807F7E7C7C808384
999B94714D272B242424272728262B4685957C65727380A9CAC6C1C4C9D6D7BE7631251F
2430354231353A424B555F656B7177797A7C7E7F8082848485888B8C8D8E909396989899
99999A9B9CA1A5A7A8A9AAAEB2B0ADAFB2B2B1B0AEABA8AAACAAA8A7A5A3A09E9B989593
908D8A898888898B8D888381817F7D7C7C808384
B0956A4629292C262121232425232D307687956675718085CAC3BBC0C8CED1CCBE432D1F
252A2D4A28313A41495560666B737A7B7A7B7B7D8083868483878B8C8C8E909396989999
9998989A9DA2A5A6A6A7A9ADB1B0AEB0B2B3B2B0AFABA9AAACABA8A8A7A4A09F9D999494
93908C8A8A8B8D8C8B888583817E7C7C7D808384
9A77472F21262926212223232421252A587C9E7971707A75B7C9B7BEC4C8C9CCC19F381E
292C303F2D3237404A5763696D757A7977797C7F828587858486898C8F90909193949698
999A9A9C9FA2A5A7A8AAADB0B3B1AFB0B1B3B4B2AFACABADAFADA9A8A6A4A1A09E9A9592
8F8F8E8C8B8E908E8A898784817E7C7D7F828384
76552B22222426252323232424201F28396F9C8D706F756C9ECBB7BEC0C0C0CFD1B46B35
2B2B34323333353F4B58646B7076797775797E81848687868585868C9191909090929497
9A9C9D9FA2A4A6A8AAAEB1B3B4B2B1B1B1B4B6B3AFADADB0B2AEA9A8A7A4A2A09E9B9791
8C8E908E8C9093908B898785827E7C7E81838484
54432824242528262426272726232020275B8D91846B776D88BAC3C1BCBEC0C5C5CDAE3B
352B2D2B303136414E58626B72757777787C8081828384858585868A8E91939392939597
9B9EA1A3A6A7A9ABADAFB1B2B3B3B2B5B7B7B5B2AEACABADAFACA9AAAAA6A19F9E9C9995
919192908F9293908C8A888784807C7F82848585
3C382E2723262A2827292B2B2927241B1D47768D996B7A7276A2CBC5B9BDC2BEB9CBCC8E
2E2628292B3036424F58606A737575787A7E81817F808183868686888B91969694959799
9CA0A4A7AAABACAEAFB0B1B2B2B2B4B9BDB9B4B1AEABAAABACABAAACADA7A19F9D9C9B99
97959392929393908D8B898886827E7F82848586
51303038413629292B2A292D2F2A241E20395A83A37C75737687BDCCB4BDC0BBB7C8CEB9
6C2A23242F32373F4A55616A717577787A7D7F7D7C7E808386888B8B8C9297979798999B
9DA0A4A9ACADADAEB0B2B3B3B2B3B4B7B8B4B0B0B1ADAAADAFADABACADA9A4A29F9E9D9A
97969594929394918E8C8B89868381807F828585
6831352621252B2D2E2A272E332C2423272E4074A18F74737B72A6CCB1BBBDBCB9C1C3DD
AE3B2A243132363C445361696E757979797B7C7B7A7D8183868B8F8F8F939798999A9B9D
9EA1A5AAAEAEADAEB0B3B5B4B3B3B3B3B3AFADB0B3B0ACAFB2B0ADACABAAA8A5A19F9D9A
96969794929394928F8D8C89858584807D808384
5332312A292A2D2D2D2C2B2D2F2D2A292929335E869D836E7B6F8BB4B8ABBEBEBFC3C4D8
BBA13F1F292A343B445260676C73787A7A7B7D7C7C7F8284868A8E91929395979A9B9C9F
A2A4A5A9ACADADAEB0B2B4B4B4B2B1B2B2B1AFB0B1B0AFB1B2B2B1AEACAAA8A5A29F9C9B
9A979493939393908E8C8A878584848280808080
3A352C2D2E2E2E2D2C2D2F2C2A2D2F2D2A272B4764A0956C7B727497BD9FBDBFC4C2C2D1
D7C07A351F20313A45525E656A7177797A7C7D7E80828485878A8D9194949396999B9CA0
A4A6A6A8AAACADAEAFB1B2B3B4B1AFB1B3B3B2B0AEB0B2B1B1B2B3B1ADAAA7A5A39F9B9C
9C9691929493918F8D8A87858483848483817E7E
3E382B2E32312F2F2F2E2E2E2E2E2E2D2B282935488CA27D736F717FB5B5B1BBC1C2C2C9
D0D8B54F30282935444F5961676F7678787A7D7E80818386898B8D9093959596989B9EA1
A2A5A7AAACACABADB0B3B4B1AEADAEB1B3B3B2B1B1B1B1B0AFB0B1B0AFACA9A7A5A19D9A
979593939593918F8D8A87858484848382818181
45392B2E34333031312E2C2F322F2C2C2C2A29283370A5906F6B726DA5C9A8B5BCC0C2C4
C5D2C9B132342432424C545D656E757676797C7E7F8081868A8C8D8F92969897979BA0A0
A0A4A8ABAEACAAADB0B4B5AFA9AAAEB1B3B2B0B2B4B1AEAEAEAFAFB0B0AEABA9A7A39F98
93939494949391908D8A86858585858280828485
4134252B3433312F2D2C2C2E302E2C2D2D2A2826315092A383636B688FB7B8A9BBBDC1C0
C0CCCFCA8D3231344047505A656D737474777B7E81818185898B8E9092969A99999CA0A1
A2A5A8AAACABAAACAFB1B2AEAAAEB2B3B2B0AFAFB0ACA9ABADAFB1B1B1AFACA8A4A09C98
95939291909192908D898684838484817D7F8282
3B2E21293333302C292A2C2D2D2D2D2E2E2B2928333476AA98616769799EC6A1B7B9BFBE
BDC4CBCFC57831313F464E59646C717374777A7E82828184888B8E9093979B9B9B9D9FA1
A3A6A8A9A9AAABACADAEAEADADB1B5B3AFAEADACABA8A6A8ACAFB1B1B0AFADA7A19D9998
97938F8C8B8F93908C888583818283807C7D7F7F
352F292F36322E2D2C2A2A2C2E3030302F2E2E2A2D2C5391A0786C6A6D92BAB5A9B3BEBF
BEC3C7C8BFC961313842505860686F7274787B7E808182868B8C8D909497999B9C9D9EA1
A5A7A8A6A5A7AAACAEAFAFADABACADACABABABACADABAAA9A9AAACADADACABA7A29E9B99
97918C8A8B8F918D88868583828282817F808080
3131313537322C2D2F2B282C313333323032322D292B366D9E91776B6687A6C69EAEBCBF
BFC0C1C5C5D0B3443B3E51565C656D7175787C7D7F8082888E8D8C909596989B9D9D9DA2
A6A8A9A4A1A4A9ACAFAFAFACA8A6A5A6A7A8A9ACAFAFAEAAA6A6A7A9AAAAA9A6A4A19E9A
958E898A8C8E8F8B868584838382818283828282
2F30313333302C2C2D2B2A2E333433323132332E2A2A314A87A0886164768FB1A9AFB6BA
BDBFC0C5C7D4BAA7503246515C656C717476797C7F8285888A8C8D919597989B9E9E9FA2
A6A7A8A4A1A4A9ACAFAEACA9A6A6A6A6A7A7A8ACB0AFADACABA9A8A7A7A9ABA8A5A4A39C
948E8A8A8B8E918D888786848382818182828282
2E2E2E2F2F2E2C2B2A2B2D31353433323232322E2C2A322C69A2965F66687996B5B3AFB4
BABDC0C3C7D2D2C58C3F40485C646A6F7374757A7F848887868A90939697989B9E9F9FA2
A5A6A6A4A2A4A7AAADAAA7A4A3A5A8A6A5A5A7ABAFACA9ACAFADA9A6A5A9ADA9A5A7A79E
938E8B89898D918F8B8988858382828180818282
2F2D2B2D2E2E2D2B2A2A2C32363431303031312C27252A26498796856B656B8AACBFAAB2
B7B9BBBFC5CCCFD5B17F513B545A676C707274787D838887868B90949798999A9B9C9DA0
A2A3A3A3A2A2A3A3A3A09D9C9C9FA1A09FA0A2A5A8A6A5A8ACACABA8A6A8A9A6A3A6A8A0
97908A8685888C8D8C8A87838081828180828585
2F2C2A2C2E2E2E2C2B2B2C3236332F2E2D2F3029232224262E628EA9746963819EC7A9B0
B2B4B6BBC0C5C8D2CEC16F394E5362676C7074777B818687878C91959899999897989A9D
9FA0A0A1A19F9D9B999693949698989897999C9E9FA0A0A3A5A8AAA9A7A6A5A2A0A4A7A3
9C9188838183868A8C8A87817D80838180838788
2C2C2D2D2E2F2F2C2B2D303234322F2E2D2D2D2924232422273E7B9E8D75637690B9B4B0
A7ADB5B8BBBFC4CDCFD1A4674F51575F696F74787B808687898D929496999B9A98989899
9A9B9C9C9B999796959290929494949392949596979A9CA09EA1A4A5A4A6A7A29EA1A4A4
A1958883818285888A898783808081807F838687
292C30302E2F2F2D2B2F33323130302F2D2C2B292726262025206385A185676D81A3BFB0
9DA6B3B5B5BBC0C4C8D2D29B5C5C4D57656D74787B8084878A8E929394989B9A99979696
969797969593929394918E9093918F8E8D8E8F8F90949899979A9D9FA1A5A7A29C9DA0A3
A3978A84818284868888878683817F7E7F828687
2B2D30313131302D2C2F32312F2F2F303031302B2725241F211C437099996E6A7285BDAE
A0A6AFB1B3B6BBC1C7CDD1BEA1585A56586370767A7F8385888B8F929394949596969696
95949290909192959690898D908D88888886898B8E8D93839696989B9EA0A09C9897979A
9C968E837B7D82858787858483817F7E7F848889
2E2E2F313332302E2C2E312F2D2E2F313435342E272422201F1F275985A5796B666BB1AD
A7A8AAADB1B3B6BEC6C8C7CEC59D54594E5C6B73797E818385888C9093908D8F92949596
95918E8C8C8F9397988F85888B878280808084888C888C70949192979C9B989796939092
94948F82767980838685838282817F7F80858B8C
2B2D2F2F2F2E2D2C2C2F312F2C2D30333535332C26252523211E1F4064938F735E6693B7
B3ACA1A7B0B3B5BCC3C6C8CDCAB99C555A5A676F787C808386888B8E908E8C8E90929392
91908F8E8E909395948A807F80817F746A847F86858E776F88807B8C9D9A93989D9B9895
938E887E76787C81848483828281817F80878F90
282C2F2D2B2B2B2B2C2F322F2C2D30333634312B26262725231E1E2C43769E805E6674BC
BDB29DA4AFB2B5BAC0C5C9C8C5C9C29B5658666D757A7E838788898B8C8C8C8D8F90918F
8E90929190908F908E857B76747A7D6B58887C8581966C7B83776D869F9B939CA5A6A29C
948A827C78787A7E828383828182828080899294
2A2A2A2A2B2C2D2D2E2F302E2C2C2D303333312F2C2825252521202230519097735766A4
C0BAA9A8A9AEB4B9BDC3C7C9C8CBC9B28D705C626F767C80838586878887878B8F90908F
8E90928F8C87838789847C7169727A695A7C808A87835D6C76685E80A3A5A1A6ACADABA5
9C91877F7B7A7C7C7D7F818080818381828A9394
2C2825272B2E3030302F2E2F2F2D2B2D30313133322B23242624231E263077A48B515F87
BABFB9AEA4A9B2B7BBC0C4C9CBC8C2C6C18F5F5D69717A7D7F818384848282888F90908F
8E8F8F8B857C767B81807B6E646E796F6673878D8F8F949FA89F969CA6A9ABACAEAFAFA9
A0968C847E7D7D7A777A7E7F7F818383848B9294
2B272325292D3031302F2F3439342F2F3131323537302927262423212726568B95765771
9CBCCAB5A0A3ADB2B8BCC0C7CBC9C6C8C8AD8E715D66777B7E7F808283807F8891919090
8F8D8B867F776F69676D7474747D8687888D989B9FA0A7AFB4B1ADAAABBBC6B49F9D9D92
8B888784827F7C7976787C7F82828282838C9496
2B272424272C313231303039413B33313131323639342E29262323262D223B6B949A5763
7BADD2BB9E9FA7AEB5B8BCC3CACAC8C6C3C5BE8D5E6374797C7D7E80817E7D8791918F8F
8D89837C756F685B535E6E7B858B8F99A1A3A4A8AEB4BBBFC1C4C4BEB6AA9F98928E8A7C
7478808384807A7776777A7F84838181838C9698
2C2B2A29282D333434302D363E3A332F2D2C2E3336312B29282623201B4127537C977967
6385C0C6A19FA1ACB7B8B8C0C7C8C8C7C5C8C5AD907A6B6F787B7C7C7B7C7E868E8F8D8B
877F75675B5A5C5D6168717F8A87828388909CADBDC2C3C6C8CBCDC9C2B5A7978A8C8D8D
6D737C81837D767677797C7F81828282848B9394
2F30302C2A2E34393C322A303836312D29282A2F332D27282A262223291E37475C809872
555CA5C9A6A19BA9B7B7B5BCC3C6C7C7C7C4C2C7C3986C6B74777977767A7F84888A8986
7F746651414550637476767F857A6D64637289A6BFC6C7CACCCFD1D1CDBFAE99888D8F9D
6B727A7E7E797374787A7C7D7E818384868B9091
36322C2A2A2D34465642282C3535332E29292B30342F29292B27242529273035445B9184
584986ACAB9E939EADB0B1B8BFC4C7C8C8C6C4C9C9B4997D686B7475777D82818081817D
75685841323A4A5D6F787B776E5E4E484850607A98B8CDCECED0D1D0CCC4B9A5928A8284
68717F7A727172767A79777B7F828587898E9394
3C322726292D36556F50292A3233332F2B2B2D3337322B2A2A2827282A2B2B2830397C90
63456B8AAC9F9097A1A7ADB3BAC0C5C7C8C7C6C4C3C9C69768666F73787F827D76767570
685A4A362935485968767B6B5544383333353D4F6A9ECAD0CED0D0CECAC8C2B29D846F65
67738275666B73787B767278808486888B919798
3830272528313A69774C342C2D2E2F2D2B2B2C3338312928292A2B292728282225316183
77575C799EB5A2A09C9C9FA6AFB6BDC3C7C9C9C6C4CACAB39679646973797B736A66635D
55483B302D394B5F6F75715C41424B58625547404D6BA9CFCFD3D0CFCCCDC9B79E795A57
627D746B61687174757474797E83868789919899
332E29262634417B754140302A282A2B2C2A2B3338312726282C2F2B252526222434486C
8771596E8AC5B6AE9C96959DA7AEB5BDC5C9CCC9C5C5C5CBC69565636B6F71695E57504A
43382F2E333E4E657670624B394D645C50565C463D3C82C9CED5D0D0CECFCAB5976B4752
62846363616971706F73777A7D82868788909799
302F2D282930528D5F344233292627292C2C2C3337312A27272D312E2A27272E383C4353
849070696EADC5BBA6A2A2A8AFB3B7BABEC6CDCBC8C7C7CDCBB1916C575F6962564B413C
37312D2E323D4B6374624E3C52575A4A3C49515B472B5CB5CBD2CACDCECAC3A5815B435C
777B59606A7073716F757C7F808487898B8F9394
2E2F312A2C2F659546284133292625282C2D2E3236332E2A282E3535332C293B4D443F3A
75A48A6C588CC7C3B3B0B0B4B8B9BAB7B7C2CCCDCACAC9C8C6C9C1795254615B51453934
322F2E2E3139455D6D523B31695B483223374A70542C48A4C8CEC4C8C9C0B28C654B4264
856C5260747877737179818384878A8C8E909191
2F2E2E273037787D392836312D2A282A2D2D2E2F3031322C2937464844382B221D212E2E
538F98895676A2B7C2B4A9ADB4B6B7B5B5BBC3C9CDCBC7C7C6C8BDBB71584D54554C423B
36302B2B2E343D505D463232564A392B251C38544F364497CFD3C4C2B9B58965453C3F55
6A584C617B7D7A76747A818486888B8E90929393
2F2E2E283344885E312B2C2E2F2E2C2C2D2D2E2F32373B342F3F50534E3C2A2829201B22
326D9BA3626778A5CBB8A2A5AEB1B3B3B4B5B9C5CFCBC4C3C3C8CCB7B66C474C59544D46
3D322A292C2F35424B3C2D363D362D252927634E415D83ACCFCEC0B5A0A05D412B2F3B42
47474A657F817C7A787B8184878A8C8F91949696
2C323E4330548C4D2D2B2F2E2D2C2A2A2B2927394E575B534C5C6752382F2B26221F1F20
29498CA0846C6290BDCAAAA9A9ACAFB2B4B6B9C4CDCBC6C4C3C4C4BFB7B46C424C4C4C47
3F362E2D2E2F31363A352F3434312C292B29493E3E58769CBEBBA99376693E30272A2F2F
3240536D8385827E7C7E8285898A8C8F92959697
293A4C5A2C608A412B29332F2A282828292628496B767671654F382B24272B2824242721
262A7390A37A587CA7D3B5AFA5A8ADB0B4B7BAC3CACBC9C6C3BEBBC5CCB6B64C49434A46
413A35323130302F2E31333331302E2D2D2F2F333B4B6186A39E8A6C4C3529282B282524
29426076858886827F8082868A8B8C8F93969798
2A4C45492F5B803A2A262F2B272525242A254D65797A705E49392C26242A2F2B25272822
221F4979A39462728CBEC1B4A5A9ACAFB2B5B8C0C7CACAC6C1BDBBC2C4BDB2AE66404642
433E3835333131303032333332312F2E2D2F2C2F353E4A6479715F4B382B27272926232D
3D587380878784817F8082878B8C8D909396999A
305838323254743529232926252323232E2E727A7B6F5D41272122252A2F322E28282924
211D235E92A87570749EC5BAA9ABADAFB1B3B6BDC4C8CAC6C1BEBDBAB8C0C1CAA6574C42
46413D3936353435363534343433312F2E2E2F2F3032374550483A332D2C2C2A2927293F
5A7184888785817F7E7F82878C8E8F9193989B9C
4B40332B2F5E682F282226262626272C375A797362503E312725262A2D30312C26272725
1E1C1E466DA68E7B6E7AACC5B8A1AEADB0B2B5BCC3C8CBC8C4BFBBB9B8BCBBD1BC874E42
42474946413E3A3532353937343332302F2F2F31323130343735312C2827272A2E2C3A5B
788289868282837F7D8085898C8E9094989A9C9D
5F262F292D685F2B29222526282A2E3944827361433023262E2E2E2F30302E2925262726
221F223045959F8A725D8DC7C39CB0ACAEB0B4BBC3C7CACAC8C1BAB9B9B5B3BFC4D2936C
494C54524E49433A3339403C36353534333232333433322F2D2F312E2A26252E3C355171
8C8D88817B7F837F7B80878A8C8F92979C9D9D9D
49272D2C345B612C2E252525272D36495877644C2F2726292E2E2F2F2F2F2E2B28262820
382C23212C70929F805676A8BAB8ADABAAACB0B8C0C5C8CBCBC4BDB9B5B1AFB5BDE2D097
59474D525956514D4B4C4D453D3C3D3F3F3B35312F363E4140362B30332F323F4A776060
7A8F7F7D797B7C7A787D83878B91969A9D9E9E9E
2D2D2C313B4D622E32282724263140586B61503723262F2E2D2E2E2E2D2D2D2C2C2B3121
4C3824181C4879AA905D6884A8CFACABA7A8ACB4BCC1C6CACCC7C1B8B1ADABAFB4BCC3BE
AE6C4E5262615F6265615B5149484A4E50493F322B3D525B5B453038423E415974728754
6087747876757473747980868D949A9D9E9FA0A0
2C2D2A2F375556342A262825263649616F5A3D2D23252A2B2C2F302D292A27292A23262C
4B341C181C3558919D7768728BBABCB4A6A7ABB0B6BDC2C6C8C7C3B9AEA8A6A9AFB6C3D1
D0C571645E60666A6D6B67646161626567645B3F2D476B88987653465F634B6072798362
627871706C6C6E6D6F77828C94999B9EA0A1A2A2
2F2C292D315D473923242926273B51656E522F28282626282B2F302C262828262A405653
402C1B1C2228386EA090736C739BC4BAA9A8AAADB1B8BFC2C4C6C5BBAEA6A1A3A9B1B9C2
C7B6B98B61616C6F7272727578797A7C7D7D7651365B879190857B5C798557616A747871
66676C66606267686B7887949E9E9D9FA2A3A4A5
292A2B2D2D563C3A2C2928252C4056636B413628272526282A2C2D2A2C243F3E436D744B
34333E21211B2551829290807487A5B3BAB0A4A8B0B4B9BDC1C6C7BFB4A69C9DA2ABB5BF
C6C5C5AE927C6C6F777A7D7E7F84898A8987826856759AA19E948975838A735E6C6C6A66
5E5A5C56525357606D7D8E9BA5A5A2A3A5A7A7A8
23282D2C28493238382F26252D42585E62323F2D252528282928282932275B5B5974521F
2D425E2523161B375C89A9977C787FA5C7B8A2A6AEB1B3B9BEC4C8C4BBA999979CA5B0B8
BFC5C7CAC39A747681838382838B9292908D887D788DA5A6A1988E89838387596A605B56
534F4B4948494F60758696A3ABAAA6A7A9A9AAAA
242428384670554736404B5A464C4E5C462F353C2425272728262529322745606C865624
2D4E57272E201D273F73A19C89716A8FB8B9B1AAA4AAB3B7BBC1C5C5C0AF9E97979FAAB2
B9C0C3C9C9B79E7F686E7D848B91959898948F8D8F9AA5A49F968C857B7574565A524D48
444242454A5564778A98A2A8ABABA9A9A9AAACAD
2626272828513C3E3A3A34492339475C2C2F2A4825272627282524283251686237665A30
345745283D2D221E28598A9895755D789DB4BFAF9DA6B2B6B8BDC1C5C4B6A69A949BA5AD
B4B9BDC1C4C7C4AD9480747F8F9293989C9793979D9E9D9B978E84796E6359534B474440
3D3F444C576B8092A1A9ADADAAABACAAA9ABADAE
2527292929403B44464138422F3E484C2B2E2C3E2E2C28292B272738466E6724254B5C2B
495B34254B341E1C264264899A8F5E66799CBBB3A5A8ADB1B5B9BCC3C5BCAFA196989FA6
AFB7BDC0C1C6C7BDAD95817D7F868E949B98939697928B88847C72675C4F454745444348
4F555D6B7C8A97A3ACAFAFAFAFB0B1AEACACADAE
24292E2A282C36454F4437343842493B2F2D2F3236302B2C2F2A29465A73434A35465C26
5D59262356391C1E292F3D7197A6695D5A82ABB3B0ADA9ADB2B4B7BFC5C0B6A79A979AA1
AAB4BDBEBEBFC1C7C7AD9181787B838A92918E8C89817874706A63584E433C4149494C5A
69727C8FA0A7ABB0B3B1AFB0B3B4B5B2B0AEADAD
222C362F282B353B3F3832333B3B3F332E2C2E323A332B2C324150485557383735376037
654F29285F3E201D23212B4A879E866C576B8AA6BAB4A9AAAEB0B3BBC1C0BAAA9B989A9D
A3AFBBBEBFC1C3C5C5CDC99E7065666E71767978746F6A6764636158504F525860646976
848D95A1ABB0B2B5B6B4B1B1B3B3B3B2B1AFACAC
212E3B332A2F35322E2D2E353A36332F2C2B2D343A332C31383536264F3D302C362C624B
67442F2B62452921211B23266F8A9D81615E6A93BAB8ADAAAAACAFB6BDBFBCAC9C9A9B9B
9DABB9BEC1C3C4C4C2BFBBBAB080505C555D636361616160606467605C6570757A818993
9CA3A8ACAFB2B4B6B7B5B3B2B2B1B0B1B2AFADAC
212B37332E363D3B3734313434402A2A2A29292D312F2D313635382955372B2530255F5A
654329235D593536362A231F476E95907F685B799EB4BFB4A6A7ACB2B7BAB9ADA09B9A99
9BA7B5BCC1C2C2C3C3C2BFBDB7A5904748444E565F6468696B717877777E85888C939AA0
A6AAADAFB1B2B4B6B7B5B3B1B0B0B0B1B1B0B0AF
20283231323B4443403E3B38324C272A2B282627292C2F323532352D5A3F2A232A225864
6442241B526C464B4839292225507E959B7958627DA7C9BBA5A4A8ADB2B5B5ADA49D9998
9BA5B1BAC0C0BEC1C4C0BBBCBCBDB49F68524753656E74787C838A8F93949597999FA5A8
AAACADAFB1B1B1B4B6B5B2B1AFB0B1B1B1B2B3B3
1F262F2E2D31354D635F554E454E3C39342D28282A2C2F3439333328545D262526264762
6F3D26203D5F392B3737322B24375380A188675E638BB3B8B3A8A3A8AFB1B1AEA8A29D9B
9EA7B1BAC0BFBCBEBFBEBCBAB8B9B8B9AB8D716C6F7780868B9094999C9E9FA0A2A5A8A9
AAACAFB0B0B1B1B3B4B4B4B2B1B1B1B2B3B5B6B6
21262C2B292A2A3443596B665B5250473E342B2A2C2D2F373C342F234B792827242C375C
79382C2327686534212C3A342B242B6398917A61526E93ADBEAFA0A4ACADADADABA6A09F
A0A8B2BAC0BEBBBABBBCBCB7B2B1B2AFADA9A28F7E838C93989A9B9EA0A3A5A6A7A7A8A8
A9ACAEAFAFB0B2B2B1B3B5B4B3B1B1B3B5B7B8B8
2E27272D3622373C454A5160686846433F362E2A292B2F363B30272842733C24272F3B5A
73393A2A274A72363922362E292022497383856B535E7494AEBDA3A4A4A6A9A9A7A39F9E
A1A8B1BAC0BFBCB9B7BABBB6B0B0B3B4B7B1AA9F969495989B9EA1A3A4A5A6A6A6A6A6A7
A9AAABADAEB0B2B1B0B1B3B3B2B2B1B1B1B4B8B8
3B2E252F40214341403531546F77393D423A312925282E35392D212E396552212A314356
663A45322F265C7E3E193129252021324A6E8A785F595F7B96C3A8A59EA1A4A4A3A09D9E
A1A8B0B9C0C0BDB9B5B8BAB4AEAEB0B3B5AFA9A9AAA39C9A9B9FA4A5A5A5A5A4A3A3A3A6
A8A8A7AAADB0B2B0AFAFB0B1B1B2B2B0AEB2B8B9
3F492D2F31343534322D2B2E3B696F644F40332A26282D353A2F242C34596124272F434E
51373B33332644736B3F2D23211E1F2331547B837F6F666F7FA9ACADA6A29FA0A1A09FA0
A2A9B0B8BFBFBCB9B7BABBB4ACA7A1ABBAB6AFACA9A6A29E9B9DA0A2A3A5A6A4A1A1A2A4
A7A6A6AAADAFB0AFAEAEAFB1B2B3B4B2B1B5B9BA
3C5E38302245252624262C3747525D615E4B362C28292C353B332A282F4D6A2A25304545
3D342E31362F2E618E62281E1E1D1E1D25436A879A8A776D6D89AAB0AEA59D9EA1A1A1A2
A4AAB1B8BDBDBBBABABBBBB3A99B91A3BBBBB5ADA5A5A6A19C9A9B9DA0A4A6A39F9FA1A3
A5A5A6AAADAEAEAEADAEAFB1B2B4B5B5B5B8BBBB
2F4B423625392925212A374F3E3E44535D503E32292A2F3438332D282A476536273C5637
323B242B313432587B56241E201D1C27315D677F899F8B796A768FA1AFA9A0A0A1A1A2A4
A7AEB5BABCBBB9BBBBBAB6AFA28286A8B3BDBEB7ADA9A6A19D9A999A9D9FA09E9C9EA1A2
A3A4A6A9ACADADACACAEB0B1B2B3B5B5B5B8BCBD
2232463A2B2A2E28253646663C2F253D565348382A2C313435332F2827435B432B45612B
2B40202931363A505E41211F231D1D354B7A646C6BA69B89706D738FA9ABA6A3A1A1A3A6
ABB2B8BBBCBAB8BBBCB8B0A79B6D7FAFABBCC4C0B7AEA6A29F9B99999A9A9B9A9A9DA1A1
A1A3A6A9ABACACABABAEB1B1B1B3B4B4B4B9BCBD
232B39332B282B2C3058594B362B2735475153412E2D303437353029273D4F512B3D4E2E
2B382B36452F3649593F221F221C2039757C5B404E869C948173708095A4AEA79FA1A6AA
AFB1B4BBC0BCB8BBBDB7AF979D6C83B2AAB9C0C2BFB7ADA8A49F9B9B9D9E9E9B989BA0A2
A3A3A3A7ABACACACADAEB0B1B1B1B2B4B7BABCBD
26282A2B2B2828334075642E342D3031374A5948332E2E343A37312B2939435A2E343733
2C2E39485929364556422922221D284398764E17335C8F97918175768099AFAAA0A3A9AD
B1B0B0BAC3BEB8BABCB5B088A0748AB3AAB4B9C1C6C0B7B0A9A39F9FA0A2A39D989A9EA1
A4A2A0A5AAABACADAEAEADAFB1B0B0B5B9BBBCBC
262728292A27294054685037423A342F2E3E4C42352F2E343A3834302E363E503D3A342E
262C3A5D5E34494A4942392D252B396A9467361325406986969C797474869AA7AFACA8AA
AEB0B3BAC0BDB9B7B6B4B4879E838BB3A2ACB3BEC6C5BFB6ABA6A2A1A2A3A4A19E99979C
A1A09FA3A7A9A9ABADADADAEAFB1B3B6B9BCBDBE
272728292A272B4C675238434D4438302B333C3B37312D323939383432353A424A413529
222C3A6B5D445D4F41474C392937498F875A231A1D293F6C90AF8178707583A0B9B4A9A7
A9B0B7BBBCBBB9B4B0B3B78B9A928DB09BA6AFBBC5C8C6BBAFA8A4A4A4A4A4A5A49A9296
9D9D9EA1A4A5A6A9ABACACADAEB2B7B8B9BCBFC0
2B2826282B282D4F714030353C3B39363332333A3F352B2F35393A363231333C473F332A
2735455E554D6047515558575B5C78AA8B60291F1C1D294D729B96897672778EA6B3B9AF
A5ADB8BAB9B8B6B2B0B4B696929597A99EA7AFBAC3C8C8C1B8AEA5A6A8A8A6A5A39E9997
96989C9FA3A3A3A7ABABABABABB1B6B8BABDC0C0
2F2A25282D2A2F5273342D25292F373C3E362F3B45392A2C32373B37322E2D37403B332E
2E3C4C4C4E566044676560524B39669C8D6733231D181D314F7BA1988377727C8EACC3B6
A4ACB7B8B7B4B1B0B0B3B29F8B94A2A2A5AAB0B9C1C5C7C5C0B2A6A8ACABA9A5A2A3A39B
9395999DA1A1A1A6AAAAA9A9AAAFB5B8BBBEC0C1
2E2A25282D2E33636B3D2824292D3340493D30373F372E2F32363939372F2A323B3B3835
33363D4655616C66775752434135699177432C201F1C1E24345983969D8978767E98B2B5
B1AFAEB3B7B2ADABABAEAD9C8895A7A7AAADB1B6BCC1C5C4BFB4A9A9ACAAA9A8A7A7A6A1
9C989697999DA0A5A9A9A9A9ABAFB4B8BBBEC0C1
302C282A2E323671634A26262D2C2E404F433434363432323234363A3C31282F383C3E3B
372F2D445F6972808244402E303169835C20231E2222231F213A5B89AB9B8377738399AD
BCB2A6AEB6B0A9A6A5A8A8968796A9AEAFAFAFB3B7BDC2C1BCB4ACAAAAA9A8ABADAAA8A8
A79E969394999FA4A7A8A9AAACAFB3B7BBBEC0C0
413D362F2C303967694F2A282D2B2B3843433F3A363635312E2F32383B3229303B3E3F3A
3432354E5F6C5B617E39362A303A7E854624272324242320202738638BA7958171737E99
B2B3AFAFAEAAA6A5A5A7A6938595A9AFAFAAA6AFBABEC0BFBBB5AEABA9A8A9ABADABAAAB
ACA8A29B9595989FA6A7A8AAACAEB1B4B8BBBEBF
4E493F332B2F3B586F53312B2B2A2A2E343F4740373738312B2B2F3439332E3640413F37
323842565E6A3F3A7233302A374B9185342E2C2826242324241D1D3C5FA59F8F776A6882
A0AFB7B1A8A6A5A6A6A7A5918393A8ADADA59EADBDC0BFBDB9B5B0ABA8A8A9AAABABAAAC
ADAFAEA69C96939AA3A5A7A9ACADAEB1B5B9BCBD
61625E452F2D37536E56373029282A2B2E39423A32373C352C2D313133383E4346433E38
363E4B485C612D345C39342648728F712C27262525232122231C1A273C778BA7907A6471
869DB1B7B5ACA2A4A7A7A390818E9FA7AAA5A2ABB6BDC0B9B1B3B5AEA8A8AAAAAAA8A7A8
A9ADAFAFACA096969BA0A6A9ACADAFB2B5B8BABA
3D3D3D383430335068583F3328282A2A2B333A332D363E372F30333030404F4F4A443E3B
3B434F3A5A582134464039265795885C2A2224252724212122201F1B21446DB1A58D6C68
7088A3B6C0B3A2A3A6A6A18F808A99A2A9A9A8ABB0BAC1B6ABB1B9B2A9A9AAA9A8A5A3A3
A4A8ACB5BAAD9D96959CA5A8ABADAFB2B6B7B8B8
5B5243372E2B3049615C4F2B2A272A2A2B3136312C3138342F3032363B49544C41414344
443F3E425B5A21323F3B33305296855A2A2A333535302A262422211C1D2C49879C9A8978
6B73849FB6B5AEA8A1A19D8C79889DAAB3B0ABACB1BBC2BBB3B6BAB2AAA8A8A7A5A3A2A0
A1A5AAB2B8B5AEA69F9D9DA2A8AAACAFB2B4B6B7
7861413127272E42565D5D262F282B2A2B3033302C2E31302F30333E4951534639404A4D
4A392D4B5C5F252F3C342E3E4E8E845E31384746413A312B26242321201F2954839BA38B
6F656682A1B0B6AC9F9D9886768AA5B4BDB6ADAFB4BCC3C1BDBCBBB3ACA9A7A5A3A1A09F
9FA2A8ADB2B9BDB6ACA0989DA4A7A8ABAEB2B5B6
766C583B2425303A45535C36332D2D2C2C2E2F2E2E30312E2D343D4B545048423F49534E
45342C3B5F612129332F2E486089886D4D4F5965694C2C2525242422211F2337577E9D97
846C5B668198ACB1AF9F93778093ACB6BEB7AFB2B7BCC0C1C0C0BEB8B1ACA7A5A4A2A09F
A0A3A7ABB0B6BAB8B2AAA2A1A2A4A7ABAEB2B4B5
75562F26272C33333447564A3933302E2D2C2C2D2F32332E2C3A4A565B4C3C4048535A4C
3B2F2F2C615F1E232D2E3655758389766164685E4E3A292525252423232325242D5A8898
96785955627C98AFBAA38E6C8F9CAFB6BCB6B0B4BABBBDBFC2C2C1BDB7B0AAA7A6A29FA0
A2A4A6A9ADB0B3B6B6B3AEA7A1A2A6AAAEB1B3B4
7358352E2A2F352E2A3E4F5D3E37302E2D2C2D2E3031312E2F44585852463D434E595E47
302C333A5B4F2421283E536B7F807B62473A312925292F2C2828282522232420233E5D7C
8F7C606757647795ABAA8C759F9FA0BCB6B6B3B5B8B9BABDBFC0C0BCB7B3AEA9A5A29FA0
A1A3A5A7A9ACAFB4B8B5B0A8A2A0A0A3A7ADB1B3
725B3E3733373A2F26384869443C312E2D2D2F2F2F2F2F2F334C615746424149525C5E42
272A3649543E29242B4F717F82796644252832343433322E2A2B2C28242324232428345A
7B7A6A7E5653567692AB8780AD9E8FBEB1B6B5B5B6B6B8BABCBDBDBAB7B5B3ACA5A2A0A0
A1A3A5A5A6A8ACB3B8B5AFAAA49E9B9DA2A9AFB1
70615041524F4C3D313B475F50473A34312F2F2E2D2E3033394C5B524543444C55595640
2B2D36495239262F44537B807A664D3625272D2F303132302D2C2C2C2C29262525242940
59676E8266574A5E7392777BB19D89AFB6B8B3B3B4B5B6B7B8BBBCBBB9B8B5B0AAA6A4A2
A2A4A7A8A8ABADB2B6B4B1AEABA29C9FA5A9ACAD
6F6660496E675D4A3B3E47515B50423B35312F2C2B2D31363D49534D4645474F56554E3F
323035465238223A5D537E7B7154372D2B2D3132323131302F2D2B30332F29282727282D
39577187755C434B587B6B76B19C879EBCB9B1B1B2B4B6B5B5B9BCBDBCBAB7B3AEAAA7A4
A3A6AAABACAEB0B2B3B3B2B2B1A79EA3AAABA9A9
6F67644B75695F5E5E50454C5D53443C36322F2C2B2D31373F49514C4645475057544C3F
333134465237213C6354807B6F50312A2B2D313131313030302D2B3035302A2828262629
324661518875605852614864B39E869BBDB9B0B0B2B4B6B5B5B8BCBDBCBAB7B3AFABA8A4
A3A6AAABACAEB0B2B3B3B2B3B2A89FA4ABABA9A9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5D6685BBB54029292428262D425238333932392F2F3835392F3A37434B513F3B382F2D26
2B283E6A66665A7165535C62676A736F76827D7C83837B837D81827E8385888989888887
8C8E928B8E8C908C88898A8B8E8A8A8D8E8A928E8F9292929293908D9195938F8E929295
9090999493969B979B9B9EA0ACB1C4CFCBD1CFBE
5A597093C19C3E282C29242A373630343837372B323B30322F4135444C4D4236372F2E30
2B2742696164607A644A5C62696D7575757C7C7E7A82847F7F7E807F8586868A8B88898B
8B9090888C8A8F8B8F87888B8D8B8F8E8D9191939595928F919292909698999195949492
9293979798969A9B9BA0A1A7AAAEC4CFD1CDCCC0
595A5F729AC2953A2A262A2D38342F364438322E3335332C343D384A413D422D2E34302C
292A416364675F7B59515E69766E6D7777787D7E818281818087837F8284838B8786898B
8F8C908C8B88898B928A8A8E908D8B8E8E9694939595949595979292979C9C9394979690
94919694959B9B999B9A9DA4ABB0C4D4D3CECDC5
60595D667CACC06E2F2A24282B2A2B3D4030333031312A2E363E2F4E443E3C312D362F27
262A466C65685C77585B63656F70717276797D7B7E818082847F82828088878B8889898E
8D888D8E8C888C90928D8C908E938D949196949499979593939998999899A09A99939392
96909797949699969A999DA5A5B0C2D2CFCECCC1
5F5A5B59708DBFB35B2C27242B2D32342E30292C32332B2D3133324B4339363031343228
27304C74606A676F565E636A6E7073787A7777817F7E7E858382827C7F85888B8787878E
8B8889908B8B918B8F8C8F8E8D8F8E95949796949598969794999898999F9B979593928F
94979A9A97909897979C96A3A5AABECED1CEC8BC
625A585F6176A0C8AA3F2824242934312D2C2C3135343032383C3D4C403D433A33322C30
302D4B77696E6169515E6169737273747D7A7C827D8080837F8182848288858B898D898D
8D8F8D8D8A8C8C8A8D8B8C918C9294989A97979997979A94979C9696979D999899949494
939598959294939797989A9EA4ABB8CACECDC7BB
5C6A595A62658AC3C791372C31262C322834312E31332E2D313731413D3C3B2E322F2C2B
28264A706F6E666654616C6C717170767F7A79827A7D7E7D7E797E83848582858C898991
898D8E8F8B888A8C8E8C8F918F949697999897979B9A9694989D999C9B9C9B979794929A
9895939294949491909497969CA9B6C6CDCAC1B7
4E6955515A6994B3C7C57E3927252C2B2A313238383B39403E43424C4142423C3A3A2F39
3A3A5C72746770625D636B6B6F72787B807F7F7D7F828584838386818588888A8F8A8F91
8A8B8A8C8C8B8E8D8C9090959099999A9A9A9C99999B98989B9F9E9C9F9D9B9B9897979A
98959795929493918E8E95989FA3B1BFC9C8C0B0
516063596276939CC1CBC374383537363641403E373733383A343D3F3836342C2E32272D
2C325A6F705D6E565660646A707476787B787D827A80807E7F8280848384888D8B898D8F
8A8E8D8A8C8F938F91919397969B979D979999999A9A9C9B9F9CA09D9D9C9D9A96949A98
999796949697929291918F959EA1ACBAC2C5BBA8
65586F6A63748789A4C2D0BA4B2F2E303030343431312D353433413638363632322F2C2C
30345C73735F695554646169717076777B7D7F807A7F807F7C817F8482848B8B898B898D
8F8D908F8F918E93948D8F919398999B979E999C9D9E9EA1A49F9D9D9D9C9E9B9A989A99
999693919691918F8F8D8D949499A5B3BABFB1A1
9E5B63705F6A777D8AABCFD4A13A322E2D34383635323A393E403E3A3833393435312F31
31386077815E6751545C656D6D7275787979797B7D7C7D7B787D828682828685868E8A8C
8A8D938E908E8F8E918F91958E94989A9B9A9A9C9A9F9E9D9EA29B9D9E9D9E9C9B9BA096
969896969690958F8A8D8A8B8D919DA4B2B6A59A
B48A60646A5E65757D8EC0D4CB7730292A292E2B2F2A3232332D4641343436313332292A
2D3164777957664E575B606E6D73737A79797F7C7D7C7E7A8181847E7D8381818A898588
908B919591908F92909095949495969F9A999C9C999B9B9EA09F9B9DA19C9E9A9C9E9A98
969396908F918F8A868785888D8F9798A6A49693
ADAC72647566636C7283A2D3D7C05225262A272426292D31383D41343031302F31272529
262E6776795E644B555B676A7374737576747B797D7E7D8081827C7F8386898689898789
8E8D938E8F918D91929394979893949B99999A9A9E9A96999E9E9FA29C989C999D9A979C
9592948F938D8C86838B828385878D8F968F8486
879794616A746B6C6F7384BBCFCF9D2D29252C23292A323A434E5A3435312A2730232A2B
2F35637D7563634F52596970716F717578787A7D7A7F81817F82847F828685878B8C868C
92918D918E949393909493959A94969E9D989A979DA09D9C9F9E9F9F9E9F9C9D98979195
94958F8D898E887F7D807F808280858788817679
606F7E6D6D7A7F84847A879BB5B4B7633127232324262A3B524B4B46452C2C2D2D27333B
342C577179685D53515C61696B70777674767E7E7F7E7B7E7F88818580868687868C878D
94928F9191989294909491959493989C9A9397989D9C9D9E9FA3989B9E9E9A9794969893
938D868686827D7A7A80828287848686827C7477
4C5E6470707B8B949694999FA8A4AE9E5F3727262023282E383C2C312F2B2A2B31262F2F
2A3163747368524A505E666C68746F717577807E817B7B7C807F82828188888A898A8B90
8E95939294939595939187969693969A97969C989B9E9CA19F9E9AA09E9A9C9594949592
9089827E7B7A7E7C8082848784868685847E7777
2C3B46698D899399A1ADADB1B6BEC0B9AE8129252627242A2F2B2C342E2C2E2F3228312C
3130606E6D644D4E506365666C75777175767D7D787E818083828385858A88868A8E9190
938C8F8F909597959795969D979A9C9D999A9C9A9B9F9EA09D9D9C9EA29B979891949490
90817B74787D7F7F837F807C7E837F817D776F6E
221F235192979EA2A2AFC2B9BEC0C7C6BCA23C2325232728292727272B2B2F2D2E2F2F29
24295F6B70664D4E535F66636A6C706F7875787A7A7D7D7E838283848389888A88909090
92909492919796989696939599979A9F9C9B9F9D9F9D9EA09D9F9F9E9C9B96949494938C
8B7C777A7E808278736C6560666D78746F696064
201C222F81A4A6AAB1B4C5B7BEBFC1BEBCAE6534232128282A2525262B2A3432342F2C27
272E5A6D7069474F555C626466696E7473797C79807D7D7F83828180858787888B8C8B93
93938E9493999796969598979494989D9C9FA09E9F9B9E9C9E9D9C9FA296969895948F8B
857B757A848384816957463B4751615D5C575559
25221F2158ADB1ADB3BAC4B4B7BDBCBEB7AEA27430292A232126262525262C382E2A2E2B
2B2D576A625F4B4951605E60626B70717579787A7A7B808182808282868A8988888B8A90
8F8D8E9A9696939999969B9C98959A9C9A9A9D9CA09F9E9F9F9EA09FA1989394918D8F8A
82777981848688836541323132404D59605A6371
201D1D1F37A2B4ACAFADBFB3B3B8BDB9B3AFA7A15B3C35272521222226292D2F2F252729
252E5E6E585B47504C565D62656A777379777D7C7A7D82807F7E8284878A8D8C8B8A9090
919090959B94929A94979A9C9598999D999F9C9E9C9E9C9E9D9D999F9D9C9692948A8A87
807478878485848A78563A38394959667273777E
2920211D258CAEA5A7A7B4B4A9B0B0B4B9B4B6B4997B4C2D292620222222302D2B262829
2534606F645C464D4C555C5D666D746F797A7D807C7D857F7D83838288868C8A918D8D8F
908D9295959697959A9895979597999C9C9F989D9E9E9EA09FA09D9B9E97968F948A8A84
716C71817F89878585837770757E7F8082847E7A
2A201B1B1D62A89DAAA8A6AFA9ACA7B1B5B5B8BDAD8C774F3729242626272C2931312F26
273258695B563E3A47555A60656E7473767D7C7F837D84807F83808586838B908E898D8D
978D8F988F96999397959797949B9C9CA09A979CA19F9F9E9E9C9B9A9B969192908B9480
746C747C7D878A8786878684868D89848B847E77
28261D1D1C3BA0A3A3A59F9FA6ACA19E9B9FA9BDBAAA8F5D412621201F2635282F282A29
28345B6A675A47443D53585F697072747676837B7F84817F7F8383868686878D8D8D908D
928D939091949C9796989B9C9C979C9D9E9B9E9D9EA59E9E9F9CA29D9A9794998F918F83
756B72787D858F8D8B89888A928D8F908C837E78
26312720212A78A9A1A6A49996928180757782A1ABBDB191653124242428263227232728
252C5D71635943454A4C5C5A696D6F74787B80787D7F8280818581838887898C8B928F90
908F8F9395979796999598A19B9D9F9C9F9F9F9F9FA29F9E9F9DA19E9A959292908B8C7E
786870767D86868D8D8E898C8D8C908E8A827C79
25302C212225478C989A968881766B6D6476838792A2AD9C6E372925262323272E242F46
252E57715B4E4643444E5957636B7672777A7B827E7C827F80828686868C888F8E91918D
8E8F939C9399969695979A9D9C9F9C9F9C9D9E9EA0A29E9F9D9F9F9D9A92938E8B8D8A7D
746B6D747D83878A8D8B888B908D8F888680807D
24243226221E224C7883787A7A67656C6C90B5ADA38D909A875A452D23222B252B282822
232E5A6D5A43404B4E51535F5F6A747176767D7F7D7C827D81838685878B8D8A8B8F9493
948F939B97979A98969A9A96999C9A9F99A29F9CA19FA2A4A3A1A19B999899928C8B8F7F
77726E737C8087868B888A898B8F8484817C7D7F
2323302F2B1E23285165677E856A6E727290B9C9C3A682977D3424231F1E232925222A25
292A5C6C5C413847484F565D67686C737575797D7F808482838287858886878C8B8D9091
9393959A9B99989897999A969A9D9E9DA2A39FA2A69EA2A4A4A3A19D9C98989691908E85
7C797572767C84858387868483827F84797B7B81
25312C372F1F1B212E4F4B6D877672807B7E9EC9CACAABA0A33C28221F25272B27262C25
252C596A5D3D42474D525958656A6D7574767B7E7D8080818585858C8782858A898D9492
979693999697979896949B9A9E9FA2A0A0A0A2A5A59EA3A5A29D9F9D9B9892958E8E908A
837C7772797D8286868B8783817E7B7C7A7C7B7E
2A24293A32212330212C285C898A7578787992BFCCCECABFC57F2F2222272B2922282727
283056645A4137484553575C6066717577777D8080808784848486868A878C8F86909092
96999397959894969A9D9B9C9C989EA3A2A0A5A4A4A0A4A4A3A4A19E9B9D9494928F8E88
857D7C7A7B7C7B82838C857D7F7B7D7E79757A7E
232532382F2C1F1F221E2244829A7B7176737FA8D0CFD0CCD0B94926232A26282C242425
22285360543C414A4B545D61676A71757779777F8080858181878386878B8C988A929090
969892999899989A9B9E9B9B9F9A9EA09FA3A7A7A4A3A09EA0A1A39F9E9D999591928988
87827E817F7E7C838387837E7C7B7F7F79757681
232E3D4E3523201B1E1C1F2F6B8F867370747690BFCDCBCECCCEA3382524262925262722
24254D664E3A4247454B5761676C7171797E807A7E80808382878889898A8E8E8F949390
91989B9796999A9EA29E9D9CA09F9F9FA2A6A8A2A6A4A5A2A0A4A5A2A69F9E9A93938C8E
85858484808181847D84827C7F7C7B797B797C7D
26324C734D2620211E1D1D25508395796F797678A5C7C8CECFCECE893125262527212329
2729495C48353C45494D5A62666C72747582837D7B8083867E8487898A8A8689909A9290
96969B9997A1A1A1A3A09E9FA0A2A3A2A5A8A5A3A8A9A8A4A5A8A2A6A69FA09B96919089
8A8883838382848481817B7C7D7978787A7B7C7D
333D5C857646241E1B1B1C233770A08B6D7E767591BEC3CACACCCFC3642821232526211F
272E4B5544353A444A515668696B706F7B7E7D7D81838185817F898B8B87888D92989196
97999A969BA19DA3A29A9E9EA2A4ABAAABAAA8A7A9A8AAA6A8A6A0A0A5A19E9B9598918C
8B8A86858083868785827D7E807C787A7B7C7B7D
345166887758241C1D1B1A1E2659929E716F6F7185A8C5C9CCCBCCCEB546272121232A25
232947563F3A383C45555569666C7076777D7D858182848082828487898D8B909093959D
979C9D98A09DA1A4A2A1A2A0AAA7AAA6A3ABACA8AAABA9A7A9A5A5A1A5A1999B9897928E
89868884838383878381817D827E7B787A7E7B7E
43627E937F60261D1F241D1E243B819C7F756E707EA0C6C7CACCCDCECCA53F2623232321
212B41573C37343C45505B64656C7074767C7981818083858687838689918F928E939397
959B9C9F9A9FA4A2A0A4A0A4AAACADA6A3ABADACA8A8ABAAA9AAA7A5A5A69E9D9D979488
878584868587868883828383817C77787D7B7E83
53749BAD9869261E2024231F20265B8C947C6E6B7490B6CEC6CDCFCDCDC98B3122272724
2B264455382F35394C565A65666F7173767E788385808385858586878B8B90938F959898
9898A09DA0A49C9DA0A3A8A4ADB1A9AAA7ACA8AEB0ABAAACACA5A7A0A5A69F9E98999491
8A85868686848886828580807F7B7A787B7C8282
5F80B6AD8A5129232328252028243B7A99836D6F6F81A0D1C7C9CBCCCDD1C15C27202623
2425404E3931383F4F545B62656C706F787C7D7E857F87848685848D8F8B8C9093989B99
999C9E9B9E9CA4A1A6A3AAACB2ADACACAFAEABACAEADA8A8ABA6A7A7A1A29F9995979591
8A88868984848787878A7E7B807F80797B7D8185
7993B2986E32212E22262B2B2827306090956D64707985C3CAC5C8CBCED1D4A72F222525
282F394837363C4751535E656E6D77747A807E83837E848286878A8D8D8D909794989697
989C9C9B9D9CA5A9A7ADABABB4AFADAFB1AFB2AFACA8A7ACACA7A9A7A4A1A29E9A999391
8A898588868587889186837F81817A7D7C7C8489
A49A9470492D2621222528242A2B2A4D80977964707B7DADCCBCC4C8CCD0D5C875352922
26273F43312F363D475164686C707779798080807F828084898C8D8B8D93929098919997
98999A9E9FA2A6A9A5ADA8ABB3AEAEAEB1B0B1B0B2AAA8ABADA8A8A8A4A39F9D9B979895
92908B8C8B89898B8B86847E817E7D817C838184
AC976C442C282B262126222320282833718F8E697074778FC7BCBDC4C7CBCFD1B3442A23
24282F3E2F343C434F5163686C707A7A7B7B7B7E8183888282868C8A8D8F909298959A99
9B96999D9DA0A5A5A5ADA7AEB1B0ACB1B5B1B2AFADABA9ABAAACAAA7A7A5A1A19D9A9293
938F8C888A8A90888F88858380827B7D79828283
907A452A222B2F29222122292622242A53859F787374777BB6C5B8BDC4C5C9D0CC973229
292935432C303C3D4B555F656E747F797678797F83828C84848589898F8F918E95969899
9C929B9B9AA2A7A3A7A9AAB2AFB3AFB1AFB1B8B1AEAEA9ABB0AEA5A6A5A49E9D9B9F9292
8C8E8F898B8C918B8A898984817C76847F808388
77582D252320232225242322221F212539729A8B737270749BC6B9BBBFC4C3C5CCC26A32
302A2D3A2D37343C4D59656C71757A7876787E83868487828585878C9094928E92919495
9C9D9BA2A2A2A8A6ACAFB0B1B0B8AEB2B4B5B7B0AFAFAFABB2ADA9A8A6A7A2A2A09A9695
8B8F918C8D94938E8A8B8586817F7E7D83808682
593E272524272C27232226322522221F295B8994766F6F7384C0C7BBBDC6BDBDC3CEAC3A
2F2B2D352E3236404F59656C727175757B7B82837E8289858886848B8F91909390909597
989DA2A7A9A5A8ABACB0B2B4B6B3B0AFB4B7B3ADAFAEA9AFB0AFABADA9A2A39E9B9B9796
918F93908D92948C91888886867E7F7C82848585
4331332C2827292A29252831252A201D223A769493707478759FCCBEB9C2C0BCBBCACA90
3523252C2B2E37454D596167757379757C7D7E83827A848186848589889296969593979A
9E9EA5A7A8AAADACB2ADB1B0B1B4B4B7BEB9B5AFADAEA8ABABA9ABA8AFA8A19FA09A9B9C
989393969095928C8D8C8A8486857B8081858489
542F2F383335242A2C2A29322B27282224335F90A48373777286BFCCB1BEC1BFBAC1D1C1
622827282C30344448555F6874747979787C80807F798083868A8C8E8D92989898979B98
9CA0A1A6ADADB0AEAEB3B5B3AEB6B3BABAB6B4ADB3ABABACB0ADACA8B0A6A4A59D9F9F98
96939495919495958C8E8C8A8587817E81838483
5F37302B23292B2F2C272632333026212A2C3C789794766D7D76A4CDB3B6BFBBBCBDCAD1
AF4229272D393637475761696D75787A787C7A7B7A7A8383868A8F918F91989899989D9C
9EA2A6A8AFAEAEADB1B1B4B3B4B4B2B4B2B0AFACB6ADAFB0B3AEB0AAACAEA7A6A29F9D9A
98929999929195948F8C8C8A848983817C818482
503A2E2E26322A30322A2D2E2F292726282A325C889B7F69797983B2B8ACBBBDC0BEC8D1
CD983524262F323B415461656E727A777B7C7C7F7D7C868187898B8F938E95969B9B9C9C
A5A4A7A8ACAAACACB1B3B4B4B3B3B0ADB0AEAEAEB3B0ADADB2B3B1ABAAA9A5A2A19E9B9B
9B9A909291908E928B8B8884848081847F7F8082
3738292E2F322E2D2B2C2D2F2A2F3329292A303A6C94977373787590BCA8B6C1C1C3C3CD
D2C97C2D21282D38475560626C6F777C7B7A7E80807F87818A888E9494919397979D9D9D
A5A5A7A7AAAEADACB0B1B3B0B5AFB0B4B2B7B4AEAEAFB4B3B0B3B2B2ADAAA8A6A1A19A9D
999A9092929490948A8D8A818587858382827B7F
3E352F2D2E2E2E2F2D2E302E2D2E2F31302B2C365389AA807372747DB5B5B3BCC0C3C3C6
CFCFBD5829242E34444D575F696F777577797C7D7E8682838D898D9493979897989A9EA1
A2A3A7A9ABAEADABAEB3B2B4B0ACAAB4B3B0B1B1B2B1B0ADAEB2AFB2AFADAAA9A7A49B9C
9493949498958E928A8D86828886847F84838285
4A302D3335342F3A2D2D2C30302D2B3029292926316F9E9470666F76A6C0ABB4BDBCC4C2
C9D0CCA83D2A2836414B545A66717574757A7D7E807E81868A8C8D9290949898959E9EA2
9FA4A7AEACADA9ADAFB6B5AEA8AAABB2B2B1AFB6B3B1B0B0ADAEAFB1B0B0A9AAA4A39F9A
93919595949193908C8C85858586877D81838285
532F272E32362D2C31302B3035302B2A2C2927282D5493A27D66677088BBB4AEB9BCC2BF
C2CBCEC8903430333F4C535F5F6F727579787A7B837F8384888A8B90929799959A9DA0A0
A2A7A8A8AEA7A7B1ACB4B0ADA8B1B6B6B1B1B0AFACABA5A9AEB2AEB2ABAEAAA8A3A09A98
9696908E8E90918F8C8B86817E87877C7F808084
4227252834333429262F2B2A292F2D2D2E2B29282D42779C986E616A76A4BEA7B1BCBFBB
BDC6CCCDC17A36343D474B56676D727075787C7B83818084878C908F94989C969B9D9FA0
A5A4A8A8ACA7ADADACB0ADAEADB0B2B2ADAFACAAACADA8A4ADB1B1B2AEB2ACA7A29B9B98
9593908A8E8D948F8B8884878182877C807A7F83
2F2C2D2D36332E2E2C2D2830312C3431372C2B322C29528BA57E6967708CC0B2ABB5BCBE
BDC2C6C9C9BB593637455152616B70716F797E7A8482828A8B8B8D8D92979D9AA19B9F9F
A2A9A9A4A5A5AAADA9B1ADADACABADABACADABAAACADA8A9A8A9A9B0B0ADA8ACA09C9A9A
95948D888E8E96898B8980838281817A867A7E87
3134313337362E2B302C282F322F35332D2E313127273A6F969B746C6982ACBEA0B3B8BF
C0BEC4C3C7CCB04C39434B575F647070767C7A797F7F7F8C8B8B8A93939698979E9D9F9F
A7AAA9A1A3A2AAACAEB4ACABA9A3A6A5A8A6A9ACAEAEADACA8A8AAA6A8ACA8AAA3A2A099
948E8A888D8D8D8A858387828183847F85807F89
333030333431262B2B2C282C31353136353234352A2E2C5082A37F67656E8EB9A3B1B6BC
BBBDC0C2C8CCCCA4403F47515C5F6C7074787B7C837D868D898C8E95969898989D9FA09E
A8A9A7A3A5A2AAACACB2ABA9A8A3A6AAA4A7A8AEB1B0AEACA5A9A6A6A6A7A7A6A1A69B9F
958D88898B8E92908A86878584867F8281818488
322B2F32302C302E27302E31323F30303030332B2A2A2C386B92956F626475A2B5AAB2B5
BABDBDC6C9CFCEC78A40404D59616A71717576777D858689858A8D979497969CA198A1A2
A4A7A4A6A0A4A7AAADACA6A6A0A5A7A5A8A3A7A9ABADA9A9B1AEA9A4A6ACB0A4A6AEA59E
938C8E8888908F8E8B8689868181838182807F8B
2C2C2D2F2D272C31282B293036372D33323130302627282D47829E8469656B87B4ADB1B4
B6BBBBC3C3CACFCDC1813F4554606671706F72787F878687838E8C9694979C9C9C9B9FA4
A1A1A2A49EA6A1A1A39F9A9F9BA2A29D9E9FA6A4ABAAA3A6B1ACAEA5A2ACACA0A2AAA4A4
958C8D8585888A8F8E888882827E847F7F807D8C
302D292C2E2E2D2C2B2F2934352F2F322A2F32292521252330668F9F7C64687BA4BBACB6
B1B3B7BAC0C6CBCCCEBB703C4E555E656E70767879828787868D8E989699979A97979A9B
A0A39EA39FA09C9A9A97949696989B96999E9B9C9CA5A0A2A4A5A7AAA5A7A5A29FA6A3A7
9C8E8B827F84868B8C8789807E8084828283878D
2B2F2C2F3231332C272E31383633302F2D2D2C2723242523243F799C8F736B6F96C1B2AB
A6AAB1B5BCBFC8CCCFCCB66047515C5F676E727B7A7C838B88909294999A9A989793969E
949B9B9F9A9D9A9597918E9291938F909093929298969C9DA0A1A8A8A7A3A4A49CA1A3A7
A0928683858484868A8B87847F817C837C81848E
272B342E2D2B2E2F302D2E362C2E2F2B2F2A3027282B262122286085A1826B677EA9C0A8
A1ABB2B6B7B5C1C7C9CACAA95F4A565D636D75757D7F838A888D939494959B999A9A9698
969497999594939095908B94928F908D8E908E8F8E969796979A9B9DA1A3A5A49A9DA1A3
A1988B81818188848A88868781837E827F82838C
342A2C343432312E282E3733332E3437342C3030271E212020233C76999B6E63708CB9AA
9FA7B0B3B3B0BBC2CAC9CBC8A25D4F535C63717679848386878B8C8F9392979A92969297
999193918B8F919495958C8A94908D8988898B8D8D94918C95959B999F9FA49E9A949699
9C9C8D837A7B81848689868285817F7F7D838590
2D2A2C312F3433292E33302E2F2C2F343532362D2627261C1E23265987A180636673A8B8
A3A3A8B3ADB2B5BDC5C8CBC6C49E595151606B6E7B807E8385878E92958D8D9090969497
92948B8F8C8F9396979084838C89827C7E847F88888585778C958E90A099999696969191
96958F83777A80818884857E8383807D80868991
2E31334429292B2F2F2E2D2E2A2C2C303236342D28252623222223326B8D956E626990BB
B7A2A1B0ADB6B8BCC4C4CBC9C5C59A59515F666E767C818289858C8D93858D8B91949392
8E928D9190909695948E837781817B716E867F888A8F7B6C868A8186A692929799979992
8E8E847F75797F838384847F81837E7F82888A91
282B2D262D292D2C2C3034342B2A2F39382F302C2327262323222126467C9980625C7FB3
C3AD9FA9AAB3B3B8C1C2C8CAC5C7C1965953696C747E7E8388858A8D8D8A8E8E908F8F91
8E8C91958F8C908D8E85816D77807A6E5C808089868B716E807B667DA698939CA5A2A399
978A837E7A777A7C8284847D838081807E8A9495
2C262A2D2E2B302F2B2D2E312F3030333239332E2B312426222320202A5E899C6F59679C
C0C2A2A4A8AFB0BBBDC2C8CEC6C5C6C2966060696E76787F8583868B848789898F8D9291
908F9292898684888A837A6D68777D6459768182847F696A8073657F9FA3A8A7B3AFAFA8
9E90887D777D787E7C81818283848782818A8F96
302A23292A2F2C362D2E2F30302B2A2B322C3A2D39282425242523222239779C875F6181
B7CAB9A6A7AAB1B6BABEC3CACBC9C2C2BF8A5E5F68757781827C828A81878285928E8F8F
8D8F8F8D8678767D7E7F7E6C6D6B7C6F607A858892969193A7A08D9FA2A4AFACACABAEAD
9F948C837E807C7F747B827B7E808383868D9295
2824252B252C2F343231303138322E3930312F2A382F27262D22211F232C52849F6D566C
9BC2CBAFA3A7ACB6B9BCBEC8C9CAC6C4C5BE94625C6C787B7C7B81867E817D8493939190
8F8D878881706D72696C78726F7485858F979B979EA9A7ACB2B2AAB1B4BBBDB1A09B9794
88888984837E79777973788083818079828D9497
2C2724272931342C312D303C403A362E2C3032443B2F342B232725222C293B6E91935F60
7CACCEBF9EA3A6AEB4BABBC5C8CAC8C6C4BFBC8F606277797B7B7F8181807E889093908D
8D8C827C746B6369534B717D878A92959D9D9FA8ADB0BBBBC1C4C1B9AFA7AA9B928E877C
75768280867E7D7877797B8082828580848E949A
322C27272429303938322E36433F2E2E36302C2E313727242825242120392A4D859B7C63
6688C2C59C959FADB1B9B5C0C7C7C6C7C5C1C1BC926669727F7C7B7A7C7E7B878E8B8D86
8685726A5F5B5D5F5E6E77828B8D83858A939EB6BBC1C5C7CBCED1CEC7B69E908991988B
73707C83827D797275797C8481828185848D8D99
2C2B362C2F2B363D3A362D283740312726292C2F303526252E2D2123212A363C58889663
5866A3C2AB969CACB5B2B4BDC3C3C7C9C5C7C1C4C19C6C6A73777A72767E7C838C838F88
7C766353434352637377777C84786C65667489A3BAC5C6CACDCFD1CFCAC6B09788908E94
716E79857E747179747C7B7C7F82828386869094
3C35282E2A2E34454F3D2A29313A322D2C282D2D36382827272421252A3032353F6E957C
53567EAFB99F98A9B0B3B4BCBEC3C7C9CAC4C5C5C5C4A06D68717576767F8284827C827C
756C56412F2F496371707578715F523F424B587F9EBCCACBCACACECCC6C3BCA3948A8478
6A747E7A7070737C7D78767B7A86848B8A8F949B
402E2C282C283A52744D2A2C3430352C2D2B2B3534302A302C27282B272E28252C407D8A
67516689A6A19097A3A8ABBBB9C1C6C5C8C7C5C4C2C7C3986C6370727A7E817D7475796D
64604A322B33445C69727D71593E39363D3A414D6BA0C6D0CED0CFD1CAC8C0B09E837261
667D7D74666F72777C75717B818286898A8E939B
38282627262D40657F4F352E3129352B29312D313D2D282D262C2B28232D2724262F5A78
73515C7D97B19E93979399A2AAB4BBC3C6C9CAC8C5C5C3C298676D6573787A756E64615F
564E372F3345535A6C7F73583B3C4F575A504D374171ADCFD3D2D3D3CDCECAB69E7B5D54
637E7666626B6F6F7572767A80808688899097A2
382E2B292B31457977463E2C292A2C2A2D2C2A303A2E2A2628292B2B25272325252E4A69
8472566C93BCBFA8A1999599A8ADB3BEC3CACACBC6C1C6C7C793696267746E695C54524E
423B2E2B2D454A5D757963433A546256565B534839427EC5D1CED0D2CDCEC8B6956C4C46
6C7E6A5C6070706D7076797A7D81858A888D959C
352A3026272E528854364430302324262F262E37382F2B29273439322B25282D35484A62
899D756074A9CDBFAAA4ADAAB2BBB6BDBCC8C9CBC6C6CDC9C8C28D5D616B656156534035
3330312D2F42475F736B47345C625A4842425A6C4A3557B1CFCCCCCECBC8BFAB80584658
7C785E5A6C7772707173787B818687888B8D9199
28352B2C2C34668D49313D35292729282E2E2F2C3A32322A2B2A343A342A292F494B393B
74988E675C8CC2C9B4A4AFB6B3B9B9B8B7C0CCCFCBC7C9C9C4C9BD7A505B5E5651443838
35332A2E3438465C675A32395E5D4C30292B45704D38429DCCCCC6C6C6C1AC906246445D
836E545B747A75747173888284898B89908C8F99
27382E272C3E7A7D3F2B352B2C282A2B2933302F312E2F2B2B2D404841383A2526272125
528DA17E606C9CC6BDA4ADAFB1B7B2B1B7B9C3CECBCAC7C1C8C5CBB76B515258554E4438
31352C2A2C3341525A51323C504F30262427385A413248A3CCCCC7C0C0B98B6B483C3E68
6C544B647B7C787A7779808782878B8B968D919A
2C302D2E304780652A2F2D31312E2B322F2B2D30323B3B2D333F505A55322A2722211F21
3272989C6B5F79B1C8B0A4A8ACB3B5AFB5B8B6CACEC9C7C1C5C5C5C4AF694C5057554C44
3C322A292A33353D4D432B2F3E3C2D2724285857415679AECACCBFB0A39A61452B2B3B4C
4A3F4F6D7B827C797679808A868C8B9290919499
31303840334F8D53282E2C2C2F2B282928252B344867604A5A536D5E2F292A2823252220
26538C9F85656592C3C6ABACA6AFB2AEB5B5B4C4C9CAC4C7C5C0BEC0C8AE614448504B4B
463A292F3130313035352F2B363132282E304C3E455E80A2C1C0AF9577623B2A2726272A
2C33516E8187817E7D807E8788858E8C93959899
2F3A5256355C8747252D34322C252B292B2A303E6E7A706D66523B2B27272D2922222621
21336A93A6715F7EACC9BDA7A9AAABAFB3B9B9C4C9CDCAC2C4BEBEC3C1C5A659434B493E
3B42333030342F30302F372F33302E2C2E2F2C3238465A8AA2968E684E382A29292B262A
2E436475848884817E8082888A8B8A8F92969499
2A3F553D2D5E82382C2C2A2826242429252A4169797972674828242926272D2F25292722
21234580A195646490B9C6AFA7A4ACB1B0B8B8C2C5CDCAC3C2C0BDBFBFBDC5A75E4A4141
43433935322F30353533353733352D2C2A2F2E2F304F4262776F5C46392E2A272E29262E
3C5673818B8787837D8282858D8D90979394999D
37563A2F3259732E26292724272525203035707971726040262624272B2F33342A20262A
1B1F265A90AD76677B9AC1C3A6A6ACB0ADB6B4B9C4C8CBC3C1C2BABCBEB9C2C6A2584640
3F4B3B36373935323534343A332F32342E302E2F2C33373F544737332E282E2727302837
586F8388898180837B7E83828C8F8B9294949C9D
4A472D303163672E2B262B242826272B305C7B7C6E4F322D2A2E282B292F2E2C25242C33
1D1F1F3978A098806D7DAACBB4A7ADB3AFB1B7BBC4C8CBC5C2BEB9B7BAB4BBC6C89D5041
47464744433F3A3533363433343431322F31302E323B30383936412C2E28262C292A385E
838A8D82827F847D7E83828F8C8E909197999C9E
582F2C2A2F5D652F282622232631303A497D7865412F28252B2B2C392F2F302826242427
1F2523284F91A0886E668DBCC0A6ACAAADB0B3BBC3C6CBC7C9C2BBB9BBB6B6BFC5C99F5A
484E564D5048473C343B4038363935323831323533353532312D2B2D2B29282C35444B6A
8A8C8880807A85837D7A8989899292979B9E9C9F
4027292D36595D2B27262624292E30435C76603A2A292C2F322D282F2D2E332930262423
283D2122276E8F9F77656FA2BFB9A8AAAAB0AEB6BFC4CBCCCBC7BCB9B5ACB1B7BFC6CDA6
5E4F514F5E574D454657544040433E393B3936322C32353C37382F2B2F303038537B6461
7888817C797A7B7C777A84898C8F969A9FA19A9D
31302D2D3C545E312F2D262429333E5F606C573425302B2B2C2E2D342A2E2B2B2A2E2727
443F1E1D223E81A28D6A697CB0C6B5A4AAA8ADB1BBC1C5C8C8CAC0B5B3A9AEADB7BDC6CA
AD6454555F6260646764604A4B49435249513B362F3851695E4B302E434540546F798057
6580777A75737474777A80868D93999C9DA2A09D
2C2C312A305B57342E29252324304D676C6234282B2528262B34322E2D262C2A25282D3B
55261C1E212C6194A173686B8CB9C1B0A4ACA7B2BBBDC2C4CBC8C3B9B1A8A8A6B2BABCC4
CCB275556460686C6B655E5F626666696D6B573E2F456F91847C5344657049676E7B7C6B
5F75746F6D7170666D79818A939B9F9A9EA3A3A2
302F292A3C5351322626282A30315565685B2D272828242A2A302F28282A28312D385262
3D2922262121357B9699716D779EBCC2A7A3ACAEAFB8C0C0C3C7C5BBACA3A1A2A6B7BAC2
C8C8B68264626C7171727875767D78757C816E58335A8195928B7460777D5B5971737C71
69646E635D6461686D7A85989C9D9C9DA1A6A4A5
28252C29344C40372B27263028385766664C352A23222C2D2C2A3128272A3335436C6E41
2B312F221E20214A7B9E8E7B7281A3BFB9A8A8A9ABB2B8BDC1C6C5BFB5A99AA19CB1B5BE
C4C7C7BD956C6F71787E7D7B7C8A8786848A83734F7B9B9D9B9D89718489765B6C656A64
5E575D5A515A5C626F778F9EA5A4A3A3A7AAA2A5
2429312634473B3E372E2A2C33395B5D613C3830242424292829272A3031595360855225
2B495C27201D1F32628EA796827182A8C3B7A1A8ACB1B3B8BBC7C6C4BBA7969A99A8ABBA
BFC1C5C7C09E6F6E7B828283858992938E928A757A90A5A3A09B8F7F818A7E5B685A5E55
544F4B4E484E4E60768796A6AAA9A6A8A7ABAAAD
26242F3345614C463C373D63463F5B5C4327353B2929282B272529232D334F5F66765426
2D5B592E2A1F1D2439759AA7886E688FB7C3ACA7AAADB4B4BEC2C6C7BFACA39696A1A9B3
BCBEC4C5C7C1AB7C74787A86898E97999A958E7B969D9FA3A09A8B857E7E736161565348
48443F3F414F5B798895A1A7ABA7ABA4A7ABABAD
25282727334D3F423A2B3D532A334A543429363E2A28232C29202829345066593D696125
335D3A2D3E2228272A5085A2907264739ABFBDA69EAAB0B2B8BBC1C6C4B3A69B949CA5A8
B2BBBDC0C5C3BDB1887679838B919198999998929DA29B96958F817A6D605D52464D4341
3F39464F59678196A0A9AFABAAADABA8ABAAABB0
212827262A3C4C424E4C3B35293B4F4835302B3C2D2727282A272A2E4A6D6033284E6328
4B5C2B364E28221D2F3A6E8D9E816562799BBFB1A1ABAFB0B7B9BAC3C7BDAF9B979A9CAB
ACBCBDBAC6C3C3C0B9927B7D84898F969C9696979794918C847D74685C4B433B463D3D44
4C585E71848D9BA7A9AFB0ADAFB5B1AEACAEAEB1
242B34232A34353C5642323B344746392F2A2C3A372F322B30302C4260684E46323C602E
5B53252D55311F2725233E75979F6E5B607BAAB9AEA6ADACB4B2B8C0C2C4B5A59A9C989F
A8B6BCBBBDC2C3C2C1BA9979767A8289908C8E8D897F79756E6B645B503F3F4447494B59
6A6F7A8D9EA5A8B0B3B0AFB1B3B4B3B4B0ACACAC
2828362E2730302F383738343F4A393329302F36392D2B272F48464F5A52323D3D345733
694E262F5C341D2727202A4C84A6836C5C6488B0BFAEA9AAACAFB5B8BEC2BBA9979A989E
9EB6BABEBEC2C4C2C1C2C19E7666686E76787977756C666067655B534D57555D656B727D
8592989FA7AEB0B9B5B5B0ADB1B3B2B1AFAFADAA
262B412C2C2E383433392A34353A302B2F2A2C353A372E323839352E4A462F2B2C386049
6C3E30325F422A25201D232B6D8B9982635D6C8FB5C1ACA5ACAEB3B2BFC0BBAD9A9D999C
9DADB8BDC0C3C4C6C5C0C0BFAA785555575861616066635B6068646456666E737A7C8690
9CA3A6ADAFB3B3B6B6B5B1B2B3B0B0AFB5ADAAAF
23263D3233393F39342F2F2F3340322831292A2B342C2E353335312C47372A2929306555
6C3929325B5B37322E291E233B798CA0785F647297C6BAA9ABA6A7B0B9B9B7ABA39A9B96
9BA4B3BDC3C1C0C2C5C0BEBBB9B0894F454755595D656A6E6874797D7E7D84878994989E
A6A6ACB1AFB5B4B4B7B5B5B4AEB3B3AFAFB2AFB4
262230373235484D463E3C323E432D282C28252A282D3132333A332F57472424262C5465
6C3C23234A6D4145503B27212A457D9D97745B657DAAC6B9A4A8A7ABB3B3B7ABA69A9C96
9DA6B2B8C0C0C0BEC6BFBEBFBBB6B8A36D4E4A5266756E797986898E93919498989EA4AB
AAAEAEAAB1B4B0B4B6B4B0B4AEAEB1B0B1B2AFB5
22292F33292A32405A615F5043463A3A312B272C292A2C3435382B315A582D2326263C69
633D25243A6A412C3440362E2F2B5883A689605D6187B4C2AFA3A6B0ACB3B2AEA5A69B9C
9EA7B3B7BFBEBEBABFBDB9B4B9B4B6B5A5896C64687C7B8A8A8E939499A0A3A3A5A5A8A9
A6AEB1AFB2AFB0B3B3B4B2B0B2B0B1AFB4B7B5B8
2621253725282F384853666E565056433E312C2C2D2D313E38332D2B476F2F2728263864
753D29252C5C662A2B30383226242E648E9A735F596994B4B9ACA0A9A6B0ABAEA9A59FA1
9EA7B0BDBFBEBABAB9BFBCB7B2B6B2B0B4ACA28C7C858B9397969E9FA2A1A3A4A7A4A6AF
A9A8AEB0AEB1B1B2B1B3B6B7AFB5B2AFB6B6B7B7
27292A34372334474B444E687857494F48353127282F28383D31252B4472332A282B3F5E
723E36292B417D3A29242D342E21223E768C906956597290B9B89FA0A7A7A5A8AAA59D9F
A1A9AFBEBEBEBDBAB5C0BAB7ADAFB2B8AFAEB2A89E959598A0A0A1A3A3A7A5A5A7A3A7A9
A7A9ABABAEAFB4B1B1AFB1B2B2B1B0B0B4B2B8B8
363424283D2C3A3F3B3B33476D71423946363425272E2C3C37292827376B4D272A2C3F5D
5D3A3B3B282A5D753E282C282520292B49788775635C66799ABBB0A1A0A4A3A5A29C9E9E
A3A6AFBCBEC2BCB7B4BCB7B8B2AAAEB9B5ACA9A6A6A79B989AA1A4A8A2A4A6A4A4A1A6A3
A9A7A7ACABB4B2ADB0B0B0B2B0B2B4AEAEB1B6BC
404F2B2433373D2F322D2E37426B686547363B2A25222B3B372E26293759642A252A4751
583940432F273C78714130231D1E2020325372767E6C636A839EB4AEA29DA1A1A09FA1A1
A0A6ADBCBBBEBEB5B7B9B7B4AC9CA2B6B9B6ACA3A7A6A49B9A9A9CA1A6A9A4A1A3A29EA4
A9A7A6A8ADB0ADAEADAEAFB1B2B4B4B1B2B4B8BE
3A6234292839282524272C363E4D6369623F3637282930393C2E2B2C2D52642D262D4A3C
3E392931322D2E638C61291F1F1D1F21283E6C8E97847C716E86A7BCAD9D9EA3A09FA2A1
A6ACAFBBBCBABBBCBBBBBBB2AE908FABB5BCB8A7A9A7A6A19E9A9B9CA0A5A6A39E9DA3A1
A6A1A8A8B0ABB0ADADB0B0AEB4B5B6B2B6B8B9BE
274A5432313C2A2525283452483E395A62533D322628293239372C292940663B273B5A31
343225263245344F7A532120231E1E203162678E8EA1887D6A7488A3B2A5A0A4A19CA2A2
A5AFB3C0BCBAB9BBB8BBB9AFA48A84ABB0B9C3B8AEA8A69F9C9E9C9B989EA09E9E9EA3A0
A2A6A5ACAAAEAFABACACB0AFAFB4B4B3B7B6BCBD
2931453327302C26293449613B2E293B55584A392E2B2F3831392A2C2A3C5F412B455D33
2D37272B2E3D364F653F241F2120202C4F7D675F729BA187746F7A84ABAFA3A4A29DA6A6
AAB4B5BDBBBAB6BFBBB8B1A098747DA9B0BCC3C0B6AFA6A2A199979B969B9A9B999BA0A4
A1A3A5A9AAADAAA9ACAFB1B1B4B0B7B5B7B5BDC1
2926363728292B2C3348684B3625322E3E574E35342D3C362F3B2A302A36594B323D4E2F
3137312E422D344E533F23231F20243373865A3156819F947D6F777A90B7A99DA2A5A5AB
AEB3B3BABEBAB9BBBBBAAE929A7681ACABB8C0C2BEB8AAABA19D999CA2A59A989B98A1A1
A0A3A2A8AAAEADACAEADB3AEB3B0B0B2B5B7BBBD
2328292E292A2A34476B5F3B312B2F30334D5C46362D2C35383A2D2C2E334A542F343B28
2F2E3451562A324D51412B2823202B45947B4B202C6687A0907A777F8095B1AA9DA7A7AE
B1AEB0BCC3BBB8BBB9B9AC8C9B7D88B0ADB1BAC0C5C1B6AFA9A4A09C9BA9A2939C9D9F9D
A99DA1A8A9A9ABAEAEADAEAEB3B0B0B9B8B8BAC3
2B282B2B292A2B335A6C4D3F3E3D342F3F41484B312F2A32394732312C303D523F38382F
282C3868612E4A514C482F2722242E6E91692E1D2336698AA28A787A727B96BAABA6A6AC
ADACB3BFC2BCBABAB4B9AF8998878BAAA6ADB4BCC5C9C0B2ACA7A2A19FA1AAA29C96999B
A1A09CA3A6A9AAABAEAAAEACB0ABB2BDBBB8BFC1
252729232D282F45685733474B4E352B2C2F3A423131313039383536333239484B3A3926
272C386A5B3C67434251473733344F9A88512A1F212041788BAA8579707781A2B6B3AAAA
AAADBBB8BBBEB4B4ADB6B2939A8F95A7A1A4B2B9C6C6C5BCAEAAA2A5A6A1A4A6A797939A
9A9E9BA5A2A9A5A8ABADAFABADB4B5B8B7BCBEC3
2B27252C2929314D6E492C3336383E332E2D353D47302D3337333A423131373B483D3526
242E4769594E643C4B59615D565677A68A5E271D1E202A46769A9B83787B7881AABEB6A5
AAACB9B3B8BBB6B5ACB5B399919298A7A0A3AEB6C3C9C7C3B6ADA5A7A8A9A49FA0A69493
989B9CA09FA3A2A6ADAAA9A8AEB3B7B4BABBBDBF
2D2926272E282B576E3E272B2E2A38403F2F353744342C2F34383D373132312E443C312E
313C4B5548595B4568655F52533E68A48C6F36231D1D20295285979B8079727B8EAFC0B7
A6ACB8B5BAB0B2B0B3B3B1A18D90A4A6A6AAB1B7C0C7C5CABEB0A8A6ADADABA4A2A3A49D
95929B9CA1A0A2A6AAABABAAA8ACB4B8BBBDC0C1
3A2729252E39345B693F2527272F3047513E303840422B292D383438362A2B2E3A483B2D
3938334649666C6F79594C3B3B2D5E986A41251F1C201D252E5983A196857C737B93B4BD
A9AAB0B8B9AEAEA9A8ABAE998A90A7A8A7A6B6BABDBFBFC4BFB3ABA5A9ACA7A7A9A7A2A5
9991969B9D9C9FA6A6A8A7A9ADAFB7B8BAC1C2BE
322B32262F3538696D41272A292F2E414C47382C363D302D333732423537292E36413C38
3734323F607269787E50402A35366889582920262024221E24365D91A994847B777D95B6
B9A9A8B6B3AEAAA6A3B0A3948B8FA9B5ADACAFAEB9BEC3BFBAB6ACA7ACABA7ABADA8A7AB
A5A0959394979DA5A6A9ABA8ADADB3B7B9BEBFBE
3F372E2A2C2C3C686D4D2E312C2B2B303E473F32333B353235313736442E2B2E3B3E4039
3232374E636E675C7A3F372D333B8089472524281F24232823292B6291A5958174727BA0
B5B9A5AEADA8A9A1A8A8AA96878EA9B6B1A9A8AFB9BCC0C6B9B8AFA7AAABA9AAACA9ABAE
AAAFA19693959CA3A6A5A9A7AEACB2B0BABDBFB9
4F5247332B2C35666D49342D2A2A2C2E3646463A3B3C392A2B2E2F2F3B353134433E4239
3634445A60633B436A372C2F3450908137292D2A27242123202124346B9BA08F786B6A7D
9BB5B5ACABA5A5A6A6A7A394848DA7B1ADA39FB1BAC1BEBDB8B7B1A7A7A7A8AAABABAAAB
ADAEACA79C9395A2A0A2A9AAADAFB0AEB6BABCBB
5C5C5A43392E3754685A322D292A2D262D4043372E413A322C2E342B303A3C414C3A3B41
353448545C4F3137613A2C2E406F8F712C2E292327262322211F2025367097A88E746772
83A0B3BFB1A9A4A5A4A5A08E8489A4A9A59E9FA9B6C1BBB5ADB6B4ABACACA9A9ACA6A8A4
AAA8B2B3AF9D8A939D9FA6A7A9ACAFAFB4B9BBB7
43424435342E2E5561623E2D2A272D292D343B2E2E383E33312F36313340514C4A413D44
39414D465950292B4B3B352D59888A5E272926242E282323211D1E1F264173A4AC887167
74879FB6BFADA6A4A6A5A38D86809BA7A4ACACA2B0C0BFB6ADACBDAEA7ADAAA9AAA1A7A0
A8A3AEB0B7B59E8F999FA6A5AAB2ADAFB4BBB4B9
50563F2F2E3233515E604D322B2A29272D3237332F313B3332352E333853544848454245
41433A4061562B2E3E40373C57928E5B28272C2D2B2A25242A211E1E21254A85A49C8970
6A7284A0BABDA7A4A5A4A386808399AFB5B6AEA4B2C1C0B8B9B3BBB3A9A7A6A0A8A0A4A1
A5A4AEAFB4BBB5A59B9C9BA4A7AEACADB5B6B3BD
7569472D272B2D3E575F562C2D292F262B2F36342D2B32302D3134384A564F453A3F494B
4540314562582B2D3C3C2C32518E8558313E404B433E2E29262423231F212956829AA088
716C68789FB8B5A0A7A298807B8EA0BBBAB1B4A6B7BCC3BCBCBEB8B5ADAAACA2A4A39FA1
9E9FA7B1B4B6BCB1B09F989CA4A8A8A7AFB0B4BA
786857302C262B363F5B5D362D2F2C2B352A2A2A2B2E30312B37434C54504E3B3F485655
45382838675324232D392B3B629187635651646F63593325212A22241F22282E50869FA2
81665D637C9EB5ABA1A48E7A7B86B0BEBAAEAFB4B5C0C1BFBFC1BFB5AEAAA6A2A5A29F9C
A19FA6AAADB5B9B6B2B0A29EA0A4A7ADADADB0BB
725D342D26292F3C33435847413330302B2D312D3132382F3134465C50533B3F4B4E594B
3D2C2E3A625325232A3731537288876B685E5F5D48352523262A242125242521325B839A
94755A53667696B4B6A589788D95ACBBBCB6B0B5BBBABCC0C2C1C1BDB6B3A7A9A5A5A1A1
A1A6A5AAAFACB4B7B6B2ADA7A4A1A6ABADACB1B8
76522E272B313B342B3C54503D39312C2B2D2F2F352F2E2B2F3E585F58423A415557604D
2B272F405750252A2C3A5C687D8D865C463F362F2E2A31292A26292322222428262F5F7E
937A6669605C7795B5AE8677A69EA7BCB6B4B4B5B6B5BABCC1BEBFBEB9B4B1A9A2A49B9C
A2A4A5A8ABACB0B5B6B3B1A6A29BA0A5ACAEB6B6
765D4335353D392E2B384E5F4A36342B2D333129312F3233394A62594A3E45475254613B
2B2F3648564127282E4776757E8162392A2A2D2F2E3031342B2F2C2E232222242629375F
767C6C755C4E5B7793A38B7AB19893B9B5B3B6B4B8B6B8BABCBBBDBBB6B5B3AAA5A5A1A0
A1A0A6A4A6ABACB3B9B4AFACA7999CA39EA5AEB5
6D5E56434A534433313249665949412E33342A2A302B2F343346614B3B454458555B5945
292D37485036222F3B5A76857C6F4B2A2B2C302E333A312B2929292C2D282A2324242736
5C696E7A6B4F4F5F6F89827DB19785B3B7B4B7B1B6B2B6BBB6BBBDBBB8B4B4AFA9A7A1A2
A3A5A7A6A6A5ABB1B6B6B0ACABA39A9DA5A7A9A7
6A66584F67625D4E463B44575A4F4233342E2F2D2E2B31353D4A55514655444855604C3D
3825384B4F3F282C5E597B806C5E35292D2F322D31323234302C2A31332B2F21272C2635
3C536F8A765649545D6C657CB19A86A7BDB7B7AFB3B7B6B6B7B9BDBFBCB9B6B6ADACA4A2
A0A9A8A9AEAEB0B3B1B8B0AEB1AB9D9DAAADA8A6
766F5C5B7C716A595553494A514D4C3D3E3B3230292A383A484D484E434145455551473E
3B27364C51382636715B79785F5832282C2B2F3A2F2C2D30303631303A2F292A2C292729
2C415F6C846B585559614F72A7A1839DB6B0AEA9B1B7B1B0B3B5B7BBBCBCB7B2ABADADA5
A3A6ABACAFACB3B3AFB2B4B3B0A9A7A0AFB3ACAD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
566585A3BE3529212E2423333E403A31323334313032343433343943504B413E38302E28
282F3B6962615A7D68466062646B7276767B807D807C837F7B7B7D7E838A8587898E8785
8B8F8D8C89909290858889888A8B8B8D8E908F909091919591909192919694929090968D
909696969597979B9B9AA1A2ABB5C5C9CDD3D4B1
5A6072A1BFA545232A2525303C3834363D3936303137353635333B444B484137332F2F27
28303B6C65655B7B5E51596368716F7576787E7D7F847E83828284848086878B8988878D
8B92918C8C8C898A8F8B898C8F8F8E8B8B918F9594939291929091919497969393929592
9296969595989B9B9D9AA2A5A7B4C4CBD3D0CDBF
5857577B96B3973E281E2C2C33312D3340373130352D2F3535363D3F43473C2F2F333229
272F39696065617758595B6771746F7479767C827C7E847F7F818181848586848A8C888C
8B908F888B89898A928C8B8E918B8C8F909295979693959696949893999A9E9796939496
9095939795989A9A9C99A0A3A9B7C7CFD3D3C8CC
5F55596B83A5B97E3B1D29272C322D3542362F2C312F2A2C34363950414139332C2F3328
2435416F61666079555A606770726D72787A7B827F7F82858481808280838888888A858C
8C8E8C888C928F8F908C898B8E8E90949593949698939693939793959A9A9E9A97969491
929394989599979A999B9EA1A8B2C0C9D3D2C3CC
5E5B5B5A7183C3B7552B2320293030372C2C2E2A35312C3333352D543E3938373230312A
2535487563676078525C64686D757376787A777E807A8281867E828381838A8F848B8A8A
8C8F8D898D8F8C8D8D908E8F8E8F8F93969696969497999696989B969A9B9A9C9494948E
9599999994949696999C9C9BA9B0BFCAD1CDC7C6
615E59586377A5C4A73D332424262E332D2B2C2F35352D2F3636374C403C393932302E2E
282A4A79656F626C535E636A706F7376797F7A7E8181817E818083808280858C8A8A8B87
8D8D888F878B898B8B8F908D8D9693969798979A989A9695969E9C969AA099999593918F
969699979392959397979C95A1AFBBC9D4CAC2C2
66615B565B6E8DB5CF96322A2C2A2D2C282E30303131333437383F3D40443D3833332F2B
2A1E4F786B75666258616A6E716F73767F7F7C797E81817C7D847E7E888483888A8B8E8B
8E8D8E92898A888B8F8C908D8F939797989B96989A979697979D9B989C9B999A98969698
9995948F9492968F9292989A9BABB7C3CDCCBFBC
54605E5A5B7394A7D5B57C4528252E302E37363839363534393F3D3840403936342A2C35
4D31586E73636C605661696F717075797C7C7F7B7C81807F7E857F848888898A8D8C8E8A
8D8D8A8E8C8D91928B8D919497999A999B9D99989B999B9B9B9B9A9D9D9D9C9B96959897
9899939395959490938F95989DA9ACBCCBC6C2B2
4F5C665C5F779993C6CBC86F302F3735303C3A3934393234373D3F3D3B383530332F2F25
2C2A656A77546E63555B656B6D7977777A7D807F7B847F858382838383848A8B8B8E8E8C
8D8D8C8D8B8D918F919392929A98999E979B979D9A989D9E9E9F9E9CA09B9E96979A999C
99989393959592938F8F8F979E9EADBFC5BDC3A2
7358616B5D6F8888A8C1CBC95828332A36373A3836373638393D3E3A3A36363630342E2C
342E646E7D5968625359666C6E7074777E7F7B7E7B8081787A7E84807F87878A898C8B88
8D918D908E8F908F919490929094999D949A9B9C9E999CA0A19FA59D9A9E9F9C9A999698
97939C929696918F918C908F9798A6B3BDB8B5A0
96605E7A5C69777D89AECFD1983F2C262E31333432333335373B403B3937353733342E2D
352E6476805A635A515B646C6E7077767A7D7C7C7B7F7F757C86837F83848385878B8D87
8B9193908F928E91918D9293929397A1999C9D979C9DA19EA19C9A9A9DA19D999C9D9F9D
999298939294938B8B8B898E8E939CA9B3AEA6A4
AA8B67646969656D7899B9D7C3843D212C2E2C2F282A3333353C3E3B2D2F32322F2B2A2A
312E67757C5662565356646F6E767675747A777C7D7C7E7C7F7E817E8186848889898788
8F918C90918F8D90929094949594979C9C9A9B99A19A9CA2A0A19D9EA1A5989A9D99999A
968E95919293908988878887868E8FA0A69F9692
A9AF6D52756B61636E889FD0E0C451292724282627282D303240423B302B31312F2B271F
2A2D6B727D5863555258686F71747273757D797A7D7B7F84807E8180808685878B86868A
8C8D8F938F8D9391909794979896949A9C979D9A9B99979B9D9E9D9F9C9F9A9B9C9C9597
9498928F8E8F8D8585848083848D898C948F8483
8AA299706D707071777E8AAFC9C7961730232B2528283138434A4844352F2B2C2A2D272A
332E69737A625F525158666C71707276757D7B7A7F797E8282818083808486848A88898C
948F919790909291919591949896979A9A98979BA0979D9B9BA4A19C9B999E979A9A9898
96938D908C8786807F8185818287878C8A847A7A
656A797066718082807C849CB0BDB95B3120252222262C3A4E4D45453A2E282A2931312F
362E5E6C7D685D544F5A656C6D6D737474767D7F807D7C7C7D8483838385878B8889888C
92929292919794939193919096949697999B95969BA09EA0A19F999BA19B9F9594969591
9391868684817E7F787C80828784848584797679
4854617376818C91919196A2AFB8B1A9614F2220252327303F3E3C383430282C28312D2B
312F626D76665250525A67696B6F7A7473787D807E7D7E7F8187847F818787878B888C92
968E8B8F909896939391909497999D999A9999999B9E9C9D9EA2999EA39C9B9893979191
8D86827D7D7F797D7E85848681858682817A7471
30394368878F8F9BA1A9B2B3B2BDC2B0AC842522252726262D2A27272D2C2A2D2D2D2E2B
2B3164686E634D50505F656A6C6E727273757A8077797F817F81848387898C868B8E918F
8F8F94918F979793989894959C959D9C98999B9C99A0A19F9F9E99A39B9E969791929396
8C857A7576827E7E8280817D7F86818380787272
2624304E90959BA4A8B4BDB7B8BFC2BFB8A23C2721242628262926262C2E312F33322F24
2D28616C75644A4F505E65696A6D727477777B7D7C7F7D7F83867E83868788858A8E9090
9193928F929695959695959899949B9A9E9D9F9F9EA19A9E9D9B9EA29E99969894929293
8A8076777A827F7D74686361636E72716E675F63
2417202E879AACB0ADB7C3BEBCC1C1C1BBAF5B391E1F282828232327222E2F2E30312E26
2B265B68755E4B51535D616263686D7273797880797E7B8081818282848589898B898C91
9293918F979998969996999797949B9C9D9DA19D9DA09C9E9F9F9C9DA09994969493918E
827F747C8587837F6352404241525F5D58595753
26171D285AA7ADB2A8B7C0BCB6BBBFC0B5BFA3783328292725262529272E2E2F302D2A25
2827636668574E5154586062656B6E747576757C797F7D838280828189848B8B898F8C8F
92909293989697959699969693999A969E9C9B9E9F9D9F9E9CA2A19EA299949494908A82
7F7A777B858488836E5036323444515C62676565
23201D212DB0ACB2AAB5BCB3B2B5B9B9B4ACA29F513E312A201D211E202C2E292C2A2523
2C2B626862544C504E56605F6170737279777C7D797B8380807D848489888D898B8B8E90
918C91979B959496979B9A9A96999B9A9D9E9BA09C9CA09C9F9E9E999E9C968D918F8B81
7F78787E888787807A5635313641536371767778
22221B1D2390AFA2AAAEB4B0AEB5B7B5B6B5B4C0A4764B332628252124272D272F2D2F24
26365D6666504A4649525A5E656E7473777C827E7D80857F7D81838485888F8B8F8C8F8D
90918F9495969398969A9798979B9A999A9C9B9E9FA09B9DA29D989B9F9B979093908F81
7874777C84888D828078797A7B8389827D7B807F
26251C151C64AE95ACA3A6ADABB0A9B2B9B7B3B2AB9072483029252024252D2E2D2C2C22
243C59636853434148505D606670717473787D8080827F827F7F84848883888D908C8B90
8F948F9691909B9D9396969596959AA09E9E959AA1A19FA19F9A9D9D9A93968E8F95917D
756C73757F878B898A8683828587808B89847D78
2B2522181E4495A6A8A5A3A5A09C9A9794A4B8BBBAA8946D4A231F1E25272C312A2D2F21
29395D6264554242444D5D5F656C7475797E7B7F7D838182837E8484848A8A8E8E8C8C92
93908E939396979595989A999B9D9CA19E9C9F9CA19FA19D9BA0A19F9C92958E8D928B7A
6F6D72797E85878D8A8D8D8C8E8B90938E897A7C
2D2C2A1D1F2E75B0A1A3A3A0978E877F7574809CB4B9B28E5F23262124262729282B301C
302F5E69695D4844444E585D686F7073737A7C81797F7F7F80818386878B868D908E928C
8F8C919494989A979696989D9E9D9DA09C9D9F9FA0A39D9F9D9C9FA1989592948E8F8B7D
796D6D717D8388938F89878B8F908C8F8683797E
24292E1E20224A8794928F9182777370707681858EA1A4A37537362A21262B282726203B
1F295D6F5C5040434A4E5758646A73717B797E7F7D808482818583868489878B8B909392
8E93969397959698999B9C9C9C9C9C99A09D9F9F9EA39FA3A0A29F9A9C9594948F8D9080
756D70768084888D89878A8E8E8C8F8C83817D7C
22253129231A234F7A7F8079796D645F6995BAB1A39C8DAB884C4B31201F2226292C311B
2D2B5673514C40424D51545C616C756D75777D7E7D7F827C7F8185878A888E8D8D90948F
93929599999A989A9793999D979E9C9D9C9F9D9FA0A2A0A3A1A1A19D989A97928C8B8D81
76707072798086878B87878D8D8788857F7C7E7E
2725302B2B2418354E6C63777C746B6B778FACC9BB9E7C877A291C1A2525272527262D22
2D2B5D6B584B393E4C52565D61696F737578767D7E817E7F8388858785868B898B8C918F
978E96969C979A979595989B979AA0A0A0A4A1A2A2A1A0A4A4A4A19B9A9797948D8C8B86
7C766E75767D8386878788858681817F807C7D7C
2D2833302E261B232658446C877E7674798B9BD2CBC5B7AAA5472C1E23222B2426282B27
2A27615E5D4A3B3F4C50565B646A706F777C7D7D7D81818582858588878A83828B909293
97959A96989799959A97999E9C9EA2A3A2A1A0A2A4A5A1A2A3A29E9C9B98948E92938F8D
807F7477737F837F87898784807F7D7A7B7A7E7A
22272F2C352A1D1C23352C5D8591717474828CC4D1CEC2BFC07B351A21212A2525292321
24295E575A493B4150555B5A64666F737278777D8082848581888686868B8E898C919192
979691959799949799999A9F9E9C9C9E9BA6A3A7A4A1A7A4A0A1A3A0A19A9C9691908B8C
81817E7A7B7E7E7E8A87887D7E7A7E7B78787A79
202B322F3029212026151D4F79A1757472777DA8CDD0CED8D2B151262324292B25292324
26265A55554A3F3E4C545A5E656970777B777E7C807F8484828785888691918D908F9191
939B9696959B959B9D9D9E9C9C9C9F9FA2A2A6A7A39FA0A2A0A2A3A29D9B9896938C8A8A
85857F7B7F817B80858287817E79807E767D7778
202D3C513A23251F20131640628F867A72717A89BCD6C5D2CCCC9F343029252427282522
2822525C4B443D3F474F5A63686F727578797E7F817E8481827F8686868A888E90909591
929A9799999C9A9EA19F9A9D9DA09EA1A3A9A7A7A9A2A3A6A0A0A3A2A1A29B999591918C
8785838080857F8081817D7E7C7B7B7A787C7A7D
27354E6D4A1D251B1F1A1C2E507B94826D747F72A3D5C1CBC9D9CF842A25262228232324
2B1F4B64403C3B404A52555F656C71727880837E7D7B85848184898E888A868B9393958E
98959A9C979CA1A3A1A19D9E9DA3A2A7A5A5A7A6A8A6A7A9A8A1A6A4A3A59E9B96918F8B
8A8A86827F878384817F7E7D7C7A7779797B7C7C
2F3A558F7F442319211D1B1F376F98966C6F767392C0C4CFC9D2CAC96828251E24252420
282D445E3D3F383E494F5967696C6E71797F807A808084828284858C8C8C8A8F95929895
95989B9B999AA3A4A1A29DA3A4ACA6A8A7AAA5A3A8A9AAA9A8A2A6A5A9A69D9B96958E8F
878484868480858885857E7E857A79797C7D7C7D
3A4C648C6D4E281C1B1C1C1E256194A0706D707C84A5C6CAC8CED1C2C23B2A1F2522281E
1D383D5B393C373C474E5A65676C70727A7A7D857E88808180878389898B8B938F8E949A
9A999B9C9E9DA2A6A4A09FA4A3ACACA5A4ACAEA9AAA8A6A9AAA5A5A1A59D9D9D98989090
87898981838585848284817E827A7B787B7D7D7C
4561849B895D28221F171E1D2038779F80756B717A9DC4C8CBCCCFCBC4A5481B25212921
2327415E3835343B4B555863666E7179777C79828285838186848285888D8C8E9295979B
98989D9F9E9EA19F9F9EA1A7A6ADA7A7A7ABAEADACADAFADA8A3A6A6A4A29A9D9C98958D
88858882878288858484807B857A7A79797B7D7F
4E739FA59E612A1F211F222124205C968D7F6B707098B9C7CBCCCDD5CFC78E2B2B1C2921
2D1B445A3332323C45585A63676A6F75747B798183838387858886868E8B928F9195969C
9598A09E9EA59F9EA2A1A6AAABB0ABAAA9A9AAAFB0A8AAACACA7A7A7A5A2A29C9A96968E
8A86868387828B888084808280797A7A797A8384
6386B1A38A4C281E26292A2427213E7B9190686A6E89A0C6C9CEC8CACCD8B669221E2826
2A24444C3934343E4E565A63686B7177787A7E82847F8284868289898F9090929194959A
989C9C9E9AA29FA2A5A8A8ADB1B2ACABADACABADAFA6A7ABACA6A7A1A4A4A39D98969591
8B8588878A8483888988827F7F7D7C7E7F7D8284
7893B599732F28212726292A29262E618C9D6667727588C7CAC9C8CACCD8D4A330242621
21343B3D393739414D585E656B707475797E8281848083858689898E8F8D909694979798
989B9E9E9AA4A5A6A9A9A9AFB2AEACAEB2B2B3ABAEACA7A9ACA7A7A7A59DA19F99959790
8C8D888188858A878E887E847F827E7D7A808482
999C92704A282C2422232425272A2D4883967B66707481A7C6C7C1C6CAD4D7BF7737261C
2634354231383D3E4D525E646C7177767B7E7C7D7D848380878C8A8B8C8D8E93979A9A98
9899979B9CA2A5A8A8ACACACB3AFAEB3B0B0B2B0B1ABABAAADAAADABA79FA19D9D979694
8E8C8C8A8B8989898F8481827E7E7A787D7F838A
B0946A48292A2C262021222524222C307985926976708186CCC2BBC4C6CED2CDBD422920
25282D47292F3A424B5461696C727B7C7A7C7A7E7E86897E82888C898C8F909395959B99
9999989F9DA0A7A5A6A5ACA7B6AEAEB3B4B0B3AFAFAAA8ACACA8A7A4A5A8A29B9E999397
948D8B8A898C8C8A8989878480807E7D7F7D818A
9C764A2C2326282726212627261F2528567BA07D6E707974B8C8B6BCC6C4C9CDBDA23A21
252B323F2E303741485565656B737B78767A7E80868687868886888D9194909495939597
9D969B9D9DA2A3A6ABA9AFACB3B2ACADB0B6B5AEB0ACAAADAEACAAAAA7A0A19EA09C9390
908E928E8A8A94908E89848481827C7D7F818282
75562B2324222725231F2524241F1E283B6C9D8D706C756D9FCBB8BFC1BDC0D3D1B36B34
2F283632313433414C59666A71777979767A7F8082888A848484898A9093908C90929497
9B9D9E9EA3A5A5A9ABADB1B1B2B4B2B0B1B6B5B1AFAFAEAFB5ACAAA9A6A5A59F9E9C9592
8E8A918D8E90938C8A898689827A7D7E7F838685
55422A2022232725222427212624231F29598D90876E787083BBC6BFBCC0BFC7C5C9AF3C
372A2C30313035424F52636875777774787A807D81868084868386898D90959391959596
989BA0A3A6A9ABA7ACAEB1B5B6B4AFB6B8B7B6B2ADAFABA7B0ABA8AAAAA59F9F9C9C9D95
928D9292908E96908D888887837F7D8086878580
3E372D2924272929252C2A2D2828201C1B48778E966B79707A9ECDC3B9BEC3BBBCC8CE8D
2B29282A2A2D3742515A6067737376787B827F807D8281868783878C8D9098979294949A
9CA0A2A7AAADADABB2B3B1B3AFB2B3B8BCBAB2B3ABAFA8A9ACADA8ADB0A5A3A09F9B9D9B
99919492969096908D8E8B8787837E7C82838786
4E31303A41342A292D28282F2E2D271C223A587FA57E75717889BCCAB6BCC1BABAC6D1B7
6C2E1C2331323B3E445A616C70747977797B837F7E817D8485868C898C8D9497999A999E
9EA0A7ABAAAAAEACB0AFB2B2B3B4B8B7B8B6AEB2AFACADB0B0B0ADACA9A8A5A4A09A9998
969898948D93918D8C8D85888783827D80808486
683234271F262B2E2F2727323227242326314272A18F73737B71A7CBB3BABDB9BAC2C3DA
AE392A253130353E41585D696E7579797B7A7C79797D82848589909190969A969E949B9D
9F9EA5ABB0ADAEAFB0B4B5B7B1B2B2B3B4AEACB2B3B2A9AEB1B2ABAAAEACA6A6A1A09F9B
95989595929495948D8F8D89858584817C818188
52342F282A2E2B2B2C2B2C2F322C2B2A2924335F899B876D7A6E8BB6B6ABC0C1BCC3C5DB
BDA241252A26353A47575F656C7577797B777E7C7B808082898C8E91929295969896A2A0
9FA1A3A9ACACACB2AEB3B3B3B5B4B1AEB1B1B0B4AFADB0B2B2B0B4AFABAAA8A5A39F9D9D
9B949493979591948F8C8A888387818380837E82
3E312F2D2D312D2D2D2C302B2B2D2F2F2A272C4A62A0956D7E6F7597BDA1B8C0C2C3C2CF
D7BD7C341F21303C43535D646A73757B7C797E827E81858687888D90949593969B9A9A9F
A4A8A6A8A9AEADABB0B2B4B2B3B2B0AFB5B4B1B0AEAFB2B2B2AFB5B0ADA7A9A4A1A2989F
9B9192949290938E90868A848385848382817D81
3F372D2C30342F2C2F312C2A2B2D2B302C262638478AA07A746E757EB3B8B1BAC3C1C2C7
D3D8B44A2F2A283241505A5E686D7777777B7D7F7F8283858988909095979399999E9FA2
A3A6A6ACABAAAEADB1AFB3B2AFAFADAFB3B6B0B0B2B1B0B1B1AEB0B1B1AFA7ABA5A29C9A
99939496948E948C8C888786858385838280817F
453A2D2B36362F30332F2C3130332C292B2B262A3273A5907366756CA5CCA8B3BCC0C3C5
C2D6CCAF3339242F454D5260646E747576797C7D7F827F858D898C9291949999959C9F9F
A3A3A7ADADAAAAABB1B2B5B1A7A9AEB6B0B4AFB2B4AFB1ADAFB3B1ACB1AFAAADA5A2A199
92929496959291908D8988848587867F82818682
3E3424263337342B2C2F2A332F312B292F2E2A252E5294A38264676C8DB5B6AABABCC0C1
BECECBC9893731323F46515A666D767674787B7A81838184888E8D929193999C9698A0A5
9DA1A9B0ABABABADAFB3B4ADABAFB1B2B2AFB1B1B2ABA8AAABADB0B3AFABAAA8A2A0989C
949191928F8E93918F8B84828381857E7F7F8483
3B2E22293232312D2A272D2C2C2E2D2D2D282628333672AD9562656D779CC7A2B6BABFC0
BCC7CCCEC57D312F414A5057676870727674798182828383888E8C8E92999A9C9D9B9DA6
A4A5A8A8AAA8ABABABB1ACAAABB1B4B3B1A9AFACA9A7AAA6AEB0B1B0B0B4B0A1A49E989C
95918F8E8D8D95908B858583838085817F787F82
3632272F3836282D2D2B292F2933302E32332E2B2D2C5494A0796B696E92BAB5A9B4BDBE
BCC3C8C7C0C6602F38414D546069747073787E817E7F8086878E8E919697999C9A9D9DA2
A5A4A8A7A7A5ACADAEAEB0AEAFADAEAFAEA9AAAFAEAAA6A8AAABAFAEACAFABA4A3A0979F
94918B8D8A8B918F89888883818182827E7D827C
2D332F3732342C2C2E2D242D31333432313032312828366C9F8D776B6785A9C1A2A9BFBF
C1BEC3C3C6CEB4453C3D58535D686B707679797D7D81818B8C8C8B8D9396999B9CA29C9F
A9A8A7A69FA4A8ADAFAFAEAEA6A2A5A4A7A7A9ACADAEB1ACA4A8A6A7AAA9A9A5A49F9B9E
948C878F8B8E8E8E8287847E86808183857F8582
302D3135352F2D2B2C2B2B30323133312F2F2F2F2B29324D8A9E8C5F647491B0ACB0B6BA
BEBFC0C2C8D6BAA64F32434F5D656B6F7577797F8083868C8C8F8C93979698999BA39EA0
A6A6ACA5A0A6A8ABB1ABAAABA5A8A7A6A7A9A9AEB1ADACADA9ACA6A4A9AAACA9A4A7A59C
938D878D8B8B918F878884858581808382808382
2F2E312D2F2C2C2A292A2D2E36353533352F33332926312B699D975D68687993B5B3B0B3
BBBBC1C6C6D3D0C38E40404C5A646A6E7274747D7F828A87868D8E9396979A97A09F9FA4
A5A4A7A1A2A8A5A9AEABA8A69FA6A6A7A2A9A5AAAEA8A9B2AEABACA4A6AAAEA8A5A6A79C
94928C8A898B93908D868886837F82847E858181
31282B2C302A312C2B2E2B313933302B3035302C29252C284B8597856C666B89ACBEAAB0
B8B9B8C0C0CDD5D0B47E513A545C696C7171707A7A7F85878286919595989B9B9B9B9BA0
A4A3A39FA3A5A3A2A39E9D9FA09EA09F9DA1A0A5ABA6A5A8ACACACA5A5A4A8A4A6A3A89F
93908684878A8B8D8B8A8A83808083807D838386
302E2B2C2D2C2C2E2A2A2A343733312E2E2F3327242123262F618FA7736B627E9EC6ACAF
B4B5B6B9C0C8CACED3C06E394E5465646D6F76777C81878C8A869398999A999798949D9C
9FA1A39EA2A19B9D989693939696999698989D9E9FA0A19EA6ABAAA8A6A9A7A0A1A2A7A4
9C948A808085848A8C88887B7F81847F82878587
2B282D2D30332E2A292F332E312E2E2F2C2E2A2924222522243F7B9F8C75647695B7B5AD
A5ADB5B8BEBDC3CACCCFA46C4D4E555C6B7174777B8483888C8C919395969B999A979998
999D9C999C999897969292919298959393969395949B9F9F9F9FA1AAA6A3A9A19FA0A7A6
A1928A83818488878C8F87878181827C7F82888A
2D2B332D2E302F2C2C2D35313432322D2D2E2B2B2822262123246088A085656E7EA2BFB1
9EA9B3B4B6BAC2C9C9D0D29D5A5C4D5D617074767C8084898B8C929296969C9B989A9793
969A98949494919592908D8F93928F8B8C8F8F8F9196979A999D9DA0A2A4A8A29E9EA1A2
A4978B8680808488878A888583817D827E818586
2B2D3130312F302F2E2E3131302D312B3134302928242424231C407299996E6A7383C0AC
A0A6AEB0B1B6B9C0C6CECDC2A1565956566270747B7E8484848D93919494959493939496
9595909191948E9695948A8B94898788898889878F8E92819296969D9A9CA29798929995
9D968A807C7E808184868083817F7F817F82878C
2C302E2F33332F2F2E2B32302D2D32303636342D2723241F201E275786A6796B6769B1AD
A7AAA8ADAFB5B6BDC8C8C9CEC59B565B4E5B6B747A7C828586848C9291908B929492949C
8E968C8D8B93939A969083888B888381817D87888D8A8D70969292959F989C9697949190
96949280767B808785898381857F817D8283898D
2C2E2F30302F2D2B2B2B34302D2C30313433342E2622251F201D233E64928F725F6793B6
B3ABA1ADB0B3BAB6C4C6C7CEC9B898585A576870797A7E82878B878D918C8C8F908D9197
9190908D8B8F8F9693888081817B7F7669857D83858A766E897D7D8BA19B94929EA09795
9290897D787A7B7F838684838180808280859195
292E2F2E2A282C2D2C31302E2B2E2F363635302927292726251C1D2E44769F7D5E6772BB
C0B29CA7ACB1B4B8C1C6CBC8C4CAC19C5855666B767C7F81858A8A8B8F89908B90909390
8F8E948F929090948D847A797476806C568B7A8983936E7C85756C889E99949FA5A4A19C
928C817C7878797F828382828084827E82889094
2428292A2C2D2C2F2B33312D2E2E2B303434322D2929232624221F222E51909576576AA5
BDB9A6A9A6B0B4BBBFC1C7CBC8CCCBB58B6E5F656D747D83858587858783868D928F8F8C
8A91908F8E88808A88837B716B6F796A5B7D7F8B85835F68766A617FA3A59FA4AAADACA7
9B938580787D7C7F7C7F817E7F87817F808A9393
2C2B24292A2C3032312A2D2F2E2A2A3131303132342824252527221D2632779F8C515E8A
BAC0B8B2A1AAB0B4BCC0C5CBCBC7C2C7C18E5D5D68707881807E86838384818A8C8F928E
8F9091898779777A80847B6D646E7B6B6772878A8E93959BAAA09798A6AFA9ACAEB2ADA9
A0978B827F7B7D79767A817E81818284838D9393
2D2623262B283330312E32363C3531302D303238373028262325231D2829588796785370
9BBEC7B6A2A3B0B0B9BBBDC7CAC7C3CAC9AD90716069737D787F808385857B8C8F93918F
948B8B867D766E6B666E7472757E8787888F989D9EA6A5AFB5B2ADA6ACBBC7B29F9B9F90
8C858887837E7B7C76797B7B7F838182868C9495
2B272421292A3230332F3137423C3136312E30353835302A262321252C203B6C90A15467
7AAED2BD9E9CA8B0B3B8BDC2C9CAC9C6C3C5BF8A5C66737C7C7E7D7D7E7E7C888F90908D
8C8B827A76726859535D6F7D878B9098A0A3A2AAACB2BCBEC2C3C4BDB5AAA19492918A7B
75797F8582827879727C7A808585837E848C9898
2A2B2C29292F3533342F2C363C382E2F2E2A3338362F2828262A24211C4225537C967768
6183C0C8A29D9FADB9BBBAC2CBC7C5CAC1C7C5AE907A676D787E7C7F7F79818692908D89
88817666595B5A5C636D6E7F84847F85888C9DAEBDC2C1C7C9C9CECEC3B7A6978D8C8C8D
6B777A80807E777677797A8080828081848A9191
2E302D2C293034373C332A313935322E2A25282F3130262A29262024281C38485D7C9A75
5560A5C7A6A29CAAB6B7B4B8C3C0C9C9CBBDC4C8C695706A77757A757778827F898B8885
807563513E494E6371747682847A7064637389A6BEC3C6CBCCCED1CECEBDAE9A878B909C
6B7278807F767277777A7E7B7F818483858C8F94
34352C2D272B32475743282C3834353129272B33332D292B2A28212329282F36435D9082
544B84ABAB9F919CADB0B2BBC3C5C8C8CAC5C6CAC9AF9A7F66657773787D807D7E82837D
71685844343E4A5C73797B78765B4F45495060789BBCCECFCCD2D2CDCAC7B8A6918A8582
6871807C746F737777797779818586868C8E9696
3B332628293135596C522729322F32302A2D2E3038312C272A2A2926283328272E3E7B8B
65476C86B09D9596A3AAABB4B8C1C5C8C9C4C6C6C6C7C8986A6570727981818176737371
685948332936485869757B6A52423A3434333C50679ECBD0CECFCECCC8CAC2B09B856C65
687582736767727C787B7277808684888A8F9999
3432232425333668744E34322F2F2F2E2A292B3539332C272C282B27272B27232135647E
7A5B5D779DB2A09F989B9EA4AEB5BDC2C7C8CAC4C3C9C8B39878646971787B736B67645E
574A3E302B37495F6C74725F4143485862574A434E6BA6CACFD6D3CFCFD0C7B4A37D5C55
617D726C626A7077747572767C8586888B8E9498
333128272833437B754341322726292B2B2A2C313A2E2827292A302D24252425242F4C6A
8871596B8BC8B6AE9C97979AA9ABB6BCC4CBCBC7C6C6C7CAC79365676B6E72695E574F4B
43342E2B343F4D63766F634A384F635D50565A433B4185C5CDD7D0CDCECECAB596694852
63856460646372736C74767B7E8084898890989B
2C2E2D29292F539060303F2E2A2826292C2F2C3137312825272A31322725272D3E394252
83906F6B70ACC6BBA7A4A4A6B2B5B7B8BFC7D0C8C8CAC5C9C9B48E6D56616863554A403F
34322F30343B4D6778614E395157594E374A515D472C59B6CFD0C8CED0C8C6A57F5A3F5F
777B5B5F6D6C74726E757D818086868A86919494
2F31302C2D2D6695472947302A2823292D292D3534342E2C292D3435302E2A374E43413C
76A2886D568DC9BEB6ADB1B1B6BAB6B9B6BDCDC9C9CDCBC6C8CAC27751555E5954413937
31302A312E3A445C6B523B346859483422394771532C48A7C7CBC6CBC6C3AF8C62523E64
866C525F77757B7271798280838A8A88918F9191
2E2D2D263034797C3925372C2F2A2A2C2A2F30322F32302D2A37484A493B2B231D1F2D2D
52919B885775A5B5C1B8A9AEB4BAB7B6B8BCC7CCCFCCC5C4C4CABEBC74594F56554B423F
32302A2D2B363A4E5C483036564A382C241E3A5150394397CFD1C4C1B9B68866433E4056
68564A627A7C77777479808486878C8C91919195
2E2F2D293342885F322B2F2C31302D24302D2C2F323839362E3E4F534B3E292628211A24
316C9C9C636C79A1CABCA0A3AEB0B2B4B3B7B5C3CCCEC3C3C4CACCB3B46D474A5B564B46
3D33272A2B2F36424B3B2E353B342E272A286152405C83AAD0CDC3B6A3A15D4128323744
464C496782817F787A7B8187868B8D9093939698
29353B4730548D512E28312D2B2B2A2B2D2827374D575B544C5E6651352F2B2823231D1F
294B8E9C876B628DBDCFA7AAA8ADADB5AEB8B7C5CDC9C7C6C2C2C7BEBAB56C3E494D4C45
3F36302F2F2933383A332F3537322B282828473F3B57769FBFBAA69472673E33272D2E2C
304251697E87827B7B7B8283898A88908F949697
243F485C2A5C8A422D273331282927272625274C6B747575644E392925262A2824232820
242B738DA3815678A8D3B4B0A6A5ABB5B2B8B8C6CCCBC9C9C4BBBCC6CCB3B74D4B404A46
41363437332B31322E2E33352D302E2D2D332F303F4B6284A19F876F4D382A262A262426
28455E75888985847F8285858A898B9093989996
274D444E2F5D813827292E2C282426272D274D667A7B705F47372E24272D312624272823
242248779E9865728CC0C1B4A4A6ADB3AEB8B6C2C3C5CBC5C4BBBBC2C2BFB2AD68464644
453F373531312E353031323630352E2F2D312B30343C4A6579746149362A26252C27242F
3A57777E878682837F7D7F868F90909193949897
33563A333152733528252626252122262B2E737978725B3F292025232B2C322E272A2A25
201A246093A67171729EC6BCA9AAABB1B0B2B6BEC4CCCAC3C3BEBDB9B7C2C0C8A5574A43
44403F393735353439343536323530302E2D322F333235464F4739312F2C2E2B2B222B3E
5B7085858A86827F7E8183898A8C8F8A95989D9B
4B3E302A305E683326262727272326313556797561513D322A24262A2C31322C272B2223
21191D4C6CA7937C6D7DA8C4B9A1AEB1B1B0B7BCC3C8CDC7C4BEBEB9B7BFBBD0BB8B4C3F
4449494342403B31303538373233302E302D2C2F2F2C35333736342C2B2725282D2C3A5C
7A818A838283827E7A8181898B8F92949A9F9A9C
5E282F272D6A5D2C26212525282B2E3A457F7560443122262E2B302E2F302E2722282525
2020213445959F87735F8BC8C39DB1AEACB0B3BBC1CAC8CBCABFBDB8BBB8B3BCC3D7926D
474D5751504744393438403B343B363232343135343232312C2D312F2A27242D3A3A4F6F
8D8B88807C7C847E7C83878B8C8E9398999E9C9C
472A2E2E3558602D302725222A2E3647587B654A2E2626292F2C303030302D2A29282D22
3830201E2B6D959C7F5879A8BAB5A9AAACACAFBBBFC2CBCACDC0BDB8B1B0AEB2BDE2CE96
574B4A4D5C54534E4F4F4D473B403B3C413D363330383C4340362A30322B393F4A7B5F5E
7B90827F7B7B7E7A797E83878B91929B9AA29E9A
2F2A2A303B4A652E31292921292F41576A61503525262F2F2E2C2F2F2B2C2D2B2B292E23
4B3825181D4979AB93596789A5D0AEAAA7A7AAB3BCC0C5CCCBC6BFBCAFAEAAAEB4BCC3C0
AA6F4C54625E5F6364615A53484C48514E493C342A3B515E58473137463F405A71758353
5F85777478747573757A80838B959A9D9DA29E9E
2C2E2C323954563328242723273549616F5C3D2F24222A2C2D2A312E2B28272D2C21272C
48351C151E3457929E7466738DB9BCB7A5A8ADB2B8BEC0C6C8CBC4BAADAEA6ABB1B6C5D2
D0C771645E60656A6A6B66625F5E606865665D3E2D466A8E967251495D5F496070798368
6476706C6C6C6D6C6D7A828D979C9C9D9FA5A3A1
2F2B282C2F5C473923252A222B3951656E4F2E2B272525272A312F2728262A25283F5750
412D1A1D2128396DA0917369729CC3B9AAA9AAAAB0B9BFC1C5C5C6B8AEA6A0A5A7B1BBBD
C5BBB78863636D6E75737472787A7B7C7E807453355D84918E857B5C7988575F6D74776D
64666D675E6565696C7786969D9C9D9FA2A5A4A4
2C292B2E2D573D3C2C2C2B242D4157646D42362927242B292C2E312B2D233A43446F754D
34333D22201B2355819095857785A4B6B8AEA5A7AFB7B8BFBFC7C6C0B5A199A0A1ACB5BB
C6CDC5AA907B6C6F74787D7E828688898684816856769BA4A1968A77838A765D6B6E6D68
60595D58535259606B808C9AA3A3A4A1A6A6A6A6
27252D2F264A2F38382F25233240585F60323F2D25262728272727273225586058725022
2B3F5F2623161B375B8AA7977C767FA7C8B1A5A3AFB2B4B8BFC3C9C3BDA79A9999A8B1B6
BCC7C5CBC39C727780828485818B919691898A7F7989A3A59F968E888481865C6A605B56
534E4A4947494F63728997A1AEACA6A5A9A9A9AE
2023293A476F574735414A5A43494F5B4630333B242523282728232B3229486069815728
304B5A232D221C283E749E9B87706892BCB8B6A9A5A9B1B6BDBFC8C4C2ADA099989BA8B5
BAC0BFCAC9B79E816B717B808894919B9A948F8B8F9BA8A5A0958C847D727457594F494A
43434245495661758C98A2A6ABA9ABA9A7AEACAD
25272529284D3B3D3A3D314B2538485C2A3029452525272128272328335467603A685931
335445283B31212029588A9A97715E789CB4C0AE9EA5B2B5B7BDC2C6C6B6A798959AA6AC
B1BABEC1C3C8C2AC91807481909492999C9695979E9D9D99978D867A70625A534A494441
3D3D444B546E7F94A1A8ADB1ADA8ACA9A9ABAEAB
272929282B423F444541393F2E42484B2D30303F32302D2C2B272638406B662626485B2B
4A5B36274A351B1B244566879A8F6265789DB8B2A4AEAFB0B6B9BBC0C5B8B09E9997A2A7
B0BABCC1C2C7C8BFAD93817E7C858F919997919895928B87867A71645A4F484647444349
4F555D6E7C8D96A3ABABB0B0ACAFB4ADADADADAB
1E2B2D28282C35444D4638313944483C2E2C2D313431282B2D2D27445D75424A36445E27
5C582523563A1E1E28333C6F97A7665E5A83AAB7AEAEACA6B6B3B9BFC8BEBAA4999799A0
A7B5BCBFBDC0C0C5C5B29183787D858894928D8E8B7F7A796E6A655A504140404A4B4B58
69707C909FA6AAB1B4B3B0AEB6B2B6B1B1ADAFAD
252B37302A27333D423831363A3940322E2C2E313A322A2B3543524C5556393636335F38
664F282C5F381F1D2023284984A3856B586C88ABB9B2AAA5AFB3B4B9C3BDBDAA9D9B96A2
A3AEBCBDBEBEC5C6C5CAC49D7066646F70757A78726C666662656057524D51545E62697C
888A97A2A9AEB4B6B7B1B1B1B4B4B2B2AFAEACA8
212D3B342A2D35342D2B31363B32352E2E2C2C3739322E33383336274F3A2F2C372B6549
68432F2A64422C211F1C22276D899B83615D6698B7B9ACAEA9ABB0B8BEBCBEAE9A9B979E
9BAABBBEC2C6C1C7C3BDBEBBAE7F4F61565864666260655B6165685E5B6B70757C858695
9AA1A6AEAEB2B2B9B9B3B4AFB0B4AEB3B1B0ACAC
1D2D36312F363E3E35322D3534412B282829272F31302C313630372854382E2531255F5A
66442B235C5A36353B2D2422457694927C685D7A9EB3BEB5A5A6AAB3B7BBB7AB9C9C999E
99A4B2BEBFC2C1C0C4BEC0C3B9A1924548414C595D636B6C6C707679747F86868D9198A3
A3ACADB6AFB2B4B5B4B5B8B1B2B3AFB2AFB3B1B2
222732322F3E42463E3C3C3A2D5124292C2A2626292A30343733352E594028212E1C5C67
64412419546B464A47392723244E7B9A9A7557627EA2CABCA4A6A9ADB0B8B3AFA39F9896
9DA4B1BCC1BDC1C0C6BDBCBDBBBDB6A166554553666F74747B828A91929598949C9EA4AA
AAABACB0B0B2B2B5B6B5B4AEAEB2B0AFB2B0B5B2
1E282D332F2D324E6463554B4554383B332B29262C2D2F3235353229555A2727291D4761
6E3C27213C61392B3635322B233451839F89685F6689B5BBB1AA9FA9AFB4B0B2A8A29E9E
A0A6B4BABEBFBEBAC2C1B9B6B6B8B5BBAB8D726C6E7680859090939A9C9E9E9CA6A2ABAC
A8ABAEAFAFAFB0B0B7B3B0B2B1B1B0B5B4B1B3B5
1E282C2C2B27303244576A685C50504A3E332D292C312A383B37301F4D772628242A3A5E
763B2828236A633422313B352C202F649792795F536B92ADBEB09FA7A9ACA9B3A8A5A19E
A0AAB3B9C0BDBDB8BBBFBDB6B3B7B0B1AEA4A2967E818C9398999CA09EA6A2A6A7A6A9A9
A9ACAEAFB0B0B4B0B2B3B7B4B2B0B0B5B3B9B8BA
2D27242C341E363A474A535E676446443D392C27282D32393D2D282642763D25262D3B59
77393929274C71383520332D2B2320467285846C545C7696ABBEA3A5A5A5A9A9A6A29D9E
9EA9ACBAC4BCBDB9B5B7BCB6ACAFB4B3B8B2A89F9591999B979CA2A0A1A8A6AAA6A3A5A7
A8A8ACB0AEAFB5B0B0B4B3B4B2B4B1AFB2B4B6B7
392F262F432046423F3730546F783A3D423E2F2C22272C34382F202D3963502328354255
653A45342B2758833D1A34252824242D4D6F8B7562575D7F97C1A9A69FA2A59EA4A19D9F
A1ABB0BBC1BBBEBBB5B9BBB4B3ACB1B2B4B0A9AAACA29B9F9A9EA5A5A5A7A2A2A2A4A4A3
AAA9A6A8B0ADB3B1AFAFB1B0AEB5B1ADAEB3B8BB
424A2D2F32333332312C2A303E676F634C3E312D252E2B343A30243033586322272F424E
51363C34362744746A442F211D1B1E2630557A837E6E66717CA8ADA9A5A0A2A0A4A29F9E
A1ACAEB8BEBFBEBAB9B5BCB5ACA6A3ADBAB7AFAAA7A69CA29D9AA1A2A4A7A8A7A2A3A4A1
A8A9A7A8AEAFB1ADAEABACB3B2B8B2B5B1B5B8BA
385F382D2243262925252D3946505F625F4B352F232C2C313D342828324B6A2A24344446
3D342F2E362B2E5F8C63281F21201E242344668A9B89786F6B87A9B3AFA19C9EA0A1A0A2
A4ACB1B8BEBEBAB8BDB8BBB6A89B91A3BCBAB5AEA5A8A6A29B999B9BA4A1A4A59A9EA09F
A6A3A7A7AEB0AFA8AFAFAFB2B4B2B6B4B4BABABB
324B4335283D27271F28394F3F3B44555F4B3F352829313436352C2728446838263D5434
313E2529333634577E55211A1F1D15282E596B85879D887C6D788DA4AEAAA49D9FA3A5A0
A8AFB7B9BCB9BCB9BCBCB6AEA37E85A6B2BBBEBAA9ACA7A09C9D9A9B9B9AA0A09EA1A2A3
A7A3A7A8AAB2ACAEADADB2B1AFAEB5B8B3BBBBC0
2231473A272C2D26263548653C2C253F564F49392B28343237332F2A28425B432B46622B
2B3E21272F3B394F5D422021241E1D364D7967666DA99C88706B758CAAACA4A3A39EA4A7
ACAFB7BEBCBDB9B9BABDB0A29D6E7FAFACBDC5C2B7AFA59E9F9E98959B9B9B979C9AA1A2
A1A2A6A8AAB1A9ADAAAEB0B1B2B1B3B6B4B3BAC2
252A38342C262B2F2F5A574D382A29364751563F302E323136343028263C4F502B3E4D2C
2D3A2A36442E334A564423231E1F213A777A5B3C51889A928075727D95A8ADA79FA1A4AB
ACB8B2BBBFB9B7BDBCB8AE959E6E85B4ABB7C0BCC0B8AEA8A49F9B9CA09DA298979AA19F
A3A0A5AAA6B0A7ABAEADB1B7B5B3B2B8B7BDBCC2
232B2B2B2C2826373D76642D34312F3036475C45342E2F323C36332A293A43582E353635
2C2D39475A29354955402A22231B284197774F18325B8E998F827772829AAFACA1A0AAAD
AFB5ABBBC2C1B9BCBDB1B0889E768BB2ABB5BBC0C8C0B6AFA8A09FA19F9CA39D9A989FA2
A3A29DA8A5ACABABAEAFABB0B0ABB0B6B8B6BDBF
222727262A262A40536A4F383D353332343B4B4234312E343D373430303640513B3C322B
232D3B5D5E37484B4844352B262D386A9665331A233E6B87979C7970768698A9AEADAAA7
ADB1B6B9C1BBB8B6B7B7B58AA07F88B0A0AAB3BDC7C2BFBAADA3A3A4A4A2A8A19D9A979C
A3A19AA8AAACAEAEAEADACB1AEB0B3BBB9BBBDBA
2B27292A2A292A4C685137474E46393029303D3E35302D343639363731343A4249453427
232C3C675B4A5A4F40484D38283A4791865D211D1C2B3E6F94AB827A6F73839FB9B5A9A5
ABB1B7B9BBBEBAB2B3B1B78E99938FB29CA8AFB8C8C7C6BEADA7A4A5A79FA6A3A5999097
9C9F9FA0A6A1A5ABA9AAACAEAEB3B4B9B6BFBEC2
2B25242A28282A506F412F343B3D37363730323E3F37292E39353C392F30343A463E3529
2A37445D534F5F4553515B55595C75AA885F27251919284C7095998D77727A90A6B4BAAB
A6ABB9B7BBBAB6B0AFB2B2968F9598A59CA9AFB9C3C7C6C5B5AEA5A7A5A5A7A4A59E9D96
96939D9FA39BA3ABAAACABA9ABAFB8B7B8BFBFC0
3228242B2D2D2E5075332B252A32353F3E35303B453B282E33333E3732302D35433B332D
2A3F4D4B4D5A6144686361534A3C659C8D6833241E181C345078A1988474727A8BACC2B7
A5A9B8B8B7B1B1AFB2B2B6A08C94A3A4A3AEADBAC2C8C7C3C1AFA8A8AFA6AAA8A1A0A398
96969A9FA4A3A2A3A9ABA8AAAAAEB6B7BCC1BEBF
312829262B2E35626B402A26262D343F453F30363B382F2F3432393A35322932393E3533
35333C47556069647957524242376B8E78482A1D211C2026395983979B887978819AB3B6
B4AFAFB4B9B0B0AFADACA99F8697A6A6A8B3AFB3B9C2C2C6C0B8A9A9B1A5ABACA7A3AAA2
9C969595959CA3A2ABACA9ABAFAAB7B4B9C2BFC2
2F2E2827312E3772644A23262C2D2D404E44343537382F323036353A3C33272C36413E38
3A2B31465D6A758080464030302E6B815B22221F2123221F20395D89AB9C8175708696AE
BCB3A9AAB8AEA8A5A4A6AA998792ACB0AFB2AEB4B8C0C1C0BAB8ABA5ADA7AAA9AEA7A8A8
AA9D9794959AA0A0A5ABA5A9ACADB5B7BAC3BEBF
403935322D313968664D292C2E2D2B3948423E3B363337312E3432363C302C333A424039
3631354E616A5A607F39352832377D89442428222424221C212638608DA596846C787B95
B0B0ADADAFA9A7A5A6A8A3968590A9ADACA9A5AEB9BFC1BBB8B9ACAEA8A6A8ACAFAAAAAC
A9A5A39A9795999EA6A8AAAAADADB3B4B6BEBAC0
4D4B41312B3039587054302F2B252C2D3141473F393637332A2B2F303C312C3640413E37
343C42545F6A413D7230312D374B8E8C323029262821242523211C3A5FA69E8F776B6A80
A1B3B6B0A5A8A5A3A5A9A48F8293A9AFABA79FADBEBDC0BDB9B2B0ACA7A9A8ABACA9A9AE
ADB1AEA59D92949CA4A1A6ABAAAFADB1B5BABEBE
64605E432D2D38526C59332B28282B2B2F394238353340362D2B3333313C3F4246403F37
2F3E4A485A622A315C3A362845758E7129292A2628212422221B1D263C788BA48F7D636E
89A1B2B5B7B0A0A4A9A8A5918490A0A6AFA69FADB6BCC1B9B4B6B6ACA9A8AAABA5ABA6AA
A7ACB1AEAEA098959C9FA8A9ACACADB3B5B8B9B7
40393F3A36313150675C3F35272C2A292A3538372B353D3B2D2D322E2F424E4E4C453D3A
3C454E385A5D1F3347403925549D86582929231F2A22232322201E1D204370AEA88D6D68
7087A3B5BFB3A2A4A6A7A28B828999A1A7A8A7B0ADB9C0B5A9B2B9AEACA8AAA9A8A5A3A2
A9A6ACB7BAA99F939899A4ABACA9B0B2B3B8B9B9
5D5243362A2D334A60594F2C2924272B2D3037332C303532352F37383A4B534A413E4545
47414042595B223241383330519984582C2B333135322527241F1F1E1D2A4B869B988B78
697283A0B6B7AEA89FA09E8878889DABB2AEA9B0B0BBC4B8B3B8BBAFAAACA5A6A5A8A29C
A1A2ABB3B6B6AEA79E9B9DA4A7A8ADB4B2B5B6B5
74623D3626252D4158575F2B31242D2B292F322E2D2B332E2E31333A4A4F54453C404E4B
49382E465E5D262D3E34303F4C92825B313746473E3C322C26232323211C2956839DA18E
6D6464839DB2B4AD9DA0978A768AA5B1BFB8ADAEB3BCC2BEC0BBBBB4ABACA7A3A1A39E9E
9FA5A6AFB0BEBAB6AF9D9B9EA4A4A8ACABB3B3B4
796D5A3F2523303B49515B393228312E2D312F322D31362A2C333D49565249443E484F4D
44362C3D635F2227332B2C46608A8A704E505A6A6A4B282426242523221E2536557D9A9A
866E5C698498ACAFB29F90767F94AFB3BEB9B0B1B9BBC0C6BDBCBEB7AFADA5A7A3A5A2A0
A0A5A4AAACB7B9B8B3A8A0A0A5A5A6AAACB4B6B9
75572F23292D342E3546554E39312F302D2B2D2D2E36332B2A3B4C545B4C3A4047515C4F
3A2C2D30625A20262D313655778488756161695C4F382A2626232520232226202E59869E
94745859607899B0B9A1916C8F9DAEB6BDB4AFB6BCB6BFC2C1C3C0BBB9AFAAABA5A2A09C
A0A8A3ABACAFB5B6B8B5AEA79FA3A8A8AFB0B2B4
715636282A30362E2A3C4E5B3F362F2F2B292B2E2E302E303347565752443F444F5A5D49
302C34395A4B2620283E556C7C7E7B64463832272628302E26292A2326232323243F5C7D
8E755F6B55637997ABAA8D769E9DA0BDB9B4B7B4B8B7B7BEC0C1C3BDB7B2ABA9A1A3A09D
A3A8A3AAACABAEB2B8B0B1ACA29E9EA5A9A8B0B6
725D403435393931263A4968453D31302C2B3131322B302E314A625944454147525F5D42
252D354A553F29242C4F6E82857867422824343235342F31282B2C272223232321293258
7F786D7E5553577592AE877EAFA28FBDB1B5B6B5B7B7B9BABBBBBEB9B7B6B3ADA3A4A09D
A1A4A5A1A7AAABB6BBB2B0AFA39F999FA2A5AFB5
6D66513E52524A3A303A475C4E48383633312E2C2C2D3335374F58554345434855575642
2A2F2F4D503B253043527B7F77654B392526302D2F3132312F302D2D2D2A252824262D40
5A646F816858485E6F937678AF9F85B0B6B8B2B1B5B2B5BAB9BBBBB8BBBAB5B0AAABA2A1
A0A4A9A4A6A8ADB6B5B0AFADA7A39DA1A5A7ADB2
6E6661446F685D473C3F48505951423D362D322F2D2B30363A4D504E4547455356524E41
313035475237223860517E807253362D292D313332302F342F292C31322C273029202B2D
39567087755F434B5A7D6D74B39D88A0BBB7B4B1B5B3B7B8B4B8BEBABABDB5B0AEADAAA3
A3A8A7ACADB1ADB2B1B5B2B1B1AA9DA2AAAAA9A7
70656747776D5F5F614E474D6057413A342B302C2A2A313A3E4D504E4348465158564C40
3230354B5138223F63527F7E6F4E362A2D302F3032312E342C292C33352C282D251B2829
334963518475605552634863B59A859EBDB9B1AEB4AEB5B7B4B7BDBDBBBDB9ADAEACA1A2
A3AAABAAABAEB0B4B2B8B2B5B2A99DA4AEAAAAA9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{890, 278.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=j00015R000`400?l00000o`00003oo`38h=So
0<SPf?l0b>3HO@38h=P00?l0b>3Ho`38h=So0<SPf7d0b>3H003o0<SPf?l0b>3Ho`38h=Qm0<SPf000
o`38h=So0<SPf?l0b>3HO@38h=P00?l0b>3Ho`38h=So0<SPf7d0b>3H003o0<SPf?l0b>3Ho`38h=Qm
0<SPf000o`38h=So0<SPf?l0b>3HO@38h=P00?l0b>3Ho`38h=So0<SPf7d0b>3H003o0<SPf?l0b>3H
o`38h=Qm0<SPf000o`38h=So0<SPf?l0b>3HO@38h=P00?l0b>3Ho`38h=So0<SPf7d0b>3H003o0<SP
f?l0b>3Ho`38h=Qm0<SPf000o`38h=So0<SPf?l0b>3HO@38h=P00?l0b>3Ho`38h=So0<SPf7d0b>3H
000L0<SPf080EeMG0P1XJ6P208>3P`80YjNW0P2l_;`203<c<`80:BTY0P0T92@202h^;P809RHV0P0R
8R82034a<@030410@00o?cl0?clo0080>SXj0P0e=CD2038b<P80=3@d0P0e=CD2038b<P80<30`0P0d
=3@203Lg=`80=CDe0P0c<c<203@d=080>3Ph0P15ADD2051@D080Bd];0P12@T8203dm?@80>3Ph0P0a
<C4202`/;0@0:2PX0P0`<3000`0k>c/0KFe]06e]K@0406=SH`80FUYJ0P1lO7`206MWI`80ATI6101P
H60206ATI080K6a/0P1cLg<207EeM@80MWIf0P1jNWX207inOP@0Ogmo0P20P8020861P@80Ogmo101n
OWh207moO`030861P@23Ph<0Ph>30080QXJ60P28R8P408Z:RP80RHV90P28R8P208V9R@80Rh^;0P2>
SXh2092@T080SHf=0P2;Rh/208j>SP80T92@0P2=SHd208V9R@80R8R80P29RHT208Z:RPP0S8b<0P2=
SHd00`2>SXh0Shn?08n?S`02092@T080TI6A102BTY84096AT@@0T92@0P2ATI4209:BTP80Ti>C0P2D
U9@2096AT@80Shn?0P2ATI4209BDU080TY:B0P2@T90209BDU080V9RH0P2FUYH209BDU080UYJF0P2I
VIT00`2JVYX0Vi^K09^KV`0209fMW@80X:2P0P2SXj<20:RXZ080]KFe0P33`l<20<[:bP80clo?0P3@
d=020=?Cd`80/k>c9`38h=P205eMG@80IVIV0P25QHD20;^k^`80]KFe0P10@40402TY:@8092@T0P0X
:2P202HV9P80;Bd]0P12@T82059BDP80>3Ph00<0<c<c03Ti>@0i>CT00P0b<S8203Ti>@@0;bl_0P0h
>3P203De=@80>CTi0P0_;bl203Xj>P80=cLg0P13@d<204];B`80DE5A0P0o?cl203/k>`80>3Ph0P0_
;bl202d];@809RHV0P0[:b/202PX:080?Shn0P1ZJVX406IVIP80FUYJ0P1aLG4206EUI@80De=C0P1L
G5`00`1RHV80IfMW06MWI`0206YZJP80Lg=c0P1_Kfl207IfMP80PX:20P1mOGd207alO0@0Ph>30P1k
Ng/208>3P`80OGem0P21PH4208:2PP80OWin0P23Ph<208F5Q@80R8R81029RHT408R8R080QhN70P2<
S8`208j>SP80TY:B0P2;Rh/208j>SP80S8b<0P2@T9000`2<S8`0R8R808R8R00208V9R@80RXZ:0P2;
Rh/208j>SP@0RXZ:0P2=SHd208j>SP80RXZ:0P2BTY8208j>SP80Shn?202BTY8209>CT`80T92@0P2=
SHd2096AT@80UIFE0P2CTi<208n?S`80SXj>102BTY8209FEU@@0T92@0P2IVIT00`2DU9@0Ti>C09>C
T`0209JFUP80Vi^K0P2GUiL409^KV`80WYjN0P2PX:020:b/[080/K6a0P34a<@20<o?c`80bl_;0P3A
dM420<o?c`80_[jn9`38h=P205IFEP80IFEU0P25QHD20:>SX`80_[jn0P0e=CD202TY:@808B4Q0P0^
;Rh202@T90808b<S0P0c<c<00`0n?Sh0@4100410@00203Xj>P80<C4a0P0b<S8203<c<`80=3@d0P0a
<C42030`<080<S8b100d=3@203<c<`80=3@d0P0i>CT204=3@`80D51@0P1;Bd/20451@@80?Shn0P0h
>3P2030`<080;Rh^100X:2P202l_;`0303/k>`1YJFT0JFUY0080HV9R0P1QHF4205YJFP80OGem0P1X
J6P204I6AP80H61P0P1RHV8206ATI080Jf][0P1bLW8407IfMP80Ng]k0P20P80207emO@80P8200P1l
O7`208>3P`80Ogmo101kNg/207emO@0307inOP23Ph<0Ph>30080RXZ:0P25QHD208N7Q`80RHV90P2>
SXh208N7Q`80QHF50P2;Rh/208n?S`80SHf=0P2<S8`208V9R@80T92@0P2BTY82092@T080QHF50P28
R8P208V9R@80R8R80P2:RXX408^;R`80SHf=0P2>SXh00`2@T900Shn?08n?S`04092@T0@0TI6A0P2E
UID2096AT@80T92@0P2ATI4209:BTP80TI6A0P2FUYH209BDU080TY:B102@T90209JFUP80SHf=0P2@
T90609JFUP80UIFE102GUiL309^KV`80VYZJ0P2QXJ420::RXP80Zj^[0P2e]KD20<G5a@80bLW90P3=
cLd20=?Cd`80e=CD0P2a/K4N0<SPf0007038h=P205MGE`80J6QX0P23Ph<20:NWY`80_;bl0P0c<c<2
02TY:@8092@T0P0^;Rh202HV9P808R8R0P0a<C400`10@400?clo03lo?`0203Xj>P80=CDe0P0b<S82
03@d=080=CDe0P0b<S82030`<080=3@d0P0g=cL203De=@80<c<c0P0d=3@203Ph>080ADE50P1@D502
04];B`80@T920P0m?Cd203Ph>080<C4a0P0/;2`402PX:080<30`00<0>c/k06e]K@1]KFd0101SHf<2
05YJFP80O7al0P1WIfL204I6AP@0H61P0P1TI6@206a/K080Lg=c0P1eMGD207IfMP80NWYj0P1nOWh4
07moO`80P8200P21PH4207moO`@0OWin0P1oOgl00`21PH40Ph>308>3P`0208J6QP80R8R8102:RXX2
08V9R@80R8R80P29RHT208^;R`80SXj>0P2@T90208f=S@80Rh^;0P2>SXh2092@T080SHf=0P29RHT2
08R8R080RHV90P2:RXX808b<S080SHf=00<0SXj>08n?S`2?Shl00P2@T902096AT@@0TY:B102ATI44
092@T080TI6A0P2BTY8209>CT`80U9BD0P2ATI4208n?S`80TI6A0P2DU9@209:BTP80T92@0P2DU9@2
09RHV080UYJF0P2DU9@209JFUP80VIVI00<0VYZJ09^KV`2KVi/00P2MWId20:2PX080Xj>S0P2XZ:P2
0;Fe]@80`l?30P3:b/X20<o?c`80d=3@0P3Cdm<20;>c/bL0b>3H0P1MGEd206IVIP80QHF50P2k^k/2
0;Fe]@80@410100Y:BT202@T9080:2PX0P0V9RH202d];@80@T920P1BDU8203Ph>00303<c<`0i>CT0
>CTi0080<S8b0P0i>CT402l_;`80>3Ph0P0e=CD203Ti>@80;bl_0P0j>SX203Lg=`80@d=30P1;Bd/2
055AD@80?clo0P0k>c/203Ph>080;bl_0P0];Bd202HV9P80:b/[0P0X:2P203hn?P80JVYZ101VIVH2
05YJFP80LG5a0P1UIFD205=CD`80G5aL00<0HV9R06MWI`1WIfL00P1ZJVX207=cL`80Kfm_0P1fMWH2
08:2PP80OGem0P1lO7`408>3P`80Ng]k0P23Ph<207emO@80PH610P22PX8207inOP80Ph>30P25QHD2
08R8R0@0RHV91028R8P208N7Q`80S8b<0P2>SXh209:BTP80Rh^;0P2>SXh208b<S080T92@00<0S8b<
08R8R028R8P00P29RHT208Z:RP80Rh^;0P2>SXh408Z:RP80SHf=0P2>SXh208Z:RP80TY:B0P2>SXh2
08n?S`P0TY:B0P2CTi<2092@T080SHf=0P2ATI4209FEU@80Ti>C0P2?Shl208j>SP@0TY:B0P2EUID4
092@T080VIVI00<0U9BD09>CT`2CTi<00P2FUYH209^KV`80UiNG102KVi/209jNWP80X:2P0P2/[:`2
0;6a/@80a<C40P3?cll20<_;b`80dM7A0P3?cll20;jn_RL0b>3H0P1FEUH206EUI@80QHF50P2SXj<2
0;jn_P80=CDe0P0Y:BT2024Q8@80;Rh^0P0T92@202<S8`80<c<c00<0?Shn0410@010@4000P0j>SX2
034a<@80<S8b0P0c<c<203@d=080<C4a0P0`<302038b<P@0=3@d0P0c<c<203@d=080>CTi0P13@d<2
051@D080Bd];0P11@D4203hn?P80>3Ph0P0`<30202h^;P@0:2PX0P0_;bl00`0k>c/0JFUY06UYJ@02
069RHP80HF5Q0P1JFUX207emO@80J6QX0P16ATH2061PH080HV9R0P1TI6@206][J`80LW9b101fMWH2
07]kN`80P8200P1mOGd20820P080O7al0P23Ph<207moO`@0Ng]k0P1mOGd00`1nOWh0Ph>308>3P`02
08Z:RP80QHF50P27QhL208V9R@80SXj>0P27QhL208F5Q@80Rh^;0P2?Shl208f=S@80S8b<0P29RHT2
092@T080TY:B0P2@T90208F5Q@80R8R80P29RHT208R8R080RXZ:102;Rh/208f=S@80SXj>00<0T92@
08n?S`2?Shl0102@T904096AT@80UIFE0P2ATI42092@T080TI6A0P2BTY82096AT@80UYJF0P2DU9@2
09:BTP@0T92@0P2FUYH208f=S@80T92@1P2FUYH209FEU@@0UiNG0`2KVi/209ZJVP80XJ6Q0P2RXZ82
0:^[Z`80]KFe0P35aLD20<W9b@80cLg=0P3Cdm<20=CDe080/K6a7P38h=P001`0b>3H0P1HF5P205mO
G`80L71`0P2QXJ420;no_`80YZJV0P16ATH2024Q8@80:BTY0P0U9BD202HV9P80<C4a00<0>c/k03Ph
>00h>3P00P0c<c<203Lg=`80>SXj0P0g=cL203<c<`80<S8b0P0a<C42038b<PH0=3@d0P0f=SH203/k
>`80@T920P1<C4`204Q8B080@4100P0i>CT203<c<`80<30`0P0_;bl202TY:@809bLW0P0_;bl00`0j
>SX0K6a/06a/K002069RHP80I6AT0P1LG5`207]kN`80HF5Q0P1?Cdl205eMG@80HV9R0P1[Jf/206i^
KP80LG5a0P1dM7@207IfMP80NWYj101nOWh207moO`80P8200P22PX820861P@80Ogmo1020P8000`21
PH40Ph>308>3P`0208F5Q@80QhN70P29RHT208Z:RP80RHV90P28R8P208Z:RP80S8b<0P2>SXh208n?
S`80SHf=0P2:RXX208^;R`80S8b<102=SHd208Z:RP80RHV90P2;Rh/208j>SP80SHf=0P2<S8`208f=
S@80SXj>00<0T92@09:BTP2BTY801P2CTi<409:BTP80Ti>C0P2BTY82096AT@80TY:B0P2DU9@209JF
UP80UiNG0P2EUID209:BTP80Ti>C0P2DU9@209>CT`80TI6A0P2CTi<409JFUP80UIFE0P2HV9P309ZJ
VP80Vi^K0P2MWId20:2PX080Xj>S0P2YZJT20;Jf]P80a<C40P3<c<`20=7Ad@80d=3@0P3?cll20;jn
_RL0b>3H0P1JFUX205UIF@80L71`0P2CTi<20<71`@80W9bL0P0n?Sh202PX:080;2`/0P0Y:BT202@T
9080:RXZ0P0g=cL203Hf=P80<30`00<0=3@d03Ph>00h>3P0100g=cL202/[:`80<S8b0P0k>c/2030`
<080<S8b0P0_;bl20451@@80=CDe0P14A4@204a<C080CDe=0P12@T8203Hf=P80=cLg0P0_;bl202h^
;P80<30`0P0[:b/202LW9`80@T920P1YJFT2065QH@80I6AT0P1PH60207YjNP80I6AT0P1:BTX205aL
G003069RHP1YJFT0JFUY0080KFe]1P1eMGD407alO080OWin0P1jNWX208:2PP80Q8B4101oOgl207in
OP80P8200P1oOgl208F5Q@@0QXJ60P2:RXX208^;R`80R8R80P29RHT408^;R`@0T92@0P28R8P208b<
S080RXZ:0P2?Shl00`2;Rh/0Shn?08n?S`0208N7Q`80R8R80P2;Rh/208f=S@80Rh^;0P2?Shl208j>
SP80SHf=102ATI4209>CT`@0UIFE0P2BTY8208n?S`80TI6A102BTY82092@T080UYJF0P2HV9P209VI
V@80TI6A0P2EUID409BDU0@0TY:B0P2CTi<309NGU`80V9RH0P2FUYH209ZJVP@0Vi^K0P2PX:020:6Q
X@80YjNW0P2ZZZX20:j^[P80a<C40P3?cll20=7Ad@80cLg=0P3<c<`20<30`2L0b>3H0P1JFUX2061P
H080LW9b0P2QXJ420;no_`80YJFU0P15ADD202<S8`80:RXZ100U9BD2030`<00303`l?00h>3P0>3Ph
0080=3@d0P0f=SH203dm?@80>CTi0P0f=SH2030`<080<C4a0P0g=cL203De=@80=SHf0P0e=CD203<c
<`80>c/k0P14A4@204];B`80B4Q80P11@D4203Lg=`80<c<c100_;bl202LW9`80:2PX0P0`<3000`0k
>c/0K6a/06a/K00406EUI@80Fe]K0P1kNg/205iNGP80DE5A0P1IFET206=SH`80J6QX0P1aLG4206m_
K`80MGEe0P1fMWH207QhN080OWin0P1mOGd207moO`80Q8B40P1nOWh208>3P`@0PX:20`24Q8@20820
P080QXJ60P27QhL208^;R`80RHV90P28R8P208N7Q`80SHf=0P2;Rh/209:BTP80TI6A1P2<S8`208V9
R@80RXZ:0P2?Shl208^;R`80RHV90P2<S8`408n?S`80SXj>102;Rh/00`2ATI40Shn?08n?S`0209FE
U@80U9BD0P2CTi<209:BTP80TI6A0P2BTY82092@T0@0TI6A0P2DU9@209NGU`80UYJF102CTi<209:B
TP80UIFE102BTY8409JFUP@0UIFE0P2HV9P309^KV`80WIfM0P2JVYX20::RXP80YJFU0P2WYjL20;Bd
]080a<C40P3;bl/20=?Cd`80d=3@0P3=cLd20;no_ah0b>3H000L0<SPf080F5QH0P1OGel2071`L080
XJ6Q0P2o_kl20:JVYP80ATI60P0Q8B4202TY:@809BDU0P0V9RH2034a<@0303/k>`0h>3P0>3Ph0080
<c<c0P0g=cL203Xj>P80=cLg0P0c<c<2038b<P80<C4a0P0b<S8603@d=080=SHf0P0k>c/20492@P80
C4a<0P18B4P20410@080>CTi0P0c<c<2030`<080;bl_0P0Y:BT202LW9`80;bl_00<0>SXj06a/K01/
K6`00P1RHV8206ATI080G5aL0P1kNg/2065QH@80Cdm?0P1MGEd2069RHP80Jf][0P1^KVh2075aL@80
M7Ad0P1fMWH207YjNP@0OWin0P1oOgl20820P080PX:20P21PH4207moO`@0P82000<0PH6108>3P`23
Ph<00P25QHD208N7Q`80RHV90P2:RXX208V9R@80R8R80P2:RXX208b<S080SXj>0P2?Shl208f=S@80
RXZ:0P2;Rh/208b<S0@0SHf=0P2:RXX208V9R@80Rh^;0P2>SXh208f=S@80S8b<0P2=SHd208j>SP03
092@T02BTY80TY:B00H0Ti>C102BTY8209>CT`80TY:B0P2ATI4209:BTP80U9BD0P2FUYH209NGU`80
UIFE0P2BTY8209>CT`80U9BD0P2CTi<2096AT@80Ti>C102FUYH209FEU@80V9RH0`2JVYX209^KV`80
WIfM0P2PX:020:>SX`80ZJVY0P2f][H20<C4a080c<c<0P3AdM420=3@d080clo?0P2n_[hW0<SPf080
FUYJ0P1IFET2071`L080Ti>C0P31`L4209bLW080?Shn0P0X:2P202`/;080:BTY0P0T92@202XZ:P80
=cLg0P0f=SH2030`<00303@d=00h>3P0>3Ph00@0=cLg0P0[:b/2038b<P80>c/k0P0`<302038b<P80
;bl_0P11@D4203De=@80A4A40P1<C4`204e=C@80@T920P0f=SH203Lg=`80;bl_0P0^;Rh2030`<080
:b/[0P0W9bL20492@P80JFUY0P1QHF4206ATI080H61P0P1jNWX206ATI080BTY:0P1LG5`00`1RHV80
JFUY06UYJ@0206e]K@H0MGEe101lO7`207inOP80NWYj0P22PX8208B4Q0@0Ogmo0P1nOWh20820P080
Ogmo0P25QHD408J6QP80RXZ:0P2;Rh/208R8R080RHV9102;Rh/4092@T080R8R80P2<S8`208Z:RP80
Shn?00<0Rh^;08n?S`2?Shl00P27QhL208R8R080Rh^;0P2=SHd208^;R`80Shn?0P2>SXh208f=S@@0
TI6A0P2CTi<409FEU@80TY:B0P2?Shl2096AT@@0TY:B0P2@T90209JFUP80V9RH0P2IVIT2096AT@80
UIFE102DU9@409:BTP80Ti>C0`2GUiL209RHV080UYJF0P2JVYX409^KV`80X:2P0P2QXJ420:NWY`80
ZZZZ0P2^[Zh20<C4a080clo?0P3AdM420<g=c@80c<c<0P30`<0W0<SPf080FUYJ0P1PH602079bLP80
XJ6Q0P2o_kl20:FUY@80ADE50P0S8b<202XZ:P@09BDU0P0`<3000`0l?3`0>3Ph03Ph>00203@d=080
=SHf0P0m?Cd203Ti>@80=SHf0P0`<302034a<@80=cLg0P0e=CD203Hf=P80=CDe0P0c<c<203/k>`80
A4A40P1;Bd/204Q8B080@D510P0g=cL203<c<`@0;bl_0P0W9bL202PX:080<30`00<0>c/k06a/K01/
K6`0101UIFD205]KF`80Ng]k0P1NGUh2055AD@80FEUI0P1SHf<206QXJ080LG5a0P1_Kfl207EeM@80
MWIf0P1hN7P207inOP80OGem0P1oOgl208B4Q080OWin0P23Ph<408:2PP<0Q8B40P20P80208J6QP80
QhN70P2;Rh/208V9R@80R8R80P27QhL208f=S@80Rh^;0P2BTY82096AT@H0S8b<0P29RHT208Z:RP80
Shn?0P2;Rh/208V9R@80S8b<102?Shl208j>SP@0Rh^;00<0TI6A08n?S`2?Shl00P2EUID209BDU080
Ti>C0P2BTY82096AT@80TY:B0P2@T904096AT@80U9BD0P2GUiL209JFUP@0Ti>C0P2BTY8209FEU@@0
TY:B102FUYH409FEU@80V9RH0`2KVi/209fMW@80VYZJ0P2RXZ820:FUY@80YjNW0P2d];@20<C4a080
bl_;0P3Cdm<20=3@d080cLg=0P2o_klN0<SPf0007038h=P205]KF`80EeMG0P1JFUX207UiN@80UYJF
0P2d];@209RHV080?clo0P0X:2P2024Q8@80:RXZ0P0_;bl00`0c<c<0;bl_02l_;`0202`/;080>3Ph
0P12@T8203Xj>P@0<C4a0P0c<c<2034a<@80;bl_0P0a<C4203De=@80>CTi0P0m?Cd20451@@80ATI6
0P12@T8203dm?@80=3@d0P0];Bd202l_;`80<S8b0P0[:b/202HV9P80;bl_00<0>SXj06][J`1[Jf/0
0P1PH60206IVIP80H61P0P1iNGT205MGE`@0FUYJ0P1VIVH2079bLP80LG5a0P1_Kfl2079bLP80MgMg
0P1jNWX207alO080OWin0P1oOgl20861P@@0PX:21021PH4508:2PP80Q8B40P26QXH208R8R0H0RHV9
0P2;Rh/208f=S@@0SXj>0P2<S8`208Z:RP80RHV90P28R8P208f=S@80TI6A0P2=SHd208V9R@80S8b<
0P2@T90208n?S`80SHf=0P2>SXh2092@T00309:BTP2DU9@0U9BD00@0UYJF0P2EUID409BDU080UIFE
102DU9@209FEU@80UiNG0P2JVYX209bLW080VIVI1P2EUID209BDU080TY:B0P2CTi<209BDU080UIFE
0P2FUYH209VIV@80Vi^K0`2JVYX209bLW080WinO0P2SXj<20:RXZ080][Jf0P34a<@20<o?c`80e=CD
0P3@d=020<W9b@80b/[:9`38h=P205UIF@80FUYJ0P1OGel2079bLP80VYZJ0P32`/8209FEU@80>SXj
0P0Z:RX202HV9P80:RXZ0P0];Bd203Ph>080=3@d0P0_;bl00`0f=SH0A4A404A4A00203Ph>080<S8b
0P0^;Rh203<c<`80=CDe0P0c<c<202`/;080=3@d0P0m?Cd203Ph>080BTY:0P11@D4203dm?@80@T92
0P0];Bd202h^;P80=3@d0P0`<30202`/;080:BTY0P0Z:RX20451@@80Hf=S0P1TI6@206MWI`80GemO
0P1kNg/205UIF@80DE5A0P1NGUh00`1YJFT0MWIf07IfMP0206i^KP80KFe]101gMgL207QhN080OGem
0P1nOWh20861P@80PX:21021PH420820P080QhN70P23Ph<207moO`80PX:20P24Q8@208>3P`80Rh^;
0P27QhL208J6QP80RHV90P2;Rh/208n?S`80S8b<0P2@T90208b<S080Rh^;0P28R8P208V9R@0308^;
R`2BTY80TY:B00@0RXZ:0P2>SXh2092@T080SHf=0P2;Rh/408j>SP80UYJF0P2DU9@209>CT`@0UIFE
0P2DU9@409FEU@80UiNG102BTY8209NGU`@0W9bL0P2CTi<209BDU080UiNG0P2FUYH2092@T080U9BD
0P2ATI4209JFUP0309BDU02EUID0UIFE00@0Vi^K0P2IVIT209^KV`80VYZJ0P2MWId20:BTY080Zj^[
0P2`/;020<C4a080e=CD0P3Cdm<20<k>cP80cLg=0P35aLDW0<SPf080F5QH101GEeL207]kN`80UYJF
0P2c/k<209NGU`80?Shn0P0X:2P201hN7P@0;2`/00<0<c<c034a<@0a<C400P0];Bd203<c<`80@410
0P0g=cL2034a<@80<30`0P0e=CD202d];@80;bl_100e=CD203Hf=P80?Cdm0P0o?cl204=3@`80AdM7
0P0l?3`402l_;`80<c<c0P0b<S8202TY:@809bLW0P0_;bl00`0i>CT0JFUY06UYJ@02061PH080IFEU
0P1QHF4207MgM`80F5QH0P1IFET205]KF`80IfMW0P1aLG4207AdM080Kfm_0P1dM7@207UiN@80MWIf
0P1lO7`208:2PP80O7al0P1nOWh208B4Q0@0Ogmo1@21PH4208B4Q080QHF50P26QXH208B4Q080RXZ:
0P2<S8`208R8R080S8b<0P2;Rh/2092@T080Shn?0P28R8P208^;R`@0RHV90P2:RXX209:BTP80S8b<
0P2;Rh/208j>SP80TI6A0P2;Rh/208b<S080Shn?0P2@T9000`2BTY80UIFE09FEU@0209NGU`80UYJF
0P2CTi<209FEU@@0UYJF0P2DU9@209RHV080Ti>C0P2IVIT209ZJVP80WYjN0P2GUiL209JFUP80Ti>C
0P2DU9@209JFUP80T92@0P2EUID209>CT`80UiNG0P2EUID209RHV0<0VYZJ0P2LW9`209VIV@80X:2P
0P2SXj<20:VYZ@80]kNg0P37alL20<o?c`@0dm?C0P38b<P20<c<c1h0b>3H000L0<SPf080Fe]K0P1G
EeL205YJFP80NGUi0P2FUYH20;Bd]080V9RH0P0o?cl202PX:0808B4Q0P0Z:RX202l_;`0303<c<`0_
;bl0;bl_0080;2`/0P0h>3P20492@P80>SXj100a<C4203<c<`80<C4a0P0_;bl2034a<@80=CDe0P0i
>CT203dm?@80@D510P16ATH20492@P80?Cdm0P0d=3@202d];@80;bl_0P0b<S8202/[:`809RHV0P0_
;bl00`0j>SX0Jf][06][J`02061PH080IVIV0P1PH60207UiN@80EeMG101JFUX206IVIP80LW9b0P1a
LG4206m_K`80LW9b0P1gMgL207YjNP80O7al0P1nOWh207moO`80PH611022PX840861P@D0PX:20P24
Q8@208J6QP80R8R81P29RHT208^;R`80SHf=102>SXh208b<S080RXZ:0P29RHT208R8R080SHf=0P2A
TI4208f=S@80RHV90P2<S8`2092@T080Shn?0P2=SHd208j>SP80T92@00<0TY:B09BDU02DU9@0102F
UYH209FEU@@0U9BD0P2EUID409BDU080UIFE0P2GUiL209ZJVP80W9bL0P2IVIT609FEU@80U9BD0P2B
TY8209>CT`80U9BD0P2EUID209JFUP80VIVI0P2KVi/309ZJVP80W9bL0P2OWil20:>SX`80Z:RX0P2f
][H20<C4a080clo?0P3De=@20=3@d080bLW90P3:b/XW0<SPf080FEUI0P1JFUX205mOG`80LW9b0P2J
VYX20<;2`P80UIFE0P0j>SX202XZ:P809RHV0P0Z:RX202d];@80>3Ph0P0d=3@202l_;`0303Hf=P14
A4@0A4A40080>3Ph0P0b<S8202h^;P80<c<c0P0e=CD203<c<`80;2`/0P0d=3@203dm?@80>3Ph0P1:
BTX20451@@80?Cdm0P12@T8202d];@80;Rh^0P0d=3@2030`<080;2`/0P0Y:BT202XZ:P80@D510P1S
Hf<206ATI080IfMW0P1OGel207]kN`80FEUI0P1ADE4205iNGP0306UYJ@1fMWH0MWIf0080KVi^0P1]
KFd407MgM`80N7Qh0P1mOGd207inOP80PH610P22PX840861P@80P8200P27QhL208>3P`80Ogmo0P22
PX8208B4Q080Ph>30P2;Rh/208N7Q`80QXJ60P29RHT208^;R`80Shn?0P2<S8`2092@T080S8b<0P2;
Rh/208R8R080RHV900<0Rh^;09:BTP2BTY80102:RXX208j>SP80T92@0P2=SHd208^;R`@0SXj>0P2F
UYH209BDU080Ti>C102EUID209BDU0@0UIFE0P2GUiL409:BTP80UiNG102LW9`209>CT`80U9BD0P2G
UiL209JFUP80T92@0P2DU9@2096AT@80UYJF00<0U9BD09FEU@2EUID0102KVi/209VIV@80Vi^K0P2J
VYX209fMW@80Y:BT0P2[Zj/20;2`/080a<C40P3De=@20=?Cd`80c/k>0P3=cLd20<G5aBL0b>3H0P1H
F5P405MGE`80Ng]k0P2FUYH20;>c/`80UiNG0P0n?Sh202PX:0807QhN100/;2`00`0c<c<0<C4a034a
<@0202d];@80<c<c0P10@40203Lg=`80<C4a0P0`<30203De=@80;Bd]0P0_;bl403De=@80=SHf0P0m
?Cd203lo?`80@d=30P17AdL203`l?0@0;bl_0P0c<c<2038b<P80:BTY0P0W9bL202l_;`0303Ti>@1Y
JFT0JFUY0080H61P0P1UIFD2065QH@80MgMg0P1HF5P205UIF@80Fe]K0P1WIfL2075aL@80M7Ad0P1_
Kfl207AdM080NGUi0P1fMWH207alO080PX:20P1lO7`207inOP80Q8B4101oOgl50861P@80Q8B40P25
QHD208J6QP80Q8B40P2:RXX208b<S080R8R80P2<S8`208^;R`80T92@0P2?Shl208R8R080Rh^;1029
RHT208Z:RP80TY:B0P2<S8`208^;R`80SXj>0P2ATI4208^;R`80S8b<0P2?Shl2092@T00309:BTP2E
UID0UIFE0080UiNG0P2FUYH209>CT`80UIFE102FUYH209BDU080V9RH0P2CTi<209VIV@80VYZJ0P2N
WYh209NGU`80UYJF0P2CTi<209BDU080UYJF0P2@T90209FEU@80Ti>C0P2GUiL209FEU@80V9RH0`2J
VYX209bLW080VIVI0P2PX:020:>SX`80ZJVY0P2g]kL20<O7a`80clo?103Cdm<20<S8b080c<c<7P38
h=P001`0b>3H0P1LG5`405MGE`80JVYZ0P23Ph<20:JVYP80][Jf0P1lO7`203Xj>P807AdM0P0W9bL2
02PX:0<0;Bd]0P0_;bl203Hf=P80>c/k0P0d=3@202d];@80;bl_0P0c<c<2030`<080;Bd]0P0`<302
03@d=0@0=SHf0P1=CDd20410@080?clo0P0i>CT203<c<`80;Rh^0P0`<302038b<P80:RXZ0P0U9BD2
03@d=0030410@01`L700L71`0080HF5Q0P1VIVH2061PH080NGUi0P1DE5@205]KF`80GUiN0P1XJ6P6
075aL@80M7Ad0P1gMgL207UiN@80Ng]k0P1mOGd207moO`80P8200P21PH4208:2PP@0Ph>30P22PX83
0861P@80Q8B40P28R8P208V9R@80R8R81029RHT208^;R`@0SHf=102<S8`608^;R`80SXj>0P2@T902
08j>SP80Rh^;0P2=SHd608n?S`80TI6A0P2CTi<00`2DU9@0UIFE09FEU@0809JFUP@0UIFE0P2FUYH4
09NGU`80V9RH0P2KVi/209fMW@80VYZJ0P2FUYH209BDU080Ti>C102BTY8209FEU@@0UiNG0P2FUYH2
09NGU`80V9RH00<0VIVI09ZJVP2JVYX00P2KVi/209fMW@80XJ6Q0P2WYjL20;Bd]080`L710P3=cLd2
0=CDe080clo?0P37alL20<W9bBL0b>3H0P1PH60205UIF@80GEeM0P1VIVH207alO080[:b/0P30`<02
06i^KP80;bl_0P0Z:RX202@T9080:2PX0P0[:b/202XZ:P80:b/[00<0?Cdm0410@010@4000P0`<302
03<c<`80<30`100a<C4202XZ:P80;Rh^0P0f=SH203hn?P80;bl_0P1>CTh204A4A080?Shn0P0l?3`2
034a<@80;Bd]0P0f=SH202l_;`809bLW0P0V9RH202XZ:P80ATI60P1/K6`206EUI@80J6QX0P1LG5`2
07MgM`80F5QH0P1KFe/206=SH`0306EUI@1_Kfl0Kfm_0080L71`0P1aLG42079bLP80MWIf0P1iNGT2
07emO@80Ng]k0P1nOWh20861P@80P8200P22PX8208B4Q080Ogmo1022PX820820P080R8R80P27QhL2
08^;R`80R8R81029RHT208j>SP80SHf=0P28R8P208f=S@80SXj>0P2<S8`208R8R080S8b<00<0T92@
09:BTP2BTY800P2=SHd208b<S080T92@0P2>SXh209>CT`80SHf=0P2DU9@2096AT@80UYJF102DU9@2
09VIV@80UiNG0P2EUID409>CT`80VIVI0P2HV9P209VIV@80V9RH0P2IVIT20:2PX080VYZJ0P2IVIT4
09>CT`80TY:B0P2FUYH2092@T0<0UiNG0P2DU9@209JFUP80VIVI0P2FUYH209ZJVP80VIVI0P2MWId4
0:FUY@80/;2`0P32`/820=;BdP80clo?0P3>c/h20<c<c080`L719`38h=P205mOG`80EEEE0P1IFET2
06][J`80Ph>30P2UYJD20;Vi^@80OWin0P0k>c/201dM7@80:BTY0P0W9bL00`0/;2`0<S8b038b<P02
02d];@80=CDe0P12@T8203Hf=P80;bl_0P0/;2`2034a<@80;bl_0P0Z:RX202`/;080=3@d0P0f=SH2
03Ti>@80D51@1011@D4203Ti>@80<c<c0P0/;2`202l_;`80<c<c0P0X:2P202@T9080=CDe00<0@D51
06m_K`1_Kfl00P1QHF4206IVIP80H61P0P1iNGT205EEE@80FUYJ0P1PH60206MWI`80L71`0P1bLW82
06e]K@80LW9b0P1hN7P207YjNP80Ng]k0P22PX8407moO`80PX:20P25QHD208B4Q080PH610P20P800
0`22PX80P8200820P00208>3P`H0R8R80P2:RXX208F5Q@@0S8b<0P2>SXh208b<S080R8R80P2<S8`2
09:BTP@0Shn?0P2@T90208b<S080RHV90P2;Rh/408j>SP80T92@0P2DU9@209FEU@0309>CT`2DU9@0
U9BD0080UYJF0P2HV9P209>CT`80UYJF102CTi<209NGU`80Ti>C0P2EUID409ZJVP80WYjN0P2JVYX2
09NGU`80UYJF0P2DU9@2096AT@80TY:B0P2CTi<209BDU080V9RH0P2EUID209VIV@80UiNG00<0VYZJ
09VIV@2IVIT00P2KVi/209jNWP80XJ6Q0P2XZ:P20;:b/P80`<300P39bLT20=?Cd`80d];B0P33`l<2
0<c<c1h0b>3H000L0<SPf080G5aL101GEeL206YZJP80Ph>30P2VYZH20;Jf]P80O7al0P0j>SX201dM
7@809bLW0P0X:2P302d];@80;bl_0P0f=SH203/k>`80=3@d0P0];Bd202l_;`80<c<c0P0`<30202d]
;@80<30`0P0d=3@403Hf=P80CDe=0P10@40203lo?`80>CTi0P0c<c<202h^;P80<30`0P0b<S8202XZ
:P809BDU0P0d=3@00`10@400L71`071`L002065QH@80IVIV0P1PH60207UiN@80E5AD0P1KFe/205iN
GP80J6QX1P1aLG4207AdM080MgMg0P1iNGT207]kN`80OGem0P1oOgl20820P080PH610P22PX8408>3
P`80PX:20`21PH4208B4Q080R8R80P29RHT208R8R0@0RHV90P2;Rh/408f=S@@0S8b<1P2;Rh/208j>
SP80T92@0P2>SXh208^;R`80SHf=1P2?Shl2096AT@80Ti>C00<0U9BD09FEU@2EUID0202FUYH409FE
U@80UYJF102GUiL209RHV080Vi^K0P2MWId209ZJVP80UYJF0P2DU9@209>CT`@0TY:B0P2EUID409NG
U`80UYJF0P2GUiL209RHV00309VIV@2JVYX0VYZJ0080Vi^K0P2MWId20:6QX@80YjNW0P2d];@20<71
`@80cLg=0P3De=@20<o?c`80alO70P39bLTW0<SPf080H61P0P1IFET205eMG@80IVIV0P1lO7`20:b/
[080`<300P1^KVh202l_;`80:RXZ0P0T92@202PX:080:b/[0P0Z:RX202/[:`0303dm?@10@400@410
0080<30`0P0c<c<2030`<0@0<C4a0P0Z:RX202h^;P80=SHf0P0n?Sh202l_;`80CTi>0P14A4@203hn
?P80?3`l0P0a<C4202d];@80=SHf0P0_;bl202LW9`809RHV0P0Z:RX204I6AP80K6a/0P1UIFD206QX
J080G5aL0P1gMgL205QHF080Fe]K0P1SHf<00`1UIFD0Kfm_06m_K`02071`L080LG5a0P1bLW8207If
MP80NGUi0P1mOGd207]kN`80OWin0P21PH420820P080PX:20P24Q8@207moO`@0PX:20P20P80208R8
R080QhN70P2;Rh/208R8R0@0RHV90P2>SXh208f=S@80R8R80P2=SHd208j>SP80S8b<0P28R8P208b<
S003092@T02BTY80TY:B0080SHf=0P2<S8`2092@T080SXj>0P2CTi<208f=S@80U9BD0P2ATI4209JF
UP@0U9BD0P2IVIT209NGU`80UIFE102CTi<209VIV@80V9RH0P2IVIT209RHV080VIVI0P2PX:0209ZJ
VP80VIVI102CTi<209:BTP80UYJF0P2@T90309NGU`80U9BD0P2FUYH209VIV@80UYJF0P2JVYX209VI
V@80WIfM102UYJD20;2`/080`/;20P3Bd]820<o?c`80c/k>0P3<c<`20<71`BL0b>3H0P1OGel205EE
E@80FEUI0P1[Jf/208>3P`80YJFU0P2i^KT207inOP80>c/k0P0M7Ad202TY:@809bLW00<0;2`/038b
<P0b<S800P0];Bd203De=@80@T920P0f=SH202l_;`80;2`/0P0a<C4202l_;`80:RXZ0P0/;2`203@d
=080=SHf0P0i>CT2051@D0@0@D510P0i>CT203<c<`80;2`/0P0_;bl203<c<`80:2PX0P0T92@203De
=@030451@@1_Kfl0Kfm_0080HF5Q0P1VIVH2061PH080NGUi0P1EEED205YJFP80H61P0P1WIfL2071`
L080LW9b0P1]KFd2079bLP80N7Qh0P1jNWX207]kN`80PX:2101oOgl208:2PP80QHF50P24Q8@20861
P@80P82000<0PX:20820P020P8000P23Ph<608R8R080RXZ:0P25QHD408b<S080SXj>0P2<S8`208R8
R080S8b<0P2BTY8408n?S`80T92@0P2<S8`208V9R@80Rh^;102>SXh2092@T080U9BD0P2EUID00`2C
Ti<0U9BD09BDU00209JFUP80V9RH0P2CTi<209JFUP@0Ti>C0P2GUiL209>CT`80UIFE102JVYX209jN
WP80VYZJ0P2GUiL209JFUP80U9BD0P2ATI4209:BTP80Ti>C0P2DU9@209RHV080UIFE0P2IVIT209NG
U`0309ZJVP2IVIT0VIVI0080Vi^K0P2NWYh20:6QX@80Z:RX0P2b/[820<30`080bLW90P3Cdm<20=;B
dP80`l?30P3<c<`N0<SPf0007038h=P205iNGP@0FUYJ0P1OGel2071`L080PX:20P34a<@20;Jf]P80
FEUI0P0Z:RX202DU9@808R8R00<0:2PX02d];@0];Bd0100c<c<2038b<P80;Rh^0P0Z:RX202l_;`80
<c<c0P0_;bl202/[:`80<30`0P0d=3@203<c<`80<30`0P1GEeL203dm?@80?3`l0P0g=cL203@d=0H0
<C4a0P0Y:BT202DU9@80=cLg00<0B4Q807EeM@1eMGD00P1SHf<206MWI`80H61P0P1gMgL2059BDP80
Fe]K0P1SHf<206UYJ@80KVi^0P1aLG4207=cL`80MWIf0P1hN7P207UiN@80NWYj0P1mOGd60820P080
PX:20P24Q8@208>3P`80PH6100<0P82007moO`1oOgl00P25QHD408Z:RP80R8R81029RHT208^;R`@0
S8b<102;Rh/208b<S080SHf=102>SXh208f=S@P0SXj>0P2?Shl2096AT@80U9BD2@2FUYH209NGU`80
V9RH0P2FUYH209FEU@80UiNG1P2IVIT209^KV`80W9bL0P2JVYX209JFUP80Ti>C102ATI4209>CT`80
UiNG0P2JVYX209RHV080UIFE0P2DU9@209FEU@0309NGU`2IVIT0VIVI0080VYZJ0P2KVi/209nOW`80
YJFU0P2a/K420;jn_P80b/[:0P3Bd]820<g=c@80a/K60P35aLDW0<SPf080GemO0P1JFUX205]KF`80
FEUI0P1`L70208f=S@80_kno0P2c/k<205]KF`80;2`/0P0W9bL202@T9080:b/[0P0];Bd2038b<P03
03@d=00^;Rh0;Rh^0080<30`0P0Y:BT202`/;080<S8b0P0c<c<202/[:`80;Bd]0P0a<C4203<c<`80
<S8b0P1;Bd/204=3@`80>CTi0P0f=SH2030`<080<C4a0P0d=3@2038b<P80:2PX0P0W9bL2030`<080
C4a<0P1dM7@2061PH080JVYZ0P1WIfL206m_K`80EUIF0P1NGUh206=SH`0306YZJP1^KVh0KVi^0080
L71`0P1cLg<207QhN080NWYj101gMgL20861P@80Ogmo101nOWh208F5Q@80Ph>31022PX8207alO080
Ogmo0P25QHD208R8R080Rh^;1P27QhL208j>SP80Rh^;0P28R8P208V9R@80T92@102;Rh/2096AT@03
08^;R`2?Shl0Shn?0080S8b<0P2?Shl208j>SP80SHf=0P2?Shl208j>SP80UIFE0P2DU9@209NGU`80
UYJF0P2DU9@209FEU@80V9RH0P2FUYH209NGU`80U9BD0P2IVIT409RHV080VIVI0P2OWil209^KV`80
UiNG0P2EUID209>CT`80TY:B0P2?Shl209BDU080UiNG0`2JVYX209NGU`80T92@0P2HV9P409NGU`80
W9bL0P2FUYH20:>SX`80YJFU0P2ZZZX20;jn_P80c/k>0P3AdM420<k>cP80b<S80P2l_;`W0<SPf080
GUiN101KFe/205YJFP80LG5a0P23Ph<20<?3``80]kNg0P1EEED202/[:`808b<S0P0P82000`0Y:BT0
<30`030`<002030`<080=cLg100/;2`202h^;P80:RXZ0P0e=CD2034a<@80;2`/100c<c<203De=@80
;Bd]0P1DE5@203hn?P80>CTi0P0h>3P203Lg=`80<S8b0P0`<302034a<@80:RXZ0P0U9BD203De=@03
04Q8B01eMGD0MGEe0080Hf=S0P1WIfL2061PH080N7Qh0P1BDU8205aLG080I6AT0P1XJ6P206e]K@80
MGEe0P1cLg<207IfMP80N7Qh0P1jNWX207MgM`80OWin0P20P80207YjNP80PX:20P21PH4208J6QP80
OWin0P22PX800`23Ph<0PH610861P@0208>3P`80RXZ:0P2?Shl208B4Q080Rh^;102:RXX208b<S080
Shn?0P2=SHd208V9R@80SHf=0P2?Shl208b<S0@0SHf=0P2@T90208j>SP80Shn?0P2>SXh408n?S`80
Ti>C1`2FUYH209BDU080UiNG0P2IVIT409JFUP80V9RH0P2KVi/209JFUP80VYZJ0P2KVi/209ZJVP80
W9bL1P2DU9@208j>SP80UIFE1P2IVIT409BDU0<0UYJF0P2IVIT409bLW080Vi^K0P2YZJT20;2`/080
_kno0P3:b/X20=7Ad@80cLg=0P37alL20<K6aQh0b>3H000L0<SPf080GUiN101JFUX205mOG`80L71`
0P22PX820<C4a080][Jf0P1IFET202XZ:P809BDU0P0R8R800`0X:2P0;Bd]02d];@0403<c<`80<S8b
0P0^;Rh202XZ:P80;bl_0P0c<c<202l_;`80:b/[0P0`<30203@d=080<c<c0P0`<30205MGE`80?Cdm
0P0l?3`203Lg=`80=3@d1P0a<C4202TY:@809BDU0P0g=cL00`18B4P0MGEe07EeM@0206=SH`80IfMW
0P1PH60207MgM`80DU9B0P1KFe/206=SH`80JFUY0P1^KVh2075aL@80Lg=c0P1fMWH207QhN080NGUi
0P1jNWX207emO@H0P8200P22PX8208B4Q080Ph>30P21PH400`20P800Ogmo07moO`0208F5Q@@0RXZ:
0P28R8P408V9R@80Rh^;102<S8`408^;R`80S8b<0P2=SHd408j>SP80SHf=202>SXh208n?S`80TI6A
0P2DU9@909JFUP80UiNG0P2HV9P209JFUP80UIFE0P2GUiL609VIV@80Vi^K0P2LW9`209ZJVP80UYJF
0P2CTi<4096AT@80Ti>C0P2GUiL209ZJVP80V9RH0P2EUID209BDU080UIFE00<0UiNG09VIV@2IVIT0
0P2JVYX209^KV`80WinO0P2UYJD20;6a/@80_[jn0P3:b/X20=;BdP80cLg=0P36a/H20<G5aBL0b>3H
0P1OGel205YJFP80Fe]K0P1IFET2071`L080SHf=0P2o_kl20;>c/`80Fe]K0P0/;2`202LW9`8092@T
0P0[:b/202d];@80<S8b00<0=3@d02h^;P0^;Rh00P0`<30202TY:@80;2`/0P0b<S8203<c<`80:b/[
0P0];Bd2034a<@80<c<c0P0b<S8204];B`80@d=30P0i>CT203Hf=P80<30`0P0a<C4203@d=080<S8b
0P0X:2P202LW9`80<30`0P1<C4`207AdM080H61P0P1ZJVX206MWI`80Kfm_0P1FEUH205iNGP80Hf=S
00<0JVYZ06i^KP1^KVh00P1`L70207=cL`80N7Qh0P1jNWX407MgM`80PH610P1oOgl407inOP80QHF5
0P23Ph<408:2PP80O7al0P1oOgl208F5Q@80R8R80P2;Rh/608N7Q`80SXj>0P2;Rh/208R8R080RHV9
0P2@T90408^;R`80TI6A00<0Rh^;08n?S`2?Shl00P2<S8`208n?S`80SXj>0P2=SHd208n?S`80SXj>
0P2EUID209BDU080UiNG0P2FUYH209BDU080UIFE0P2HV9P209JFUP80UiNG0P2DU9@209VIV@@0V9RH
0P2IVIT209nOW`80Vi^K0P2GUiL209FEU@80Ti>C0P2BTY8208n?S`80U9BD0P2GUiL309ZJVP80UiNG
0P2@T90209RHV0@0UiNG0P2LW9`209JFUP80Xj>S0P2UYJD20:ZZZP80_[jn0P3>c/h20=7Ad@80c/k>
0P38b<P20;bl_2L0b>3H0P1NGUh405]KF`80FUYJ0P1aLG4208>3P`80`l?30P2g]kL205EEE@80:b/[
0P0S8b<2020P800302TY:@0`<300<30`0080<30`0P0g=cL402`/;080;Rh^0P0Z:RX203De=@80<C4a
0P0/;2`403<c<`80=CDe0P0];Bd205ADE080?Shn0P0i>CT203Ph>080=cLg0P0b<S82030`<080<C4a
0P0Z:RX202DU9@80=CDe00<0B4Q807EeM@1eMGD00P1SHf<206MWI`80H61P0P1hN7P2059BDP80G5aL
0P1TI6@206QXJ080KFe]0P1eMGD207=cL`80MWIf0P1hN7P207YjNP80MgMg0P1nOWh20820P080NWYj
0P22PX820861P@80QXJ60P1nOWh208:2PP0308>3P`21PH40PH610080Ph>30P2:RXX208n?S`80Q8B4
0P2;Rh/408Z:RP80S8b<0P2?Shl208f=S@80RHV90P2=SHd208n?S`80S8b<102=SHd2092@T080SXj>
0P2?Shl208j>SP@0Shn?0P2CTi<709JFUP80U9BD0P2GUiL209VIV@@0UYJF0P2HV9P209^KV`80UYJF
0P2JVYX209^KV`80VYZJ0P2LW9`609BDU080SXj>0P2EUID609VIV@@0U9BD0`2FUYH209VIV@@0W9bL
0P2KVi/20:VYZ@80/;2`0P2o_kl20<[:bP80dM7A0P3=cLd20<O7a`80a/K67P38h=P001`0b>3H0P1S
Hf<205iNGP@0FEUI0P1SHf<207EeM@80Z:RX0P34a<@20:JVYP80>SXj0P0b<S8202@T900302HV9P0Z
:RX0:RXZ0080;bl_0P0^;Rh202d];@@0;2`/0P0`<30203<c<`80<C4a0P0^;Rh2038b<P80=CDe0P0f
=SH203De=@80C4a<100o?cl203Xj>P80=cLg0P0c<c<2034a<@80<30`0P0Z:RX202TY:@80:b/[00<0
BTY:07UiN@1iNGT00P1WIfL206e]K@80I6AT0P1[Jf/205IFEP80GUiN0P1WIfL206a/K080Kfm_0P1`
L702079bLP80MgMg0P1lO7`407]kN`80OGem101oOgl40820P080PH611020P8000`21PH40Ph>308>3
P`0208F5Q@80QhN70P28R8P408Z:RP@0Rh^;4P2<S8`208f=S@80Shn?102>SXh2096AT@80U9BD0P2G
UiL309RHV0@0UiNG0P2HV9P809NGU`80V9RH1P2JVYX409^KV`80VIVI0P2GUiL209BDU080Ti>C0P2D
U9@209FEU@@0UiNG0P2EUID209>CT`80U9BD0P2EUID00`2DU9@0UIFE09FEU@0209NGU`80VIVI0P2L
W9`20:6QX@80[Jf]0P2j^[X20<S8b080dM7A0P3;bl/20<;2`P80a<C49`38h=P2069RHP80FUYJ0P1H
F5P205mOG`80HF5Q0P1fMWH20:2PX080b<S80P2ZZZX203lo?`80:2PX100T92@202TY:@80=3@d00<0
<C4a02d];@0];Bd0100/;2`2034a<@80=CDe0P0d=3@2030`<080<S8b0P0h>3P203`l?080?Cdm0P1<
C4`20410@080?Cdm0P13@d<203Xj>P80<c<c0P0b<S8202`/;0@0<30`0P0];Bd204];B`80MgMg0P1Y
JFT206i^KP80HF5Q0P1YJFT2055AD@80GUiN0P1QHF400`1YJFT0Lg=c07=cL`02079bLP80Lg=c0P1d
M7@207emO@80NWYj0P1lO7`208:2PP80OGem1020P80208>3P`80Ogmo0P21PH4208:2PP80Q8B40P22
PX8208R8R080QHF50P2;Rh/208V9R@80SHf=0P29RHT408f=S@80Shn?102=SHd208Z:RP@0S8b<00<0
RXZ:08f=S@2=SHd00P2;Rh/208b<S080TI6A0P2<S8`209:BTP80U9BD0P2HV9P209ZJVP@0UiNG0P2I
VIT409NGU`80VYZJ0P2DU9@209NGU`80W9bL102FUYH209NGU`80WIfM0P2IVIT209RHV080VIVI1P2D
U9@209>CT`80UIFE0P2HV9P00`2EUID0TY:B09:BTP0209BDU080Ti>C102GUiL209RHV080VYZJ0P2N
WYh20:BTY080Zj^[0P2h^;P20<[:bP80c/k>0P3=cLd20<O7a`80^k^k9`38h=P2065QH@80GUiN0P1I
FET205QHF080Hf=S0P1gMgL20:FUY@80a<C40P2WYjL203dm?@80<c<c0`0T92@202HV9P80;Rh^0P0c
<c<202d];@80:b/[0P0/;2`202l_;`@0=CDe0P0];Bd202l_;`@0=SHf0P0g=cL204a<C080@4100P0l
?3`403Ti>@80<S8b0P0`<30402h^;P80:2PX0P0Z:RX00`1:BTX0NGUi07UiN@0206EUI@80Kfm_0P1R
HV8206a/K080De=C0P1NGUh206=SH`80JVYZ0P1`L70206m_K`80Lg=c0P1fMWH207UiN@80Ogmo0P1j
NWX207inOPH0PH610P1nOWh20861P@80P8200P23Ph<00`20P800PX:208:2PP020820P080QHF50P2<
S8`408Z:RP80Rh^;0P27QhL408f=S@80R8R80P2?Shl208N7Q`80Rh^;0P29RHT408^;R`80Shn?0P2@
T90408f=S@80UYJF0P2CTi<209JFUP80UiNG00<0V9RH09NGU`2GUiL00P2JVYX209RHV080VYZJ0P2F
UYH209FEU@80UYJF0P2NWYh209bLW080UYJF0P2JVYX20:2PX0@0VIVI0P2EUID209>CT`80TI6A0P2?
Shl409JFUP80VIVI0P2GUiL209>CT`80TY:B0P2EUID00`2CTi<0UiNG09NGU`0209NGU`80W9bL0P2E
UID20:6QX@80[jn_0P2k^k/20<W9b@80e=CD0P3:b/X40<;2`Qh0b>3H000L0<SPf080Hf=S0P1NGUh4
05UIF@80Hf=S0P1eMGD20:RXZ080a<C40P2VYZH203Xj>P80<S8b0P0T92@00`0V9RH0:RXZ02XZ:P02
02l_;`80;Rh^0P0];Bd402`/;080<30`0P0c<c<2034a<@80;Rh^0P0b<S8203De=@80=SHf0P0e=CD2
04a<C0@0?clo0P0j>SX203Lg=`80<c<c0P0a<C42030`<080:RXZ0P0Y:BT202/[:`0304Y:BP1iNGT0
NGUi0080IfMW0P1]KFd206ATI080Jf][0P1FEUH205iNGP80IfMW0P1/K6`206m_K`80L71`0P1bLW82
07MgM`80O7al101kNg/207emO@@0Ogmo1020P8020861P@@0P82000<0PH6108>3P`23Ph<00P25QHD2
08N7Q`80R8R8102:RXX408^;Ra80S8b<0P2=SHd208n?S`@0SXj>0P2ATI4209BDU080UiNG0`2HV9P4
09NGU`80V9RH202GUiL209RHV0H0VYZJ102KVi/209VIV@80UiNG0P2DU9@209>CT`80U9BD0P2EUID4
09NGU`80UIFE0P2CTi<209BDU080UIFE00<0U9BD09FEU@2EUID00P2GUiL209VIV@80W9bL0P2QXJ42
0:f][@80^[Zj0P38b<P20=7Ad@80bl_;0P32`/820<C4a2L0b>3H0P1RHV8205YJFP80F5QH0P1OGel2
065QH@80MWIf0P2PX:020<S8b080ZZZZ0P0o?cl202PX:0@092@T0P0Y:BT203@d=003034a<@0];Bd0
;Bd]00@0;2`/0P0a<C4203De=@80=3@d0P0`<302038b<P80>3Ph0P0l?3`203dm?@80C4a<0P10@402
03dm?@80@d=30P0j>SX203<c<`80<S8b0P0/;2`4030`<080;Bd]0P1;Bd/207MgM`80JFUY0P1^KVh2
065QH@80JFUY0P1ADE4205iNGP80HF5Q00<0JFUY07=cL`1cLg<00P1bLW8207=cL`80M7Ad0P1mOGd2
07YjNP80O7al0P22PX8207emO@@0P8200P23Ph<207moO`80PH610P22PX8208B4Q080PX:20P28R8P2
08F5Q@80Rh^;0P29RHT208f=S@80RHV9102=SHd208n?S`@0SHf=0P2:RXX408b<S00308Z:RP2=SHd0
SHf=0080Rh^;0P2<S8`2096AT@80S8b<0P2BTY8209BDU080V9RH0P2JVYX409NGU`80VIVI102GUiL2
09ZJVP80U9BD0P2GUiL209bLW0@0UYJF0P2GUiL209fMW@80VIVI0P2HV9P209VIV@H0U9BD0P2CTi<2
09FEU@80V9RH00<0UIFE09:BTP2BTY800P2DU9@209>CT`@0UiNG0P2HV9P209ZJVP80WYjN0P2TY:@2
0:^[Z`80^;Rh0P3:b/X20<k>cP80cLg=0P37alL20;^k^bL0b>3H0P1QHF4205iNGP80FEUI0P1HF5P2
06=SH`80MgMg0P2UYJD20<C4a080YjNW0P0m?Cd203<c<`<092@T0P0V9RH202h^;P80<c<c0P0];Bd2
02/[:`80;2`/0P0_;bl403De=@80;Bd]0P0_;bl403Hf=P80=cLg0P1<C4`20410@080?3`l100i>CT2
038b<P80<30`100^;Rh202PX:080:RXZ00<0BTY:07UiN@1iNGT00P1UIFD206m_K`80HV9R0P1/K6`2
05=CD`80GUiN0P1SHf<206YZJP80L71`0P1_Kfl207=cL`80MWIf0P1iNGT207moO`80NWYj0P1nOWh6
0861P@80OWin0P21PH420820P080Ph>300<0P82008:2PP22PX800P20P80208F5Q@80S8b<102:RXX2
08^;R`80QhN7102=SHd208R8R080Shn?0P27QhL208^;R`80RHV9102;Rh/208n?S`80T92@102=SHd2
09JFUP80Ti>C0P2FUYH209NGU`0309RHV02GUiL0UiNG0080VYZJ0P2HV9P209ZJVP80UYJF0P2EUID2
09JFUP80WYjN0P2LW9`209JFUP80VYZJ0P2PX:0409VIV@80UIFE0P2CTi<2096AT@80Shn?102FUYH2
09VIV@80UiNG0P2CTi<209:BTP80UIFE00<0Ti>C09NGU`2GUiL00P2GUiL209bLW080UIFE0P2QXJ42
0:n_[`80^k^k0P39bLT20=CDe080b/[:1032`/8N0<SPf0007038h=P206EUI@80H61P0P1KFe/205MG
E`80FUYJ0P1`L70208Z:RP80^;Rh0P3>c/h209JFUP80<c<c0P0W9bL302XZ:PH0:b/[0P0];Bd2030`
<080<S8b100c<c<2038b<P80=3@d0P0g=cL203Xj>P80?Cdm0P0n?Sh20492@P80@D510P0n?Sh203Ti
>@80=3@d0P0a<C4202l_;`80:BTY0P0[:b/201dM7@0304e=C@1lO7`0O7al0080K6a/0P1`L70206UY
J@80GemO0P1IFET2061PH080JVYZ0P1^KVh6075aL@80N7Qh101nOWh207alO080OGem0P1nOWh207mo
O`80P8200P1oOgl407inOP80P82000<0Ph>308J6QP26QXH00P24Q8@208>3P`80QhN70P2;Rh/808b<
S0@0SXj>0P2=SHd208^;R`80RXZ:0P29RHT208^;R`80S8b<0P2>SXh408n?S`80T92@0P2CTi<209NG
U`80VIVI0P2JVYX00`2IVIT0V9RH09RHV00209VIV@80VYZJ0P2HV9P209JFUP80UiNG0P2IVIT409ZJ
VP80Vi^K0P2LW9`209^KV`80VYZJ0P2IVIT209RHV080UYJF0P2EUID209JFUP80V9RH0P2FUYH209BD
U0H0Ti>C0P2DU9@00`2BTY80T92@092@T00209>CT`80UiNG0P2IVIT209fMW@80ZJVY0P2f][H20<G5
a@80clo?0P38b<P40;no_bL0b>3H0P1LG5`206YZJP80FEUI0P1JFUX2069RHP80IFEU0P2:RXX20<?3
``80alO70P2ATI4203Lg=`80;2`/0P0a<C4202HV9P80;2`/00<0<S8b02PX:00X:2P00P0d=3@2034a
<@80;Rh^0P0a<C4203<c<`80;Rh^0P0];Bd2034a<@80=cLg0P0a<C420451@@80?Cdm0P0l?3`203/k
>`80;Rh^0P0b<S8202l_;`80;2`/0P0[:b/202PX:0809RHV0P1:BTX2071`L080Kfm_0P1^KVh406IV
IP80E5AD0P1QHF4306a/K0@0LG5a0P1`L70207IfMP80Ogmo0P1jNWX207UiN@80PX:20P1jNWX207em
O@80OWin0P1mOGd207inOP80NGUi0P1nOWh208>3P`80Q8B40P25QHD208:2PP80QHF50P2<S8`408V9
R@80TI6A0P29RHT208f=S@80SXj>0P2?Shl208^;R`80R8R80P2:RXX00`2<S8`0SXj>08j>SP0208b<
S080Shn?0P2ATI4208n?S`80U9BD0P2FUYH209NGU`80VIVI0P2HV9P409NGU`80Vi^K0P2JVYX209JF
UP80U9BD0P2HV9P209fMW@80VIVI0P2LW9`209^KV`80W9bL0P2KVi/409NGU`80U9BD0P2BTY8209ZJ
VP80V9RH0P2EUID209>CT`0309:BTP2DU9@0U9BD00@0U9BD0P2ATI42092@T080U9BD0P2GUiL209JF
UP80W9bL0P2YZJT20;Jf]P80a/K60P3=cLd20<[:bP80`L710P2g]kLW0<SPf080IVIV0P1QHF4205]K
F`80EUIF0P1KFe/206i^KP80SHf=0P2e]KD20<o?c`80UYJF0P0b<S8202XZ:P0302`/;00Z:RX0:RXZ
0080;Bd]0P0/;2`202PX:080;Rh^100`<304034a<@80<c<c0P0d=3@203Lg=`80>3Ph0P0o?cl203dm
?@80@4100P14A4@203dm?@80>3Ph100c<c<202l_;`80:b/[0P0Z:RX201hN7P0304m?C`1hN7P0N7Qh
0080Jf][0P1eMGD206IVIP80HV9R0P1HF5P2065QH@80JVYZ0P1^KVh2075aL@80Kfm_0P1cLg<207If
MP@0Ogmo0P1lO7`207UiN@80OWin1021PH4207alO080OGem0P24Q8@307inOP80R8R80P24Q8@208>3
P`80R8R80P2:RXX208^;R`80SXj>0P2;Rh/208j>SP80SHf=0P2>SXh209:BTP80RHV90P2:RXX208R8
R080Rh^;0P2?Shl208b<S080T92@0P2=SHd208n?S`80Ti>C102GUiL209RHV00309^KV`2FUYH0UYJF
0080V9RH0P2JVYX209NGU`80UYJF102GUiL209fMW@80Vi^K0P2HV9P209bLW080Vi^K0P2IVIT209ZJ
VP80V9RH102FUYH209RHV080VIVI0P2EUID209BDU080Shn?0P2DU9@209:BTP80UYJF00<0Shn?09:B
TP2BTY800P2BTY8209RHV080VYZJ0P2KVi/20:^[Z`80]kNg0P33`l<20<g=c@80c<c<0P2o_kl20;bl
_1h0b>3H000L0<SPf080IFEU0P1PH60205]KF`80EeMG0P1JFUX2071`L080RXZ:0P2h^;P20<k>cP80
UYJF0P0c<c<202LW9`<0:RXZ1P0[:b/202d];@80<30`0P0b<S8403<c<`80<S8b0P0d=3@203Lg=`80
>SXj0P0m?Cd203hn?P80@T920P11@D4203hn?P80>CTi0P0d=3@2034a<@80;bl_0P0Y:BT202/[:`80
7AdM00<0CDe=07alO01lO7`00P1/K6`2071`L080JFUY0P1OGel205UIF@80H61P0P1ZJVX206i^KPH0
LG5a0P1hN7P407inOP80O7al0P1mOGd207inOP80Ogmo0P20P80207moO`@0OWin0P20P8000`23Ph<0
QXJ608J6QP0208B4Q080Ph>30P27QhL208^;R`P0S8b<102>SXh208f=S@80Rh^;0P2:RXX208V9R@80
Rh^;0P2<S8`208j>SP@0Shn?0P2@T90209>CT`80UiNG0P2IVIT209ZJVP0309VIV@2HV9P0V9RH0080
VIVI0P2JVYX209RHV080UYJF0P2GUiL209VIV@@0VYZJ0P2KVi/209bLW080Vi^K0P2JVYX209VIV@80
V9RH0P2FUYH209FEU@80UYJF0P2HV9P209JFUP80U9BD1P2CTi<209BDU00309:BTP2@T900T92@0080
Ti>C0P2GUiL209VIV@80WIfM0P2YZJT20;Jf]P80aLG50P3?cll20<S8b0@0_kno9`38h=P205aLG080
JVYZ0P1IFET205YJFP80HV9R0P1UIFD208Z:RP80`l?30P37alL2096AT@80=cLg0P0/;2`2034a<@80
9RHV0P0/;2`00`0b<S80:2PX02PX:00203@d=080<C4a0P0^;Rh2034a<@80<c<c0P0^;Rh202d];@80
<C4a0P0g=cL2034a<@80@D510P0m?Cd203`l?080>c/k0P0^;Rh2038b<P80;bl_0P0/;2`202/[:`80
:2PX0P0V9RH204Y:BP80L71`0P1_Kfl206i^KP@0IVIV0P1DE5@2065QH@<0K6a/101aLG42071`L080
MWIf0P1oOgl207YjNP80NGUi0P22PX8207YjNP80OGem0P1nOWh207emO@80OWin0P1iNGT207inOP80
Ph>30P24Q8@208F5Q@80PX:20P25QHD208b<S0@0RHV90P2ATI4208V9R@80SHf=0P2>SXh208n?S`80
Rh^;0P28R8P208Z:RP0308b<S02>SXh0SXj>0080S8b<0P2?Shl2096AT@80Shn?0P2DU9@209JFUP80
UiNG0P2IVIT209RHV0@0UiNG0P2KVi/209ZJVP80UYJF0P2DU9@209RHV080WIfM0P2IVIT209bLW080
Vi^K0P2LW9`209^KV`@0UiNG0P2DU9@209:BTP80VYZJ0P2HV9P209FEU@80Ti>C00<0TY:B09BDU02D
U9@0102DU9@2096AT@80T92@0P2DU9@209NGU`80UYJF0P2LW9`20:VYZ@80][Jf0P36a/H20<g=c@80
b/[:0P31`L420;Ng]bL0b>3H0P1VIVH2065QH@80Fe]K0P1FEUH205]KF`80KVi^0P2=SHd20;Fe]@80
clo?0P2FUYH2038b<P80:RXZ00<0;2`/02XZ:P0Z:RX00P0];Bd202`/;080:2PX0P0^;Rh4030`<0@0
<C4a0P0c<c<203@d=080=cLg0P0h>3P203lo?`80?Cdm0P10@40204A4A080?Cdm0P0h>3P403<c<`80
;bl_0P0[:b/202XZ:P807QhN00<0Cdm?07QhN01hN7P00P1[Jf/207EeM@80IVIV0P1RHV8205QHF080
HF5Q0P1ZJVX206i^KP80LG5a0P1_Kfl207=cL`80MWIf101oOgl207alO080NGUi0P1nOWh40861P@80
O7al0P1mOGd208B4Q0<0OWin0P28R8P208B4Q080Ph>30P28R8P208Z:RP80Rh^;0P2>SXh208^;R`80
SXj>0P2=SHd208j>SP80TY:B0P29RHT208Z:RP80R8R80P2;Rh/208n?S`80S8b<0P2@T90208f=S@80
Shn?0P2CTi<409NGU`80V9RH00<0Vi^K09JFUP2FUYH00P2HV9P209ZJVP80UiNG0P2FUYH409NGU`80
WIfM0P2KVi/209RHV080W9bL0P2KVi/209VIV@80VYZJ0P2HV9P409JFUP80V9RH0P2IVIT209FEU@80
U9BD0P2?Shl209BDU080TY:B0P2FUYH00`2?Shl0TY:B09:BTP0209:BTP80V9RH0P2JVYX209^KV`80
Zj^[0P2g]kL20<?3``80cLg=0P3<c<`20;no_`80_;bl7P38h=P001`0b>3H0P1GEeL205iNGP80H61P
0P1HF5P205]KF`80Lg=c0P2@T9020:NWY`80e=CD0P2h^;P207inOP80AdM700<09bLW02TY:@0Y:BT0
0P0a<C42030`<080;bl_0P0c<c<403Lg=`80=SHf100d=3@203De=@80>3Ph0P0k>c/203hn?P80?Cdm
0P0o?cl203dm?@80>SXj0P0f=SH203<c<`80;Bd]0P0/;2`203Ti>@80Bd];0P0b<S800`1GEeL0LG5a
075aL@02075aL@80I6AT0P1]KFd205iNGP80FEUI0P1OGel206QXJ080KFe]0P1`L702079bLP80M7Ad
0P1iNGT207emO@@0OWin101mOGd20820P080PX:20P21PH4207moO`80P8200P21PH400`23Ph<0QHF5
08F5Q@0208J6QP80QhN70P29RHT208b<S0`0SHf=0P2<S8`208^;R`80S8b<0P2=SHd408j>SP80Shn?
0P2ATI4209:BTP80U9BD0P2GUiL209VIV@80VYZJ1@2IVIT409ZJVP@0VIVI0P2JVYX209bLW0H0WIfM
102LW9`209^KV`80VIVI0P2GUiL209JFUP80UiNG0P2HV9P209VIV@80UiNG202DU9@209>CT`03096A
T@2@T900T92@0080TI6A0P2DU9@209NGU`80WIfM0P2VYZH20;6a/@80_kno0P3:b/X20<K6aP80`L71
0P2_[jlW0<SPf080CTi>0P1YJFT205EEE@80DE5A0P1JFUX206UYJ@80U9BD0P2c/k<20<O7a`80aLG5
0P1nOWh203Ti>@809bLW0P0U9BD202`/;00302/[:`0Z:RX0:RXZ0080<C4a0P0b<S8403Ph>080>c/k
0P0i>CT20410@080?Shn0P13@d<20492@P80C4a<0P11@D440492@P80?3`l100j>SX202l_;`80>CTi
100j>SX205aLG080LW9b0P1dM7@206MWI`80L71`0P1RHV8205eMG@80Hf=S0`1[Jf/206m_K`80LW9b
0P1hN7P207]kN`80P820101oOgl207emO@80Ogmo0P22PX8208F5Q@80Q8B41023Ph<208J6QP80PH61
0P25QHD408R8R080RXZ:0P2?Shl208Z:RP80Shn?0P2ATI4208Z:RP80Rh^;0P2:RXX408b<S080Rh^;
0P2>SXh00`2=SHd0S8b<08b<S004092@T080UIFE0P2@T90409VIV@H0VYZJ0P2LW9`409VIV@80Vi^K
102HV9P209^KV`80WinO0P2NWYh209bLW080WinO0P2MWId409^KV`80V9RH102GUiL209ZJVP80V9RH
0P2EUID209NGU`0309FEU@2BTY80TY:B0080U9BD0P2CTi<2096AT@@0SXj>0P2EUID209RHV080WinO
0P2SXj<20;6a/@80_kno0P39bLT20<S8b080`<300P2`/;0W0<SPf080E5AD0P1PH60205iNGP80FUYJ
0P1KFe/207=cL`80U9BD0P2WYjL20=GEe@80]KFe0P1lO7`204E5A@0302PX:00U9BD09BDU0080;Rh^
0P0`<30202h^;P80=cLg0P0f=SH203Ph>080>CTi0P0f=SH203De=@80=3@d0P0i>CT203lo?`80?Cdm
0P0h>3P40410@080>CTi0P0f=SH203@d=080:RXZ0P0/;2`203De=@80CDe=0P0a<C400`1HF5P0KVi^
06i^KP0207=cL`80Hf=S0P1/K6`2061PH080EUIF0P1QHF4206UYJ@80Kfm_0P1aLG42071`L080MGEe
0P1iNGT407alO080Ogmo0P1kNg/207alO080PH610P20P80207moO`80OWin0P25QHD207moO`0308B4
Q028R8P0R8R80080R8R80P29RHT208Z:RP80SHf=0P2<S8`208j>SP80RXZ:102=SHd208Z:RP80SXj>
0P2<S8`208f=S@80TI6A0P2BTY8208^;R`80SHf=0P2ATI4209BDU080UiNG0P2IVIT209ZJVP80VIVI
0P2KVi/00`2MWId0VIVI09VIV@0209RHV080Vi^K0P2IVIT809^KV`80VYZJ1P2MWId209bLW080Vi^K
0P2FUYH209FEU@80V9RH0P2GUiL209RHV080VIVI102CTi<409FEU@80U9BD00<0T92@09>CT`2CTi<0
0P2?Shl209FEU@80V9RH0P2MWId20:VYZ@80[:b/0P2l_;`20<_;b`80a/K60P32`/820;:b/Qh0b>3H
000L0<SPf080EeMG0P1NGUh2061PH080F5QH0P1KFe/207=cL`80T92@0P2WYjL20=CDe080^;Rh0P1n
OWh204M7A`0302LW9`0Y:BT0:BTY0080<C4a0P0`<30202l_;`80<c<c100g=cL203Hf=P@0=3@d0P0e
=CD203Ph>080>c/k0P0n?Sh203dm?@80?clo0P0m?Cd203Xj>P80=SHf0P0c<c<202d];@80;2`/0P0i
>CT204];B`80<S8b00<0EeMG075aL@1aLG400P1aLG4206ATI080KFe]0P1NGUh205UIF@80GemO0P1X
J6P206e]K@80L71`0P1bLW8207AdM080NGUi0P1mOGd407inOP@0OGem0P20P80208:2PP80PH610P1o
Ogl20820P080PH6100<0Ph>308F5Q@25QHD00P26QXH208N7Q`80RHV90P2<S8`<08f=S@80S8b<0P2;
Rh/208b<S080SHf=102>SXh208n?S`80TI6A0P2BTY8209BDU080UiNG0P2IVIT209ZJVPD0VIVI102J
VYX409VIV@80VYZJ0P2LW9`609fMW@@0W9bL0P2KVi/209VIV@80UiNG0P2FUYH209NGU`80V9RH0P2I
VIT209NGU`P0U9BD0P2CTi<00`2ATI40T92@092@T002096AT@80U9BD0P2GUiL209fMW@80YZJV0P2a
/K420;no_`80b/[:0P36a/H20<71`@80[jn_9`38h=P204i>CP80JFUY0P1EEED2055AD@80FUYJ0P1Y
JFT209BDU080/k>c0P37alL20<G5a@80OWin0P0i>CT202LW9`809BDU0P0/;2`00`0[:b/0:RXZ02XZ
:P02034a<@80<S8b100h>3P203/k>`80>CTi0P10@40203hn?P80@d=30P12@T8204a<C080@D511012
@T8203`l?0@0>SXj0P0_;bl203Ti>@@0>SXj0P1LG5`2079bLP80M7Ad0P1WIfL2071`L080HV9R0P1M
GEd206=SH`<0Jf][0P1_Kfl2079bLP80N7Qh0P1kNg/20820P0@0Ogmo0P1mOGd207moO`80PX:20P25
QHD208B4Q0@0Ph>30P26QXH20861P@80QHF51028R8P208Z:RP80Shn?0P2:RXX208n?S`80TI6A0P2:
RXX208^;R`80RXZ:102<S8`208^;R`80SXj>00<0SHf=08b<S02<S8`0102@T90209FEU@80T92@102I
VIT609ZJVP80W9bL102IVIT209^KV`@0V9RH0P2KVi/209nOW`80WYjN0P2LW9`209nOW`80WIfM102K
Vi/209RHV0@0UiNG0P2JVYX209RHV080UIFE0P2GUiL00`2EUID0TY:B09:BTP0209BDU080Ti>C0P2A
TI4408j>SP80UIFE0P2HV9P209nOW`80Xj>S0P2a/K420;no_`80bLW90P38b<P20<30`080/;2`9`38
h=P205ADE080H61P0P1NGUh205YJFP80Fe]K0P1cLg<209BDU080YjNW0P3EeMD20;Fe]@80O7al0P15
ADD00`0X:2P09BDU02DU9@0202h^;P80<30`0P0^;Rh203Lg=`80=SHf0P0h>3P203Ti>@80=SHf0P0e
=CD203@d=080>CTi0P0o?cl203dm?@80>3Ph1010@40203Ti>@80=SHf0P0d=3@202XZ:P80;2`/0P0e
=CD204e=C@80<C4a00<0F5QH06i^KP1^KVh00P1cLg<206=SH`80K6a/0P1PH60205IFEP80HF5Q0P1Y
JFT206m_K`80LG5a0P1`L70207EeM@80NGUi101lO7`207moO`80Ng]k0P1lO7`20861P@80P8200P1o
Ogl207inOP80QHF50P1oOgl00`24Q8@0R8R808R8R00208R8R080RHV90P2:RXX208f=S@80S8b<0P2>
SXh208Z:RP@0SHf=0P2:RXX208j>SP80S8b<0P2=SHd2096AT@80TY:B0P2;Rh/208f=S@80TI6A0P2D
U9@209NGU`80VIVI0P2JVYX209VIV@80Vi^K00<0WIfM09VIV@2IVIT00P2HV9P209^KV`80VIVI202K
Vi/209ZJVPH0WIfM0P2LW9`209^KV`80UYJF0P2EUID209RHV080UiNG0P2HV9P209VIV@@0Ti>C102E
UID209BDU003092@T02CTi<0Ti>C0080Shn?0P2EUID209RHV080WIfM0P2YZJT20:b/[080_;bl0P3;
bl/20<K6aP80`/;20P2b/[8N0<SPf0007038h=P2051@D080Fe]K0P1UIFD205eMG@80GUiN0P1gMgL2
09VIV@80TY:B0P34a<@20<k>cP80b<S80P1]KFd00`0c<c<0;Bd]02d];@0203Hf=P@0=3@d0P0h>3P2
03dm?@80>c/k0P0g=cL203Hf=P80=CDe0P0f=SH203Ti>@80?3`l0P0n?Sh203dm?@80>c/k0P0h>3P2
03De=@80<c<c0P0b<S8202l_;`80;Bd]0P0W9bL202`/;080:BTY00<0Hf=S06][J`1[Jf/00P1fMWH2
05IFEP80Kfm_0P1PH60205MGE`80G5aL0P1VIVH206][J`80Kfm_0P1cLg<207MgM`80NGUi0P1kNg/2
07emO@80Ogmo0P1nOWh207emO@80P8201022PX820861P@D0PX:20P23Ph<208N7Q`@0Rh^;102<S8`6
08f=S@P0S8b<0P2?Shl209:BTP80TI6A0P2@T902096AT@80TY:B0P2EUID209NGU`80VIVI102JVYX2
09VIV@L0VYZJ102KVi/209fMW@H0WinO0P2NWYh609fMW@80VYZJ102GUiL209RHV0@0VIVI0P2GUiL4
09FEU@80UYJF0P2DU9@209:BTP<0TI6A102@T90209FEU@80WIfM0P2SXj<20:^[Z`80^KVi0P34a<@2
0<;2`P80`L710P2PX:0W0<SPf080DE5A0P1PH60206=SH`80FEUI0P1RHV8207IfMP80Ti>C0P2LW9`2
0<71`@80bl_;0P33`l<207AdM080>3Ph0P0e=CD203Lg=`<0=SHf0P11@D420410@080?Shn100g=cL2
03<c<`80>3Ph0P0j>SX203@d=080?Cdm0P0o?cl203Ph>080=SHf0P0d=3@202`/;080;Rh^0P0b<S82
02LW9`80;Bd]0P0/;2`2038b<P80FUYJ0P1_Kfl2071`L080GEeM0P1^KVh405IFEP80H61P0P1TI6@0
0`1ZJVX0L71`071`L00207AdM080MWIf0P1hN7P207]kN`80N7Qh0P1mOGd208:2PP80NWYj1020P802
07inOP80Ogmo0P22PX820820P080Q8B40P23Ph<208B4Q080R8R80P2=SHd208^;R`80RHV90P2=SHd2
08n?S`80RXZ:0P2>SXh208f=S@80RXZ:0P2<S8`208n?S`80Ti>C00<0Shn?096AT@2ATI400P2ATI42
09>CT`80UiNG0P2FUYH209^KV`80UiNG0P2MWId209NGU`H0VIVI102JVYX209bLW080Vi^K0P2OWil2
09bLW080X:2P102MWId209bLW080WIfM0P2JVYX209JFUP80U9BD0P2JVYX209RHV080VIVI0P2GUiL2
09JFUP0309BDU02FUYH0UYJF0080UiNG102BTY84096AT@80Shn?0P2EUID209jNWP80XJ6Q0P2/[:`2
0;Zj^P80`/;20P35aLD20;^k^`80Z:RX9`38h=P204m?C`80G5aL0P1VIVH205aLG080GemO0P1gMgL2
09VIV@80Ti>C0P36a/H20<_;b`80b<S80P1_Kfl00`0`<300;bl_02l_;`0203Lg=`80=CDe0P0`<302
03`l?080>SXj0P0i>CT203@d=080>CTi0P0b<S8203@d=080=cLg0P0m?Cd203lo?`80?Cdm0P0k>c/2
03Ph>080=CDe0P0`<30203<c<`@0;bl_0P0U9BD202`/;080:RXZ00<0IFEU06YZJP1ZJVX00P1gMgL2
05ADE080KVi^0P1SHf<205EEE@80Fe]K0P1UIFD206][J`80KFe]0P1iNGT407MgM`80NWYj0P1mOGd2
0820P080Ogmo0P1kNg/208B4Q080Ogmo0P25QHD208>3P`80PX:21@23Ph<208B4Q080RXZ:102;Rh/4
08j>SP80S8b<102=SHd208b<S080SHf=0P2;Rh/208f=S@80TI6A0P2?Shl2096AT@80Ti>C102BTY82
09ZJVP80V9RH0P2IVIT209jNWP80UiNG00<0Vi^K09NGU`2GUiL00P2MWId209ZJVP80V9RH0P2MWId4
09jNWP80WinO0P2NWYh209bLW080X:2P0P2KVi/209jNWP80UYJF0P2GUiL209ZJVP80VIVI0P2LW9`2
09VIV@80V9RH102CTi<409FEU@80TY:B00<0Ti>C08n?S`2?Shl0102?Shl209NGU`@0WYjN0P2][Jd2
0;no_`80aLG50P2m_Kd20<?3``80XZ:R7P38h=P001`0b>3H0P1@D50205]KF`80IFEU0P1MGEd205iN
GP80MgMg0P2IVIT209:BTP80a<C40P3>c/h20<S8b080KFe]00<0<c<c02d];@0];Bd00P0f=SH403@d
=080>3Ph0P0m?Cd203/k>`80=cLg0P0f=SH203De=@80=SHf0P0i>CT203`l?080?Shn0P0m?Cd203/k
>`80>3Ph0P0e=CD203<c<`80<S8b0P0_;bl202d];@809bLW0P0/;2`202TY:@0306=SH`1[Jf/0Jf][
0080MWIf0P1FEUH206m_K`80H61P0P1GEeL205aLG080IVIV0P1[Jf/206m_K`80Lg=c0P1gMgL207Ui
N@80Ng]k0P1mOGd207moO`80OWin0P1mOGd20820P0@0PX:20P21PH4508:2PP80Ph>30P27QhL408^;
R`@0S8b<1P2=SHd808b<S080Shn?0P2BTY82096AT@80T92@0P2ATI4209:BTP80UIFE0P2GUiL209VI
V@@0VYZJ0P2IVIT709ZJVP@0Vi^K0P2MWId609nOW`80WYjN1P2MWId209ZJVP@0UiNG0P2HV9P409VI
V@80UiNG102EUID209JFUP80U9BD0P2BTY83096AT@@0T92@0P2EUID209fMW@80Xj>S0P2[Zj/20;Vi
^@80a<C40P32`/820<71`@80X:2P9`38h=P2055AD@80H61P0P1SHf<205UIF@80HV9R0P1fMWH209>C
T`80W9bL0P31`L420<_;b`80`l?30P1dM7@203Ph>080=CDe0P0g=cL303Hf=P80@D510P10@40203hn
?P@0=cLg0P0c<c<203Ph>080>SXj0P0d=3@203dm?@80?clo0P0h>3P203Hf=P80=3@d0P0/;2`202h^
;P80<S8b0P0W9bL202d];@80;2`/0P0b<S8205YJFP80Kfm_0P1`L70205eMG@80KVi^101FEUH2061P
H080I6AT00<0JVYZ071`L01`L7000P1dM7@207IfMP80N7Qh0P1kNg/207QhN080OGem0P22PX8207Yj
NP@0P8200P1nOWh207moO`80PX:20P20P80208B4Q080Ph>30P24Q8@208R8R080SHf=0P2;Rh/208V9
R@80SHf=0P2?Shl208Z:RP80SXj>0P2=SHd208Z:RP80S8b<0P2?Shl209>CT`0308n?S`2ATI40TI6A
0080TI6A0P2CTi<209NGU`80UYJF0P2KVi/209NGU`80WIfM0P2GUiL609VIV@@0VYZJ0P2LW9`209^K
V`80WinO0P2LW9`20:2PX0@0WIfM0P2LW9`209fMW@80VYZJ0P2FUYH209BDU080VYZJ0P2HV9P209VI
V@80UiNG0P2FUYH00`2DU9@0UYJF09JFUP0209NGU`@0TY:B102ATI4208n?S`80UIFE0P2NWYh20:6Q
X@80[:b/0P2j^[X20<;2`P80aLG50P2k^k/20:RXZ2L0b>3H0P1?Cdl205aLG080IVIV0P1LG5`205mO
G`80MgMg0P2IVIT209>CT`80a/K60P3;bl/20<S8b080Kfm_00<0<30`02l_;`0_;bl00P0g=cL203De
=@80<30`0P0l?3`203Xj>P80>CTi0P0d=3@203Ti>@80<S8b0P0d=3@203Lg=`80?Cdm0P0o?cl203dm
?@80>c/k0P0h>3P203De=@80<30`0P0c<c<402l_;`809BDU0P0/;2`202XZ:P0306EUI@1ZJVX0JVYZ
0080MgMg0P1DE5@206i^KP80Hf=S0P1EEED205]KF`80IFEU0P1[Jf/206e]K@80NGUi101gMgL207Yj
NP80OGem0P20P80207moO`80Ng]k0P24Q8@207moO`80QHF50P23Ph<208:2PPD0Ph>30P24Q8@208Z:
RP@0Rh^;102>SXh208b<S0@0SHf=0P2<S8`208f=S@80Rh^;0P2=SHd2096AT@80Shn?0P2ATI4209>C
T`@0TY:B0P2JVYX209RHV080VIVI0P2NWYh209NGU`0309^KV`2GUiL0UiNG0080WIfM0P2JVYX209RH
V080WIfM102NWYh209nOW`80WYjN0P2LW9`20:2PX080Vi^K0P2NWYh209JFUP80UiNG0P2JVYX209VI
V@80W9bL0P2IVIT209RHV0@0Ti>C102EUID209:BTP0309>CT`2?Shl0Shn?00@0Shn?0P2GUiL409jN
WP80[Jf]0P2o_kl20<G5a@80_Kfm0P33`l<20::RXQh0b>3H000L0<SPf080Lg=c0P1HF5P2065QH@80
KVi^0P1LG5`2071`L0@0RHV90P2XZ:P20<71`@80b<S80P35aLD00`1DE5@0:b/[02/[:`02030`<080
;bl_0P0b<S8203Hf=P80>CTi0P0h>3P603De=@80=SHf0P0h>3P203`l?080?Shn0P0l?3`203Ti>@80
=cLg0P0f=SH203@d=080<c<c0P0`<30202l_;`80;2`/0P0c<c<202d];@0306ATI01_Kfl0Kfm_0080
O7al0P1FEUH206YZJP80G5aL0P1EEED205]KF`80IFEU0P1ZJVX206i^KP80Lg=c0P1fMWH207UiN@80
NWYj0P1lO7`207inOP@0OGem0P1nOWh20820P080OWin0P1mOGd20820P0<0Ph>30P22PX8208F5Q@80
R8R80P29RHT208Z:RP80Rh^;1P2<S8`208f=S@@0Shn?0P2>SXh208n?S`80T92@1P2ATI4409:BTP80
U9BD0P2GUiL709ZJVPH0Vi^K0P2LW9`209jNWP80WinO0P2QXJ4209nOW`@0WIfM1P2NWYh209^KV`80
VIVI0P2JVYX209^KV`80VYZJ0P2GUiL209JFUPH0UIFE0P2DU9@209:BTP03092@T02>SXh0SXj>0080
SHf=0P2>SXh2096AT@80UYJF0P2LW9`20:BTY080/[:b0P2n_[h20;Zj^P80]KFe0P2SXj<W0<SPf080
IFEU0P1HF5P206m_K`80JVYZ0P1SHf<207AdM080QhN70P29RHT20:BTY080`/;20P3@d=020;Zj^P80
Bd];0P0_;bl202h^;PD0<30`100d=3@4034a<@80;Bd]0P0e=CD203@d=080<c<c0P11@D4203Hf=P80
>3Ph100f=SH4038b<P80;bl_100/;2`2030`<080=3@d0P1LG5`407=cL`80GemO0P1YJFT205EEE@80
E5AD0P1TI6@2065QH@0306UYJ@1aLG40LG5a0080L71`0P1fMWH207MgM`80Ng]k0P1mOGd207moO`80
P8200P1jNWX207moO`80P8200P1oOgl207alO080PH610P1oOgl208B4Q080PX:20P24Q8@408^;R`80
RHV90P2;Rh/208V9R@80SHf=0P2?Shl208f=S@80T92@102?Shl2096AT@80SXj>00<0Ti>C09BDU02D
U9@00P2=SHd208n?S`80TI6A0P2CTi<209RHV080VIVI0P2KVi/209NGU`80WYjN0P2IVIT209bLW080
WIfM102NWYh20:6QX@80Y:BT0P2OWil609fMW@80W9bL0P2NWYh209^KV`80VYZJ0P2HV9P209ZJVP@0
VIVI0P2FUYH209>CT`03096AT@2FUYH0UYJF00@0TI6A102?Shl408f=S@@0U9BD0P2IVIT20:FUY@80
/k>c0P2j^[X20;no_`80/K6a0P2QXJ4W0<SPf080Lg=c0P1HF5P2065QH@80Jf][0P1MGEd206m_K`@0
R8R80P2XZ:P20<71`@80bl_;0P39bLT00`1HF5P0:2PX02PX:00203<c<`80:RXZ0P0f=SH203Lg=`80
>SXj0P0h>3P203Hf=P80=cLg0P0f=SH203Ph>080>CTi0P0m?Cd203hn?P@0>SXj1P0f=SH2030`<080
=3@d0P0^;Rh202`/;080=3@d0P0^;Rh00`1TI6@0KVi^06i^KP0207emO@80FEUI0P1XJ6P2069RHP80
De=C0P1IFET206IVIP80K6a/0P1^KVh2071`L080M7Ad0P1gMgL207inOP80Ogmo0P1kNg/207inOP80
Ng]k0P20P8020861P@80N7Qh0P1jNWX207inOP80Q8B400<0P82007moO`1oOgl01027QhL208Z:RP80
RHV90P2<S8`208^;R`80R8R80P2=SHd2096AT@80SHf=0P2@T90208j>SP80Shn?0P2@T90208n?S`80
TI6A0P2DU9@2092@T080TY:B0P2@T90209BDU080VIVI0P2MWId209BDU00309ZJVP2KVi/0Vi^K0080
W9bL0P2NWYh209VIV@80W9bL0P2PX:020:6QX@80WinO0P2UYJD209fMW@80VYZJ0P2NWYh209nOW`80
W9bL0P2JVYX209VIV@80UYJF0P2HV9P209NGU`80Ti>C0P2LW9`209:BTP@0UYJF0P2ATI400`2?Shl0
TI6A096AT@0208b<S080T92@0P2?Shl209NGU`80V9RH0P2VYZH20;>c/`80_Kfm0P2h^;P20;Fe]@80
X:2P7P38h=P001`0b>3H0P1cLg<205QHF080HF5Q0P1^KVh205aLG080L71`1029RHT20:RXZ080`L71
0P38b<P20<G5a@0305ADE00[:b/0:b/[0080<30`0P0_;bl2038b<P80=SHf0P0i>CT203Ph>0H0=CDe
0P0f=SH203Ph>080?3`l0P0n?Sh203`l?080>CTi0P0g=cL203Hf=P80=3@d0P0c<c<2030`<080;bl_
0P0/;2`203<c<`80;Bd]00<0I6AT06m_K`1_Kfl00P1lO7`205IFEP80JVYZ0P1LG5`205EEE@80Fe]K
0P1UIFD206YZJP80KVi^0P1cLg<207IfMP80NGUi0P1jNWX207alO080OWin101mOGd207inOP80P820
0P1nOWh207emO@80P8200`23Ph<208:2PP80QHF50P28R8P208V9R@80RXZ:0P2;Rh/608b<S080SHf=
102?Shl208j>SP80Shn?0P2@T906096AT@@0TY:B0P2DU9@209NGU`L0VYZJ1P2KVi/209bLW080WYjN
0P2OWil20:6QX@80WinO102MWId609jNWP80Vi^K0P2IVIT209ZJVP80Vi^K0P2JVYX209NGU`80UYJF
1P2EUID209BDU080TY:B00<0T92@08j>SP2>SXh00P2=SHd208j>SP80TI6A0P2FUYH209bLW080Y:BT
0P2b/[820;jn_P80^[Zj0P2e]KD20:>SXbL0b>3H0P1UIFD205QHF080Kfm_0P1ZJVX206=SH`80M7Ad
0P27QhL208V9R@80Y:BT0P32`/820=3@d080^[Zj0P1;Bd/202l_;`80;Rh^1@0`<30403@d=0@0<C4a
0P0];Bd203De=@80=3@d0P0c<c<20451@@80=SHf0P0h>3P403Hf=P@0<S8b0P0_;bl402`/;080<30`
0P0d=3@205aLG0@0Lg=c0P1OGel206UYJ@80EEEE0P1DE5@206ATI080HF5Q00<0JFUY075aL@1aLG40
0P1`L70207IfMP80MgMg0P1kNg/207emO@80Ogmo0P20P80207YjNP80Ogmo0P20P80207moO`80O7al
0P21PH4207moO`80Q8B40P22PX8208B4Q0@0Rh^;0P29RHT208^;R`80RHV90P2=SHd208n?S`80SHf=
0P2@T90408n?S`80TI6A0P2>SXh00`2CTi<0U9BD09BDU00208f=S@80Shn?0P2ATI4209>CT`80V9RH
0P2IVIT209^KV`80UiNG0P2NWYh209VIV@80W9bL0P2MWId409jNWP80XJ6Q0P2TY:@209nOW`H0WIfM
0P2LW9`209jNWP80Vi^K0P2JVYX209RHV080VYZJ102IVIT209JFUP80Ti>C00<0TI6A09JFUP2FUYH0
102ATI4408n?S`@0SHf=102DU9@209VIV@80YJFU0P2c/k<20;Zj^P80_kno0P2a/K420:6QXBL0b>3H
0P1cLg<205QHF080HF5Q0P1[Jf/205eMG@80Kfm_1028R8P20:RXZ080`L710P3;bl/20<W9b@0305QH
F00X:2P0:2PX0080<c<c0P0Z:RX203Hf=P80=cLg0P0j>SX203Ph>080=SHf0P0g=cL203Hf=P80>3Ph
0P0i>CT203dm?@80?Shn100j>SX603Hf=P80<30`0P0d=3@202h^;P80;2`/0P0d=3@202h^;P0306AT
I01^KVh0KVi^0080OGem0P1IFET206QXJ080HV9R0P1CDe<205UIF@80IVIV0P1/K6`206i^KP80L71`
0P1dM7@207MgM`80OWin0P1oOgl207]kN`80OWin0P1kNg/20820P080PH610P1hN7P207YjNP80OWin
0P24Q8@00`20P800Ogmo07moO`0408N7Q`80RXZ:0P29RHT208b<S080Rh^;0P28R8P208f=S@80TI6A
0P2=SHd2092@T080SXj>0P2?Shl2092@T080Shn?0P2ATI4209BDU080T92@0P2BTY82092@T080U9BD
0P2IVIT209fMW@80U9BD00<0VYZJ09^KV`2KVi/00P2LW9`209jNWP80VIVI0P2LW9`20:2PX080XJ6Q
0P2OWil20:FUY@80WIfM0P2JVYX209jNWP80WinO0P2LW9`209ZJVP80VIVI0P2FUYH209RHV080UiNG
0P2CTi<209bLW080TY:B102FUYH2096AT@0308n?S`2ATI40TI6A0080S8b<0P2@T90208n?S`80UiNG
0P2HV9P20:JVYP80/k>c0P2m_Kd20;Rh^080]KFe0P2PX:0N0<SPf0007038h=P209VIV@80GEeM0P1O
Gel207UiN@80G5aL0P1YJFT207EeM@80OGem0P27QhL20;6a/@80d=3@0P3?cll00`2KVi/0?clo03lo
?`0202`/;0809RHV0P0_;bl2034a<@80=3@d0P0c<c<2034a<@80<S8b0P0d=3@203Hf=P80>3Ph0P0k
>c/203hn?P80>c/k0P0g=cL403Hf=P80=CDe0P0d=3@2034a<@80;bl_0P0^;Rh203Hf=P80;bl_00<0
I6AT07AdM01dM7@00P21PH4205UIF@80IFEU0P1HF5P205=CD`80FUYJ0P1UIFD206YZJP80KVi^0P1b
LW8207EeM@80N7Qh0P1jNWX207]kN`H0O7al101mOGd207]kN`80NGUi0P1nOWh308>3P`80PH610P22
PX8208B4Q080QXJ60P28R8P208V9R@80RXZ:0P2;Rh/208b<S080Shn?102ATI42092@T0H0Shn?1P2A
TI44092@T080U9BD0P2IVIT209ZJVPL0Vi^K0P2LW9`209fMW@80WinO0P2PX:020:6QX@80WYjN0P2L
W9`209fMW@H0WYjN0P2LW9`209^KV`80W9bL0P2MWId209ZJVP80UYJF102EUID209BDU0@0Ti>C0P2B
TY800`2>SXh0Rh^;08^;R`0208Z:RP80Rh^;0P2<S8`208j>SP80Ti>C0P2KVi/20:VYZ@80];Bd0P2^
[Zh40:FUYBL0b>3H0P2NWYh205]KF`80Hf=S0P1`L70205mOG`80JVYZ0P1gMgL207emO@80RXZ:0P2[
Zj/20<o?c`80e=CD0P2QXJ4203Xj>P80<S8b00<0;Rh^02d];@0];Bd00P0d=3@203Ph>080=SHf0P0e
=CD2038b<P80>SXj0P0i>CT203hn?P80@4100P0n?Sh203Xj>P80>3Ph0P0c<c<203Ti>@80=3@d0P0e
=CD2034a<@80;bl_100a<C4203Ph>080H61P0P1gMgL20861P@80GUiN0P1WIfL2055AD@80E5AD0P1L
G5`206EUI@<0KFe]0P1bLW8207EeM@80N7Qh1P1iNGT207]kN`80OGem0P1lO7`207emO@80Ng]k0P1h
N7P207emO@80PX:20P26QXH408:2PP80QXJ60P25QHD208J6QP80SXj>0P2:RXX208b<S080RXZ:0P2=
SHd209>CT`80SXj>0P2@T90208j>SP80Shn?00<0SXj>096AT@2ATI400P2?Shl2096AT@80UIFE0P2>
SXh209BDU080V9RH0P2JVYX209^KV`@0VYZJ0P2LW9`209ZJVP80WinO0P2NWYh209fMW@80WYjN0P2R
XZ8209^KV`80WIfM0P2NWYh209fMW@80WYjN0P2LW9`409^KV`80X:2P102FUYH209RHV0D0UYJF0P2@
T90209FEU@80Shn?0P2:RXX208f=S@80RXZ:0P2;Rh/208f=S@80TI6A0P2MWId20:BTY080/[:b0P2f
][H20:FUY@80VYZJ9`38h=P209JFUP80H61P0P1NGUh207YjNP80G5aL0P1YJFT207MgM`80OGem0P29
RHT20:j^[P80clo?0P3AdM400`2HV9P0?clo03lo?`0202`/;0809RHV0P0^;Rh2034a<@80<c<c0P0d
=3@2038b<P@0<c<c0P0e=CD203Lg=`80>c/k0P10@40203/k>`80>CTi0P0g=cL203De=@80=cLg0P0c
<c<203@d=080;Rh^0P0];Bd203De=@80;Rh^00<0I6AT07IfMP1fMWH00P20P80205YJFP80Hf=S0P1J
FUX2055AD@80Fe]K0P1TI6@206a/K080KVi^0P1`L70207MgM`80MWIf0P1jNWX207emO@@0O7al0P1k
Ng/407moO`80MGEe0P1lO7`208J6QP80Ph>300<0Ogmo08>3P`23Ph<00P24Q8@208>3P`80QHF50P27
QhL208^;R`80SHf=0P27QhL208^;R`80TI6A0P2CTi<2092@T080Shn?0P2BTY8208j>SP@0TI6A0P2=
SHd209:BTP80Ti>C0P2BTY8209>CT`80UiNG0P2QXJ4209VIV@0309bLW02MWId0WIfM0080UiNG0P2L
W9`209fMW@80XJ6Q0P2NWYh20:6QX@80W9bL102JVYX209fMW@80XJ6Q0P2MWId209VIV@80W9bL0P2M
WId209nOW`80WIfM0P2IVIT209:BTP80V9RH0P2CTi<209:BTP80U9BD0P2CTi<508^;R`80RHV9102>
SXh209>CT`80W9bL0P2YZJT20;>c/`80[Zj^0P2VYZH20:BTY1h0b>3H000L0<SPf080VIVI0P1MGEd2
05mOG`80NGUi0P1LG5`206UYJ@80MGEe0P1mOGd208N7Q`80/K6a0P3@d=020<o?c`0309^KV`0o?cl0
?clo0080;2`/0P0V9RH202l_;`80<C4a0P0d=3@203<c<`80<C4a0P0b<S8203@d=080=SHf0P0h>3P2
03/k>`80?Shn0P0k>c/203Lg=`@0=SHf0P0e=CD203@d=080<C4a0P0_;bl202h^;P80=SHf0P0_;bl0
0`1TI6@0M7Ad07AdM0020861P@80FEUI0P1UIFD205QHF080De=C0P1JFUX206EUI@80JVYZ0P1^KVh2
079bLP80MGEe0P1hN7P207YjNP80Ng]k1P1lO7`407emO@80Ng]k0P1iNGT207inOP<0Ph>30P21PH42
08:2PP80Q8B40P26QXH208R8R080RHV90P2:RXX208^;R`80S8b<0P2?Shl4096AT@80T92@1P2?Shl6
096AT@@0T92@0P2DU9@209VIV@80VYZJ1`2KVi/209bLW080WIfM0P2OWil20:2PX080XJ6Q0P2NWYh2
09bLW080WIfM1P2NWYh209bLW080Vi^K0P2LW9`209fMW@80VYZJ0P2FUYH409FEU@80U9BD102CTi<2
09:BTP0308j>SP2;Rh/0Rh^;0080RXZ:0P2;Rh/208b<S080SXj>0P2CTi<209^KV`80ZJVY0P2d];@2
0:j^[P@0YJFU9`38h=P209jNWP80Fe]K0P1SHf<2071`L080GemO0P1ZJVX207MgM`80OGem0P2:RXX2
0:^[Z`80clo?0P3De=@20:6QX@80>SXj0P0b<S800`0^;Rh0;Bd]02d];@0203@d=080>3Ph0P0f=SH2
03De=@80<S8b0P0j>SX203Ti>@80?Shn0P10@40203hn?P80>SXj0P0h>3P203<c<`80>CTi0P0d=3@2
03De=@80<C4a0P0_;bl4034a<@80>3Ph0P1PH60207MgM`80PH610P1NGUh206MWI`80DE5A0P1DE5@2
05aLG080IFEU0`1]KFd2079bLP80MGEe0P1hN7P607UiN@80Ng]k0P1mOGd207alO080OGem0P1kNg/2
07QhN080OGem0P22PX8208J6QP@0PX:20P26QXH208F5Q@80QXJ60P2>SXh208Z:RP80S8b<0P2:RXX2
08f=S@80Ti>C0P2>SXh2092@T080SXj>0P2?Shl00`2>SXh0TI6A096AT@0208n?S`80TI6A0P2EUID2
08j>SP80U9BD0P2HV9P209ZJVP80Vi^K102JVYX209bLW080VYZJ0P2OWil209jNWP80WIfM0P2NWYh2
0::RXP80Vi^K0P2MWId209jNWP80WIfM0P2NWYh209bLW0@0Vi^K0P2PX:0409JFUP80V9RH1@2FUYH2
092@T080UIFE0P2?Shl208Z:RP80SHf=0P2:RXX208^;R`80SHf=0P2ATI4209fMW@80Y:BT0P2b/[82
0;Jf]P80YJFU0P2JVYXW0<SPf080UYJF0P1PH60205iNGP80NWYj0P1LG5`206UYJ@80MgMg0P1mOGd2
08V9R@80[Zj^0P3?cll20=7Ad@0309RHV00o?cl0?clo0080;2`/0P0V9RH202h^;P80<C4a0P0c<c<2
03@d=080<S8b100c<c<203De=@80=cLg0P0k>c/20410@080>c/k0P0i>CT203Lg=`80=CDe0P0g=cL2
03<c<`80=3@d0P0^;Rh202d];@80=CDe0P0^;Rh00`1TI6@0MWIf07IfMP020820P080FUYJ0P1SHf<2
05YJFP80DE5A0P1KFe/206ATI080K6a/0P1^KVh2071`L080MgMg0P1fMWH207YjNP80OGem101lO7`2
07]kN`@0Ogmo0P1eMGD207alO080QXJ60P23Ph<00`1oOgl0Ph>308>3P`0208B4Q080Ph>30P25QHD2
08N7Q`80Rh^;0P2=SHd208N7Q`80Rh^;0P2ATI4209>CT`80T92@0P2?Shl209:BTP80SXj>102ATI42
08f=S@80TY:B0P2CTi<209:BTP80Ti>C0P2GUiL20:6QX@80VIVI00<0W9bL09fMW@2MWId00P2GUiL2
09bLW080WIfM0P2QXJ4209jNWP80XJ6Q0P2LW9`409ZJVP80WIfM0P2QXJ4209fMW@80VIVI0P2LW9`2
09fMW@80WinO0P2MWId209VIV@80TY:B0P2HV9P209>CT`80TY:B0P2DU9@209>CT`D0Rh^;0P29RHT4
08j>SP80Ti>C0P2LW9`20:VYZ@80/k>c0P2^[Zh20:JVYP80Y:BT7P38h=P001`0b>3H0P2YZJT208^;
R`80IfMW0P1UIFD206YZJP80J6QX0P1WIfL206i^KP80MgMg0P2JVYX20;Zj^P80f=SH00<0aLG508:2
PP22PX800P0j>SX2028R8P@0:b/[0P0^;Rh202d];@80:b/[0P0^;Rh2034a<@80<c<c0P0d=3@203`l
?080@D510P0j>SX2034a<@80<S8b100c<c<2034a<@80;Bd]0P0Z:RX202PX:080<30`0P0^;Rh00`1X
J6P0MGEe07EeM@020820P080EEEE0P1TI6@205IFEP80DE5A0P1IFET206EUI@80K6a/0P1`L702079b
LP80M7Ad0P1fMWH207QhN080NGUi0P1jNWX207]kN`80O7al0P1mOGd207inOP@0OGem0P1oOgl50861
P@80Ph>30P25QHD208N7Q`80RHV91028R8P208Z:RP80S8b<0P2?Shl4096AT@80T92@102?Shl2092@
T080TI6A0P2BTY8209>CT`@0U9BD0P2EUID209NGU`80VIVI1`2KVi/409bLW080Vi^K0P2MWId409nO
W`H0WYjN0P2MWId809bLW080Vi^K0P2HV9P209JFUP@0UIFE0P2CTi<209:BTP80TI6A0P2@T9000`2<
S8`0R8R808R8R00608N7Q`80R8R80P2=SHd209:BTP80WIfM0P2UYJD209jNWP80U9BD0P2EUIDW0<SP
f080];Bd0P2:RXX2061PH080I6AT0P1ZJVX205iNGP80IFEU0P1eMGD207emO@80SXj>0P30`<020=CD
e080bl_;0P1gMgL2030`<00302TY:@0Z:RX0:RXZ0080:BTY0P0^;Rh202/[:`80;bl_0P0Z:RX4038b
<P80<c<c0P0];Bd204I6AP80@D51100d=3@203Hf=P80<C4a0P0c<c<2038b<P80:BTY0P0Z:RX202d]
;@80<C4a0P1TI6@207MgM`80NGUi0P1GEeL206IVIP80CTi>0P1GEeL205]KF`80H61P00<0KVi^06e]
K@1]KFd0101cLg<207YjNP@0NGUi0P1oOgl207alO080OGem0P1lO7`207inOP80NWYj1021PH4208B4
Q080OWin0P1mOGd208>3P`@0PH610P2:RXX208V9R@80QHF50P28R8P2092@T080Rh^;0P2ATI4209FE
U@80TI6A0P2@T90208n?S`0309:BTP2@T900T92@0080T92@0P2EUID409BDU080UIFE0P2FUYH209nO
W`80VYZJ0P2IVIT409bLW080VIVI102KVi/209jNWP80X:2P0P2OWil209^KV`80WIfM0P2QXJ4209bL
W080WYjN0P2JVYX209bLW080WYjN0P2JVYX209RHV080UYJF0P2CTi<209JFUP03092@T02?Shl0Shn?
0080TI6A0P2?Shl208Z:RP80QXJ60P27QhL208F5Q@80R8R80P2=SHd208n?S`80UiNG0P2HV9P20:JV
YP80Y:BT0P2FUYH209>CTbL0b>3H0P2ZZZX208^;R`80IfMW0P1TI6@406UYJ@80IFEU0P1]KFd207Qh
N080VIVI0P2i^KT20=OGe`030<?3``24Q8@0Q8B40080?Cdm0P0Q8B4202`/;080;Rh^0P0/;2`202l_
;`80:2PX0P0Z:RX403<c<`80=CDe0P0l?3`203hn?P80>c/k0P0];Bd202l_;`@0<S8b0P0_;bl202/[
:`@0:RXZ0P0a<C4202h^;P0306MWI`1eMGD0MGEe0080O7al0P1FEUH2069RHP80EUIF0P1CDe<205IF
EP80I6AT0P1_Kfl206i^KP@0MWIf0P1eMGD207AdM080NWYj0P1gMgL207alO080OGem0P1lO7`207in
OP80O7al0P1oOgl207inOP80PH6100<0OWin0861P@21PH400P26QXH208B4Q080R8R81029RHT208N7
Q`80R8R80P2?Shl2096AT@80S8b<0P2@T902096AT@80Shn?0P2=SHd2092@T080TY:B0P2@T90409BD
U080UIFE0P2DU9@209NGU`@0W9bL00<0VYZJ09^KV`2KVi/00P2IVIT20:6QX@80VYZJ0P2LW9`20::R
XP80X:2P0P2QXJ4209fMW@80WYjN0P2QXJ420:FUY@80V9RH0P2JVYX209fMW@@0VIVI0P2JVYX209JF
UP80SXj>0P2EUID2096AT@80TY:B0P2CTi<2092@T00308V9R@28R8P0R8R80080QhN70P28R8P208N7
Q`80QXJ60P2>SXh208n?S`80X:2P0P2VYZH209nOW`80UYJF0P2BTY8N0<SPf0007038h=P20:VYZ@80
Rh^;0P1WIfL206EUI@80JVYZ0P1XJ6P206MWI`80KVi^0P1gMgL209ZJVP80^[Zj0P3Hf=P00`35aLD0
PX:208:2PP0203Xj>P808R8R100[:b/202h^;P80;Bd]0P0[:b/202h^;P80<C4a0P0c<c<203@d=080
?3`l0P11@D4203Xj>P80<C4a0P0b<S8403<c<`80<C4a0P0];Bd202XZ:P80:2PX0P0`<30202h^;P03
06QXJ01eMGD0MGEe0080P8200P1EEED206ATI080EUIF0P1ADE4205UIF@80IFEU0P1/K6`2071`L080
LW9b0P1dM7@207IfMP80N7Qh0P1iNGT207YjNP80Ng]k0P1lO7`207emO@80OWin101mOGd207moO`D0
PH610P23Ph<208F5Q@80QhN70P29RHT408R8R080RXZ:0P2<S8`208n?S`@0TI6A0P2@T90408n?S`80
T92@0P2ATI4209:BTP80Ti>C102DU9@209FEU@80UiNG0P2IVIT709^KV`@0W9bL0P2KVi/209fMW@@0
WinO1P2NWYh209fMW@P0W9bL0P2KVi/209RHV080UYJF102EUID209>CT`80TY:B0P2ATI42092@T003
08b<S028R8P0R8R800H0QhN70P28R8P208f=S@80TY:B0P2MWId20:FUY@80WYjN0P2DU9@209FEUBL0
b>3H0P2d];@208Z:RP80H61P0P1TI6@206YZJP80GUiN0P1UIFD207EeM@80OGem0P2>SXh20<30`080
e=CD0P3;bl/207MgM`80<30`00<0:BTY02XZ:P0Z:RX00P0Y:BT202h^;P80:b/[0P0_;bl202XZ:P@0
<S8b0P0c<c<202d];@80ATI60P11@D4403@d=080=SHf0P0a<C4203<c<`80<S8b0P0Y:BT202XZ:P80
;Bd]0P0a<C4206ATI080MgMg0P1iNGT205MGE`80IVIV0P1>CTh205MGE`80Fe]K0P1PH6000`1^KVh0
KFe]06e]K@0407=cL`80NWYj101iNGT207moO`80O7al0P1mOGd207alO080OWin0P1jNWX40861P@80
Q8B40P1nOWh207emO@80Ph>31021PH4208Z:RP80RHV90P25QHD208R8R080T92@0P2;Rh/2096AT@80
UIFE0P2ATI42092@T080Shn?00<0TY:B092@T02@T9000P2@T90209FEU@@0U9BD0P2EUID209JFUP80
WinO0P2JVYX209VIV@@0W9bL0P2IVIT409^KV`80WYjN0P2PX:0209nOW`80Vi^K0P2MWId20:6QX@80
W9bL0P2NWYh209ZJVP80W9bL0P2NWYh209ZJVP80V9RH0P2FUYH209>CT`80UYJF00<0T92@08n?S`2?
Shl00P2ATI4208n?S`80RXZ:0P26QXH208N7Q`80QHF50P28R8P208f=S@80Shn?0P2GUiL209RHV080
YZJV0P2TY:@209JFUP80Ti>C9`38h=P20:ZZZP80Rh^;0P1WIfL206ATI0@0JFUY0P1UIFD206e]K@80
N7Qh0P2IVIT20;Vi^@80emOG00<0`l?308B4Q024Q8@00P0m?Cd2024Q8@80;2`/0P0^;Rh202`/;080
;bl_0P0X:2P202XZ:P@0<c<c0P0e=CD203`l?080?Shn0P0k>c/202d];@80;bl_100b<S8202l_;`80
:b/[100Z:RX2034a<@80;Rh^00<0IfMW07EeM@1eMGD00P1lO7`205IFEP80HV9R0P1FEUH205=CD`80
EUIF0P1TI6@206m_K`80KVi^101fMWH207EeM@80M7Ad0P1jNWX207MgM`80O7al0P1mOGd207alO080
OWin0P1lO7`207moO`80OWin0P21PH400`1nOWh0PH610861P@0208J6QP80Q8B40P28R8P408V9R@80
QhN70P28R8P208n?S`80TI6A0P2<S8`2092@T080TI6A0P2?Shl208f=S@80T92@0P2BTY82092@T0@0
U9BD0P2EUID209BDU080UiNG102LW9`00`2JVYX0Vi^K09^KV`0209VIV@80XJ6Q0P2JVYX209bLW080
XZ:R0P2PX:020:6QX@80WIfM0P2NWYh20:6QX@80YJFU0P2HV9P209ZJVP80WIfM102IVIT209ZJVP80
UYJF0P2>SXh209FEU@80TI6A0P2BTY8209>CT`80T92@00<0RHV908R8R028R8P00P27QhL208R8R080
QhN70P26QXH208j>SP80Shn?0P2PX:020:JVYP80WinO0P2FUYH209:BTQh0b>3H000L0<SPf080ZJVY
0P2`/;0206e]K@80D51@0P1gMgL206YZJP80HF5Q0P1TI6@2071`L080QXJ60P2PX:020<c<c0030>3P
h031`L40`L710080De=C0P0Y:BT202LW9`809BDU0P0Z:RX202LW9`809RHV0P0Z:RX202h^;P80<C4a
0P0d=3@203hn?P80A4A40P0j>SX402h^;P@0<30`0P0_;bl202TY:@809BDU0P0R8R8202XZ:P80;Bd]
00<0Jf][07EeM@1eMGD00P1lO7`205=CD`80I6AT0P1FEUH2051@D080FEUI0P1VIVH206e]K@80LW9b
101cLg<207AdM080MgMg0P1hN7P207YjNP80Ng]k0P1lO7`207emO@80Ogmo0P21PH4208:2PP80P820
0P1oOgl00`20P800PX:208:2PP0208B4Q080QXJ60P28R8P208Z:RP80R8R80P26QXH208Z:RP80SXj>
0P2?Shl:092@T080TI6A0P2BTY8209>CT`80UIFE0P2GUiL209RHV080UiNG0P2EUID209VIV@80W9bL
00<0Vi^K09ZJVP2JVYX00P2KVi/209fMW@80VYZJ0P2HV9P209ZJVP80WYjN0P2OWil20:2PX080WinO
0P2NWYh209bLW080Vi^K102LW9`209ZJVP@0UiNG0P2FUYH209FEU@80Ti>C0P2ATI42092@T080SXj>
0P2<S8`00`28R8P0Q8B408B4Q00608>3P`80QHF50P27QhL208^;R`80TI6A0P2EUID208f=S@80QHF5
0P23Ph<W0<SPf080[Jf]0P2/[:`2079bLP80I6AT0P1eMGD206IVIP80Hf=S0P1/K6`2079bLP80Ph>3
0P2RXZ820=?Cd`80emOG0P30`<02059BDP0302DU9@0V9RH09RHV0080:RXZ0P0W9bL202@T90809RHV
0P0Y:BT202d];@80<C4a0P0h>3P203dm?@80@D510P0d=3@2030`<080<C4a0P0`<30202l_;`80<C4a
0P0W9bL202DU9@80:BTY0P0V9RH202h^;P80IfMW0P1fMWH207UiN@80GUiN0P1TI6@204];B`80EEEE
0P1KFe/206MWI`0306YZJP1cLg<0Lg=c0080M7Ad0P1cLg<207EeM@80MWIf0P1dM7@207]kN`80NGUi
0P1mOGd207inOP80OGem0P20P8020861P@80PX:20P1lO7`207moO`80Ph>30P26QXH208V9R@80QXJ6
1029RHT208N7Q`80RHV90P2>SXh208f=S@80Ti>C0P2>SXh208n?S`80TI6A0P2=SHd00`2ATI40TY:B
09:BTP0209>CT`80U9BD0P2GUiL209RHV080Ti>C0P2DU9@209^KV`@0VIVI102JVYX209jNWP80VYZJ
0P2FUYH209VIV@@0WYjN0P2OWil20::RXP80W9bL0P2HV9P209bLW080VIVI0P2MWId209ZJVP80UiNG
0P2LW9`209FEU@80TY:B0P2DU9@00`2?Shl0Ti>C09>CT`0208f=S@80S8b<0P26QXH208>3P`80Rh^;
0P22PX8208>3P`80QHF50P27QhL208f=S@80Shn?0P2FUYH208n?S`80Q8B40P26QXHW0<SPf080ZJVY
0P2_[jl206e]K@80DU9B0P1eMGD206][J`80HF5Q0P1SHf<206i^KP80R8R80P2OWil20=3@d0030>3P
h034a<@0a<C40080DE5A0P0Y:BT202LW9`8092@T0P0X:2P202HV9P809bLW0P0X:2P202d];@80<30`
0P0b<S820410@080@T920P0k>c/2030`<080:b/[100a<C4202l_;`80:b/[0P0W9bL201lO7`80:RXZ
0P0];Bd00`1[Jf/0LW9b079bLP0207emO@80F5QH0P1SHf<205EEE@80DU9B0P1HF5P206QXJ080Kfm_
0P1aLG4207AdM080LW9b0P1cLg<207EeM@80OGem0P1iNGT207YjNP80OGem0P1kNg/207moO`80Q8B4
0P20P80207inOP80PH610`20P80208J6QP80QHF50P27QhL208^;R`@0QXJ60P2:RXX208b<S080SHf=
0P2?Shl209>CT`80Shn?0P2=SHd209>CT`80TI6A0P2@T90209NGU`80U9BD0P2GUiL209RHV080UYJF
0P2DU9@209ZJVP80W9bL00<0UiNG09fMW@2MWId00P2JVYX209^KV`80VIVI0P2GUiL209^KV`80WIfM
0P2NWYh209fMW@80WinO0P2LW9`209nOW`80VYZJ0P2KVi/409bLW080UIFE0P2GUiL209BDU080V9RH
0P2BTY8208n?S`80SXj>0P2?Shl208f=S@<0QHF50P24Q8@20820P080Ph>30P24Q8@208f=S@80RHV9
0P2<S8`209BDU080Shn?0P24Q8@208>3Pah0b>3H000L0<SPf080ZJVY0P2`/;0206e]K@80D51@0P1g
MgL206YZJP80HF5Q0P1TI6@2071`L080QXJ60P2PX:020<c<c0030>3Ph031`L40`L710080De=C0P0Y
:BT202LW9`809BDU0P0Z:RX202LW9`809RHV0P0Z:RX202h^;P80<C4a0P0d=3@203hn?P80A4A40P0j
>SX402h^;P@0<30`0P0_;bl202TY:@809BDU0P0R8R8202XZ:P80;Bd]00<0Jf][07EeM@1eMGD00P1l
O7`205=CD`80I6AT0P1FEUH2051@D080FEUI0P1VIVH206e]K@80LW9b101cLg<207AdM080MgMg0P1h
N7P207YjNP80Ng]k0P1lO7`207emO@80Ogmo0P21PH4208:2PP80P8200P1oOgl00`20P800PX:208:2
PP0208B4Q080QXJ60P28R8P208Z:RP80R8R80P26QXH208Z:RP80SXj>0P2?Shl:092@T080TI6A0P2B
TY8209>CT`80UIFE0P2GUiL209RHV080UiNG0P2EUID209VIV@80W9bL00<0Vi^K09ZJVP2JVYX00P2K
Vi/209fMW@80VYZJ0P2HV9P209ZJVP80WYjN0P2OWil20:2PX080WinO0P2NWYh209bLW080Vi^K102L
W9`209ZJVP@0UiNG0P2FUYH209FEU@80Ti>C0P2ATI42092@T080SXj>0P2<S8`00`28R8P0Q8B408B4
Q00608>3P`80QHF50P27QhL208^;R`80TI6A0P2EUID208f=S@80QHF50P23Ph<W0<SPf080[Jf]0P2/
[:`2079bLP80I6AT0P1eMGD206IVIP80Hf=S0P1/K6`2079bLP80Ph>30P2RXZ820=?Cd`80emOG0P30
`<02059BDP0302DU9@0V9RH09RHV0080:RXZ0P0W9bL202@T90809RHV0P0Y:BT202d];@80<C4a0P0h
>3P203dm?@80@D510P0d=3@2030`<080<C4a0P0`<30202l_;`80<C4a0P0W9bL202DU9@80:BTY0P0V
9RH202h^;P80IfMW0P1fMWH207UiN@80GUiN0P1TI6@204];B`80EEEE0P1KFe/206MWI`0306YZJP1c
Lg<0Lg=c0080M7Ad0P1cLg<207EeM@80MWIf0P1dM7@207]kN`80NGUi0P1mOGd207inOP80OGem0P20
P8020861P@80PX:20P1lO7`207moO`80Ph>30P26QXH208V9R@80QXJ61029RHT208N7Q`80RHV90P2>
SXh208f=S@80Ti>C0P2>SXh208n?S`80TI6A0P2=SHd00`2ATI40TY:B09:BTP0209>CT`80U9BD0P2G
UiL209RHV080Ti>C0P2DU9@209^KV`@0VIVI102JVYX209jNWP80VYZJ0P2FUYH209VIV@@0WYjN0P2O
Wil20::RXP80W9bL0P2HV9P209bLW080VIVI0P2MWId209ZJVP80UiNG0P2LW9`209FEU@80TY:B0P2D
U9@00`2?Shl0Ti>C09>CT`0208f=S@80S8b<0P26QXH208>3P`80Rh^;0P22PX8208>3P`80QHF50P27
QhL208f=S@80Shn?0P2FUYH208n?S`80Q8B40P26QXHW0<SPf080ZJVY0P2_[jl206e]K@80DU9B0P1e
MGD206][J`80HF5Q0P1SHf<206i^KP80R8R80P2OWil20=3@d0030>3Ph034a<@0a<C40080DE5A0P0Y
:BT202LW9`8092@T0P0X:2P202HV9P809bLW0P0X:2P202d];@80<30`0P0b<S820410@080@T920P0k
>c/2030`<080:b/[100a<C4202l_;`80:b/[0P0W9bL201lO7`80:RXZ0P0];Bd00`1[Jf/0LW9b079b
LP0207emO@80F5QH0P1SHf<205EEE@80DU9B0P1HF5P206QXJ080Kfm_0P1aLG4207AdM080LW9b0P1c
Lg<207EeM@80OGem0P1iNGT207YjNP80OGem0P1kNg/207moO`80Q8B40P20P80207inOP80PH610`20
P80208J6QP80QHF50P27QhL208^;R`@0QXJ60P2:RXX208b<S080SHf=0P2?Shl209>CT`80Shn?0P2=
SHd209>CT`80TI6A0P2@T90209NGU`80U9BD0P2GUiL209RHV080UYJF0P2DU9@209ZJVP80W9bL00<0
UiNG09fMW@2MWId00P2JVYX209^KV`80VIVI0P2GUiL209^KV`80WIfM0P2NWYh209fMW@80WinO0P2L
W9`209nOW`80VYZJ0P2KVi/409bLW080UIFE0P2GUiL209BDU080V9RH0P2BTY8208n?S`80SXj>0P2?
Shl208f=S@<0QHF50P24Q8@20820P080Ph>30P24Q8@208f=S@80RHV90P2<S8`209BDU080Shn?0P24
Q8@208>3Pah0b>3H000L0<SPf080QhN70P2TY:@209NGU`80L71`0P1]KFd206][J`80L71`0P1aLG42
07EeM@80OGem0P2<S8`20;2`/0030<_;b`3:b/X0b/[:0080UYJF0P0J6QX203<c<`808B4Q0P0V9RH2
02<S8`8092@T0P0W9bL202d];@80>3Ph0P12@T8204Q8B080BDU90P10@40203De=@80;bl_100[:b/2
02`/;080:b/[0P0Z:RX202TY:@80<C4a0P0];Bd00`1UIFD0LW9b079bLP0207]kN`80HF5Q0P1OGel2
05ADE080D51@0P1IFET206IVIP80Jf][0P1_Kfl2079bLP80Lg=c0P1dM7@207EeM@80N7Qh0P1kNg/2
07emO@80OWin101mOGd207moO`80PH610P22PX850861P@80Q8B40P26QXH208R8R080RHV90P28R8P2
08N7Q`80S8b<102ATI42092@T0@0TI6A2P2BTY8209>CT`80UIFE1P2FUYH209RHV080Vi^K00<0VIVI
09NGU`2GUiL00P2JVYX209bLW080Vi^K0P2JVYX209fMW@@0WinO0P2MWId409jNWP80WIfM0P2KVi/2
09ZJVP80VIVI0P2GUiL409JFUP80UIFE0P2BTY8208j>SP80S8b<0P2;Rh/208R8R080QHF500<0PH61
07inOP1nOWh00P20P80208:2PP80Ph>30P24Q8@208F5Q@80QhN70P29RHT208Z:RP80Ph>30P1lO7`2
07YjNRL0b>3H0P27QhL209NGU`80U9BD0P1QHF4206YZJP80M7Ad0P1[Jf/206a/K080Kfm_0P1cLg<2
08B4Q080^k^k103?cll209fMW@0302d];@0Y:BT0:BTY00809BDU0P0/;2`202<S8`80:BTY0P0Z:RX2
038b<P80>SXj0P13@d<204i>CP80FUYJ0P0d=3@203De=@80<C4a0P0Z:RX202LW9`80<30`0P0S8b<2
02XZ:P80:b/[0P0_;bl203De=@80Hf=S0P1mOGd207EeM@@0Hf=S0P1?Cdl2059BDP80FEUI0P1YJFT0
0`1`L700LG5a075aL@0206m_K`80LG5a0P1eMGD407QhN080NWYj0P1mOGd207YjNP80Ogmo1021PH42
07moO`80PX:20P24Q8@207moO`80PX:20P26QXH208F5Q@80QhN70P2;Rh/208b<S080QXJ60P2<S8`2
09:BTP80TI6A0P2=SHd2096AT@80SXj>0P2DU9@309>CT`80T92@0P2DU9@209>CT`80UIFE0P2JVYX2
09BDU080UYJF0P2NWYh209fMW@80V9RH0P2JVYX209NGU`80WIfM0P2PX:0209fMW@80W9bL0P2OWil2
09jNWP@0WinO0P2NWYh209nOW`80W9bL0P2MWId209RHV080UiNG0P2ATI4209FEU@80U9BD0P2EUID2
08n?S`0308f=S@29RHT0RHV90080SXj>0P28R8P207moO`80OGem0P20P80207moO`80P8200P22PX82
0820P080QHF50P27QhL208R8R080PH610P1fMWH207UiNBL0b>3H0P2:RXX20::RXP80VIVI0P1`L702
06e]K@@0L71`0P1aLG4207MgM`80OWin0P2:RXX20:n_[`030<W9b@37alL0alO70080UYJF0P0G5aL2
030`<0808b<S0P0[:b/202DU9@@0:2PX0P0a<C4203Ph>080@d=30P1:BTX204Q8B080A4A40P0e=CD2
02l_;`80:b/[0P0/;2`202XZ:P80;Bd]0P0W9bL202XZ:P80<c<c0P0^;Rh00`1YJFT0Lg=c07=cL`02
07YjNP80HV9R0P1OGel2059BDP80DE5A0P1HF5P206IVIP80K6a/0P1aLG42071`L080LW9b0P1fMWH2
07EeM@80OGem0P1kNg/207YjNP80Ogmo0P1iNGT207inOP@0PX:20P21PH420820P00308>3P`20P800
P8200080Q8B40P26QXH208B4Q080RXZ:0P28R8P208V9R@80S8b<0P2DU9@208n?S`80TI6A0P2GUiL4
092@T080TY:B102ATI4209FEU@80TI6A0P2DU9@209RHV080UYJF0P2GUiL409ZJVP0309RHV02GUiL0
UiNG0080Vi^K0P2PX:0209NGU`80WIfM102KVi/20:BTY080XJ6Q0P2LW9`209^KV`80VIVI0P2NWYh2
09NGU`@0VYZJ102HV9P209JFUP80Ti>C0P2=SHd2092@T080S8b<0P27QhL208J6QP030820P01oOgl0
Ogmo0080PH610P25QHD20861P@80PX:21027QhL208b<S080RXZ:0P24Q8@407YjNQh0b>3H000L0<SP
f080QhN70P2TY:@209NGU`80L71`0P1]KFd206][J`80L71`0P1aLG4207EeM@80OGem0P2<S8`20;2`
/0030<_;b`3:b/X0b/[:0080UYJF0P0J6QX203<c<`808B4Q0P0V9RH202<S8`8092@T0P0W9bL202d]
;@80>3Ph0P12@T8204Q8B080BDU90P10@40203De=@80;bl_100[:b/202`/;080:b/[0P0Z:RX202TY
:@80<C4a0P0];Bd00`1UIFD0LW9b079bLP0207]kN`80HF5Q0P1OGel205ADE080D51@0P1IFET206IV
IP80Jf][0P1_Kfl2079bLP80Lg=c0P1dM7@207EeM@80N7Qh0P1kNg/207emO@80OWin101mOGd207mo
O`80PH610P22PX850861P@80Q8B40P26QXH208R8R080RHV90P28R8P208N7Q`80S8b<102ATI42092@
T0@0TI6A2P2BTY8209>CT`80UIFE1P2FUYH209RHV080Vi^K00<0VIVI09NGU`2GUiL00P2JVYX209bL
W080Vi^K0P2JVYX209fMW@@0WinO0P2MWId409jNWP80WIfM0P2KVi/209ZJVP80VIVI0P2GUiL409JF
UP80UIFE0P2BTY8208j>SP80S8b<0P2;Rh/208R8R080QHF500<0PH6107inOP1nOWh00P20P80208:2
PP80Ph>30P24Q8@208F5Q@80QhN70P29RHT208Z:RP80Ph>30P1lO7`207YjNRL0b>3H0P27QhL209NG
U`80U9BD0P1QHF4206YZJP80M7Ad0P1[Jf/206a/K080Kfm_0P1cLg<208B4Q080^k^k103?cll209fM
W@0302d];@0Y:BT0:BTY00809BDU0P0/;2`202<S8`80:BTY0P0Z:RX2038b<P80>SXj0P13@d<204i>
CP80FUYJ0P0d=3@203De=@80<C4a0P0Z:RX202LW9`80<30`0P0S8b<202XZ:P80:b/[0P0_;bl203De
=@80Hf=S0P1mOGd207EeM@@0Hf=S0P1?Cdl2059BDP80FEUI0P1YJFT00`1`L700LG5a075aL@0206m_
K`80LG5a0P1eMGD407QhN080NWYj0P1mOGd207YjNP80Ogmo1021PH4207moO`80PX:20P24Q8@207mo
O`80PX:20P26QXH208F5Q@80QhN70P2;Rh/208b<S080QXJ60P2<S8`209:BTP80TI6A0P2=SHd2096A
T@80SXj>0P2DU9@309>CT`80T92@0P2DU9@209>CT`80UIFE0P2JVYX209BDU080UYJF0P2NWYh209fM
W@80V9RH0P2JVYX209NGU`80WIfM0P2PX:0209fMW@80W9bL0P2OWil209jNWP@0WinO0P2NWYh209nO
W`80W9bL0P2MWId209RHV080UiNG0P2ATI4209FEU@80U9BD0P2EUID208n?S`0308f=S@29RHT0RHV9
0080SXj>0P28R8P207moO`80OGem0P20P80207moO`80P8200P22PX820820P080QHF50P27QhL208R8
R080PH610P1fMWH207UiNBL0b>3H0P2:RXX20::RXP80VIVI0P1`L70206e]K@@0L71`0P1aLG4207Mg
M`80OWin0P2:RXX20:n_[`030<W9b@37alL0alO70080UYJF0P0G5aL2030`<0808b<S0P0[:b/202DU
9@@0:2PX0P0a<C4203Ph>080@d=30P1:BTX204Q8B080A4A40P0e=CD202l_;`80:b/[0P0/;2`202XZ
:P80;Bd]0P0W9bL202XZ:P80<c<c0P0^;Rh00`1YJFT0Lg=c07=cL`0207YjNP80HV9R0P1OGel2059B
DP80DE5A0P1HF5P206IVIP80K6a/0P1aLG42071`L080LW9b0P1fMWH207EeM@80OGem0P1kNg/207Yj
NP80Ogmo0P1iNGT207inOP@0PX:20P21PH420820P00308>3P`20P800P8200080Q8B40P26QXH208B4
Q080RXZ:0P28R8P208V9R@80S8b<0P2DU9@208n?S`80TI6A0P2GUiL4092@T080TY:B102ATI4209FE
U@80TI6A0P2DU9@209RHV080UYJF0P2GUiL409ZJVP0309RHV02GUiL0UiNG0080Vi^K0P2PX:0209NG
U`80WIfM102KVi/20:BTY080XJ6Q0P2LW9`209^KV`80VIVI0P2NWYh209NGU`@0VYZJ102HV9P209JF
UP80Ti>C0P2=SHd2092@T080S8b<0P27QhL208J6QP030820P01oOgl0Ogmo0080PH610P25QHD20861
P@80PX:21027QhL208b<S080RXZ:0P24Q8@407YjNQh0b>3H000L0<SPf080I6AT0P1/K6`207QhN080
L71`0P1VIVH207=cL`80PX:20P23Ph<20820P080Ogmo0P22PX8209VIV@030;2`/02l_;`0_;bl0080
^KVi0P1HF5P2034a<@808B4Q0P0W9bL202<S8`8092@T0P0U9BD202/[:`80?Cdm0P1=CDd204i>CP80
BDU90P13@d<203/k>`80<C4a100X:2P202/[:`80;Bd]0P0a<C42030`<080=cLg0P0];Bd00`1OGel0
Kfm_06m_K`0207UiN@80KFe]0P1JFUX2059BDP80D51@0P1JFUX206EUI@80JFUY0P1/K6`2071`L0@0
M7Ad0P1eMGD207UiN@80OGem101oOgl207emO@80O7al0P1mOGd20820P080PX:20P24Q8@00`23Ph<0
PH610861P@0208B4Q080QhN70P28R8P208V9R@@0R8R80P2>SXh209>CT`80TY:B0P2@T902096AT@80
Ti>C0P2DU9@209FEU@80Ti>C0P2BTY84092@T080TY:B0P2EUID209JFUP80UiNG0P2IVIT209ZJVP03
09RHV02FUYH0UYJF0080VIVI0P2LW9`209fMW@80WYjN0P2PX:020:6QX@80WYjN0P2KVi/209fMW@@0
WYjN0P2LW9`209RHV0H0UIFE0P2DU9@209:BTP80SHf=0P28R8P208J6QP80QHF50P22PX8207inOP03
07]kN`1jNWX0NWYj0080OGem0P21PH4208>3P`P0Q8B40P23Ph<207alO080MWIf0P1dM7@W0<SPf080
H61P0P1_Kfl207inOP@0KFe]0P1jNWX207moO`@0Q8B40P1jNWX208N7Q`80Vi^K0P2e]KD20;Bd]080
]kNg00<0Hf=S034a<@0a<C400P0W9bL402<S8`8092@T0P0V9RH202XZ:P80>c/k0P1BDU8404];B`80
ATI60P15ADD402`/;0@0;Bd]0P0W9bL203<c<`80>c/k0P0d=3@202`/;080EeMG0P1aLG4207UiN@80
J6QX0P1MGEd205=CD`80DE5A0P1LG5`2065QH@0306UYJ@1[Jf/0Jf][0080L71`0P1gMgL207IfMP80
M7Ad0P1fMWH407inOP80Ogmo0P1nOWh207]kN`80OWin0P1oOgl208R8R080PH610P25QHD20820P0@0
QXJ60P27QhL208J6QP80S8b<0P27QhL208f=S@80U9BD0P2BTY8208n?S`@0TI6A0P2HV9P209:BTP03
09BDU02@T900T92@0080U9BD0P2ATI4209FEU@80U9BD0P2CTi<209RHV080W9bL0P2JVYX209>CT`80
UiNG0P2HV9P209fMW@80W9bL0P2MWId209jNWP80WinO0P2SXj<209RHV080Vi^K102NWYh209ZJVP80
UiNG0P2DU9@209JFUP80V9RH102CTi<208f=S@D0QXJ60P22PX8207emO@@0NWYj0P20P80408:2PP80
QhN70P24Q8@408J6QP80PX:20P1lO7`207AdM080MgMg9`38h=P206EUI@80JVYZ0P1iNGT2071`L080
IVIV0P1aLG420820P080PX:20P20P80207alO080Q8B40P2LW9`00`2`/;00_Kfm0;fm_@020;Vi^@80
Fe]K0P0a<C42020P80809BDU100R8R8202HV9P80;2`/0P0j>SX204i>CP80CDe=1015ADD203Xj>P80
;Rh^0P0X:2P202XZ:P80:BTY100a<C4202l_;`80=SHf0P0^;Rh00`1NGUh0K6a/06a/K00207emO@80
J6QX0P1MGEd205ADE080Cdm?0P1JFUX206EUI@80K6a/101]KFd207=cL`@0M7Ad0P1fMWH207emO@80
Ogmo0P20P80207emO@@0O7al0P1mOGd208B4Q0D0Ph>30P25QHD208N7Q`80Rh^;0P28R8P208V9R@80
R8R80P2<S8`809:BTP80TI6A0P2GUiL209BDU080Ti>C0P2ATI4209>CT`80TI6A0P2@T90209JFUP80
U9BD0P2FUYH209NGU`80VIVI00<0Vi^K09FEU@2EUID00P2FUYH209^KV`80X:2P0P2NWYh20:2PX080
XJ6Q0P2OWil209VIV@80Vi^K0P2QXJ4209^KV`80WinO0P2EUID209BDU080UYJF0P2EUID2096AT@80
Ti>C0P2ATI4408J6QP80Q8B40P21PH4207inOP0307moO`1hN7P0N7Qh0080O7al0P20P80208:2PP80
QhN71024Q8@208F5Q@80Q8B40P1iNGT207IfMP80NGUi7P38h=P001`0b>3H0P1TI6@206a/K080N7Qh
0P1`L70206IVIP80Lg=c0P22PX8208>3P`80P8200P1oOgl208:2PP80VIVI00<0/;2`0;bl_02l_;`0
0P2i^KT205QHF080<C4a0P0Q8B4202LW9`808b<S0P0T92@202DU9@80:b/[0P0m?Cd204e=C@80CTi>
0P19BDT204=3@`80>c/k0P0a<C4402PX:080:b/[0P0];Bd2034a<@80<30`0P0g=cL202d];@0305mO
G`1_Kfl0Kfm_0080NGUi0P1]KFd205YJFP80DU9B0P1@D50205YJFP80IFEU0P1YJFT206a/K080L71`
101dM7@207EeM@80NGUi0P1mOGd407moO`80OGem0P1lO7`207emO@80P8200P22PX8208B4Q00308>3
P`21PH40PH610080Q8B40P27QhL208R8R080RHV91028R8P208j>SP80Ti>C0P2BTY82092@T080TI6A
0P2CTi<209BDU080UIFE0P2CTi<209:BTP@0T92@0P2BTY8209FEU@80UYJF0P2GUiL209VIV@80VYZJ
00<0V9RH09JFUP2FUYH00P2IVIT209bLW080WIfM0P2NWYh20:2PX080XJ6Q0P2NWYh209^KV`80WIfM
102NWYh209bLW080V9RH1P2EUID209BDU080TY:B0P2=SHd208R8R080QXJ60P25QHD208:2PP80OWin
00<0Ng]k07YjNP1jNWX00P1mOGd20861P@80Ph>32024Q8@208>3P`80O7al0P1fMWH207AdM2L0b>3H
0P1PH60206m_K`80OWin101]KFd207YjNP80Ogmo1024Q8@207YjNP80QhN70P2KVi/20;Fe]@80];Bd
0P2g]kL00`1SHf<0<C4a034a<@0202LW9`@08b<S0P0T92@202HV9P80:RXZ0P0k>c/2059BDP@0Bd];
0P16ATH204E5A@@0;2`/100];Bd202LW9`80<c<c0P0k>c/203@d=080;2`/0P1GEeL2075aL@80NGUi
0P1XJ6P205eMG@80De=C0P1ADE4205aLG080HF5Q00<0JFUY06][J`1[Jf/00P1`L70207MgM`80MWIf
0P1dM7@207IfMP@0OWin0P1oOgl207inOP80Ng]k0P1nOWh207moO`80R8R80P21PH4208F5Q@80P820
1026QXH208N7Q`80QXJ60P2<S8`208N7Q`80SHf=0P2DU9@209:BTP80Shn?102ATI4209RHV080TY:B
00<0U9BD092@T02@T9000P2DU9@2096AT@80UIFE0P2DU9@209>CT`80V9RH0P2LW9`209ZJVP80Ti>C
0P2GUiL209RHV080WIfM0P2LW9`209fMW@80WYjN0P2OWil20:>SX`80V9RH0P2KVi/409jNWP80VYZJ
0P2GUiL209BDU080UYJF0P2HV9P409>CT`80SHf=1@26QXH208:2PP80OGem101jNWX20820P0@0PX:2
0P27QhL208B4Q0@0QXJ60P22PX8207alO080M7Ad0P1gMgLW0<SPf080IFEU0P1ZJVX207UiN@80L71`
0P1VIVH2075aL@80P8200P22PX820820P080O7al0P24Q8@209bLW0030;2`/02m_Kd0_Kfm0080^KVi
0P1KFe/2034a<@80820P0P0U9BD4028R8P809RHV0P0/;2`203Xj>P80CTi>0P1=CDd404E5A@80>SXj
0P0^;Rh202PX:080:RXZ0P0Y:BT4034a<@80;bl_0P0f=SH202h^;P0305iNGP1/K6`0K6a/0080OGem
0P1XJ6P205eMG@80E5AD0P1?Cdl205YJFP80IFEU0P1/K6`406e]K@80Lg=c101dM7@207IfMP80OGem
0P1oOgl20820P080OGem101lO7`207emO@80Q8B41@23Ph<208F5Q@80QhN70P2;Rh/208R8R080RHV9
0P28R8P208b<S0P0TY:B0P2ATI4209NGU`80U9BD0P2CTi<2096AT@80Ti>C0P2ATI42092@T080UYJF
0P2DU9@209JFUP80UiNG0P2IVIT00`2KVi/0UIFE09FEU@0209JFUP80Vi^K0P2PX:0209jNWP80X:2P
0P2QXJ4209nOW`80VIVI0P2KVi/20:6QX@80Vi^K0P2OWil209FEU@80U9BD0P2FUYH209FEU@80TI6A
0P2CTi<2096AT@@0QXJ60P24Q8@20861P@80OWin00<0Ogmo07QhN01hN7P00P1lO7`20820P080PX:2
0P27QhL408B4Q080QHF50P24Q8@207UiN@80MWIf0P1iNGTN0<SPf0007038h=P204Q8B080D51@0P1S
Hf<2079bLP80MgMg0P21PH4208Z:RP80SXj>0P2ATI4209>CT`80UiNG0P2SXj<00`2_[jl0]kNg0;Ng
]`020;Bd]080YjNW0P1PH60204a<C0808b<S0P0R8R8202HV9P809BDU0P0W9bL203<c<`80?Shn0P0m
?Cd203Ti>@80=cLg0P0e=CD202l_;`@0:RXZ0P0/;2`202d];@80<30`0P0];Bd203<c<`80;Bd]00<0
HV9R06i^KP1^KVh00P1dM7@206QXJ080E5AD0P1?Cdl2055AD@80Fe]K0P1WIfL206YZJP80K6a/0P1`
L70607AdM080N7Qh2P1mOGd207moO`80P8200P22PX8508B4Q080QXJ60P28R8P408V9R@80Rh^;0P2=
SHd2092@T080TY:B0P2ATI42092@T080TI6A0P2BTY8209BDU080UYJF0P2EUID209BDU080TY:B0P2A
TI4209BDU080UiNG0P2HV9P909VIV@80VYZJ0P2LW9`209fMW@80WinO102PX:0209jNWP80W9bL0P2M
WId209nOW`80WIfM0P2JVYX209JFUP80Ti>C0P2DU9@209FEU@80Ti>C0P2@T90208R8R080PH610P1n
OWh707emO@80OWin0P21PH4208B4Q0@0QHF51026QXH208F5Q@80PX:20P1kNg/207AdM080LW9b9`38
h=P204a<C080GUiN0P1TI6@4071`L080Ng]k0P2;Rh/209BDU080UYJF0P2DU9@209VIV@80WinO0P2X
Z:P20:BTY080[Zj^00<0WYjN05mOG`1OGel00P0g=cL202LW9`809RHV0P0P820202<S8`80:2PX0P0^
;Rh203Ph>080?3`l0P0/;2`2034a<@80;bl_0P0[:b/202XZ:P80:b/[0P0a<C4202HV9P@0;bl_0P0Z
:RX2034a<@80Hf=S0P1dM7@207=cL`80J6QX0P1BDU8204Y:BP80D51@0P1NGUh206IVIP0306a/K01X
J6P0J6QX0080M7Ad0P1_Kfl2075aL@80MGEe0P1gMgL20820P080OWin0P21PH4407]kN`80O7al0P20
P80207moO`@0PX:20P21PH4408R8R080RXZ:0P29RHT208Z:RP80Rh^;0P2@T90208j>SP80UIFE0P2C
Ti<209:BTP80U9BD0P2CTi<309FEU@80Ti>C0P2ATI4208N7Q`@0UYJF0P2CTi<209JFUP80VYZJ0P2G
UiL209JFUP80W9bL0P2HV9P209^KV`80WYjN0P2LW9`20:6QX@80WinO0P2NWYh209ZJVP80X:2P0P2N
WYh209ZJVP80W9bL0P2EUID409BDU080UIFE0P2BTY82092@T080RHV90P22PX800`1nOWh0Ng]k07]k
N`0207YjNP80OWin0P1lO7`20820P080PX:20P24Q8@208N7Q`80Q8B41026QXH208F5Q@80Q8B40P1n
OWh407MgMbL0b>3H0P18B4P205ADE080HF5Q0P1cLg<207IfMP80PH610P2<S8`6096AT@80UYJF0P2R
XZ800`2_[jl0^;Rh0;Rh^0020;6a/@80ZJVY0P1QHF4204m?C`808R8R0P0P820202DU9@808b<S0P0W
9bL2030`<080?clo0P0n?Sh203`l?080>3Ph0P0d=3@2030`<080:2PX0P0/;2`202PX:080<C4a0P0]
;Bd202/[:`80<C4a0P0_;bl00`1RHV80KFe]06e]K@0207IfMP80IVIV0P1BDU82051@D080DU9B0P1J
FUX206MWI`80JFUY0P1[Jf/206m_K`80NWYj0P1dM7@207=cL`80N7Qh0P1mOGd20820P080OWin0P1m
OGd207inOP80Ogmo0P21PH4208N7Q`80Q8B400<0Ogmo0861P@21PH401P27QhL208^;R`80R8R80P2<
S8`209:BTP80UYJF0P2>SXh208^;R`80Shn?0P2@T90209RHV080UYJF102CTi<2096AT@80T92@0P2D
U9@209NGU`80VIVI0P2MWId209VIV@80VYZJ1@2IVIT209^KV`80WYjN0P2LW9`209fMW@80WYjN0P2R
XZ8209VIV@80WYjN0P2SXj<209bLW080Vi^K0P2HV9P209>CT`80UiNG102ATI4208f=S@80QXJ60P22
PX8407emO@80Ogmo0P1iNGT00`1mOGd0OWin07inOP0208F5Q@80Q8B40P26QXH20861P@80QHF50P26
QXH208:2PP80PH610P1jNWX207AdM080LG5a7P38h=P001`0b>3H0P18B4P2051@D080Hf=S0P1bLW82
07MgM`80PH610P2:RXX208j>SP80TI6A0P2CTi<209NGU`80Xj>S00<0[jn_0;Ng]`2g]kL00P2d];@2
0:NWY`80H61P0P1<C4`202<S8`808R8R0P0V9RH202DU9@809bLW0P0c<c<203hn?P80?Cdm0P0i>CT2
03Lg=`80=CDe0P0_;bl402XZ:P80;2`/0P0];Bd2030`<080;Bd]0P0c<c<202d];@03069RHP1^KVh0
KVi^0080M7Ad0P1XJ6P205ADE080Cdm?0P1ADE4205]KF`80IfMW0P1ZJVX206a/K080L71`1P1dM7@2
07QhN0X0OGem0P1oOgl20820P080PX:21@24Q8@208J6QP80R8R81029RHT208^;R`80SHf=0P2@T902
09:BTP80TI6A0P2@T902096AT@80TY:B0P2DU9@209JFUP80UIFE0P2DU9@209:BTP80TI6A0P2DU9@2
09NGU`80V9RH2@2IVIT209ZJVP80W9bL0P2MWId209nOW`@0X:2P0P2NWYh209bLW080WIfM0P2OWil2
09fMW@80VYZJ0P2FUYH209>CT`80U9BD0P2EUID209>CT`80T92@0P28R8P20861P@80OWin1`1mOGd2
07inOP80PH610P24Q8@408F5Q@@0QXJ60P25QHD208:2PP80Ng]k0P1dM7@2079bLRL0b>3H0P1<C4`2
05iNGP80I6AT101`L70207]kN`80Rh^;0P2DU9@209JFUP80U9BD0P2IVIT209nOW`80Z:RX0P2TY:@2
0:j^[P0309jNWP1OGel0GemO0080=cLg0P0W9bL202HV9P80820P0P0S8b<202PX:080;Rh^0P0h>3P2
03`l?080;2`/0P0a<C4202l_;`80:b/[0P0Z:RX202/[:`80<C4a0P0V9RH402l_;`80:RXZ0P0a<C42
06=SH`80M7Ad0P1cLg<206QXJ080DU9B0P1:BTX2051@D080GUiN0P1VIVH00`1/K6`0J6QX06QXJ002
07AdM080Kfm_0P1aLG4207EeM@80MgMg0P20P80207inOP80PH61101kNg/207alO080P8200P1oOgl4
08:2PP80PH611028R8P208Z:RP80RHV90P2:RXX208^;R`80T92@0P2>SXh209FEU@80Ti>C0P2BTY82
09BDU080Ti>C0`2EUID209>CT`80TI6A0P27QhL409JFUP80Ti>C0P2FUYH209ZJVP80UiNG0P2FUYH2
09bLW080V9RH0P2KVi/209jNWP80W9bL0P2QXJ4209nOW`80WYjN0P2JVYX20:2PX080WYjN0P2JVYX2
09bLW080UIFE102DU9@209FEU@80TY:B0P2@T90208V9R@80PX:200<0OWin07]kN`1kNg/00P1jNWX2
07inOP80O7al0P20P80208:2PP80Q8B40P27QhL208B4Q0@0QXJ60P25QHD208B4Q080OWin101gMgLW
0<SPf080B4Q80P1DE5@2065QH@80Lg=c0P1fMWH20861P@80S8b<1P2ATI4209JFUP80XZ:R00<0[jn_
0;Rh^02h^;P00P2a/K420:VYZ@80HF5Q0P1?Cdl2028R8P80820P0P0U9BD202<S8`809bLW0P0`<302
03lo?`80?Shn0P0l?3`203Ph>080=3@d0P0`<30202PX:080;2`/0P0X:2P2034a<@80;Bd]0P0[:b/2
034a<@80;bl_00<0HV9R06e]K@1]KFd00P1fMWH206IVIP80DU9B0P1@D502059BDP80FUYJ0P1WIfL2
06UYJ@80Jf][0P1_Kfl207YjNP80M7Ad0P1cLg<207QhN080OGem0P20P80207inOP80OGem0P1nOWh2
07moO`80PH610P27QhL208B4Q00307moO`21PH40PH6100H0QhN70P2;Rh/208R8R080S8b<0P2BTY82
09JFUP80SXj>0P2;Rh/208n?S`80T92@0P2HV9P209JFUP@0Ti>C0P2ATI42092@T080U9BD0P2GUiL2
09VIV@80WIfM0P2IVIT209ZJVPD0VIVI0P2KVi/209jNWP80W9bL0P2MWId209jNWP80XZ:R0P2IVIT2
09jNWP80Xj>S0P2LW9`209^KV`80V9RH0P2CTi<209NGU`@0TI6A0P2=SHd208J6QP80PX:2101mOGd2
07moO`80NGUi00<0OGem07inOP1nOWh00P25QHD208B4Q080QXJ60P21PH4208F5Q@80QXJ60P22PX82
0861P@80NWYj0P1dM7@2075aLAh0b>3H000L0<SPf080<c<c0P0g=cL204E5A@80J6QX0P28R8P208n?
S`80T92@0P2IVIT20::RXP80ZZZZ0P2a/K430;:b/P80^k^k0P31`L420;6a/@80Zj^[0P25QHD202DU
9@80820P0P0W9bL202HV9P809BDU0P0X:2P202`/;080:RXZ0P0Y:BT202XZ:PH0;2`/0P0];Bd602h^
;P80:BTY0P0];Bd202`/;00306EUI@1^KVh0KVi^0080L71`0P1PH60204m?C`80CDe=0P1BDU8205aL
G080IfMW0P1ZJVX206a/K080L71`101dM7@207=cL`80N7Qh0P1lO7`207]kN`80NWYj0P1lO7`207mo
O`80P8200P21PH4208:2PP80Ph>300<0Q8B408J6QP26QXH00P28R8P608V9R@80SHf=102ATI44092@
T080TI6A0P2@T902096AT@80U9BD0P2FUYH209NGU`80UYJF0P2EUID209>CT`80UYJF0P2IVIT409^K
V`80VYZJ0P2IVIT00`2KVi/0W9bL09bLW00209bLW080Vi^K0P2MWId409nOW`80WYjN102MWId209jN
WP80WinO0P2LW9`209RHV080UIFE102CTi<209BDU080TY:B0P2=SHd208>3P`80NWYj0P1gMgL207Qh
N080Ng]k0P1nOWh00`20P800PH610861P@020861P@H0P8200P22PX8208B4Q080Ph>30P20P80207Ui
N@80LG5a0P1`L70W0<SPf080;2`/0P0k>c/204I6AP80JFUY0P2=SHd208V9R@80Ti>C0P2IVIT20:6Q
X@@0[Jf]0P2a/K420;Jf]P80_[jn0P30`<000`2i^KT0[Zj^0:j^[P020861P@80:BTY0P0U9BD202HV
9P809bLW0P0T92@202XZ:P80;bl_0P0[:b/202`/;080=3@d0P0^;Rh202`/;080;Rh^0P0_;bl2038b
<P80:2PX0P0a<C4202`/;080<C4a0P0`<302061PH080KVi^0P1]KFd206ATI080CDe=0P1>CTh2051@
D080Hf=S0P1UIFD00`1VIVH0K6a/06a/K00207EeM@80MgMg0P1aLG4207EeM@80MWIf101mOGd207Qh
N080OWin0P21PH420820P080Ph>30P22PX8208>3P`@0QHF50P2:RXX208R8R080QXJ60P2:RXX208j>
SP80TI6A0P2@T90209>CT`80S8b<102?Shl2092@T080UIFE0P2GUiL00`2EUID0UiNG09NGU`0209FE
U@80UYJF0P2MWId209NGU`80VYZJ0P2LW9`209fMW@80VIVI0P2JVYX209bLW080VYZJ0P2KVi/209nO
W`80WYjN0P2PX:0409fMW@80W9bL0P2NWYh20::RXP80Vi^K0P2GUiL209RHV080TI6A102DU9@4092@
T080PH610P1kNg/00`1dM7@0N7Qh07QhN00207emO@@0Ogmo0P23Ph<207moO`80P8200P1lO7`207in
OP80Ph>30P1oOgl20861P@80OGem0P1gMgL206m_K`80KVi^9`38h=P2030`<080>CTi0P13@d<206QX
J080QhN7102?Shl209^KV`80XJ6Q0P2YZJT20;:b/P80/k>c00<0/[:b0;fm_@2m_Kd00P32`/820;2`
/080[:b/0P24Q8@202DU9@808R8R0P0U9BD202LW9`@09RHV0P0];Bd202XZ:P@09bLW0P0];Bd202`/
;080:RXZ1P0];Bd202h^;P@0:b/[0P0a<C400`1TI6@0J6QX06QXJ00206i^KP80Hf=S0P1=CDd4051@
D080GemO0P1UIFD206YZJP80K6a/0P1^KVh4079bLP80Lg=c0P1eMGD207YjNP80P8200P1gMgL207Ui
N@80Ogmo0P21PH4207moO`80PH610P24Q8@00`23Ph<0QhN708N7Q`0208V9R@80S8b<0P26QXH208^;
R`80SXj>0P2ATI4608n?S`80U9BD0P2ATI4208n?S`@0UiNG0P2CTi<409RHV080U9BD0P2EUID209bL
W080UIFE0P2MWId209bLW080V9RH00<0VIVI09^KV`2KVi/00P2LW9`209VIV@80X:2P0P2QXJ4409nO
W`80WYjN0P2IVIT20:>SX`80Vi^K0P2NWYh209JFUP80UiNG0P2ATI4209:BTP80Ti>C0P2FUYH208b<
S080QHF50P1jNWX207EeM@80MWIf0P22PX8307inOP80PX:20P20P8020861P@80OGem0P1oOgl208J6
QP80PH610P23Ph<20820P080N7Qh101bLW8N0<SPf0007038h=P202LW9`8092@T0P0_;bl204e=C@80
SXj>0P2EUID209nOW`80Y:BT0P2YZJT20;>c/`80_;bl0P2k^k/00`2h^;P0_Kfm0;fm_@020<71`@80
`l?30P2i^KT209nOW`80?Shn0P0W9bL2020P80808B4Q0P0U9BD202LW9`80:2PX0P0W9bL202DU9@80
9bLW0P0Z:RX202`/;080;bl_100`<30202l_;`80;Rh^0P0X:2P202/[:`80:2PX00<0H61P06e]K@1]
KFd00P1bLW82061PH0@0CDe=0P1DE5@205eMG@80IFEU0P1WIfL206QXJ080K6a/0P1`L702079bLP80
M7Ad0P1gMgL207YjNP80Ng]k101lO7`207emO@80P8201P22PX800`23Ph<0QHF508F5Q@0208N7Q`80
R8R80P29RHT208Z:RP80S8b<0P2?Shl:096AT@80Ti>C0P2EUID409NGU`@0UYJF0P2EUID209JFUP80
UiNG0P2IVIT209ZJVP@0Vi^K00<0WIfM09jNWP2NWYh00P2NWYh209fMW@`0WYjN102OWil209^KV`80
UYJF0P2EUID409BDU080TY:B0P2?Shl208V9R@80Ogmo0P1fMWH207QhN080O7al0P20P80208:2PP03
07alO01dM7@0M7Ad0080JVYZ0P1RHV82061PH080HV9R0P1ZJVX2079bLP80L71`0P1/K6`206IVIP80
HF5Q0P1PH60W0<SPf0808R8R0P0O7al202<S8`80DE5A0P2BTY8209NGU`80WYjN102RXZ820:n_[`80
`/;20P2i^KT20;jn_P80`<300P37alL00`36a/H0_;bl0;bl_0020::RXP80?3`l0P0S8b<202DU9@80
8b<S0P0W9bL202PX:080:BTY1P0W9bL402/[:`80;bl_0P0];Bd202h^;P@0;bl_0P0Y:BT202@T9080
:BTY0P1OGel206][J`80L71`0P1VIVH204e=C@80CTi>0P1CDe<205mOG`80IVIV00<0Hf=S06YZJP1Z
JVX00P1/K6`2071`L080Kfm_0P1hN7P207EeM@80N7Qh101jNWX407emO@80OWin0P23Ph<208:2PP80
Ph>30P24Q8@208>3P`80RHV90P28R8P208Z:RP80R8R81P2@T90209:BTP80T92@0P2DU9@209:BTP80
TI6A0P2GUiL209JFUP0309RHV02FUYH0UYJF0080UYJF0P2CTi<209FEU@80VIVI0P2GUiL209ZJVP80
WinO0P2LW9`209^KV`80WinO0P2MWId209nOW`80WIfM0P2NWYh20:2PX080WIfM102OWil209jNWP80
W9bL0P2KVi/209JFUPH0U9BD0P2CTi<208b<S080Rh^;0P1lO7`207MgM`0307YjNP1nOWh0OWin0080
P8200P22PX8207QhN080Lg=c0P1/K6`206EUI@80H61P0P1VIVH206e]K@80N7Qh0P1dM7@206m_K`80
JFUY0P1PH60206ATI2L0b>3H0P0V9RH202@T9080<30`0P1>CTh2092@T080UIFE0P2KVi/20:BTY080
Z:RX0P2d];@20;fm_@80]kNg00<0^;Rh0;no_`2o_kl00P32`/820;no_`80^;Rh0P2RXZ8203`l?080
9bLW0P0Q8B4202@T90809RHV0P0X:2P202HV9P80:BTY100V9RH202`/;080;Rh^0P0a<C4202l_;`80
<c<c0P0b<S8202l_;`8092@T0P0];Bd202PX:003065QH@1/K6`0K6a/0080MGEe0P1TI6@204Y:BP80
Cdm?0P1@D50205iNGP80IFEU0P1YJFT206YZJP80KFe]0P1bLW8207AdM0@0MgMg0P1kNg/207emO@80
O7al0P1oOgl207emO@80Ogmo0P23Ph<208J6QP80OWin00<0Ph>308J6QP26QXH00P27QhL208R8R080
QHF50P2:RXX208j>SP@0T92@0P2ATI4209>CT`80TY:B0P2?Shl209:BTP80UYJF102EUID209JFUP@0
UIFE0P2HV9P209VIV@80U9BD0P2KVi/209ZJVP80WYjN00<0WIfM09nOW`2OWil00P2OWil209jNWP80
XJ6Q0P2JVYX209jNWP80WIfM0P2KVi/209jNWP80XZ:R0P2NWYh209VIV@80UYJF0P2HV9P209BDU0@0
TY:B0P2CTi<208Z:RP80P8200P1fMWH207MgM`80NWYj0P22PX8207moO`0307emO@1dM7@0M7Ad0080
J6QX0P1SHf<2065QH@80Hf=S0P1^KVh2079bLP80LG5a0P1^KVh206MWI`80GemO0P1SHf<N0<SPf000
7038h=P202LW9`8092@T0P0_;bl204e=C@80SXj>0P2EUID209nOW`80Y:BT0P2YZJT20;>c/`80_;bl
0P2k^k/00`2h^;P0_Kfm0;fm_@020<71`@80`l?30P2i^KT209nOW`80?Shn0P0W9bL2020P80808B4Q
0P0U9BD202LW9`80:2PX0P0W9bL202DU9@809bLW0P0Z:RX202`/;080;bl_100`<30202l_;`80;Rh^
0P0X:2P202/[:`80:2PX00<0H61P06e]K@1]KFd00P1bLW82061PH0@0CDe=0P1DE5@205eMG@80IFEU
0P1WIfL206QXJ080K6a/0P1`L702079bLP80M7Ad0P1gMgL207YjNP80Ng]k101lO7`207emO@80P820
1P22PX800`23Ph<0QHF508F5Q@0208N7Q`80R8R80P29RHT208Z:RP80S8b<0P2?Shl:096AT@80Ti>C
0P2EUID409NGU`@0UYJF0P2EUID209JFUP80UiNG0P2IVIT209ZJVP@0Vi^K00<0WIfM09jNWP2NWYh0
0P2NWYh209fMW@`0WYjN102OWil209^KV`80UYJF0P2EUID409BDU080TY:B0P2?Shl208V9R@80Ogmo
0P1fMWH207QhN080O7al0P20P80208:2PP0307alO01dM7@0M7Ad0080JVYZ0P1RHV82061PH080HV9R
0P1ZJVX2079bLP80L71`0P1/K6`206IVIP80HF5Q0P1PH60W0<SPf0808R8R0P0O7al202<S8`80DE5A
0P2BTY8209NGU`80WYjN102RXZ820:n_[`80`/;20P2i^KT20;jn_P80`<300P37alL00`36a/H0_;bl
0;bl_0020::RXP80?3`l0P0S8b<202DU9@808b<S0P0W9bL202PX:080:BTY1P0W9bL402/[:`80;bl_
0P0];Bd202h^;P@0;bl_0P0Y:BT202@T9080:BTY0P1OGel206][J`80L71`0P1VIVH204e=C@80CTi>
0P1CDe<205mOG`80IVIV00<0Hf=S06YZJP1ZJVX00P1/K6`2071`L080Kfm_0P1hN7P207EeM@80N7Qh
101jNWX407emO@80OWin0P23Ph<208:2PP80Ph>30P24Q8@208>3P`80RHV90P28R8P208Z:RP80R8R8
1P2@T90209:BTP80T92@0P2DU9@209:BTP80TI6A0P2GUiL209JFUP0309RHV02FUYH0UYJF0080UYJF
0P2CTi<209FEU@80VIVI0P2GUiL209ZJVP80WinO0P2LW9`209^KV`80WinO0P2MWId209nOW`80WIfM
0P2NWYh20:2PX080WIfM102OWil209jNWP80W9bL0P2KVi/209JFUPH0U9BD0P2CTi<208b<S080Rh^;
0P1lO7`207MgM`0307YjNP1nOWh0OWin0080P8200P22PX8207QhN080Lg=c0P1/K6`206EUI@80H61P
0P1VIVH206e]K@80N7Qh0P1dM7@206m_K`80JFUY0P1PH60206ATI2L0b>3H0P0V9RH202@T9080<30`
0P1>CTh2092@T080UIFE0P2KVi/20:BTY080Z:RX0P2d];@20;fm_@80]kNg00<0^;Rh0;no_`2o_kl0
0P32`/820;no_`80^;Rh0P2RXZ8203`l?0809bLW0P0Q8B4202@T90809RHV0P0X:2P202HV9P80:BTY
100V9RH202`/;080;Rh^0P0a<C4202l_;`80<c<c0P0b<S8202l_;`8092@T0P0];Bd202PX:003065Q
H@1/K6`0K6a/0080MGEe0P1TI6@204Y:BP80Cdm?0P1@D50205iNGP80IFEU0P1YJFT206YZJP80KFe]
0P1bLW8207AdM0@0MgMg0P1kNg/207emO@80O7al0P1oOgl207emO@80Ogmo0P23Ph<208J6QP80OWin
00<0Ph>308J6QP26QXH00P27QhL208R8R080QHF50P2:RXX208j>SP@0T92@0P2ATI4209>CT`80TY:B
0P2?Shl209:BTP80UYJF102EUID209JFUP@0UIFE0P2HV9P209VIV@80U9BD0P2KVi/209ZJVP80WYjN
00<0WIfM09nOW`2OWil00P2OWil209jNWP80XJ6Q0P2JVYX209jNWP80WIfM0P2KVi/209jNWP80XZ:R
0P2NWYh209VIV@80UYJF0P2HV9P209BDU0@0TY:B0P2CTi<208Z:RP80P8200P1fMWH207MgM`80NWYj
0P22PX8207moO`0307emO@1dM7@0M7Ad0080J6QX0P1SHf<2065QH@80Hf=S0P1^KVh2079bLP80LG5a
0P1^KVh206MWI`80GemO0P1SHf<N0<SPf0007038h=P2028R8P806ATI0P0O7al2030`<080QhN70P2J
VYX20:^[Z`@0[Jf]0P2h^;P20<;2`P80`<3000<0_;bl0;no_`2o_kl00P31`L420<G5a@80^KVi0P2/
[:`205aLG080=cLg0P0O7al2020P80H0:2PX0P0V9RH202DU9@809RHV0P0X:2P202`/;080<30`100b
<S82030`<080;Rh^0P0W9bL202XZ:P809BDU00<0G5aL06][J`1[Jf/00P1cLg<2061PH080C4a<0P1>
CTh205EEE@80G5aL0P1RHV8206ATI080IFEU0P1YJFT206i^KP80LW9b0P1eMGD207MgM`80NGUi0P1k
Ng/407emO@80O7al0P20P80208>3P`80PX:20P21PH400`22PX80Q8B408B4Q00208J6QP80QhN70P29
RHT208Z:RP80Rh^;0P2<S8`2092@T080Ti>C0P2BTY82096AT@80Ti>C0P2EUID209NGU`80V9RH0P2G
UiL209JFUP@0UiNG0P2FUYH209FEU@80UiNG0P2IVIT209^KV`80WIfM00<0WYjN09nOW`2OWil0102O
Wil209jNWP80WIfM202NWYh409nOW`80VYZJ0P2DU9@409FEU@80U9BD0P2ATI4208^;R`80QHF50P1k
Ng/207EeM@80Ng]k0P23Ph<208N7Q`80QXJ600<0NGUi06MWI`1WIfL00P1CDe<20492@P80?clo0P13
@d<2055AD@@0GUiN0P1JFUX205QHF0@0EUIF9`38h=P2020P808071`L0P0R8R8202l_;`80PH610P2T
Y:@20:JVYP80ZZZZ0P2a/K420;Bd]080aLG50P2g]kL20;jn_P80_kno0P31`L400`2n_[h0_;bl0;bl
_0020:j^[P80IFEU0P0d=3@202<S8`808B4Q100X:2P202XZ:P@09BDU0P0V9RH202/[:`80:RXZ0P0d
=3@2038b<P80=3@d0P0_;bl202`/;0@09bLW0P0^;Rh205YJFP80KFe]0P1`L70206UYJ@80AdM70P1?
Cdl205EEE@80G5aL0P1RHV800`1TI6@0IVIV06IVIP0206UYJ@80KVi^0P1dM7@207=cL`80NGUi0P1l
O7`207UiN@80P820101mOGd207moO`80Ph>30P22PX820861P@80P8200P25QHD408N7Q`80R8R80P2;
Rh/208b<S080Rh^;1P2CTi<208j>SP80U9BD0P2CTi<209VIV@80UiNG0`2FUYH209FEU@80V9RH0P2G
UiL409BDU080V9RH0P2MWId209bLW080WinO0P2PX:0209jNWP80WinO0P2KVi/209jNWP80W9bL0P2N
WYh209fMW@80W9bL0P2OWil20::RXP@0UYJF0P2HV9P209FEU@80U9BD0P2?Shl208^;R`80QHF50P1k
Ng/207EeM@0307YjNP24Q8@0Q8B40080Ph>30P24Q8@20861P@80JFUY0P1GEeL204I6AP80>c/k0P17
AdL2055AD@80HF5Q0P1MGEd205aLG080EeMG0P1EEED205UIFBL0b>3H0P0T92@201LG5`80820P0P0^
;Rh208N7Q`80VYZJ0P2/[:`20;2`/080[Jf]0P2g]kL20<?3``80_[jn00<0_;bl0<71`@31`L401031
`L420;^k^`80[jn_0P1KFe/203Ti>@807QhN0P0O7al602PX:0@08b<S0P0W9bL2028R8P80;Rh^0P0_
;bl202h^;P80<30`0P0a<C4202h^;P809RHV0P0[:b/202HV9P0305]KF`1XJ6P0J6QX0080MGEe0P1N
GUh204];B`80DE5A0P1CDe<205eMG@80HF5Q0P1RHV8206=SH`80J6QX0P1]KFd2079bLP80Lg=c0P1i
NGT207QhN080P8200P1iNGT207inOP80Ng]k0P20P8040861P@<0PX:20P24Q8@208F5Q@@0RHV90P2;
Rh/208V9R@80S8b<0P2ATI4209:BTP80Ti>C0P2ATI4208n?S`80UiNG0P2IVIT209RHV080UYJF0P2I
VIT209JFUP80VIVI102GUiL209BDU080Vi^K0P2LW9`309fMW@80XJ6Q102MWId20:2PX080W9bL0P2N
WYh409nOW`80W9bL0P2MWId20:2PX080VIVI0P2DU9@209JFUP80U9BD0P2CTi<2096AT@80SXj>0P22
PX8207moO`80M7Ad0P1lO7`208F5Q@80QhN70P23Ph<00`1oOgl0Hf=S06=SH`02059BDP80@4100P12
@T820451@@80DU9B0P1OGel205eMG@80F5QH0P1IFET205MGE`80De=C7P38h=P001`0b>3H0P0R8R82
01TI6@807alO0P0`<30208N7Q`80VYZJ0P2[Zj/40:f][@80^;Rh0P32`/820<30`0030;bl_02o_kl0
_kno0080`L710P35aLD20;Vi^@80[:b/0P1LG5`203Lg=`807alO0P0P820602PX:0809RHV0P0U9BD2
02HV9P80:2PX0P0/;2`2030`<0@0<S8b0P0`<30202h^;P809bLW0P0Z:RX202DU9@0305aLG01[Jf/0
Jf][0080Lg=c0P1PH60204a<C080CTi>0P1EEED205aLG080HV9R0P1TI6@206EUI@80JFUY0P1^KVh2
079bLP80MGEe0P1gMgL207UiN@80Ng]k101mOGd207alO080P8200P23Ph<208:2PP80PH6100<0PX:2
08B4Q024Q8@00P26QXH208N7Q`80RHV90P2:RXX208^;R`80S8b<0P2@T90209>CT`80TY:B0P2ATI42
09>CT`80UIFE0P2GUiL209RHV080UiNG0P2FUYH409NGU`80UYJF0P2EUID209NGU`80VIVI0P2KVi/2
09fMW@0309jNWP2OWil0WinO00@0WinO0P2NWYh209fMW@P0WYjN102OWil209ZJVP80U9BD102EUID2
09BDU080TI6A0P2;Rh/208F5Q@80Ng]k0P1eMGD207]kN`80Ph>30P27QhL208J6QP0307UiN@1WIfL0
IfMW0080De=C0P12@T8203lo?`80@d=30P1ADE4405iNGP80FUYJ0P1HF5P405IFERL0b>3H0P0P8202
01`L70808R8R0P0_;bl20861P@80Y:BT0P2VYZH20:ZZZP80/K6a0P2d];@20<G5a@80]kNg0P2n_[h2
0;no_`80`L7100<0_[jn0;bl_02l_;`00P2^[Zh206EUI@80=3@d0P0S8b<2024Q8@@0:2PX0P0Z:RX4
02DU9@809RHV0P0[:b/202XZ:P80=3@d0P0b<S8203@d=080;bl_0P0/;2`402LW9`80;Rh^0P1JFUX2
06e]K@80L71`0P1YJFT204M7A`80Cdm?0P1EEED205aLG080HV9R00<0I6AT06IVIP1VIVH00P1YJFT2
06i^KP80M7Ad0P1cLg<207UiN@80O7al0P1iNGT20820P0@0OGem0P1oOgl208>3P`80PX:20P21PH42
0820P080QHF51027QhL208R8R080Rh^;0P2<S8`208^;R`H0Ti>C0P2>SXh209BDU080Ti>C0P2IVIT2
09NGU`<0UYJF0P2EUID209RHV080UiNG102DU9@209RHV080WIfM0P2LW9`209nOW`80X:2P0P2NWYh2
09nOW`80Vi^K0P2NWYh209bLW080WYjN0P2MWId209bLW080WinO0P2RXZ8409JFUP80V9RH0P2EUID2
09BDU080Shn?0P2;Rh/208F5Q@80Ng]k0P1eMGD00`1jNWX0Q8B408B4Q00208>3P`80Q8B40P21PH42
06UYJ@80EeMG0P16ATH203/k>`80AdM70P1ADE42065QH@80GEeM0P1LG5`205MGE`80EEEE0P1IFETW
0<SPf08092@T0P0G5aL2020P8080;Rh^0P27QhL209ZJVP80[:b/0P2`/;020:f][@80]kNg0P33`l<2
0;jn_P030;bl_031`L40`L7100@0`L710P2k^k/20:n_[`80Fe]K0P0i>CT201hN7P807alO1P0X:2P4
02<S8`809bLW0P0R8R8202h^;P80;bl_0P0^;Rh2030`<080<C4a0P0^;Rh202HV9P80:b/[0P0V9RH0
0`1KFe/0J6QX06QXJ00207EeM@80GUiN0P1;Bd/2055AD@80De=C0P1MGEd2065QH@80HV9R0P1SHf<2
06QXJ080KFe]0P1bLW8207=cL`80NGUi0P1hN7P20820P080NGUi0P1nOWh207]kN`80P8201021PH43
08:2PP80Q8B40P25QHD408V9R@80Rh^;0P29RHT208b<S080TI6A0P2BTY8209>CT`80TI6A0P2?Shl2
09NGU`80VIVI0P2HV9P209JFUP80VIVI0P2FUYH209VIV@@0UiNG0P2DU9@209^KV`80W9bL0`2MWId2
0:6QX@@0WIfM0P2PX:0209bLW080WYjN102OWil209bLW080WIfM0P2PX:0209VIV@80U9BD0P2FUYH2
09BDU080Ti>C0P2ATI4208j>SP80PX:20P1oOgl207AdM080O7al0P25QHD208N7Q`80Ph>300<0Ogmo
06=SH`1SHf<00P1BDU820410@080@T920P11@D42059BDP80GemO0P1MGEd205QHF080FEUI0P1GEeL2
05=CDah0b>3H000L0<SPf0808R8R0P0J6QX201`L70809bLW0P1KFe/20:VYZ@80[Jf]0P2d];@20:^[
Z`80]kNg0P31`L420;fm_@030;Ng]`2k^k/0^k^k0080_kno0P2n_[h20;Fe]@80`<300P2RXZ8207]k
N`80<c<c100Y:BT202HV9P8092@T100S8b<202@T90809BDU0P0Z:RX202l_;`80<30`0P0_;bl202`/
;080:RXZ0P0V9RH202/[:`809RHV00<0HF5Q06QXJ01XJ6P00P1ZJVX205aLG080CDe=0P1>CTh205=C
D`80FEUI0P1PH602069RHP80I6AT0P1ZJVX2071`L080Lg=c0P1fMWH207QhN0@0NWYj0P1kNg/207em
O@80Ogmo0P20P8060861P@0308>3P`26QXH0QXJ60080R8R81P2:RXX208^;R`80SHf=0P2@T904096A
T@80T92@0P2DU9@209RHV080UiNG0P2EUID209JFUP80UiNG102IVIT209RHV080UYJF0P2GUiL209VI
V@80Vi^K0P2LW9`00`2MWId0WYjN09jNWP0609jNWP80WIfM1P2NWYh209fMW@@0WinO0P2JVYX209FE
U@80U9BD0P2CTi<2092@T080S8b<0P27QhL20861P@80NWYj0P1gMgL207emO@80QHF50P28R8P208N7
Q`0307emO@1^KVh0KVi^0080D51@0P0f=SH2034a<@80=cLg0P15ADD205EEE@80GEeM0P1RHV8206AT
I080IFEU0P1VIVHW0<SPf0809BDU0P0R8R8201lO7`808B4Q0P1HF5P20:f][@80/K6a0P2][Jd20;>c
/`80^[Zj0P34a<@20;Bd]080]kNg0P2m_Kd20;bl_0030;jn_P2g]kL0]kNg0080[Zj^0P2RXZ8207Ad
M080<30`0P0Y:BT202XZ:P808b<S0P0Q8B4402HV9P@09BDU0P0V9RH202`/;080>3Ph0P0^;Rh202XZ
:P80;Rh^100[:b/202d];@80EeMG0P1ZJVX2069RHP80GemO0P1;Bd/204U9B@80DE5A0P1PH60205iN
GP03061PH01RHV80HV9R0080Jf][0P1`L702075aL@80MGEe0P1iNGT207QhN0@0NWYj0P1kNg/20820
P080PH610P22PX820820P0@0PX:20P26QXH208Z:RP80RHV91028R8P208^;R`80RXZ:0P2@T90208n?
S`80SHf=0P2>SXh209ZJVP@0UYJF0P2CTi<309VIV@80UYJF0P2KVi/209bLW080V9RH0P2EUID209ZJ
VP80W9bL102JVYX209fMW@80W9bL0P2PX:0209nOW`80WYjN102OWil209jNWP80X:2P0P2OWil20:6Q
X@80V9RH0P2CTi<209BDU080TI6A0P2=SHd208n?S`80RXZ:0P22PX8207MgM`80NGUi00<0PH6108B4
Q024Q8@00P26QXH208R8R080Ph>30P1UIFD20451@@80<S8b0P0a<C42038b<P80@4100P1=CDd205UI
F@80H61P0P1JFUX206=SH`80LG5a9`38h=P202HV9P805aLG0P0M7Ad202PX:080FUYJ0P2WYjL20:f]
[@80/[:b0P2XZ:P20;Ng]`80`<300P2l_;`00`2f][H0^k^k0;^k^`020;no_`80`<300P2e]KD20;no
_`80Xj>S0P1hN7P203<c<`80:2PX0P0Y:BT202LW9`809BDU0P0V9RH202DU9@80:BTY0P0W9bL402h^
;P80;bl_0P0`<30202d];@80:RXZ0P0U9BD202PX:0809bLW00<0Hf=S06IVIP1VIVH00P1XJ6P205MG
E`80CTi>0P1ADE4205ADE080F5QH0P1PH602069RHP80IFEU0P1[Jf/206i^KP80M7Ad0P1eMGD207If
MP80MGEe0P1lO7`207UiN@80Ogmo0P1mOGd208>3P`80PX:20P20P80208:2PP030861P@29RHT0RHV9
0080Q8B4102;Rh/208V9R@80Shn?0P2<S8`208n?S`80TY:B0P2@T90209:BTP80Ti>C0P2HV9P209JF
UP80UiNG0P2EUID209JFUP80VIVI102FUYH209>CT`80VIVI0P2JVYX209JFUP80WYjN00<0W9bL09^K
V`2KVi/00P2NWYh209nOW`80WIfM0P2OWil209jNWP80W9bL0P2RXZ820:6QX@80WYjN0P2RXZ8209VI
V@H0U9BD0P2@T90208Z:RP80PX:20P1oOgl207YjNP80MgMg0P1kNg/208F5Q@80Q8B40P28R8P00`23
Ph<0KVi^06i^KP02051@D080=SHf0P0b<S8203@d=080A4A40P1ADE4205aLG080HV9R0P1WIfL406EU
IAh0b>3H000L0<SPf0808R8R0P0J6QX201`L70809bLW0P1KFe/20:VYZ@80[Jf]0P2d];@20:^[Z`80
]kNg0P31`L420;fm_@030;Ng]`2k^k/0^k^k0080_kno0P2n_[h20;Fe]@80`<300P2RXZ8207]kN`80
<c<c100Y:BT202HV9P8092@T100S8b<202@T90809BDU0P0Z:RX202l_;`80<30`0P0_;bl202`/;080
:RXZ0P0V9RH202/[:`809RHV00<0HF5Q06QXJ01XJ6P00P1ZJVX205aLG080CDe=0P1>CTh205=CD`80
FEUI0P1PH602069RHP80I6AT0P1ZJVX2071`L080Lg=c0P1fMWH207QhN0@0NWYj0P1kNg/207emO@80
Ogmo0P20P8060861P@0308>3P`26QXH0QXJ60080R8R81P2:RXX208^;R`80SHf=0P2@T904096AT@80
T92@0P2DU9@209RHV080UiNG0P2EUID209JFUP80UiNG102IVIT209RHV080UYJF0P2GUiL209VIV@80
Vi^K0P2LW9`00`2MWId0WYjN09jNWP0609jNWP80WIfM1P2NWYh209fMW@@0WinO0P2JVYX209FEU@80
U9BD0P2CTi<2092@T080S8b<0P27QhL20861P@80NWYj0P1gMgL207emO@80QHF50P28R8P208N7Q`03
07emO@1^KVh0KVi^0080D51@0P0f=SH2034a<@80=cLg0P15ADD205EEE@80GEeM0P1RHV8206ATI080
IFEU0P1VIVHW0<SPf0809BDU0P0R8R8201lO7`808B4Q0P1HF5P20:f][@80/K6a0P2][Jd20;>c/`80
^[Zj0P34a<@20;Bd]080]kNg0P2m_Kd20;bl_0030;jn_P2g]kL0]kNg0080[Zj^0P2RXZ8207AdM080
<30`0P0Y:BT202XZ:P808b<S0P0Q8B4402HV9P@09BDU0P0V9RH202`/;080>3Ph0P0^;Rh202XZ:P80
;Rh^100[:b/202d];@80EeMG0P1ZJVX2069RHP80GemO0P1;Bd/204U9B@80DE5A0P1PH60205iNGP03
061PH01RHV80HV9R0080Jf][0P1`L702075aL@80MGEe0P1iNGT207QhN0@0NWYj0P1kNg/20820P080
PH610P22PX820820P0@0PX:20P26QXH208Z:RP80RHV91028R8P208^;R`80RXZ:0P2@T90208n?S`80
SHf=0P2>SXh209ZJVP@0UYJF0P2CTi<309VIV@80UYJF0P2KVi/209bLW080V9RH0P2EUID209ZJVP80
W9bL102JVYX209fMW@80W9bL0P2PX:0209nOW`80WYjN102OWil209jNWP80X:2P0P2OWil20:6QX@80
V9RH0P2CTi<209BDU080TI6A0P2=SHd208n?S`80RXZ:0P22PX8207MgM`80NGUi00<0PH6108B4Q024
Q8@00P26QXH208R8R080Ph>30P1UIFD20451@@80<S8b0P0a<C42038b<P80@4100P1=CDd205UIF@80
H61P0P1JFUX206=SH`80LG5a9`38h=P202HV9P805aLG0P0M7Ad202PX:080FUYJ0P2WYjL20:f][@80
/[:b0P2XZ:P20;Ng]`80`<300P2l_;`00`2f][H0^k^k0;^k^`020;no_`80`<300P2e]KD20;no_`80
Xj>S0P1hN7P203<c<`80:2PX0P0Y:BT202LW9`809BDU0P0V9RH202DU9@80:BTY0P0W9bL402h^;P80
;bl_0P0`<30202d];@80:RXZ0P0U9BD202PX:0809bLW00<0Hf=S06IVIP1VIVH00P1XJ6P205MGE`80
CTi>0P1ADE4205ADE080F5QH0P1PH602069RHP80IFEU0P1[Jf/206i^KP80M7Ad0P1eMGD207IfMP80
MGEe0P1lO7`207UiN@80Ogmo0P1mOGd208>3P`80PX:20P20P80208:2PP030861P@29RHT0RHV90080
Q8B4102;Rh/208V9R@80Shn?0P2<S8`208n?S`80TY:B0P2@T90209:BTP80Ti>C0P2HV9P209JFUP80
UiNG0P2EUID209JFUP80VIVI102FUYH209>CT`80VIVI0P2JVYX209JFUP80WYjN00<0W9bL09^KV`2K
Vi/00P2NWYh209nOW`80WIfM0P2OWil209jNWP80W9bL0P2RXZ820:6QX@80WYjN0P2RXZ8209VIV@H0
U9BD0P2@T90208Z:RP80PX:20P1oOgl207YjNP80MgMg0P1kNg/208F5Q@80Q8B40P28R8P00`23Ph<0
KVi^06i^KP02051@D080=SHf0P0b<S8203@d=080A4A40P1ADE4205aLG080HV9R0P1WIfL406EUIAh0
b>3H000L0<SPf0808b<S0P0O7al201dM7@808b<S0P0^;Rh20:j^[P80Zj^[0P2e]KD20:RXZ080/k>c
0P2l_;`20;Jf]P030;2`/02f][H0][Jf0080^k^k0P2h^;P20;:b/P80[Zj^0P2RXZ8209^KV`80DU9B
0P0o?cl2034a<@80:2PX0P0R8R82024Q8@@08R8R0P0S8b<202PX:0@0;Bd]0P0/;2`202TY:@809bLW
0P0T92@202/[:`80:RXZ00<0IFEU06IVIP1VIVH00P1QHF4205MGE`80CDe=0P1<C4`2051@D080EUIF
0P1MGEd2061PH080I6AT0P1/K6`207=cL`80MGEe0P1fMWH207UiN@80O7al0P1jNWX207UiN@80OWin
0P22PX820861P@80OWin0P20P80208:2PP0308B4Q027QhL0QhN70080RXZ:0P2<S8`208^;R`80RXZ:
0P2<S8`208j>SPH0Shn?0P2@T90209FEU@80VYZJ0P2GUiL209>CT`80UIFE0P2HV9P409ZJVP80VIVI
0P2GUiL209RHV080VYZJ102KVi/00`2LW9`0WIfM09fMW@0609fMW@@0WYjN0P2OWil209fMW@80W9bL
0P2NWYh209nOW`80VYZJ0P2EUID209>CT`80TI6A0P2=SHd208V9R@80Ph>30P1mOGd207UiN@80N7Qh
0P1oOgl208J6QP80R8R80P27QhL00`24Q8@0NGUi07UiN@0205IFEP80=SHf0P0a<C4203Hf=P80@T92
0P1ADE42069RHP80LG5a0P1fMWH207QhN080NGUi9`38h=P2020P80@07AdM0P0O7al203Lg=`80XZ:R
0P2d];@20:b/[080[jn_0P2][Jd20;no_`@0/k>c0P2h^;P20;fm_@030;Vi^@2c/k<0/k>c0080[jn_
0P2WYjL20:6QX@80Fe]K0P0l?3`203De=@809bLW0P0U9BD2024Q8@@08R8R0P0V9RH202TY:@80;Bd]
100_;bl202DU9@809bLW0P0Y:BT202DU9@80;Rh^0P1NGUh206i^KP80F5QH0P1KFe/204M7A`80D51@
0P1<C4`205IFEP80GEeM00<0HV9R06EUI@1UIFD00P1ZJVX207MgM`80Lg=c0P1iNGT207MgM`80OGem
0P1lO7`207YjNP80OGem0P22PX820820P080Ogmo0P1nOWh208:2PP80Q8B40P27QhL208Z:RP80SHf=
0P2<S8`208^;R`80RXZ:102@T902096AT@@0T92@0P2EUID209^KV`80U9BD0P2BTY800`2JVYX0U9BD
09BDU00209NGU`80VYZJ0P2LW9`209FEU@80V9RH0P2IVIT209fMW@80VIVI0P2OWil209bLW080WYjN
0P2LW9`209jNWP80W9bL0P2NWYh409fMW@80VIVI0P2OWil209fMW@80W9bL0P2FUYH209:BTP80U9BD
102:RXX208N7Q`80P8200P1dM7@207QhN00308N7Q`24Q8@0Q8B40080QHF50P24Q8@208Z:RP80N7Qh
0P1FEUH203Xj>P80>3Ph0P0i>CT204U9B@80FEUI0P1VIVH2079bLP80Lg=c0P1gMgL207inORL0b>3H
0P0S8b<2020P80807AdM0P0Q8B4202d];@80/;2`0P2/[:`20;:b/P80ZZZZ0P2e]KD20;bl_080/k>c
00<0/[:b0;Fe]@2e]KD0102i^KT20;Bd]080[:b/0P2RXZ8209nOW`80DE5A0P0n?Sh2034a<@80:RXZ
0P0P820201dM7@808B4Q0P0N7Qh2020P8080;2`/0P0^;Rh202TY:@80;2`/0P0Z:RX202DU9@808b<S
0P0/;2`202/[:`03069RHP1XJ6P0J6QX0080HV9R0P1DE5@204a<C080D51@0P1>CTh205IFEP80H61P
0P1OGel2065QH@80L71`0P1cLg<2079bLP80NGUi0P1gMgL207alO080OGem0P1iNGT207]kN`80Ph>3
1020P80207emO@<0Q8B40P29RHT208R8R080SHf=0P29RHT408^;R`80SXj>0P2@T902096AT@80S8b<
0P2ATI4209NGU`80Vi^K0P2EUID209BDU080UYJF0P2GUiL209^KV`@0VYZJ0P2FUYH209VIV@80Vi^K
0P2JVYX209fMW@0309jNWP2KVi/0Vi^K0080X:2P102LW9`20:2PX080W9bL0P2OWil409jNWP80VIVI
0P2NWYh209bLW080UYJF0P2=SHd2096AT@80Shn?0P2;Rh/20861P@80Ogmo101hN7P207inOP80R8R8
1027QhL00`20P800NWYj07YjNP0205IFEP80=CDe0P0a<C4203Hf=P80@D510P1CDe<206=SH`80LG5a
0P1fMWH207MgM`80N7Qh7P38h=P001`0b>3H0P0S8b<201lO7`807AdM0P0S8b<202h^;P80[Zj^0P2[
Zj/20;Fe]@80Z:RX0P2c/k<20;bl_080][Jf00<0/;2`0;Jf]P2f][H00P2k^k/20;Rh^080/[:b0P2^
[Zh20::RXP80Vi^K0P1BDU8203lo?`80<C4a0P0X:2P2028R8P808B4Q100R8R8202<S8`80:2PX100]
;Bd202`/;080:BTY0P0W9bL202@T9080:b/[0P0Z:RX00`1UIFD0IVIV06IVIP02065QH@80EeMG0P1=
CDd204a<C080D51@0P1FEUH205eMG@80H61P0P1TI6@206a/K080Lg=c0P1eMGD207IfMP80NGUi0P1l
O7`207YjNP80NGUi0P1nOWh208:2PP80PH610P1nOWh20820P080PX:200<0Q8B408N7Q`27QhL00P2:
RXX208b<S080Rh^;0P2:RXX208b<S080SXj>1P2?Shl2092@T080UIFE0P2JVYX209NGU`80Ti>C0P2E
UID209RHV0@0VYZJ0P2IVIT209NGU`80V9RH0P2JVYX409^KV`0309bLW02MWId0WIfM00H0WIfM102N
WYh209nOW`80WIfM0P2LW9`209jNWP80WinO0P2JVYX209FEU@80Ti>C0P2ATI4208f=S@80RHV90P23
Ph<207emO@80NGUi0P1hN7P207moO`80QXJ60P28R8P208N7Q`0308B4Q01iNGT0NGUi0080EUIF0P0f
=SH2034a<@80=SHf0P12@T82055AD@80HV9R0P1aLG4207IfMP80N7Qh0P1iNGTW0<SPf080820P100M
7Ad201lO7`80=cLg0P2RXZ820;Bd]080[:b/0P2_[jl20:f][@80_kno102c/k<20;Rh^080_Kfm00<0
^KVi0;>c/`2c/k<00P2_[jl20:NWY`80XJ6Q0P1KFe/203`l?080=CDe0P0W9bL202DU9@808B4Q100R
8R8202HV9P80:BTY0P0];Bd402l_;`809BDU0P0W9bL202TY:@809BDU0P0^;Rh205iNGP80KVi^0P1H
F5P205]KF`80AdM70P1@D50204a<C080EUIF0P1MGEd00`1RHV80IFEU06EUI@0206YZJP80MgMg0P1c
Lg<207UiN@80MgMg0P1mOGd207alO080NWYj0P1mOGd208:2PP80P8200P1oOgl207inOP80PX:20P24
Q8@208N7Q`80RXZ:0P2=SHd208b<S080Rh^;0P2:RXX4092@T080TI6A102@T90209FEU@80Vi^K0P2D
U9@209:BTP0309ZJVP2DU9@0U9BD0080UiNG0P2JVYX209bLW080UIFE0P2HV9P209VIV@80WIfM0P2I
VIT209nOW`80W9bL0P2NWYh209bLW080WYjN0P2LW9`209jNWP@0WIfM0P2IVIT209nOW`80WIfM0P2L
W9`209JFUP80TY:B0P2DU9@408Z:RP80QhN70P20P80207AdM080N7Qh00<0QhN708B4Q024Q8@00P25
QHD208B4Q080RXZ:0P1hN7P205IFEP80>SXj0P0h>3P203Ti>@80BDU90P1IFET206IVIP80LW9b0P1c
Lg<207MgM`80OWin9`38h=P202<S8`80820P0P0M7Ad2024Q8@80;Bd]0P2`/;020:b/[080/[:b0P2Z
ZZX20;Fe]@80_;bl0P2c/k<00`2b/[80]KFe0;Fe]@040;Vi^@80];Bd0P2/[:`20::RXP80WinO0P1A
DE4203hn?P80<C4a0P0Z:RX2020P80807AdM0P0Q8B4201hN7P80820P0P0/;2`202h^;P80:BTY0P0/
;2`202XZ:P809BDU0P0S8b<202`/;080:b/[00<0HV9R06QXJ01XJ6P00P1RHV8205ADE080C4a<0P1@
D50204i>CP80EUIF0P1PH60205mOG`80HF5Q0P1`L70207=cL`80LW9b0P1iNGT207MgM`80O7al0P1m
OGd207UiN@80Ng]k0P23Ph<40820P080OGem0`24Q8@208V9R@80R8R80P2=SHd208V9R@@0Rh^;0P2>
SXh2092@T080TI6A0P2<S8`2096AT@80UiNG0P2KVi/209FEU@80U9BD0P2FUYH209NGU`80Vi^K102J
VYX209JFUP80VIVI0P2KVi/209ZJVP80WIfM00<0WYjN09^KV`2KVi/00P2PX:0409bLW080X:2P0P2L
W9`209nOW`@0WYjN0P2IVIT209jNWP80W9bL0P2FUYH208f=S@80TI6A0P2?Shl208^;R`80PH610P1o
Ogl407QhN080OWin0P28R8P408N7Q`030820P01jNWX0NWYj0080EUIF0P0e=CD2034a<@80=SHf0P11
@D4205=CD`80Hf=S0P1aLG4207IfMP80MgMg0P1hN7PN0<SPf0007038h=P202DU9@808B4Q0P0L71`2
01/K6`808B4Q0P2=SHd20;2`/080Xj>S0P2ZZZX20:f][@80/K6a0P2`/;000`2_[jl0/[:b0;:b/P02
0;Fe]@80]kNg0P2h^;P20;Fe]@80/k>c0P30`<020::RXP80N7Qh0P1;Bd/203@d=0809RHV0P0U9BD2
02<S8`@08R8R0P0W9bL402d];@80;2`/0P0[:b/202XZ:P809BDU0P0V9RH203Hf=P0305iNGP1TI6@0
I6AT0080HV9R0P1EEED204M7A`80ATI60P1;Bd/205=CD`80G5aL0P1QHF4206EUI@80KFe]0P1dM7@2
07EeM@80MWIf0P1jNWX607emO@80P8200P22PX820820P080OWin0P20P80208:2PP0308B4Q026QXH0
QXJ60080RHV90P2;Rh/208b<S0H0SHf=0P2?Shl4096AT@80T92@0P2CTi<809JFUP80UiNG0P2HV9P2
09VIV@80UiNG0P2FUYH209RHV080VYZJ0P2LW9`209fMW@0309^KV`2JVYX0VYZJ0080W9bL102OWil2
09jNWP@0WinO0P2MWId209bLW0@0WIfM0P2IVIT209BDU080TY:B0P2@T90208n?S`80SHf=0P21PH42
07IfMP80M7Ad0P1fMWH207alO080Ph>30P27QhL208V9R@0308F5Q@1oOgl0Ogmo0080O7al0P1iNGT2
07QhN080NGUi0P21PH4208R8R080Q8B40P1nOWh407emO@80O7al9`38h=P202TY:@80820P0P0Q8B42
01dM7@809BDU0P2<S8`20:j^[P80YJFU102WYjL40;Bd]080ZJVY102`/;000`2d];@0^KVi0;Vi^@02
0;Bd]080][Jf0P2d];@209VIV@80Ng]k0P1<C4`202d];@80:BTY0P0V9RH2020P80H08R8R0P0`<302
02d];@80:b/[0P0V9RH202PX:080:BTY0P0U9BD203@d=080H61P0P1_Kfl206ATI080G5aL0P16ATH2
04e=C@80C4a<0P1EEED205aLG00305eMG@1VIVH0IVIV0080KFe]0P1dM7@206m_K`80NGUi0P1jNWX2
07emO@80P8200P1lO7`207emO@80QHF50P1oOgl207emO@@0Ph>30P22PX8208R8R080QXJ60P2<S8`2
08Z:RP80TI6A102=SHd208n?S`80T92@0P2=SHd209:BTP@0UIFE0P2FUYH209NGU`0309FEU@2JVYX0
VYZJ0080V9RH0P2EUID209NGU`80UIFE0P2GUiL209VIV@@0W9bL0P2OWil209RHV080WIfM1P2NWYh2
0:2PX080WinO0P2PX:0209fMW@80Vi^K0P2NWYh209NGU`80UYJF0P2?Shl209BDU0@0RXZ:0P24Q8@2
075aL@80K6a/0P1aLG400`21PH40Ogmo07moO`0208V9R@80QhN71025QHD208>3P`80MgMg0P1`L702
07EeM@80OWin0P1oOgl20820P080PX:20P24Q8@207inOP80NWYj9`38h=P4028R8P806a/K0P0M7Ad2
02<S8`80T92@0P2_[jl20::RXP80ZZZZ0P2^[Zh20;Bd]080/;2`00<0[Zj^0;Fe]@2e]KD00P2g]kL2
0;Fe]@80][Jf0P2e]KD20;Bd]080`<300P2TY:@207IfMP80Bd];0P0c<c<202HV9P80:2PX0P0U9BD2
024Q8@8092@T0P0W9bL202d];@809bLW0P0_;bl202d];@80;bl_0P0T92@202HV9P80=SHf00<0GEeM
06IVIP1VIVH00P1VIVH2051@D080BTY:0P16ATH204U9B@80DU9B0P1JFUX205iNGP80IFEU0P1^KVh2
07AdM080Lg=c0P1gMgL207alO080PX:20P1nOWh207emO@80P8200P25QHD207moO`80OGem0P21PH42
08>3P`0308B4Q025QHD0QHF50080R8R80P2?Shl208^;R`80Shn?0P2<S8`208n?S`80SHf=0P2@T902
096AT@80Shn?0P2DU9@209FEU@80UYJF0P2CTi<209RHV080UYJF0P2JVYX209NGU`80V9RH0P2GUiL2
09^KV`80VYZJ0P2IVIT209ZJVP0309bLW02KVi/0Vi^K0080WYjN0P2OWil20:2PX080Vi^K0P2MWId2
0::RXP80WIfM0P2HV9P209^KV`80WinO0P2KVi/209NGU`80T92@0P2CTi<2092@T080Shn?0P21PH42
07QhN080M7Ad0P1gMgL207alO080Q8B40P28R8P208f=S@0308:2PP20P800P8200080N7Qh0P1iNGT2
07YjNP80Ng]k0P23Ph<208V9R@80PX:20P1mOGd207]kN`80P8200P1oOglN0<SPf0007038h=P202DU
9@808B4Q0P0L71`201/K6`808B4Q0P2=SHd20;2`/080Xj>S0P2ZZZX20:f][@80/K6a0P2`/;000`2_
[jl0/[:b0;:b/P020;Fe]@80]kNg0P2h^;P20;Fe]@80/k>c0P30`<020::RXP80N7Qh0P1;Bd/203@d
=0809RHV0P0U9BD202<S8`@08R8R0P0W9bL402d];@80;2`/0P0[:b/202XZ:P809BDU0P0V9RH203Hf
=P0305iNGP1TI6@0I6AT0080HV9R0P1EEED204M7A`80ATI60P1;Bd/205=CD`80G5aL0P1QHF4206EU
I@80KFe]0P1dM7@207EeM@80MWIf0P1jNWX607emO@80P8200P22PX820820P080OWin0P20P80208:2
PP0308B4Q026QXH0QXJ60080RHV90P2;Rh/208b<S0H0SHf=0P2?Shl4096AT@80T92@0P2CTi<809JF
UP80UiNG0P2HV9P209VIV@80UiNG0P2FUYH209RHV080VYZJ0P2LW9`209fMW@0309^KV`2JVYX0VYZJ
0080W9bL102OWil209jNWP@0WinO0P2MWId209bLW0@0WIfM0P2IVIT209BDU080TY:B0P2@T90208n?
S`80SHf=0P21PH4207IfMP80M7Ad0P1fMWH207alO080Ph>30P27QhL208V9R@0308F5Q@1oOgl0Ogmo
0080O7al0P1iNGT207QhN080NGUi0P21PH4208R8R080Q8B40P1nOWh407emO@80O7al9`38h=P202TY
:@80820P0P0Q8B4201dM7@809BDU0P2<S8`20:j^[P80YJFU102WYjL40;Bd]080ZJVY102`/;000`2d
];@0^KVi0;Vi^@020;Bd]080][Jf0P2d];@209VIV@80Ng]k0P1<C4`202d];@80:BTY0P0V9RH2020P
80H08R8R0P0`<30202d];@80:b/[0P0V9RH202PX:080:BTY0P0U9BD203@d=080H61P0P1_Kfl206AT
I080G5aL0P16ATH204e=C@80C4a<0P1EEED205aLG00305eMG@1VIVH0IVIV0080KFe]0P1dM7@206m_
K`80NGUi0P1jNWX207emO@80P8200P1lO7`207emO@80QHF50P1oOgl207emO@@0Ph>30P22PX8208R8
R080QXJ60P2<S8`208Z:RP80TI6A102=SHd208n?S`80T92@0P2=SHd209:BTP@0UIFE0P2FUYH209NG
U`0309FEU@2JVYX0VYZJ0080V9RH0P2EUID209NGU`80UIFE0P2GUiL209VIV@@0W9bL0P2OWil209RH
V080WIfM1P2NWYh20:2PX080WinO0P2PX:0209fMW@80Vi^K0P2NWYh209NGU`80UYJF0P2?Shl209BD
U0@0RXZ:0P24Q8@2075aL@80K6a/0P1aLG400`21PH40Ogmo07moO`0208V9R@80QhN71025QHD208>3
P`80MgMg0P1`L70207EeM@80OWin0P1oOgl20820P080PX:20P24Q8@207inOP80NWYj9`38h=P4028R
8P806a/K0P0M7Ad202<S8`80T92@0P2_[jl20::RXP80ZZZZ0P2^[Zh20;Bd]080/;2`00<0[Zj^0;Fe
]@2e]KD00P2g]kL20;Fe]@80][Jf0P2e]KD20;Bd]080`<300P2TY:@207IfMP80Bd];0P0c<c<202HV
9P80:2PX0P0U9BD2024Q8@8092@T0P0W9bL202d];@809bLW0P0_;bl202d];@80;bl_0P0T92@202HV
9P80=SHf00<0GEeM06IVIP1VIVH00P1VIVH2051@D080BTY:0P16ATH204U9B@80DU9B0P1JFUX205iN
GP80IFEU0P1^KVh207AdM080Lg=c0P1gMgL207alO080PX:20P1nOWh207emO@80P8200P25QHD207mo
O`80OGem0P21PH4208>3P`0308B4Q025QHD0QHF50080R8R80P2?Shl208^;R`80Shn?0P2<S8`208n?
S`80SHf=0P2@T902096AT@80Shn?0P2DU9@209FEU@80UYJF0P2CTi<209RHV080UYJF0P2JVYX209NG
U`80V9RH0P2GUiL209^KV`80VYZJ0P2IVIT209ZJVP0309bLW02KVi/0Vi^K0080WYjN0P2OWil20:2P
X080Vi^K0P2MWId20::RXP80WIfM0P2HV9P209^KV`80WinO0P2KVi/209NGU`80T92@0P2CTi<2092@
T080Shn?0P21PH4207QhN080M7Ad0P1gMgL207alO080Q8B40P28R8P208f=S@0308:2PP20P800P820
0080N7Qh0P1iNGT207YjNP80Ng]k0P23Ph<208V9R@80PX:20P1mOGd207]kN`80P8200P1oOglN0<SP
f0007038h=P202LW9`808R8R0P0M7Ad201DE5@807alO0P1SHf<20:j^[P80Ti>C0P2[Zj/20:NWY`80
YZJV0P2YZJT00`2][Jd0[:b/0:b/[0020:b/[080/[:b102g]kL20;Bd]080/[:b0P2][Jd2092@T080
KVi^0P1<C4`2030`<080:2PX0P0T92@2028R8P808b<S0P0W9bL202`/;0@0;Bd]0P0^;Rh202d];@80
9BDU0P0Q8B4203lo?`0305MGE`1TI6@0I6AT0080IFEU0P1DE5@20492@P80@D510P16ATH2051@D080
Fe]K0P1QHF4206IVIP80KFe]0P1cLg<207EeM@80MWIf0P1jNWX207inOP@0P8200P21PH4208:2PP80
P8200P1oOgl20861P@80Ph>300<0Q8B408F5Q@25QHD00P27QhL208V9R@80SHf=0P2?Shl208f=S@80
Rh^;0P2?Shl409:BTP@0TI6A0P2BTY8209JFUP80VIVI0P2HV9P409JFUP80UiNG102FUYH209RHV080
Vi^K0P2MWId209nOW`0309^KV`2HV9P0V9RH0080W9bL102PX:0609nOW`80WIfM102LW9`209ZJVP80
UiNG0P2DU9@2096AT@80Shn?0P2ATI42092@T080P8200P1`L70206m_K`80Lg=c0P1hN7P207moO`80
QXJ60`2;Rh/208R8R080QHF50P22PX8208B4Q0@0QHF50P24Q8@208V9R@80Rh^;0P24Q8@207emO@80
Ng]k9`38h=P202XZ:P80820P100K6a/201dM7@80HV9R0P2XZ:P209fMW@80ZZZZ0P2XZ:P20:JVYP80
[jn_0P2YZJT20:b/[080YjNW00<0/K6a0;Fe]@2e]KD00P2e]KD20;Rh^080_Kfm0P2][Jd208b<S080
MgMg0P1?Cdl203Lg=`80:BTY0P0T92@402HV9P809bLW0P0/;2`202TY:@@0<C4a0P0_;bl202HV9P80
9bLW0P0b<S8205QHF080JFUY0P1KFe/205IFEP80?Shn0P0j>SX204M7A`80EEEE0P1JFUX00`1PH600
IFEU06EUI@0206i^KP80M7Ad0P1cLg<207IfMP80OGem0P1lO7`207moO`80Ph>30P1mOGd208B4Q080
P8200P1oOgl208>3P`80P8200P25QHD208J6QP80Ph>30P2;Rh/2092@T080SXj>0P29RHT408f=S@80
UiNG0P2=SHd208n?S`80V9RH0P2?Shl209JFUP80VIVI00<0Ti>C09NGU`2GUiL00P2EUID409NGU`80
U9BD0P2KVi/409bLW080X:2P0P2JVYX209NGU`80W9bL0P2QXJ4409nOW`@0WYjN0P2LW9`209^KV`80
VYZJ0P2KVi/209JFUP80TI6A0P2BTY82092@T080Rh^;0P2DU9@20820P080M7Ad0P1/K6`207AdM003
07alO01mOGd0OGem0080QhN70P2:RXX208N7Q`80QXJ60P27QhL208J6QP80Q8B40P26QXH208f=S@80
RHV90P24Q8@208^;R`80Q8B40P1nOWh207MgMbL0b>3H0P0V9RH202DU9@8071`L0P0E5AD201`L7080
I6AT0P2^[Zh209FEU@80[:b/0P2SXj<20:JVYP80[Jf]00<0Zj^[0;2`/02`/;000P2YZJT20;:b/P80
^KVi0P2g]kL20;>c/`80/[:b0P2[Zj/2092@T080LW9b0P18B4P2030`<080:BTY0P0U9BD2020P8080
92@T0P0U9BD202d];@80;Rh^0P0];Bd402`/;0808R8R0P0T92@203`l?00305UIF@1SHf<0Hf=S0080
J6QX0P1CDe<204=3@`80@D510P18B4P2051@D080GEeM0P1PH60206IVIP80L71`0P1aLG4207AdM080
Lg=c0P1hN7P207emO@@0P8200P22PX8207moO`80PX:2101oOgl308B4Q080R8R80P23Ph<208R8R080
SHf=0P2@T90208b<S080Rh^;0P2@T90208n?S`80U9BD0P2?Shl209JFUP80TI6A0P2@T90209^KV`80
WIfM0P2CTi<409JFUP80UIFE0P2FUYH209FEU@80VYZJ0P2PX:0309jNWP80UIFE0P2JVYX40:6QX@80
WinO0P2QXJ4209nOW`80VYZJ102MWId209ZJVP80Ti>C0P2FUYH208j>SP80Shn?0P2EUID2096AT@80
OGem0P1eMGD206a/K080Lg=c0P1eMGD207moO`80QhN70P2;Rh/00`29RHT0RXZ:08Z:RP0208J6QP80
Ph>30P22PX8208F5Q@80QhN70P20P80208^;R`80RHV90P24Q8@207emO@80N7Qh7P38h=P001`0b>3H
0P0W9bL2028R8P807AdM0P0E5AD201lO7`80Hf=S0P2^[Zh209>CT`80Zj^[0P2WYjL20:JVYP80ZJVY
00<0[Jf]0:b/[02/[:`00P2/[:`20;:b/P@0]kNg0P2d];@20;:b/P80[Jf]0P2@T90206i^KP80C4a<
0P0`<30202PX:08092@T0P0R8R8202<S8`809bLW0P0/;2`402d];@80;Rh^0P0];Bd202DU9@808B4Q
0P0o?cl00`1GEeL0I6AT06ATI00206EUI@80E5AD0P12@T820451@@80ATI60P1@D50205]KF`80HF5Q
0P1VIVH206e]K@80Lg=c0P1eMGD207IfMP80NWYj0P1nOWh40820P080PH610P22PX820820P080Ogmo
0P21PH4208>3P`0308B4Q025QHD0QHF50080QhN70P29RHT208f=S@80Shn?0P2=SHd208^;R`80Shn?
102BTY84096AT@80TY:B0P2FUYH209VIV@80V9RH102FUYH209NGU`@0UYJF0P2HV9P209^KV`80WIfM
0P2OWil00`2KVi/0V9RH09RHV00209bLW0@0X:2P1P2OWil209fMW@@0W9bL0P2JVYX209NGU`80U9BD
0P2ATI4208n?S`80TI6A0P2@T9020820P080L71`0P1_Kfl207=cL`80N7Qh0P1oOgl208J6QP<0Rh^;
0P28R8P208F5Q@80PX:20P24Q8@408F5Q@80Q8B40P29RHT208^;R`80Q8B40P1mOGd207]kNbL0b>3H
0P0Z:RX2020P80@06a/K0P0M7Ad2069RHP80Z:RX0P2MWId20:ZZZP80Z:RX0P2VYZH20:n_[`80ZJVY
0P2/[:`20:NWY`030;6a/@2e]KD0]KFe0080]KFe0P2h^;P20;fm_@80[Jf]0P2<S8`207MgM`80Cdm?
0P0g=cL202TY:@8092@T100V9RH202LW9`80;2`/0P0Y:BT4034a<@80;bl_0P0V9RH202LW9`80<S8b
0P1HF5P206UYJ@80Fe]K0P1FEUH203hn?P80>SXj0P17AdL205EEE@80FUYJ00<0H61P06EUI@1UIFD0
0P1^KVh207AdM080Lg=c0P1fMWH207emO@80O7al0P1oOgl208>3P`80OGem0P24Q8@20820P080Ogmo
0P23Ph<20820P080QHF50P26QXH208>3P`80Rh^;0P2@T90208j>SP80RHV9102=SHd209NGU`80SHf=
0P2?Shl209RHV080Shn?0P2FUYH209VIV@0309>CT`2GUiL0UiNG0080UIFE102GUiL209BDU080Vi^K
102LW9`20:2PX080VYZJ0P2GUiL209bLW080XJ6Q102OWil409jNWP80W9bL0P2KVi/209ZJVP80Vi^K
0P2FUYH2096AT@80TY:B0P2@T90208^;R`80U9BD0P20P80207AdM080K6a/0P1dM7@00`1lO7`0OGem
07emO@0208N7Q`80RXZ:0P27QhL208J6QP80QhN70P26QXH208B4Q080QXJ60P2=SHd208V9R@80Q8B4
0P2;Rh/208B4Q080OWin0P1gMgLW0<SPf0809RHV0P0U9BD201`L70805ADE0P0L71`206ATI080[Zj^
0P2EUID20:b/[080Xj>S0P2VYZH20:f][@030:^[Z`2`/;00/;2`0080ZJVY0P2b/[820;Vi^@80]kNg
0P2c/k<20;:b/P80Zj^[0P2@T902079bLP80B4Q80P0`<30202TY:@809BDU0P0P820202@T90809BDU
0P0];Bd202h^;P80;Bd]100/;2`2028R8P8092@T0P0l?3`00`1IFET0Hf=S06=SH`0206QXJ080De=C
0P13@d<20451@@80B4Q80P1@D50205eMG@80H61P0P1VIVH2071`L080LG5a0P1dM7@207=cL`80N7Qh
0P1mOGd40820P080PX:20P1oOgl208:2PP@0Ogmo0`24Q8@208R8R080Ph>30P28R8P208f=S@80T92@
0P2<S8`208^;R`80T92@0P2?Shl209BDU080Shn?0P2FUYH2096AT@80T92@0P2KVi/209fMW@80Ti>C
102FUYH209FEU@80UYJF0P2EUID209ZJVP80X:2P0`2NWYh209FEU@80VYZJ102QXJ4209nOW`80XJ6Q
0P2OWil209ZJVP@0WIfM0P2JVYX209>CT`80UYJF0P2>SXh208n?S`80UIFE0P2ATI4207emO@80MGEe
0P1/K6`207=cL`80MGEe0P1oOgl208N7Q`80Rh^;00<0RHV908Z:RP2:RXX00P26QXH208>3P`80PX:2
0P25QHD208N7Q`80P8200P2;Rh/208V9R@80Q8B40P1mOGd207QhN1h0b>3H000L0<SPf080:b/[0P0W
9bL202<S8`8061PH0P0N7Qh204=3@`80UiNG0P2UYJD20:RXZ080YjNW0P2UYJD20:BTY0030:>SX`2O
Wil0WinO0080Vi^K102FUYH20:JVYP80]kNg0P2h^;P20;Jf]P80ZZZZ0P2FUYH206a/K080BDU90P0R
8R8202<S8`80820P0P0T92@202LW9`H0:b/[0P0/;2`202d];@808b<S0P0X:2P203Hf=P0305eMG@1T
I6@0I6AT0080J6QX0P1GEeL204A4A080@D510P14A4@204i>CP80FEUI0P1PH60206MWI`80KFe]0P1b
LW8207AdM080MWIf0P1kNg/207inOP80Ogmo0P1nOWh20820P080PX:20P21PH420820P080PH610P23
Ph<00`24Q8@0QXJ608J6QP0208N7Q`80RHV90P2<S8`208n?S`@0SXj>0P2?Shl4092@T0@0TI6A0P2B
TY8209JFUP80V9RH0P2GUiL209JFUP80UiNG0P2IVIT409ZJVP80Vi^K0P2LW9`409jNWP0309fMW@2K
Vi/0Vi^K0080WYjN102PX:0209nOW`80WYjN0P2MWId409jNWP80WIfM0P2JVYX209JFUP80Ti>C0P2A
TI44092@T080SXj>0P1oOgl2075aL@80KVi^0P1_Kfl207IfMP80OWin0P25QHD208^;R`0308b<S02=
SHd0SHf=0080S8b<0P2;Rh/208f=S@P0Shn?0P2=SHd208F5Q@80OGem0P1kNg/W0<SPf080:2PX0P0V
9RH401dM7@8071`L0P0k>c/20:2PX0@0Xj>S0P2UYJD409nOW`80YZJV0P2/[:`20:6QX@0309jNWP2K
Vi/0Vi^K0080WinO0P2YZJT20;fm_@80^[Zj0P2ZZZX208n?S`80GEeM0P11@D4202HV9P808B4Q0P0P
820201lO7`809RHV0P0e=CD202PX:080;bl_0P0X:2P202XZ:P80:BTY0P0X:2P203@d=080Fe]K0P1Z
JVX206MWI`80FUYJ0P17AdL204A4A080?Cdm0P1CDe<205QHF00305mOG`1YJFT0JFUY0080L71`0P1b
LW8207AdM0@0MWIf0P23Ph<207]kN`80Ogmo0P24Q8@20861P@@0Ogmo1023Ph<608J6QP80QhN71P2=
SHd2092@T080SHf=0P2BTY8208f=S@80Ti>C0P2@T902096AT@80U9BD0P2LW9`00`2GUiL0UYJF09JF
UP0209RHV080Vi^K102LW9`209NGU`80W9bL0P2MWId209jNWP80Vi^K0P2NWYh209fMW@80WYjN0P2U
YJD409jNWP80WinO0P2LW9`20::RXP80WIfM0P2JVYX209NGU`80U9BD0P2IVIT208n?S`80TI6A0P2?
Shl208>3P`80MGEe0P1[Jf/2079bLP0307QhN01mOGd0OGem0080QHF50P2?Shl208f=S@80Rh^;0P29
RHT208R8R080RXZ:0P2BTY8208f=S@80Shn?0P2@T90208b<S080Ph>30P1nOWh207QhN2L0b>3H0P0[
:b/202DU9@808R8R0P0H61P201hN7P80A4A40P2EUID20:JVYP80Z:RX0P2UYJD20:>SX`80YJFU00<0
X:2P09bLW02LW9`00P2JVYX209NGU`80U9BD0P2TY:@20;Rh^080^k^k0P2j^[X20:RXZ080U9BD0P1]
KFd204Y:BP808b<S0P0O7al201hN7P809BDU0P0W9bL202`/;080<C4a0P0Z:RX202d];@80;bl_0P0Q
8B4202TY:@80>CTi00<0GEeM069RHP1RHV800P1TI6@205EEE@@0@T920P14A4@204e=C@80GEeM0P1O
Gel206EUI@80K6a/0P1dM7@207EeM@80NGUi0P1nOWh207]kN`80Ogmo0P1mOGd208>3P`80PH610P22
PX8208>3P`80OWin1@24Q8@408Z:RP@0SXj>102<S8`209:BTP80Ti>C0P2@T90208j>SP@0Ti>C0P2F
UYH209NGU`@0UIFE0P2HV9P209ZJVP80VIVI0P2KVi/209fMW@80W9bL0P2QXJ4209jNWP0309bLW02O
Wil0WinO0080W9bL0P2QXJ4209nOW`80XJ6Q0P2MWId209^KV`80X:2P0P2QXJ4209nOW`80W9bL0P2B
TY8209FEU@80SXj>0P2=SHd209:BTP80Rh^;0P1jNWX206m_K`80KFe]0P1bLW8207UiN@80OWin0P25
QHD208N7Q`0308f=S@2:RXX0RXZ:00@0SHf=0P2<S8`208j>SP80Rh^;0P2@T90209>CT`80SXj>0P29
RHT207YjNP80O7al7P38h=P001`0b>3H0P0[:b/202LW9`808b<S0P0H61P201hN7P80@d=30P2GUiL2
0:FUY@80Z:RX0P2WYjL20:FUY@80Y:BT00<0Xj>S09nOW`2OWil00P2KVi/409JFUP80YZJV0P2g]kL2
0;Rh^080][Jf0P2ZZZX209JFUP80K6a/0P19BDT2028R8P808b<S0P0P820202@T90809bLW1P0[:b/2
02`/;080;Bd]0P0S8b<202PX:080=SHf00<0GEeM06ATI01TI6@00P1XJ6P205MGE`80A4A40P11@D42
04A4A080CTi>0P1IFET2061PH080IfMW0P1]KFd2079bLP80M7Ad0P1fMWH207]kN`80OWin0P1oOgl2
07inOP80P8200P22PX820861P@80P8200P21PH4208>3P`0308B4Q026QXH0QXJ60080QhN70P29RHT2
08b<S080Shn?102>SXh208n?S`@0T92@102ATI4209:BTP80UYJF0P2HV9P209NGU`80UYJF0P2GUiL2
09VIV@@0VYZJ0P2KVi/209bLW0@0WYjN00<0WIfM09^KV`2KVi/00P2NWYh40:2PX080WinO0P2NWYh2
09fMW@@0WYjN0P2MWId209ZJVP80UYJF0P2CTi<2096AT@@0T92@0P2>SXh207moO`80LG5a0P1^KVh2
06m_K`80MWIf0P1nOWh208F5Q@80Rh^;00<0S8b<08f=S@2=SHd00P2<S8`208^;R`80SHf=202?Shl2
08f=S@80QHF50P1mOGd207]kNbL0b>3H0P0X:2P202HV9P@07AdM0P0L71`203/k>`80X:2P102SXj<2
0:FUY@@0WinO0P2VYZH20:b/[080XJ6Q00<0WYjN09^KV`2KVi/00P2OWil20:VYZ@80_Kfm0P2j^[X2
0:ZZZP80Shn?0P1MGEd20451@@809RHV0P0Q8B42020P80807alO0P0V9RH203De=@80:2PX0P0_;bl2
02PX:080:RXZ0P0Y:BT202PX:080=3@d0P1KFe/206YZJP80IfMW0P1JFUX204M7A`80A4A40P0m?Cd2
05=CD`80F5QH00<0GemO06UYJ@1YJFT00P1`L702079bLP80M7Ad101fMWH208>3P`80Ng]k0P1oOgl2
08B4Q080PH61101oOgl408>3P`H0QXJ60P27QhL608f=S@80T92@0P2=SHd209:BTP80SHf=0P2CTi<2
092@T080TI6A0P2DU9@209bLW00309NGU`2FUYH0UYJF0080V9RH0P2KVi/409bLW080UiNG0P2LW9`2
09fMW@80WYjN0P2KVi/209jNWP80WIfM0P2NWYh20:FUY@@0WYjN0P2OWil209bLW080XZ:R0P2MWId2
09ZJVP80UiNG0P2DU9@209VIV@80Shn?0P2ATI4208n?S`80Ph>30P1eMGD206][J`80LW9b00<0N7Qh
07emO@1mOGd00P25QHD208n?S`80SHf=0P2;Rh/208V9R@80R8R80P2:RXX209:BTP80SHf=0P2?Shl2
092@T080S8b<0P23Ph<207inOP80N7Qh9`38h=P202/[:`809BDU0P0R8R8201PH60807QhN0P14A4@2
09FEU@80YZJV0P2XZ:P20:FUY@80Xj>S0P2UYJD00`2PX:00W9bL09bLW00209ZJVP80UiNG0P2DU9@2
0:BTY080^;Rh0P2k^k/20;Zj^P80Z:RX0P2DU9@206e]K@80BTY:0P0S8b<201lO7`807QhN0P0U9BD2
02LW9`80;2`/0P0a<C4202XZ:P80;Bd]0P0_;bl2024Q8@80:BTY0P0i>CT00`1MGEd0HV9R069RHP02
06ATI080EEEE1012@T8204A4A080CDe=0P1MGEd205mOG`80IFEU0P1/K6`207AdM080MGEe0P1iNGT2
07inOP80Ng]k0P1oOgl207emO@80Ph>30P21PH4208:2PP80Ph>30P1nOWh508B4Q0@0RXZ:102>SXh4
08b<S080TY:B0P2CTi<2092@T080SXj>102CTi<209JFUP80UiNG102EUID209RHV080VYZJ0P2IVIT2
09^KV`80WIfM0P2LW9`20:6QX@80WYjN00<0W9bL09nOW`2OWil00P2LW9`20:6QX@80WinO0P2QXJ42
09fMW@80Vi^K0P2PX:020:6QX@80WinO0P2LW9`209:BTP80UIFE0P2>SXh208f=S@80TY:B0P2;Rh/2
07YjNP80Kfm_0P1]KFd2079bLP80NGUi0P1nOWh208F5Q@80QhN700<0SHf=08Z:RP2:RXX0102=SHd2
08b<S080SXj>0P2;Rh/2092@T080Ti>C0P2>SXh208V9R@80NWYj0P1lO7`N0<SPf0007038h=P202`/
;080:b/[0P0Y:BT201hN7P80820P0P0Z:RX207MgM`80/K6a0P2PX:020:FUY@80XJ6Q0P2LW9`00`2F
UYH0Shn?08n?S`0208N7Q`80OGem0P1eMGD207MgM`80PH610P2LW9`20;Jf]P80_;bl0P2c/k<208b<
S080I6AT0P0Q8B4202DU9@807alO0P0T92@202LW9`80:RXZ0P0Y:BT202PX:080:RXZ0P0_;bl201dM
7@80<C4a0P0Z:RX00`1RHV80IfMW06MWI`0206QXJ080F5QH0P17AdL204=3@`80ADE50P1=CDd205QH
F080GemO0P1VIVH206a/K080LG5a0P1dM7@207MgM`80Ng]k0P1nOWh207emO@80O7al0P1oOgl60861
P@80PX:20P23Ph<00`25QHD0QhN708N7Q`0208R8R080RHV90P2;Rh/208j>SP@0T92@0P2?Shl208j>
SP80Shn?0P2ATI4209>CT`80U9BD0P2FUYH409NGU`80UYJF0P2HV9P209^KV`80WIfM1P2NWYh209fM
W@<0WYjN0P2OWil80:2PX080WYjN0P2MWId209nOW`80XJ6Q0P2NWYh209ZJVP80UYJF0P2BTY82096A
T@80Shn?0P2>SXh208Z:RP80Ogmo0P1dM7@206i^KP80KFe]0P1eMGD207inOP80Q8B40P29RHT00`2=
SHd0SXj>08j>SP0208^;R`80R8R80P2:RXX208f=S@@0Shn?0P2>SXh208Z:RP80Ph>30P1lO7`207]k
NbL0b>3H0P0V9RH2034a<@809bLW0P0P8202024Q8@80:RXZ0P1hN7P20:VYZ@80XJ6Q0P2VYZH20:BT
Y080VIVI0P2FUYH209:BTP80PH6100<0P82007EeM@1eMGD00P1gMgL208:2PP80XJ6Q0P2[Zj/20;fm
_@80/K6a0P2ATI4206EUI@80<C4a1P0T92@202PX:0809RHV0P0b<S8202LW9`808b<S0P0W9bL202PX
:0809BDU0P0/;2`205eMG@80LG5a0P1SHf<205UIF@80@d=30P15ADD204Y:BP80C4a<0P1LG5`00`1J
FUX0JFUY06UYJ@0206e]K@80Kfm_0P1dM7@207QhN080Ng]k0P20P80207QhN080OGem0P1oOgl208:2
PP80P8200P21PH4208F5Q@80PH610P23Ph<208R8R080QhN70P29RHT208b<S080Rh^;0P2BTY8208n?
S`@0T92@102?Shl209>CT`80UIFE102GUiL00`2FUYH0VIVI09VIV@0209FEU@80V9RH0P2QXJ4209^K
V`80WIfM0P2OWil209bLW0X0WinO0P2RXZ8209nOW`80WYjN0P2OWil209fMW@80XJ6Q0P2NWYh209ZJ
VP80UIFE102BTY82092@T080Rh^;0P2<S8`207inOP80N7Qh0P1XJ6P2071`L00307IfMP1mOGd0OGem
00@0QXJ6102=SHd208j>SP80RHV90P2<S8`208f=S@80S8b<0P2@T90208j>SP80RXZ:0P22PX8207al
O080NGUi9`38h=P202d];@80;2`/0P0Z:RX201dM7@807alO0P0^;Rh207EeM@80/;2`0P2QXJ440:>S
X`80X:2P00<0UiNG08j>SP2>SXh00P27QhL207moO`80MGEe0P1dM7@20820P080W9bL0P2d];@20;Vi
^@80/[:b0P2>SXh205mOG`808b<S0P0V9RH2024Q8@8092@T0P0V9RH202LW9`80:BTY0P0X:2P202/[
:`80<30`0P0L71`2030`<080;bl_00<0GUiN06UYJ@1YJFT00P1YJFT205eMG@80B4Q81014A4@204i>
CP80F5QH0P1MGEd206QXJ080Kfm_0P1`L70407=cL`80NWYj0P1lO7`20861P@80NGUi1P1oOgl20820
P080PH610P23Ph<00`26QXH0QhN708N7Q`0208^;R`80QXJ60P2=SHd2092@T080SXj>0P2BTY8208b<
S080Shn?0P2<S8`2096AT@@0U9BD0P2HV9P209ZJVP80UiNG102FUYH209RHV080WIfM0P2NWYh409fM
W@80X:2P0P2LW9`00`2MWId0WinO09nOW`0209nOW`80X:2P0P2SXj<209fMW@80WinO0P2MWId209bL
W080WinO0P2QXJ4209RHV080UIFE0P2BTY8209BDU080SXj>0P2?Shl208^;R`80OGem0P1iNGT406e]
K@80LG5a0P1mOGd208>3P`80R8R800<0Ti>C08n?S`2?Shl00P29RHT208N7Q`80Rh^;0P2?Shl2092@
T080S8b<0P2?Shl208J6QP80Ph>30P1iNGT207inOQh0b>3H000L0<SPf080;2`/0P0[:b/202TY:@80
7QhN0P0P820202XZ:P80MgMg0P2a/K420:2PX080YJFU0P2QXJ4209bLW00309JFUP2?Shl0Shn?0080
QhN70P1mOGd207EeM@80MgMg0P21PH4209bLW080][Jf0P2l_;`20;>c/`80S8b<0P1TI6@2024Q8@80
9BDU0P0O7al202@T90809bLW0P0Z:RX202TY:@80:2PX0P0Z:RX202l_;`807AdM0P0a<C4202XZ:P03
069RHP1WIfL0IfMW0080J6QX0P1HF5P204M7A`80@d=30P15ADD204e=C@80F5QH0P1OGel206IVIP80
K6a/0P1aLG4207AdM080MgMg0P1kNg/207inOP80OGem0P1lO7`207moO`H0PH610P22PX8208>3P`03
08F5Q@27QhL0QhN70080R8R80P29RHT208^;R`80SXj>102@T90208n?S`80SXj>0P2?Shl2096AT@80
Ti>C0P2DU9@209JFUP@0UiNG0P2FUYH209RHV080Vi^K0P2MWId609jNWP80WIfM0`2NWYh209nOW`P0
X:2P0P2NWYh209fMW@80WinO0P2QXJ4209jNWP80VYZJ0P2FUYH209:BTP80TI6A0P2?Shl208j>SP80
RXZ:0P1oOgl207AdM080KVi^0P1]KFd207EeM@80OWin0P24Q8@208V9R@0308f=S@2>SXh0SXj>0080
Rh^;0P28R8P208Z:RP80SHf=102?Shl208j>SP80RXZ:0P23Ph<207alO080Ng]k9`38h=P202HV9P80
<C4a0P0W9bL2020P80808B4Q0P0Z:RX207QhN080ZJVY0P2QXJ420:JVYP80Y:BT0P2IVIT209JFUP80
TY:B0P21PH400`20P800MGEe07EeM@0207MgM`80PX:20P2QXJ420:^[Z`80_Kfm0P2a/K42096AT@80
IFEU0P0a<C4602@T9080:2PX0P0V9RH2038b<P809bLW0P0S8b<202LW9`80:2PX0P0U9BD202`/;080
GEeM0P1aLG4206=SH`80FEUI0P13@d<204E5A@80BTY:0P1<C4`205aLG00305YJFP1YJFT0JFUY0080
KFe]0P1_Kfl207AdM080N7Qh0P1kNg/20820P080N7Qh0P1mOGd207moO`80PX:20P20P8020861P@80
QHF50P21PH4208>3P`80R8R80P27QhL208V9R@80S8b<0P2;Rh/209:BTP80Shn?102@T90408n?S`80
Ti>C0P2EUID409NGU`0309JFUP2IVIT0VIVI0080UIFE0P2HV9P20:6QX@80Vi^K0P2MWId209nOW`80
W9bL2P2OWil20::RXP80WinO0P2NWYh209nOW`80WIfM0P2QXJ4209jNWP80VYZJ0P2EUID409:BTP80
T92@0P2;Rh/208b<S080OWin0P1hN7P206QXJ080L71`00<0MWIf07emO@1mOGd01026QXH408f=S@80
SXj>0P29RHT208b<S080SHf=0P2<S8`2092@T080SXj>0P2:RXX208:2PP80O7al0P1iNGTW0<SPf080
;Bd]0P0/;2`202XZ:P807AdM0P0O7al202h^;P80MGEe0P2`/;020:6QX@@0Xj>S0P2PX:000`2GUiL0
SXj>08j>SP0208N7Q`80Ogmo0P1eMGD207AdM080P8200P2LW9`20;Bd]080^KVi0P2b/[8208j>SP80
GemO0P0S8b<202HV9P808B4Q0P0T92@202HV9P809bLW0P0Y:BT202PX:080:b/[0P0`<30201`L7080
<30`0P0_;bl00`1NGUh0JFUY06UYJ@0206UYJ@80GEeM0P18B4P404A4A080CTi>0P1HF5P205eMG@80
J6QX0P1_Kfl2071`L0@0Lg=c0P1jNWX207alO080PH610P1iNGT607moO`80P8200P21PH4208>3P`03
08J6QP27QhL0QhN70080Rh^;0P26QXH208f=S@80T92@0P2>SXh209:BTP80S8b<0P2?Shl208b<S080
TI6A102DU9@209RHV080VYZJ0P2GUiL409JFUP80V9RH0P2MWId209jNWP@0WIfM0P2PX:0209bLW003
09fMW@2OWil0WinO0080WinO0P2PX:020:>SX`80WIfM0P2OWil209fMW@80W9bL0P2OWil20:6QX@80
V9RH0P2EUID209:BTP80U9BD0P2>SXh208n?S`80Rh^;0P1mOGd207UiN@@0KFe]0P1aLG4207emO@80
Ph>30P28R8P00`2CTi<0Shn?08n?S`0208V9R@80QhN70P2;Rh/208n?S`80T92@0P2<S8`208n?S`80
QXJ60P23Ph<207UiN@80OWin7P38h=P001`0b>3H0P0V9RH202TY:@80;2`/0P0S8b<4020P8080BTY:
0P23Ph<209:BTP80UIFE0P2BTY8208b<S00308B4Q01kNg/0Ng]k0080Lg=c0P1^KVh206e]K@80MGEe
0P1oOgl208B4Q080SXj>0P2LW9`20::RXP80X:2P0P1eMGD203Hf=P80=cLg0P0X:2P402<S8`809bLW
100Y:BT202HV9P80820P0P0n?Sh2028R8P808b<S00<0GUiN079bLP1bLW800P1LG5`2051@D080@d=3
0P14A4@204U9B@80Cdm?0P1FEUH205eMG@80I6AT0P1[Jf/2079bLP80M7Ad0P1eMGD207UiN@H0OGem
0P1oOgl20861P@@0P8200P22PX8208B4Q00308J6QP27QhL0QhN70080RHV90P2;Rh/208b<S080SHf=
0P2@T90209:BTP80T92@0P2?Shl2096AT@80Ti>C0P2EUID209NGU`@0V9RH102GUiL209RHV080VYZJ
0P2KVi/409bLW0H0WIfM00<0WYjN09nOW`2OWil0302PX:040:6QX@80WIfM0P2IVIT209NGU`80UIFE
0P2ATI4408f=S@80Rh^;0P20P80207AdM080Kfm_0P1]KFd207AdM080O7al0P23Ph<208R8R00308^;
R`2<S8`0S8b<0080RXZ:0P29RHT208^;R`@0SXj>0P2=SHd208V9R@80QHF50P21PH4207emO@80O7al
9`38h=P202DU9@80<30`0P0/;2`2024Q8@808R8R0P0U9BD204M7A`80S8b<0P2HV9P209ZJVP80UYJF
0P28R8P20861P@80MWIf0P1[Jf/00`1]KFd0I6AT06ATI00207IfMP80Ph>30P27QhL209:BTP80XZ:R
0P2][Jd209bLW080KVi^0P0g=cL202TY:@809BDU0P0V9RH402<S8`809bLW0P0^;Rh202@T9080;bl_
0P16ATH202DU9@80;Rh^0P1GEeL2075aL@80Fe]K0P1>CTh204I6AP80@d=30P14A4@204i>CP80FEUI
00<0EeMG06=SH`1SHf<00P1[Jf/207IfMP80LW9b0P1gMgL207YjNP80Ng]k0P22PX8207inOP80O7al
0P22PX8207moO`80P8200P22PX8608J6QP80S8b<0P28R8P208n?S`80SXj>102ATI4208f=S@80SXj>
0P2?Shl209>CT`80W9bL0P2CTi<209VIV@<0UYJF0P2EUID209NGU`80VYZJ0P2MWId209bLW080WinO
0P2LW9`209nOW`80W9bL0P2MWId409jNWP80X:2P0P2RXZ8209jNWP80WinO0P2MWId409nOW`80WIfM
0P2JVYX209:BTP80Ti>C0P2>SXh208^;R`80SHf=0P2:RXX207emO@80M7Ad0P1[Jf/206e]K@0307Ad
M01mOGd0OGem0080Ph>30P27QhL208Z:RP80SHf=0P2;Rh/208R8R080Rh^;0P2@T90208f=S@80Shn?
0P28R8P208J6QP@0P8200P1mOGdW0<SPf08092@T0P0Y:BT202h^;P807QhN0P0P8202028R8P80BTY:
0P27QhL209BDU080TY:B0P2?Shl2096AT@0308:2PP1gMgL0MgMg0080Lg=c101`L70207IfMP80PH61
0P25QHD208j>SP80XJ6Q0P2TY:@20:>SX`80MGEe0P0g=cL203Hf=P80:RXZ0P0Q8B4202HV9P80:b/[
0P0X:2P202LW9`809RHV0P0P820203/k>`807alO0P0Y:BT00`1MGEd0Kfm_06m_K`0205aLG080D51@
0P10@40204=3@`80BTY:0P1>CTh205MGE`80F5QH0P1TI6@206YZJP80Lg=c0P1aLG4207]kN`80NGUi
0P1nOWh207moO`80OGem0P20P80208B4Q080PX:20P21PH4208F5Q@80Ph>300<0QXJ608B4Q024Q8@0
0P29RHT208N7Q`@0Rh^;0P2@T90209>CT`80TY:B0P2>SXh209>CT`80UYJF0P2CTi<209NGU`80UIFE
0P2FUYH209RHV080VIVI0P2KVi/:09bLW080VIVI0P2PX:000`2MWId0WinO09nOW`0209nOW`80WYjN
0P2SXj<209nOW`80Xj>S0P2PX:020::RXP80WinO0P2JVYX209bLW080UIFE102DU9@208n?S`80SHf=
0P2@T9020820P080MGEe0P1]KFd2071`L080MWIf0P20P80208B4Q080R8R800<0SHf=08V9R@29RHT0
0P27QhL208Z:RP@0SXj>0P2<S8`208n?S`80S8b<0P23Ph<20861P@80OGem0P1lO7`N0<SPf0007038
h=P202HV9P80:BTY0P0/;2`202<S8`@0820P0P1:BTX208>3P`80TY:B0P2EUID209:BTP80S8b<00<0
Q8B407]kN`1kNg/00P1cLg<206i^KP80KFe]0P1eMGD207moO`80Q8B40P2>SXh209bLW080XZ:R0P2P
X:0207EeM@80=SHf0P0g=cL202PX:0@08b<S0P0W9bL402TY:@809RHV0P0P820203hn?P808R8R0P0S
8b<00`1NGUh0LW9b079bLP0205aLG080D51@0P13@d<204A4A080BDU90P1?Cdl205IFEP80GEeM0P1T
I6@206][J`80LW9b0P1dM7@207EeM@80NGUi1P1mOGd207moO`80PH611020P80208:2PP80Q8B400<0
QXJ608N7Q`27QhL00P29RHT208^;R`80S8b<0P2=SHd2092@T080TY:B0P2@T90208n?S`80TI6A0P2C
Ti<209FEU@80UiNG102HV9P409NGU`80V9RH0P2JVYX209^KV`@0W9bL1P2MWId00`2NWYh0WinO09nO
W`0<0:2PX0@0XJ6Q0P2MWId209VIV@80UiNG0P2EUID2096AT@@0SHf=0P2;Rh/20820P080M7Ad0P1_
Kfl206e]K@80M7Ad0P1lO7`208>3P`80R8R800<0Rh^;08b<S02<S8`00P2:RXX208V9R@80Rh^;102>
SXh208f=S@80RHV90P25QHD20861P@80OGem0P1lO7`W0<SPf0809BDU0P0`<30202`/;0808B4Q0P0R
8R8202DU9@80AdM70P2<S8`209RHV080VYZJ0P2FUYH208R8R080PH610P1fMWH206][J`0306e]K@1T
I6@0I6AT0080MWIf0P23Ph<208N7Q`80TY:B0P2RXZ820:f][@80W9bL0P1^KVh203Lg=`80:BTY0P0U
9BD202HV9P@08b<S0P0W9bL202h^;P8092@T0P0_;bl204I6AP809BDU0P0^;Rh205MGE`80LG5a0P1K
Fe/204i>CP80ATI60P13@d<204A4A080CTi>0P1IFET00`1GEeL0Hf=S06=SH`0206][J`80MWIf0P1b
LW8207MgM`80NWYj0P1kNg/208:2PP80OWin0P1lO7`208:2PP80Ogmo0P20P80208:2PPH0QXJ60P2<
S8`208R8R080Shn?0P2>SXh4096AT@80SHf=0P2>SXh208n?S`80Ti>C0P2LW9`209>CT`80VIVI0`2F
UYH209FEU@80UiNG0P2JVYX209fMW@80W9bL0P2OWil209bLW080WinO0P2LW9`209fMW@@0WYjN0P2P
X:020::RXP80WYjN0P2OWil209fMW@@0WinO0P2MWId209ZJVP80TY:B0P2CTi<208j>SP80Rh^;0P2=
SHd208Z:RP80OGem0P1dM7@206][J`80KFe]00<0M7Ad07emO@1mOGd00P23Ph<208N7Q`80RXZ:0P2=
SHd208^;R`80R8R80P2;Rh/2092@T080SHf=0P2?Shl208R8R080QXJ61020P80207emOBL0b>3H0P0T
92@202TY:@80;Rh^0P0N7Qh2020P80808R8R0P1:BTX208N7Q`80U9BD0P2BTY8208n?S`80TI6A00<0
PX:207MgM`1gMgL00P1cLg<4071`L080MWIf0P21PH4208F5Q@80SXj>0P2QXJ420:BTY080Xj>S0P1e
MGD203Lg=`80=SHf0P0Z:RX2024Q8@809RHV0P0[:b/202PX:0809bLW0P0V9RH2020P8080>c/k0P0O
7al202TY:@0305eMG@1_Kfl0Kfm_0080G5aL0P1@D5020410@080@d=30P1:BTX204i>CP80EeMG0P1H
F5P206ATI080JVYZ0P1cLg<2075aL@80Ng]k0P1iNGT207inOP80Ogmo0P1mOGd20820P080Q8B40P22
PX820861P@80QHF50P23Ph<00`26QXH0Q8B408B4Q00208V9R@80QhN7102;Rh/2092@T080Ti>C0P2B
TY8208j>SP80Ti>C0P2FUYH209>CT`80UiNG0P2EUID209JFUP80V9RH0P2IVIT209^KV`X0W9bL0P2I
VIT20:2PX00309fMW@2OWil0WinO0080WinO0P2NWYh20:>SX`80WinO0P2SXj<20:2PX080XZ:R0P2O
Wil209ZJVP80W9bL0P2EUID409BDU080Shn?0P2=SHd2092@T080P8200P1eMGD206e]K@80L71`0P1f
MWH20820P080Q8B40P28R8P00`2=SHd0RHV908V9R@0208N7Q`80RXZ:102>SXh208b<S080Shn?0P2<
S8`208>3P`80PH610P1mOGd207alO1h0b>3H000L0<SPf0807alO0P0W9bL202h^;P80:2PX0P0R8R82
01hN7P808b<S0P1>CTh207alO080P8200P1mOGd207alO00307MgM`1/K6`0K6a/0080I6AT0P1RHV82
06][J`80U9BD0P2j^[X20;Bd]080YJFU0P2JVYX208f=S@80Zj^[0P27QhL204m?C`80BTY:0P0`<302
024Q8@80820P0P0U9BD202HV9P80:2PX0P0[:b/202l_;`8071`L0P0_;bl202LW9`0305MGE`1fMWH0
MWIf0080DE5A0P18B4P203hn?P80A4A40P1=CDd2055AD@80EEEE0P1KFe/2065QH@80JVYZ0P1bLW84
07AdM080N7Qh0P1lO7`207emO@80OWin0P1oOgl40820P080Ogmo0P23Ph<308J6QP80QhN70P2:RXX6
08b<S080Shn?0P2BTY84096AT@80Ti>C0P2EUID209NGU`80VIVI0P2JVYX209VIV@80V9RH0P2GUiL2
09RHV080VYZJ102IVIT209ZJVP80W9bL0P2MWId309jNWP@0WinO0P2PX:040:6QX@80XZ:R0P2SXj<2
0::RXP80X:2P0P2LW9`209VIV@@0V9RH0P2BTY8208b<S080SHf=0P2<S8`20861P@80MWIf0P1`L702
06m_K`80M7Ad0P1jNWX20820P080QHF51`28R8P208Z:RP80S8b<0P2:RXX208N7Q`80Ph>30P20P804
07inOP80OGem9`38h=P402@T9080<S8b0P0V9RH2028R8P807QhN0P0R8R8204a<C080N7Qh0P23Ph<2
07QhN0@0NWYj0P1WIfL206EUI@<0K6a/0P2@T9020;Fe]@80[Jf]0P2SXj<208f=S@80T92@0P2JVYX2
08N7Q`80FUYJ0P15ADD202d];@808b<S0P0R8R8202/[:`809BDU0P0[:b/402PX:0808R8R0P0S8b<2
02h^;P80FUYJ0P1]KFd205YJFP80@d=30P10@40204];B`80CTi>0P1ADE4205=CD`<0GemO0P1ZJVX2
07AdM080LG5a101fMWH207emO@80Ogmo0P1mOGd207alO080PX:20P1mOGd20861P@80Ph>30P26QXH2
08F5Q@80QhN70P2;Rh/208f=S@80RXZ:0P2;Rh/208n?S`80U9BD0P2CTi<209BDU080Shn?0P2CTi<2
09^KV`@0UiNG0P2JVYX00`2HV9P0UYJF09JFUP0409ZJVP80UYJF0P2IVIT209bLW080VYZJ0P2OWil2
09VIV@80XZ:R0P2OWil209bLW080XJ6Q0P2OWil20::RXP80Y:BT0P2SXj<40:6QX@80Vi^K0P2IVIT2
09RHV080VIVI0P2BTY8208b<S080Rh^;0P2?Shl207moO`80MgMg0P1bLW8206i^KP0307=cL`1lO7`0
O7al0080P8200P27QhL208J6QP80Rh^;0P28R8P208Z:RP80RHV90P2;Rh/208n?S`@0Q8B40P21PH42
07alO080OGem0P1oOglW0<SPf0808R8R0P0U9BD2034a<@80:BTY0P0S8b<201XJ6P808b<S0P1?Cdl2
07YjNP80Ogmo0P20P80307UiN@80KFe]0P1TI6@205mOG`80JFUY0P2EUID20;Zj^P80/K6a0P2SXj<2
09bLW080SHf=0P2[Zj/208R8R080C4a<0P1;Bd/2034a<@80820P0P0O7al2028R8P809RHV0P0Y:BT2
02`/;080<C4a0P0K6a/202d];@80:b/[00<0EUIF07=cL`1cLg<00P1ADE4204a<C080@4100P12@T82
04e=C@80DE5A0P1DE5@205aLG080HF5Q0P1/K6`207EeM@80KFe]0P1eMGD207MgM`80OGem0P1nOWh2
07emO@80Ogmo0P22PX8207alO080Ogmo0P21PH4208F5Q@0308N7Q`2:RXX0RXZ:0080R8R80P2>SXh4
08f=S@80T92@0P2DU9@208n?S`80Ti>C0P2BTY8209FEU@@0VIVI0P2JVYX209RHV080VYZJ0P2GUiL2
09>CT`80VIVI0P2MWId209NGU`80WYjN0P2LW9`209fMW@80W9bL00<0WinO09fMW@2MWId00P2OWil2
0:2PX080XZ:R0P2PX:020:>SX`H0XJ6Q0P2MWId209RHV080VYZJ0P2GUiL209:BTP80S8b<0P2;Rh/2
08f=S@80PH610P1fMWH4071`L080LW9b0P1iNGT20820P080QXJ600<0QhN708^;R`2;Rh/01027QhL4
08f=S@80QhN70P28R8P208F5Q@80Ogmo0P1lO7`407inOQh0b>3H000L0<SPf0807alO0P0W9bL202h^
;P80:2PX0P0R8R8201hN7P808b<S0P1>CTh207alO080P8200P1mOGd207alO00307MgM`1/K6`0K6a/
0080I6AT0P1RHV8206][J`80U9BD0P2j^[X20;Bd]080YJFU0P2JVYX208f=S@80Zj^[0P27QhL204m?
C`80BTY:0P0`<302024Q8@80820P0P0U9BD202HV9P80:2PX0P0[:b/202l_;`8071`L0P0_;bl202LW
9`0305MGE`1fMWH0MWIf0080DE5A0P18B4P203hn?P80A4A40P1=CDd2055AD@80EEEE0P1KFe/2065Q
H@80JVYZ0P1bLW8407AdM080N7Qh0P1lO7`207emO@80OWin0P1oOgl40820P080Ogmo0P23Ph<308J6
QP80QhN70P2:RXX608b<S080Shn?0P2BTY84096AT@80Ti>C0P2EUID209NGU`80VIVI0P2JVYX209VI
V@80V9RH0P2GUiL209RHV080VYZJ102IVIT209ZJVP80W9bL0P2MWId309jNWP@0WinO0P2PX:040:6Q
X@80XZ:R0P2SXj<20::RXP80X:2P0P2LW9`209VIV@@0V9RH0P2BTY8208b<S080SHf=0P2<S8`20861
P@80MWIf0P1`L70206m_K`80M7Ad0P1jNWX20820P080QHF51`28R8P208Z:RP80S8b<0P2:RXX208N7
Q`80Ph>30P20P80407inOP80OGem9`38h=P402@T9080<S8b0P0V9RH2028R8P807QhN0P0R8R8204a<
C080N7Qh0P23Ph<207QhN0@0NWYj0P1WIfL206EUI@<0K6a/0P2@T9020;Fe]@80[Jf]0P2SXj<208f=
S@80T92@0P2JVYX208N7Q`80FUYJ0P15ADD202d];@808b<S0P0R8R8202/[:`809BDU0P0[:b/402PX
:0808R8R0P0S8b<202h^;P80FUYJ0P1]KFd205YJFP80@d=30P10@40204];B`80CTi>0P1ADE4205=C
D`<0GemO0P1ZJVX207AdM080LG5a101fMWH207emO@80Ogmo0P1mOGd207alO080PX:20P1mOGd20861
P@80Ph>30P26QXH208F5Q@80QhN70P2;Rh/208f=S@80RXZ:0P2;Rh/208n?S`80U9BD0P2CTi<209BD
U080Shn?0P2CTi<209^KV`@0UiNG0P2JVYX00`2HV9P0UYJF09JFUP0409ZJVP80UYJF0P2IVIT209bL
W080VYZJ0P2OWil209VIV@80XZ:R0P2OWil209bLW080XJ6Q0P2OWil20::RXP80Y:BT0P2SXj<40:6Q
X@80Vi^K0P2IVIT209RHV080VIVI0P2BTY8208b<S080Rh^;0P2?Shl207moO`80MgMg0P1bLW8206i^
KP0307=cL`1lO7`0O7al0080P8200P27QhL208J6QP80Rh^;0P28R8P208Z:RP80RHV90P2;Rh/208n?
S`@0Q8B40P21PH4207alO080OGem0P1oOglW0<SPf0808R8R0P0U9BD2034a<@80:BTY0P0S8b<201XJ
6P808b<S0P1?Cdl207YjNP80Ogmo0P20P80307UiN@80KFe]0P1TI6@205mOG`80JFUY0P2EUID20;Zj
^P80/K6a0P2SXj<209bLW080SHf=0P2[Zj/208R8R080C4a<0P1;Bd/2034a<@80820P0P0O7al2028R
8P809RHV0P0Y:BT202`/;080<C4a0P0K6a/202d];@80:b/[00<0EUIF07=cL`1cLg<00P1ADE4204a<
C080@4100P12@T8204e=C@80DE5A0P1DE5@205aLG080HF5Q0P1/K6`207EeM@80KFe]0P1eMGD207Mg
M`80OGem0P1nOWh207emO@80Ogmo0P22PX8207alO080Ogmo0P21PH4208F5Q@0308N7Q`2:RXX0RXZ:
0080R8R80P2>SXh408f=S@80T92@0P2DU9@208n?S`80Ti>C0P2BTY8209FEU@@0VIVI0P2JVYX209RH
V080VYZJ0P2GUiL209>CT`80VIVI0P2MWId209NGU`80WYjN0P2LW9`209fMW@80W9bL00<0WinO09fM
W@2MWId00P2OWil20:2PX080XZ:R0P2PX:020:>SX`H0XJ6Q0P2MWId209RHV080VYZJ0P2GUiL209:B
TP80S8b<0P2;Rh/208f=S@80PH610P1fMWH4071`L080LW9b0P1iNGT20820P080QXJ600<0QhN708^;
R`2;Rh/01027QhL408f=S@80QhN70P28R8P208F5Q@80Ogmo0P1lO7`407inOQh0b>3H000L0<SPf080
8b<S0P0Y:BT202l_;`80;Bd]0P0Y:BT2024Q8@806QXJ0P0b<S82051@D080K6a/0P1RHV8207=cL`03
07inOP1bLW80LW9b00@0JVYZ0P1cLg<2096AT@80[Jf]0P3:b/X20;Ng]`80WYjN0P1nOWh208f=S@80
NGUi0P0X:2P201`L70806ATI0P0S8b<202@T90H09RHV0P0Y:BT202`/;0808b<S0P0[:b/202PX:003
05aLG01]KFd0KFe]0080EUIF0P18B4P203/k>`80@T920P1=CDd2055AD@80EEEE0P1KFe/2069RHP80
JFUY0P1`L702079bLP80M7Ad0P1hN7P207]kN`80OGem0P1nOWh20820P0@0PH610P22PX8208B4Q080
QXJ60`27QhL408R8R080RHV90P2;Rh/208j>SP80TY:B102CTi<209BDU080UIFE0P2GUiL409VIV@80
V9RH0P2GUiL209JFUP80V9RH0P2IVIT409ZJVP80W9bL102OWil50:2PX080XJ6Q1P2RXZ820:>SX`80
Y:BT0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080UYJF0P2BTY8208j>SP80Shn?0P2>SXh208J6QP80
O7al0P1fMWH2079bLP80M7Ad0P1hN7P207inOP80Ph>300<0QXJ608N7Q`27QhL01028R8P208N7Q`80
QXJ60P23Ph<20861P@80OWin101lO7`407emOBL0b>3H100S8b<2030`<080;bl_0P0[:b/201hN7P80
8b<S0P0X:2P2055AD@80IFEU0P1WIfL207inOP80QHF50P1ZJVX206i^KP<0LW9b0P2@T9020;Vi^@80
bLW90P33`l<20:JVYP80PX:20P2GUiL207emO@80=3@d0P0T92@202<S8`807alO0P0N7Qh202<S8`80
:BTY0P0U9BD2028R8P80:RXZ0P0U9BD202TY:@80:RXZ0P1LG5`206a/K080G5aL0P11@D4203Ph>080
AdM70P18B4P204m?C`80EUIF00<0GEeM06MWI`1WIfL00P1XJ6P206a/K080Lg=c101eMGD207UiN@80
OGem0P1oOgl20820P080Q8B40P22PX8208>3P`80PX:20P27QhL208F5Q@80R8R80P26QXH208N7Q`80
S8b<0P2;Rh/208f=S@80T92@0P2ATI4409>CT`80UIFE0P2JVYX209^KV`80VIVI0`2HV9P209NGU`80
VIVI0P2JVYX209JFUP80VYZJ0P2MWId209jNWP80WIfM0P2RXZ820:>SX`80WinO0P2RXZ820:JVYP80
WYjN0P2RXZ840:BTY080Xj>S0P2QXJ4209fMW@80W9bL102HV9P209JFUP80TI6A0P2@T90208j>SP80
QHF50P1lO7`207UiN@80MGEe00<0LW9b07IfMP1fMWH00P1lO7`208B4Q080QHF50P23Ph<208N7Q`80
QXJ60P24Q8@208>3P`80PX:20P1oOgl208B4Q080NGUi101kNg/20861PBL0b>3H0P0W9bL202DU9@80
<30`100[:b/202@T908061PH0P0e=CD204i>CP80K6a/0P1SHf<207MgM`0307alO01dM7@0M7Ad00@0
Jf][0P1gMgL208n?S`80[:b/0P39bLT20;^k^`80WYjN0P1lO7`208N7Q`80NWYj0P0Y:BT201`L7080
6QXJ100U9BD202LW9`809BDU0P0W9bL202HV9P80;Bd]0P0R8R8202d];@80:b/[00<0GEeM06][J`1[
Jf/00P1HF5P204];B`80>CTi0P0n?Sh204a<C080DU9B0P1FEUH205eMG@80HF5Q0P1YJFT206m_K`80
Lg=c0P1eMGD207QhN080MWIf0P1mOGd207inOP80PH610P1nOWh207moO`80Ph>30P28R8P208F5Q@03
08N7Q`25QHD0QHF50080QXJ60P2;Rh/208V9R@80Rh^;0P2<S8`2096AT@80Shn?0P2GUiL208j>SP@0
UYJF0P2LW9`209NGU`80VYZJ0P2GUiL409FEU@80V9RH0P2KVi/209NGU`80VYZJ1P2PX:000`2TY:@0
XJ6Q0:6QX@040::RXP80XJ6Q0P2PX:060:BTY080XJ6Q0P2KVi/209ZJVP@0UiNG0P2DU9@208f=S@80
S8b<0P2;Rh/208J6QP80O7al0P1fMWH206i^KP80MGEe0P1fMWH207emO@80Ph>300<0QXJ608N7Q`27
QhL00P27QhL208R8R080QHF50P26QXH40861P@80Ogmo0P20P80207alO080OGem0P1lO7`N0<SPf000
7038h=P202<S8`80:BTY0P0_;bl202d];@80:BTY0P0Q8B4201XJ6P80<S8b0P1@D50206a/K080HV9R
0P1cLg<00`1nOWh0LW9b079bLP0406YZJP80Lg=c0P2ATI420:f][@80b/[:0P2g]kL209jNWP80OWin
0P2=SHd207UiN@80:2PX0P0L71`201TI6@808b<S0P0T92@602HV9P80:BTY0P0/;2`202<S8`80:b/[
0P0X:2P00`1LG5`0KFe]06e]K@0205IFEP80B4Q80P0k>c/20492@P80CDe=0P1ADE4205EEE@80Fe]K
0P1RHV8206UYJ@80L71`0P1bLW8207AdM080N7Qh0P1kNg/207emO@80OWin0P20P8040861P@80PX:2
0P24Q8@208J6QP<0QhN71028R8P208V9R@80Rh^;0P2>SXh209:BTP@0Ti>C0P2DU9@209FEU@80UiNG
102IVIT209RHV080UiNG0P2FUYH209RHV080VIVI102JVYX209bLW0@0WinO1@2PX:020:6QX@H0XZ:R
0P2SXj<20:BTY080XZ:R0P2OWil209fMW@80VYZJ0P2HV9P209JFUP80TY:B0P2>SXh208n?S`80SXj>
0P26QXH207alO080MWIf0P1bLW8207AdM080N7Qh0P1nOWh208>3P`0308J6QP27QhL0QhN700@0R8R8
0P27QhL208J6QP80Ph>30P21PH4207inOP@0O7al101mOGdW0<SPf0@08b<S0P0`<30202l_;`80:b/[
0P0N7Qh202<S8`80:2PX0P1ADE4206EUI@80IfMW0P1nOWh208F5Q@80JVYZ0P1^KVh3079bLP80T92@
0P2i^KT20<W9b@80`l?30P2VYZH208:2PP80UiNG0P1mOGd203@d=08092@T0P0S8b<201lO7`807QhN
0P0S8b<202TY:@809BDU0P0R8R8202XZ:P809BDU0P0Y:BT202XZ:P80G5aL0P1/K6`205aLG080@D51
0P0h>3P204M7A`80B4Q80P1?Cdl205IFEP0305eMG@1WIfL0IfMW0080J6QX0P1/K6`207=cL`@0MGEe
0P1iNGT207emO@80Ogmo0P20P80208B4Q080PX:20P23Ph<208:2PP80QhN70P25QHD208R8R080QXJ6
0P27QhL208b<S080Rh^;0P2=SHd2092@T080TI6A102CTi<209FEU@80VYZJ0P2KVi/209VIV@<0V9RH
0P2GUiL209VIV@80VYZJ0P2FUYH209ZJVP80WIfM0P2NWYh209fMW@80XZ:R0P2SXj<209nOW`80XZ:R
0P2VYZH209jNWP80XZ:R102TY:@20:>SX`80XJ6Q0P2MWId209bLW0@0V9RH0P2FUYH2096AT@80T92@
0P2>SXh208F5Q@80O7al0P1iNGT207EeM@03079bLP1fMWH0MWIf0080O7al0P24Q8@208F5Q@80Ph>3
0P27QhL208J6QP80Q8B40P23Ph<208:2PP80Ogmo0P24Q8@207UiN@@0Ng]k0P21PH4W0<SPf0809bLW
0P0U9BD2030`<0@0:b/[0P0T92@201PH6080=CDe0P1>CTh206a/K080Hf=S0P1gMgL00`1lO7`0M7Ad
07AdM00406][J`80MgMg0P2?Shl20:b/[080bLW90P2k^k/209jNWP80O7al0P27QhL207YjNP80:BTY
0P0L71`201XJ6P@09BDU0P0W9bL202DU9@809bLW0P0V9RH202d];@808R8R0P0];Bd202/[:`0305eM
G@1[Jf/0Jf][0080F5QH0P1;Bd/203Ti>@80?Shn0P1<C4`2059BDP80EUIF0P1MGEd2065QH@80JFUY
0P1_Kfl207=cL`80MGEe0P1hN7P207IfMP80OGem0P1nOWh20861P@80OWin0P1oOgl208>3P`80R8R8
0P25QHD00`27QhL0QHF508F5Q@0208J6QP80Rh^;0P29RHT208^;R`80S8b<0P2ATI4208n?S`80UiNG
0P2>SXh409JFUP80W9bL0P2GUiL209ZJVP80UiNG102EUID209RHV080Vi^K0P2GUiL209ZJVPH0X:2P
00<0Y:BT0:6QX@2QXJ40102RXZ820:6QX@80X:2P1P2TY:@20:6QX@80Vi^K0P2JVYX409NGU`80U9BD
0P2=SHd208b<S080Rh^;0P26QXH207alO080MWIf0P1^KVh207EeM@80MWIf0P1mOGd208>3P`0308J6
QP27QhL0QhN70080QhN70P28R8P208F5Q@80QXJ61021PH4207moO`80P8200P1lO7`207emO@80O7al
7P38h=P001`0b>3H0P0X:2P202/[:`80;bl_100a<C4202HV9P8071`L0P0Q8B4202TY:@80EEEE0P16
ATH206][J`0308N7Q`1oOgl0Ogmo0080M7Ad0P1eMGD207]kN`80RXZ:0P2JVYX20=KFeP80bl_;0P35
aLD20;>c/`80[Zj^0P2TY:@204Q8B080;2`/0P0O7al2028R8P8092@T0P0X:2P202HV9P809BDU0P0W
9bL202TY:@809RHV0P0Y:BT202PX:0<0H61P0P1MGEd204Y:BP80>CTi0P10@40204a<C080DE5A0P1F
EUH205aLG080Hf=S0P1YJFT206i^KP80LW9b0P1eMGD207QhN080Ng]k0P1mOGd207inOP80P8200P22
PX8208>3P`80Q8B40P25QHD208J6QP0308N7Q`28R8P0R8R80080QXJ60P25QHD208N7Q`80RXZ:0P2=
SHd2096AT@80U9BD102FUYH209FEU@80UiNG102HV9P209NGU`80UYJF0P2GUiL209RHV080VYZJ0P2K
Vi/209bLW080WYjN1P2QXJ430::RXP80Xj>S0P2TY:@20:>SX`80XZ:R0P2SXj<20:BTY080XJ6Q0P2O
Wil209fMW@80W9bL0P2HV9P209FEU@80TY:B102ATI4208n?S`80RXZ:0P23Ph<207alO080MgMg0P1e
MGD207IfMP80O7al0P21PH400`25QHD0QXJ608J6QP0408N7Q`80Ph>30P1oOgl207emO@80O7al0P1k
Ng/207YjNP80Ng]k101lO7`W0<SPf0809BDU0P0a<C4202`/;080=cLg0P0_;bl201lO7`806a/K0P0Q
8B4202h^;P80Cdm?0P1;Bd/206e]K@80QhN70P1fMWH2079bLP030820P01kNg/0Ng]k0080OWin0P2N
WYh20<W9b@@0b/[:0P2[Zj/20:2PX080Xj>S0P0l?3`202PX:0808R8R0P0O7al202DU9@809bLW0P0[
:b/202LW9`809RHV0P0/;2`402DU9@80;2`/0P1IFET206YZJP80GEeM0P0m?Cd20492@P80AdM70P1=
CDd2059BDP80FEUI00<0F5QH06EUI@1UIFD00P1ZJVX206e]K@80MGEe0P1dM7@207IfMP80Ng]k0P1n
OWh207emO@@0P8200P21PH4608F5Q@80S8b<0P27QhL208:2PP80QHF50P2:RXX208V9R@80SHf=0P2D
U9@209:BTP80UiNG0P2FUYH209>CT`80VIVI0P2FUYH409NGU`0309RHV02FUYH0UYJF0080U9BD0P2K
Vi/209ZJVP80WYjN0P2OWil20::RXPH0X:2P0P2RXZ840:FUY@80WYjN0P2SXj<20:FUY@80XZ:R0P2M
WId209nOW`80WIfM0P2KVi/209RHV080TY:B0P2EUID408j>SP80T92@0P2:RXX208>3P`80O7al0P1g
MgL00`1bLW80NGUi07UiN@0207emO@80PX:21026QXH208^;R`80QhN70P23Ph<20861P@80OWin0P1k
Ng/207alO080NWYj0P1lO7`207]kN`80OWin9`38h=P202d];@80:2PX0P0c<c<2030`<080;Rh^0P0V
9RH201/K6`808b<S0P0V9RH205QHF080A4A40P1/K6`00`27QhL0OWin07inOP0207IfMP80M7Ad0P1i
NGT208^;R`80Vi^K0P3Bd]820<_;b`80aLG50P2g]kL20:ZZZP80YJFU0P17AdL202`/;0807QhN0P0S
8b<2028R8P80:b/[0P0T92@202HV9P80:2PX0P0[:b/202LW9`80:RXZ0P0W9bL00`1QHF40GUiN05iN
GP0205eMG@80BTY:0P0k>c/203lo?`80C4a<0P1@D50205IFEP80Fe]K0P1TI6@206YZJP80L71`0P1_
Kfl207MgM`80O7al1P1mOGd40861P@80QHF50P22PX8408F5Q@0308R8R027QhL0QhN70080RXZ:0P23
Ph<208:2PP80Rh^;0P2@T90209:BTP80Ti>C0P2GUiL209FEU@80VYZJ0P2FUYH209RHV080UiNG0P2I
VIT209FEU@80VYZJ0P2GUiL209VIV@80WYjN0P2LW9`209jNWP80XZ:R0P2SXj<20::RXP030:6QX@2P
X:00X:2P0080XZ:R0P2TY:@20:FUY@80XJ6Q0P2RXZ820:>SX`80XZ:R0P2NWYh209bLW080Vi^K0P2H
V9P209BDU080SXj>0P2BTY8209>CT`80Shn?0P2=SHd20820P080Ogmo0P1dM7@207MgM`80Lg=c0P1o
Ogl208>3P`0307moO`27QhL0QhN70080RHV90P27QhL208B4Q080P8200P1oOgl207emO@80NWYj0P1k
Ng/207YjNP80OWin0P1jNWXN0<SPf0007038h=P202PX:080:b/[0P0_;bl4034a<@809RHV0P0L71`2
024Q8@80:BTY0P1EEED204I6AP80Jf][00<0QhN707moO`1oOgl00P1dM7@207EeM@80Ng]k0P2:RXX2
09ZJVP80e]KF0P3;bl/20<G5a@80/k>c0P2^[Zh20:BTY080B4Q80P0/;2`201lO7`808R8R0P0T92@2
02PX:0809RHV0P0U9BD202LW9`80:BTY0P0V9RH202TY:@80:2PX0`1PH60205eMG@80BTY:0P0i>CT2
0410@080C4a<0P1ADE4205IFEP80G5aL0P1SHf<206UYJ@80KVi^0P1bLW8207EeM@80N7Qh0P1kNg/2
07emO@80OWin0P20P80208:2PP80Ph>30P24Q8@208F5Q@80QXJ600<0QhN708R8R028R8P00P26QXH2
08F5Q@80QhN70P2:RXX208f=S@80TI6A0P2DU9@409JFUP80UIFE0P2GUiL409RHV080UiNG0P2FUYH2
09NGU`80V9RH0P2JVYX209^KV`80W9bL0P2NWYh60:6QX@<0XZ:R0P2SXj<20:BTY080Xj>S0P2RXZ82
0:>SX`80Y:BT0P2QXJ4209nOW`80WIfM0P2LW9`209RHV080UIFE0P2BTY84096AT@80Shn?0P2:RXX2
08>3P`80O7al0P1gMgL207EeM@80MWIf0P1lO7`20861P@0308F5Q@26QXH0QXJ600@0QhN70P23Ph<2
07moO`80OGem0P1lO7`207]kN`80NWYj0P1kNg/407alO2L0b>3H0P0U9BD2034a<@80;2`/0P0g=cL2
02l_;`807alO0P0K6a/2024Q8@80;Rh^0P1?Cdl204];B`80KFe]0P27QhL207IfMP80LW9b00<0P820
07]kN`1kNg/00P1nOWh209jNWP80bLW9103:b/X20:^[Z`80X:2P0P2SXj<203`l?080:2PX0P0R8R82
01lO7`809BDU0P0W9bL202/[:`809bLW0P0V9RH202`/;0@09BDU0P0/;2`205UIF@80JVYZ0P1MGEd2
03dm?@80@T920P17AdL204e=C@80DU9B0P1IFET00`1HF5P0IFEU06EUI@0206YZJP80KFe]0P1eMGD2
07AdM080MWIf0P1kNg/207inOP80OGem1020P8020861P@H0QHF50P2<S8`208N7Q`80PX:20P25QHD2
08Z:RP80RHV90P2=SHd209BDU080TY:B0P2GUiL209JFUP80Ti>C0P2IVIT209JFUP@0UiNG00<0V9RH
09JFUP2FUYH00P2DU9@209^KV`80VYZJ0P2NWYh209nOW`80XZ:R1P2PX:020::RXP@0YJFU0P2NWYh2
0:>SX`80YJFU0P2RXZ8209fMW@80WinO0P2MWId209^KV`80V9RH0P2BTY8209FEU@@0SXj>0P2@T902
08Z:RP80Ph>30P1lO7`207MgM`03079bLP1iNGT0NGUi0080OGem0P22PX8408J6QP80Rh^;0P27QhL2
08>3P`80PH610P1nOWh207]kN`80O7al0P1jNWX207alO080Ng]k0P1nOWhW0<SPf080;Bd]0P0X:2P2
03<c<`80<30`0P0^;Rh202HV9P806a/K0P0S8b<202HV9P80F5QH0P14A4@206a/K00308N7Q`1nOWh0
OWin0080MWIf0P1dM7@207UiN@80Rh^;0P2KVi/20=;BdP80bl_;0P35aLD20;Ng]`80ZZZZ0P2UYJD2
04M7A`80;2`/0P0N7Qh202<S8`808R8R0P0[:b/202@T90809RHV0P0X:2P202/[:`809bLW0P0Z:RX2
02LW9`03065QH@1NGUh0GUiN0080GEeM0P1:BTX203/k>`80?clo0P1<C4`2051@D080EUIF0P1KFe/2
06ATI080JVYZ0P1`L70206m_K`80MgMg0P1lO7`607emO@@0PH610P25QHD208:2PP@0QHF500<0R8R8
08N7Q`27QhL00P2:RXX208>3P`80PX:20P2;Rh/2092@T080TY:B0P2CTi<209NGU`80UIFE0P2JVYX2
09JFUP80V9RH0P2GUiL209VIV@80UIFE0P2JVYX209NGU`80VIVI0P2NWYh209bLW080WYjN0P2RXZ82
0:>SX`80XZ:R00<0XJ6Q0:2PX02PX:000P2RXZ820:BTY080YJFU0P2QXJ420::RXP80Xj>S0P2RXZ82
09jNWP80W9bL0P2KVi/209RHV080U9BD0P2>SXh209:BTP80Ti>C0P2?Shl208f=S@80P8200P1oOgl2
07AdM080MgMg0P1cLg<207moO`80Ph>300<0Ogmo08N7Q`27QhL00P29RHT208N7Q`80Q8B40P20P802
07moO`80OGem0P1jNWX207]kN`80NWYj0P1nOWh207YjNQh0b>3H000L0<SPf08092@T0P0Y:BT202l_
;`80;Rh^0P0`<30202TY:@807QhN0P0O7al2024Q8@80=3@d0P0^;Rh205eMG@0308B4Q02BTY80TY:B
0080M7Ad0P1eMGD207QhN080Ogmo0P2;Rh/20<C4a080dM7A0P3<c<`20<71`@80`/;20P2k^k/207Yj
NP80=3@d0P0I6AT202<S8`8092@T0P0Y:BT202PX:0@09RHV0P0W9bL202@T90809bLW0P0V9RH00`1N
GUh0FUYJ05YJFP0205YJFP80BDU90P0k>c/20451@@80Bd];0P1BDU8205UIF@80GUiN0P1SHf<206UY
J@80Kfm_0P1cLg<207IfMP80N7Qh0P1jNWX207emO@80Ogmo0P21PH4408>3P`80Q8B40P25QHD308J6
QP80QhN70P29RHT608^;R`80SXj>0P2ATI4209BDU0@0UYJF0P2EUID209NGU`80V9RH0P2GUiL209JF
UP80V9RH102JVYX209^KV`@0W9bL0P2MWId209jNWP80WinO0P2QXJ400`2SXj<0YJFU0:FUY@020:FU
Y@80Y:BT0P2SXj<40:6QX@80XZ:R102QXJ4209nOW`80WIfM0P2JVYX209NGU`80U9BD0P2BTY82092@
T080SHf=0P29RHT208F5Q@80Ogmo0P1kNg/207YjNP80Ng]k0P1lO7`207inOP0308:2PP25QHD0QHF5
00@0QXJ60P21PH4407alO080OGem0P1kNg/407UiN@@0NWYj9`38h=P202XZ:P8092@T0P0Y:BT203Xj
>P80<S8b0P0Q8B4202<S8`80<30`0P0Q8B4202`/;080:2PX0P1LG5`208V9R@80RXZ:0P1eMGD307Qh
N080NGUi0P2BTY820;no_`80c<c<0P3>c/h20<[:bP80_kno0P35aLD207moO`80;bl_100R8R8202LW
9`80:b/[0P0Y:BT2028R8P80:2PX100W9bL202PX:080<30`0P1FEUH206ATI080FUYJ0P11@D4203Lg
=`80B4Q80P15ADD205=CD`80EeMG00<0G5aL061PH01PH6000P1VIVH2075aL@80MGEe101gMgL207em
O@H0P8200P27QhL608B4Q0@0QXJ60P2:RXX208N7Q`80S8b<0P2?Shl208J6QP@0T92@0P2BTY8209JF
UP80VIVI0P2CTi<209NGU`80UIFE0P2HV9P209BDU00309JFUP2JVYX0VYZJ0080WIfM0P2KVi/409bL
W080V9RH0P2NWYh20:>SX`80XZ:R0P2PX:020:FUY@@0Y:BT0P2PX:040:BTY080Xj>S0P2TY:@20:6Q
X@80WYjN0P2KVi/209fMW@@0U9BD0P2BTY8208n?S`80SXj>0P28R8P208F5Q@80OGem0P1lO7`00`1j
NWX0Ng]k07]kN`0207alO080Ng]k0P22PX8208>3P`80S8b<0P25QHD207emO@80Ogmo0P1kNg/207em
O@80OWin0P1iNGT207EeM@80NWYj0P1nOWhW0<SPf0808R8R0P0W9bL202l_;`80;2`/0P0e=CD202XZ
:P807AdM0P0L71`202<S8`80=CDe0P0/;2`205eMG@0308F5Q@2ATI40TI6A0080LG5a101dM7@208:2
PP80S8b<0P34a<@20=7Ad@80c/k>0P32`/820;no_`80`<300P1kNg/203De=@806QXJ100Q8B4202XZ
:P@09BDU0P0Y:BT202<S8`808B4Q0P0T92@202TY:@0305iNGP1GEeL0EeMG0080FUYJ0P19BDT203/k
>`80@D510P1@D50205EEE@80Fe]K0P1JFUX206ATI080IVIV0P1_Kfl207=cL`80LW9b0P1hN7P207Mg
M`80OGem0P20P80208:2PP80Q8B40P25QHD20861P@80R8R81@26QXH208^;R`80SXj>0P29RHT208b<
S0@0TI6A0P2BTY8209NGU`80UYJF0P2ATI4209FEU@80UiNG0P2IVIT209BDU080UiNG102IVIT209ZJ
VP80WinO0P2NWYh409bLW080WYjN0P2KVi/00`2VYZH0Xj>S0:>SX`020:NWY`80Y:BT0P2QXJ420:NW
Y`80Y:BT0P2PX:020:6QX@80Xj>S0P2PX:020:6QX@80VYZJ0P2LW9`209JFUP80TI6A0P2@T90208^;
R`80S8b<1021PH4207inOP80NWYj0P1kNg/507inOP80RXZ:0P27QhL208R8R080OGem0P1nOWh207Yj
NP80OWin0P1kNg/407QhN080NWYj0P1iNGTN0<SPf0007038h=P202@T9080:BTY0P0_;bl202h^;P80
<30`0P0Y:BT201hN7P807alO0P0Q8B4203@d=080;Rh^0P1MGEd00`24Q8@0TY:B09:BTP0207AdM080
MGEe0P1hN7P207moO`80Rh^;0P34a<@20=7Ad@80c<c<0P31`L420<;2`P80^k^k0P1jNWX203@d=080
6ATI0P0S8b<202@T9080:BTY0P0X:2P402HV9P809bLW0P0T92@202LW9`809RHV00<0GUiN05YJFP1J
FUX00P1JFUX204U9B@80>c/k0P11@D4204];B`80DU9B0P1IFET205iNGP80Hf=S0P1YJFT206m_K`80
Lg=c0P1fMWH207QhN080NWYj0P1mOGd207moO`80PH611023Ph<208B4Q080QHF50`26QXH208N7Q`80
RHV91P2;Rh/208j>SP80TI6A0P2DU9@409JFUP80UIFE0P2GUiL209RHV080UiNG0P2FUYH209RHV0@0
VYZJ0P2KVi/409bLW080WIfM0P2NWYh209nOW`80XJ6Q00<0Xj>S0:FUY@2UYJD00P2UYJD20:BTY080
Xj>S102QXJ420::RXP@0XJ6Q0P2OWil209fMW@80VYZJ0P2GUiL209BDU080TY:B0P2@T90208f=S@80
RHV90P25QHD207moO`80Ng]k0P1jNWX207]kN`80O7al0P1nOWh00`22PX80QHF508F5Q@0408J6QP80
PH61101lO7`207emO@80Ng]k101iNGT407YjNRL0b>3H0P0Z:RX202@T9080:BTY0P0j>SX2038b<P80
8B4Q0P0S8b<2030`<0808B4Q0P0/;2`202PX:080G5aL0P29RHT208Z:RP80MGEe0`1hN7P207UiN@80
TY:B0P2o_kl20<c<c080c/k>0P3:b/X20;no_`80aLG50P1oOgl202l_;`@08R8R0P0W9bL202/[:`80
:BTY0P0R8R8202PX:0@09bLW0P0X:2P2030`<080EUIF0P1TI6@205YJFP80@D510P0g=cL204Q8B080
ADE50P1CDe<205MGE`0305aLG01PH600H61P0080IVIV0P1aLG4207EeM@@0MgMg0P1mOGd60820P080
QhN71P24Q8@408J6QP80RXZ:0P27QhL208b<S080Shn?0P26QXH4092@T080TY:B0P2FUYH209VIV@80
Ti>C0P2GUiL209FEU@80V9RH0P2DU9@00`2FUYH0VYZJ09ZJVP0209fMW@80Vi^K102LW9`209RHV080
WYjN0P2SXj<20::RXP80X:2P0P2UYJD40:BTY080X:2P102TY:@20:>SX`80Y:BT0P2QXJ4209jNWP80
Vi^K0P2MWId409BDU080TY:B0P2?Shl208j>SP80R8R80P25QHD207emO@80O7al00<0NWYj07]kN`1k
Ng/00P1lO7`207]kN`80PX:20P23Ph<208b<S080QHF50P1mOGd207moO`80Ng]k0P1mOGd207inOP80
NGUi0P1eMGD207YjNP80OWin9`38h=P2028R8P809bLW0P0_;bl202`/;080=CDe0P0Z:RX201dM7@80
71`L0P0S8b<203De=@80;2`/0P1MGEd00`25QHD0TI6A096AT@02075aL@@0M7Ad0P22PX8208b<S080
a<C40P3AdM420<k>cP80`/;20P2o_kl20<30`080Ng]k0P0e=CD201XJ6P@08B4Q0P0Z:RX402DU9@80
:BTY0P0S8b<2024Q8@8092@T0P0Y:BT00`1NGUh0EeMG05MGE`0205YJFP80BDU90P0k>c/20451@@80
D51@0P1EEED205]KF`80FUYJ0P1TI6@206IVIP80Kfm_0P1cLg<2079bLP80N7Qh0P1gMgL207emO@80
P8200P22PX8208B4Q080QHF50P21PH4208R8R0D0QXJ60P2;Rh/208j>SP80RHV90P2<S8`4096AT@80
TY:B0P2GUiL209JFUP80TI6A0P2EUID209NGU`80VIVI0P2DU9@209NGU`@0VIVI0P2JVYX209nOW`80
WYjN102LW9`209jNWP80Vi^K00<0YZJV0:>SX`2SXj<00P2WYjL20:BTY080XJ6Q0P2WYjL20:BTY080
X:2P0P2QXJ420:>SX`80X:2P0P2QXJ4209ZJVP80W9bL0P2FUYH2096AT@80T92@0P2;Rh/208b<S0@0
PH610P1nOWh207YjNP80Ng]k1@1nOWh208Z:RP80QhN70P28R8P207emO@80OWin0P1jNWX207inOP80
Ng]k101hN7P207YjNP80NGUi7P38h=P001`0b>3H0P0Q8B4202PX:0H0<C4a0P0Z:RX4024Q8@808b<S
0P0H61P201/K6`80CDe=00<0Ng]k09jNWP2NWYh0101eMGD207=cL`80M7Ad0P1oOgl20:NWY`80c/k>
0P3AdM420<g=c@80f=SH0P3AdM420;Bd]080D51@100U9BD202@T9080:RXZ0P0Y:BT202PX:0809RHV
0P0U9BD2028R8P809bLW0P0T92@00`1JFUX0F5QH05QHF00205ADE080B4Q80P0n?Sh20492@P80Bd];
0P1CDe<205]KF`80H61P0P1TI6@206][J`80LG5a0P1eMGD207QhN080NGUi0P1jNWX207emO@80P820
0P22PX8608>3P`80Q8B40`26QXH208N7Q`80S8b<0P2ATI42092@T080SXj>0P2?Shl2096AT@80Ti>C
0P2EUID409JFUP80UiNG0P2HV9P409NGU`80VYZJ102MWId409bLW0H0WIfM0P2NWYh20:2PX0030:BT
Y02WYjL0YjNW0080YZJV0P2TY:@20::RXP80XJ6Q102PX:020::RXP80Xj>S0P2QXJ4209nOW`80W9bL
0P2IVIT209JFUP80Ti>C0P2?Shl208^;R`80R8R80P26QXH208:2PP80P8200P1oOgl20820P080OWin
0P1mOGd00`20P800Q8B408B4Q00208F5Q@80Q8B40P20P80207]kN`80OGem0P1oOgl207alO0P0NGUi
9`38h=P202<S8`809BDU0P0b<S8203Ph>080;bl_0P0/;2`401lO7`808R8R0P0N7Qh2028R8P80A4A4
0P22PX8209ZJVP80Ng]k00<0LG5a07IfMP1fMWH00P1cLg<207moO`80Z:RX0P3@d=020<o?c`80d=3@
0P3<c<`20=3@d080^KVi0P19BDT202HV9P808b<S0P0Z:RX202HV9P80:2PX0P0/;2`402@T90809BDU
0P0R8R8202PX:080De=C0P1PH60205ADE080?3`l0P11@D4204Y:BP80Bd];0P1DE5@205eMG@03065Q
H@1WIfL0IfMW0080JVYZ0P1aLG4207EeM@80MgMg0P1iNGT207MgM`80Ogmo1020P80208F5Q@@0PH61
0P27QhL208>3P`80QXJ60P27QhL208^;R`80S8b<0P2HV9P208Z:RP80TY:B102@T90209JFUP80V9RH
0P2BTY8209VIV@80V9RH0P2IVIT209RHV00309ZJVP2KVi/0Vi^K0080WYjN102KVi/209nOW`80VYZJ
0P2NWYh20:2PX080WinO0P2SXj<40:NWY`80Y:BT0P2SXj<20:2PX080WYjN0P2PX:020:6QX@80Xj>S
0P2OWil209jNWP80WIfM0P2IVIT209FEU@80TI6A0P2BTY8208V9R@80R8R80P27QhL208:2PP80OWin
00<0PH6107moO`1oOgl00P1nOWh207alO0@0Ph>30P27QhL208>3P`80OWin0P1lO7`207]kN`@0Ogmo
0P1iNGT207EeM@80MWIf0P21PH4W0<SPf080820P0P0[:b/2038b<P80;bl_0P0`<30202TY:@808B4Q
0P0P820202HV9P805ADE0P0M7Ad204m?C`0307UiN@2QXJ40XJ6Q0080MGEe0P1dM7@2079bLP80MgMg
0P1mOGd20:RXZ080cLg=0P3@d=020<k>cP80f=SH0P3Bd]820;6a/@80DE5A0P0V9RH202<S8`8092@T
0P0Y:BT202/[:`809BDU0P0Y:BT202<S8`8092@T100V9RH00`1JFUX0EEEE05EEE@0205EEE@80BTY:
0P0o?cl203hn?P80C4a<0P1DE5@205YJFP80GUiN0P1UIFD206UYJ@80L71`0P1gMgL207]kN`80MgMg
0P1nOWh207alO080P8200P1oOgl408B4Q080PX:20P27QhL208F5Q@0308R8R026QXH0QXJ600@0TI6A
0P2=SHd2092@T080Shn?102ATI4209>CT`80Vi^K102FUYH209FEU@80Vi^K0P2EUID209^KV`@0WIfM
0P2NWYh609bLW0@0WinO0`2RXZ820:JVYP80YjNW0P2SXj<209nOW`80X:2P0P2RXZ820:2PX080XZ:R
0P2SXj<20::RXP80WIfM0P2KVi/209RHV080UYJF0P2CTi<208b<S0@0RXZ:1025QHD207moO`80Ng]k
0P1oOgl20861P@80Ng]k00<0P82008F5Q@25QHD00P22PX8208N7Q`80PH610P1nOWh207UiN@80P820
0P1nOWh207IfMP80OGem0P1gMgL207QhN1h0b>3H000L0<SPf0808B4Q0P0X:2P6034a<@80:RXZ100Q
8B4202<S8`8061PH0P0K6a/204e=C@0307]kN`2NWYh0WYjN00@0MGEe0P1cLg<207AdM080Ogmo0P2W
YjL20<k>cP80dM7A0P3=cLd20=SHf080dM7A0P2d];@2051@D0@09BDU0P0T92@202XZ:P80:BTY0P0X
:2P202HV9P809BDU0P0R8R8202LW9`8092@T00<0FUYJ05QHF01HF5P00P1DE5@204Q8B080?Shn0P12
@T8204];B`80De=C0P1KFe/2061PH080I6AT0P1[Jf/2075aL@80MGEe0P1hN7P207UiN@80NWYj0P1m
OGd20820P080PX:21P23Ph<208B4Q0<0QXJ60P27QhL208b<S080TI6A0P2@T90208j>SP80Shn?0P2A
TI4209>CT`80UIFE102FUYH209NGU`80V9RH102GUiL209ZJVP@0WIfM102LW9`609fMW@80WYjN0P2P
X:000`2TY:@0YjNW0:NWY`020:JVYP80Y:BT0P2RXZ820:6QX@@0X:2P0P2RXZ820:>SX`80XJ6Q0P2O
Wil209bLW080VIVI0P2FUYH209>CT`80Shn?0P2;Rh/208R8R080QXJ60P22PX820820P080Ogmo0P20
P80207inOP80OGem00<0P82008B4Q024Q8@00P25QHD208B4Q080P8200P1kNg/207emO@80Ogmo0P1l
O7`807UiNBL0b>3H0P0S8b<202DU9@80<S8b0P0h>3P202l_;`80;2`/100O7al2028R8P807QhN0P0R
8R8204A4A080PX:20P2JVYX207]kN`03075aL@1fMWH0MWIf0080Lg=c0P1oOgl20:RXZ080d=3@0P3?
cll20=3@d080c<c<0P3@d=020;Vi^@80BDU90P0V9RH202<S8`80:RXZ0P0V9RH202PX:080;2`/100T
92@202DU9@808R8R0P0X:2P205=CD`80H61P0P1DE5@203`l?080@D510P1:BTX204];B`80E5AD0P1M
GEd00`1QHF40IfMW06MWI`0206YZJP80LG5a0P1eMGD207MgM`80NGUi0P1gMgL207moO`@0P8200P25
QHD40861P@80QhN70P23Ph<208J6QP80QhN70P2;Rh/208b<S080V9RH0P2:RXX209:BTP@0T92@0P2F
UYH209RHV080TY:B0P2IVIT209RHV080VIVI0P2HV9P00`2JVYX0Vi^K09^KV`0209jNWP@0Vi^K0P2O
Wil209ZJVP80WYjN0P2PX:0209nOW`80Xj>S102WYjL20:BTY080Xj>S0P2PX:0209jNWP80X:2P0P2Q
XJ420:>SX`80WinO0P2NWYh209fMW@80VIVI0P2EUID2096AT@80TY:B0P29RHT208R8R080QhN70P22
PX8207inOP030861P@1oOgl0Ogmo0080OWin0P1lO7`408>3P`80QhN70P23Ph<207inOP80O7al0P1k
Ng/407moO`80NGUi0P1eMGD207IfMP80PH619`38h=P2020P8080:b/[0P0b<S8202l_;`80<30`0P0Y
:BT2024Q8@80820P0P0V9RH201DE5@807AdM0P1?Cdl00`1iNGT0XJ6Q0:6QX@0207EeM@80M7Ad0P1b
LW8207MgM`80OGem0P2XZ:P20<g=c@80d=3@0P3>c/h20=SHf080d];B0P2a/K42055AD@809RHV0P0S
8b<202@T9080:BTY0P0[:b/202DU9@80:BTY0P0S8b<202@T90@09RHV00<0FUYJ05EEE@1EEED00P1E
EED204Y:BP80?clo0P0n?Sh204a<C080E5AD0P1JFUX205iNGP80IFEU0P1YJFT2071`L080MgMg0P1k
Ng/207MgM`80OWin0P1lO7`20820P080Ogmo1024Q8@208:2PP80QhN70P25QHD00`28R8P0QXJ608J6
QP04096AT@80SHf=0P2@T90208n?S`@0TI6A0P2CTi<209^KV`@0UYJF0P2EUID209^KV`80UIFE0P2K
Vi/409fMW@80WYjN1P2LW9`409nOW`<0XZ:R0P2VYZH20:NWY`80Xj>S0P2OWil20:2PX080XZ:R0P2P
X:020::RXP80Xj>S0P2RXZ8209fMW@80Vi^K0P2HV9P209JFUP80Ti>C0P2<S8`408Z:RP@0QHF50P1o
Ogl207]kN`80Ogmo0P21PH4207]kN`030820P025QHD0QHF50080PX:20P27QhL20861P@80OWin0P1i
NGT20820P080OWin0P1fMWH207emO@80MgMg0P1hN7PN0<SPf0007038h=P2020P8080;Rh^0P0m?Cd2
04i>CP80?Shn0P0P820202<S8`80820P0P0Q8B4201DE5@8061PH0P0n?Sh00`1WIfL0SHf=08f=S@02
08J6QP80NWYj0P1`L702075aL@80OWin0P2:RXX20;^k^`80eMGE0P39bLT20=7Ad@80clo?0P3@d=02
0:6QX@80;bl_0P0`<30602HV9P809bLW0P0U9BD202@T90808b<S0P0Z:RX2020P8003059BDP1NGUh0
GUiN0080BTY:0P13@d<203`l?080@D510P1:BTX2055AD@80FEUI0P1PH60206IVIP80K6a/0P1`L702
07AdM080N7Qh0P1lO7`407inOP80OGem0P20P80208B4Q080Ph>30P22PX8208B4Q080QhN700<0R8R8
08V9R@29RHT00P2:RXX208b<S080SXj>0P2ATI4409:BTP80Ti>C0P2DU9@209JFUPH0V9RH0P2JVYX2
09bLW080WYjN0P2PX:0209jNWP80W9bL0P2MWId209jNWP@0WinO0P2QXJ420:BTY0030:FUY@2VYZH0
YZJV0080YZJV102UYJD20:BTY080Xj>S0P2RXZ860:>SX`80XZ:R0P2PX:0209fMW@80VIVI0P2DU9@2
092@T080SHf=0P2:RXX208R8R080QHF50P23Ph<208:2PPH0PH6100<0PX:208>3P`23Ph<00P22PX82
0820P080OWin0P1lO7`407]kN`80NWYj0P1iNGT207YjNP@0Ng]k9`38h=P202<S8`80;Rh^0P0m?Cd2
04i>CP80=CDe0P0S8b<2020P80806a/K0P0N7Qh201`L70807alO0P0_;bl206][J`80Shn?0P26QXH0
0`1cLg<0L71`071`L00207AdM080MWIf0P2@T9020;no_`80cLg=0P3;bl/20<k>cP80c<c<0P3>c/h2
0:>SX`80>3Ph0P0U9BD202@T90809RHV0P0Y:BT202DU9@809RHV0P0W9bL2028R8P8092@T0P0U9BD2
04e=C@80IVIV0P1>CTh203Xj>P80@T920P17AdL204E5A@80Bd];0P1GEeL00`1QHF40IfMW06MWI`02
06a/K0@0LG5a0P1iNGT207inOP80P8200P1jNWX207inOP@0P8200P23Ph<208:2PP80QhN70P28R8P4
08V9R@80RXZ:102>SXh208n?S`80U9BD0P2CTi<2092@T080TI6A0P2HV9P209^KV`80UiNG0P2FUYH2
09VIV@80VYZJ00<0WYjN0::RXP2RXZ800P2NWYh209fMW@80W9bL0P2PX:0609nOW`80XZ:R0P2VYZH2
0:RXZ080XZ:R0P2VYZH20:BTY080YJFU0P2RXZ820:2PX080Y:BT0P2UYJD20::RXP80YZJV0P2OWil2
09jNWP80VYZJ102CTi<208b<S080SXj>1025QHD308B4Q080P8201021PH4208B4Q080OGem0P24Q8@2
08:2PP80O7al0P1oOgl207alO080Ng]k0P1iNGT207]kN`80NGUi0P1lO7`207emOBL0b>3H0P0P8202
02d];@80?3`l0P1ADE4203Xj>P808b<S0P0U9BD201lO7`80820P0P0C4a<201HF5P80@41000<0HV9R
08n?S`2?Shl00P26QXH207YjNP80LW9b0P1aLG4207YjNP80RHV90P2l_;`20=KFeP80aLG50P3Bd]84
0<c<c080WinO0P0d=3@2030`<080:BTY0P0U9BD202@T90809bLW0P0X:2P202DU9@808R8R0P0X:2P2
028R8P03059BDP1LG5`0G5aL0080Bd];0P14A4@203dm?@80?clo0P17AdL204m?C`80FUYJ0P1SHf<2
06QXJ080Kfm_0P1bLW8207EeM@80N7Qh0P1iNGT207inOP80Ogmo0P21PH4207inOP80Q8B40P21PH42
08:2PP80Ogmo1@26QXH208Z:RP80R8R80P2>SXh4092@T080UIFE0P2ATI4209:BTP80VYZJ0P2GUiL4
09VIV@80W9bL0P2JVYX209jNWP80XJ6Q0P2OWil209ZJVP@0WIfM0P2PX:0209jNWP80XJ6Q0P2SXj<0
0`2YZJT0YjNW0:NWY`020:NWY`80ZJVY0P2RXZ820:>SX`80YZJV102PX:020:>SX`80XZ:R0P2QXJ42
0::RXP80Vi^K0P2IVIT209FEU@@0TI6A0P2<S8`208N7Q`80QHF50P23Ph<40820P080QHF50P1oOgl0
0`20P800PH610861P@020861P@80OGem0P1nOWh207alO0@0Ng]k0P1jNWX207QhN080O7al0P1jNWX2
07emOAh0b>3H000L0<SPf080820P0P0^;Rh203dm?@80CTi>0P0n?Sh2020P80808b<S0P0P8202024Q
8@805ADE0P0H61P203hn?P0306MWI`2=SHd0SHf=0080QXJ60P1jNWX2071`L080LG5a0P1nOWh208Z:
RP80^k^k0P3EeMD20<W9b@80dM7A0P3?cll20=3@d080XJ6Q0P0_;bl2030`<0H09RHV0P0W9bL202DU
9@8092@T0P0S8b<202XZ:P80820P00<0DU9B05iNGP1NGUh00P1:BTX204=3@`80?3`l0P11@D4204Y:
BP80DE5A0P1IFET2061PH080IVIV0P1/K6`2071`L080M7Ad0P1hN7P207alO0@0OWin0P1mOGd20820
P080Q8B40P23Ph<208:2PP80Q8B40P27QhL00`28R8P0RHV908V9R@0208Z:RP80S8b<0P2>SXh2096A
T@@0TY:B0P2CTi<209BDU080UYJF1P2HV9P209ZJVP80W9bL0P2NWYh20:2PX080WYjN0P2LW9`209fM
W@80WYjN102OWil20:6QX@80Y:BT00<0YJFU0:JVYP2VYZH00P2VYZH40:FUY@80Y:BT0P2SXj<20::R
XPH0Xj>S0P2RXZ820:2PX080WIfM0P2IVIT209BDU080T92@0P2=SHd208Z:RP80R8R80P25QHD208>3
P`80PX:21P21PH400`22PX80Ph>308>3P`0208:2PP80P8200P1nOWh207alO0@0Ng]k0P1jNWX207Ui
N@80NWYj101kNg/W0<SPf0808b<S0P0^;Rh203dm?@80CTi>0P0e=CD202<S8`80820P0P0K6a/201hN
7P8071`L0P0O7al202l_;`80Jf][0P2?Shl208J6QP0307=cL`1`L700L71`0080M7Ad0P1fMWH2092@
T080_kno0P3=cLd20<_;b`80c/k>0P3<c<`20<k>cP80Xj>S0P0h>3P202DU9@8092@T0P0V9RH202TY
:@809BDU0P0V9RH202LW9`808R8R0P0T92@202DU9@80CDe=0P1VIVH204i>CP80>SXj0P12@T8204M7
A`80ADE50P1;Bd/205MGE`03065QH@1WIfL0IfMW0080K6a/101aLG4207UiN@80OWin0P20P80207Yj
NP80OWin1020P80208>3P`80PX:20P27QhL208R8R0@0RHV90P2:RXX408j>SP80Shn?0P2DU9@209>C
T`80T92@0P2ATI4209RHV080Vi^K0P2GUiL209JFUP80VIVI0P2JVYX00`2NWYh0XZ:R0::RXP0209jN
WP80WIfM0P2LW9`20:2PX0H0WinO0P2RXZ820:JVYP80Z:RX0P2RXZ820:JVYP80Y:BT0P2UYJD20::R
XP80X:2P0P2TY:@20:FUY@80XZ:R0P2VYZH209nOW`80WYjN0P2JVYX409>CT`80S8b<0P2>SXh408F5
Q@<0Q8B40P20P8040861P@80Q8B40P1mOGd208B4Q080PX:20P1lO7`207moO`80O7al0P1kNg/207Ui
N@80Ng]k0P1iNGT207alO080OGem9`38h=P2020P8080;Bd]0P0l?3`2055AD@80>SXj0P0S8b<202DU
9@807alO0P0P820201<C4`805QHF0P10@4000`1RHV80Shn?08n?S`0208J6QP80NWYj0P1bLW82075a
L@80NWYj0P29RHT20;bl_080e]KF0P35aLD20=;BdP@0c<c<0P2OWil203@d=080<30`0P0Y:BT202DU
9@8092@T0P0W9bL202PX:0809BDU0P0R8R8202PX:0808R8R00<0DU9B05aLG01LG5`00P1;Bd/204A4
A080?Cdm0P0o?cl204M7A`80Cdm?0P1JFUX206=SH`80J6QX0P1_Kfl2079bLP80MGEe0P1hN7P207Ui
N@80OWin0P1oOgl20861P@80OWin0P24Q8@20861P@80PX:20P1oOgl508J6QP80RXZ:0P28R8P208j>
SP@0T92@0P2EUID2096AT@80TY:B0P2JVYX209NGU`@0VIVI0P2LW9`209ZJVP80WYjN0P2QXJ4209nO
W`80VYZJ102MWId20:2PX080WYjN0P2QXJ420:>SX`030:VYZ@2WYjL0YjNW0080YjNW0P2YZJT20::R
XP80Xj>S0P2VYZH40:2PX080Xj>S0P2RXZ820:6QX@80XZ:R0P2KVi/209VIV@80UIFE102ATI4208b<
S080QhN70P25QHD208>3P`@0P8200P25QHD207moO`030820P021PH40PH610080PH610P1mOGd207in
OP80O7al101kNg/207YjNP80N7Qh0P1lO7`207YjNP80OGem7P38h=P001`0b>3H0P0S8b<203Lg=`80
C4a<0P1]KFd204a<C0806QXJ0P0U9BD201hN7P807alO0P0I6AT201XJ6P80<30`00<0Cdm?07IfMP1f
MWH00P2FUYH208B4Q080Kfm_0P1aLG4207moO`80LW9b0P2TY:@20=?Cd`80`/;20P39bLT20<[:bP80
e]KF0P3AdM4208:2PP80;Rh^0P0T92@202HV9P809BDU0P0V9RH402<S8`8092@T0P0/;2`2020P8003
04];B`1TI6@0I6AT0080@4100P0m?Cd203/k>`80@D510P19BDT2051@D080EeMG0P1PH60206QXJ080
KFe]0P1`L70207AdM080N7Qh0P1nOWh208:2PP80Ogmo0P1kNg/207moO`80Q8B40P22PX820861P@80
Q8B40P28R8P00`2:RXX0Rh^;08^;R`0208R8R080QXJ60P2<S8`209>CT`@0U9BD102CTi<209NGU`80
Vi^K0P2IVIT209RHV080W9bL0P2QXJ440::RXP80X:2P0P2MWId209jNWP80X:2P0P2RXZ820:>SX`80
YZJV0P2WYjL00`2VYZH0YJFU0:FUY@020:JVYP80YjNW102XZ:P20:NWY`80YJFU0P2TY:@20:>SX`@0
YJFU0P2SXj<209nOW`80Vi^K0P2FUYH209:BTP80T92@0P2<S8`208Z:RP80QhN70P25QHD208>3P`80
PX:20P23Ph<208F5Q@0308B4Q022PX80PX:20080Ogmo1P1mOGd207YjNP80MgMg0P1hN7P207YjNP@0
O7al0P1mOGdW0<SPf0809RHV0P0b<S8204a<C080Lg=c0P1=CDd202HV9P80820P0P0Q8B4201hN7P@0
7AdM0P0U9BD2051@D080Ph>30P2EUID00`1iNGT0Kfm_06m_K`0207UiN@80MWIf0P1hN7P20:FUY@80
alO70P38b<P20<k>cP80clo?103>c/h208V9R@80<C4a0P0U9BD202HV9P809BDU0P0W9bL2024Q8@80
8b<S0P0Y:BT202LW9`80:BTY0P19BDT205aLG080B4Q80P0e=CD203`l?080ADE50P19BDT204e=C@80
FUYJ00<0HV9R06IVIP1VIVH00P1/K6`2079bLP80M7Ad0P1eMGD208:2PP80Ph>30P1mOGd207]kN`80
P8200P23Ph<208J6QP80OWin0P24Q8@208N7Q`80RHV9102:RXX208J6QP80RHV90P2@T90209ZJVP80
TY:B0P2@T90409JFUP80Vi^K0P2IVIT209NGU`D0XJ6Q0P2SXj<20:2PX080WYjN0P2OWil20:2PX080
XZ:R0P2SXj<20::RXP80YJFU0P2XZ:P20:FUY@80Xj>S0P2XZ:P20:VYZ@80Z:RX0P2TY:@20:FUY@80
Z:RX0P2RXZ840:JVYP80WinO0P2PX:0209^KV`80UYJF0P2ATI42092@T080RHV90P2:RXX208R8R0D0
Ph>30P22PX8408B4Q0@0PH610P1kNg/207alO080OGem0P1iNGT407QhN080NWYj0P1kNg/207alO080
OGem9`38h=P202LW9`80=CDe0P1>CTh206e]K@80BTY:0P0M7Ad202DU9@806a/K0P0O7al201XJ6P80
71`L0P0^;Rh00`1@D500Ng]k07]kN`0209BDU080PX:20P1]KFd207AdM080Ogmo0P1bLW820:>SX`80
eMGE0P31`L420<_;b`80bLW90P3IfMT20<o?c`80Q8B40P0Z:RX202DU9@809RHV0P0R8R8202PX:0@0
8b<S0P0T92@202/[:`807alO00<0Bd];06ATI01TI6@00P10@40203`l?080>c/k0P10@40204Y:BP80
DU9B0P1EEED205mOG`80IFEU0P1/K6`2075aL@80LW9b0P1hN7P20820P080Ph>30P1nOWh207emO@80
Ng]k0P25QHD208B4Q080PH610P24Q8@208V9R@0308j>SP28R8P0R8R80080RXZ:0P26QXH208^;R`@0
Ti>C0P2EUID208j>SP80V9RH0P2EUID209ZJVP80W9bL0P2GUiL209bLW080XJ6Q0P2SXj<40:6QX@80
WIfM0P2NWYh209fMW@80Xj>S0P2RXZ820:NWY`<0YJFU0P2WYjL20:JVYP80Z:RX0P2VYZH20:NWY`80
ZJVY0P2XZ:P20:6QX@80YZJV0P2TY:@20:>SX`80YJFU0P2NWYh209^KV`80UYJF0P2ATI4208n?S`80
Rh^;102:RXX208J6QP80PX:20P1oOgl208N7Q`80Ph>300<0Q8B40861P@21PH400P1oOgl207inOP80
OGem0P1lO7`207YjNP80MgMg101iNGT207]kN`@0O7al7P38h=P001`0b>3H0P0S8b<203Lg=`80C4a<
0P1]KFd204a<C0806QXJ0P0U9BD201hN7P807alO0P0I6AT201XJ6P80<30`00<0Cdm?07IfMP1fMWH0
0P2FUYH208B4Q080Kfm_0P1aLG4207moO`80LW9b0P2TY:@20=?Cd`80`/;20P39bLT20<[:bP80e]KF
0P3AdM4208:2PP80;Rh^0P0T92@202HV9P809BDU0P0V9RH402<S8`8092@T0P0/;2`2020P800304];
B`1TI6@0I6AT0080@4100P0m?Cd203/k>`80@D510P19BDT2051@D080EeMG0P1PH60206QXJ080KFe]
0P1`L70207AdM080N7Qh0P1nOWh208:2PP80Ogmo0P1kNg/207moO`80Q8B40P22PX820861P@80Q8B4
0P28R8P00`2:RXX0Rh^;08^;R`0208R8R080QXJ60P2<S8`209>CT`@0U9BD102CTi<209NGU`80Vi^K
0P2IVIT209RHV080W9bL0P2QXJ440::RXP80X:2P0P2MWId209jNWP80X:2P0P2RXZ820:>SX`80YZJV
0P2WYjL00`2VYZH0YJFU0:FUY@020:JVYP80YjNW102XZ:P20:NWY`80YJFU0P2TY:@20:>SX`@0YJFU
0P2SXj<209nOW`80Vi^K0P2FUYH209:BTP80T92@0P2<S8`208Z:RP80QhN70P25QHD208>3P`80PX:2
0P23Ph<208F5Q@0308B4Q022PX80PX:20080Ogmo1P1mOGd207YjNP80MgMg0P1hN7P207YjNP@0O7al
0P1mOGdW0<SPf0809RHV0P0b<S8204a<C080Lg=c0P1=CDd202HV9P80820P0P0Q8B4201hN7P@07AdM
0P0U9BD2051@D080Ph>30P2EUID00`1iNGT0Kfm_06m_K`0207UiN@80MWIf0P1hN7P20:FUY@80alO7
0P38b<P20<k>cP80clo?103>c/h208V9R@80<C4a0P0U9BD202HV9P809BDU0P0W9bL2024Q8@808b<S
0P0Y:BT202LW9`80:BTY0P19BDT205aLG080B4Q80P0e=CD203`l?080ADE50P19BDT204e=C@80FUYJ
00<0HV9R06IVIP1VIVH00P1/K6`2079bLP80M7Ad0P1eMGD208:2PP80Ph>30P1mOGd207]kN`80P820
0P23Ph<208J6QP80OWin0P24Q8@208N7Q`80RHV9102:RXX208J6QP80RHV90P2@T90209ZJVP80TY:B
0P2@T90409JFUP80Vi^K0P2IVIT209NGU`D0XJ6Q0P2SXj<20:2PX080WYjN0P2OWil20:2PX080XZ:R
0P2SXj<20::RXP80YJFU0P2XZ:P20:FUY@80Xj>S0P2XZ:P20:VYZ@80Z:RX0P2TY:@20:FUY@80Z:RX
0P2RXZ840:JVYP80WinO0P2PX:0209^KV`80UYJF0P2ATI42092@T080RHV90P2:RXX208R8R0D0Ph>3
0P22PX8408B4Q0@0PH610P1kNg/207alO080OGem0P1iNGT407QhN080NWYj0P1kNg/207alO080OGem
9`38h=P202LW9`80=CDe0P1>CTh206e]K@80BTY:0P0M7Ad202DU9@806a/K0P0O7al201XJ6P8071`L
0P0^;Rh00`1@D500Ng]k07]kN`0209BDU080PX:20P1]KFd207AdM080Ogmo0P1bLW820:>SX`80eMGE
0P31`L420<_;b`80bLW90P3IfMT20<o?c`80Q8B40P0Z:RX202DU9@809RHV0P0R8R8202PX:0@08b<S
0P0T92@202/[:`807alO00<0Bd];06ATI01TI6@00P10@40203`l?080>c/k0P10@40204Y:BP80DU9B
0P1EEED205mOG`80IFEU0P1/K6`2075aL@80LW9b0P1hN7P20820P080Ph>30P1nOWh207emO@80Ng]k
0P25QHD208B4Q080PH610P24Q8@208V9R@0308j>SP28R8P0R8R80080RXZ:0P26QXH208^;R`@0Ti>C
0P2EUID208j>SP80V9RH0P2EUID209ZJVP80W9bL0P2GUiL209bLW080XJ6Q0P2SXj<40:6QX@80WIfM
0P2NWYh209fMW@80Xj>S0P2RXZ820:NWY`<0YJFU0P2WYjL20:JVYP80Z:RX0P2VYZH20:NWY`80ZJVY
0P2XZ:P20:6QX@80YZJV0P2TY:@20:>SX`80YJFU0P2NWYh209^KV`80UYJF0P2ATI4208n?S`80Rh^;
102:RXX208J6QP80PX:20P1oOgl208N7Q`80Ph>300<0Q8B40861P@21PH400P1oOgl207inOP80OGem
0P1lO7`207YjNP80MgMg101iNGT207]kN`@0O7al7P38h=P001`0b>3H0P0];Bd203hn?P80E5AD0P2@
T90207alO080@d=30P0T92@201/K6`807AdM0P0I6AT201/K6`808b<S00<0=cLg06e]K@1]KFd00P2H
V9P209JFUP80KFe]0P1^KVh207MgM`80Lg=c0P2CTi<20;fm_@80a<C40P3;bl/20<[:bP80d=3@0P3;
bl/20<K6aP80J6QX0P0Y:BT2024Q8@80820P0P0U9BD402@T90808R8R0P0U9BD202XZ:P0304=3@`1Q
HF40HF5Q0080?Cdm0P0k>c/203Ti>@80?clo0P18B4P2051@D080FEUI0P1QHF4206UYJ@80KFe]0P1`
L70207AdM080N7Qh0P1mOGd40820P080OWin0P21PH4208>3P`80PX:20P21PH4208>3P`80QhN700<0
RHV908Z:RP2:RXX01029RHT208f=S@80TY:B102DU9@209FEU@80UYJF0P2IVIT209^KV`@0VYZJ0P2N
WYh20::RXP@0Xj>S0P2PX:0209jNWP80X:2P0P2SXj<20:JVYP@0YjNW0P2VYZH00`2XZ:P0ZJVY0:VY
Z@020:RXZ080YjNW0P2XZ:P20:VYZ@80Z:RX0P2WYjL20:FUY@80Xj>S0P2TY:@20:FUY@80XZ:R0P2N
WYh209^KV`80V9RH0P2EUID2096AT@80SHf=0P29RHT208N7Q`80QXJ60P24Q8@208:2PP80Q8B40`25
QHD208>3P`80P8200P1nOWh207moO`80P8200P1lO7`207QhN080NGUi0P1kNg/407alO080OGem9`38
h=P203<c<`80?Cdm0P1LG5`208F5Q@80MWIf0P16ATH202@T90807QhN100K6a/201`L70808b<S0P0g
=cL2071`L080X:2P00<0Rh^;06e]K@1]KFd00P1nOWh207IfMP80MGEe0P2ATI420;jn_P80`l?3103:
b/X20<c<c080clo?0P33`l<206ATI080:2PX0P0Q8B4202<S8`809BDU0P0V9RH2024Q8@807alO0P0W
9bL202h^;P80Bd];0P1EEED204A4A080=CDe0P0j>SX204A4A080BTY:0P1ADE4205IFEP0306QXJ01Y
JFT0JFUY0080Jf][0P1`L70206m_K`80Ng]k0P1nOWh407emO@80PH610P23Ph<20861P@80QHF50P21
PH4207moO`80RHV9102;Rh/208N7Q`80R8R80P2=SHd209:BTP80V9RH0P2ATI4209JFUP80UiNG0P2I
VIT209ZJVP80UYJF0P2KVi/20:6QX@80WIfM00<0Xj>S0::RXP2RXZ800P2JVYX409jNWP80XZ:R0P2T
Y:@20:^[Z`80ZZZZ0P2[Zj/20:ZZZP80Z:RX0P2WYjL20:VYZ@80Z:RX0P2ZZZX20:JVYP80Z:RX0P2V
YZH40:2PX080YJFU0P2QXJ4209jNWP80Vi^K0P2EUID209RHV080TI6A0P2<S8`208^;R`80RXZ:0P26
QXH00`25QHD0P8200820P00208>3P`80QXJ60P27QhL208F5Q@80PX:20P1mOGd207inOP80P8200P1l
O7`207QhN080NWYj0P1kNg/207alO080Ng]k0P1mOGdW0<SPf080;bl_0P0j>SX205EEE@80Shn?0P1o
Ogl204A4A0808b<S0P0I6AT2024Q8@807AdM0P0K6a/201lO7`0303Lg=`1_Kfl0Kfm_0080V9RH0P2F
UYH206a/K080Kfm_0P1fMWH207=cL`80TY:B0P30`<020<C4a080clo?0P39bLT20=;BdP80b/[:0P39
bLT206QXJ080:2PX0P0U9BD201hN7P8092@T0P0U9BD202@T9080820P0P0X:2P202d];@0304A4A01N
GUh0GUiN0080?Cdm0P0o?cl203Ph>080?Shn0P19BDT204m?C`80FEUI0P1WIfL206UYJ@80K6a/0P1^
KVh2075aL@80NGUi0P1oOgl20820P080NWYj1020P80208B4Q0@0PX:20P24Q8@208F5Q@D0S8b<0P2:
RXX208n?S`80UIFE0P2BTY8209RHV0@0UIFE0P2HV9P409^KV`80VIVI0P2JVYX20:>SX`80Y:BT0P2Q
XJ420::RXP80WIfM0P2SXj<20:BTY080[:b/0P2VYZH20:RXZ080YjNW00<0ZZZZ0:FUY@2UYJD00P2S
Xj<20:RXZ080ZJVY0P2ZZZX20:VYZ@80Z:RX0P2RXZ820:JVYP80YJFU0P2YZJT20:JVYP80WIfM0P2K
Vi/209JFUP80UIFE0P2>SXh208n?S`80QhN71024Q8@208J6QP80Q8B40P20P80208F5Q@0308R8R025
QHD0QHF50080QHF5101nOWh208F5Q@80NWYj101iNGT207alO080OGem0P1lO7`207emOAh0b>3H000L
0<SPf080;Bd]0P0n?Sh205ADE080T92@0P1lO7`204=3@`8092@T0P0K6a/201dM7@806ATI0P0K6a/2
02<S8`0303Lg=`1]KFd0KFe]0080V9RH0P2FUYH206e]K@80KVi^0P1gMgL207=cL`80Ti>C0P2m_Kd2
0<C4a080bl_;0P3:b/X20=3@d080bl_;0P36a/H206QXJ080:BTY0P0Q8B42020P80809BDU100T92@2
028R8P809BDU0P0Z:RX00`13@d<0HF5Q065QH@0203dm?@80>c/k0P0i>CT203lo?`80B4Q80P1@D502
05UIF@80HF5Q0P1YJFT206e]K@80L71`0P1dM7@207QhN080OGem1020P80207inOP80PH610P23Ph<2
08:2PP80PH610P23Ph<208N7Q`0308V9R@2:RXX0RXZ:00@0RHV90P2=SHd209:BTP@0U9BD0P2EUID2
09JFUP80VIVI0P2KVi/409ZJVP80WYjN0P2RXZ840:>SX`80X:2P0P2NWYh20:2PX080Xj>S0P2VYZH4
0:NWY`80YZJV00<0Z:RX0:VYZ@2YZJT00P2XZ:P20:NWY`80Z:RX0P2YZJT20:RXZ080YjNW0P2UYJD2
0:>SX`80Y:BT0P2UYJD20::RXP80WYjN0P2KVi/209RHV080UIFE0P2ATI4208f=S@80RHV90P27QhL2
08J6QP80Q8B40P22PX8208B4Q0<0QHF50P23Ph<20820P080OWin0P1oOgl20820P080O7al0P1hN7P2
07UiN@80Ng]k101lO7`207emOBL0b>3H0P0c<c<203dm?@80G5aL0P25QHD207IfMP80ATI60P0T92@2
01hN7P@06a/K0P0L71`202<S8`80=cLg0P1`L7020:2PX00308^;R`1]KFd0KFe]0080OWin0P1fMWH2
07EeM@80TI6A0P2n_[h20<?3``@0b/[:0P3<c<`20<o?c`80`l?30P1TI6@202PX:0808B4Q0P0S8b<2
02DU9@809RHV0P0Q8B4201lO7`809bLW0P0^;Rh204];B`80EEEE0P14A4@203De=@80>SXj0P14A4@2
04Y:BP80DE5A0P1FEUH00`1XJ6P0JFUY06UYJ@0206][J`80L71`0P1_Kfl207]kN`80OWin101mOGd2
0861P@80Ph>30P21PH4208F5Q@80PH610P1oOgl208V9R@@0Rh^;0P27QhL208R8R080SHf=0P2BTY82
09RHV080TI6A0P2FUYH209NGU`80VIVI0P2JVYX209JFUP80Vi^K0P2QXJ4209fMW@030:>SX`2RXZ80
XZ:R0080VYZJ102NWYh20::RXP80Y:BT0P2[Zj/20:ZZZP80Zj^[0P2ZZZX20:RXZ080YjNW0P2YZJT2
0:RXZ080ZZZZ0P2VYZH20:RXZ080YZJV102PX:020:FUY@80XJ6Q0P2NWYh209^KV`80UIFE0P2HV9P2
096AT@80S8b<0P2;Rh/208Z:RP80QXJ600<0QHF50820P020P8000P23Ph<208J6QP80QhN70P25QHD2
08:2PP80OGem0P1nOWh20820P080O7al0P1hN7P207YjNP80Ng]k0P1lO7`207]kN`80OGem9`38h=P2
02l_;`80>SXj0P1EEED208n?S`80Ogmo0P14A4@202<S8`806ATI0P0Q8B4201dM7@806a/K0P0O7al0
0`0g=cL0Kfm_06m_K`0209RHV080UYJF0P1/K6`206m_K`80MWIf0P1cLg<209:BTP80`<300P34a<@2
0<o?c`80bLW90P3Bd]820<[:bP80bLW90P1XJ6P202PX:0809BDU0P0N7Qh202@T90809BDU0P0T92@2
020P8080:2PX0P0];Bd00`14A4@0GUiN05iNGP0203dm?@80?clo0P0h>3P203hn?P80BDU90P1?Cdl2
05UIF@80IfMW0P1YJFT206a/K080KVi^0P1aLG4207UiN@80Ogmo0P20P80207YjNP@0P8200P24Q8@4
08:2PP80Q8B40P25QHD508b<S080RXZ:0P2?Shl209FEU@80TY:B0P2HV9P409FEU@80V9RH102KVi/2
09VIV@80VYZJ0P2SXj<20:BTY080XJ6Q0P2RXZ8209fMW@80Xj>S0P2TY:@20:b/[080YZJV0P2XZ:P2
0:NWY`030:ZZZP2UYJD0YJFU0080Xj>S0P2XZ:P20:VYZ@80ZZZZ0P2YZJT20:RXZ080XZ:R0P2VYZH2
0:FUY@80ZJVY0P2VYZH209fMW@80Vi^K0P2FUYH209FEU@80SXj>0P2?Shl208N7Q`@0Q8B40P26QXH2
08B4Q080P8200P25QHD00`28R8P0QHF508F5Q@0208F5Q@@0OWin0P25QHD207YjNP@0NGUi0P1lO7`2
07emO@80O7al0P1mOGdN0<SPf0007038h=P203Ti>@80CDe=0P1SHf<208f=S@80KFe]0P1>CTh202LW
9`807QhN0P0M7Ad201/K6`8071`L0P0K6a/00`0U9BD0H61P061PH002092@T080Y:BT0P1_Kfl206i^
KP80L71`0P1hN7P208F5Q@80YJFU0P36a/H20<_;b`80bLW90P3>c/h20=;BdP80`<300P31`L420492
@P80:BTY0P0M7Ad202@T90809BDU0P0V9RH2024Q8@807QhN0P0c<c<00`0o?cl0G5aL05aLG00203/k
>`80>SXj0P0g=cL203hn?P80AdM70P1ADE4205YJFP80Hf=S0P1YJFT206e]K@80Kfm_0P1dM7@207Ui
N@80Ng]k0P1mOGd20820P080PX:20P23Ph<608:2PP80Ph>30P24Q8@00`27QhL0RXZ:08Z:RP0208b<
S080SHf=0P2?Shl2096AT@80Ti>C0P2EUID209RHV0@0VYZJ102KVi/209bLW080WinO0P2RXZ840:>S
X`80X:2P0P2OWil20::RXP80YZJV0P2YZJT20:^[Z`80Z:RX0P2UYJD00`2YZJT0[Jf]0:f][@020:^[
Z`80Z:RX1P2YZJT20:RXZ080YZJV0P2SXj<40:BTY080X:2P0P2LW9`209^KV`80VYZJ0P2GUiL209:B
TP80SHf=0P28R8P408N7Q`80Q8B40P23Ph<208B4Q0D0QHF50P22PX820820P0@0PH610P1mOGd207Ui
N@80NWYj0P1kNg/207alO0@0OGem9`38h=P203@d=080DE5A0P1VIVH208R8R080MgMg0P1HF5P202@T
908071`L0P0M7Ad201/K6`806QXJ0P0N7Qh202HV9P80FEUI0P2BTY800`2NWYh0LG5a075aL@0406m_
K`80LG5a0P25QHD20:RXZ080aLG50P39bLT20<c<c080bl_;0P3<c<`20<k>cP80]KFe0P16ATH202LW
9`@08B4Q0P0S8b<202XZ:P809BDU0P0S8b<202TY:@80AdM70P1FEUH203lo?`80>SXj0P0h>3P203`l
?080ADE5101EEED00`1YJFT0IVIV06IVIP0206a/K080L71`0P1fMWH207MgM`@0OGem0P25QHD20861
P@80PX:20P24Q8@20820P0@0PX:20P24Q8@208N7Q`80RHV90P2=SHd208^;R`@0T92@0P2CTi<209FE
U@80WIfM0P2GUiL209bLW080WIfM0P2HV9P20:2PX080WIfM0P2QXJ400`2TY:@0XZ:R0::RXP020:6Q
X@80XZ:R0P2PX:020:ZZZP80YjNW0P2ZZZX20:JVYP80Xj>S0P2[Zj/20:b/[080Z:RX0P2ZZZX20:^[
Z`80ZJVY0P2WYjL20:VYZ@@0YJFU0P2QXJ420:FUY@80XJ6Q0P2IVIT209^KV`80V9RH0P2GUiL209:B
TP80SXj>0P29RHT208J6QP80R8R800<0Q8B408>3P`23Ph<01023Ph<208N7Q`80Ph>31021PH4207em
O@80PX:20P1nOWh207]kN`80N7Qh0P1jNWX207inOP80Ng]k0P1nOWhW0<SPf080>SXj0P1<C4`206AT
I080S8b<0P1]KFd204i>CP80:2PX0P0L71`201/K6`@071`L0P0N7Qh00`0U9BD0HF5Q065QH@0209BD
U080X:2P0P1`L70206e]K@80L71`0P1lO7`208B4Q080YJFU0P36a/H20<[:bP80b<S80P3>c/h20=7A
d@@0`/;20P0k>c/202XZ:P807alO0P0U9BD2028R8P80:2PX0P0N7Qh201dM7@80>3Ph00<0?Cdm05]K
F`1KFe/00P0i>CT203`l?080=cLg0P0l?3`204M7A`80CTi>0P1JFUX206EUI@80IfMW0P1/K6`2071`
L080LW9b101jNWX207emO@80QHF50P1nOWh208R8R080P8200P21PH420820P080QhN70P23Ph<308V9
R@@0Rh^;0P2CTi<208n?S`80SXj>0P2DU9@409ZJVP80VIVI0P2KVi/209bLW080WYjN0P2MWId20::R
XP80YZJV0P2TY:@20:2PX080WinO0P2TY:@20:>SX`@0[:b/0P2UYJD20:BTY0030:b/[02^[Zh0[Zj^
0080ZJVY0P2ZZZX20:RXZ080YZJV0P2YZJT20:ZZZP@0YJFU0P2QXJ420:FUY@H0WIfM102HV9P4092@
T080QhN71029RHT20861P@80Ph>31025QHD00`24Q8@0PX:208:2PP0208B4Q080PH610P1nOWh208:2
PP80NWYj0P1kNg/207QhN080Ng]k101mOGd207alO1h0b>3H000L0<SPf080>CTi0P1=CDd206=SH`80
SHf=0P1]KFd204i>CP809bLW0P0N7Qh201dM7@806a/K0P0L71`201/K6`0302DU9@1PH600H61P0080
T92@0P2TY:@206m_K`80KVi^0P1`L70207QhN080QHF50P2UYJD20<K6aP80bl_;0P39bLT20<k>cP80
d];B0P30`<020<71`@80@T920P0Y:BT201dM7@8092@T0P0U9BD202HV9P808B4Q0P0N7Qh203<c<`03
03lo?`1LG5`0G5aL0080>c/k0P0j>SX203Lg=`80?Shn0P17AdL2055AD@80FUYJ0P1SHf<206UYJ@80
KFe]0P1_Kfl207AdM080NGUi0P1kNg/207emO@80P8200P22PX8208>3P`H0PX:20P23Ph<208B4Q003
08N7Q`2:RXX0RXZ:0080S8b<0P2=SHd208n?S`80TI6A0P2CTi<209FEU@80V9RH102JVYX409^KV`80
W9bL0P2OWil20::RXP@0Xj>S0P2PX:0209nOW`80XZ:R0P2VYZH20:VYZ@80Zj^[0P2XZ:P20:FUY@03
0:VYZ@2][Jd0[Jf]0080Zj^[0P2XZ:P60:VYZ@80Z:RX0P2VYZH20:>SX`@0Y:BT0P2PX:0209bLW080
Vi^K0P2JVYX209NGU`80TY:B0P2=SHd208R8R0@0QhN70P24Q8@208>3P`80Q8B41@25QHD208:2PP80
P8201021PH4207emO@80NGUi0P1jNWX207]kN`80O7al101mOGdW0<SPf080=3@d0P1ADE4206IVIP80
R8R80P1gMgL205QHF08092@T0P0L71`201dM7@806a/K0P0J6QX201hN7P809RHV0P1IFET209:BTP03
09jNWP1aLG40LG5a00@0Kfm_0P1aLG4208F5Q@80Z:RX0P35aLD20<W9b@80c<c<0P3;bl/20<c<c080
c/k>0P2e]KD204I6AP809bLW100Q8B4202<S8`80:RXZ0P0U9BD202<S8`80:BTY0P17AdL205IFEP80
?clo0P0j>SX203Ph>080?3`l0P15ADD405EEE@0306UYJ@1VIVH0IVIV0080K6a/0P1`L70207IfMP80
MgMg101mOGd208F5Q@80PH610P22PX8208B4Q080P8201022PX8208B4Q080QhN70P29RHT208f=S@80
Rh^;102@T90209>CT`80UIFE0P2MWId209NGU`80W9bL0P2MWId209RHV080X:2P0P2MWId20:6QX@03
0:BTY02RXZ80XZ:R0080XJ6Q0P2RXZ820:2PX080ZZZZ0P2WYjL20:ZZZP80YZJV0P2SXj<20:^[Z`80
[:b/0P2XZ:P20:ZZZP80Zj^[0P2YZJT20:NWY`80ZJVY102UYJD20:6QX@80YJFU0P2QXJ4209VIV@80
Vi^K0P2HV9P209NGU`80TY:B0P2>SXh208V9R@80QXJ60P28R8P00`24Q8@0Ph>308>3P`0408>3P`80
QhN70P23Ph<40861P@80OGem0P22PX8207inOP80Ng]k0P1hN7P207YjNP80OWin0P1kNg/207inORL0
b>3H0P0j>SX204a<C080I6AT0P2<S8`206e]K@80CTi>0P0X:2P201`L70806a/K100L71`201hN7P03
02DU9@1QHF40HF5Q0080U9BD0P2PX:02071`L080KFe]0P1`L70207alO080Q8B40P2UYJD20<K6aP80
b/[:0P38b<P20<k>cP80dM7A1032`/8203/k>`80:RXZ0P0O7al202DU9@808R8R0P0X:2P201hN7P80
7AdM0P0h>3P00`0m?Cd0Fe]K05]KF`0203Ti>@80?3`l0P0g=cL203`l?080AdM70P1>CTh205YJFP80
IFEU0P1WIfL206a/K080L71`0P1bLW8407YjNP80OGem0P25QHD207inOP80R8R80P20P8020861P@80
P8200P27QhL208>3P`<0RHV9102;Rh/209>CT`80Shn?0P2>SXh209BDU0@0VYZJ0P2IVIT209^KV`80
W9bL0P2NWYh209fMW@80XZ:R0P2VYZH20:BTY080X:2P0P2OWil20:BTY080Xj>S102/[:`20:FUY@80
Y:BT00<0[:b/0:j^[P2^[Zh00P2YZJT20:ZZZP80Z:RX0P2VYZH20:VYZ@80ZZZZ102UYJD20:6QX@80
YJFU1P2MWId409RHV0@0T92@0P27QhL408V9R@80PH610P23Ph<408F5Q@0308B4Q022PX80PX:20080
Q8B40P21PH4207inOP80PX:20P1jNWX207]kN`80N7Qh0P1kNg/407emO@80O7al7P38h=P001`0b>3H
0P13@d<2061PH080PH610P2MWId208V9R@80H61P0P0X:2P201hN7P807alO0P0N7Qh201lO7`806a/K
00<08R8R03dm?@0m?Cd00P1gMgL20::RXP80OWin0P1eMGD206i^KP80LW9b0P1kNg/209fMW@80a<C4
0P38b<P20<[:bP80c/k>0P3@d=020<_;b`80`L710P2WYjL204M7A`8071`L0P0T92@2028R8P809bLW
0P0S8b<202@T90809RHV00<0@D5105eMG@1MGEd00P0g=cL203De=@80=3@d0P0m?Cd204Q8B080DU9B
0P1KFe/2069RHP80J6QX0P1/K6`206m_K`80M7Ad0P1hN7P207YjNP80O7al0P20P80808>3P`H0Q8B4
00<0QhN708Z:RP2:RXX00P2=SHd408n?S`80T92@0P2DU9@209NGU`@0V9RH0P2KVi/409fMW@80WYjN
0P2OWil20:2PX0H0XJ6Q0P2RXZ820:JVYP80ZZZZ0P2[Zj/20:b/[080ZJVY0P2WYjL00`2YZJT0[:b/
0:b/[0020:b/[0@0Zj^[1P2ZZZX20:NWY`80Y:BT102UYJD20::RXP80WYjN0P2LW9`209ZJVP80UiNG
0P2DU9@208j>SP80R8R80P27QhL208J6QP80QHF50P24Q8@208F5Q@80QXJ600<0QHF508B4Q024Q8@0
0P22PX840861P@80P8200P1mOGd407UiN@80NWYj0P1mOGd407moObL0b>3H0P13@d<2069RHP80OWin
0P2CTi<207moO`80H61P0P0V9RH201dM7@807alO0P0T92@201dM7@807QhN0P0T92@203/k>`80PH61
00<0W9bL07moO`1oOgl00P1eMGD206i^KP80L71`0P1nOWh20:2PX080a/K60P37alL20<[:bP80c<c<
0P3=cLd20<k>cP80c<c<0P2UYJD203lo?`809RHV1P0S8b<4024Q8@80:b/[0P11@D4205MGE`80?3`l
0P0g=cL203@d=080?3`l0P15ADD2051@D080Fe]K00<0I6AT06EUI@1UIFD00P1/K6`2071`L080M7Ad
0P1fMWH207alO080NGUi1021PH420820P080Ph>30P25QHD208J6QP80QhN70P23Ph<208J6QP80RHV9
0P2ATI4208n?S`80TY:B0P2>SXh409>CT`80UiNG0P2EUID209^KV`80W9bL0P2OWil209ZJVP80WinO
0P2TY:@00`2RXZ80X:2P0:2PX0020:BTY080X:2P0P2TY:@20:ZZZP80[:b/0P2][Jd20:JVYP80Xj>S
0P2[Zj/20:f][@80[:b/102XZ:P20:^[Z`80ZZZZ0P2YZJT20:ZZZP80YjNW102UYJD20:JVYP80WYjN
102MWId209NGU`80U9BD0P28R8P208N7Q`80QHF50P24Q8@00`26QXH0QHF508F5Q@0208N7Q`80QXJ6
0P28R8P208>3P`80PX:21023Ph<20861P@80O7al0P1gMgL207QhN080OGem0P1kNg/207inOP80Ph>3
9`38h=P204E5A@80HF5Q0P24Q8@209^KV`80RHV90P1MGEd202PX:0808R8R0P0O7al201LG5`807QhN
0P0M7Ad00`0P8200>3Ph03Ph>00207MgM`80WinO0P20P80207EeM@80Jf][0P1aLG4207YjNP80WIfM
0P34a<@20<S8b080bl_;0P3<c<`20<o?c`80bl_;0P34a<@20:FUY@80B4Q80P0K6a/202DU9@808B4Q
0P0Y:BT2024Q8@808b<S0P0W9bL00`11@D40GUiN05iNGP0203Ph>080=CDe0P0d=3@203/k>`80Bd];
0P1EEED205QHF080Hf=S0P1VIVH206i^KP80LG5a0P1iNGT207MgM`80O7al0P1iNGT408:2PP80QHF5
0P23Ph<20861P@80QXJ60P24Q8@208:2PP0308F5Q@28R8P0R8R80080SHf=0P2<S8`208j>SP80TY:B
0P2EUID209NGU`80Vi^K102HV9P209fMW@80WinO102NWYh20:6QX@@0WinO0P2NWYh20:6QX@80YjNW
0P2VYZH20:f][@H0YjNW00<0Zj^[0:j^[P2^[Zh00P2][Jd20:b/[080[Jf]0P2_[jl20:f][@80Z:RX
0P2SXj<40:JVYP80Y:BT0P2RXZ8209ZJVP80WIfM0P2LW9`209RHV080UIFE0P2=SHd208R8R080QHF5
0P28R8P208:2PP80QhN70P22PX8208R8R00308F5Q@24Q8@0Q8B40080Q8B40P20P80207]kN`80QHF5
101jNWX407UiN@80Ng]k0P1mOGd207moOah0b>3H000L0<SPf080@d=30P1PH6020861P@80WIfM0P29
RHT2061PH080:2PX0P0N7Qh201lO7`807QhN0P0O7al201/K6`03028R8P0m?Cd0?Cdm0080MgMg0P2R
XZ8207inOP80MGEe0P1^KVh2079bLP80Ng]k0P2MWId20<C4a080b<S80P3:b/X20<k>cP80d=3@0P3;
bl/20<71`@80YjNW0P17AdL201`L708092@T0P0R8R8202LW9`808b<S0P0T92@202HV9P030451@@1M
GEd0GEeM0080=cLg0P0e=CD203@d=080?Cdm0P18B4P2059BDP80Fe]K0P1RHV8206QXJ080K6a/0P1_
Kfl207AdM080N7Qh0P1jNWX207alO080P8202023Ph<608B4Q00308N7Q`2:RXX0RXZ:0080SHf=102?
Shl2092@T080U9BD0P2GUiL409RHV080Vi^K102MWId209jNWP80WinO0P2PX:060:6QX@80XZ:R0P2V
YZH20:ZZZP80Zj^[0P2/[:`20:VYZ@80YjNW00<0ZJVY0:b/[02/[:`00P2/[:`40:^[Z`H0ZZZZ0P2W
YjL20:BTY0@0YJFU0P2RXZ8209jNWP80W9bL0P2JVYX209NGU`80U9BD0P2>SXh208R8R080QhN70P26
QXH208F5Q@80Q8B40P25QHD208J6QP0308F5Q@24Q8@0Q8B40080PX:21021PH420820P080OGem101i
NGT207YjNP80OGem101oOglW0<SPf080@d=30P1RHV8207inOP80Ti>C0P1oOgl2061PH0809RHV0P0M
7Ad201lO7`8092@T0P0M7Ad201hN7P8092@T0P0k>c/20861P@0309bLW01oOgl0Ogmo0080MGEe0P1^
KVh2071`L080OWin0P2PX:020<K6aP80alO70P3:b/X20<c<c080cLg=0P3>c/h20<c<c080YJFU0P0o
?cl202HV9PH08b<S100Q8B4202/[:`80@D510P1GEeL203`l?080=cLg0P0d=3@203`l?080ADE50P1@
D50205]KF`0306ATI01UIFD0IFEU0080K6a/0P1`L70207AdM080MWIf0P1lO7`207UiN@@0PH610P20
P80208>3P`80QHF50P26QXH208N7Q`80Ph>30P26QXH208V9R@80TI6A0P2?Shl209:BTP80SXj>102C
Ti<209NGU`80UIFE0P2KVi/209bLW080WinO0P2JVYX209nOW`80Y:BT00<0XZ:R0:2PX02PX:000P2T
Y:@20:2PX080Y:BT0P2ZZZX20:b/[080[Jf]0P2VYZH20:>SX`80Zj^[0P2][Jd20:b/[0@0Z:RX0P2[
Zj/20:ZZZP80ZJVY0P2ZZZX20:NWY`@0YJFU0P2VYZH209jNWP@0WIfM0P2GUiL209BDU080R8R80P27
QhL208F5Q@80Q8B400<0QXJ608F5Q@25QHD00P27QhL208J6QP80R8R80P23Ph<208:2PP@0Ph>30P21
PH4207alO080MgMg0P1hN7P207emO@80Ng]k0P1nOWh208>3PbL0b>3H0P15ADD2065QH@80Q8B40P2K
Vi/208V9R@80GEeM0P0X:2P2028R8P807alO0P0G5aL201hN7P807AdM00<0820P03Ph>00h>3P00P1g
MgL209nOW`80P8200P1eMGD206][J`80LG5a0P1jNWX209fMW@80a<C40P38b<P20<_;b`80c<c<0P3?
cll20<_;b`80a<C40P2UYJD204Q8B0806a/K0P0U9BD2024Q8@80:BTY0P0Q8B4202<S8`809bLW00<0
@D5105iNGP1NGUh00P0h>3P203De=@80=3@d0P0k>c/204];B`80EEEE0P1HF5P206=SH`80IVIV0P1^
KVh2075aL@80NGUi0P1gMgL207alO080NGUi1022PX8208F5Q@80Ph>30P21PH4208J6QP80Q8B40P22
PX800`25QHD0R8R808R8R00208f=S@80S8b<0P2>SXh209:BTP80UIFE0P2GUiL209^KV`@0V9RH0P2M
WId209nOW`@0WYjN0P2QXJ4409nOW`80WYjN0P2QXJ420:NWY`80YZJV0P2][Jd60:NWY`030:^[Z`2^
[Zh0[Zj^0080[Jf]0P2/[:`20:f][@80[jn_0P2][Jd20:RXZ080Xj>S102VYZH20:BTY080XZ:R0P2J
VYX209fMW@80W9bL0P2HV9P209FEU@80SHf=0P28R8P208F5Q@80R8R80P22PX8208N7Q`80PX:20P28
R8P00`25QHD0Q8B408B4Q00208B4Q080P8200P1kNg/208F5Q@@0NWYj101iNGT207]kN`80OGem0P1o
OglN0<SPf0007038h=P2051@D080Lg=c0P2OWil20:FUY@80VYZJ0P1SHf<202TY:@807alO0P0R8R82
024Q8@808b<S0P0O7al00`0U9BD07QhN01hN7P0205YJFP80UIFE0P2=SHd207moO`80KFe]0P1ZJVX2
07=cL`80UYJF0P2k^k/20<G5a@80bl_;0P3<c<`20<_;b`80e=CD0P3@d=020<C4a080Rh^;0P0c<c<2
02DU9@807QhN0P0W9bL202HV9P80:b/[0P0J6QX00`15ADD0Fe]K05]KF`0203@d=080<S8b0P0a<C42
03`l?080BTY:0P1DE5@205aLG080HF5Q0P1VIVH206][J`80L71`0P1dM7@207MgM`80NGUi0P1kNg/2
07moO`H0Ph>30P25QHD208J6QP@0QHF500<0QhN708^;R`2;Rh/00P2>SXh208n?S`80T92@0P2ATI42
09FEU@80VIVI0P2HV9P209NGU`80VYZJ0P2NWYh:09nOW`80X:2P0P2RXZ820:FUY@80ZZZZ102][Jd2
0:^[Z`80ZZZZ0`2YZJT20:ZZZP80[Jf]0P2^[Zh20:b/[0@0ZZZZ0P2[Zj/20:RXZ0H0YJFU0P2SXj<2
0:6QX@80WIfM0P2IVIT209NGU`80UIFE0P2?Shl208V9R@80QXJ61P25QHD208N7Q`80R8R800<0QXJ6
08B4Q024Q8@00P23Ph<20861P@80P8200P1oOgl207alO0@0NGUi0P1jNWX207emO@80PH610P22PX8W
0<SPf080De=C0P1dM7@209^KV`80[Jf]0P2HV9P206UYJ@809RHV0P0N7Qh2020P808092@T0P0S8b<2
01lO7`80820P0P0V9RH205]KF`0308b<S02DU9@0U9BD0080O7al0P1^KVh206][J`80M7Ad0P2@T902
0;Jf]P80c/k>0P36a/H20<g=c@80clo?103=cLd20<W9b@80Rh^;0P0a<C42028R8P@09bLW0P0T92@2
02/[:`809RHV0P14A4@205EEE@80>3Ph0P0_;bl203De=@80>CTi0P1<C4`205IFEP80FUYJ00<0IFEU
06IVIP1VIVH00P1_Kfl2075aL@80Lg=c0P1fMWH207inOP80N7Qh0P23Ph<208F5Q@80P8200P23Ph<6
08F5Q@80QXJ60P27QhL408^;R`80T92@0P2CTi<208n?S`80UIFE202HV9P20:2PX080WIfM0P2PX:02
0:BTY080W9bL00<0WIfM0:2PX02PX:000P2SXj<20:RXZ080Y:BT0P2][Jd20;6a/@80ZJVY0P2ZZZX2
0:NWY`80[:b/0P2XZ:P20:j^[P80/;2`0P2[Zj/20:ZZZP@0[:b/0P2UYJD20:NWY`80X:2P0P2UYJD2
0:JVYP80WinO0P2NWYh209RHV080VIVI0P2DU9@2096AT@80RXZ:0P25QHD508J6QP80Q8B40P28R8P2
08J6QP80PX:20P25QHD40820P080Ogmo0P1kNg/207YjNP80N7Qh0P1kNg/207alO0@0PX:29`38h=P2
04i>CP80Lg=c0P2OWil20:FUY@80WYjN0P1QHF4202XZ:P807alO0P0Q8B4201lO7`808R8R0P0Q8B40
0`0T92@0820P020P800205aLG080UYJF0P2=SHd207moO`80Jf][101`L70209RHV080^KVi0P37alL2
0<_;b`80c<c<0P3=cLd20=GEe@80clo?0P37alL208j>SP@0:b/[0P0L71`202TY:@808B4Q0P0];Bd2
01/K6`0304A4A01JFUX0FUYJ0080<c<c100b<S8203`l?080ADE50P1HF5P205YJFP80Hf=S0P1WIfL2
06YZJP80Kfm_0P1eMGD207AdM080Ng]k0P1iNGT20861P@H0Ph>30P27QhL208F5Q@80R8R80`26QXH2
08j>SP80Rh^;0P2BTY8208n?S`80TI6A0P2EUID209JFUP80W9bL0P2EUID209RHV080X:2P102NWYh2
0:FUY@80WinO0P2NWYh20::RXP80XJ6Q0P2VYZH20:ZZZP80Zj^[0P2`/;020:^[Z`80ZZZZ0`2YZJT2
0:ZZZP80[jn_0P2`/;020:RXZ080ZZZZ102/[:`60:NWY`80YJFU102RXZ8209bLW080VYZJ102FUYH2
08j>SP80RXZ:1026QXH208>3P`80QhN70P22PX8208^;R`0308R8R020P800P8200080Q8B40P20P802
08:2PP80P8200P1iNGT407YjNP80NGUi0P1jNWX208>3P`80Q8B47P38h=P001`0b>3H0P1@D50207=c
L`80WinO0P2UYJD209ZJVP80Hf=S0P0Y:BT201lO7`808R8R0P0Q8B4202<S8`807alO00<09BDU01hN
7P0N7Qh00P1JFUX209FEU@80SHf=0P1oOgl206e]K@80JVYZ0P1cLg<209JFUP80^k^k0P35aLD20<_;
b`80c<c<0P3;bl/20=CDe080d=3@0P34a<@208^;R`80<c<c0P0U9BD201hN7P809bLW0P0V9RH202/[
:`806QXJ00<0ADE505]KF`1KFe/00P0d=3@2038b<P80<C4a0P0l?3`204Y:BP80E5AD0P1LG5`2065Q
H@80IVIV0P1[Jf/2071`L080M7Ad0P1gMgL207UiN@80Ng]k0P1oOgl608>3P`80QHF50P26QXH408F5
Q@0308N7Q`2;Rh/0Rh^;0080SXj>0P2?Shl2092@T080TI6A0P2EUID209VIV@80V9RH0P2GUiL209ZJ
VP80WYjN2P2OWil20:2PX080XZ:R0P2UYJD20:ZZZP@0[Jf]0P2[Zj/20:ZZZP<0ZJVY0P2ZZZX20:f]
[@80[Zj^0P2/[:`40:ZZZP80Zj^[0P2XZ:P60:FUY@80Xj>S0P2QXJ4209fMW@80VIVI0P2GUiL209FE
U@80Shn?0P29RHT208J6QPH0QHF50P27QhL208R8R00308J6QP24Q8@0Q8B40080Ph>30P21PH420820
P080Ogmo0P1lO7`407UiN@80NWYj0P1mOGd20861P@80PX:29`38h=P205=CD`80M7Ad0P2KVi/20:f]
[@80V9RH0P1YJFT202HV9P807QhN0P0P820202@T90808b<S0P0O7al2020P80809RHV0P1KFe/00`2<
S8`0U9BD09BDU00207alO080KVi^0P1[Jf/207AdM080T92@0P2f][H20<k>cP80a/K60P3=cLd20<o?
c`@0cLg=0P39bLT208^;R`80<C4a0P0R8R8402LW9`8092@T0P0[:b/202HV9P80A4A40P1EEED203Ph
>080;bl_0P0e=CD203Ti>@80C4a<0P1FEUH205YJFP0306EUI@1VIVH0IVIV0080Kfm_0P1aLG4207=c
L`80MWIf0P1nOWh207QhN080Ph>30P25QHD20820P080Ph>31P25QHD208J6QP80QhN7102;Rh/2092@
T080Ti>C0P2?Shl209FEU@P0V9RH0P2PX:0209fMW@80X:2P0P2TY:@209bLW00309fMW@2PX:00X:2P
0080Xj>S0P2XZ:P20:BTY080[Jf]0P2a/K420:VYZ@80ZZZZ0P2WYjL20:b/[080Z:RX0P2^[Zh20;2`
/080Zj^[0P2ZZZX40:b/[080YJFU0P2WYjL20:2PX080YJFU0P2VYZH209nOW`80WYjN0P2HV9P209VI
V@80U9BD0P2ATI4208Z:RP80QHF51@26QXH208B4Q080R8R80P26QXH208:2PP80QHF51020P80207mo
O`80Ng]k0P1jNWX207QhN080Ng]k0P1lO7`408:2PRL0b>3H0P1>CTh207=cL`80WinO0P2UYJD209jN
WP80HF5Q0P0Z:RX201lO7`808B4Q0P0O7al2028R8P808B4Q00<092@T020P800P82000P1LG5`209JF
UP80SHf=0P1oOgl206][J`@0L71`0P2HV9P20;Vi^@80alO70P3;bl/20<c<c080cLg=0P3EeMD20<o?
c`80alO70P2>SXh402/[:`8071`L0P0Y:BT2024Q8@80;Bd]0P0K6a/00`14A4@0FUYJ05YJFP0203<c
<`@0<S8b0P0l?3`204E5A@80F5QH0P1JFUX206=SH`80IfMW0P1ZJVX206m_K`80MGEe0P1dM7@207]k
N`80NGUi0P21PH4608>3P`80QhN70P25QHD208R8R0<0QXJ60P2>SXh208^;R`80TY:B0P2?Shl2096A
T@80UIFE0P2FUYH209bLW080UIFE0P2HV9P20:2PX0@0WYjN0P2UYJD209nOW`80WYjN0P2RXZ820:6Q
X@80YZJV0P2ZZZX20:^[Z`80/;2`0P2[Zj/20:ZZZP<0ZJVY0P2ZZZX20:n_[`80/;2`0P2XZ:P20:ZZ
ZP@0[:b/1P2WYjL20:FUY@@0XZ:R0P2LW9`209ZJVP@0UYJF0P2>SXh208Z:RP@0QXJ60P23Ph<208N7
Q`80PX:20P2;Rh/00`28R8P0P8200820P00208B4Q080P8200P22PX820820P080NGUi101jNWX207Ui
N@80NWYj0P23Ph<208B4Q1h0b>3H000L0<SPf080HF5Q0P27QhL20;6a/@80YJFU0P2=SHd204U9B@80
:RXZ0P0P820202@T90809BDU0P0W9bL202@T900302LW9`0O7al07alO0080@D510P1mOGd2092@T080
TI6A0P1VIVH206UYJ@80Kfm_0P27QhL20:2PX080b/[:0P38b<P20<c<c080bLW90P3@d=020<g=c@80
fMWI0P2d];@206][J`808R8R0P0P820202HV9P809BDU0P0X:2P202HV9P0304=3@`1:BTX0BTY:0080
>3Ph100e=CD203lo?`80C4a<0P1EEED205aLG080Hf=S0P1XJ6P206e]K@80LG5a0P1eMGD207QhN080
Ng]k0P1nOWh20861P@80Ph>31022PX8208B4Q0H0QhN700<0RXZ:08f=S@2=SHd00P2>SXh2092@T080
TI6A0P2CTi<209JFUPH0V9RH0P2KVi/609jNWP80X:2P0P2RXZ820:>SX`80YJFU0P2VYZH20:RXZ080
[Jf]0P2`/;020:j^[P@0[:b/1@2][Jd40:j^[P80Zj^[0P2YZJT20:ZZZP80Zj^[0P2YZJT20:NWY`80
YJFU0P2TY:@20:>SX`80XJ6Q0P2MWId209VIV@80UiNG0P2FUYH2092@T080RXZ:0P28R8P:08J6QP03
08R8R029RHT0RHV90080QHF50P21PH420820P080Ogmo0P1nOWh207alO0@0Ng]k0P1oOgl208:2PP80
Ph>39`38h=P205mOG`80P8200P2f][H20:f][@80RXZ:0P1ADE4202TY:@@08b<S0P0X:2P202DU9@80
820P0P0X:2P202@T9080>c/k00<0NWYj09VIV@2IVIT00P23Ph<206e]K@@0Kfm_0P21PH420:2PX080
dM7A0P37alL20<W9b@80bl_;0P3<c<`20<g=c@80dM7A0P31`L4205aLG0809bLW0P0P820202HV9P80
8b<S0P0T92@202DU9@80@4100P1>CTh203Ti>@80<C4a0P0h>3P203lo?`80Cdm?0P1DE5@205]KF`03
069RHP1UIFD0IFEU0080K6a/0P1`L70206m_K`80N7Qh0P1lO7`207emO@80OWin0P25QHD207moO`80
QhN70P24Q8@208J6QP80QHF50P24Q8@208f=S@80Shn?0P2;Rh/208b<S080T92@0P2CTi<209RHV080
Vi^K102IVIT209bLW080WYjN0P2KVi/209jNWP80W9bL0P2TY:@00`2QXJ40YZJV0:JVYP020:>SX`80
ZZZZ0P2/[:`20;:b/P80[Jf]102/[:`20:n_[`80[Zj^0P2[Zj/20:b/[080[Zj^0P2][Jd40:RXZ080
Zj^[0P2VYZH40:NWY`80XJ6Q0P2RXZ8209nOW`80VIVI0P2EUID209NGU`80UIFE0P2ATI4208Z:RP80
R8R80P26QXH00`29RHT0Q8B408B4Q00208B4Q0H0QhN70P2:RXX207inOP80Ng]k0P20P80207moO`80
P8200P1iNGT207]kN`80OGem0P21PH4208F5QBL0b>3H0P1SHf<208J6QP80/K6a0P2SXj<208Z:RP80
C4a<0P0X:2P201hN7P809RHV0P0Y:BT202XZ:P8092@T00<09bLW024Q8@0Q8B400P0n?Sh207]kN`80
TI6A0P2@T90206QXJ080JVYZ0P1^KVh208V9R@80X:2P0P36a/H20<W9b@80c/k>0P38b<P20<[:bP80
c<c<0P3Hf=P20;Jf]P80JFUY0P0R8R8201hN7P80:2PX0P0V9RH202XZ:P8092@T00<0A4A404a<C01<
C4`00P0i>CT403@d=080?Shn0P1>CTh205IFEP80FUYJ0P1SHf<206QXJ080Jf][0P1aLG4207MgM`80
N7Qh0P1jNWX207inOP80PX:20P24Q8@207moO`80PX:20P24Q8@208J6QP80PX:20`29RHT208n?S`@0
T92@0P2BTY82096AT@80U9BD0P2EUID209ZJVP80V9RH102LW9`209jNWP80VYZJ0P2RXZ8209nOW`80
XZ:R0P2UYJD40:RXZ080[Jf]0P2a/K420;:b/P80[:b/0P2[Zj/20:f][@030:b/[02[Zj/0Zj^[0080
[Jf]0P2_[jl20:JVYP80YjNW0P2[Zj/20:b/[080YZJV0P2WYjL20:6QX@@0Y:BT0P2SXj<209fMW@80
V9RH0P2FUYH209FEU@80TI6A0P2;Rh/208F5Q@80R8R80P27QhL208Z:RP80Q8B40P23Ph<00`28R8P0
RHV908V9R@0208R8R080PX:2101oOgl207emO@80O7al0P1nOWh207moO`80OGem0P22PX8208B4Q1h0
b>3H000L0<SPf080HF5Q0P27QhL20;6a/@80YJFU0P2=SHd204U9B@80:RXZ0P0P820202@T90809BDU
0P0W9bL202@T900302LW9`0O7al07alO0080@D510P1mOGd2092@T080TI6A0P1VIVH206UYJ@80Kfm_
0P27QhL20:2PX080b/[:0P38b<P20<c<c080bLW90P3@d=020<g=c@80fMWI0P2d];@206][J`808R8R
0P0P820202HV9P809BDU0P0X:2P202HV9P0304=3@`1:BTX0BTY:0080>3Ph100e=CD203lo?`80C4a<
0P1EEED205aLG080Hf=S0P1XJ6P206e]K@80LG5a0P1eMGD207QhN080Ng]k0P1nOWh20861P@80Ph>3
1022PX8208B4Q0H0QhN700<0RXZ:08f=S@2=SHd00P2>SXh2092@T080TI6A0P2CTi<209JFUPH0V9RH
0P2KVi/609jNWP80X:2P0P2RXZ820:>SX`80YJFU0P2VYZH20:RXZ080[Jf]0P2`/;020:j^[P@0[:b/
1@2][Jd40:j^[P80Zj^[0P2YZJT20:ZZZP80Zj^[0P2YZJT20:NWY`80YJFU0P2TY:@20:>SX`80XJ6Q
0P2MWId209VIV@80UiNG0P2FUYH2092@T080RXZ:0P28R8P:08J6QP0308R8R029RHT0RHV90080QHF5
0P21PH420820P080Ogmo0P1nOWh207alO0@0Ng]k0P1oOgl208:2PP80Ph>39`38h=P205mOG`80P820
0P2f][H20:f][@80RXZ:0P1ADE4202TY:@@08b<S0P0X:2P202DU9@80820P0P0X:2P202@T9080>c/k
00<0NWYj09VIV@2IVIT00P23Ph<206e]K@@0Kfm_0P21PH420:2PX080dM7A0P37alL20<W9b@80bl_;
0P3<c<`20<g=c@80dM7A0P31`L4205aLG0809bLW0P0P820202HV9P808b<S0P0T92@202DU9@80@410
0P1>CTh203Ti>@80<C4a0P0h>3P203lo?`80Cdm?0P1DE5@205]KF`03069RHP1UIFD0IFEU0080K6a/
0P1`L70206m_K`80N7Qh0P1lO7`207emO@80OWin0P25QHD207moO`80QhN70P24Q8@208J6QP80QHF5
0P24Q8@208f=S@80Shn?0P2;Rh/208b<S080T92@0P2CTi<209RHV080Vi^K102IVIT209bLW080WYjN
0P2KVi/209jNWP80W9bL0P2TY:@00`2QXJ40YZJV0:JVYP020:>SX`80ZZZZ0P2/[:`20;:b/P80[Jf]
102/[:`20:n_[`80[Zj^0P2[Zj/20:b/[080[Zj^0P2][Jd40:RXZ080Zj^[0P2VYZH40:NWY`80XJ6Q
0P2RXZ8209nOW`80VIVI0P2EUID209NGU`80UIFE0P2ATI4208Z:RP80R8R80P26QXH00`29RHT0Q8B4
08B4Q00208B4Q0H0QhN70P2:RXX207inOP80Ng]k0P20P80207moO`80P8200P1iNGT207]kN`80OGem
0P21PH4208F5QBL0b>3H0P1SHf<208J6QP80/K6a0P2SXj<208Z:RP80C4a<0P0X:2P201hN7P809RHV
0P0Y:BT202XZ:P8092@T00<09bLW024Q8@0Q8B400P0n?Sh207]kN`80TI6A0P2@T90206QXJ080JVYZ
0P1^KVh208V9R@80X:2P0P36a/H20<W9b@80c/k>0P38b<P20<[:bP80c<c<0P3Hf=P20;Jf]P80JFUY
0P0R8R8201hN7P80:2PX0P0V9RH202XZ:P8092@T00<0A4A404a<C01<C4`00P0i>CT403@d=080?Shn
0P1>CTh205IFEP80FUYJ0P1SHf<206QXJ080Jf][0P1aLG4207MgM`80N7Qh0P1jNWX207inOP80PX:2
0P24Q8@207moO`80PX:20P24Q8@208J6QP80PX:20`29RHT208n?S`@0T92@0P2BTY82096AT@80U9BD
0P2EUID209ZJVP80V9RH102LW9`209jNWP80VYZJ0P2RXZ8209nOW`80XZ:R0P2UYJD40:RXZ080[Jf]
0P2a/K420;:b/P80[:b/0P2[Zj/20:f][@030:b/[02[Zj/0Zj^[0080[Jf]0P2_[jl20:JVYP80YjNW
0P2[Zj/20:b/[080YZJV0P2WYjL20:6QX@@0Y:BT0P2SXj<209fMW@80V9RH0P2FUYH209FEU@80TI6A
0P2;Rh/208F5Q@80R8R80P27QhL208Z:RP80Q8B40P23Ph<00`28R8P0RHV908V9R@0208R8R080PX:2
101oOgl207emO@80O7al0P1nOWh207moO`80OGem0P22PX8208B4Q1h0b>3H000L0<SPf080MWIf0P2E
UID20;>c/`80VIVI0P1cLg<202/[:`80:RXZ0P0R8R8202HV9P809bLW1@0Y:BT202PX:080;Rh^0P1Q
HF4208b<S080WYjN0P1UIFD206YZJP80KVi^0P1hN7P208F5Q@80bLW90P35aLD20<_;b`80a/K60P39
bLT20<[:bP80fMWI0P3Cdm<20:BTY080<30`100V9RH202<S8`8092@T0P0c<c<00`0o?cl0>c/k03/k
>`0203/k>`80>3Ph0P0i>CT20492@P80CTi>0P1FEUH205eMG@80IFEU0P1[Jf/206m_K`80Lg=c0P1f
MWH207UiN@80OGem0P21PH4208:2PPH0PH610P24Q8@208N7Q`80R8R80P2:RXX00`2<S8`0SXj>08j>
SP0208n?S`80T92@0P2CTi<209JFUP@0UiNG0P2HV9P209VIV@80Vi^K0P2MWId409bLW080X:2P0P2U
YJD20:RXZ080ZJVY0P2ZZZX20:^[Z`80[jn_0P2b/[820;2`/080[Jf]0P2_[jl30;6a/@80/;2`0P2_
[jl20:f][@80ZZZZ0P2XZ:P20:VYZ@80Zj^[0P2ZZZX20:RXZ080YZJV0P2SXj<20::RXP80X:2P0P2L
W9`209VIV@80UiNG0P2FUYH2096AT@80S8b<0P2:RXX208R8R0@0QhN70P26QXH208F5Q@0308Z:RP2>
SXh0SXj>0080QhN71P20P80207moO`80OWin101lO7`20820P080Ph>30P24Q8@W0<SPf080NGUi0P2C
Ti<20;:b/P80V9RH0P1^KVh2038b<P808B4Q0P0^;Rh2028R8P809RHV100[:b/202PX:0809bLW0P0`
<3000`1PH600T92@092@T00209FEU@80KFe]0P1TI6@2071`L080NGUi0P25QHD20<?3``80b/[:0P35
aLD20<S8b080bl_;0P3>c/h20=7Ad@80e=CD0P2WYjL202l_;`808R8R100U9BD202PX:080;bl_0P0i
>CT204Q8B080=cLg0P0f=SH203`l?080AdM70P1ADE4205=CD`80GUiN00<0IFEU06i^KP1^KVh00P1]
KFd207MgM`80M7Ad0P1jNWX20820P080OWin1023Ph<207inOP80Q8B40P22PX8208J6QP80QhN70P2:
RXX608f=S@80T92@0P2GUiL209BDU080V9RH0P2FUYH209NGU`80V9RH102LW9`209^KV`80WIfM0P2L
W9`20:FUY@030:VYZ@2WYjL0YjNW0080[Jf]102[Zj/20;Bd]080[jn_0P2][Jd20:n_[`80/K6a0P2_
[jl20;:b/P80[jn_0P2/[:`20:RXZ080YjNW102/[:`20:NWY`80ZJVY0P2WYjL20:BTY080XJ6Q0P2R
XZ8209jNWP80VYZJ0P2IVIT209>CT`80TI6A0P2:RXX208V9R@80QHF500<0R8R808J6QP26QXH00P25
QHD208N7Q`80R8R80P2ATI4208J6QP80Ph>30P1oOgl40861P@80NWYj0P1mOGd407alO080Q8B40P29
RHTW0<SPf080N7Qh0P2CTi<20;Fe]@80VIVI0P1cLg<202l_;`80:2PX0P0Q8B4202LW9`809RHV0P0Y
:BT202XZ:P0302TY:@0V9RH09RHV0080;Rh^0P1QHF4208b<S080WIfM0P1VIVH206MWI`80LW9b0P1e
MGD208R8R080alO70P3:b/X20<W9b@80b<S80P3:b/X20<c<c080f=SH0P3De=@20:>SX`80<30`0P0T
92@202HV9P@08B4Q0P0d=3@00`0k>c/0?Cdm03dm?@0203Ti>@80=cLg0P0i>CT20451@@80CDe=0P1H
F5P205iNGP80IFEU0P1[Jf/2071`L080M7Ad0P1eMGD207UiN@80OWin0P22PX820861P@80Q8B40P20
P80208>3P`80QHF50P26QXH408V9R@0308j>SP2?Shl0Shn?0080SHf=0P2@T90209JFUP80U9BD102G
UiL409RHV080Vi^K102NWYh209ZJVP80Y:BT0P2UYJD20:JVYPH0ZJVY0P2_[jl20;:b/P80[Zj^0P2/
[:`20:j^[P<0/[:b0P2c/k<20:^[Z`80[Zj^0P2/[:`20:NWY`80ZJVY0P2/[:`60:NWY`80YJFU0P2M
WId20:6QX@80WinO0P2IVIT209FEU@80UiNG0P2@T90208b<S080SHf=0P28R8P20861P@80R8R80P25
QHD208Z:RP0308N7Q`2>SXh0SXj>0080R8R80P1nOWh208B4Q080Ogmo0P22PX8207inOP80OGem0P1j
NWX20820P080Q8B40P22PX8N0<SPf0007038h=P207IfMP80UIFE0P2c/k<209VIV@80Lg=c0P0[:b/2
02XZ:P808R8R0P0V9RH202LW9`D0:BTY0P0X:2P202h^;P80HF5Q0P2<S8`209jNWP80IFEU0P1ZJVX2
06i^KP80N7Qh0P25QHD20<W9b@80aLG50P3;bl/20<K6aP80bLW90P3:b/X20=WIf@80dm?C0P2TY:@2
030`<0@09RHV0P0S8b<202@T9080<c<c00<0?clo03/k>`0k>c/00P0k>c/203Ph>080>CTi0P12@T82
04i>CP80EUIF0P1MGEd206EUI@80Jf][0P1_Kfl207=cL`80MWIf0P1iNGT207emO@80PH610P22PX86
0861P@80Q8B40P27QhL208R8R080RXZ:00<0S8b<08j>SP2>SXh00P2?Shl2092@T080Ti>C0P2FUYH4
09NGU`80V9RH0P2IVIT209^KV`80WIfM102LW9`20:2PX080YJFU0P2XZ:P20:VYZ@80ZZZZ0P2[Zj/2
0:n_[`80/[:b0P2`/;020:f][@80[jn_0`2a/K420;2`/080[jn_0P2][Jd20:ZZZP80Z:RX0P2YZJT2
0:^[Z`80ZZZZ0P2XZ:P20:JVYP80Xj>S0P2RXZ820:2PX080W9bL0P2IVIT209NGU`80UYJF0P2ATI42
08b<S080RXZ:0P28R8P408N7Q`80QXJ60P25QHD00`2:RXX0SXj>08j>SP0208N7Q`H0P8200P1oOgl2
07inOP@0O7al0P20P80208>3P`80Q8B49`38h=P207UiN@80Ti>C0P2b/[8209RHV080KVi^0P0b<S82
024Q8@80;Rh^0P0R8R8202HV9P@0:b/[0P0X:2P202LW9`80<30`00<0H61P092@T02@T9000P2EUID2
06e]K@80I6AT0P1`L70207UiN@80QHF50P33`l<20<[:bP80aLG50P38b<P20<_;b`80c/k>0P3AdM42
0=CDe080YjNW0P0_;bl2028R8P@09BDU0P0X:2P202l_;`80>CTi0P18B4P203Lg=`80=SHf0P0l?3`2
04M7A`80DE5A0P1CDe<205iNGP0306EUI@1^KVh0KVi^0080KFe]0P1gMgL207AdM080NWYj0P20P802
07inOP@0Ph>30P1nOWh208B4Q080PX:20P26QXH208N7Q`80RXZ:1P2=SHd2092@T080UiNG0P2DU9@2
09RHV080UYJF0P2GUiL209RHV0@0W9bL0P2KVi/209fMW@80W9bL0P2UYJD00`2YZJT0YjNW0:NWY`02
0:f][@@0Zj^[0P2d];@20:n_[`80[Jf]0P2_[jl20;6a/@80[jn_0P2b/[820:n_[`80[:b/0P2XZ:P2
0:NWY`@0[:b/0P2WYjL20:VYZ@80YjNW0P2TY:@20:6QX@80XZ:R0P2NWYh209ZJVP80VIVI0P2CTi<2
096AT@80RXZ:0P29RHT208F5Q@0308R8R026QXH0QXJ60080QHF50P27QhL208R8R080TI6A0P26QXH2
08>3P`80Ogmo1021PH4207YjNP80OGem101lO7`208B4Q080RHV99`38h=P207QhN080Ti>C0P2e]KD2
09VIV@80Lg=c0P0_;bl202PX:0808B4Q0P0W9bL202HV9P80:BTY0P0Z:RX00`0Y:BT09RHV02HV9P02
02h^;P80HF5Q0P2<S8`209fMW@80IVIV0P1WIfL2079bLP80MGEe0P28R8P20<O7a`80b/[:0P39bLT2
0<S8b080b/[:0P3<c<`20=SHf080e=CD0P2SXj<2030`<08092@T0P0V9RH4024Q8@80=3@d00<0>c/k
03dm?@0m?Cd00P0i>CT203Lg=`80>CTi0P11@D4204e=C@80F5QH0P1NGUh206EUI@80Jf][0P1`L702
07AdM080MGEe0P1iNGT207inOP80PX:20P21PH4208B4Q080P8200P23Ph<208F5Q@80QXJ61029RHT0
0`2>SXh0Shn?08n?S`0208f=S@80T92@0P2FUYH209BDU0@0UiNG102HV9P209^KV`@0WYjN0P2JVYX2
0:BTY080YJFU0P2VYZH60:VYZ@80[jn_0P2b/[820:j^[P80[:b/0P2^[Zh30;:b/P80/k>c0P2[Zj/2
0:j^[P80[:b/0P2WYjL20:VYZ@80[:b/1P2WYjL20:FUY@80WIfM0P2QXJ4209nOW`80VIVI0P2EUID2
09NGU`80T92@0P2<S8`208f=S@80R8R80P21PH4208R8R080QHF50P2:RXX00`27QhL0SXj>08j>SP02
08R8R080OWin0P24Q8@207moO`80PX:20P1nOWh207emO@80NWYj0P20P80208B4Q080PX:27P38h=P0
01`0b>3H0P2IVIT209^KV`80U9BD0P1aLG4204e=C@809bLW0P0[:b/602@T90@09bLW00<0:2PX02HV
9P0V9RH00P0[:b/204I6AP80QHF50P2EUID207alO080IFEU0P1bLW8207=cL`80P8200P2YZJT20<[:
bP80a/K60P31`L420<C4a080bLW90P3Fe]H20=OGe`80_[jn0P1fMWH2034a<@809BDU0P0O7al202@T
9080<30`00<0=CDe0492@P12@T800P0a<C4203De=@80>SXj0P12@T8204];B`80EEEE0P1OGel206EU
I@80Jf][0P1aLG4207MgM`80NGUi0P1jNWX207alO080OWin0P1oOgl20820P080PX:21024Q8@208F5
Q@80R8R80P2;Rh/00`2<S8`0SHf=08f=S@0208j>SP80T92@0P2CTi<209JFUP@0V9RH1P2IVIT209ZJ
VP80Vi^K0P2LW9`20:6QX@80YJFU0P2WYjL20:RXZ080ZJVY0P2ZZZX20:j^[P80/[:b0P2`/;020:f]
[@80[jn_0`2b/[820;6a/@80/;2`0P2^[Zh20:^[Z`80Z:RX0P2ZZZX20:b/[080ZZZZ0P2XZ:P20:NW
Y`80YJFU0P2SXj<20:2PX080WYjN0P2KVi/209RHV080UIFE0P2CTi<2092@T080SHf=0P2:RXX208V9
R@@0R8R80P29RHT00`2;Rh/0SHf=08f=S@0208R8R080Ph>31021PH4207moO`80OGem101lO7`20820
P080Ph>30P24Q8@W0<SPf080Y:BT0P2JVYX209BDU080L71`0P19BDT202d];@809RHV0P0Q8B42028R
8P809BDU0P0X:2P202@T9080:RXZ0P0[:b/202XZ:P0304e=C@20P800P8200080UiNG0P1iNGT206AT
I080L71`0P1kNg/207emO@80[Jf]0P3<c<`20;bl_080a<C40P38b<P20<c<c080d=3@0P3EeMD20<S8
b080MGEe0P0e=CD202TY:@808R8R0P0V9RH202LW9`80?clo0P13@d<2034a<@80;bl_0P0f=SH203dm
?@80AdM70P1ADE4206ATI00306QXJ01/K6`0K6a/0080L71`0P1gMgL407UiN@H0P8200P1oOgl208:2
PP80P8200P24Q8@208V9R@80S8b<0P2=SHd208^;R`80SHf=0P2CTi<209:BTP80T92@0P2HV9P2096A
T@80VIVI0P2GUiL209RHV080VIVI0P2JVYX209jNWP80WinO0P2RXZ820:JVYP030:VYZ@2UYJD0YJFU
0080[Jf]0P2XZ:P20:^[Z`80/k>c1P2^[Zh20;6a/@80/;2`0P2a/K420;2`/080/[:b0P2ZZZX20:RX
Z080Zj^[0P2][Jd60:RXZ080Y:BT0P2SXj<209nOW`80WIfM0P2KVi/209NGU`80V9RH0P2EUID209:B
TP80T92@0P2;Rh/00`2<S8`0Rh^;08^;R`0408V9R@@0Rh^;0P26QXH208B4Q080OWin0P21PH4207in
OP80OGem0P21PH4207alO080Ph>30P21PH4208B4Q2L0b>3H0P2IVIT209bLW080TY:B0P1`L70204Y:
BP80:2PX0P0/;2`202@T90808R8R0P0S8b<202@T90809BDU00<09bLW02XZ:P0Z:RX00P0];Bd204Q8
B080Ph>30P2FUYH207]kN`80IVIV0P1`L70207AdM080PH610P2WYjL20<K6aP80alO70P31`L420<K6
aP80b/[:0P3De=@20=OGe`80_kno0P1gMgL203Lg=`809RHV0P0L71`202HV9P80=3@d00<0=CDe0492
@P12@T800P0a<C4203Ph>080?Cdm0P0n?Sh204e=C@80DU9B0P1NGUh206ATI080K6a/0P1aLG4207Mg
M`80MWIf0P1kNg/207inOP80O7al101mOGd208B4Q080Ph>30P20P80208N7Q`80S8b<0P2:RXX00`2;
Rh/0S8b<08b<S00208f=S@80SXj>0P2CTi<209NGU`@0VYZJ102HV9P209VIV@80UiNG0P2KVi/209bL
W080XZ:R0P2UYJD40:RXZ0H0[:b/0P2c/k<20:n_[`80[Zj^0P2c/k<30;2`/080/[:b0P2`/;020;6a
/@@0Zj^[0P2ZZZX20:f][@80ZZZZ0P2][Jd20:^[Z`80YjNW0P2OWil20:6QX@@0WIfM0P2GUiL209JF
UP80U9BD0P2>SXh408b<S080RXZ:0P2;Rh/508V9R@80Shn?0P24Q8@20861P@80PX:2101nOWh207Yj
NP80N7Qh0P1mOGd207moO`80Ph>30P2:RXXN0<SPf0007038h=P209VIV@80Vi^K0P2DU9@2075aL@80
CDe=0P0W9bL202/[:`H092@T100W9bL00`0X:2P09RHV02HV9P0202/[:`80ATI60P25QHD209FEU@80
O7al0P1UIFD2079bLP80Lg=c0P20P8020:VYZ@80b/[:0P36a/H20<71`@80a<C40P39bLT20=KFeP80
emOG0P2n_[h207IfMP80<C4a0P0U9BD201lO7`8092@T0P0`<3000`0e=CD0@T920492@P02034a<@80
=CDe0P0j>SX20492@P80Bd];0P1EEED205mOG`80IFEU0P1[Jf/2075aL@80MgMg0P1iNGT207YjNP80
O7al0P1nOWh207moO`80P8200P22PX8408B4Q080QHF50P28R8P208^;R`0308b<S02=SHd0SHf=0080
SXj>0P2@T90209>CT`80UYJF102HV9P609VIV@80VYZJ0P2KVi/209bLW080XJ6Q0P2UYJD20:NWY`80
Z:RX0P2YZJT20:ZZZP80[Zj^0P2b/[820;2`/080[Jf]0P2_[jl30;:b/P80/K6a0P2`/;020:j^[P80
Zj^[0P2XZ:P20:ZZZP80[:b/0P2ZZZX20:RXZ080YjNW0P2UYJD20:>SX`80X:2P0P2NWYh209^KV`80
V9RH0P2EUID209>CT`80T92@0P2=SHd208Z:RP80RHV91028R8P208V9R@0308^;R`2=SHd0SHf=0080
R8R80P23Ph<40861P@80Ogmo0P1mOGd407alO080P8200P23Ph<208B4Q2L0b>3H0P2TY:@209ZJVP80
U9BD0P1`L70204U9B@80;Bd]0P0V9RH2024Q8@808R8R0P0U9BD202PX:08092@T0P0Z:RX202/[:`80
:RXZ00<0CDe=0820P020P8000P2GUiL207UiN@80I6AT0P1`L70207]kN`80OGem0P2][Jd20<c<c080
_;bl0P34a<@20<S8b080c<c<0P3@d=020=GEe@80b<S80P1eMGD203De=@80:BTY0P0R8R8202HV9P80
9bLW0P0o?cl204=3@`80<C4a0P0_;bl203Hf=P80?Cdm0P17AdL2055AD@80I6AT00<0J6QX06a/K01/
K6`00P1`L70207MgM`@0NGUi1P20P80207moO`80PX:20P20P80208B4Q080RHV90P2<S8`208f=S@80
Rh^;0P2=SHd209>CT`80TY:B0P2@T90209RHV080TI6A0P2IVIT209NGU`80V9RH0P2IVIT209ZJVP80
WYjN0P2OWil20::RXP80YZJV00<0ZJVY0:FUY@2UYJD00P2][Jd20:RXZ080Zj^[0P2c/k<60:j^[P80
/K6a0P2`/;020;6a/@80/;2`0P2b/[820:ZZZP80Z:RX0P2[Zj/20:f][@H0Z:RX0P2TY:@20:>SX`80
WinO0P2MWId209^KV`80UiNG0P2HV9P209FEU@80TY:B0P2@T90208^;R`0308b<S02;Rh/0Rh^;00@0
RHV9102;Rh/208J6QP80Q8B40P1nOWh20861P@80OWin0P1mOGd20861P@80O7al0P23Ph<20861P@80
Q8B49`38h=P209VIV@80W9bL0P2BTY82071`L080BTY:0P0X:2P202`/;08092@T0P0R8R8202<S8`80
92@T0P0U9BD00`0W9bL0:RXZ02XZ:P0202d];@80B4Q80P23Ph<209JFUP80Ng]k0P1VIVH2071`L080
M7Ad0P21PH420:NWY`80a/K60P37alL20<71`@80a/K60P3:b/X20=CDe080emOG0P2o_kl207MgM`80
=cLg0P0V9RH201`L70809RHV0P0d=3@00`0e=CD0@T920492@P02034a<@80>3Ph0P0m?Cd203hn?P80
CDe=0P1BDU8205iNGP80I6AT0P1/K6`2075aL@80MgMg0P1fMWH207]kN`80OWin0P1lO7`407emO@80
Q8B40P23Ph<20820P080QhN70P2<S8`208Z:RP0308^;R`2<S8`0S8b<0080SHf=0P2>SXh209>CT`80
UiNG102JVYX409RHV080VIVI0P2GUiL209^KV`80W9bL0P2RXZ820:FUY@@0Z:RX1P2/[:`20;>c/`80
[jn_0P2^[Zh20;>c/`<0/;2`0P2b/[820;2`/080/K6a102[Zj/20:ZZZP80[Jf]0P2ZZZX20:f][@80
Zj^[0P2WYjL209nOW`80XJ6Q102MWId209NGU`80UYJF0P2DU9@208j>SP@0S8b<0P2:RXX208^;R`D0
RHV90P2?Shl208B4Q080PH610P22PX8407inOP80NWYj0P1hN7P207emO@80Ogmo0P23Ph<208Z:RQh0
b>3H000L0<SPf080/;2`0P2EUID206YZJP80ATI6100Y:BT202`/;0809RHV100Q8B4202<S8`8092@T
00<09BDU02<S8`0S8b<00P0];Bd2030`<080MWIf0P27QhL209FEU@80IVIV0P1eMGD2075aL@80P820
0P25QHD20<[:bP80`l?30P2k^k/20<30`080b<S80P3>c/h20=7Ad@80c<c<0P2n_[h204=3@`80;Bd]
0P0O7al202DU9@80:RXZ00<0;Bd]04Y:BP1:BTX00P0X:2P2034a<@80>SXj0P11@D4204U9B@80EEEE
0P1PH60206IVIP80Jf][0P1cLg<207YjNP80Ng]k0P1jNWX407]kN`80OGem0P20P80208>3P`80QXJ6
0P24Q8@208>3P`80QhN70P2;Rh/308b<S080SXj>0P2@T90209>CT`80UYJF0P2HV9P609VIV@@0V9RH
0P2JVYX209fMW@80XZ:R0P2UYJD40:JVYP80YjNW0P2YZJT20:f][@80/K6a0P2`/;020:j^[P80/;2`
0P2b/[800`2c/k<0/[:b0;:b/P020;2`/080[jn_0P2[Zj/20:VYZ@80ZZZZ0P2/[:`20:^[Z`@0Z:RX
0P2WYjL20:BTY080X:2P0P2OWil209fMW@80VIVI102DU9@209>CT`80T92@0P2<S8`408Z:RP80Rh^;
0P2=SHd00`2<S8`0Rh^;08^;R`0208R8R080QHF50P23Ph<20861P@80OWin101lO7`207emO@80P820
0P23Ph<208B4Q2L0b>3H0P2/[:`209NGU`80K6a/0P14A4@202`/;080:2PX0P0[:b/202HV9P808B4Q
0P0V9RH2028R8P808b<S0P0P820402PX:00303<c<`1aLG40LG5a0080Shn?0P2>SXh206UYJ@80L71`
0P1dM7@207MgM`80Shn?0P37alL20;bl_080_Kfm0P34a<@20<O7a`80bl_;0P3?cll20=7Ad@80/k>c
0P14A4@202XZ:P808b<S0P0T92@202PX:080;bl_0P0n?Sh202l_;`80=3@d0P0l?3`204=3@`80Cdm?
0P1ADE4206=SH`0306QXJ01/K6`0K6a/0080L71`101jNWX607]kN`80OWin0P21PH4208>3P`80R8R8
1022PX8208J6QP80S8b<0P2:RXX208f=S@80Shn?0P2@T90209:BTP80V9RH0P2EUID209ZJVP80VIVI
0P2KVi/209JFUP80VIVI102MWId20:2PX0D0YJFU0P2][Jd20:NWY`80[Zj^0P2a/K420;2`/080[:b/
0P2a/K420;Fe]@80/K6a0P2b/[820:n_[`80[Jf]0P2[Zj/20:VYZ@80Zj^[0P2ZZZX20:b/[080ZZZZ
102WYjL20:FUY@@0XJ6Q0P2MWId209ZJVP80TY:B102CTi<208n?S`80S8b<00<0R8R808Z:RP2:RXX0
0P2:RXX2092@T080R8R80P2?Shl208R8R080QHF50P23Ph<20820P080PX:20P1kNg/207emO@80NGUi
1022PX8208>3PbL0b>3H0P2`/;0209BDU080JVYZ0P18B4P202TY:@80:RXZ0P0/;2`202HV9P80820P
0P0Q8B42028R8P809BDU00<092@T028R8P0R8R800P0/;2`2030`<080NGUi0P25QHD209:BTP80JFUY
0P1fMWH2071`L080PH610P26QXH20<c<c080`/;20P2k^k/20<C4a080a/K60P3>c/h20=;BdP80cLg=
0P2m_Kd20492@P80:BTY0P0P820202DU9@80:2PX00<0;Bd]04M7A`17AdL00P0Y:BT202l_;`80>SXj
0P12@T8204];B`80E5AD0P1QHF4206UYJ@80K6a/0P1bLW8207]kN`80O7al0P1jNWX207alO080NWYj
101nOWh208J6QP80RHV90P1nOWh208:2PP80R8R80P2<S8`00`29RHT0S8b<08b<S00208n?S`80T92@
0P2CTi<409FEU@80Vi^K1P2IVIT209RHV080WinO0P2MWId20:2PX080YjNW0P2UYJD20:JVYP80YJFU
0P2/[:`20:NWY`80][Jf102^[Zh20;>c/`80];Bd00<0/;2`0;>c/`2c/k<0102_[jl20:ZZZP80Z:RX
102/[:`20:RXZ080YjNW0P2TY:@20:FUY@80Z:RX0P2RXZ8209^KV`80WYjN0P2IVIT209>CT`80UiNG
0P2DU9@208f=S@80Rh^;0P2:RXX208V9R@@0S8b<00<0RXZ:08V9R@29RHT00P29RHT208N7Q`80Q8B4
1020P80207inOP80OGem0P1oOgl207emO@80PH610P2:RXXN0<SPf0007038h=P20;2`/080UIFE0P1Z
JVX204I6AP@0:BTY0P0/;2`202HV9P@08B4Q0P0S8b<202@T900302DU9@0S8b<08b<S0080;Bd]0P0`
<30207IfMP80QhN70P2EUID206IVIP80MGEe0P1aLG420820P080QHF50P3:b/X20<?3``80^k^k0P30
`<020<S8b080c/k>0P3AdM420<c<c080_[jn0P13@d<202d];@807alO0P0U9BD202XZ:P0302d];@1:
BTX0BTY:0080:2PX0P0a<C4203Xj>P80@D510P19BDT205EEE@80H61P0P1VIVH206][J`80Lg=c0P1j
NWX207]kN`80NWYj101kNg/207emO@80P8200P23Ph<208J6QP80Q8B40P23Ph<208N7Q`80Rh^;0`2<
S8`208j>SP80T92@0P2CTi<209JFUP80V9RH1P2IVIT409RHV080VYZJ0P2MWId20::RXP80YJFU102V
YZH20:NWY`80ZJVY0P2][Jd20;6a/@80/;2`0P2^[Zh20;2`/080/[:b00<0/k>c0;:b/P2b/[800P2`
/;020:n_[`80Zj^[0P2YZJT20:ZZZP80[:b/0P2[Zj/40:RXZ080YjNW0P2TY:@20:2PX080WinO0P2M
WId209VIV@@0U9BD0P2CTi<2092@T080S8b<102:RXX208^;R`80SHf=00<0S8b<08^;R`2;Rh/00P28
R8P208F5Q@80Ph>30P21PH4207inOP@0O7al0P1mOGd20820P080Ph>30P24Q8@W0<SPf080[:b/0P2G
UiL206a/K080A4A40P0/;2`202PX:080:b/[0P0V9RH2024Q8@809RHV0P0R8R8202<S8`80820P100X
:2P00`0c<c<0LG5a075aL@0208n?S`80SXj>0P1YJFT2071`L080M7Ad0P1gMgL208n?S`80alO70P2l
_;`20;fm_@80a<C40P37alL20<_;b`80clo?0P3AdM420;>c/`80A4A40P0Z:RX202<S8`8092@T0P0X
:2P202l_;`80?Shn0P0_;bl203@d=080?3`l0P13@d<204m?C`80DE5A0P1SHf<00`1XJ6P0K6a/06a/
K002071`L0@0NWYj1P1kNg/207inOP80PH610P23Ph<208R8R0@0PX:20P26QXH208b<S080RXZ:0P2=
SHd208n?S`80T92@0P2BTY8209RHV080UIFE0P2JVYX209VIV@80Vi^K0P2FUYH209VIV@@0WIfM0P2P
X:050:FUY@80[Jf]0P2WYjL20:j^[P80/K6a0P2`/;020:b/[080/K6a0P2e]KD20;6a/@80/[:b0P2_
[jl20:f][@80Zj^[0P2YZJT20:^[Z`80ZZZZ0P2/[:`20:ZZZP@0YjNW0P2UYJD40:6QX@80WIfM0P2J
VYX209:BTP@0Ti>C0P2?Shl208b<S00308R8R02:RXX0RXZ:0080RXZ:0P2@T90208R8R080Shn?0P28
R8P208F5Q@80Ph>30P20P80208:2PP80Ng]k0P1mOGd207UiN@@0PX:20P23Ph<W0<SPf080/;2`0P2D
U9@206YZJP80B4Q80P0Y:BT202XZ:P80;2`/0P0V9RH2020P80808B4Q0P0R8R8202DU9@0302@T900R
8R808R8R0080;2`/0P0`<30207UiN@80QHF50P2BTY8206UYJ@80MWIf0P1`L7020861P@80QXJ60P3<
c<`20<;2`P80^k^k0P34a<@20<K6aP80c/k>0P3Bd]820<g=c@80_Kfm0P12@T8202TY:@80820P0P0U
9BD202PX:00302d];@17AdL0AdM70080:BTY0P0_;bl203Xj>P80@T920P1;Bd/205ADE080HF5Q0P1Y
JFT206a/K080LW9b0P1kNg/207alO080NWYj0P1lO7`207YjNP@0OWin0P26QXH208V9R@80OWin0P22
PX8208R8R080S8b<00<0RHV908b<S02<S8`00P2?Shl2092@T080Ti>C102EUID209^KV`H0VIVI0P2H
V9P209nOW`80WIfM0P2PX:020:NWY`80YJFU0P2VYZH20:FUY@80[:b/0P2WYjL20;Jf]P@0[Zj^0P2c
/k<20;Bd]0030;2`/02c/k<0/k>c00@0[jn_0P2ZZZX20:RXZ0@0[:b/0P2XZ:P20:NWY`80Y:BT0P2U
YJD20:RXZ080XZ:R0P2KVi/209jNWP80VIVI0P2CTi<209NGU`80U9BD0P2=SHd208^;R`80RXZ:0P29
RHT408b<S00308Z:RP29RHT0RHV90080RHV90P27QhL208B4Q0@0P8200P1nOWh207emO@80Ogmo0P1m
OGd20861P@80RXZ:7P38h=P001`0b>3H0P2JVYX207MgM`80AdM70P0_;bl2024Q8@809RHV0P0Y:BT2
02HV9P808B4Q0P0R8R8402<S8`0302@T900Q8B408B4Q00809BDU0P0Z:RX205QHF080O7al0P2NWYh2
07UiN@80LG5a0P1`L70207YjNP80MGEe0P2g]kL20<W9b@80]kNg0P2n_[h20<C4a080b<S80P39bLT2
0<c<c080`L710P2OWil203Ph>0807QhN0P0Y:BT202`/;003030`<00o?cl0?clo0080;Bd]0P0b<S82
03Lg=`80@4100P1:BTX205MGE`80Hf=S0P1YJFT206e]K@80MGEe0P1jNWX207UiN@80MgMg0P1iNGT2
07alO080Ogmo0P22PX8208F5Q@80QhN70P25QHD208B4Q080QXJ60P29RHT00`2<S8`0Shn?08n?S`04
092@T080TI6A0P2CTi<209BDU080UYJF0P2HV9P209VIV@@0VYZJ0P2LW9`209nOW`80XZ:R0P2UYJD2
0:NWY`80Z:RX0P2ZZZX20:f][@80/;2`0P2c/k<20;6a/@80[jn_0P2`/;020;6a/@030;>c/`2d];@0
];Bd0080/[:b0P2_[jl20:b/[080Zj^[0P2][Jd20:n_[`80[Jf]0P2YZJT20:RXZ080YZJV0P2TY:@2
0:6QX@80X:2P0P2NWYh209ZJVP80UIFE0P2BTY8408n?S`80SXj>0P2<S8`208^;R`80SXj>0P2@T900
0`2>SXh0RXZ:08Z:RP0208V9R@80QhN70P24Q8@20861P@80OWin0P1lO7`207emO@80Ogmo0P22PX82
08>3P`80Q8B49`38h=P2092@T080NWYj0P15ADD202XZ:P808R8R0P0[:b/202l_;`80:BTY0P0R8R82
024Q8@808R8R0P0Y:BT202HV9P808R8R0P0T92@00`0Z:RX0De=C05=CD`0208F5Q@80WinO0P1hN7P2
07=cL`80M7Ad0P1gMgL207]kN`80][Jf0P35aLD20;Rh^080_Kfm0P34a<@20<G5a@80bLW90P3@d=02
0<c<c080UiNG0P0b<S8602TY:@80=CDe0P13@d<202`/;080<30`0P0l?3`203dm?@80Bd];0P1EEED2
05mOG`0306EUI@1^KVh0KVi^0080M7Ad0P1oOgl207UiN@80MWIf0P1hN7P207UiN@80Ogmo0P23Ph<2
08:2PP80S8b<1024Q8@208F5Q@@0RHV9102?Shl2096AT@80SXj>0P2EUID209JFUP80V9RH0P2IVIT2
09bLW080TY:B102KVi/209ZJVP80XZ:R0P2WYjL00`2SXj<0YjNW0:NWY`020:VYZ@80ZZZZ0P2b/[82
0:n_[`80/k>c0P2_[jl20;6a/@80[jn_0P2a/K420;Rh^080/K6a102^[Zh20:VYZ@80Zj^[0P2`/;02
0:j^[P80YJFU0P2VYZH20:FUY@80Y:BT0P2NWYh209fMW@80Vi^K0P2OWil409:BTP80S8b<0P2>SXh2
08n?S`0308V9R@2;Rh/0Rh^;0080S8b<0P2ATI4208^;R`80RXZ:1029RHT208B4Q080PH610P1lO7`2
07IfMP80Q8B40P1oOgl20820P080Ph>30P28R8PW0<SPf080W9bL0P1fMWH204Y:BP80;2`/0P0S8b<2
02HV9P80:2PX0P0W9bL202HV9P808B4Q0P0V9RH202LW9`0302HV9P0O7al07alO00809BDU0P0X:2P2
05IFEP80Ng]k0P2PX:0207emO@80KVi^0P1`L70207UiN@80M7Ad0P2h^;P20<S8b080][Jf0P2l_;`2
0<K6aP80a<C40P39bLT20<g=c@80_Kfm0P2RXZ8203Xj>P808B4Q0P0U9BD202/[:`03038b<P0o?cl0
?clo0080;Rh^0P0`<30203Lg=`80@D510P18B4P205EEE@@0IFEU0P1[Jf/207=cL`80Ng]k0P1hN7P2
07IfMP80NWYj0P1nOWh20820P0@0QXJ60P27QhL208J6QP80R8R80P26QXH208R8R00308f=S@2ATI40
TI6A0080U9BD0P2@T90209BDU080UIFE0P2CTi<209FEU@80UiNG0P2MWId209JFUP80Vi^K102MWId2
0::RXP80Xj>S0P2VYZH20:^[Z`80ZJVY0P2_[jl20:b/[080/k>c0P2b/[820:b/[080[Jf]0P2`/;00
0`2f][H0]KFe0;Fe]@020:j^[P80/;2`0P2/[:`20:ZZZP80[Jf]0P2^[Zh20:b/[0@0ZZZZ0P2WYjL2
0:2PX080XJ6Q0P2NWYh20:2PX080W9bL0P2CTi<4092@T080SXj>0P2BTY8208j>SP@0RXZ:0P2DU9@0
0`2@T900SXj>08j>SP0208V9R@@0Q8B40P21PH4208:2PP80O7al0P1mOGd207moO`80PH611022PX8N
0<SPf0007038h=P209ZJVP80MgMg0P17AdL202l_;`808B4Q0P0V9RH202TY:@809RHV0P0Q8B42028R
8P@08b<S00<092@T024Q8@0Q8B400P0U9BD202XZ:P80F5QH0P1lO7`209jNWP80NGUi0P1aLG42071`
L080NWYj0P1eMGD20;Ng]`80bLW90P2g]kL20;jn_P80a<C40P38b<P20<W9b@80c<c<0P31`L4209nO
W`80>3Ph0P0N7Qh202TY:@80;2`/00<0<30`03lo?`0o?cl00P0];Bd2038b<P80=cLg0P10@40204Y:
BP80EeMG0P1SHf<206UYJ@80KFe]0P1eMGD207YjNP80NGUi0P1gMgL207UiN@80O7al0P1oOgl208:2
PP80QHF50P27QhL208F5Q@80Q8B40P26QXH208V9R@0308b<S02?Shl0Shn?00@0T92@0P2ATI4209>C
T`80U9BD0P2FUYH209RHV080VIVI102JVYX209bLW080WinO0P2RXZ820:FUY@80YjNW0P2XZ:P20:ZZ
ZP80[Jf]0P2`/;020;>c/`80/K6a0P2_[jl20;2`/080/K6a00<0/k>c0;Bd]02d];@00P2b/[820:n_
[`80[:b/0P2[Zj/20:f][@80[jn_0P2][Jd20:VYZ@80Z:RX0P2VYZH20:BTY080XJ6Q0P2PX:0209jN
WP80VYZJ0P2EUID209:BTP@0Shn?0P2>SXh208b<S080Rh^;0P2>SXh2092@T00308j>SP2:RXX0RXZ:
0080RHV90P27QhL208B4Q080PH610P1nOWh207alO080OGem0P1oOgl208:2PP80Ph>30P24Q8@W0<SP
f080T92@0P1jNWX204E5A@80:RXZ0P0R8R8202/[:`80;bl_0P0Y:BT2028R8P808B4Q0P0R8R8202TY
:@809RHV0P0R8R8202@T900302XZ:P1CDe<0De=C0080QHF50P2OWil207QhN080Lg=c0P1dM7@207Mg
M`80Ng]k0P2f][H20<G5a@80^;Rh0P2m_Kd20<C4a080aLG50P39bLT20=3@d080c<c<0P2GUiL2038b
<PH0:BTY0P0e=CD204=3@`80;2`/0P0`<30203`l?080?Cdm0P1;Bd/205EEE@80GemO00<0IFEU06i^
KP1^KVh00P1dM7@207moO`80NGUi0P1fMWH207QhN080NGUi0P1oOgl208>3P`80PX:20P2<S8`408B4
Q080QHF51029RHT408n?S`80TI6A0P2>SXh209FEU@80UYJF0P2HV9P209VIV@80W9bL0P2BTY8409^K
V`80VYZJ0P2RXZ820:NWY`030:>SX`2WYjL0YjNW0080ZJVY0P2ZZZX20;:b/P80[jn_0P2c/k<20:n_
[`80/K6a0P2_[jl20;6a/@80^;Rh0P2a/K440:j^[P80ZJVY0P2[Zj/20;2`/080[Zj^0P2UYJD20:JV
YP80YJFU0P2TY:@209jNWP80WIfM0P2KVi/209nOW`@0TY:B0P2<S8`208j>SP80Shn?00<0RHV908^;
R`2;Rh/00P2<S8`2096AT@80Rh^;0P2:RXX408V9R@80Q8B40P21PH4207alO080MWIf0P24Q8@207mo
O`80P8200P23Ph<208R8R2L0b>3H0P2LW9`207IfMP80BTY:0P0/;2`202<S8`809RHV0P0X:2P202LW
9`809RHV0P0Q8B4202HV9P809bLW00<09RHV01lO7`0O7al00P0U9BD202PX:080EUIF0P1kNg/20:2P
X080OGem0P1^KVh2071`L080NGUi0P1dM7@20;Rh^080b<S80P2f][H20;bl_080a/K60P34a<@20<W9
b@80cLg=0P2m_Kd20::RXP80>SXj0P0Q8B4202DU9@80:b/[00<0<S8b03lo?`0o?cl00P0^;Rh2030`
<080=cLg0P11@D4204Q8B080EEEE101UIFD206][J`80Lg=c0P1kNg/207QhN080MWIf0P1jNWX207in
OP80P8201026QXH208N7Q`80QXJ60P28R8P208J6QP80R8R800<0SHf=096AT@2ATI400P2DU9@2092@
T080U9BD0P2EUID209>CT`80UIFE0P2GUiL209fMW@80UYJF0P2KVi/409fMW@80XZ:R0P2SXj<20:JV
YP80Zj^[0P2YZJT20:n_[`80[:b/0P2c/k<20;:b/P80[:b/0P2][Jd20;2`/0030;Jf]P2e]KD0]KFe
0080[Zj^0P2`/;020:b/[080ZZZZ0P2][Jd20:j^[P80[:b/102ZZZX20:NWY`80X:2P0P2QXJ4209jN
WP80X:2P0P2LW9`209>CT`@0T92@0P2>SXh209:BTP80SXj>102:RXX209BDU003092@T02>SXh0SXj>
0080RHV91024Q8@20861P@80PX:20P1lO7`207emO@80Ogmo0P21PH4408:2PQh0b>3H000L0<SPf080
MWIf0P1EEED202/[:`@08R8R0P0T92@202HV9P809BDU1P0S8b<302@T9080820P0P0O7al202PX:080
>CTi0P1_Kfl209bLW080SHf=0P1`L70206m_K`80MGEe0P1/K6`209jNWP80bl_;0P2g]kL20;jn_PH0
`<300P3?cll20=7Ad@80];Bd0P1[Jf/203De=@@0:b/[00<0=3@d038b<P0b<S80100c<c<203De=@80
?clo0P1;Bd/205QHF080I6AT0P1[Jf/2071`L080MWIf0P1iNGT207MgM`80MGEe0P1iNGT207inOP80
PH610P24Q8@208J6QP80QhN70P26QXH408F5Q@80QXJ600<0S8b<096AT@2ATI400P2ATI46092@T080
TY:B0P2DU9@209NGU`80VYZJ0P2LW9`209fMW@80WinO0P2RXZ820:BTY080YZJV0P2XZ:P20:ZZZP80
[Zj^0P2a/K420;>c/`80];Bd0P2b/[860;6a/@030;Bd]02f][H0][Jf0080/k>c0P2_[jl40:f][@80
/;2`0P2b/[820:j^[P80ZJVY0P2XZ:P20:NWY`80Y:BT0P2RXZ820:2PX080WYjN0P2KVi/209NGU`80
TI6A0P2<S8`208j>SP80T92@0P2>SXh208b<S080T92@0P2CTi<00`2@T900Rh^;08^;R`0208V9R@80
QhN70P25QHD208:2PP80OWin0P1lO7`207inOP80PH610P23Ph<408B4Q2L0b>3H0P1gMgL205QHF080
;Bd]0P0U9BD202<S8`80820P0P0S8b<2028R8P809BDU0P0T92@202<S8`@08R8R0P0O7al2024Q8@03
02DU9@0i>CT0>CTi0080LW9b0P2JVYX208^;R`80Lg=c0P1bLW82071`L080M7Ad0P2KVi/20<K6aP80
^KVi0P2k^k/20;no_`80a<C40P33`l<20<G5a@80c<c<0P32`/8206YZJP80<S8b0P0`<30202XZ:P80
;Bd]0P0j>SX202d];@80=cLg0P0d=3@203`l?080CDe=0P1IFET206EUI@0306a/K01aLG40LG5a0080
MGEe0P1jNWX207QhN080MWIf0P1hN7P207inOP80Ph>30P26QXH208B4Q080QhN70P22PX8408F5Q@80
QhN70P2<S8`2092@T080U9BD0P2BTY8208j>SP80TY:B0P2ATI4209BDU080UIFE0P2LW9`209fMW@80
Vi^K1P2RXZ820:RXZ0030:JVYP2/[:`0[:b/0080[jn_0P2`/;020;6a/@80/;2`0P2h^;P20:j^[P80
/[:b0P2d];@20;Fe]@80]kNg0P2`/;060:n_[`80Zj^[0P2b/[820:f][@80ZJVY0P2XZ:P20:JVYP80
YjNW102RXZ820:2PX080VYZJ0P2FUYH209FEU@80Rh^;0P2?Shl2096AT@0308b<S02=SHd0SHf=0080
U9BD0P2CTi<208j>SP80RXZ:0P2;Rh/208F5Q@80QXJ60P21PH4207moO`80OWin0P1mOGd208>3P`80
P8200P26QXH208:2PRL0b>3H0P1eMGD205IFEP80:b/[0P0S8b<202@T90808R8R0P0W9bL202DU9@80
8b<S0P0O7al202DU9@<092@T0P0O7al201hN7P80:2PX0P0k>c/206a/K080WIfM0P2=SHd2071`L080
K6a/0P1eMGD206e]K@80WinO0P3;bl/20;Rh^080_kno0P31`L420;fm_@80`<300P3Cdm<20=7Ad@80
/k>c0P1[Jf/203@d=080;bl_0P0X:2P00`0f=SH0<S8b038b<P02034a<@80=3@d0P0c<c<20451@@80
C4a<0P1IFET206IVIP80JVYZ0P1aLG4207MgM`@0NGUi0P1fMWH207YjNP80Ogmo0P20P80208:2PP80
R8R80P2:RXX608B4Q080RHV900<0RXZ:092@T02@T9000P2CTi<2092@T080S8b<0P2@T90209:BTP80
U9BD0P2GUiL209^KV`80WIfM102NWYh20:>SX`@0YJFU0P2YZJT20:^[Z`80[Jf]102a/K420;:b/P80
];Bd0P2b/[820;2`/080/K6a00<0][Jf0;Fe]@2e]KD00P2a/K440:n_[`80[Zj^0P2_[jl20;Fe]@80
[:b/0P2ZZZX20:VYZ@80YZJV102UYJD209nOW`80WYjN0P2LW9`209FEU@80TY:B0P2>SXh208Z:RP80
TI6A0P2=SHd208j>SP80T92@0P2CTi<00`2<S8`0RXZ:08Z:RP0208V9R@80QXJ60P29RHT208:2PP80
NWYj0P1mOGd207inOP80Ogmo0P23Ph<208J6QP80QHF57P38h=P001`0b>3H0P1fMWH205EEE@80:b/[
100R8R8202@T90809RHV0P0U9BD602<S8`<092@T0P0P820201lO7`80:2PX0P0i>CT206m_K`80W9bL
0P2=SHd2071`L080Kfm_0P1eMGD206a/K080WYjN0P3;bl/20;Ng]`80_[jn1P30`<020<o?c`80dM7A
0P2d];@206][J`80=CDe100[:b/00`0d=3@0<S8b038b<P0403<c<`80=CDe0P0o?cl204];B`80F5QH
0P1TI6@206][J`80L71`0P1fMWH207UiN@80MgMg0P1eMGD207UiN@80OWin0P21PH4208B4Q080QXJ6
0P27QhL208J6QP@0QHF50P26QXH00`2<S8`0TI6A096AT@02096AT@H0T92@0P2BTY8209BDU080UiNG
0P2JVYX209bLW080WIfM0P2OWil20::RXP80Y:BT0P2VYZH20:RXZ080ZZZZ0P2^[Zh20;6a/@80/k>c
0P2d];@20;:b/PH0/K6a00<0];Bd0;Jf]P2f][H00P2c/k<20:n_[`@0[Jf]0P2`/;020;:b/P80[Zj^
0P2YZJT20:RXZ080YjNW0P2TY:@20::RXP80X:2P0P2NWYh209^KV`80UiNG0P2ATI4208b<S080SXj>
0P2@T90208j>SP80S8b<0P2@T90209>CT`03092@T02;Rh/0Rh^;0080RHV90P27QhL208F5Q@80PX:2
0P1nOWh207alO080OWin0P21PH4208>3P`@0Q8B49`38h=P207MgM`80F5QH0P0];Bd202DU9@808b<S
0P0P820202<S8`808R8R0P0U9BD202@T90808b<S100R8R8201lO7`808B4Q00<09BDU03Ti>@0i>CT0
0P1bLW8209ZJVP80Rh^;0P1cLg<2079bLP80L71`0P1dM7@209^KV`80a/K60P2i^KT20;^k^`80_kno
0P34a<@20<?3``80aLG50P3<c<`20<;2`P80JVYZ0P0b<S82030`<080:RXZ0P0];Bd203Xj>P80;Bd]
0P0g=cL203@d=080?3`l0P1=CDd205UIF@80IFEU00<0K6a/075aL@1aLG400P1eMGD207YjNP80N7Qh
0P1fMWH207QhN080OWin0P23Ph<208J6QP80Q8B40P27QhL208:2PP@0QHF50P27QhL208b<S080T92@
0P2DU9@209:BTP80SXj>0P2BTY82096AT@80U9BD0P2EUID209bLW080WIfM0P2KVi/60::RXP80Z:RX
00<0YZJV0:b/[02/[:`00P2_[jl20;2`/080/K6a0P2`/;020;Rh^080[Zj^0P2b/[820;Bd]080]KFe
0P2g]kL20;2`/0H0[jn_0P2[Zj/20;:b/P80[Jf]0P2YZJT20:RXZ080YZJV0P2WYjL40::RXP80X:2P
0P2JVYX209JFUP80UIFE0P2;Rh/208n?S`80TI6A00<0S8b<08f=S@2=SHd00P2DU9@209>CT`80SXj>
0P2:RXX208^;R`80QHF50P26QXH20861P@80Ogmo0P1nOWh207emO@80Ph>30P20P80208J6QP80PX:2
9`38h=P207EeM@80EUIF0P0[:b/202<S8`8092@T0P0R8R8202LW9`809BDU0P0S8b<201lO7`809BDU
0`0T92@201lO7`807QhN0P0X:2P203/k>`80K6a/0P2MWId208f=S@80L71`0P1/K6`207EeM@80KFe]
0P2OWil20<_;b`80^;Rh0P2o_kl20<71`@80_Kfm0P30`<020=?Cd`80dM7A0P2c/k<206][J`80=3@d
0P0_;bl202PX:00303Hf=P0b<S80<S8b0080<C4a0P0d=3@203<c<`80@D510P1<C4`205UIF@80IVIV
0P1ZJVX2075aL@80MgMg101iNGT207IfMP80NWYj0P1oOgl20820P080PX:20P28R8P208Z:RPH0Q8B4
0P29RHT00`2:RXX0T92@092@T00209>CT`80T92@0P2<S8`2092@T080TY:B0P2DU9@209NGU`80Vi^K
0P2MWId409jNWP80Xj>S102UYJD20:VYZ@80Zj^[0P2][Jd40;6a/@80/[:b0P2d];@20;:b/P80/;2`
0P2a/K400`2f][H0]KFe0;Fe]@020;6a/@@0[jn_0P2^[Zh20:n_[`80]KFe0P2/[:`20:ZZZP80ZJVY
0P2VYZH40:FUY@80WinO0P2NWYh209bLW080UIFE0P2BTY8208j>SP80RXZ:0P2ATI4208f=S@80SXj>
0P2@T90209>CT`0308b<S02:RXX0RXZ:0080RHV90P26QXH208V9R@80PX:20P1jNWX207emO@80OWin
0P1oOgl208>3P`80QXJ60P25QHDN0<SPf0007038h=P205ADE080@d=30P0X:2P402@T90809BDU0P0X
:2P202HV9P8092@T0P0V9RH402LW9`0302HV9P0S8b<08b<S00@0820P0P0W9bL205]KF`80SHf=0P2A
TI4208B4Q080Jf][0P1gMgL206e]K@80R8R80P2j^[X20<?3``80`L710P2l_;`20;jn_P80`<301035
aLD20<g=c@80[Zj^0P0k>c/203De=@80:b/[00<0;Bd]02/[:`0[:b/00P0`<302034a<@80=SHf0P11
@D4204i>CP80F5QH0P1RHV8206][J`80LW9b0P1eMGD407MgM`80N7Qh0P1lO7`20820P080PH610P22
PX8208>3P`80Q8B41P25QHD208J6QP0308Z:RP2>SXh0SXj>0080TI6A102CTi<209:BTP80Ti>C0P2E
UID209NGU`80Vi^K0P2NWYh20:6QX@80Xj>S0P2VYZH20:NWY`80ZJVY0P2[Zj/20:f][@80[jn_0P2a
/K420;:b/P@0/k>c0P2b/[820;Fe]@<0]kNg0P2e]KD20;:b/P80[Zj^0P2/[:`20:^[Z`80[Jf]0P2_
[jl20:b/[080ZJVY102ZZZX20:JVYP80XJ6Q0P2OWil209jNWP80W9bL0P2IVIT209FEU@@0TI6A0P2B
TY82092@T080Shn?0P2BTY8209>CT`03092@T02<S8`0S8b<0080RXZ:0P28R8P208N7Q`80Q8B40P20
P80207alO080Ogmo0P22PX8208B4Q0@0QHF59`38h=P205UIF@80?Shn0P0W9bL202DU9@8092@T0P0W
9bL202`/;0809bLW0P0S8b<2028R8P809RHV0P0b<S8202DU9@@08R8R00<07alO02TY:@0Y:BT00P1K
Fe/208V9R@80U9BD0P1fMWH406m_K`80Lg=c0P24Q8@20<30`080alO70P2k^k/20;fm_@80a/K6102m
_Kd20<?3``80c/k>0P2/[:`203Xj>P80;bl_0P0[:b/202d];@80=CDe0P0^;Rh2038b<P80=SHf0P10
@40204m?C`80FEUI0P1UIFD00`1/K6`0LW9b079bLP02075aL@@0MGEe101kNg/208:2PP80Ph>30P1n
OWh208:2PP80RHV90P25QHD208R8R080QXJ60P24Q8@208^;R`80Shn?0P2ATI42092@T080Ti>C102@
T90209FEU@80UiNG0P2HV9P209fMW@80XZ:R0P2WYjL20:VYZ@80YJFU0P2XZ:P00`2[Zj/0[:b/0:b/
[0020;2`/080/[:b0P2d];@20;Jf]P80/k>c0P2`/;020:n_[`80];Bd0P2g]kL20;>c/`80[Jf]0P2_
[jl20:j^[P80ZJVY0P2_[jl20;2`/080[jn_0P2[Zj/20:f][@80ZJVY0P2RXZ820:>SX`80WYjN102K
Vi/209NGU`80UYJF0P2ATI4208n?S`80Ti>C00<0T92@08f=S@2=SHd00P2BTY8209BDU080S8b<0P2A
TI4408R8R0@0QXJ60P1nOWh207moO`80O7al0P22PX8208B4Q0@0QHF59`38h=P205EEE@80@T920P0Z
:RX2020P80808R8R0P0S8b<202LW9`809BDU0P0R8R8202@T90809bLW0P0Q8B400`0V9RH092@T02@T
900202<S8`807alO0P0Y:BT205UIF@80SHf=0P2@T90208N7Q`80KVi^0P1hN7P2071`L080Ph>30P2k
^k/20<K6aP80_kno0P2l_;`20<30`080_kno0P37alL20<G5a@80bLW90P2_[jl203`l?080=cLg0P0Z
:RX00`0/;2`0<30`030`<002034a<@80<30`0P0e=CD20492@P80Cdm?0P1BDU8206=SH`80J6QX0P1e
MGD407MgM`80M7Ad0P1hN7P207YjNP80P8200P1mOGd20861P@80QXJ60P20P80208B4Q080QXJ60P23
Ph<208J6QP0308V9R@2=SHd0SHf=0080T92@0P2EUID209>CT`80TI6A102EUID209JFUP80V9RH0P2K
Vi/20:2PX080Xj>S0P2VYZH20:VYZ@80Zj^[0P2WYjL20:b/[080[Zj^0P2a/K420;Fe]@80][Jf0P2d
];@20:n_[`80][Jf0P2h^;P00`2g]kL0][Jf0;Jf]P020;:b/P80[Jf]0P2_[jl20:^[Z`80YjNW0P2`
/;020:^[Z`80Z:RX102ZZZX20:FUY@@0WinO102LW9`209fMW@80UIFE0P2BTY8208f=S@@0TY:B0P2@
T90208j>SP80UYJF00<0T92@08f=S@2=SHd01028R8P208N7Q`80Ph>30P1oOgl207emO@80P8200P26
QXH208N7Q`80QHF50P20P80N0<SPf0007038h=P205ADE080@d=30P0X:2P402@T90809BDU0P0X:2P2
02HV9P8092@T0P0V9RH402LW9`0302HV9P0S8b<08b<S00@0820P0P0W9bL205]KF`80SHf=0P2ATI42
08B4Q080Jf][0P1gMgL206e]K@80R8R80P2j^[X20<?3``80`L710P2l_;`20;jn_P80`<301035aLD2
0<g=c@80[Zj^0P0k>c/203De=@80:b/[00<0;Bd]02/[:`0[:b/00P0`<302034a<@80=SHf0P11@D42
04i>CP80F5QH0P1RHV8206][J`80LW9b0P1eMGD407MgM`80N7Qh0P1lO7`20820P080PH610P22PX82
08>3P`80Q8B41P25QHD208J6QP0308Z:RP2>SXh0SXj>0080TI6A102CTi<209:BTP80Ti>C0P2EUID2
09NGU`80Vi^K0P2NWYh20:6QX@80Xj>S0P2VYZH20:NWY`80ZJVY0P2[Zj/20:f][@80[jn_0P2a/K42
0;:b/P@0/k>c0P2b/[820;Fe]@<0]kNg0P2e]KD20;:b/P80[Zj^0P2/[:`20:^[Z`80[Jf]0P2_[jl2
0:b/[080ZJVY102ZZZX20:JVYP80XJ6Q0P2OWil209jNWP80W9bL0P2IVIT209FEU@@0TI6A0P2BTY82
092@T080Shn?0P2BTY8209>CT`03092@T02<S8`0S8b<0080RXZ:0P28R8P208N7Q`80Q8B40P20P802
07alO080Ogmo0P22PX8208B4Q0@0QHF59`38h=P205UIF@80?Shn0P0W9bL202DU9@8092@T0P0W9bL2
02`/;0809bLW0P0S8b<2028R8P809RHV0P0b<S8202DU9@@08R8R00<07alO02TY:@0Y:BT00P1KFe/2
08V9R@80U9BD0P1fMWH406m_K`80Lg=c0P24Q8@20<30`080alO70P2k^k/20;fm_@80a/K6102m_Kd2
0<?3``80c/k>0P2/[:`203Xj>P80;bl_0P0[:b/202d];@80=CDe0P0^;Rh2038b<P80=SHf0P10@402
04m?C`80FEUI0P1UIFD00`1/K6`0LW9b079bLP02075aL@@0MGEe101kNg/208:2PP80Ph>30P1nOWh2
08:2PP80RHV90P25QHD208R8R080QXJ60P24Q8@208^;R`80Shn?0P2ATI42092@T080Ti>C102@T902
09FEU@80UiNG0P2HV9P209fMW@80XZ:R0P2WYjL20:VYZ@80YJFU0P2XZ:P00`2[Zj/0[:b/0:b/[002
0;2`/080/[:b0P2d];@20;Jf]P80/k>c0P2`/;020:n_[`80];Bd0P2g]kL20;>c/`80[Jf]0P2_[jl2
0:j^[P80ZJVY0P2_[jl20;2`/080[jn_0P2[Zj/20:f][@80ZJVY0P2RXZ820:>SX`80WYjN102KVi/2
09NGU`80UYJF0P2ATI4208n?S`80Ti>C00<0T92@08f=S@2=SHd00P2BTY8209BDU080S8b<0P2ATI44
08R8R0@0QXJ60P1nOWh207moO`80O7al0P22PX8208B4Q0@0QHF59`38h=P205EEE@80@T920P0Z:RX2
020P80808R8R0P0S8b<202LW9`809BDU0P0R8R8202@T90809bLW0P0Q8B400`0V9RH092@T02@T9002
02<S8`807alO0P0Y:BT205UIF@80SHf=0P2@T90208N7Q`80KVi^0P1hN7P2071`L080Ph>30P2k^k/2
0<K6aP80_kno0P2l_;`20<30`080_kno0P37alL20<G5a@80bLW90P2_[jl203`l?080=cLg0P0Z:RX0
0`0/;2`0<30`030`<002034a<@80<30`0P0e=CD20492@P80Cdm?0P1BDU8206=SH`80J6QX0P1eMGD4
07MgM`80M7Ad0P1hN7P207YjNP80P8200P1mOGd20861P@80QXJ60P20P80208B4Q080QXJ60P23Ph<2
08J6QP0308V9R@2=SHd0SHf=0080T92@0P2EUID209>CT`80TI6A102EUID209JFUP80V9RH0P2KVi/2
0:2PX080Xj>S0P2VYZH20:VYZ@80Zj^[0P2WYjL20:b/[080[Zj^0P2a/K420;Fe]@80][Jf0P2d];@2
0:n_[`80][Jf0P2h^;P00`2g]kL0][Jf0;Jf]P020;:b/P80[Jf]0P2_[jl20:^[Z`80YjNW0P2`/;02
0:^[Z`80Z:RX102ZZZX20:FUY@@0WinO102LW9`209fMW@80UIFE0P2BTY8208f=S@@0TY:B0P2@T902
08j>SP80UYJF00<0T92@08f=S@2=SHd01028R8P208N7Q`80Ph>30P1oOgl207emO@80P8200P26QXH2
08N7Q`80QHF50P20P80N0<SPf0007038h=P203`l?080>3Ph0P0^;Rh202LW9`808b<S0P0V9RH202XZ
:P80:2PX0P0W9bL202TY:@@0:b/[00<0:BTY02LW9`0W9bL00P0T92@201/K6`807AdM0P17AdL207If
MP80SHf=0P2IVIT206][J`80NWYj0P1bLW8207IfMP80XZ:R0P3;bl/20<G5a@80^KVi0P2m_Kd20<;2
`P80_[jn0P2i^KT20<_;b`80c<c<0P2>SXh202h^;P809RHV00<0:2PX02TY:@0Y:BT00P0[:b/2030`
<080=SHf0P12@T8204m?C`80F5QH0P1PH60206YZJP80Lg=c101eMGD207QhN080NWYj0P1nOWh40861
P@80Ogmo0P20P8020861P@80Ph>31P26QXH00`28R8P0Rh^;08^;R`02096AT@@0UYJF0P2DU9@209FE
U@80UiNG0P2IVIT209bLW080X:2P0P2TY:@20:NWY`80ZZZZ0P2[Zj/20:b/[080[Zj^0P2_[jl20;2`
/080/K6a1P2b/[820;Bd]080^KVi0P2m_Kd00`2i^KT0];Bd0;Bd]0020;6a/@80[Zj^0P2[Zj/20:ZZ
ZP80Zj^[0P2/[:`20:^[Z`80ZZZZ0P2/[:`20:f][@80YjNW0P2QXJ4209nOW`80WIfM0P2LW9`209^K
V`80VIVI0P2GUiL209FEU@80Ti>C102BTY8409>CT`03092@T02=SHd0SHf=0080Rh^;0P29RHT208R8
R080QXJ60P22PX8207inOP80Ogmo0P22PX8208B4Q080QHF50P26QXHW0<SPf080@d=30P0a<C4203<c
<`80;2`/0P0X:2P202LW9`80:BTY0P0Z:RX202TY:@809BDU0P0X:2P2034a<@809BDU0P0Z:RX2020P
800301dM7@0R8R808R8R0080>SXj0P1fMWH209BDU080Ti>C0P1`L70207AdM080N7Qh0P1eMGD209nO
W`80c<c<0P2n_[h20;Vi^@80`/;20P30`<020;bl_080^k^k103:b/X2092@T080=CDe0P0S8b<202DU
9@80;2`/0P0[:b/202h^;P80=cLg0P15ADD204e=C@80FEUI0P1QHF400`1WIfL0MGEe07EeM@0207=c
L`80NGUi0P1eMGD207alO080OGem0P1nOWh208>3P`80PX:20P1jNWX208B4Q080PH610P26QXH208B4
Q080QHF50P29RHT208R8R080TY:B102FUYH209FEU@80Ti>C0P2GUiL209ZJVP@0WYjN0P2UYJD20:NW
Y`80Z:RX0P2ZZZX20:f][@030:b/[02b/[80/[:b0080[Jf]0P2a/K420;2`/080/K6a102d];@20;Ng
]`80_[jn0P2i^KT20;Fe]@80[jn_0P2][Jd20:j^[P80Z:RX102[Zj/20:VYZ@80Zj^[0P2XZ:P20:n_
[`80Z:RX0P2QXJ4209nOW`80X:2P0P2JVYX209^KV`80W9bL0P2HV9P409>CT`0309JFUP2@T900T92@
0080UIFE0P2BTY8208b<S080SHf=0P2<S8`208Z:RP80Q8B40P26QXH208F5Q@80Ng]k0P20P8020861
P@80QHF50P24Q8@208V9RBL0b>3H0P0n?Sh203Lg=`80;Bd]0P0Y:BT202@T90809bLW100Y:BT202DU
9@80;2`/0P0Z:RX202d];@<0:2PX0P0P820201`L70806a/K0P18B4P207MgM`80SXj>0P2FUYH206][
J`80NGUi0P1`L70207YjNP80WYjN0P3=cLd20<?3``80^KVi0P2n_[h20<?3``80^k^k0P2l_;`20<S8
b080c/k>0P2=SHd202/[:`80:BTY00<0:2PX02XZ:P0Z:RX00P0Z:RX202d];@80=cLg0P12@T82055A
D@80FUYJ0P1PH60206MWI`@0Lg=c0P1fMWH207QhN080Ng]k0P22PX8207moO`80P8200P1mOGd208:2
PP80PH610P26QXH208N7Q`80Ph>30P27QhL00`2<S8`0SHf=08f=S@02092@T080V9RH0P2GUiL209:B
TP@0U9BD0P2JVYX209bLW080X:2P0P2RXZ820:NWY`80ZZZZ102][Jd20:^[Z`80/[:b0P2c/k<20;6a
/@80/k>c0P2_[jl20;:b/P80/k>c0P2h^;P20;bl_0030;Zj^P2b/[80/[:b0080/k>c0P2[Zj/20:n_
[`80Z:RX0P2YZJT20:b/[080[Jf]0P2XZ:P20:f][@80/;2`0P2UYJD20:>SX`80X:2P0P2OWil209^K
V`80WIfM0P2KVi/209VIV@80TI6A0P2DU9@209:BTP80UYJF0P2@T90209JFUP03092@T02=SHd0SHf=
0080SXj>0P2;Rh/408N7Q`80Ph>30P1nOWh207alO080PX:20P23Ph<208N7Q`80QXJ67P38h=P001`0
b>3H0P0l?3`203Ph>080;Rh^0P0W9bL202<S8`809RHV0P0Z:RX202PX:0809bLW0P0Y:BT402/[:`03
02TY:@0W9bL09bLW008092@T0P0K6a/201dM7@80AdM70P1fMWH208f=S@80VIVI0P1[Jf/207YjNP80
LW9b0P1fMWH20::RXP80bl_;0P35aLD20;Vi^@80_Kfm0P32`/820;jn_P80^KVi0P3;bl/20<c<c080
SXj>0P0^;Rh202HV9P0302PX:00Y:BT0:BTY0080:b/[0P0`<30203Hf=P80@T920P1?Cdl205QHF080
H61P0P1ZJVX207=cL`@0MGEe0P1hN7P207YjNP80OWin1021PH4207moO`80P8200P21PH4208>3P`H0
QXJ600<0R8R808^;R`2;Rh/00P2ATI4409JFUP80U9BD0P2EUID209NGU`80VIVI0P2LW9`20:2PX080
Y:BT0P2WYjL20:ZZZP80Zj^[0P2/[:`20:j^[P80[jn_0P2`/;020;6a/@H0/[:b0P2d];@20;Vi^@80
_Kfm00<0^KVi0;Bd]02d];@00P2a/K420:j^[P80Zj^[0P2ZZZX20:^[Z`80[:b/0P2[Zj/20:ZZZP80
[:b/0P2][Jd20:NWY`80XJ6Q0P2OWil209fMW@80W9bL0P2KVi/209VIV@80UiNG0P2EUID209>CT`@0
TY:B102CTi<00`2@T900SHf=08f=S@0208^;R`80RHV90P28R8P208J6QP80PX:20P1nOWh207moO`80
PX:20P24Q8@208F5Q@80QXJ69`38h=P204=3@`80<C4a0P0c<c<202`/;080:2PX0P0W9bL202TY:@80
:RXZ0P0Y:BT202DU9@80:2PX0P0a<C4202DU9@80:RXZ0P0P82000`0M7Ad08R8R028R8P0203Xj>P80
MWIf0P2DU9@209>CT`80L71`0P1dM7@207QhN080MGEe0P2OWil20<c<c080_[jn0P2i^KT20<;2`P80
`<300P2l_;`20;^k^`@0b/[:0P2@T90203De=@808b<S0P0U9BD202`/;080:b/[0P0^;Rh203Lg=`80
ADE50P1=CDd205UIF@80HF5Q00<0IfMW07EeM@1eMGD00P1cLg<207UiN@80MGEe0P1lO7`207emO@80
OWin0P23Ph<208:2PP80NWYj0P24Q8@20861P@80QXJ60P24Q8@208F5Q@80RHV90P28R8P209:BTP@0
UYJF0P2EUID209>CT`80UiNG0P2JVYX409jNWP80YJFU0P2WYjL20:RXZ080ZZZZ0P2][Jd00`2/[:`0
/[:b0;:b/P020:f][@80/K6a0P2`/;020;6a/@@0];Bd0P2g]kL20;jn_P80^KVi0P2e]KD20:n_[`80
[Jf]0P2^[Zh20:RXZ0@0Zj^[0P2YZJT20:^[Z`80Z:RX0P2_[jl20:RXZ080XJ6Q0P2OWil20:2PX080
VYZJ0P2KVi/209bLW080V9RH102CTi<00`2FUYH0T92@092@T00209FEU@80TY:B0P2<S8`208f=S@80
S8b<0P2:RXX208B4Q080QXJ60P25QHD207]kN`80P8200P21PH4208F5Q@80Q8B40P29RHTW0<SPf080
?Shn0P0g=cL202d];@80:BTY0P0T92@202LW9`@0:BTY0P0U9BD202`/;080:RXZ0P0];Bd302PX:080
820P0P0L71`201/K6`80B4Q80P1gMgL208j>SP80UYJF0P1[Jf/207UiN@80L71`0P1jNWX209jNWP80
cLg=0P33`l<20;Vi^@80_[jn0P33`l<20;^k^`80_;bl0P38b<P20<k>cP80SHf=0P0[:b/202TY:@03
02PX:00Z:RX0:RXZ0080:RXZ0P0];Bd203Lg=`80@T920P1ADE4205YJFP80H61P0P1WIfL407=cL`80
MWIf0P1hN7P207]kN`80PX:20P1oOgl20820P080OGem0P22PX820861P@80QXJ60P27QhL208>3P`80
QhN700<0S8b<08f=S@2=SHd00P2@T90209RHV080UiNG0P2BTY8409BDU080VYZJ0P2LW9`20:2PX080
XZ:R0P2WYjL20:ZZZP@0[Jf]0P2[Zj/20;:b/P80/k>c0P2a/K420;>c/`80[jn_0P2b/[820;>c/`80
^;Rh0P2l_;`00`2j^[X0/[:b0;:b/P020;>c/`80Zj^[0P2_[jl20:RXZ080ZJVY0P2/[:`20:f][@80
Z:RX0P2][Jd20;2`/080YJFU0P2SXj<20:2PX080WinO0P2KVi/209fMW@80Vi^K0P2IVIT2096AT@80
U9BD0P2BTY8209JFUP80T92@0P2FUYH00`2@T900SHf=08f=S@0208j>SP80Rh^;1027QhL208>3P`80
OWin0P1lO7`208:2PP80Ph>30P27QhL208J6QQh0b>3H000L0<SPf080DE5A100`<30203Ph>080@D51
0P0f=SH402TY:@80:b/[0P0Z:RX202TY:@80;Bd]00<0;bl_02XZ:P0Z:RX00P0T92@201hN7P80820P
0P0i>CT205YJFP80Ph>30P2SXj<207alO080MGEe0P1cLg<207IfMP80QhN70P2m_Kd20<c<c080];Bd
0P2m_Kd20<30`080^k^k0P2g]kL20<S8b080c/k>0P2i^KT206a/K080:RXZ00<08b<S02@T900T92@0
0P0_;bl2038b<P80=cLg0P0o?cl204Y:BP80EEEE0P1QHF4206YZJP80LG5a0P1eMGD207MgM`80N7Qh
0P1jNWX207emO@80Ogmo0P1mOGd207alO080OWin0P20P80208>3P`80QXJ60P28R8P308^;R`80S8b<
0P2BTY8609NGU`80V9RH0P2IVIT209^KV`80WIfM0P2PX:020:BTY080ZJVY0P2/[:`40:f][@80[Zj^
0P2`/;020;:b/P@0/k>c0P2b/[820;>c/`80];Bd0P2g]kL20;Rh^0030;Bd]02`/;00/;2`0080/;2`
0P2a/K420:f][@80ZZZZ0P2][Jd20:n_[`80[Jf]0P2[Zj/20:b/[080[Jf]0P2YZJT20:BTY080XZ:R
0P2OWil209jNWP80WIfM0P2JVYX209NGU`80UYJF0P2EUID209BDU080TY:B0P2CTi<209BDU003096A
T@2>SXh0SXj>0080S8b<0P2;Rh/208V9R@80QXJ60P23Ph<20861P@80P8200P1oOgl208:2PP@0QHF5
9`38h=P205ADE0@0;bl_0P0h>3P203<c<`80=CDe0P0T92@202XZ:P80;2`/0P0Z:RX202TY:@80<S8b
0P0[:b/202LW9`80:2PX00<08R8R02@T900T92@00P0c<c<205mOG`80T92@0P2TY:@208>3P`80Lg=c
0P1gMgL2079bLP80QXJ60P2o_kl20<c<c080/K6a0P2n_[h20<71`@80_kno0P2j^[X20<71`@80dM7A
0P31`L42069RHP80:2PX0P0W9bL202PX:080;2`/0P0`<30203@d=080A4A40P18B4P205EEE@80GemO
00<0J6QX07AdM01dM7@00P1dM7@407UiN@80N7Qh0P1lO7`40820P080Ogmo0P1iNGT20820P080Ph>3
0P26QXH208Z:RP80S8b<0P2>SXh208f=S@80TY:B1P2HV9P209NGU`80Vi^K0P2HV9P209bLW080X:2P
0P2QXJ420:JVYP@0[Jf]0P2`/;030:j^[P80/k>c0P2e]KD20;>c/`80[Zj^0P2f][H20;>c/`@0^[Zj
0P2f][H20;Bd]080[Jf]0P2c/k<40:^[Z`80[:b/0P2`/;020:f][@80[:b/0P2XZ:P20;2`/080YZJV
0P2TY:@20:FUY@80WIfM102OWil209RHV080UYJF0P2CTi<209BDU00309FEU@2ATI40TI6A0080U9BD
102EUID208b<S080SXj>0P2<S8`208Z:RP80QHF50P27QhL20861P@80OWin0P21PH4208>3P`80Q8B4
0P23Ph<W0<SPf080CTi>0P0a<C42030`<080>SXj0P11@D4203@d=080:RXZ0P0Y:BT202d];@@0:2PX
0P0_;bl00`0^;Rh0;Bd]02d];@0202LW9`8071`L0P0R8R8203Xj>P80F5QH0P1oOgl20:FUY@80OWin
0P1eMGD2075aL@80N7Qh0P29RHT20;bl_080b/[:0P2f][H20;bl_080`L71102j^[X20<K6aP80dM7A
0P2g]kL206a/K080;Rh^00<071`L02<S8`0S8b<00P0a<C42038b<P80>c/k0P0n?Sh204A4A080FUYJ
0P1QHF4206a/K080L71`0P1dM7@207UiN@80MgMg0P1iNGT207]kN`80Ph>30P1oOgl207inOP80PH61
0P1mOGd208B4Q080QHF50P26QXH208b<S00308V9R@2<S8`0S8b<0080SHf=0P2DU9@209NGU`80VIVI
0P2JVYX209VIV@@0WYjN0P2PX:020:NWY`80Zj^[102ZZZX20:j^[P80[:b/0P2`/;020:n_[`@0/[:b
0P2c/k<20;Bd]080^;Rh0P2g]kL20;Rh^0030;Jf]P2^[Zh0[Zj^0080/[:b0P2_[jl20:b/[080[Jf]
1P2`/;020:f][@80[:b/0P2YZJT20:RXZ080YJFU0P2TY:@20:2PX080VYZJ0P2IVIT209RHV080UYJF
102HV9P209BDU080SHf=0P2CTi<2096AT@0308f=S@2<S8`0S8b<0080SHf=0P25QHD208R8R080QhN7
0P23Ph<208:2PP80OGem1020P80208B4Q080QXJ67P38h=P001`0b>3H0P1ADE44030`<080>3Ph0P11
@D4203Hf=P@0:BTY0P0[:b/202XZ:P80:BTY0P0];Bd00`0_;bl0:RXZ02XZ:P0202@T90807QhN0P0P
820203Ti>@80FUYJ0P23Ph<20:>SX`80O7al0P1eMGD207=cL`80MWIf0P27QhL20;fm_@80c<c<0P2d
];@20;fm_@80`<300P2k^k/20;Ng]`80b<S80P3>c/h20;Vi^@80K6a/0P0Z:RX00`0S8b<092@T02@T
900202l_;`80<S8b0P0g=cL203lo?`80BTY:0P1EEED2065QH@80JVYZ0P1aLG4207EeM@80MgMg0P1h
N7P207YjNP80OGem0P1oOgl207emO@80O7al0P1nOWh20820P080Ph>30P26QXH208R8R0<0Rh^;0P2<
S8`209:BTPH0UiNG0P2HV9P209VIV@80Vi^K0P2MWId20:2PX080Y:BT0P2YZJT20:b/[0@0[Jf]0P2^
[Zh20;2`/080/[:b102c/k<20;:b/P80/k>c0P2d];@20;Ng]`80^;Rh00<0];Bd0;2`/02`/;000P2`
/;020;6a/@80[Jf]0P2ZZZX20:f][@80[jn_0P2][Jd20:^[Z`80[:b/0P2][Jd20:VYZ@80Y:BT0P2R
XZ8209nOW`80WYjN0P2MWId209ZJVP80UiNG0P2FUYH209FEU@80U9BD0P2BTY8209>CT`80U9BD00<0
TI6A08j>SP2>SXh00P2<S8`208^;R`80RHV90P26QXH208>3P`80PH610P20P80207moO`80PX:21025
QHDW0<SPf080E5AD100_;bl203Ph>080<c<c0P0e=CD202@T9080:RXZ0P0/;2`202XZ:P80:BTY0P0b
<S8202/[:`809bLW0P0X:2P00`0R8R8092@T02@T900203<c<`80GemO0P2@T9020:BTY080Ph>30P1c
Lg<207MgM`80LW9b0P26QXH20;no_`80c<c<0P2a/K420;jn_P80`L710P2o_kl20;Zj^P80`L710P3A
dM420<71`@80HV9R0P0X:2P202LW9`80:2PX0P0/;2`2030`<080=3@d0P14A4@204Q8B080EEEE0P1O
Gel00`1XJ6P0M7Ad07AdM00207AdM0@0NGUi0P1hN7P207alO0@0P8200P1oOgl207UiN@80P8200P23
Ph<208J6QP80RXZ:0P2<S8`208j>SP80SHf=0P2BTY8609RHV080UiNG0P2KVi/209RHV080W9bL0P2P
X:020:6QX@80YZJV102][Jd20;2`/0<0[Zj^0P2c/k<20;Fe]@80/k>c0P2^[Zh20;Jf]P80/k>c102j
^[X20;Jf]P80];Bd0P2][Jd20;>c/`@0Zj^[0P2/[:`20;2`/080[Jf]0P2/[:`20:RXZ080/;2`0P2V
YZH20:BTY080YJFU0P2MWId409nOW`80V9RH0P2FUYH209>CT`80U9BD00<0UIFE096AT@2ATI400P2D
U9@409FEU@80S8b<0P2>SXh208b<S080RXZ:0P25QHD208N7Q`80PH610P1nOWh20861P@80Ph>30P24
Q8@208>3PbL0b>3H0P1>CTh2034a<@80<30`0P0j>SX20451@@80=3@d0P0Z:RX202TY:@80;Bd]100X
:2P202l_;`0302h^;P0];Bd0;Bd]00809bLW0P0L71`2028R8P80>SXj0P1HF5P207moO`80YJFU0P1n
OWh207EeM@80LG5a0P1hN7P208V9R@80_;bl0P3:b/X20;Jf]P80_;bl0P31`L440;Zj^P80a/K60P3A
dM420;Ng]`80K6a/0P0^;Rh00`0L71`08b<S02<S8`02034a<@80<S8b0P0k>c/203hn?P80A4A40P1J
FUX2065QH@80K6a/0P1`L70207AdM080NGUi0P1gMgL207UiN@80Ng]k0P23Ph<207moO`80OWin0P21
PH4207emO@80Q8B40P25QHD208J6QP80S8b<00<0RHV908b<S02<S8`00P2=SHd209BDU080UiNG0P2I
VIT209ZJVP80VIVI102NWYh20:2PX080YjNW0P2[Zj/40:ZZZP80[Zj^0P2/[:`20;2`/080[jn_102b
/[820;>c/`80];Bd0P2h^;P20;Ng]`80^;Rh00<0][Jf0:j^[P2^[Zh00P2b/[820:n_[`80[:b/0P2]
[Jd60;2`/080[Jf]0P2/[:`20:VYZ@80Z:RX0P2UYJD20:BTY080X:2P0P2JVYX209VIV@80V9RH0P2F
UYH409RHV080U9BD0P2=SHd209>CT`80TI6A00<0SHf=08b<S02<S8`00P2=SHd208F5Q@80R8R80P27
QhL208>3P`80PX:20P1mOGd40820P080Q8B40P26QXHN0<SPf0007038h=P206QXJ080<C4a0P0e=CD2
02HV9P808B4Q0P0U9BD202/[:`80;Bd]0P0^;Rh202XZ:P809bLW0P0^;Rh00`0c<c<0;2`/02`/;002
02@T90808b<S0P0W9bL202h^;P80@4100P1dM7@20:6QX@80Shn?0P1dM7@207=cL`80Ng]k0P1bLW82
0:JVYP80c<c<0P2a/K420;^k^`80_Kfm0P2l_;`20;Vi^@80`L710P33`l<20=gMg@80[Zj^0P0k>c/0
0`0Z:RX092@T02@T9002034a<@80<S8b0P0f=SH203`l?080A4A40P1CDe<2065QH@80JFUY0P1^KVh2
07EeM@H0NGUi0P1kNg/207alO080Ng]k0P1jNWX207emO@80PH610P23Ph<208J6QP80Rh^;1@2?Shl2
09>CT`80UiNG0P2HV9P209VIV@80VYZJ0P2KVi/209fMW@80WYjN0P2QXJ420:FUY@80ZZZZ102^[Zh2
0:f][@80[Zj^0P2`/;020;>c/`80]KFe0P2d];@:0;>c/`030:n_[`2][Jd0[Jf]0080/;2`0P2c/k<2
0;2`/080[:b/0P2_[jl20;:b/P80/;2`0P2][Jd20:b/[080Zj^[0P2ZZZX20:RXZ080YJFU0P2QXJ42
09nOW`80WIfM0P2JVYX409JFUP80UiNG0P2DU9@209:BTP80Ti>C0P2DU9@00`2BTY80Shn?08n?S`02
08f=S@80S8b<0P29RHT408F5Q@80Q8B40P20P80207emO@80P8200P23Ph<208B4Q2L0b>3H0P1OGel2
03Lg=`80<30`0P0[:b/202<S8`80:BTY0P0[:b/202l_;`80;2`/0P0W9bL202HV9P80<S8b0P0c<c<2
030`<0809RHV00<08B4Q02XZ:P0Z:RX00P0/;2`203`l?080N7Qh0P2GUiL209BDU080MWIf0P1]KFd2
07emO@80MWIf0P2TY:@20<g=c@80/k>c0P2f][H20;no_`80^k^k0P2l_;`20;fm_@80b/[:0P3AdM42
0:n_[`80@T920P0Y:BT202LW9`80;Bd]0P0i>CT203Hf=P80=cLg0P17AdL205MGE`80HF5Q00<0JFUY
06e]K@1]KFd00P1eMGD207QhN080NWYj0P1hN7P207alO080NWYj0P1kNg/407YjNP@0Ph>30P26QXH2
08Z:RP80Shn?0P2ATI4208n?S`80TI6A102HV9P209VIV@80V9RH0P2MWId209bLW080WYjN0P2RXZ82
0:JVYP80Z:RX0P2_[jl40:j^[P030:f][@2a/K40/K6a0080/K6a0P2d];@20;>c/`@0];Bd0P2b/[82
0;Bd]080/[:b0P2`/;020:n_[`80[:b/0P2f][H20:f][@80[jn_0P2`/;020;>c/`80[Zj^0P2`/;02
0:ZZZP80[:b/0P2^[Zh20:NWY`80YZJV0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080TY:B0`2IVIT2
09:BTP80TI6A0P2EUID209BDU080Shn?102<S8`208Z:RP80Q8B40P29RHT208>3P`80PH610P1lO7`2
0861P@80Q8B40P22PX8W0<SPf080J6QX0P0b<S8203@d=0809bLW0P0O7al202HV9P80:b/[0P0^;Rh2
02l_;`@09bLW0`0b<S8202LW9`8092@T0P0S8b<202HV9P80<C4a0P12@T82079bLP80XJ6Q0P2?Shl4
07=cL`80Ng]k0P1aLG420:NWY`80bl_;0P2c/k<20;Zj^P80_Kfm0P2i^KT20;Zj^P80`/;20P33`l<2
0=[JfP80[Zj^0P0i>CT00`0Z:RX09BDU02DU9@02034a<@80<30`0P0e=CD203hn?P80@D510P1HF5P2
05eMG@80JFUY0P1^KVh207EeM@@0NGUi0P1kNg/207YjNP80O7al101iNGT207emO@80PX:20P24Q8@2
08F5Q@80RHV90P2@T9000`2ATI40T92@092@T00209JFUP80VYZJ0P2FUYH209jNWP80U9BD0P2KVi/2
09fMW@80WinO0P2NWYh20:FUY@80Zj^[0P2`/;020:f][@80[Zj^0P2_[jl20;2`/080];Bd0P2e]KD2
0;Ng]`80/K6a102b/[820;>c/`80];Bd00<0[Zj^0:b/[02/[:`00P2b/[820;>c/`80/[:b0P2YZJT2
0:j^[P80/K6a0P2b/[820:^[Z`80ZZZZ0P2^[Zh20:b/[0@0YZJV0P2QXJ420:2PX080WinO0P2KVi/2
09FEU@80V9RH102EUID209:BTP80U9BD0P2EUID00`2DU9@0SHf=08f=S@0208n?S`80SHf=0P29RHT4
08F5Q@80Q8B40P21PH4207alO0@0PH610P28R8PN0<SPf0007038h=P206QXJ080<C4a0P0e=CD202HV
9P808B4Q0P0U9BD202/[:`80;Bd]0P0^;Rh202XZ:P809bLW0P0^;Rh00`0c<c<0;2`/02`/;00202@T
90808b<S0P0W9bL202h^;P80@4100P1dM7@20:6QX@80Shn?0P1dM7@207=cL`80Ng]k0P1bLW820:JV
YP80c<c<0P2a/K420;^k^`80_Kfm0P2l_;`20;Vi^@80`L710P33`l<20=gMg@80[Zj^0P0k>c/00`0Z
:RX092@T02@T9002034a<@80<S8b0P0f=SH203`l?080A4A40P1CDe<2065QH@80JFUY0P1^KVh207Ee
M@H0NGUi0P1kNg/207alO080Ng]k0P1jNWX207emO@80PH610P23Ph<208J6QP80Rh^;1@2?Shl209>C
T`80UiNG0P2HV9P209VIV@80VYZJ0P2KVi/209fMW@80WYjN0P2QXJ420:FUY@80ZZZZ102^[Zh20:f]
[@80[Zj^0P2`/;020;>c/`80]KFe0P2d];@:0;>c/`030:n_[`2][Jd0[Jf]0080/;2`0P2c/k<20;2`
/080[:b/0P2_[jl20;:b/P80/;2`0P2][Jd20:b/[080Zj^[0P2ZZZX20:RXZ080YJFU0P2QXJ4209nO
W`80WIfM0P2JVYX409JFUP80UiNG0P2DU9@209:BTP80Ti>C0P2DU9@00`2BTY80Shn?08n?S`0208f=
S@80S8b<0P29RHT408F5Q@80Q8B40P20P80207emO@80P8200P23Ph<208B4Q2L0b>3H0P1OGel203Lg
=`80<30`0P0[:b/202<S8`80:BTY0P0[:b/202l_;`80;2`/0P0W9bL202HV9P80<S8b0P0c<c<2030`
<0809RHV00<08B4Q02XZ:P0Z:RX00P0/;2`203`l?080N7Qh0P2GUiL209BDU080MWIf0P1]KFd207em
O@80MWIf0P2TY:@20<g=c@80/k>c0P2f][H20;no_`80^k^k0P2l_;`20;fm_@80b/[:0P3AdM420:n_
[`80@T920P0Y:BT202LW9`80;Bd]0P0i>CT203Hf=P80=cLg0P17AdL205MGE`80HF5Q00<0JFUY06e]
K@1]KFd00P1eMGD207QhN080NWYj0P1hN7P207alO080NWYj0P1kNg/407YjNP@0Ph>30P26QXH208Z:
RP80Shn?0P2ATI4208n?S`80TI6A102HV9P209VIV@80V9RH0P2MWId209bLW080WYjN0P2RXZ820:JV
YP80Z:RX0P2_[jl40:j^[P030:f][@2a/K40/K6a0080/K6a0P2d];@20;>c/`@0];Bd0P2b/[820;Bd
]080/[:b0P2`/;020:n_[`80[:b/0P2f][H20:f][@80[jn_0P2`/;020;>c/`80[Zj^0P2`/;020:ZZ
ZP80[:b/0P2^[Zh20:NWY`80YZJV0P2RXZ8209nOW`80WIfM0P2JVYX209RHV080TY:B0`2IVIT209:B
TP80TI6A0P2EUID209BDU080Shn?102<S8`208Z:RP80Q8B40P29RHT208>3P`80PH610P1lO7`20861
P@80Q8B40P22PX8W0<SPf080J6QX0P0b<S8203@d=0809bLW0P0O7al202HV9P80:b/[0P0^;Rh202l_
;`@09bLW0`0b<S8202LW9`8092@T0P0S8b<202HV9P80<C4a0P12@T82079bLP80XJ6Q0P2?Shl407=c
L`80Ng]k0P1aLG420:NWY`80bl_;0P2c/k<20;Zj^P80_Kfm0P2i^KT20;Zj^P80`/;20P33`l<20=[J
fP80[Zj^0P0i>CT00`0Z:RX09BDU02DU9@02034a<@80<30`0P0e=CD203hn?P80@D510P1HF5P205eM
G@80JFUY0P1^KVh207EeM@@0NGUi0P1kNg/207YjNP80O7al101iNGT207emO@80PX:20P24Q8@208F5
Q@80RHV90P2@T9000`2ATI40T92@092@T00209JFUP80VYZJ0P2FUYH209jNWP80U9BD0P2KVi/209fM
W@80WinO0P2NWYh20:FUY@80Zj^[0P2`/;020:f][@80[Zj^0P2_[jl20;2`/080];Bd0P2e]KD20;Ng
]`80/K6a102b/[820;>c/`80];Bd00<0[Zj^0:b/[02/[:`00P2b/[820;>c/`80/[:b0P2YZJT20:j^
[P80/K6a0P2b/[820:^[Z`80ZZZZ0P2^[Zh20:b/[0@0YZJV0P2QXJ420:2PX080WinO0P2KVi/209FE
U@80V9RH102EUID209:BTP80U9BD0P2EUID00`2DU9@0SHf=08f=S@0208n?S`80SHf=0P29RHT408F5
Q@80Q8B40P21PH4207alO0@0PH610P28R8PN0<SPf0007038h=P205=CD`80<S8b0P0a<C4202XZ:P80
:BTY0P0Z:RX602d];@80;2`/0P0[:b/202d];@0302l_;`0];Bd0;Bd]0080:RXZ1P0Y:BT203<c<`80
GUiN0P26QXH209fMW@80Ph>30P1^KVh207]kN`80Kfm_0P2;Rh/20;Bd]080^;Rh0P2[Zj/40;jn_P80
_kno0P33`l<20<C4a080f=SH0P2k^k/20:6QX@0303lo?`0O7al07alO0080:BTY0P0Z:RX203@d=080
>c/k0P14A4@2059BDP80H61P0P1WIfL206a/K080Lg=c0P1hN7P407YjNP80Ng]k0P1mOGd407alO080
Ogmo0P22PX8208B4Q080QXJ60P2:RXX208j>SP03096AT@2BTY80TY:B0080Ti>C0P2EUID209NGU`80
VYZJ0P2KVi/209bLW080WinO0P2RXZ820:BTY080YJFU0P2YZJT20:b/[0@0[Jf]0P2^[Zh20;2`/080
/[:b1P2d];@20;:b/P80/K6a102b/[800`2a/K40[jn_0:n_[`020;2`/080/K6a0P2`/;020:n_[`80
/K6a102b/[820;6a/@80[Zj^0P2/[:`20:ZZZP80Z:RX0P2UYJD20::RXP80WinO0P2LW9`209^KV`80
VYZJ0P2GUiL209BDU0P0Ti>C00<0T92@08j>SP2>SXh00P2<S8`208Z:RP80QhN70P25QHD408B4Q080
PX:22020P80W0<SPf080D51@0P0j>SX402h^;P809RHV0P0b<S8202XZ:P80<30`0P0b<S8202XZ:P80
;Bd]0P0^;Rh202l_;`80:BTY0P0W9bL00`0V9RH0:2PX02PX:00202XZ:P80<S8b0P1LG5`208R8R080
Vi^K0P1oOgl206UYJ@@0NGUi0P23Ph<20;:b/P80^;Rh0P2/[:`20;^k^`80_Kfm0P30`<020;jn_P80
b<S80P3AdM420<g=c@80V9RH0P0e=CD202@T90809RHV0P0_;bl2038b<P80>c/k0P11@D4205ADE080
HF5Q00<0IFEU06i^KP1^KVh00P1bLW8207YjNP80MgMg0P1kNg/407alO080Ogmo0P1mOGd207alO080
QXJ60P21PH4208N7Q`80RHV90P2;Rh/208n?S`80Ti>C0P2>SXh209FEU@80UYJF102KVi/409bLW080
YJFU0P2TY:@20:NWY`80Z:RX0P2/[:`20:ZZZP<0[:b/0P2a/K420;>c/`@0];Bd102c/k<20;2`/080
[Jf]0P2`/;060:j^[P80/k>c0P2`/;040:f][@80/[:b0P2c/k<20;6a/@80Zj^[0P2ZZZX20:VYZ@80
YJFU0P2RXZ820:6QX@80WYjN1P2KVi/209ZJVP80T92@00<0TY:B096AT@2ATI400P2@T90208j>SP80
TY:B102;Rh/208R8R0@0Q8B40P20P8020861P@80Q8B4101oOgl20820P080PX:29`38h=P2059BDP80
=3@d0P0_;bl202PX:080:RXZ0P0^;Rh402/[:`80;2`/0P0[:b/202`/;080;bl_00<0<S8b02`/;00/
;2`00P0[:b/202XZ:P80:BTY0P0T92@203<c<`80GemO0P29RHT209^KV`80QhN70P1]KFd207YjNP80
KVi^0P2;Rh/40;Jf]P80Zj^[0P30`<020<71`@80_;bl0P33`l<20<G5a@80fm_K0P2m_Kd20::RXP03
0451@@0U9BD09BDU0080:RXZ0P0V9RH203De=@80>SXj0P17AdL205MGE`80GemO0P1UIFD206a/K080
MGEe0P1gMgL207UiN@80Ng]k0P1gMgL207inOP80O7al0P1kNg/40820P080PX:20P29RHT208b<S080
SXj>00<0TI6A09:BTP2BTY800P2BTY8209FEU@80UYJF0P2HV9P209JFUP80XZ:R0P2PX:0209nOW`80
XJ6Q0P2SXj<20:VYZ@H0[:b/0P2b/[820:j^[PH0/k>c0P2e]KD20;Bd]080/K6a0P2^[Zh30;6a/@80
/;2`0P2d];@20:n_[`80[Jf]0P2`/;040;:b/P80/;2`0P2d];@20:n_[`80Zj^[0P2ZZZX20:RXZ080
YJFU0P2SXj<209nOW`@0WIfM0P2KVi/409BDU080Ti>C0P2GUiL209FEU@80TI6A00<0U9BD08n?S`2?
Shl00P2<S8`208Z:RP80R8R80P23Ph<208N7Q`80PH610P23Ph<20820P080Ph>30P1nOWh208:2PQh0
b>3H000L0<SPf080De=C0P0b<S82034a<@80:RXZ0P0Y:BT202XZ:PH0;Bd]0P0/;2`202/[:`80;Bd]
00<0;bl_02d];@0];Bd00P0Z:RX602TY:@80<c<c0P1NGUh208J6QP80WIfM0P23Ph<206i^KP80Ng]k
0P1_Kfl208^;R`80];Bd0P2h^;P20:^[Z`@0_[jn0P2o_kl20<?3``80a<C40P3Hf=P20;^k^`80XJ6Q
00<0?clo01lO7`0O7al00P0Y:BT202XZ:P80=3@d0P0k>c/204A4A080DU9B0P1PH60206MWI`80K6a/
0P1cLg<207QhN0@0NWYj0P1kNg/207emO@@0O7al0P1oOgl208:2PP80Q8B40P26QXH208Z:RP80SXj>
00<0TI6A09:BTP2BTY800P2CTi<209FEU@80UiNG0P2JVYX209^KV`80W9bL0P2OWil20::RXP80Y:BT
0P2UYJD20:VYZ@80[:b/102][Jd20:j^[P80/;2`0P2b/[860;Bd]080/[:b0P2a/K440;:b/P030;6a
/@2_[jl0[jn_0080/;2`0P2a/K420;2`/080[jn_0P2a/K440;:b/P80/K6a0P2^[Zh20:b/[080ZZZZ
0P2XZ:P20:FUY@80XZ:R0P2OWil209bLW080Vi^K0P2JVYX209NGU`80U9BD202CTi<00`2@T900SXj>
08j>SP0208b<S080RXZ:0P27QhL208F5Q@@0Q8B40P22PX880820P2L0b>3H0P1@D50203Xj>P@0;Rh^
0P0V9RH2038b<P80:RXZ0P0`<302038b<P80:RXZ0P0];Bd202h^;P80;bl_0P0Y:BT202LW9`0302HV
9P0X:2P0:2PX0080:RXZ0P0b<S8205aLG080R8R80P2KVi/207moO`80JFUY101iNGT208>3P`80/[:b
0P2h^;P20:b/[080^k^k0P2m_Kd20<30`080_[jn0P38b<P20=7Ad@80cLg=0P2HV9P203De=@8092@T
0P0V9RH202l_;`80<S8b0P0k>c/20451@@80E5AD0P1QHF400`1UIFD0KVi^06i^KP02079bLP80NWYj
0P1gMgL207]kN`@0O7al0P1oOgl207emO@80O7al0P26QXH20861P@80QhN70P29RHT208^;R`80Shn?
0P2CTi<208j>SP80UIFE0P2FUYH409^KV`@0W9bL0P2UYJD20:BTY080YjNW0P2XZ:P20:b/[080ZZZZ
0`2/[:`20;6a/@80/k>c102d];@40;>c/`80/;2`0P2][Jd20;2`/0H0[Zj^0P2c/k<20;2`/0@0[Jf]
0P2b/[820;>c/`80/K6a0P2[Zj/20:ZZZP80ZJVY0P2UYJD20::RXP80XJ6Q0P2NWYh609^KV`80VYZJ
0P2@T9000`2BTY80TI6A096AT@02092@T080SXj>0P2BTY8408^;R`80R8R81024Q8@20820P080PH61
0P24Q8@407moO`80P8200P22PX8W0<SPf080DU9B0P0d=3@202l_;`80:2PX0P0Z:RX202h^;P@0:b/[
0P0/;2`202/[:`80;2`/0P0_;bl00`0b<S80;2`/02`/;00202/[:`80:RXZ0P0Y:BT202@T9080<c<c
0P1OGel208V9R@80Vi^K0P27QhL206e]K@80NWYj0P1^KVh208^;R`@0][Jf0P2[Zj/20<30`080`L71
0P2l_;`20<?3``80aLG50P3Kfm/20;fm_@80XZ:R00<0@D5102DU9@0U9BD00P0Z:RX202HV9P80=CDe
0P0j>SX204M7A`80EeMG0P1OGel206EUI@80K6a/0P1eMGD207MgM`80NGUi0P1kNg/207MgM`80OWin
0P1lO7`207]kN`@0P8200P22PX8208V9R@80S8b<0P2>SXh00`2ATI40TY:B09:BTP0209:BTP80UIFE
0P2FUYH209RHV080UYJF0P2RXZ820:2PX080WinO0P2QXJ420:>SX`80ZJVY1P2/[:`20;:b/P80[Zj^
1P2c/k<20;Fe]@80];Bd0P2a/K420:j^[P<0/K6a0P2`/;020;Bd]080[jn_0P2][Jd20;2`/0@0/[:b
0P2`/;020;Bd]080[jn_0P2[Zj/20:ZZZP80Z:RX0P2UYJD20:>SX`80WinO102MWId209^KV`@0U9BD
0P2CTi<209NGU`80UIFE0P2ATI400`2DU9@0Shn?08n?S`0208b<S080RXZ:0P28R8P208>3P`80QhN7
0P21PH4208>3P`80P8200P23Ph<207inOP80PX:27P38h=P001`0b>3H0P0j>SX203De=@80;2`/0P0]
;Bd602h^;P80;Bd]0P0/;2`202d];@80;bl_0P0/;2`00`0Z:RX0;Bd]02d];@0202l_;`80;Bd]0P0Z
:RX202LW9`80:b/[0P17AdL206ATI080X:2P0P2EUID206a/K080Ng]k0P1bLW8207AdM080UiNG0P2m
_Kd209nOW`80_Kfm0P2o_kl20<C4a0@0`/;20P3AdM420=OGe`80`<3000<0NWYj03De=@0e=CD00P0O
7al2020P8080<C4a0P0j>SX204E5A@80DU9B0P1NGUh206EUI@80JVYZ0P1aLG4207MgM`80NGUi0P1j
NWX207alO080OGem0P1nOWh20820P080PX:20P24Q8@208F5Q@80QhN70P2:RXX208f=S@03096AT@2D
U9@0U9BD0080U9BD0P2CTi<209JFUP80VIVI0P2KVi/209bLW080X:2P0P2TY:@40:JVYP80Z:RX0P2Z
ZZX20:b/[080[Jf]0P2^[Zh20:n_[`80/K6a0P2b/[820;>c/`80];Bd0P2a/K420:n_[`80/K6a0`2c
/k<20;:b/P80/;2`0P2^[Zh20;2`/080/[:b102a/K420;:b/P80/k>c0P2a/K420:f][@80ZZZZ0P2W
YjL20:FUY@80Xj>S0P2OWil209^KV`@0W9bL0P2FUYH2096AT@80TY:B0P2DU9@209>CT`80TI6A00<0
Shn?08f=S@2=SHd00P2:RXX208N7Q`80QHF50P24Q8@208>3P`@0Q8B40P23Ph<20861P@@0OWin9`38
h=P203Lg=`80>3Ph0P0Y:BT202h^;P80;bl_0P0b<S8202h^;P80;Bd]0P0[:b/202`/;080;Bd]0P0_
;bl202XZ:P80;bl_0P0c<c<302TY:@80:RXZ0P0`<30203Xj>P80K6a/0P2DU9@209NGU`@0Lg=c0P1h
N7P207EeM@80T92@0P2l_;`20:RXZ080][Jf1031`L440<?3``80cLg=0P3Bd]820<W9b@80O7al0P0]
;Bd2024Q8@80:2PX0P0];Bd203Ph>080AdM70P1EEED2061PH003069RHP1/K6`0K6a/0080Kfm_0P1g
MgL207alO080Ng]k0P1jNWX207inOP@0P8200P1oOgl208N7Q`80PH610P2:RXX208R8R080SXj>102D
U9@2096AT@80Ti>C102GUiL609fMW@@0YJFU102WYjL20:ZZZP80[Zj^0P2][Jd00`2/[:`0/;2`0;2`
/0020;6a/@80/k>c0P2`/;020;Fe]@80[jn_0P2`/;020;Bd]080/[:b0P2g]kL20;Bd]0@0[Zj^0P2_
[jl20;Bd]080/k>c0P2`/;020;>c/`@0/[:b0P2][Jd20:ZZZP80Z:RX0P2VYZH40:6QX@80VYZJ0P2M
WId209VIV@80VYZJ0P2@T90309:BTP80U9BD0P2@T90209BDU080RXZ:0P2=SHd208Z:RP80PH610P25
QHD208N7Q`80QHF50P23Ph<408:2PP80Ng]k0P1oOglW0<SPf080?Shn0P0a<C4202l_;`@0;Bd]0P0a
<C4602d];@80;2`/0P0`<30302/[:`80;Bd]100_;bl202XZ:P809bLW0P0/;2`204Y:BP80HV9R0P2P
X:0209FEU@80KFe]0P1nOWh206m_K`80MGEe0P2GUiL20;fm_@80XJ6Q0P2h^;P20<30`080`/;20P33
`l<20<;2`P80clo?0P3GemL20;fm_@0307alO00d=3@0=3@d00807alO0P0Q8B42030`<080?3`l0P13
@d<205=CD`80GEeM0P1TI6@206YZJP80Lg=c0P1eMGD207]kN`80O7al0P1iNGT207inOP80PX:20P1n
OWh20861P@80QHF50P26QXH208N7Q`80R8R80P2=SHd00`2@T900U9BD09BDU00209FEU@80Ti>C0P2F
UYH209^KV`@0VYZJ0P2OWil20:BTY080Z:RX0P2VYZH20:RXZ080ZJVY0P2^[Zh20:f][@80Zj^[0P2`
/;020;:b/P80];Bd0P2b/[820;>c/`80/[:b0P2`/;020:n_[`80]KFe00<0];Bd0;6a/@2a/K400P2`
/;020:j^[P80[jn_1P2b/[820:n_[`80]KFe0P2`/;020:f][@80YjNW0P2YZJT20:BTY080XJ6Q0P2R
XZ8209RHV080WinO0P2KVi/2096AT@80TY:B0P2DU9@209:BTP80T92@0P2CTi<00`2>SXh0T92@092@
T00208J6QP80RXZ:0P24Q8@208>3P`80QHF50P24Q8@208>3P`80PX:20P21PH4207emO@80PH617P38
h=P001`0b>3H0P0n?Sh203Ph>080:b/[0P0^;Rh2038b<P80<C4a1P0_;bl;02h^;P80;Bd]0P0[:b/2
02PX:080:BTY0P0e=CD204Q8B080S8b<0P2RXZ8207emO@80Lg=c0P1_Kfl2075aL@80Ogmo102e]KD2
0;6a/@80^k^k0P31`L440<;2`P80bLW90P3@d=020=SHf0030;Fe]@1?Cdl0Cdm?0080<30`0P0X:2P2
02TY:@80=CDe0P14A4@204m?C`80FEUI0P1QHF4206MWI`80Kfm_0P1fMWH407QhN080NWYj0P1mOGd2
07inOP80P8200P21PH4208>3P`80QXJ60P29RHT208^;R`80SHf=00<0T92@09>CT`2CTi<0102EUID2
09JFUP80V9RH0P2KVi/209jNWP80XJ6Q0P2RXZ820:FUY@80YjNW0P2ZZZX40:b/[080Zj^[0P2][Jd2
0;2`/080/k>c0P2d];@20;6a/@80[Zj^0P2][Jd20:j^[P80/K6a0`2c/k<20;:b/PP0/K6a0P2`/;02
0:n_[`80/;2`0P2a/K420;2`/080[jn_0P2/[:`20:VYZ@80YjNW0P2UYJD20:6QX@80WIfM0P2JVYX2
09NGU`80UIFE102CTi<209FEU@80Ti>C0P2ATI400`2?Shl0SHf=08f=S@0208Z:RP80QhN70P25QHD6
08B4Q080Ph>30P22PX860861PBL0b>3H0P0n?Sh203De=@80;bl_0P0];Bd602h^;P80;bl_0P0];Bd2
02h^;P80<30`0P0^;Rh202d];@80;Rh^0P0_;bl00`0a<C40<30`030`<00202/[:`80;2`/0P0f=SH2
05=CD`80RHV90P2ZZZX20820P080Lg=c0P1bLW8207AdM080OGem102e]KD20;>c/`80_;bl0P30`<04
0<?3``80a/K6103?cll20;fm_@80F5QH0P0Y:BT202@T9080;Rh^0P0d=3@204A4A080CDe=0P1GEeL0
0`1OGel0JFUY06UYJ@0206m_K`80MgMg0P1eMGD207MgM`80NGUi0P1lO7`207emO@80OWin0P26QXH2
08:2PP80Ph>30P2=SHd208V9R@80SHf=0P2DU9@209>CT`80UiNG0P2HV9P209NGU`80V9RH0P2JVYX2
09jNWP80XJ6Q0P2RXZ820:>SX`80YjNW0P2YZJT20:^[Z`80[Zj^0P2][Jd00`2[Zj/0[Zj^0:j^[P02
0;>c/`80/[:b0P2d];@20;2`/080[:b/0P2ZZZX20;Bd]080/k>c0P2`/;040;6a/@80/[:b0P2a/K42
0;2`/080[Jf]0P2^[Zh20;:b/P80[jn_0P2b/[820:n_[`80[Jf]0P2ZZZX20:VYZ@80YjNW0P2TY:@2
09^KV`80W9bL0P2DU9@209>CT`<0U9BD0P2HV9P209FEU@80SXj>0P2BTY8208Z:RP80SHf=0P26QXH2
08:2PP80R8R80P26QXH208B4Q080Ogmo0P24Q8@208>3P`80PX:20P25QHDW0<SPf080?clo0P0g=cL2
02d];@80;2`/0P0`<30203@d=080;bl_0P0/;2`202l_;`80<C4a0P0/;2`202XZ:P0302/[:`0];Bd0
;Bd]0080:b/[0P0`<30202`/;0@09RHV0P0h>3P204M7A`80RXZ:0P2PX:0207YjNP80M7Ad0P1^KVh2
07EeM@80OWin0P2c/k<20;Rh^080/K6a0P2j^[X20<?3``80`L710P32`/820<O7a`80dm?C0P3Hf=P0
0`2d];@0BTY:04Y:BP0202l_;`80:RXZ0P0X:2P2038b<P80@D510P1@D50205YJFP80GUiN0P1XJ6P2
06e]K@H0MgMg0P1kNg/207emO@@0Ogmo0P22PX8208>3P`80QHF50P29RHT208R8R0<0T92@0P2EUID2
09NGU`80Ti>C102IVIT209jNWP80WinO0P2RXZ820:>SX`@0YZJV0P2/[:`20:^[Z`80ZZZZ0P2^[Zh2
0:f][@80/K6a0P2_[jl20;>c/`80/[:b102_[jl20:f][@80[jn_0P2c/k<00`2f][H0/;2`0;2`/002
0;2`/080/[:b0P2a/K420;2`/0@0/K6a0P2^[Zh20;2`/0@0/K6a0P2_[jl20:NWY`80Zj^[0P2UYJD2
0::RXP80W9bL0P2JVYX209VIV@80Ti>C0P2DU9@209JFUP80U9BD0P2>SXh209BDU0<0S8b<0P28R8P2
08N7Q`80QXJ60P25QHD208>3P`80QHF50P23Ph<208:2PP80P8200P21PH4207moOah0b>3H000L0<SP
f080?Shn0P0h>3P202/[:`80;Rh^0P0b<S82034a<@H0;bl_2`0^;Rh202d];@80:b/[0P0X:2P202TY
:@80=CDe0P18B4P208b<S080XZ:R0P1mOGd207=cL`80Kfm_0P1aLG4207moO`@0]KFe0P2a/K420;^k
^`80`L711032`/820<W9b@80d=3@0P3Hf=P00`2e]KD0Cdm?04m?C`02030`<080:2PX0P0Y:BT203De
=@80A4A40P1?Cdl205UIF@80HF5Q0P1WIfL206m_K`80MWIf101hN7P207YjNP80OGem0P1nOWh20820
P080PH610P23Ph<208J6QP80RHV90P2;Rh/208f=S@03092@T02CTi<0Ti>C00@0UIFE0P2FUYH209RH
V080Vi^K0P2NWYh20:6QX@80XZ:R0P2UYJD20:NWY`80ZZZZ102/[:`20:^[Z`80[Jf]0P2`/;020;>c
/`80];Bd0P2a/K420:j^[P80[Jf]0P2^[Zh20;6a/@<0/k>c0P2b/[880;6a/@80/;2`0P2_[jl20;2`
/080/K6a0P2`/;020:n_[`80[:b/0P2YZJT20:NWY`80YJFU0P2QXJ4209fMW@80VYZJ0P2GUiL209FE
U@@0Ti>C0P2EUID209>CT`80TI6A00<0Shn?08f=S@2=SHd00P2:RXX208N7Q`80QHF51P24Q8@208>3
P`80PX:21P21PH4W0<SPf080?Shn0P0e=CD202l_;`80;Bd]1P0^;Rh202l_;`80;Bd]0P0^;Rh2030`
<080;Rh^0P0];Bd202h^;P80;bl_00<0<C4a030`<00`<3000P0[:b/202`/;080=SHf0P1CDe<208V9
R@80ZZZZ0P20P80207=cL`80LW9b0P1dM7@207emO@@0]KFe0P2c/k<20;bl_080`<301033`l<20<K6
aP@0clo?0P2m_Kd205QHF080:BTY0P0T92@202h^;P80=3@d0P14A4@204e=C@80EeMG00<0GemO06UY
J@1YJFT00P1_Kfl207MgM`80MGEe0P1gMgL207UiN@80O7al0P1mOGd207inOP80QXJ60P22PX8208>3
P`80SHf=0P29RHT208f=S@80U9BD0P2CTi<209NGU`80V9RH0P2GUiL209RHV080VYZJ0P2NWYh20:6Q
X@80XZ:R0P2SXj<20:NWY`80ZJVY0P2[Zj/20:j^[P80[Jf]00<0Zj^[0:j^[P2^[Zh00P2c/k<20;:b
/P80];Bd0P2`/;020:b/[080ZZZZ0P2d];@20;>c/`80/;2`102a/K420;:b/P80/K6a0P2`/;020:f]
[@80[Zj^0P2b/[820:n_[`80/[:b0P2_[jl20:f][@80ZZZZ0P2YZJT20:NWY`80Y:BT0P2KVi/209bL
W080U9BD0P2CTi<309BDU080V9RH0P2EUID208j>SP80TY:B0P2:RXX208f=S@80QXJ60P22PX8208R8
R080QXJ60P24Q8@207moO`80Q8B40P23Ph<208:2PP80QHF59`38h=P203lo?`80=cLg0P0];Bd202`/
;080<30`0P0d=3@202l_;`80;2`/0P0_;bl2034a<@80;2`/0P0Z:RX00`0[:b/0;Bd]02d];@0202/[
:`80<30`0P0/;2`402HV9P80>3Ph0P17AdL208Z:RP80X:2P0P1jNWX207AdM080KVi^0P1eMGD207in
OP80/k>c0P2h^;P20;6a/@80^[Zj0P33`l<20<71`@80`/;20P37alL20=?Cd`80f=SH00<0];Bd04Y:
BP1:BTX00P0_;bl202XZ:P80:2PX0P0b<S820451@@80D51@0P1JFUX205iNGP80J6QX0P1]KFd607Mg
M`80Ng]k0P1mOGd407moO`80PX:20P23Ph<208F5Q@80RHV90P28R8P3092@T080UIFE0P2GUiL209>C
T`@0VIVI0P2NWYh209nOW`80XZ:R0P2SXj<40:JVYP80[:b/0P2[Zj/20:ZZZP80[Zj^0P2][Jd20;6a
/@80[jn_0P2c/k<20;:b/P@0[jn_0P2][Jd20:n_[`80/k>c00<0][Jf0;2`/02`/;000P2`/;020;:b
/P80/K6a0P2`/;040;6a/@80[Zj^0P2`/;040;6a/@80[jn_0P2WYjL20:^[Z`80YJFU0P2RXZ8209bL
W080VYZJ0P2IVIT209>CT`80U9BD0P2FUYH209BDU080SXj>0P2DU9@308b<S080R8R80P27QhL208J6
QP80QHF50P23Ph<208F5Q@80Ph>30P22PX820820P080PH610P1oOglN0<SPf0007038h=P204E5A@80
>CTi0P0[:b/202h^;P80=3@d0P0c<c<2030`<0@0<C4a0P0^;Rh202`/;080;bl_00<0<S8b02l_;`0_
;bl01P0/;2`202XZ:P80:BTY0P0X:2P203<c<`80L71`0P2UYJD2092@T080Kfm_0P1[Jf/2079bLP80
KFe]0P2UYJD20<W9b@80Z:RX0P2e]KD20;bl_080`<300P32`/820<C4a080aLG50P3Bd]800`39bLT0
/K6a0;6a/@02038b<P80=3@d0P0T92@2038b<P80@T920P1<C4`205ADE080GEeM0P1UIFD206i^KP80
MGEe101fMWH207UiN@80O7al0P1nOWh207moO`80P8200P21PH4208J6QP80RXZ:0P2<S8`208f=S@03
08n?S`2BTY80TY:B0080UYJF0P2HV9P409NGU`80Vi^K1P2PX:020:BTY080Z:RX0P2[Zj/20:j^[P80
[:b/0P2ZZZX20:f][@80/;2`0P2d];@20;Fe]@80[jn_0P2YZJT20:ZZZP80[Zj^0P2a/K420;>c/`03
0;:b/P2`/;00/;2`0080/[:b0P2d];@20;6a/@H0[Zj^102_[jl40;2`/080[Zj^0P2[Zj/20:VYZ@80
YjNW0P2SXj<209nOW`80V9RH102CTi<609BDU080Ti>C0P2ATI400`2@T900SHf=08f=S@0208Z:RP80
QXJ62025QHD208:2PP80P8200P22PX8208B4Q080QHF59`38h=P204Y:BP80<30`0P0];Bd203<c<`80
=CDe0P0d=3@202l_;`80>SXj100];Bd202`/;0@0<30`0P0];Bd202/[:`03030`<00Y:BT0:BTY00@0
:BTY0P0V9RH2034a<@80Kfm_0P2NWYh209BDU080L71`0P1VIVH206m_K`80MWIf0P2VYZH20<30`080
Zj^[0P2d];@20;fm_@80_;bl0P34a<@20<;2`P80bLW90P3@d=020<c<c080Z:RX0P0m?Cd202XZ:P80
:2PX0P0f=SH20451@@80Bd];0P1DE5@00`1JFUX0IVIV06IVIP02075aL@80MGEe0P1dM7@207EeM@80
NWYj0P1mOGd207inOP80P8200P1nOWh20861P@80QXJ60P2:RXX208b<S080SHf=0P2BTY82092@T080
U9BD102HV9P209FEU@@0WYjN0P2RXZ8209nOW`80Y:BT0P2WYjL20:j^[P80[:b/0P2][Jd20:VYZ@03
0:f][@2_[jl0[jn_0080][Jf0P2e]KD20:j^[P80Z:RX0P2ZZZX20:^[Z`@0/[:b0P2a/K420:n_[`80
][Jf0P2c/k<20;6a/@@0/;2`0P2][Jd20:j^[P80[jn_0P2a/K440;2`/080ZJVY0P2ZZZX20:BTY080
Xj>S0P2OWil209ZJVP80Ti>C0P2ATI4309FEU@80U9BD0P2ATI4209>CT`80T92@102<S8`608F5Q@80
QXJ60P27QhL207emO@80PH610P23Ph<208:2PP80QHF59`38h=P204E5A@80>SXj0P0];Bd202/[:`@0
=SHf0P0_;bl2030`<080<c<c0P0_;bl202`/;080<C4a00<0<30`03<c<`0c<c<00P0/;2`202TY:@@0
:b/[0P0V9RH202XZ:P80<S8b0P1cLg<20:FUY@80T92@0P1cLg<206IVIP80MGEe0P1/K6`20:FUY@80
c<c<0P2XZ:P20;>c/`80_;bl0P30`<020<?3``80aLG50P32`/820=KFeP030<c<c02_[jl0[jn_0080
<c<c0P0i>CT202@T9080;bl_0P15ADD204e=C@80DU9B0P1PH60206ATI080KVi^0P1dM7@207EeM@80
MWIf0P1iNGT207alO080OGem0P1oOgl208:2PP80Ogmo0P25QHD208f=S@80RHV90P2<S8`00`2BTY80
TI6A096AT@0209BDU0@0VIVI0P2EUID209bLW0@0WinO102SXj<20:NWY`@0[Jf]102ZZZX20:^[Z`80
/K6a0P2b/[820;Fe]@80/K6a0P2WYjL20:VYZ@80[Zj^0P2f][H20;2`/0030;Bd]02_[jl0[jn_0080
/[:b0P2d];@20:n_[`80/K6a0P2][Jd20:n_[`80/k>c0P2a/K420:b/[080/K6a0P2_[jl20:ZZZP80
[Jf]0P2UYJD20::RXP80XJ6Q0P2IVIT409:BTP80U9BD0P2FUYH209FEU@80TY:B0P2ATI400`2@T900
SHf=08f=S@0208V9R@80R8R80P24Q8@208F5Q@80QhN70P26QXH207moO`80PX:20P21PH4208J6QP80
PX:27P38h=P001`0b>3H0P15ADD203Ti>@80:b/[0P0^;Rh203@d=080<c<c0P0`<304034a<@80;Rh^
0P0/;2`202l_;`03038b<P0_;bl0;bl_00H0;2`/0P0Z:RX202TY:@80:2PX0P0c<c<2071`L080YJFU
0P2@T90206m_K`80Jf][0P1bLW8206e]K@80YJFU0P39bLT20:RXZ080]KFe0P2l_;`20<30`080`/;2
0P34a<@20<G5a@80d];B00<0bLW90;6a/@2a/K400P0b<S8203@d=08092@T0P0b<S820492@P80C4a<
0P1DE5@205eMG@80IFEU0P1^KVh207EeM@@0MWIf0P1iNGT207alO080OWin0P1oOgl20820P080PH61
0P26QXH208Z:RP80S8b<0P2=SHd00`2?Shl0TY:B09:BTP0209JFUP80V9RH102GUiL209^KV`H0X:2P
0P2TY:@20:RXZ080Zj^[0P2^[Zh20:b/[080ZZZZ0P2][Jd20;2`/080];Bd0P2e]KD20:n_[`80ZJVY
0P2ZZZX20:j^[P80/K6a0P2c/k<00`2b/[80/;2`0;2`/0020;:b/P80];Bd0P2a/K460:j^[P@0[jn_
102`/;020:j^[P80Zj^[0P2YZJT20:NWY`80Xj>S0P2OWil209RHV0@0Ti>C1P2DU9@209>CT`80TI6A
00<0T92@08f=S@2=SHd00P2:RXX208J6QPP0QHF50P22PX820820P080PX:20P24Q8@208F5QBL0b>3H
0P1:BTX2030`<080;Bd]0P0c<c<203De=@80=3@d0P0_;bl203Xj>P@0;Bd]0P0/;2`4030`<080;Bd]
0P0[:b/00`0`<300:BTY02TY:@0402TY:@809RHV0P0a<C4206m_K`80WYjN0P2DU9@2071`L080IVIV
0P1_Kfl207IfMP80YZJV0P30`<020:^[Z`80];Bd0P2m_Kd20;bl_080a<C40P32`/820<W9b@80d=3@
0P3<c<`20:RXZ080?Cdm0P0Z:RX202PX:080=SHf0P11@D4204];B`80E5AD00<0FUYJ06IVIP1VIVH0
0P1aLG4207EeM@80M7Ad0P1eMGD207YjNP80OGem0P1nOWh20820P080OWin0P21PH4208J6QP80RXZ:
0P2<S8`208f=S@80TY:B0P2@T90209BDU0@0V9RH0P2EUID409jNWP80XZ:R0P2OWil20:BTY080YjNW
0P2^[Zh20:b/[080[Jf]0P2YZJT00`2][Jd0[jn_0:n_[`020;Jf]P80]KFe0P2^[Zh20:RXZ080ZZZZ
0P2[Zj/40;:b/P80/K6a0P2_[jl20;Jf]P80/k>c0P2a/K440;2`/080[Jf]0P2^[Zh20:n_[`80/K6a
102`/;020:VYZ@80ZZZZ0P2TY:@20:>SX`80WinO0P2JVYX209>CT`80TI6A0`2EUID209BDU080TI6A
0P2CTi<2092@T0@0S8b<1P25QHD208J6QP80QhN70P1mOGd20861P@80Ph>30P22PX8208F5QBL0b>3H
0P15ADD203Xj>P80;Bd]0P0[:b/403Hf=P80;bl_0P0`<30203<c<`80;bl_0P0/;2`2034a<@03030`
<00c<c<0<c<c0080;2`/0P0Y:BT402/[:`809RHV0P0Z:RX2038b<P80Lg=c0P2UYJD2092@T080Lg=c
0P1VIVH207EeM@80K6a/0P2UYJD20<c<c080Z:RX0P2c/k<20;bl_080`<300P33`l<20<G5a@80`/;2
0P3Fe]H00`3<c<`0[jn_0:n_[`0203<c<`80>CTi0P0T92@202l_;`80ADE50P1=CDd2059BDP80H61P
0P1TI6@206i^KP80M7Ad0P1eMGD207IfMP80NGUi0P1lO7`207emO@80Ogmo0P22PX8207moO`80QHF5
0P2=SHd208V9R@80S8b<00<0TY:B096AT@2ATI400P2DU9@409VIV@80UIFE0P2LW9`409nOW`@0Xj>S
0P2WYjL40:f][@@0ZZZZ0P2[Zj/20;6a/@80/[:b0P2e]KD20;6a/@80YjNW0P2YZJT20:j^[P80][Jf
0P2`/;000`2d];@0[jn_0:n_[`020;:b/P80];Bd0P2_[jl20;6a/@80[Jf]0P2_[jl20;>c/`80/K6a
0P2/[:`20;6a/@80[jn_0P2ZZZX20:f][@80YJFU0P2RXZ820:6QX@80VIVI102BTY8209BDU080UYJF
0P2EUID209:BTP80TI6A00<0T92@08f=S@2=SHd00P29RHT208R8R080Q8B40P25QHD208N7Q`80QXJ6
0P1oOgl208:2PP80PH610P26QXH208:2PQh0b>3H000L0<SPf080@D510P0d=3@202DU9@80:b/[0P0d
=3@203<c<`80<C4a0P0_;bl202d];@@0;2`/0P0^;Rh00`0`<300;Rh^02h^;P0202`/;0@0;Bd]0P0Z
:RX202PX:0809RHV0P0a<C42051@D080TY:B0P2SXj<208>3P`80Hf=S0P1[Jf/206QXJ080Shn?0P2g
]kL20;Rh^080ZJVY0P2k^k/20;fm_@80`L711030`<020<c<c0030<o?c`3:b/X0b/[:0080SHf=0P0b
<S82034a<@80=3@d0P10@40204M7A`80D51@0P1JFUX206EUI@80KFe]0P1cLg<407AdM080MgMg0P1k
Ng/207inOPH0PH610P25QHD208V9R@80Rh^;0P2>SXh00`2@T900TY:B09:BTP0209JFUP80VYZJ102I
VIT209bLW080X:2P0P2QXJ420::RXP80YJFU0P2XZ:P20:ZZZP80[:b/0P2[Zj/20:ZZZP80[:b/0P2_
[jl20;6a/@80/[:b0P2^[Zh20:ZZZP80[Zj^0P2b/[820;>c/`80/[:b00<0/;2`0:n_[`2_[jl00P2_
[jl20;2`/080[:b/0P2YZJT20:^[Z`80[Jf]0P2_[jl60;6a/@80[jn_0P2/[:`20:RXZ080Y:BT0P2P
X:0209bLW080V9RH0P2EUID209>CT`80TY:B0P2ATI42092@T080TI6A0P2BTY800`2@T900SHf=08f=
S@0208V9R@80QXJ60P24Q8@208>3P`@0Q8B40P21PH4207emO@80Ogmo1022PX8W0<SPf080De=C0P0_
;bl202LW9`80;Rh^0P0b<S8203Hf=P80;Bd]0P0/;2`2034a<@80<30`0P0[:b/2030`<080=CDe0P0`
<30202/[:`0302XZ:P0/;2`0;2`/0080:BTY0P0W9bL202PX:080;Bd]0P1DE5@209>CT`80XZ:R0P1m
OGd206IVIP80IfMW0P1`L70208R8R080^k^k0P2d];@20:j^[P80^KVi0P2l_;`20<;2`P80_kno0P32
`/820<_;b`80c/k>0P38b<P2092@T080=3@d0P0`<30203<c<`80?clo0P1<C4`205=CD`<0GemO0P1_
Kfl2079bLP80MGEe0P1iNGT207QhN080NWYj0P1kNg/208>3P`80Ogmo0P23Ph<208B4Q080R8R80P2:
RXX208^;R`80T92@0P2BTY8209NGU`80VIVI0P2EUID209ZJVP80WIfM102PX:020::RXP80YjNW102X
Z:P20:j^[P@0YjNW00<0/K6a0:b/[02/[:`00P2d];@20;2`/080[Jf]0P2XZ:P20;6a/@@0][Jf102a
/K420;2`/080[jn_0P2/[:`20:^[Z`80YJFU0P2YZJT20:j^[P80/[:b0P2^[Zh20;:b/P80Zj^[0P2^
[Zh20:ZZZP80Z:RX0P2SXj<20:2PX080VYZJ0P2HV9P409JFUP80T92@0`2>SXh2092@T080TI6A0P2?
Shl208b<S080Rh^;0P26QXH20861P@80OWin1027QhL207alO080Ogmo1020P80208B4Q2L0b>3H0P0n
?Sh203@d=08092@T0P0V9RH203<c<`80=cLg0P0d=3@202/[:`80;2`/0P0_;bl202XZ:P80<c<c00<0
;bl_034a<@0a<C400P0[:b/202TY:@80;bl_0P0^;Rh202XZ:P809BDU0P0^;Rh2059BDP80U9BD0P2S
Xj<208:2PP80I6AT0P1WIfL206a/K080SHf=0P2e]KD20;Jf]P80ZZZZ0P2j^[X20;bl_080`<300P31
`L420;jn_P80c/k>00<0bl_;0<W9b@39bLT00P29RHT203Lg=`80<C4a0P0b<S8203lo?`80ATI60P1A
DE4205YJFP80IVIV0P1]KFd407IfMP80M7Ad0P1hN7P207]kN`80NWYj0P21PH4208>3P`80PH610P24
Q8@208R8R080SXj>0P2=SHd00`2BTY80TI6A096AT@0209>CT`80VIVI0P2LW9`209JFUP80V9RH0P2P
X:020:FUY@80WIfM0P2QXJ420:VYZ@80/;2`1P2[Zj/20:f][@80[jn_0P2c/k<20;Bd]080[Jf]0P2[
Zj/20:n_[`80/K6a102b/[800`2_[jl0/K6a0;6a/@020;6a/@80/[:b0P2[Zj/20:RXZ080ZZZZ0P2[
Zj/20:f][@80/;2`0P2c/k<20:n_[`80Zj^[0P2ZZZX20:RXZ080XZ:R0P2PX:0209RHV080W9bL0P2D
U9@4096AT@80TY:B0P2?Shl208j>SP80Ti>C00<0TI6A08n?S`2?Shl00P2;Rh/208B4Q080PX:20P23
Ph<20861P@80QHF50P1nOWh407moO`80Q8B40P23Ph<N0<SPf0007038h=P20451@@80=3@d0P0U9BD2
02/[:`80=3@d0P0c<c<2034a<@80;bl_0P0];Bd402`/;080;Rh^00<0<30`02h^;P0^;Rh00P0/;2`4
02d];@80:RXZ0P0X:2P202HV9P80<C4a0P1@D50209:BTP80Xj>S0P23Ph<206=SH`80Jf][0P1XJ6P2
08n?S`80]kNg0P2h^;P20:VYZ@80^k^k0P2m_Kd20<71`@@0`<300P3<c<`00`3?cll0b/[:0<[:bP02
08f=S@80<S8b0P0a<C4203@d=080@4100P17AdL2051@D080FUYJ0P1UIFD206e]K@80Lg=c101dM7@2
07MgM`80Ng]k0P1nOWh60861P@80QHF50P29RHT208^;R`80SXj>00<0T92@09:BTP2BTY800P2FUYH2
09ZJVP@0VIVI0P2LW9`20:2PX080XJ6Q0P2RXZ820:FUY@80Z:RX0P2ZZZX20:b/[080Zj^[0P2ZZZX2
0:b/[080[jn_0P2a/K420;:b/P80[Zj^0P2ZZZX20:j^[P80/[:b0P2c/k<20;:b/P030;2`/02_[jl0
[jn_0080[jn_0P2`/;020:b/[080ZJVY0P2[Zj/20:f][@80[jn_1P2a/K420:n_[`80[:b/0P2XZ:P2
0:BTY080X:2P0P2LW9`209RHV080UIFE0P2CTi<209:BTP80TI6A0P2@T902096AT@80TY:B00<0T92@
08f=S@2=SHd00P29RHT208J6QP80Q8B40P23Ph<408B4Q080PH610P1mOGd207moO`@0PX:29`38h=P2
05=CD`80;bl_0P0W9bL202h^;P80<S8b0P0f=SH202d];@80;2`/0P0a<C42030`<080:b/[0P0`<302
03De=@80<30`0P0[:b/00`0Z:RX0;2`/02`/;00202TY:@809bLW0P0X:2P202d];@80E5AD0P2CTi<2
0::RXP80OGem0P1VIVH206MWI`80L71`0P28R8P20;^k^`80];Bd0P2^[Zh20;Vi^@80_;bl0P32`/82
0;no_`80`/;20P3;bl/20<k>cP80b<S80P2@T90203@d=080<30`0P0c<c<203lo?`80C4a<0P1CDe<3
05mOG`80Kfm_0P1bLW8207EeM@80NGUi0P1hN7P207YjNP80Ng]k0P23Ph<207moO`80Ph>30P24Q8@2
08R8R080RXZ:0P2;Rh/2092@T080TY:B0P2GUiL209VIV@80UIFE0P2JVYX209fMW@@0X:2P0P2RXZ82
0:NWY`@0Z:RX0P2^[Zh40:NWY`030;6a/@2/[:`0[:b/0080];Bd0P2`/;020:f][@80Z:RX0P2a/K44
0;Jf]P@0/K6a0P2`/;020:n_[`80[:b/0P2[Zj/20:FUY@80ZJVY0P2^[Zh20;:b/P80[Zj^0P2b/[82
0:^[Z`80[Zj^0P2ZZZX20:RXZ080Xj>S0P2PX:0209ZJVP80V9RH102FUYH2092@T0<0SXj>0P2@T902
096AT@80Shn?0P2<S8`208^;R`80QXJ60P21PH4207inOP@0QhN70P1lO7`207moO`@0P8200P24Q8@W
0<SPf080?Shn0P0d=3@202@T90809RHV0P0c<c<203Lg=`80=3@d0P0[:b/202`/;080;bl_0P0Z:RX2
03<c<`0302l_;`0a<C40<C4a0080:b/[0P0Y:BT202l_;`80;Rh^0P0Z:RX202DU9@80;Rh^0P1BDU82
09BDU080Xj>S0P22PX8206ATI080IfMW0P1/K6`208f=S@80]KFe0P2f][H20:ZZZP80^[Zj0P2l_;`2
0<30`080`L710P2n_[h20<k>cP030<_;b`39bLT0bLW90080RHV90P0g=cL2034a<@80<S8b0P0o?cl2
04I6AP80DE5A0P1JFUX206IVIP80KFe]101fMWH207AdM080N7Qh0P1kNg/207YjNP80PH610P23Ph<2
0861P@80Q8B40P28R8P208j>SP80SHf=00<0TY:B096AT@2ATI400P2CTi<209VIV@80W9bL0P2FUYH2
09RHV080X:2P0P2UYJD209fMW@80XJ6Q0P2YZJT20;2`/0H0Zj^[0P2][Jd20:n_[`80/k>c0P2d];@2
0:f][@80Zj^[0P2_[jl20;6a/@@0/[:b00<0[jn_0;6a/@2a/K400P2a/K420;:b/P80Zj^[0P2XZ:P2
0:ZZZP80Zj^[0P2][Jd20;2`/080/k>c0P2_[jl20:^[Z`80ZZZZ0P2XZ:P20::RXP80X:2P0P2HV9P2
09bLW080U9BD102ATI4209:BTP80Shn?0P2>SXh209>CT`03096AT@2?Shl0Shn?0080Rh^;0P24Q8@2
08:2PP80Ph>30P21PH4208F5Q@80OWin101oOgl208B4Q080Ph>37P38h=P001`0b>3H0P0k>c/202h^
;P808B4Q0P0Y:BT403<c<`80<30`0P0/;2`202TY:@80:RXZ0P0/;2`702d];@@0;Rh^0P0[:b/202TY
:@80:2PX0P0c<c<203@d=080MWIf0P2ZZZX209RHV080HF5Q0P1WIfL206UYJ@80NGUi0P2NWYh20<K6
aP80XJ6Q0P2g]kL20;Vi^@80_kno0P2n_[h20;fm_@80a<C400<0bl_;0<o?c`3?cll00P35aLD207Qh
N0@0<C4a0P0o?cl204I6AP80CTi>0P1IFET206ATI080K6a/0P1aLG4207=cL`80M7Ad0P1gMgL207Yj
NP80OWin1022PX820861P@80Q8B40P28R8P208^;R`80SXj>00<0T92@09>CT`2CTi<00P2GUiL609^K
V`80WIfM0P2OWil20:6QX@80Xj>S0P2VYZH20:RXZ0@0ZJVY0P2ZZZX20:^[Z`80[:b/0P2][Jd40:j^
[P@0[Jf]0P2a/K420;Fe]@80/k>c0P2_[jl00`2^[Zh0[Jf]0:f][@020:b/[080Zj^[0P2XZ:P20:JV
YP80Z:RX0P2/[:`20:n_[`@0/K6a0P2`/;020:n_[`80[Jf]0P2WYjL20:6QX@80WIfM0P2IVIT209RH
V080UiNG0P2CTi<208n?S`80S8b<0P2;Rh/208n?S`80Ti>C00<0T92@08b<S02<S8`00P28R8P208F5
Q@80Ph>30P21PH4208:2PP80Ph>30P20P80207alO080OGem101oOglW0<SPf080@T920P0W9bL202DU
9@80:2PX0P0d=3@203<c<`80=3@d0P0Y:BT202HV9P80;bl_0P0[:b/202XZ:P80:BTY0P0_;bl302d]
;@80;Rh^0P0[:b/202TY:@80:2PX0P0];Bd20492@P80MgMg0P2LW9`209RHV080KVi^0P1QHF4206YZ
JP80MWIf0P2TY:@20;jn_P80YjNW0P2a/K420;bl_080_kno0P2k^k/20;fm_@80a/K60P3<c<`20<g=
c@80`L710P1jNWX203Hf=P80=3@d0P0m?Cd204M7A`80Bd];00<0EUIF06MWI`1WIfL00P1]KFd2079b
LP80L71`0P1eMGD207QhN080O7al0P1kNg/208>3P`80PH610P20P80208B4Q080QhN70P2<S8`2092@
T080Shn?0P2DU9@209RHV080W9bL0P2FUYH209^KV`80WIfM0P2OWil20:2PX080YJFU0P2TY:@40:RX
Z080[:b/0P2WYjL30:f][@80[:b/0P2`/;020:f][@80[Zj^0P2][Jd20;2`/0@0/[:b0P2][Jd20:n_
[`80[:b/0P2ZZZX20:b/[080[Jf]0P2XZ:P20:BTY080[Jf]102a/K420;:b/P80[Zj^0P2b/[820:b/
[080YjNW0P2RXZ8409^KV`80V9RH0P2EUID209>CT`80T92@00<0RXZ:08j>SP2>SXh00P2=SHd209BD
U080Shn?0P2;Rh/208R8R080Q8B40P27QhL20861P@80PX:20P27QhL207alO080P8200P1jNWX207mo
O`80Ph>39`38h=P203/k>`80;Rh^0P0R8R8202TY:@@0<S8b0P0a<C4202d];@80:RXZ0P0W9bL202d]
;@<0;2`/0P0^;Rh602d];@80:2PX0P0V9RH202PX:080<c<c0P0f=SH2079bLP80[Jf]0P2EUID2069R
HP80IFEU0P1]KFd207MgM`80W9bL0P37alL20::RXP80][Jf0P2j^[X20;no_`80`<300P2l_;`20<O7
a`030<c<c03>c/h0c/k>0080aLG50P1mOGd2034a<@80;bl_0P11@D4204Y:BP80D51@0P1GEeL206MW
I`80J6QX0P1`L702079bLP80MWIf0P1dM7@207UiN@80PH611022PX8408>3P`80R8R80P2>SXh208b<
S00308j>SP2BTY80TY:B0080VIVI0P2JVYX209bLW080WIfM0P2KVi/209fMW@80YZJV0P2TY:@20:FU
Y@@0Z:RX0P2ZZZX20:RXZ0H0Zj^[0P2a/K420:b/[080ZZZZ0P2[Zj/20;6a/@80];Bd0P2c/k<20;6a
/@030:VYZ@2_[jl0[jn_0080[:b/0P2YZJT20:NWY`80ZZZZ0P2VYZH20:j^[P80/;2`0P2a/K440;2`
/080];Bd0P2`/;020:6QX@80Y:BT0P2NWYh209RHV080W9bL0P2EUID2096AT@80Shn?0P2>SXh408f=
S@80UIFE00<0T92@08^;R`2;Rh/01025QHD408>3P`80P8200P25QHD20861P@80Ogmo0P1hN7P207mo
O`80PX:27P38h=P001`0b>3H0P0k>c/202h^;P808B4Q0P0Y:BT403<c<`80<30`0P0/;2`202TY:@80
:RXZ0P0/;2`702d];@@0;Rh^0P0[:b/202TY:@80:2PX0P0c<c<203@d=080MWIf0P2ZZZX209RHV080
HF5Q0P1WIfL206UYJ@80NGUi0P2NWYh20<K6aP80XJ6Q0P2g]kL20;Vi^@80_kno0P2n_[h20;fm_@80
a<C400<0bl_;0<o?c`3?cll00P35aLD207QhN0@0<C4a0P0o?cl204I6AP80CTi>0P1IFET206ATI080
K6a/0P1aLG4207=cL`80M7Ad0P1gMgL207YjNP80OWin1022PX820861P@80Q8B40P28R8P208^;R`80
SXj>00<0T92@09>CT`2CTi<00P2GUiL609^KV`80WIfM0P2OWil20:6QX@80Xj>S0P2VYZH20:RXZ0@0
ZJVY0P2ZZZX20:^[Z`80[:b/0P2][Jd40:j^[P@0[Jf]0P2a/K420;Fe]@80/k>c0P2_[jl00`2^[Zh0
[Jf]0:f][@020:b/[080Zj^[0P2XZ:P20:JVYP80Z:RX0P2/[:`20:n_[`@0/K6a0P2`/;020:n_[`80
[Jf]0P2WYjL20:6QX@80WIfM0P2IVIT209RHV080UiNG0P2CTi<208n?S`80S8b<0P2;Rh/208n?S`80
Ti>C00<0T92@08b<S02<S8`00P28R8P208F5Q@80Ph>30P21PH4208:2PP80Ph>30P20P80207alO080
OGem101oOglW0<SPf080@T920P0W9bL202DU9@80:2PX0P0d=3@203<c<`80=3@d0P0Y:BT202HV9P80
;bl_0P0[:b/202XZ:P80:BTY0P0_;bl302d];@80;Rh^0P0[:b/202TY:@80:2PX0P0];Bd20492@P80
MgMg0P2LW9`209RHV080KVi^0P1QHF4206YZJP80MWIf0P2TY:@20;jn_P80YjNW0P2a/K420;bl_080
_kno0P2k^k/20;fm_@80a/K60P3<c<`20<g=c@80`L710P1jNWX203Hf=P80=3@d0P0m?Cd204M7A`80
Bd];00<0EUIF06MWI`1WIfL00P1]KFd2079bLP80L71`0P1eMGD207QhN080O7al0P1kNg/208>3P`80
PH610P20P80208B4Q080QhN70P2<S8`2092@T080Shn?0P2DU9@209RHV080W9bL0P2FUYH209^KV`80
WIfM0P2OWil20:2PX080YJFU0P2TY:@40:RXZ080[:b/0P2WYjL30:f][@80[:b/0P2`/;020:f][@80
[Zj^0P2][Jd20;2`/0@0/[:b0P2][Jd20:n_[`80[:b/0P2ZZZX20:b/[080[Jf]0P2XZ:P20:BTY080
[Jf]102a/K420;:b/P80[Zj^0P2b/[820:b/[080YjNW0P2RXZ8409^KV`80V9RH0P2EUID209>CT`80
T92@00<0RXZ:08j>SP2>SXh00P2=SHd209BDU080Shn?0P2;Rh/208R8R080Q8B40P27QhL20861P@80
PX:20P27QhL207alO080P8200P1jNWX207moO`80Ph>39`38h=P203/k>`80;Rh^0P0R8R8202TY:@@0
<S8b0P0a<C4202d];@80:RXZ0P0W9bL202d];@<0;2`/0P0^;Rh602d];@80:2PX0P0V9RH202PX:080
<c<c0P0f=SH2079bLP80[Jf]0P2EUID2069RHP80IFEU0P1]KFd207MgM`80W9bL0P37alL20::RXP80
][Jf0P2j^[X20;no_`80`<300P2l_;`20<O7a`030<c<c03>c/h0c/k>0080aLG50P1mOGd2034a<@80
;bl_0P11@D4204Y:BP80D51@0P1GEeL206MWI`80J6QX0P1`L702079bLP80MWIf0P1dM7@207UiN@80
PH611022PX8408>3P`80R8R80P2>SXh208b<S00308j>SP2BTY80TY:B0080VIVI0P2JVYX209bLW080
WIfM0P2KVi/209fMW@80YZJV0P2TY:@20:FUY@@0Z:RX0P2ZZZX20:RXZ0H0Zj^[0P2a/K420:b/[080
ZZZZ0P2[Zj/20;6a/@80];Bd0P2c/k<20;6a/@030:VYZ@2_[jl0[jn_0080[:b/0P2YZJT20:NWY`80
ZZZZ0P2VYZH20:j^[P80/;2`0P2a/K440;2`/080];Bd0P2`/;020:6QX@80Y:BT0P2NWYh209RHV080
W9bL0P2EUID2096AT@80Shn?0P2>SXh408f=S@80UIFE00<0T92@08^;R`2;Rh/01025QHD408>3P`80
P8200P25QHD20861P@80Ogmo0P1hN7P207moO`80PX:27P38h=P001`0b>3H0P0e=CD202l_;`80:BTY
0P0_;bl203Hf=P80<S8b0P0^;Rh202d];@80;2`/100Z:RX202`/;00302h^;P0`<300<30`00@0<30`
0P0_;bl402h^;P80:RXZ0P0];Bd202`/;080De=C0P2ATI420:2PX080N7Qh0P1/K6`206YZJP80KFe]
0P2BTY820;Zj^P80]KFe0P2YZJT20;>c/`80_[jn0P2o_kl20;jn_P80`l?300<0alO70<S8b038b<P0
0P2o_kl20<W9b@80HF5Q0P0a<C4203Ph>080@T920P1@D50205QHF080H61P0P1XJ6P206m_K`80LW9b
0P1dM7@207QhN080Ng]k0P1nOWh20820P080PH610P22PX8208J6QP80Rh^;0P2<S8`208f=S@03092@
T02DU9@0U9BD0080UiNG0P2IVIT209^KV`80W9bL0P2MWId209jNWP80XJ6Q0P2UYJD20:NWY`80Z:RX
0P2VYZH20:FUY@80YjNW0P2ZZZX20:b/[080[Zj^102_[jl20:f][@80Zj^[0P2/[:`20:f][@80[:b/
1@2[Zj/20:b/[080[Jf]0P2[Zj/20:ZZZP@0ZJVY0P2ZZZX20:b/[0@0[Jf]0P2/[:`20:^[Z`80YjNW
0P2RXZ8209jNWP80Vi^K0P2IVIT209NGU`80TI6A0P2<S8`208Z:RP80Rh^;0P2?Shl2096AT@0308f=
S@28R8P0R8R80080QXJ60P25QHD208>3P`H0PX:20P21PH4207moO`H0P8209`38h=P202l_;`80;2`/
100];Bd203Hf=P80<c<c100^;Rh202`/;080;Bd]0P0X:2P2030`<080<C4a0P0/;2`203@d=003034a
<@0g=cL0=cLg0080;2`/0P0[:b/2038b<P80;2`/0P0Y:BT2059BDP80Rh^;0P2UYJD207inOP80JFUY
0P1WIfL2071`L080S8b<0P30`<020;:b/P80Zj^[0P2e]KD20;bl_080_[jn0P2m_Kd20<;2`P80a/K6
1039bLT20;^k^`80FEUI0P0f=SH203Lg=`80ADE50P1ADE400`1BDU80HF5Q065QH@0206][J`80L71`
0P1aLG4206m_K`80NGUi0P1nOWh207YjNP80Q8B41022PX8208Z:RP@0Rh^;102=SHd209:BTP80UiNG
0P2MWId209ZJVP80XJ6Q0P2KVi/409nOW`80XZ:R102YZJT20:BTY0@0YJFU0P2ZZZX00`2][Jd0ZJVY
0:VYZ@020;6a/@@0[Jf]0P2/[:`20:^[Z`80[Jf]0P2[Zj/20:b/[080[Jf]0P2[Zj/20:ZZZP80[:b/
0P2][Jd20:RXZ080ZJVY0P2XZ:P40:VYZ@@0/;2`0P2][Jd20:RXZ080[:b/0P2PX:0209bLW0@0VYZJ
0P2EUID209BDU080SHf=00<0R8R808j>SP2>SXh00P2>SXh209JFUP80RHV90P2;Rh/208V9R@80P820
0P23Ph<208:2PP@0PH610P1jNWX208J6QP80NWYj0P1nOWh208N7QbL0b>3H0P0f=SH2038b<P809bLW
0P0_;bl203Ph>080=SHf0P0X:2P402d];@80:b/[0P0Y:BT202l_;`0302TY:@0c<c<0<c<c0080<30`
0P0^;Rh2038b<P80<c<c0P0^;Rh202/[:`80;Bd]0P0/;2`205ADE080U9BD0P2PX:0207UiN@80Jf][
0P1YJFT206i^KP80TY:B0P2j^[X20;Fe]@80ZJVY0P2d];@20;fm_@80_[jn0P2l_;`20<?3``030<S8
b037alL0alO70080`<300P36a/H2061PH080;bl_0P0h>3P20451@@80CDe=0P1DE5@2061PH080JFUY
0P1dM7@2071`L080Lg=c0P1hN7P207inOP80PH610P1nOWh207moO`80P8200P26QXH208N7Q`@0SXj>
00<0TI6A09JFUP2FUYH00P2GUiL209VIV@80W9bL0P2JVYX409fMW@80XZ:R0P2UYJD20:BTY080Z:RX
102WYjL20:FUY@80[:b/0P2][Jd40:j^[P80/;2`0P2^[Zh20:n_[`80[Jf]0P2^[Zh20:n_[`80[Zj^
00<0ZJVY0:ZZZP2ZZZX00P2_[jl20:j^[P80ZZZZ0P2VYZH20:RXZ080ZZZZ0P2[Zj/20:n_[`80[Zj^
0P2/[:`20:n_[`80Zj^[0P2TY:@20:>SX`80X:2P0P2GUiL209nOW`80U9BD0P2ATI4208^;R`80SHf=
0P2:RXX208^;R`80TI6A00<0Shn?08V9R@29RHT01028R8P208>3P`@0PH611022PX8207inOP80OGem
0P22PX8207alO1h0b>3H000L0<SPf080=CDe0P0_;bl202TY:@80;bl_0P0f=SH2038b<P80;Rh^0P0]
;Bd202`/;0@0:RXZ0P0/;2`00`0^;Rh0<30`030`<004030`<080;bl_100^;Rh202XZ:P80;Bd]0P0/
;2`205=CD`80TI6A0P2PX:0207QhN080K6a/0P1ZJVX206e]K@80TY:B0P2j^[X20;Fe]@80ZJVY0P2c
/k<20;jn_P80_kno0P2n_[h20<?3``030<O7a`38b<P0b<S80080_kno0P39bLT2065QH@80<C4a0P0h
>3P20492@P80D51@0P1HF5P2061PH080J6QX0P1_Kfl2079bLP80M7Ad0P1hN7P207]kN`80OWin0P20
P8020861P@80PX:20P26QXH208^;R`80S8b<0P2=SHd00`2@T900U9BD09BDU00209NGU`80VIVI0P2K
Vi/209bLW080WIfM0P2NWYh20:6QX@80YJFU0P2WYjL20:RXZ080YZJV0P2UYJD20:NWY`80ZZZZ0P2/
[:`20:j^[P@0[jn_0P2][Jd20:^[Z`80[:b/0P2][Jd20:b/[0D0Zj^[0P2/[:`20:f][@80Zj^[0P2Z
ZZX40:VYZ@80ZZZZ0P2/[:`40:f][@80[:b/0P2[Zj/20:NWY`80XZ:R0P2NWYh209^KV`80VIVI0P2G
UiL2096AT@80S8b<0P2:RXX208^;R`80Shn?0P2ATI400`2=SHd0R8R808R8R00208J6QP80QHF50P23
Ph<608:2PP80PH610P1oOgl60820P2L0b>3H0P0_;bl202`/;0@0;Bd]0P0f=SH203<c<`@0;Rh^0P0/
;2`202d];@80:2PX0P0`<302034a<@80;2`/0P0d=3@00`0a<C40=cLg03Lg=`0202`/;080:b/[0P0b
<S8202`/;080:BTY0P1BDU8208^;R`80YJFU0P1nOWh206UYJ@80IfMW0P1`L70208b<S080`<300P2b
/[820:^[Z`80]KFe0P2l_;`20;jn_P80_Kfm0P32`/820<K6aP@0bLW90P2k^k/205UIF@80=SHf0P0g
=cL204E5A@80DE5A00<0DU9B065QH@1QHF400P1[Jf/2071`L080LG5a0P1_Kfl207UiN@80OWin0P1j
NWX208B4Q0@0PX:20P2:RXX408^;R`@0SHf=0P2BTY8209NGU`80WIfM0P2JVYX20:6QX@80Vi^K102O
Wil20::RXP@0ZJVY0P2TY:@40:FUY@80ZZZZ00<0[Jf]0:VYZ@2YZJT00P2a/K440:f][@80[:b/0P2[
Zj/20:f][@80Zj^[0P2/[:`20:f][@80Zj^[0P2ZZZX20:b/[080[Jf]0P2XZ:P20:VYZ@80Z:RX102Y
ZJT40;2`/080[Jf]0P2XZ:P20:b/[080X:2P0P2LW9`409ZJVP80UIFE0P2DU9@208f=S@0308R8R02>
SXh0SXj>0080SXj>0P2FUYH208V9R@80Rh^;0P29RHT20820P080Ph>30P22PX840861P@80NWYj0P26
QXH207YjNP80OWin0P27QhLW0<SPf080=SHf0P0b<S8202LW9`80;bl_0P0h>3P203Hf=P80:2PX100]
;Bd202/[:`80:BTY0P0_;bl00`0Y:BT0<c<c03<c<`02030`<080;Rh^0P0b<S8203<c<`80;Rh^0P0[
:b/202d];@80;2`/0P1DE5@209BDU080X:2P0P1iNGT206][J`80JFUY0P1^KVh209:BTP80^[Zj0P2e
]KD20:VYZ@80];Bd0P2m_Kd20;jn_P80_;bl0P33`l<00`38b<P0alO70<O7a`020<30`080a/K60P1P
H60202l_;`80>3Ph0P11@D4204e=C@80E5AD0P1PH60206UYJ@80M7Ad0P1`L70207=cL`80N7Qh0P1n
OWh20861P@80OWin0P1oOgl20820P080QXJ60P27QhL408j>SP03096AT@2FUYH0UYJF0080UiNG0P2I
VIT209bLW080VYZJ102MWId20::RXP80YJFU0P2TY:@20:RXZ0@0YjNW0P2UYJD20:b/[080[Jf]102^
[Zh20;2`/080[Zj^0P2_[jl20:f][@80[Zj^0P2_[jl20:j^[P030:VYZ@2ZZZX0ZZZZ0080[jn_0P2^
[Zh20:ZZZP80YZJV0P2XZ:P20:ZZZP80Zj^[0P2_[jl20:j^[P80[:b/0P2_[jl20:^[Z`80Y:BT0P2S
Xj<20:2PX080UiNG0P2OWil209BDU080TI6A0P2;Rh/208f=S@80RXZ:0P2;Rh/2096AT@0308n?S`29
RHT0RHV900@0R8R80P23Ph<40861P@@0PX:20P1nOWh207emO@80PX:20P1lO7`N0<SPf0007038h=P6
034a<@80=CDe0P0g=cL2038b<P80;2`/0P0];Bd202l_;`80:b/[0P0X:2P202`/;003034a<@0c<c<0
<c<c0080<c<c0P0b<S82030`<0@0<S8b0P0];Bd202TY:@80:b/[0P0f=SH206e]K@80WYjN0P2ATI42
07MgM`80Jf][0P1VIVH208N7Q`80YZJV0P36a/H209jNWP80[Zj^0P2l_;`40;no_`80`<3000<0`L71
0<G5a@35aLD00P35aLD20=3@d080/k>c0P14A4@203/k>`80?Shn0P1ADE4205IFEP80G5aL0P1UIFD2
06e]K@80LG5a0P1eMGD207QhN080O7al0P1mOGd207moO`80P8200P22PX8208R8R080SXj>0P2=SHd2
08b<S003092@T02EUID0UIFE0080UYJF0P2HV9P209^KV`H0WIfM0P2RXZ820:JVYP80Z:RX0P2YZJT2
0:BTY080XJ6Q0P2TY:@20:VYZ@80[:b/1P2_[jl20:b/[080Z:RX0P2VYZH20:FUY@80YZJV0P2WYjL0
0`2XZ:P0ZJVY0:VYZ@020:b/[0@0[jn_0P2^[Zh20:ZZZP@0YZJV0P2WYjL20:VYZ@@0ZZZZ0P2YZJT2
0:JVYP80Y:BT0P2QXJ4209jNWP80VYZJ0P2EUID208j>SP80RHV90P2:RXX208b<S080SXj>0P2?Shl0
0`2;Rh/0QXJ608J6QP0208F5Q@80Q8B41023Ph<208:2PP80PH610P22PX8208>3P`H0PX:29`38h=P2
034a<@80=3@d0P0a<C4203<c<`80=cLg0P0f=SH202h^;P80:b/[0P0`<30202`/;080:2PX0P0_;bl2
038b<P80;bl_0P0e=CD00`0c<c<0;Bd]02d];@0202h^;P@0<C4a100W9bL203Xj>P80Kfm_0P2FUYH2
09^KV`80M7Ad0P1/K6`206UYJ@80PX:20P2/[:`20;jn_P80X:2P0P2c/k<20;Rh^080_kno0P30`<02
0;jn_P80a<C40P33`l<20<O7a`80c<c<0P2`/;0204a<C080>CTi0P13@d<204];B`0305MGE`1OGel0
GemO0080I6AT101`L70207IfMP80O7al0P1jNWX207UiN@H0Ogmo0P2<S8`408^;R`80RXZ:102CTi<2
09JFUP80V9RH0P2GUiL209jNWP80WIfM102OWil20:NWY`80ZZZZ0P2YZJT20:6QX@80Xj>S0P2RXZ82
0:ZZZP030:b/[02^[Zh0[Zj^0080];Bd0P2/[:`20:^[Z`80ZJVY0P2SXj<20:JVYP80YJFU0P2XZ:P2
0:JVYP80ZJVY0P2/[:`40:j^[P80[Jf]0P2/[:`40:RXZ080ZZZZ0P2VYZH20:RXZ080[:b/0P2XZ:P2
0:ZZZP80Xj>S0P2RXZ820:2PX080VIVI0P2DU9@208j>SP80RXZ:00<0R8R808f=S@2=SHd0102=SHd2
08Z:RP80QHF50P23Ph<208N7Q`80PX:20P21PH4208>3P`80Q8B40P1oOgl208F5Q@80P8200P1oOgl2
08V9RBL0b>3H0P0];Bd203<c<`80;bl_0P0g=cL2038b<P80=3@d100/;2`202h^;P80;Bd]0P0T92@2
02d];@03034a<@0c<c<0<c<c0080=3@d0P0b<S82034a<@80<30`0P0b<S82034a<@@0:2PX0P0f=SH2
06a/K080WinO0P2=SHd207MgM`80Jf][0P1WIfL208F5Q@80ZJVY0P31`L420::RXP80ZJVY102o_kl2
0<71`@80_[jn0`33`l<20<K6aP80c/k>0P2d];@204E5A@80?3`l0P0m?Cd205QHF080De=C0P1MGEd2
06QXJ080Jf][0P1`L70207IfMP@0NGUi101mOGd40861P@80Rh^;102<S8`208^;R`0308f=S@2CTi<0
Ti>C0080UYJF0P2IVIT209^KV`80W9bL0P2RXZ8209bLW080WinO0P2YZJT20:RXZ080YjNW0P2VYZH2
09nOW`80Y:BT0P2XZ:P20:f][@@0[jn_102^[Zh20:JVYP80XZ:R0P2UYJD20:BTY0<0YjNW0P2YZJT2
0:b/[080[Jf]0P2^[Zh20;6a/@80[:b/0P2TY:@20:RXZ080YZJV0P2WYjL20:ZZZP@0ZJVY0P2UYJD2
0:BTY080WinO0P2KVi/209jNWP80U9BD0P2<S8`208N7Q`80Shn?0P2;Rh/508j>SP80PX:20P27QhL2
08B4Q080OWin0P26QXH20820P080PH610P23Ph<208F5Q@80Ogmo0P25QHD208:2PQh0b>3H000L0<SP
f0H0<C4a0P0e=CD203Lg=`80<S8b0P0/;2`202d];@80;bl_0P0[:b/202PX:080;2`/00<0<C4a03<c
<`0c<c<00P0c<c<2038b<P80<30`100b<S8202d];@80:BTY0P0[:b/203Hf=P80KFe]0P2NWYh2096A
T@80MgMg0P1[Jf/206IVIP80QhN70P2VYZH20<K6aP80WYjN0P2^[Zh20;bl_0@0_kno0P30`<000`31
`L40aLG50<G5a@020<G5a@80d=3@0P2c/k<204A4A080>c/k0P0n?Sh2055AD@80EUIF0P1LG5`206EU
I@80KFe]0P1aLG4207EeM@80N7Qh0P1lO7`207emO@80Ogmo0P20P80208:2PP80R8R80P2>SXh208f=
S@80S8b<00<0T92@09FEU@2EUID00P2FUYH209RHV080Vi^K1P2MWId20::RXP80YZJV0P2XZ:P20:VY
Z@80Y:BT0P2QXJ420:BTY080ZJVY0P2/[:`60:n_[`80[:b/0P2XZ:P20:JVYP80YJFU0P2VYZH20:NW
Y`030:RXZ02YZJT0ZJVY0080[:b/102_[jl20:j^[P80ZZZZ102VYZH20:NWY`80ZJVY102ZZZX20:VY
Z@80YZJV0P2TY:@20:6QX@80WYjN0P2JVYX209FEU@80SXj>0P29RHT208Z:RP80S8b<0P2>SXh208n?
S`0308^;R`26QXH0QXJ60080QHF50P24Q8@408>3P`80PX:20P21PH4208:2PP80Ph>31P22PX8W0<SP
f080<C4a0P0d=3@2034a<@80<c<c0P0g=cL203Hf=P80;Rh^0P0[:b/2030`<080;2`/0P0X:2P202l_
;`80<S8b0P0_;bl203De=@0303<c<`0];Bd0;Bd]0080;Rh^100a<C4402LW9`80>SXj0P1_Kfl209JF
UP80Vi^K0P1dM7@206a/K080JFUY0P22PX820:b/[080_[jn0P2PX:020;>c/`80^;Rh0P2o_kl20<30
`080_[jn0P34a<@20<?3``80alO70P3<c<`20;2`/080C4a<0P0i>CT204=3@`80Bd];00<0EeMG05mO
G`1OGel00P1TI6@4071`L080MWIf0P1lO7`207YjNP80NGUi1P1oOgl208b<S0@0Rh^;0P2:RXX409>C
T`80UYJF0P2HV9P209NGU`80WYjN0P2MWId409nOW`80YjNW0P2ZZZX20:VYZ@80XJ6Q0P2SXj<20::R
XP80ZZZZ00<0[:b/0:j^[P2^[Zh00P2d];@20:b/[080Zj^[0P2YZJT20:>SX`80YZJV0P2UYJD20:RX
Z080YZJV0P2YZJT20:b/[0@0[Zj^0P2][Jd20:b/[0@0Z:RX0P2ZZZX20:JVYP80Z:RX0P2/[:`20:RX
Z080ZZZZ0P2SXj<20::RXP80X:2P0P2IVIT209BDU080SXj>0P2:RXX00`28R8P0SHf=08f=S@0408f=
S@80RXZ:0P25QHD208>3P`80QhN70P22PX820861P@80Ph>30P24Q8@207moO`80QHF50P20P80207mo
O`80RHV99`38h=P202d];@80<c<c0P0_;bl203Lg=`80<S8b0P0d=3@402`/;080;Rh^0P0];Bd202@T
9080;Bd]00<0<C4a03<c<`0c<c<00P0d=3@2038b<P80<C4a0P0`<302038b<P80<C4a100X:2P203Hf
=P80K6a/0P2OWil208f=S@80MgMg0P1[Jf/206MWI`80QHF50P2YZJT20<71`@80XZ:R0P2YZJT40;no
_`80`L710P2n_[h30<?3``80a/K60P3>c/h20;Bd]080ADE50P0l?3`203dm?@80F5QH0P1CDe<205eM
G@80J6QX0P1[Jf/2071`L080MWIf101iNGT407emO@@0PH610P2;Rh/408b<S080Rh^;00<0SHf=09>C
T`2CTi<00P2FUYH209VIV@80Vi^K0P2LW9`20::RXP80W9bL0P2OWil20:VYZ@80Z:RX0P2WYjL20:JV
YP80WinO0P2TY:@20:RXZ080[Jf]102_[jl40:j^[P80YZJV0P2RXZ820:FUY@80Y:BT0`2WYjL20:VY
Z@80[:b/0P2][Jd20:j^[P80/K6a0P2/[:`20:BTY080Z:RX0P2VYZH20:NWY`80ZZZZ102YZJT20:FU
Y@80Y:BT0P2OWil209^KV`80WYjN0P2DU9@208b<S080QhN70P2?Shl208^;R`D0SXj>0P22PX8208N7
Q`80Q8B40P1nOWh208J6QP80P8200P21PH4208>3P`80QHF50P1oOgl208F5Q@80PX:27P38h=P001`0
b>3H0P0_;bl2030`<080<C4a100c<c<2030`<0@0;2`/0P0];Bd202/[:`80:RXZ0P0^;Rh00`0c<c<0
=3@d03@d=00203<c<`80<S8b0P0a<C42038b<P80<c<c0P0^;Rh402XZ:P80<C4a0P1:BTX208N7Q`80
X:2P0P28R8P2065QH@80I6AT0P1fMWH208n?S`80/K6a0P2YZJT20:n_[`80][Jf0P2j^[X20;fm_@80
_kno00<0`<300<G5a@35aLD00P37alL20=CDe080^[Zj0P2WYjL2051@D080<S8b0P16ATH2055AD@80
G5aL0P1UIFD206a/K080LG5a0P1dM7@207IfMP80NGUi0P1lO7`207moO`80PX:20P25QHD208R8R080
RXZ:0P2<S8`208f=S@03096AT@2EUID0UIFE0080UiNG0P2HV9P209^KV`@0WYjN0P2OWil20::RXP80
YZJV0P2WYjL20:RXZ080Y:BT0P2QXJ420:BTY080ZJVY0P2/[:`20:n_[`80[Zj^0P2/[:`20:VYZ@P0
YZJV0`2WYjL20:RXZ080[:b/0P2`/;020:n_[`80[Jf]0P2/[:`20:^[Z`80ZJVY0P2XZ:P40:NWY`80
ZJVY0P2[Zj/20:RXZ080YJFU0P2TY:@20:>SX`80W9bL0P2DU9@208j>SP@0RXZ:0P2;Rh/208j>SP80
TI6A00<0SHf=08R8R028R8P00P27QhL208J6QP80Q8B40P23Ph<208:2PP@0PH612022PX8W0<SPf080
<c<c100`<30203<c<`80=3@d0P0a<C4202HV9P@0:b/[0P0/;2`202PX:080;2`/0P0a<C4203De=@80
<C4a00<0=SHf03De=@0e=CD00P0b<S8203@d=080=CDe0P0Z:RX202h^;P80;2`/0P1@D50208:2PP80
Xj>S0P1oOgl206MWI`80IFEU0P1^KVh208j>SP80^KVi0P2SXj<20;6a/@80][Jf0P2l_;`20;^k^`80
_Kfm0P30`<020<;2`P80b<S8103<c<`20:BTY080@4100P0o?cl204M7A`03055AD@1LG5`0G5aL0080
GemO0P1/K6`2071`L080M7Ad0P1hN7P207]kN`80O7al0P23Ph<207emO@80QXJ60P2=SHd208V9R@80
S8b<0P2>SXh209FEU@80UYJF1P2HV9P209fMW@80WinO0P2PX:0209jNWP80Z:RX0P2YZJT20:NWY`80
Xj>S0P2UYJD20::RXP80ZZZZ0`2/[:`20;:b/P80Zj^[0P2YZJT20:RXZ080Xj>S0P2VYZH20:ZZZP80
Y:BT0P2WYjL20:RXZ080[Zj^0P2a/K420;2`/080[Zj^0P2/[:`20:FUY@80ZJVY1P2VYZH40:NWY`80
YZJV0P2QXJ420:JVYP80Vi^K0P2OWil209FEU@80SHf=0P28R8P00`29RHT0Rh^;08^;R`0208j>SP80
TY:B0P2@T90208Z:RP80QXJ60P27QhL208F5Q@80Q8B40P26QXH207moO`80PX:21021PH4208B4Q080
R8R89`38h=P2030`<080;Bd]0P0a<C4403De=@80;bl_0P0];Bd202/[:`80;2`/100[:b/2030`<003
038b<P0a<C40<C4a0080<c<c0P0a<C4802l_;`80:b/[0P0Y:BT2038b<P80CDe=0P2:RXX209jNWP80
S8b<0P1OGel206ATI080M7Ad0P2ATI420;2`/080[:b/0P2`/;020;Jf]P80^[Zj0P2n_[h20;no_`03
0<30`032`/80`/;20080b<S80P3Fe]H20;Zj^P80YZJV0P1?Cdl2038b<P80@d=30P1?Cdl205eMG@80
IFEU0P1[Jf/206m_K`80MGEe0P1gMgL207UiN@80Ogmo0P20P80208>3P`80QXJ6102<S8`208n?S`80
S8b<00<0Ti>C09NGU`2GUiL00P2FUYH209RHV080VIVI0P2KVi/20:>SX`80WYjN0P2PX:040:JVYP80
[:b/0P2UYJD20:2PX080YZJV0P2XZ:P20:^[Z`80/K6a0P2[Zj/20:ZZZP80Zj^[0P2UYJD20:RXZ080
YjNW0P2VYZH20:NWY`<0ZJVY0P2^[Zh20;6a/@80[Jf]0P2/[:`20:f][@80ZJVY0P2/[:`20:JVYP80
Y:BT0P2YZJT20:ZZZP80[:b/0P2YZJT20:BTY080YjNW0P2UYJD209bLW080Ti>C0P2=SHd208N7Q`80
SHf=102;Rh/2096AT@0308n?S`27QhL0QhN70080R8R80P24Q8@408F5Q@80PH610P20P80208>3P`80
PX:20P20P80208>3P`80PX:27P38h=P001`0b>3H0P0_;bl2030`<080<C4a100c<c<2030`<0@0;2`/
0P0];Bd202/[:`80:RXZ0P0^;Rh00`0c<c<0=3@d03@d=00203<c<`80<S8b0P0a<C42038b<P80<c<c
0P0^;Rh402XZ:P80<C4a0P1:BTX208N7Q`80X:2P0P28R8P2065QH@80I6AT0P1fMWH208n?S`80/K6a
0P2YZJT20:n_[`80][Jf0P2j^[X20;fm_@80_kno00<0`<300<G5a@35aLD00P37alL20=CDe080^[Zj
0P2WYjL2051@D080<S8b0P16ATH2055AD@80G5aL0P1UIFD206a/K080LG5a0P1dM7@207IfMP80NGUi
0P1lO7`207moO`80PX:20P25QHD208R8R080RXZ:0P2<S8`208f=S@03096AT@2EUID0UIFE0080UiNG
0P2HV9P209^KV`@0WYjN0P2OWil20::RXP80YZJV0P2WYjL20:RXZ080Y:BT0P2QXJ420:BTY080ZJVY
0P2/[:`20:n_[`80[Zj^0P2/[:`20:VYZ@P0YZJV0`2WYjL20:RXZ080[:b/0P2`/;020:n_[`80[Jf]
0P2/[:`20:^[Z`80ZJVY0P2XZ:P40:NWY`80ZJVY0P2[Zj/20:RXZ080YJFU0P2TY:@20:>SX`80W9bL
0P2DU9@208j>SP@0RXZ:0P2;Rh/208j>SP80TI6A00<0SHf=08R8R028R8P00P27QhL208J6QP80Q8B4
0P23Ph<208:2PP@0PH612022PX8W0<SPf080<c<c100`<30203<c<`80=3@d0P0a<C4202HV9P@0:b/[
0P0/;2`202PX:080;2`/0P0a<C4203De=@80<C4a00<0=SHf03De=@0e=CD00P0b<S8203@d=080=CDe
0P0Z:RX202h^;P80;2`/0P1@D50208:2PP80Xj>S0P1oOgl206MWI`80IFEU0P1^KVh208j>SP80^KVi
0P2SXj<20;6a/@80][Jf0P2l_;`20;^k^`80_Kfm0P30`<020<;2`P80b<S8103<c<`20:BTY080@410
0P0o?cl204M7A`03055AD@1LG5`0G5aL0080GemO0P1/K6`2071`L080M7Ad0P1hN7P207]kN`80O7al
0P23Ph<207emO@80QXJ60P2=SHd208V9R@80S8b<0P2>SXh209FEU@80UYJF1P2HV9P209fMW@80WinO
0P2PX:0209jNWP80Z:RX0P2YZJT20:NWY`80Xj>S0P2UYJD20::RXP80ZZZZ0`2/[:`20;:b/P80Zj^[
0P2YZJT20:RXZ080Xj>S0P2VYZH20:ZZZP80Y:BT0P2WYjL20:RXZ080[Zj^0P2a/K420;2`/080[Zj^
0P2/[:`20:FUY@80ZJVY1P2VYZH40:NWY`80YZJV0P2QXJ420:JVYP80Vi^K0P2OWil209FEU@80SHf=
0P28R8P00`29RHT0Rh^;08^;R`0208j>SP80TY:B0P2@T90208Z:RP80QXJ60P27QhL208F5Q@80Q8B4
0P26QXH207moO`80PX:21021PH4208B4Q080R8R89`38h=P2030`<080;Bd]0P0a<C4403De=@80;bl_
0P0];Bd202/[:`80;2`/100[:b/2030`<003038b<P0a<C40<C4a0080<c<c0P0a<C4802l_;`80:b/[
0P0Y:BT2038b<P80CDe=0P2:RXX209jNWP80S8b<0P1OGel206ATI080M7Ad0P2ATI420;2`/080[:b/
0P2`/;020;Jf]P80^[Zj0P2n_[h20;no_`030<30`032`/80`/;20080b<S80P3Fe]H20;Zj^P80YZJV
0P1?Cdl2038b<P80@d=30P1?Cdl205eMG@80IFEU0P1[Jf/206m_K`80MGEe0P1gMgL207UiN@80Ogmo
0P20P80208>3P`80QXJ6102<S8`208n?S`80S8b<00<0Ti>C09NGU`2GUiL00P2FUYH209RHV080VIVI
0P2KVi/20:>SX`80WYjN0P2PX:040:JVYP80[:b/0P2UYJD20:2PX080YZJV0P2XZ:P20:^[Z`80/K6a
0P2[Zj/20:ZZZP80Zj^[0P2UYJD20:RXZ080YjNW0P2VYZH20:NWY`<0ZJVY0P2^[Zh20;6a/@80[Jf]
0P2/[:`20:f][@80ZJVY0P2/[:`20:JVYP80Y:BT0P2YZJT20:ZZZP80[:b/0P2YZJT20:BTY080YjNW
0P2UYJD209bLW080Ti>C0P2=SHd208N7Q`80SHf=102;Rh/2096AT@0308n?S`27QhL0QhN70080R8R8
0P24Q8@408F5Q@80PH610P20P80208>3P`80PX:20P20P80208>3P`80PX:27P38h=P001`0b>3H1P0^
;Rh402l_;`80;Rh^0P0/;2`202/[:`80:RXZ0P0[:b/202d];@80<C4a00<0=CDe03@d=00d=3@00P0c
<c<8038b<P80;Rh^0P0/;2`202XZ:P80<S8b0P0/;2`206UYJ@80XZ:R0P2FUYH205mOG`80IVIV0P1X
J6P207UiN@80UYJF0P2e]KD20;>c/`80[jn_0P2d];@20;Zj^P80_Kfm00<0`<300<?3``33`l<00P37
alL40=;BdP80aLG50P2<S8`203lo?`80@4100P18B4P205aLG080I6AT0P1ZJVX206m_K`80Lg=c0P1d
M7@207EeM@80NWYj0P1oOgl208B4Q080R8R80P27QhL208J6QP80RXZ:0P2@T9000`2CTi<0UYJF09JF
UP0209NGU`80V9RH0P2KVi/209jNWP@0WinO0P2RXZ820:FUY@@0YZJV0P2TY:@20::RXP80Y:BT0P2W
YjL20:ZZZP80[Jf]0P2ZZZX20:NWY`80Y:BT0P2SXj<20:FUY@80Z:RX0P2VYZH30:FUY@80YjNW0P2[
Zj/20:n_[`80[:b/0P2YZJT20:b/[080[jn_0P2][Jd20:VYZ@80YZJV0P2UYJD20:VYZ@80[Jf]0P2Y
ZJT20:FUY@@0YjNW0P2NWYh209>CT`80SXj>0P2;Rh/408V9R@80SHf=0P2ATI400`2?Shl0Rh^;08^;
R`0208V9R@80R8R80P25QHD208>3P`@0PX:20P21PH420820P080PH611022PX8W0<SPf080<S8b0P0[
:b/202l_;`80<S8b0P0`<30202`/;080<30`0P0^;Rh202LW9`80<30`0P0^;Rh2034a<@80<S8b0P0o
?cl7030`<080<c<c0P0[:b/402XZ:P80;2`/0P0h>3P206][J`80TY:B0P2EUID206m_K`80HV9R0P1T
I6@207EeM@80XZ:R0P2e]KD20:ZZZP80/[:b0P2e]KD20;Zj^P@0_Kfm0P36a/H20<W9b@80clo?0P3>
c/h20<O7a`80RXZ:1010@4000`1=CDd0FEUI05UIF@02065QH@80JVYZ101aLG4207EeM@80MWIf0P1g
MgL207emO@80QHF50P26QXH208V9R@80QHF50P2:RXX208f=S@80UiNG0P2DU9@209NGU`80UYJF0P2L
W9`20:6QX@80V9RH0P2QXJ420::RXP80Y:BT0P2WYjL20:BTY080YZJV0P2PX:020:BTY080YjNW00<0
ZZZZ0:f][@2][Jd00P2/[:`40:JVYP80X:2P0P2UYJD20:NWY`80YJFU0P2XZ:P20:>SX`80YjNW0P2Y
ZJT20:^[Z`80[Jf]102YZJT20;6a/@80[Zj^0P2YZJT20:BTY080YZJV0P2/[:`20;2`/080Y:BT0P2V
YZH20:j^[P80YJFU0P2NWYh209>CT`80S8b<0P2>SXh308R8R080T92@0P2?Shl208j>SP80Rh^;0P26
QXH208V9R@80QXJ61021PH4208>3P`80PH610P22PX820820P080Ogmo0P2;Rh/W0<SPf080;bl_0P0^
;Rh2034a<@80;Bd]0P0_;bl402`/;080:RXZ0P0Y:BT202XZ:P80;Bd]0P0^;Rh00`0f=SH0=CDe03De
=@0203De=@80<c<c0P0e=CD202l_;`@0<c<c0P0Y:BT202HV9P80<C4a0P0[:b/206UYJ@80WIfM0P2G
UiL205eMG@@0J6QX0P1iNGT209>CT`80]KFe0P2c/k<20;2`/080/k>c102k^k/00`31`L40a/K60<K6
aP020<K6aP80dm?C0P3@d=020<?3``80SXj>1010@40204a<C080FUYJ0P1TI6@206YZJP80KVi^0P1b
LW8407AdM080OGem0P1oOgl208:2PP80RXZ:0P27QhL208J6QP80SHf=0P2>SXh00`2CTi<0UYJF09JF
UP0209NGU`80VYZJ0P2GUiL20:2PX0@0WinO0P2TY:@20:FUY@80Y:BT0P2WYjL20:6QX@80XZ:R0P2X
Z:P20:FUY@80ZJVY0P2^[Zh20:^[Z`80Z:RX0P2VYZH209nOW`@0YZJV0P2WYjL20::RXP030:VYZ@2U
YJD0YJFU0080ZZZZ0P2^[Zh20:RXZ080ZJVY0P2b/[820:j^[P80Zj^[0P2/[:`20:BTY080YZJV0P2Z
ZZX20:j^[P80Z:RX0P2UYJD20:JVYP80YjNW0P2LW9`209BDU080TY:B0P2<S8`208Z:RP80RHV90P2;
Rh/209>CT`03092@T02=SHd0SHf=0080QXJ60P28R8P208J6QP80Ph>30P1oOgl208:2PP80Q8B40P1n
OWh208F5Q@@0PH617P38h=P001`0b>3H1P0^;Rh402l_;`80;Rh^0P0/;2`202/[:`80:RXZ0P0[:b/2
02d];@80<C4a00<0=CDe03@d=00d=3@00P0c<c<8038b<P80;Rh^0P0/;2`202XZ:P80<S8b0P0/;2`2
06UYJ@80XZ:R0P2FUYH205mOG`80IVIV0P1XJ6P207UiN@80UYJF0P2e]KD20;>c/`80[jn_0P2d];@2
0;Zj^P80_Kfm00<0`<300<?3``33`l<00P37alL40=;BdP80aLG50P2<S8`203lo?`80@4100P18B4P2
05aLG080I6AT0P1ZJVX206m_K`80Lg=c0P1dM7@207EeM@80NWYj0P1oOgl208B4Q080R8R80P27QhL2
08J6QP80RXZ:0P2@T9000`2CTi<0UYJF09JFUP0209NGU`80V9RH0P2KVi/209jNWP@0WinO0P2RXZ82
0:FUY@@0YZJV0P2TY:@20::RXP80Y:BT0P2WYjL20:ZZZP80[Jf]0P2ZZZX20:NWY`80Y:BT0P2SXj<2
0:FUY@80Z:RX0P2VYZH30:FUY@80YjNW0P2[Zj/20:n_[`80[:b/0P2YZJT20:b/[080[jn_0P2][Jd2
0:VYZ@80YZJV0P2UYJD20:VYZ@80[Jf]0P2YZJT20:FUY@@0YjNW0P2NWYh209>CT`80SXj>0P2;Rh/4
08V9R@80SHf=0P2ATI400`2?Shl0Rh^;08^;R`0208V9R@80R8R80P25QHD208>3P`@0PX:20P21PH42
0820P080PH611022PX8W0<SPf080<S8b0P0[:b/202l_;`80<S8b0P0`<30202`/;080<30`0P0^;Rh2
02LW9`80<30`0P0^;Rh2034a<@80<S8b0P0o?cl7030`<080<c<c0P0[:b/402XZ:P80;2`/0P0h>3P2
06][J`80TY:B0P2EUID206m_K`80HV9R0P1TI6@207EeM@80XZ:R0P2e]KD20:ZZZP80/[:b0P2e]KD2
0;Zj^P@0_Kfm0P36a/H20<W9b@80clo?0P3>c/h20<O7a`80RXZ:1010@4000`1=CDd0FEUI05UIF@02
065QH@80JVYZ101aLG4207EeM@80MWIf0P1gMgL207emO@80QHF50P26QXH208V9R@80QHF50P2:RXX2
08f=S@80UiNG0P2DU9@209NGU`80UYJF0P2LW9`20:6QX@80V9RH0P2QXJ420::RXP80Y:BT0P2WYjL2
0:BTY080YZJV0P2PX:020:BTY080YjNW00<0ZZZZ0:f][@2][Jd00P2/[:`40:JVYP80X:2P0P2UYJD2
0:NWY`80YJFU0P2XZ:P20:>SX`80YjNW0P2YZJT20:^[Z`80[Jf]102YZJT20;6a/@80[Zj^0P2YZJT2
0:BTY080YZJV0P2/[:`20;2`/080Y:BT0P2VYZH20:j^[P80YJFU0P2NWYh209>CT`80S8b<0P2>SXh3
08R8R080T92@0P2?Shl208j>SP80Rh^;0P26QXH208V9R@80QXJ61021PH4208>3P`80PH610P22PX82
0820P080Ogmo0P2;Rh/W0<SPf080;bl_0P0^;Rh2034a<@80;Bd]0P0_;bl402`/;080:RXZ0P0Y:BT2
02XZ:P80;Bd]0P0^;Rh00`0f=SH0=CDe03De=@0203De=@80<c<c0P0e=CD202l_;`@0<c<c0P0Y:BT2
02HV9P80<C4a0P0[:b/206UYJ@80WIfM0P2GUiL205eMG@@0J6QX0P1iNGT209>CT`80]KFe0P2c/k<2
0;2`/080/k>c102k^k/00`31`L40a/K60<K6aP020<K6aP80dm?C0P3@d=020<?3``80SXj>1010@402
04a<C080FUYJ0P1TI6@206YZJP80KVi^0P1bLW8407AdM080OGem0P1oOgl208:2PP80RXZ:0P27QhL2
08J6QP80SHf=0P2>SXh00`2CTi<0UYJF09JFUP0209NGU`80VYZJ0P2GUiL20:2PX0@0WinO0P2TY:@2
0:FUY@80Y:BT0P2WYjL20:6QX@80XZ:R0P2XZ:P20:FUY@80ZJVY0P2^[Zh20:^[Z`80Z:RX0P2VYZH2
09nOW`@0YZJV0P2WYjL20::RXP030:VYZ@2UYJD0YJFU0080ZZZZ0P2^[Zh20:RXZ080ZJVY0P2b/[82
0:j^[P80Zj^[0P2/[:`20:BTY080YZJV0P2ZZZX20:j^[P80Z:RX0P2UYJD20:JVYP80YjNW0P2LW9`2
09BDU080TY:B0P2<S8`208Z:RP80RHV90P2;Rh/209>CT`03092@T02=SHd0SHf=0080QXJ60P28R8P2
08J6QP80Ph>30P1oOgl208:2PP80Q8B40P1nOWh208F5Q@@0PH617P38h=P001`0b>3H0P0_;bl202d]
;@80:b/[0P0];Bd402h^;P80;Bd]0P0[:b/402XZ:P80;2`/0P0b<S800`0f=SH0=3@d03@d=002034a
<@@0<30`100a<C4202`/;0809bLW0P0U9BD202XZ:P809RHV0P19BDT208N7Q`80UYJF0P25QHD206][
J`80IFEU0P1[Jf/208Z:RP80[:b/0P2o_kl20:ZZZP80/[:b0P2g]kL20;Vi^@030;^k^`2o_kl0_kno
0080aLG50P3<c<`20<o?c`80eMGE0P2a/K4207moO`80DE5A0P0k>c/205ADE080FUYJ0P1WIfL206a/
K080L71`0P1bLW8207AdM080N7Qh0P1mOGd208>3P`80R8R80P27QhL208J6QP80Rh^;0P2@T9000`2D
U9@0UiNG09NGU`0209RHV080VIVI0P2JVYX209^KV`80W9bL0P2MWId20:2PX080XZ:R1P2SXj<40::R
XPH0Xj>S0P2PX:0209fMW@@0W9bL0P2OWil20:6QX@80X:2P0P2OWil00`2PX:00XZ:R0::RXP020:FU
Y@80Z:RX0P2VYZH20:FUY@80Z:RX102/[:`20:^[Z`80Z:RX0P2VYZH20:RXZ080ZJVY0P2VYZH20:>S
X`80YZJV0P2XZ:P20:2PX080UiNG0P2@T90208Z:RP80QXJ60P25QHD208R8R080S8b<00<0SHf=08b<
S02<S8`00P2:RXX208N7Q`80Ph>30P20P8020861P@80PX:20P21PH420820P080PX:21025QHDW0<SP
f0@0;2`/0P0];Bd202l_;`80;Bd]0P0W9bL202`/;080<C4a0P0X:2P202/[:`80:BTY0P0`<30203Hf
=P80=cLg0P0];Bd00`0c<c<0<S8b038b<P02034a<@@0<30`0P0V9RH202LW9`80:2PX0P0];Bd204M7
A`80PX:20P2NWYh208B4Q080JFUY0P1UIFD206][J`80QhN70P2d];@20:f][@80/K6a0P2d];@20;Jf
]P@0^k^k1033`l<20<[:bP80clo?0P3=cLd20<71`@80PH610P0o?cl00`15ADD0E5AD05ADE002061P
H080IVIV0P1aLG42071`L080Kfm_0P1bLW8207QhN080Ogmo0P27QhL208J6QP80QhN70P23Ph<208j>
SP80S8b<0P2FUYH209BDU080UiNG1P2LW9`209^KV`80WinO0P2TY:@40:6QX@80XZ:R0P2TY:@209jN
WP80YZJV0`2QXJ420:>SX`80WinO0P2JVYX209nOW`80Vi^K102RXZ8209fMW@80WYjN0P2OWil20:JV
YP80Y:BT0P2[Zj/20:ZZZP80Xj>S0P2VYZH20;6a/@80[:b/0P2^[Zh20:FUY@80XZ:R102/[:`20:2P
X080XZ:R0P2ZZZX40:BTY080UIFE0P2<S8`208f=S@<0QHF50P28R8P208Z:RP80Shn?0P2>SXh408R8
R0@0PX:20P1nOWh208B4Q0@0Ogmo0P20P80207emO@80S8b<9`38h=P2034a<@80:2PX0P0[:b/202`/
;080<30`0P0Z:RX2034a<@80;2`/0P0[:b/202h^;P80:b/[0P0a<C400`0i>CT0<c<c03<c<`02030`
<080:b/[0P0`<30203De=@80<30`0P0/;2`202TY:@809BDU0P0/;2`202PX:080Bd];0P25QHD209NG
U`80QHF50P1/K6`206IVIP80Jf][0P29RHT20:b/[080_[jn0P2ZZZX20;2`/080^;Rh0P2i^KT00`2h
^;P0`<300<30`0020<30`080cLg=0P3EeMD20=3@d080];Bd0P1nOWh2055AD@80>SXj0P1DE5@205aL
G080JFUY0P1/K6`4075aL@80L71`101jNWX207moO`80QHF50P27QhL208:2PP80QXJ60P2ATI4309FE
U@80V9RH2P2KVi/20:2PX080Y:BT102SXj<209nOW`80Xj>S0P2UYJD20:>SX`80XZ:R0P2SXj<209jN
WP80WIfM0P2OWil20:2PX080WYjN0P2PX:0209nOW`80WIfM00<0XJ6Q0:2PX02PX:000P2UYJD20:^[
Z`80YZJV0P2UYJD20:RXZ0H0[:b/102UYJD20:BTY080Z:RX0P2TY:@20:JVYP80Xj>S0P2XZ:P209nO
W`80Ti>C0P2@T90208J6QP80Q8B40P27QhL208Z:RP80Rh^;00<0SHf=08^;R`2;Rh/0102:RXX208>3
P`@0P8200P23Ph<20820P080OGem1023Ph<208J6QQh0b>3H000L0<SPf080;bl_0P0];Bd202/[:`80
;Bd]100^;Rh202d];@80:b/[100Z:RX202`/;080<S8b00<0=SHf03@d=00d=3@00P0a<C44030`<0@0
<C4a0P0/;2`202LW9`809BDU0P0Z:RX202HV9P80BDU90P27QhL209JFUP80QHF50P1[Jf/206EUI@80
Jf][0P2:RXX20:b/[080_kno0P2ZZZX20;:b/P80]kNg0P2i^KT00`2k^k/0_kno0;no_`020<G5a@80
c<c<0P3?cll20=GEe@80/K6a0P1oOgl2055AD@80>c/k0P1DE5@205YJFP80IfMW0P1/K6`2071`L080
LW9b0P1dM7@207QhN080OGem0P23Ph<208R8R080QhN70P26QXH208^;R`80T92@00<0U9BD09NGU`2G
UiL00P2HV9P209VIV@80VYZJ0P2KVi/209bLW080WIfM0P2PX:020::RXPH0Xj>S102RXZ860:>SX`80
X:2P0P2MWId409bLW080WinO0P2QXJ420:2PX080WinO00<0X:2P0::RXP2RXZ800P2UYJD20:RXZ080
YZJV0P2UYJD20:RXZ0@0[:b/0P2[Zj/20:RXZ080YZJV0P2XZ:P20:VYZ@80YZJV0P2SXj<20:JVYP80
Z:RX0P2PX:0209NGU`80T92@0P2:RXX208J6QP80QHF50P28R8P208b<S00308f=S@2<S8`0S8b<0080
RXZ:0P27QhL208>3P`80P8200P21PH4208:2PP80PH610P20P80208:2PP@0QHF59`38h=P402`/;080
;Bd]0P0_;bl202d];@809bLW0P0/;2`2034a<@80:2PX0P0[:b/202TY:@80<30`0P0f=SH203Lg=`80
;Bd]00<0<c<c038b<P0b<S800P0a<C44030`<0809RHV0P0W9bL202PX:080;Bd]0P17AdL208:2PP80
WYjN0P24Q8@206UYJ@80IFEU0P1[Jf/208N7Q`80];Bd0P2][Jd20;6a/@80];Bd0P2f][H40;^k^`@0
`l?30P3:b/X20<o?c`80cLg=0P31`L420861P@80?clo00<0ADE505ADE01DE5@00P1PH60206IVIP80
LG5a0P1`L70206m_K`80LW9b0P1hN7P207moO`80QhN70P26QXH208N7Q`80Ph>30P2>SXh208b<S080
UYJF0P2DU9@209NGU`H0W9bL0P2KVi/209nOW`80Y:BT102QXJ420::RXP80Y:BT0P2NWYh20:JVYP<0
XJ6Q0P2SXj<209nOW`80VYZJ0P2OWil209^KV`@0XZ:R0P2MWId209jNWP80WinO0P2VYZH20:BTY080
Zj^[0P2ZZZX20:>SX`80YZJV0P2a/K420:b/[080[Zj^0P2UYJD20::RXP@0[:b/0P2PX:020::RXP80
ZZZZ102TY:@209FEU@80S8b<0P2=SHd308F5Q@80R8R80P2:RXX208n?S`80SXj>1028R8P408:2PP80
OWin0P24Q8@407moO`80P8200P1mOGd208b<S2L0b>3H0P0a<C4202PX:080:b/[0P0/;2`2030`<080
:RXZ0P0a<C4202`/;080:b/[0P0^;Rh202/[:`80<C4a00<0>CTi03<c<`0c<c<00P0`<30202/[:`80
<30`0P0e=CD2030`<080;2`/0P0Y:BT202DU9@80;2`/0P0X:2P204];B`80QHF50P2GUiL208F5Q@80
K6a/0P1VIVH206][J`80RHV90P2/[:`20;jn_P80ZZZZ0P2`/;020;Rh^080^KVi00<0^;Rh0<30`030
`<000P30`<020<g=c@80eMGE0P3@d=020;Bd]080OWin0P1ADE4203Xj>P80E5AD0P1LG5`206UYJ@80
K6a/101aLG42071`L0@0NWYj0P1oOgl208F5Q@80QhN70P22PX8208J6QP80TI6A0`2EUID209RHV0X0
Vi^K0P2PX:020:BTY0@0Xj>S0P2OWil20:>SX`80YJFU0P2SXj<20::RXP80Xj>S0P2NWYh209fMW@80
WinO0P2PX:0209jNWP80X:2P0P2OWil209fMW@030:6QX@2PX:00X:2P0080YJFU0P2[Zj/20:JVYP80
YJFU0P2XZ:P60:b/[0@0YJFU0P2TY:@20:RXZ080Y:BT0P2VYZH20:>SX`80Z:RX0P2OWil209>CT`80
T92@0P26QXH208B4Q080QhN70P2:RXX208^;R`0308f=S@2;Rh/0Rh^;00@0RXZ:0P23Ph<40820P080
Ph>30P20P80207emO@@0Ph>30P26QXHN0<SPf0007038h=P202l_;`80;2`/0P0Z:RX202`/;0H0;Rh^
0P0/;2`402/[:`80;2`/0P0b<S800`0f=SH0<c<c03<c<`0202l_;`80;Rh^0P0];Bd202l_;`80<30`
0P0Y:BT202<S8`808R8R0P0T92@202HV9P80;Rh^0P1RHV8208j>SP80ZJVY0P1dM7@206UYJ@80Hf=S
0P21PH4209jNWP80alO70P2YZJT20;2`/080/[:b0P2d];@00`2f][H0^k^k0;^k^`020<30`080aLG5
0P38b<P20=;BdP80c/k>0P31`L4206m_K`80>CTi0P1>CTh205=CD`80HV9R0P1WIfL206a/K080L71`
0P1dM7@207MgM`80Ng]k0P21PH4208J6QP@0QhN70P2<S8`2096AT@0309FEU@2HV9P0V9RH00@0VIVI
0P2HV9P209NGU`80V9RH0P2JVYX209fMW@80WinO102PX:040:6QX@80WinO0P2MWId209^KV`80VIVI
0P2FUYH209>CT`80U9BD0P2FUYH609RHV080UiNG00<0VIVI09bLW02LW9`00P2NWYh209nOW`@0X:2P
0P2SXj<20:FUY@80Z:RX0P2ZZZX20:VYZ@80YjNW0P2VYZH20:FUY@80XZ:R0P2PX:020:BTY080YjNW
0P2SXj<209bLW080TI6A0P28R8P208>3P`80PH610P23Ph<208J6QP0308Z:RP2<S8`0S8b<0080RXZ:
0P27QhL20861P@80OGem0P20P80208>3P`80PH610P20P80208>3P`80QhN70P28R8PW0<SPf080<30`
0P0];Bd202TY:@80;2`/100^;Rh202d];@80;2`/0P0[:b/202l_;`80:BTY0P0d=3@203De=@@0;bl_
00<0<S8b02XZ:P0Z:RX00P0_;bl2038b<P80:BTY0P0U9BD2024Q8@809BDU0P0S8b<2030`<080IVIV
0P2?Shl209nOW`80O7al0P1TI6@206QXJ080Ng]k0P2TY:@20;^k^`80[:b/0P2f][H20;6a/@80/k>c
0P2g]kL20;Zj^P80`<300P36a/H20<_;b`80c<c<0P3>c/h20;^k^`80L71`00<0?3`l04i>CP1>CTh0
0P1EEED205iNGP80IFEU0P1^KVh2071`L080MWIf0P1hN7P207UiN@80PX:21027QhL208J6QP80SHf=
0P2>SXh209RHV080UYJF0P2IVIT209NGU`80VYZJ102GUiL209ZJVP80Vi^K0P2PX:020:>SX`80WYjN
0P2SXj<209nOW`80X:2P0P2LW9`309ZJVP80UiNG0P2DU9@409JFUP80V9RH0P2KVi/209JFUP80VIVI
0P2NWYh209^KV`@0W9bL0P2UYJD20:2PX080XZ:R0P2TY:@20:FUY@80YjNW0P2ZZZX20:FUY@80YjNW
0P2UYJD20::RXP80WinO0P2VYZH20:>SX`80YjNW0P2LW9`208j>SP80Rh^;00<0PX:207moO`1oOgl0
0P24Q8@208J6QP80Rh^;0P2<S8`208N7Q`80RHV90P20P80207inOP80P8200P24Q8@408:2PP80Ph>3
0P27QhL208f=SBL0b>3H0P0`<30202h^;P80:b/[0P0/;2`202d];@@0;2`/0P0^;Rh602XZ:P80=3@d
00<0=cLg03<c<`0c<c<00P0a<C4402h^;P80;bl_0P0c<c<202LW9`8092@T0P0Q8B4202<S8`809RHV
0P0_;bl2065QH@80Shn?0P2WYjL207=cL`80Jf][0P1RHV8207inOP80WYjN0P36a/H20:b/[080[jn_
0P2d];@20;Fe]@030;Jf]P2i^KT0^KVi0080`<300P38b<P20<[:bP80c/k>0P3Cdm<20<30`080KVi^
0P0i>CT204i>CP80E5AD0P1UIFD206ATI080KFe]0P1_Kfl207IfMP80MgMg0P1lO7`20861P@80QhN7
0P2<S8`208Z:RP80QXJ60P2CTi<00`2HV9P0VIVI09VIV@0209ZJVP80VIVI0P2GUiL209RHV080U9BD
0P2MWId209bLW080WinO0P2QXJ420:>SX`80WYjN0P2RXZ820:6QX@80Vi^K0P2MWId209RHV080UYJF
102CTi<409JFUP80VIVI0P2FUYH309RHV080WIfM0P2NWYh209nOW`80X:2P0P2QXJ4209jNWP80YZJV
0P2[Zj/20:ZZZP80Z:RX0P2VYZH20:VYZ@80YjNW0P2PX:020:6QX@80XZ:R0P2WYjL20:BTY080W9bL
0P2DU9@208Z:RP@0P8200P25QHD208B4Q00308Z:RP2<S8`0S8b<00@0R8R80P1kNg/207moO`80PH61
0P24Q8@207moO`80PX:20P27QhL208F5Q@80QhN77P38h=P001`0b>3H0P0_;bl202`/;080:RXZ0P0/
;2`602h^;P80;2`/100[:b/202`/;080<S8b00<0=SHf03<c<`0c<c<00P0_;bl202h^;P80;Bd]0P0_
;bl2030`<080:BTY0P0S8b<2028R8P8092@T0P0V9RH202h^;P80HV9R0P2>SXh20:VYZ@80M7Ad0P1Y
JFT206=SH`80PH610P2NWYh20<O7a`80ZJVY0P2`/;020;:b/P80];Bd00<0][Jf0;^k^`2k^k/00P30
`<020<G5a@80b<S80P3Bd]820<k>cP80`L710P1_Kfl203Ti>@80CTi>0P1CDe<2069RHP80IfMW0P1/
K6`2071`L080M7Ad0P1gMgL207]kN`80PH610P26QXH408N7Q`80S8b<0P2ATI400`2EUID0V9RH09RH
V00409VIV@80V9RH0P2GUiL209RHV080VYZJ0P2MWId209nOW`@0X:2P102QXJ4209nOW`80WIfM0P2K
Vi/209VIV@80UYJF0P2CTi<209BDU080UYJF1P2HV9P209NGU`0309VIV@2LW9`0W9bL0080WYjN0P2O
Wil40:2PX080Xj>S0P2UYJD20:RXZ080ZZZZ0P2YZJT20:NWY`80YZJV0P2UYJD20::RXP80X:2P0P2T
Y:@20:NWY`80Xj>S0P2LW9`2096AT@80R8R80P23Ph<20861P@80Ph>30P26QXH00`2:RXX0S8b<08b<
S00208Z:RP80QhN70P21PH4207emO@80P8200P23Ph<20861P@80P8200P23Ph<208N7Q`80R8R89`38
h=P2030`<080;Bd]0P0Y:BT202`/;0@0;Rh^0P0];Bd202`/;080:b/[0P0_;bl202TY:@80=3@d0P0e
=CD402l_;`03038b<P0Z:RX0:RXZ0080;bl_0P0b<S8202TY:@809BDU0P0Q8B4202DU9@808b<S0P0`
<30206IVIP80Shn?0P2OWil207alO080I6AT0P1XJ6P207]kN`80Y:BT0P2k^k/20:b/[080][Jf0P2a
/K420;>c/`80]kNg0P2j^[X20<30`080a/K60P3;bl/20<c<c080c/k>0P2k^k/2071`L00303`l?01>
CTh0CTi>0080EEEE0P1NGUh206EUI@80KVi^0P1`L70207IfMP80N7Qh0P1iNGT208:2PP@0QhN70P26
QXH208f=S@80SXj>0P2HV9P209JFUP80VIVI0P2GUiL209ZJVP@0UiNG0P2JVYX209^KV`80X:2P0P2S
Xj<209jNWP80Xj>S0P2OWil20:2PX080W9bL0`2JVYX209NGU`80U9BD102FUYH209RHV080Vi^K0P2F
UYH209VIV@80WYjN0P2KVi/409bLW080YJFU0P2PX:020::RXP80Y:BT0P2UYJD20:NWY`80ZZZZ0P2U
YJD20:NWY`80YJFU0P2RXZ8209nOW`80YZJV0P2SXj<20:NWY`80W9bL0P2>SXh208^;R`0308:2PP1o
Ogl0Ogmo0080Q8B40P26QXH208^;R`80S8b<0P27QhL208V9R@80P8200P1nOWh20820P080Q8B41022
PX8208>3P`80QhN70P2=SHdW0<SPf080<30`0P0^;Rh202/[:`80;2`/0P0];Bd402`/;080;Rh^1P0Z
:RX203@d=00303Lg=`0c<c<0<c<c0080<C4a100^;Rh202l_;`80<c<c0P0W9bL202@T90808B4Q0P0S
8b<202HV9P80;bl_0P1QHF4208n?S`80YjNW0P1cLg<206][J`80HV9R0P1nOWh209jNWP80a/K60P2/
[:`20:n_[`80];Bd0P2e]KD00`2f][H0^KVi0;Vi^@020<30`080b<S80P3:b/X20<k>cP80dm?C0P30
`<0206i^KP80>CTi0P1>CTh205ADE080IFEU0P1TI6@206e]K@80Kfm_0P1fMWH207MgM`80O7al0P21
PH4208N7Q`80S8b<0P2:RXX208J6QP80Ti>C00<0V9RH09VIV@2IVIT00P2JVYX209VIV@80UiNG0P2H
V9P209BDU080WIfM0P2LW9`209nOW`80XJ6Q0P2SXj<209jNWP80XZ:R0P2QXJ4209^KV`80WIfM0P2H
V9P209JFUP@0Ti>C102FUYH209VIV@80UYJF0`2HV9P209fMW@80WYjN0P2OWil20:2PX080XJ6Q0P2N
WYh20:JVYP80Zj^[0P2ZZZX20:RXZ080YZJV0P2YZJT20:NWY`80X:2P0P2QXJ420::RXP80YjNW0P2T
Y:@209bLW080U9BD0P2:RXX40820P080QHF50P24Q8@00`2:RXX0S8b<08b<S00408R8R080Ng]k0P1o
Ogl20861P@80Q8B40P1oOgl208:2PP80QhN70P25QHD208N7Qah0b>3H000L0<SPf0@0;2`/100];Bd2
02h^;P@0;bl_0P0/;2`202/[:`80;Bd]0P0`<302038b<P0303@d=00b<S80<S8b0080;bl_0P0^;Rh6
02d];@80:BTY0P0T92@202<S8`8092@T0P0R8R8202LW9`80?Shn0P1kNg/209jNWP80SHf=0P1eMGD2
06=SH`80MWIf0P2@T9020;Vi^@80];Bd0P2`/;020:NWY`80[Jf]00<0]KFe0;Rh^02h^;P00P2k^k/2
0;no_`80a<C40P3=cLd20<o?c`80dM7A0P2TY:@206MWI`80Cdm?0P1ADE4205MGE`80GemO0P1YJFT2
06m_K`80M7Ad0P1hN7P207]kN`80P8200P26QXH208N7Q`80RHV90P2=SHd209:BTP0309BDU02FUYH0
UYJF0080VIVI0P2KVi/209ZJVPH0V9RH0P2IVIT209ZJVP80Vi^K102LW9`209^KV`80VIVI0P2GUiL2
09JFUP80UIFE0P2BTY82092@T080TY:B1P2DU9@209>CT`80TY:B00<0U9BD09FEU@2EUID00P2FUYH2
09NGU`80VYZJ0P2LW9`20:2PX080WYjN0P2QXJ420:BTY080YJFU0P2TY:@20:JVYP80YjNW0P2RXZ82
09jNWP80XJ6Q102TY:@20:6QX@80UIFE0P28R8P208>3P`80PH610P22PX8208F5Q@0308R8R02:RXX0
RXZ:0080RHV90P27QhL208>3P`@0P8200P21PH420820P080Ogmo0P23Ph<208J6QP80QhN79`38h=P2
02/[:`80;bl_0P0/;2`202l_;`80<S8b0P0a<C4203<c<`80;2`/0P0W9bL202h^;P80<C4a0P0h>3P2
03Hf=P80<c<c0P0`<3000`0_;bl0;Bd]02d];@0202d];@80;2`/0P0W9bL202<S8`8092@T0P0U9BD2
02<S8`8092@T0P0o?cl207UiN@80W9bL0P2?Shl207=cL`80Jf][0P1_Kfl209JFUP80`L710P2b/[82
0:^[Z`80YZJV0P2ZZZX20;6a/@80]KFe0P2l_;`20;no_`80b<S80P3<c<`20<o?c`80c<c<0P2f][H0
0`1PH600AdM704M7A`02055AD@80G5aL0P1OGel206MWI`80KVi^0P1bLW8207]kN`80NWYj0P1lO7`2
08>3P`80Rh^;0P28R8P2092@T080TY:B0P2DU9@209VIV@@0VYZJ0P2HV9P209NGU`80Ti>C0P2FUYH2
09jNWP80U9BD102KVi/209nOW`80VYZJ0P2MWId209ZJVP0309FEU@2GUiL0UiNG0080TI6A0P2>SXh2
09:BTP80TI6A0P2CTi<208n?S`@0T92@0P2CTi<409:BTP80V9RH0P2FUYH209bLW080WIfM0P2PX:02
0:6QX@@0Z:RX0P2WYjL20:>SX`@0Y:BT0P2LW9`20:6QX@80Xj>S0P2WYjL20:2PX080TY:B0P26QXH0
0`23Ph<0QHF508F5Q@0408B4Q080QXJ60P2:RXX208^;R`80QhN70P24Q8@207moO`80PH610P1lO7`2
08>3P`80O7al0P21PH4208B4Q080SXj>9`38h=P202/[:`80:2PX100];Bd2030`<080<c<c0P0^;Rh2
02XZ:P80:BTY0P0_;bl203<c<`80;Rh^00<0<C4a02h^;P0^;Rh00P0^;Rh202l_;`80;2`/0P0^;Rh2
02XZ:P80:BTY0P0T92@2028R8P809BDU0P0R8R8202@T9080?clo0P1kNg/209nOW`80S8b<0P1eMGD2
06ATI080MWIf0P2EUID20;Ng]`80]KFe0P2][Jd20:FUY@80[Jf]00<0]KFe0;Rh^02h^;P00P2n_[h2
0;fm_@80`l?30P3:b/X20<c<c080clo?0P2TY:@206a/K080CDe=0P1>CTh205EEE@80G5aL0P1[Jf/2
075aL@80M7Ad0P1gMgL207]kN`80Q8B40P23Ph<208R8R0@0S8b<0P2ATI400`2CTi<0UIFE09FEU@02
09JFUP80Vi^K0P2IVIT209ZJVP80UiNG0P2IVIT209RHV080VIVI0P2MWId209bLW080VIVI0P2LW9`2
09VIV@80V9RH0P2GUiL209JFUP@0TY:B0P2ATI4209:BTP80V9RH0P2EUID409>CT`0309JFUP2CTi<0
Ti>C0080UIFE0P2DU9@209^KV`P0WinO0P2QXJ420:ZZZP80YZJV0P2SXj<20:VYZ@80XJ6Q0P2OWil2
0:2PX080YjNW0P2VYZH20:6QX@80TY:B0P2:RXX208>3P`80PH610P24Q8@208R8R00308N7Q`2<S8`0
S8b<0080Shn?1027QhL40861P@80PX:20P1lO7`207moO`80PX:20P28R8P208Z:RQh0b>3H000L0<SP
f0@0;2`/100];Bd202h^;P@0;bl_0P0/;2`202/[:`80;Bd]0P0`<302038b<P0303@d=00b<S80<S8b
0080;bl_0P0^;Rh602d];@80:BTY0P0T92@202<S8`8092@T0P0R8R8202LW9`80?Shn0P1kNg/209jN
WP80SHf=0P1eMGD206=SH`80MWIf0P2@T9020;Vi^@80];Bd0P2`/;020:NWY`80[Jf]00<0]KFe0;Rh
^02h^;P00P2k^k/20;no_`80a<C40P3=cLd20<o?c`80dM7A0P2TY:@206MWI`80Cdm?0P1ADE4205MG
E`80GemO0P1YJFT206m_K`80M7Ad0P1hN7P207]kN`80P8200P26QXH208N7Q`80RHV90P2=SHd209:B
TP0309BDU02FUYH0UYJF0080VIVI0P2KVi/209ZJVPH0V9RH0P2IVIT209ZJVP80Vi^K102LW9`209^K
V`80VIVI0P2GUiL209JFUP80UIFE0P2BTY82092@T080TY:B1P2DU9@209>CT`80TY:B00<0U9BD09FE
U@2EUID00P2FUYH209NGU`80VYZJ0P2LW9`20:2PX080WYjN0P2QXJ420:BTY080YJFU0P2TY:@20:JV
YP80YjNW0P2RXZ8209jNWP80XJ6Q102TY:@20:6QX@80UIFE0P28R8P208>3P`80PH610P22PX8208F5
Q@0308R8R02:RXX0RXZ:0080RHV90P27QhL208>3P`@0P8200P21PH420820P080Ogmo0P23Ph<208J6
QP80QhN79`38h=P202/[:`80;bl_0P0/;2`202l_;`80<S8b0P0a<C4203<c<`80;2`/0P0W9bL202h^
;P80<C4a0P0h>3P203Hf=P80<c<c0P0`<3000`0_;bl0;Bd]02d];@0202d];@80;2`/0P0W9bL202<S
8`8092@T0P0U9BD202<S8`8092@T0P0o?cl207UiN@80W9bL0P2?Shl207=cL`80Jf][0P1_Kfl209JF
UP80`L710P2b/[820:^[Z`80YZJV0P2ZZZX20;6a/@80]KFe0P2l_;`20;no_`80b<S80P3<c<`20<o?
c`80c<c<0P2f][H00`1PH600AdM704M7A`02055AD@80G5aL0P1OGel206MWI`80KVi^0P1bLW8207]k
N`80NWYj0P1lO7`208>3P`80Rh^;0P28R8P2092@T080TY:B0P2DU9@209VIV@@0VYZJ0P2HV9P209NG
U`80Ti>C0P2FUYH209jNWP80U9BD102KVi/209nOW`80VYZJ0P2MWId209ZJVP0309FEU@2GUiL0UiNG
0080TI6A0P2>SXh209:BTP80TI6A0P2CTi<208n?S`@0T92@0P2CTi<409:BTP80V9RH0P2FUYH209bL
W080WIfM0P2PX:020:6QX@@0Z:RX0P2WYjL20:>SX`@0Y:BT0P2LW9`20:6QX@80Xj>S0P2WYjL20:2P
X080TY:B0P26QXH00`23Ph<0QHF508F5Q@0408B4Q080QXJ60P2:RXX208^;R`80QhN70P24Q8@207mo
O`80PH610P1lO7`208>3P`80O7al0P21PH4208B4Q080SXj>9`38h=P202/[:`80:2PX100];Bd2030`
<080<c<c0P0^;Rh202XZ:P80:BTY0P0_;bl203<c<`80;Rh^00<0<C4a02h^;P0^;Rh00P0^;Rh202l_
;`80;2`/0P0^;Rh202XZ:P80:BTY0P0T92@2028R8P809BDU0P0R8R8202@T9080?clo0P1kNg/209nO
W`80S8b<0P1eMGD206ATI080MWIf0P2EUID20;Ng]`80]KFe0P2][Jd20:FUY@80[Jf]00<0]KFe0;Rh
^02h^;P00P2n_[h20;fm_@80`l?30P3:b/X20<c<c080clo?0P2TY:@206a/K080CDe=0P1>CTh205EE
E@80G5aL0P1[Jf/2075aL@80M7Ad0P1gMgL207]kN`80Q8B40P23Ph<208R8R0@0S8b<0P2ATI400`2C
Ti<0UIFE09FEU@0209JFUP80Vi^K0P2IVIT209ZJVP80UiNG0P2IVIT209RHV080VIVI0P2MWId209bL
W080VIVI0P2LW9`209VIV@80V9RH0P2GUiL209JFUP@0TY:B0P2ATI4209:BTP80V9RH0P2EUID409>C
T`0309JFUP2CTi<0Ti>C0080UIFE0P2DU9@209^KV`P0WinO0P2QXJ420:ZZZP80YZJV0P2SXj<20:VY
Z@80XJ6Q0P2OWil20:2PX080YjNW0P2VYZH20:6QX@80TY:B0P2:RXX208>3P`80PH610P24Q8@208R8
R00308N7Q`2<S8`0S8b<0080Shn?1027QhL40861P@80PX:20P1lO7`207moO`80PX:20P28R8P208Z:
RQh0b>3H000L0<SPf080:BTY0P0/;2`4030`<080;Rh^100_;bl202d];@80:b/[0P0_;bl203<c<`80
<S8b00<0<C4a030`<00`<3000P0`<30202l_;`80;Bd]0P0/;2`202/[:`80:BTY0P0W9bL402HV9P80
820P0P0U9BD2020P8080Hf=S0P25QHD20:6QX@80QHF50P1WIfL206e]K@80PH610P2SXj<20;no_`80
/;2`0P2MWId20:JVYP030;>c/`2e]KD0]KFe0080]KFe0P2k^k/20<30`080a<C40P38b<P40=;BdP80
Vi^K101LG5`204e=C@80EeMG0P1UIFD206e]K@80M7Ad0P1hN7P207]kN`80P8200P24Q8@208N7Q`80
RXZ:0P2>SXh209:BTP0309>CT`2DU9@0U9BD0080V9RH0P2KVi/209ZJVP80VIVI0P2GUiL609JFUP@0
UiNG0P2FUYH209FEU@80Ti>C0P2BTY8209>CT`80U9BD0P2ATI4208j>SP80T92@0P2CTi<2096AT@80
Shn?0P2>SXh208f=S@0308j>SP2?Shl0Shn?0080Shn?0P2@T90209BDU080V9RH0P2IVIT209NGU`80
VYZJ0P2MWId209nOW`80XJ6Q0P2UYJD20:NWY`80XZ:R0P2LW9`209fMW@80X:2P102SXj<209NGU`80
RXZ:0P24Q8@20861P@80PX:20P24Q8@00`26QXH0R8R808R8R00208R8R080QhN70P26QXH208>3P`80
PH610P1oOgl207inOP80Ogmo0P22PX8208J6QP80QhN79`38h=P202LW9`80:b/[0P0d=3@202h^;P80
;Bd]0P0[:b/202h^;P80;bl_0P0`<30202d];@80;Rh^0P0f=SH202`/;080;Rh^0P0_;bl00`0[:b/0
;bl_02l_;`0202XZ:P80<30`0P0W9bL202PX:080:b/[0P0V9RH2024Q8@808R8R0P0X:2P2061PH080
QHF50P2QXJ4208:2PP80Jf][0P1WIfL207inOP80ZJVY0P30`<020:RXZ080XJ6Q0P2[Zj/20;:b/P80
][Jf0P2g]kL20;Fe]@80`L710P37alL20<W9b@@0b/[:00<0ZJVY05mOG`1OGel00P1:BTX205IFEP80
GEeM0P1SHf<206e]K@@0MGEe0P1mOGd207moO`80Ph>30P2:RXX208R8R080SHf=0P2CTi<409BDU080
UIFE0P2KVi/209VIV@@0VYZJ0P2FUYH209RHV080UYJF0P2DU9@209NGU`80VIVI0P2EUID209BDU080
Ti>C00<0T92@09FEU@2EUID00P2@T90208^;R`80U9BD0P2BTY8208n?S`80T92@0P2=SHd208j>SP80
T92@0P2>SXh208n?S`80SXj>0P2FUYH209NGU`80UYJF0P2GUiL209ZJVP80Vi^K0P2MWId20:6QX@80
Xj>S0P2UYJD20:BTY080VYZJ0P2MWId20:6QX@80Xj>S0P2QXJ4209RHV080Rh^;1@21PH4208R8R080
Q8B40P2:RXX208R8R080QXJ60P27QhL20861P@80Ph>30P1nOWh208:2PP80Ogmo0P22PX8208>3P`80
S8b<9`38h=P202d];@80:b/[0P0c<c<202d];@80;Rh^0P0`<30202l_;`@0;2`/0P0];Bd203De=@80
<C4a00<0=3@d038b<P0b<S800P0b<S8402d];@80;Rh^100[:b/202PX:0808R8R0P0V9RH2024Q8@80
8b<S0P0T92@2061PH080R8R80P2PX:0208F5Q@80IFEU0P1^KVh207inOP80XZ:R0P2o_kl20;6a/@80
WYjN0P2YZJT00`2c/k<0];Bd0;Bd]0020;Jf]P80^[Zj0P32`/840<W9b@80d=3@0P3Bd]8209fMW@80
FUYJ0P1LG5`204e=C@80GEeM0P1QHF42071`L080M7Ad0P1fMWH207alO080P8200P24Q8@208V9R@80
Rh^;0P2<S8`309:BTP@0UYJF0P2LW9`209^KV`80V9RH0P2JVYX209NGU`80Ti>C0P2FUYH209ZJVP80
V9RH1P2DU9@2096AT@80UIFE0P2BTY82092@T080SHf=0P2?Shl209>CT`80TY:B0P2?Shl208^;R`80
S8b<1@2?Shl2096AT@80UYJF0P2GUiL209ZJVP80VIVI102MWId20:2PX080XZ:R0P2TY:@20:RXZ080
XZ:R102NWYh20:6QX@80XZ:R0P2TY:@209NGU`80Rh^;0P26QXH40820P080Q8B400<0R8R808N7Q`27
QhL00P2:RXX208R8R080QHF50P23Ph<20861P@80OGem0P22PX8207inOP80PH610P25QHD208J6QQh0
b>3H000L0<SPf080:BTY0P0/;2`4030`<080;Rh^100_;bl202d];@80:b/[0P0_;bl203<c<`80<S8b
00<0<C4a030`<00`<3000P0`<30202l_;`80;Bd]0P0/;2`202/[:`80:BTY0P0W9bL402HV9P80820P
0P0U9BD2020P8080Hf=S0P25QHD20:6QX@80QHF50P1WIfL206e]K@80PH610P2SXj<20;no_`80/;2`
0P2MWId20:JVYP030;>c/`2e]KD0]KFe0080]KFe0P2k^k/20<30`080a<C40P38b<P40=;BdP80Vi^K
101LG5`204e=C@80EeMG0P1UIFD206e]K@80M7Ad0P1hN7P207]kN`80P8200P24Q8@208N7Q`80RXZ:
0P2>SXh209:BTP0309>CT`2DU9@0U9BD0080V9RH0P2KVi/209ZJVP80VIVI0P2GUiL609JFUP@0UiNG
0P2FUYH209FEU@80Ti>C0P2BTY8209>CT`80U9BD0P2ATI4208j>SP80T92@0P2CTi<2096AT@80Shn?
0P2>SXh208f=S@0308j>SP2?Shl0Shn?0080Shn?0P2@T90209BDU080V9RH0P2IVIT209NGU`80VYZJ
0P2MWId209nOW`80XJ6Q0P2UYJD20:NWY`80XZ:R0P2LW9`209fMW@80X:2P102SXj<209NGU`80RXZ:
0P24Q8@20861P@80PX:20P24Q8@00`26QXH0R8R808R8R00208R8R080QhN70P26QXH208>3P`80PH61
0P1oOgl207inOP80Ogmo0P22PX8208J6QP80QhN79`38h=P202LW9`80:b/[0P0d=3@202h^;P80;Bd]
0P0[:b/202h^;P80;bl_0P0`<30202d];@80;Rh^0P0f=SH202`/;080;Rh^0P0_;bl00`0[:b/0;bl_
02l_;`0202XZ:P80<30`0P0W9bL202PX:080:b/[0P0V9RH2024Q8@808R8R0P0X:2P2061PH080QHF5
0P2QXJ4208:2PP80Jf][0P1WIfL207inOP80ZJVY0P30`<020:RXZ080XJ6Q0P2[Zj/20;:b/P80][Jf
0P2g]kL20;Fe]@80`L710P37alL20<W9b@@0b/[:00<0ZJVY05mOG`1OGel00P1:BTX205IFEP80GEeM
0P1SHf<206e]K@@0MGEe0P1mOGd207moO`80Ph>30P2:RXX208R8R080SHf=0P2CTi<409BDU080UIFE
0P2KVi/209VIV@@0VYZJ0P2FUYH209RHV080UYJF0P2DU9@209NGU`80VIVI0P2EUID209BDU080Ti>C
00<0T92@09FEU@2EUID00P2@T90208^;R`80U9BD0P2BTY8208n?S`80T92@0P2=SHd208j>SP80T92@
0P2>SXh208n?S`80SXj>0P2FUYH209NGU`80UYJF0P2GUiL209ZJVP80Vi^K0P2MWId20:6QX@80Xj>S
0P2UYJD20:BTY080VYZJ0P2MWId20:6QX@80Xj>S0P2QXJ4209RHV080Rh^;1@21PH4208R8R080Q8B4
0P2:RXX208R8R080QXJ60P27QhL20861P@80Ph>30P1nOWh208:2PP80Ogmo0P22PX8208>3P`80S8b<
9`38h=P202d];@80:b/[0P0c<c<202d];@80;Rh^0P0`<30202l_;`@0;2`/0P0];Bd203De=@80<C4a
00<0=3@d038b<P0b<S800P0b<S8402d];@80;Rh^100[:b/202PX:0808R8R0P0V9RH2024Q8@808b<S
0P0T92@2061PH080R8R80P2PX:0208F5Q@80IFEU0P1^KVh207inOP80XZ:R0P2o_kl20;6a/@80WYjN
0P2YZJT00`2c/k<0];Bd0;Bd]0020;Jf]P80^[Zj0P32`/840<W9b@80d=3@0P3Bd]8209fMW@80FUYJ
0P1LG5`204e=C@80GEeM0P1QHF42071`L080M7Ad0P1fMWH207alO080P8200P24Q8@208V9R@80Rh^;
0P2<S8`309:BTP@0UYJF0P2LW9`209^KV`80V9RH0P2JVYX209NGU`80Ti>C0P2FUYH209ZJVP80V9RH
1P2DU9@2096AT@80UIFE0P2BTY82092@T080SHf=0P2?Shl209>CT`80TY:B0P2?Shl208^;R`80S8b<
1@2?Shl2096AT@80UYJF0P2GUiL209ZJVP80VIVI102MWId20:2PX080XZ:R0P2TY:@20:RXZ080XZ:R
102NWYh20:6QX@80XZ:R0P2TY:@209NGU`80Rh^;0P26QXH40820P080Q8B400<0R8R808N7Q`27QhL0
0P2:RXX208R8R080QHF50P23Ph<20861P@80OGem0P22PX8207inOP80PH610P25QHD208J6QQh0b>3H
000L0<SPf080:b/[0P0];Bd2030`<0H0<C4a0P0`<30202d];@80;2`/0P0_;bl2038b<P80<C4a1@0_
;bl4030`<080<C4a0P0`<30202/[:`809bLW0P0U9BD202@T90807alO0P0Q8B4201`L7080@d=30P1`
L70409VIV@80KVi^0P1ZJVX2079bLP80QHF50P2m_Kd20:j^[P80X:2P0P2VYZH00`2_[jl0/K6a0;6a
/@020;>c/`80][Jf0P2k^k/20<71`@80alO70P3=cLd20=7Ad@80_[jn0P2QXJ4205QHF080FUYJ0P1F
EUH205QHF080Hf=S0P1`L70207IfMP80NWYj0P1oOgl208>3P`80QHF50P28R8P208^;R`80Shn?00<0
TY:B09>CT`2CTi<0102DU9@209FEU@P0UYJF0P2EUID209BDU080TY:B102@T902096AT@80TY:B0P2E
UID209JFUP80T92@0P29RHT208f=S@80T92@0P2=SHd608R8R00308J6QP29RHT0RHV90080Rh^;0P2>
SXh208f=S@80Ti>C0P23Ph<409JFUP80V9RH0P2KVi/209jNWP@0X:2P0P2LW9`209RHV0@0UiNG0P2J
VYX209bLW080UYJF0P2>SXh208>3P`80Ng]k0P1mOGd208:2PP0308F5Q@27QhL0QhN70080QhN70P25
QHD208B4Q080Ph>30P21PH4207moO`80OWin0P1oOgl208B4Q080R8R80P29RHTW0<SPf080=3@d0P0Z
:RX202`/;0@0=3@d0P0b<S82034a<@80;Rh^0P0X:2P202h^;P80=cLg100c<c<202h^;P80=3@d00<0
=cLg03@d=00d=3@00P0/;2`4030`<0809bLW0P0N7Qh2024Q8@@0820P0P0S8b<203`l?080MWIf0P2I
VIT209^KV`80KVi^0P1SHf<2071`L080S8b<0P2i^KT20:ZZZP80WinO0P2WYjL20;2`/0@0/k>c0P2`
/;020;^k^`80`/;20P3:b/X20<W9b@80bl_;00<0b<S80::RXP2RXZ800P1MGEd204m?C`80De=C0P1L
G5`206=SH`80LG5a0P1fMWH207UiN@80Q8B40P23Ph<208J6QP80QhN70P2;Rh/208b<S080Shn?0P2C
Ti<209:BTP80UiNG0P2JVYX209:BTP80UYJF0P2BTY8209NGU`80VIVI0P2ATI4209>CT`80TI6A0P2;
Rh/208n?S`80TI6A00<0U9BD09FEU@2EUID00P2EUID208b<S080RXZ:0P2DU9@2092@T080SHf=0P29
RHT208R8R080RHV90P2;Rh/408f=S@80U9BD0P2ATI4208b<S0@0UIFE0P2KVi/209VIV@@0WinO0P2T
Y:@209jNWP80VYZJ0P2DU9@209JFUP80VIVI102LW9`208f=S@0308>3P`1jNWX0NWYj0080Ng]k0P21
PH4208B4Q080QXJ60P29RHT208J6QP80PX:20P25QHD20861P@@0Ogmo0P1mOGd208>3P`80QHF50P2@
T90W0<SPf080:b/[0P0];Bd2034a<@80<30`0P0a<C4202l_;`80<30`0P0_;bl402h^;P@0<C4a00<0
<30`02d];@0];Bd00P0a<C4202/[:`80<C4a0P0d=3@2030`<080:BTY0P0X:2P602@T90808b<S0P0L
71`20410@080LW9b102IVIT206i^KP80JVYZ0P1cLg<208>3P`80`<300P2/[:`20:2PX080YZJV00<0
[Zj^0;2`/02`/;000P2a/K420;Jf]P80^KVi0P30`<020<K6aP80c/k>0P3=cLd20<;2`P80XJ6Q0P1F
EUH205UIF@@0EUIF0P1RHV82071`L080M7Ad0P1kNg/207inOPH0Q8B40P2=SHd209>CT`03096AT@2D
U9@0U9BD0080U9BD0P2EUID209BDU0@0Ti>C0P2DU9@209JFUP@0UIFE0P2@T904096AT@80U9BD0P2>
SXh209JFUP80UIFE0P2DU9@208Z:RP80Rh^;0P2DU9@208V9R@80QhN70P28R8P208V9R@0308R8R029
RHT0RHV90080QhN70P2?Shl208j>SP80TY:B0P21PH4209:BTP@0UYJF0P2MWId209ZJVP80W9bL0P2R
XZ8209NGU`80V9RH0P2BTY8209VIV@80UIFE0P2MWId209JFUP80RXZ:0P20P80207alO080OWin0P20
P8000`21PH40Q8B408B4Q00208J6QP80P8200P23Ph<20861P@@0Ogmo0P21PH4207moO`80PX:20P27
QhL208b<S1h0b>3H000L0<SPf080:b/[0P0];Bd2030`<0H0<C4a0P0`<30202d];@80;2`/0P0_;bl2
038b<P80<C4a1@0_;bl4030`<080<C4a0P0`<30202/[:`809bLW0P0U9BD202@T90807alO0P0Q8B42
01`L7080@d=30P1`L70409VIV@80KVi^0P1ZJVX2079bLP80QHF50P2m_Kd20:j^[P80X:2P0P2VYZH0
0`2_[jl0/K6a0;6a/@020;>c/`80][Jf0P2k^k/20<71`@80alO70P3=cLd20=7Ad@80_[jn0P2QXJ42
05QHF080FUYJ0P1FEUH205QHF080Hf=S0P1`L70207IfMP80NWYj0P1oOgl208>3P`80QHF50P28R8P2
08^;R`80Shn?00<0TY:B09>CT`2CTi<0102DU9@209FEU@P0UYJF0P2EUID209BDU080TY:B102@T902
096AT@80TY:B0P2EUID209JFUP80T92@0P29RHT208f=S@80T92@0P2=SHd608R8R00308J6QP29RHT0
RHV90080Rh^;0P2>SXh208f=S@80Ti>C0P23Ph<409JFUP80V9RH0P2KVi/209jNWP@0X:2P0P2LW9`2
09RHV0@0UiNG0P2JVYX209bLW080UYJF0P2>SXh208>3P`80Ng]k0P1mOGd208:2PP0308F5Q@27QhL0
QhN70080QhN70P25QHD208B4Q080Ph>30P21PH4207moO`80OWin0P1oOgl208B4Q080R8R80P29RHTW
0<SPf080=3@d0P0Z:RX202`/;0@0=3@d0P0b<S82034a<@80;Rh^0P0X:2P202h^;P80=cLg100c<c<2
02h^;P80=3@d00<0=cLg03@d=00d=3@00P0/;2`4030`<0809bLW0P0N7Qh2024Q8@@0820P0P0S8b<2
03`l?080MWIf0P2IVIT209^KV`80KVi^0P1SHf<2071`L080S8b<0P2i^KT20:ZZZP80WinO0P2WYjL2
0;2`/0@0/k>c0P2`/;020;^k^`80`/;20P3:b/X20<W9b@80bl_;00<0b<S80::RXP2RXZ800P1MGEd2
04m?C`80De=C0P1LG5`206=SH`80LG5a0P1fMWH207UiN@80Q8B40P23Ph<208J6QP80QhN70P2;Rh/2
08b<S080Shn?0P2CTi<209:BTP80UiNG0P2JVYX209:BTP80UYJF0P2BTY8209NGU`80VIVI0P2ATI42
09>CT`80TI6A0P2;Rh/208n?S`80TI6A00<0U9BD09FEU@2EUID00P2EUID208b<S080RXZ:0P2DU9@2
092@T080SHf=0P29RHT208R8R080RHV90P2;Rh/408f=S@80U9BD0P2ATI4208b<S0@0UIFE0P2KVi/2
09VIV@@0WinO0P2TY:@209jNWP80VYZJ0P2DU9@209JFUP80VIVI102LW9`208f=S@0308>3P`1jNWX0
NWYj0080Ng]k0P21PH4208B4Q080QXJ60P29RHT208J6QP80PX:20P25QHD20861P@@0Ogmo0P1mOGd2
08>3P`80QHF50P2@T90W0<SPf080:b/[0P0];Bd2034a<@80<30`0P0a<C4202l_;`80<30`0P0_;bl4
02h^;P@0<C4a00<0<30`02d];@0];Bd00P0a<C4202/[:`80<C4a0P0d=3@2030`<080:BTY0P0X:2P6
02@T90808b<S0P0L71`20410@080LW9b102IVIT206i^KP80JVYZ0P1cLg<208>3P`80`<300P2/[:`2
0:2PX080YZJV00<0[Zj^0;2`/02`/;000P2a/K420;Jf]P80^KVi0P30`<020<K6aP80c/k>0P3=cLd2
0<;2`P80XJ6Q0P1FEUH205UIF@@0EUIF0P1RHV82071`L080M7Ad0P1kNg/207inOPH0Q8B40P2=SHd2
09>CT`03096AT@2DU9@0U9BD0080U9BD0P2EUID209BDU0@0Ti>C0P2DU9@209JFUP@0UIFE0P2@T904
096AT@80U9BD0P2>SXh209JFUP80UIFE0P2DU9@208Z:RP80Rh^;0P2DU9@208V9R@80QhN70P28R8P2
08V9R@0308R8R029RHT0RHV90080QhN70P2?Shl208j>SP80TY:B0P21PH4209:BTP@0UYJF0P2MWId2
09ZJVP80W9bL0P2RXZ8209NGU`80V9RH0P2BTY8209VIV@80UIFE0P2MWId209JFUP80RXZ:0P20P802
07alO080OWin0P20P8000`21PH40Q8B408B4Q00208J6QP80P8200P23Ph<20861P@@0Ogmo0P21PH42
07moO`80PX:20P27QhL208b<S1h0b>3H000L0<SPf0@0;Rh^0P0_;bl2034a<@80<c<c0P0b<S82030`
<080;Rh^0P0/;2`202h^;P80<C4a0P0_;bl00`0];Bd0;Rh^02h^;P0202l_;`80<C4a0P0d=3@203De
=@80=3@d0P0^;Rh202LW9`8092@T0P0R8R82020P80@07alO0P0W9bL205UIF@80QHF50P2UYJD207Ui
N@80Jf][0P1VIVH206][J`80/K6a0P2][Jd20:NWY`80Z:RX00<0ZZZZ0:f][@2][Jd00P2a/K420;>c
/`80][Jf0P2n_[h20<K6aP80b<S80P37alL20<k>cP80aLG50P2MWId205ADE080FEUI0P1>CTh205aL
G080Jf][0P1cLg<207UiN@80OWin0P21PH4208>3P`80QHF50P28R8P208b<S003092@T02CTi<0Ti>C
0080T92@0P2=SHd208n?S`80TY:B0P2DU9@209FEU@80UYJF0P2EUID2096AT@80SXj>102<S8`208n?
S`80Ti>C0P2GUiL209RHV080Shn?0P25QHD208R8R080Rh^;0P27QhL208:2PPD0P8200P24Q8@208R8
R080S8b<0P28R8P208b<S080L71`0P2DU9@2096AT@80TY:B0P2GUiL209bLW080Vi^K0P2HV9P209NG
U`80UYJF0P2CTi<2092@T080TY:B102DU9@208n?S`80PX:20P1fMWH207UiN@80P82000<0Ph>308J6
QP26QXH00P25QHD208>3P`@0PX:20P21PH4407moO`80P8200P25QHD208^;R`80S8b<9`38h=P202d]
;@80:RXZ0P0/;2`2034a<@80;bl_0P0d=3@203<c<`80:BTY0P0^;Rh203<c<`80<30`0P0^;Rh202l_
;`80;2`/0P0_;bl00`0d=3@0=CDe03De=@02038b<P80=SHf0P0];Bd202HV9P809bLW0P0V9RH201`L
70807QhN0P0S8b<202HV9P80FEUI0P27QhL20:6QX@80P8200P1SHf<206IVIP80Lg=c0P2XZ:P20;Rh
^0@0Xj>S0P2XZ:P20;>c/`80[Jf]0P2b/[820;Fe]@80_Kfm0P35aLD20<S8b080bl_;00<0a/K60<C4
a034a<@00P2NWYh205UIF@@0DE5A0P1PH60206][J`80KVi^0P1kNg/20820P080OWin0P23Ph<208F5
Q@80QhN70P2>SXh209:BTP80UIFE102=SHd4092@T080UYJF0P2DU9@209NGU`80TY:B0P2DU9@208^;
R`80Shn?0P2<S8`208n?S`80Ti>C00<0UYJF09NGU`2GUiL00P2@T90208B4Q080Ph>30P2<S8`208V9
R@80PX:20P1lO7`207inOP80Q8B40P1oOgl408R8R0@0QHF50P1gMgL208b<S080UIFE0P2>SXh2092@
T080X:2P102IVIT609JFUP@0TI6A0P2FUYH209FEU@80Shn?00<0Ph>307MgM`1gMgL00P1jNWX20820
P080PH610P28R8P208B4Q080QHF50P1nOWh408>3P`80P8200P1mOGd20820P080QXJ60P29RHT2096A
TBL0b>3H0P0/;2`2030`<080;Rh^0P0_;bl403<c<`@0;bl_0P0^;Rh202/[:`80<S8b0P0`<30302d]
;@80<S8b0P0`<30403Hf=P80=3@d0P0];Bd202LW9`808b<S0P0T92@201lO7`80820P0P0N7Qh202LW
9`80EeMG0P26QXH20:JVYP80NGUi0P1[Jf/206MWI`80JFUY0P2a/K420:f][@80YjNW0P2ZZZX00`2X
Z:P0[Jf]0:f][@020:n_[`80]KFe0P2f][H20;fm_@@0b<S80P39bLT20<k>cP80aLG50P2KVi/205IF
EP80Fe]K0P1>CTh205]KF`80Jf][0P1dM7@207YjNP80O7al0P22PX8208F5Q@80QXJ60P24Q8@208b<
S00309:BTP2ATI40TI6A0080T92@0P2;Rh/209:BTP80U9BD0P2BTY8209BDU080W9bL0P2>SXh209JF
UP80S8b<0P2=SHd208^;R`@0Ti>C0P2JVYX209JFUP80T92@0P23Ph<208R8R080Rh^;0P28R8P208>3
P`@0PH6100<0OGem08N7Q`27QhL00P28R8P208f=S@80RXZ:0P2=SHd2071`L080UYJF102BTY8209FE
U@80WinO0P2HV9P209bLW080UYJF0P2GUiL209BDU080TI6A0P2@T90209JFUP80U9BD0P2BTY820820
P080MWIf0P1kNg/20820P00308N7Q`25QHD0QHF50080RHV90P23Ph<20861P@80QHF50P1oOgl20861
P@80OGem0P22PX8208>3P`80RHV90P2=SHdN0<SPf0007038h=P402h^;P80;bl_0P0a<C4203<c<`80
<S8b0P0`<30202h^;P80;2`/0P0^;Rh2034a<@80;bl_00<0;Bd]02h^;P0^;Rh00P0_;bl2034a<@80
=3@d0P0e=CD203@d=080;Rh^0P0W9bL202@T90808R8R0P0P820401lO7`809bLW0P1IFET208F5Q@80
YJFU0P1iNGT206][J`80IVIV0P1[Jf/20;6a/@80[Jf]0P2WYjL20:RXZ0030:ZZZP2][Jd0[Jf]0080
/K6a0P2c/k<20;Jf]P80_[jn0P36a/H20<S8b080alO70P3>c/h20<G5a@80WIfM0P1DE5@205UIF@80
CTi>0P1LG5`206][J`80Lg=c0P1iNGT207inOP80PH610P23Ph<208F5Q@80R8R80P2<S8`00`2@T900
Ti>C09>CT`02092@T080SHf=0P2?Shl209:BTP80U9BD0P2EUID209JFUP80UIFE0P2ATI4208j>SP@0
S8b<0P2?Shl209>CT`80UiNG0P2HV9P208n?S`80QHF50P28R8P208^;R`80QhN70P22PX850820P080
Q8B40P28R8P208b<S080R8R80P2<S8`2071`L080U9BD0P2ATI4209:BTP80UiNG0P2LW9`209^KV`80
V9RH0P2GUiL209JFUP80Ti>C0P2@T90209:BTP@0U9BD0P2?Shl208:2PP80MWIf0P1iNGT20820P003
08>3P`26QXH0QXJ60080QHF50P23Ph<408:2PP80PH61101oOgl20820P080QHF50P2;Rh/208b<S2L0
b>3H0P0];Bd202XZ:P80;2`/0P0a<C4202l_;`80=3@d0P0c<c<202TY:@80;Rh^0P0c<c<2030`<080
;Rh^0P0_;bl202`/;080;bl_00<0=3@d03De=@0e=CD00P0b<S8203Hf=P80;Bd]0P0V9RH202LW9`80
9RHV0P0L71`201hN7P808b<S0P0V9RH205UIF@80QhN70P2QXJ420820P080Hf=S0P1VIVH207=cL`80
Z:RX0P2h^;P40:>SX`80Z:RX0P2c/k<20:f][@80/[:b0P2e]KD20;fm_@80aLG50P38b<P20<_;b`03
0<K6aP34a<@0a<C40080WYjN0P1IFET4055AD@80H61P0P1[Jf/206i^KP80Ng]k0P20P80207inOP80
Ph>30P25QHD208N7Q`80SXj>0P2BTY8209FEU@@0SHf=102@T90209JFUP80U9BD0P2GUiL209:BTP80
U9BD0P2;Rh/208n?S`80S8b<0P2?Shl209>CT`0309JFUP2GUiL0UiNG0080T92@0P24Q8@208>3P`80
S8b<0P29RHT208:2PP80O7al0P1nOWh208B4Q080Ogmo1028R8P408F5Q@80MgMg0P2<S8`209FEU@80
SXj>0P2@T9020:2PX0@0VIVI1P2FUYH4096AT@80UYJF0P2EUID208n?S`0308>3P`1gMgL0MgMg0080
NWYj0P20P8020861P@80R8R80P24Q8@208F5Q@80OWin1023Ph<20820P080OGem0P20P80208J6QP80
RHV90P2ATI4W0<SPf080;2`/0P0`<30202h^;P80;bl_100c<c<402l_;`80;Rh^0P0[:b/2038b<P80
<30`0`0];Bd2038b<P80<30`100f=SH203@d=080;Bd]0P0W9bL202<S8`8092@T0P0O7al2020P8080
7QhN0P0W9bL205MGE`80QXJ60P2VYZH207UiN@80Jf][0P1WIfL206UYJ@80/K6a0P2][Jd20:NWY`80
ZZZZ00<0Z:RX0:f][@2][Jd00P2_[jl20;Fe]@80][Jf0P2m_Kd40<S8b080bLW90P3>c/h20<G5a@80
Vi^K0P1FEUH205]KF`80CTi>0P1KFe/206][J`80M7Ad0P1jNWX207alO080PX:20P25QHD208J6QP80
Q8B40P2<S8`00`2BTY80TI6A096AT@02092@T080Rh^;0P2BTY8209BDU080TY:B0P2DU9@209bLW080
SXj>0P2FUYH208b<S080SHf=0P2;Rh/409>CT`80VYZJ0P2FUYH2092@T080Ph>30P28R8P208^;R`80
R8R80P23Ph<40861P@0307emO@27QhL0QhN70080R8R80P2=SHd208Z:RP80SHf=0P1`L70209JFUP@0
TY:B0P2EUID209nOW`80V9RH0P2LW9`209JFUP80UiNG0P2DU9@2096AT@80T92@0P2FUYH209BDU080
TY:B0P20P80207IfMP80Ng]k0P20P8000`27QhL0QHF508F5Q@0208V9R@80Ph>30P21PH4208F5Q@80
Ogmo0P21PH4207emO@80PX:20P23Ph<208V9R@80SHf=7P38h=P001`0b>3H0P0[:b/202d];@H0;bl_
0P0^;Rh202d];@@0;2`/0P0_;bl2034a<@80;bl_00<0;2`/02d];@0];Bd00P0`<30203<c<`@0=CDe
0P0c<c<202`/;0809RHV100U9BD202<S8`808B4Q0P0N7Qh201lO7`80@4100P1TI6@209>CT`80Shn?
0P1cLg<205iNGP80IVIV0P2CTi<20;Ng]`80/k>c0P2/[:`00`2QXJ40YjNW0:NWY`020;2`/080/k>c
0P2e]KD20;bl_080`l?30P36a/H20<S8b080cLg=0P3:b/X20;Vi^@80W9bL0P1EEED405YJFP80IfMW
0P1_Kfl207QhN080O7al0P20P80208>3P`80QXJ60P28R8P208^;R`0308j>SP2@T900T92@0080SXj>
0P2<S8`208j>SP80T92@0P2BTY8209>CT`80TY:B0P2ATI42092@T080Shn?102>SXh2092@T080Ti>C
0P2EUID209BDU080RXZ:0P20P80207moO`80P8200P21PH4207moO`80M7Ad0P1ZJVX00`24Q8@0Ogmo
07moO`0208J6QP80QHF50P2>SXh207MgM`80Kfm_0P28R8P20820P080Ng]k0P2<S8`209fMW@80VYZJ
0P2CTi<209RHV080WIfM0P2KVi/209RHV080UIFE0P2CTi<208j>SP80R8R80P1nOWh207IfMP80N7Qh
0P1lO7`00`21PH40Q8B408B4Q00208B4Q080Ph>31022PX840861P@80Ogmo0P20P80208N7Q`80Shn?
0P2@T90W0<SPf080;Rh^0P0a<C4203<c<`80A4A4100Y:BT202/[:`@0;bl_0P0^;Rh202d];@80;Rh^
0P0Z:RX402`/;003030`<00b<S80<S8b0080=SHf0P0d=3@202d];@80:2PX0P0U9BD202HV9P808b<S
100R8R8202<S8`80<S8b0P1[Jf/208f=S@80UIFE0P1^KVh2069RHP80JFUY0P2@T9020;^k^`80]kNg
0P2RXZ820:6QX@80/;2`0P2][Jd20;Jf]P80^;Rh0P2l_;`40<C4a080bl_;00<0bLW90<G5a@35aLD0
0P35aLD209ZJVP80FEUI0P1ADE4205mOG`80IVIV0P1^KVh207IfMP80O7al0P21PH4208:2PP80RHV9
0P25QHD208b<S080SHf=0P2CTi<208F5Q@80SHf=0P2;Rh/2096AT@80U9BD0P2CTi<209:BTP80SXj>
0P2BTY8208f=S@80TI6A102@T90209JFUP0309FEU@2DU9@0U9BD0080SXj>0P23Ph<207MgM`@0PH61
0P1kNg/2075aL@80KVi^0P26QXH207moO`80R8R80P2:RXX208n?S`80Ng]k0P1/K6`208J6QP80RXZ:
0P21PH4208J6QP80YZJV102BTY8209NGU`80VIVI0P2GUiL209VIV@80TY:B102>SXh208B4Q00307mo
O`1eMGD0MGEe0080NGUi0P1oOgl408>3P`@0Q8B40P1oOgl20861P@80Ph>30P1nOWh207moO`80PX:2
0P28R8P208Z:RP80TI6A9`38h=P202`/;080;Rh^0P0_;bl4030`<080;bl_0P0];Bd602/[:`80=3@d
0P0`<3000`0];Bd0;2`/02`/;002030`<080<C4a0P0d=3@203<c<`80=3@d0P0^;Rh202HV9P808R8R
0P0U9BD201lO7`80820P0P0M7Ad202<S8`80?Shn0P1TI6@209:BTP80Shn?0P1bLW8205mOG`80IfMW
0P2CTi<20;Jf]P80/k>c0P2[Zj/00`2QXJ40[Jf]0:f][@020;2`/080/k>c0P2j^[X20;Jf]P80a<C4
0P36a/H20<O7a`80c/k>0P39bLT20;Rh^080V9RH0P1HF5P205YJFP80EeMG0P1XJ6P2071`L080NGUi
0P1jNWX207inOP80PX:20P27QhL208^;R`80QhN700<0SHf=096AT@2ATI40102<S8`208n?S`80T92@
0P2=SHd2096AT@80UiNG0P2ATI44092@T080SHf=0P2;Rh/408n?S`80UYJF0P2CTi<208R8R080P820
1021PH4207]kN`80Ogmo0P1fMWH206UYJ@0308F5Q@1mOGd0OGem0080Ph>30P25QHD208Z:RP80MWIf
0P1^KVh208V9R@@0OGem0P2;Rh/20:6QX@80Vi^K0P2DU9@209:BTP80WYjN0P2PX:0209NGU`80UIFE
0P2BTY82092@T080RHV90P1mOGd207QhN080NWYj0P1kNg/00`1oOgl0Ph>308>3P`0208J6QP80Q8B4
0P23Ph<20861P@@0P8200P22PX820820P080QHF50P2ATI4209FEUAh0b>3H000L0<SPf080:b/[0P0]
;Bd602l_;`80;Rh^0P0];Bd402`/;080;bl_0P0a<C4202l_;`0302`/;00];Bd0;Bd]0080<30`0P0c
<c<403De=@80<c<c0P0/;2`202HV9P@09BDU0P0S8b<2024Q8@807QhN0P0O7al20410@080I6AT0P2C
Ti<208n?S`80Lg=c0P1NGUh206IVIP80Ti>C0P2g]kL20;>c/`80[:b/00<0XJ6Q0:NWY`2WYjL00P2`
/;020;>c/`80]KFe0P2l_;`20<?3``80a/K60P38b<P20<g=c@80b/[:0P2i^KT209bLW080EEEE101J
FUX206MWI`80Kfm_0P1hN7P207alO080P8200P23Ph<208J6QP80R8R80P2;Rh/00`2>SXh0T92@092@
T00208j>SP80S8b<0P2>SXh2092@T080TY:B0P2CTi<209:BTP80TI6A0P2@T90208n?S`@0SXj>0P2@
T90209>CT`80UIFE0P2DU9@208Z:RP80P8200P1oOgl20820P080PH610P1oOgl207AdM080JVYZ00<0
Q8B407moO`1oOgl00P26QXH208F5Q@80SXj>0P1gMgL206m_K`80R8R80P20P80207]kN`80S8b<0P2M
WId209ZJVP80Ti>C0P2HV9P209fMW@80Vi^K0P2HV9P209FEU@80Ti>C0P2>SXh208R8R080OWin0P1f
MWH207QhN080O7al00<0PH6108B4Q024Q8@00P24Q8@208>3P`@0PX:21021PH4207moO`80P8200P27
QhL208n?S`80T92@9`38h=P202h^;P80<C4a0P0c<c<204A4A0@0:BTY0P0[:b/402l_;`80;Rh^0P0]
;Bd202h^;P80:RXZ100/;2`00`0`<300<S8b038b<P0203Hf=P80=3@d0P0];Bd202PX:0809BDU0P0V
9RH202<S8`@08R8R0P0S8b<2038b<P80Jf][0P2=SHd209FEU@80KVi^0P1RHV8206UYJ@80T92@0P2k
^k/20;Ng]`80XZ:R0P2QXJ420;2`/080[Jf]0P2f][H20;Rh^080_;bl1034a<@20<_;b`030<W9b@35
aLD0aLG50080aLG50P2JVYX205UIF@80DE5A0P1OGel206IVIP80KVi^0P1fMWH207alO080PH610P22
PX8208V9R@80QHF50P2<S8`208f=S@80Ti>C0P25QHD208f=S@80Rh^;0P2ATI4209BDU080Ti>C0P2B
TY8208j>SP80TY:B0P2=SHd2096AT@@0T92@0P2FUYH00`2EUID0U9BD09BDU00208j>SP80Ph>30P1g
MgL40861P@80Ng]k0P1aLG4206i^KP80QXJ60P1oOgl208R8R080RXZ:0P2?Shl207]kN`80K6a/0P26
QXH208Z:RP80PH610P26QXH20:JVYP@0TY:B0P2GUiL209VIV@80UiNG0P2IVIT209:BTP@0SXj>0P24
Q8@00`1oOgl0MGEe07EeM@0207UiN@80Ogmo1023Ph<408B4Q080Ogmo0P21PH4208>3P`80OWin0P1o
Ogl208:2PP80R8R80P2:RXX2096ATBL0b>3H0P0/;2`202h^;P80;bl_100`<30202l_;`80;Bd]1P0[
:b/203@d=080<30`00<0;Bd]02`/;00/;2`00P0`<302034a<@80=3@d0P0c<c<203@d=080;Rh^0P0V
9RH2028R8P809BDU0P0O7al2020P80807AdM0P0S8b<203hn?P80I6AT0P2BTY8208n?S`80LW9b0P1O
Gel206MWI`80Ti>C0P2f][H20;>c/`80Zj^[00<0XJ6Q0:f][@2][Jd00P2`/;020;>c/`80^[Zj0P2f
][H20<C4a080a/K60P37alL20<k>cP80bLW90P2h^;P209RHV080F5QH0P1JFUX205MGE`80J6QX0P1`
L70207UiN@80NWYj0P1nOWh208:2PP80QhN70P2;Rh/208N7Q`0308f=S@2ATI40TI6A00@0S8b<0P2?
Shl2092@T080SHf=0P2ATI4209NGU`80TI6A102@T90208f=S@80Rh^;102?Shl209JFUP80Ti>C0P28
R8P20820P0@0PH610P1kNg/207moO`80MWIf0P1YJFT00`25QHD0OGem07emO@0208>3P`80QHF50P2:
RXX207IfMP80KVi^0P29RHT407emO@80Rh^;0P2QXJ4209^KV`80U9BD0P2BTY8209jNWP80X:2P0P2G
UiL209FEU@80TY:B0P2@T90208V9R@80OGem0P1hN7P207YjNP80Ng]k00<0Ogmo08>3P`23Ph<00P26
QXH208B4Q080Ph>30P21PH440820P080PX:20P20P80208F5Q@80TI6A0P2EUIDN0<SPf0007038h=P2
02PX:080;2`/0P0_;bl202d];@P0:b/[0P0/;2`202l_;`80<S8b0P0_;bl00`0/;2`0;Bd]02d];@02
030`<080<c<c0P0f=SH203@d=080<C4a0P0[:b/402HV9P809bLW0P0U9BD202<S8`@07QhN0P0/;2`2
04=3@`80MWIf0P2NWYh20820P080GUiN0P1VIVH207AdM080_;bl0P2m_Kd20;:b/P0309fMW@2TY:@0
Y:BT0080[jn_0P2b/[820;Fe]@80^[Zj0P30`<020<G5a@80bLW90P38b<P20<G5a@80bLW90P32`/82
09^KV`80EUIF0P1HF5P206IVIP80KFe]0P1eMGD207YjNP80OWin0P23Ph<208N7Q`80R8R80P29RHT0
0`2;Rh/0S8b<08b<S00408b<S080SHf=0P2?Shl2092@T080TI6A0P2?Shl208j>SP80T92@0P2BTY82
096AT@@0T92@0P2?Shl2092@T080SXj>0P25QHD207]kN`80MWIf0P1dM7@207YjNP80OGem0P1[Jf/2
05QHF00308R8R01lO7`0O7al0080QHF50P21PH4209JFUP80K6a/0P1kNg/208>3P`80MgMg0P1]KFd2
08J6QP80WinO0P2KVi/209>CT`80W9bL0P2UYJD20:JVYP80XZ:R0P2LW9`209BDU080RXZ:0P22PX82
07alO0@0N7Qh0P1jNWX00`1nOWh0PX:208:2PP0408>3P`80PX:20P21PH4408:2PP@0P8200P29RHT2
09:BTP80U9BD9`38h=P202PX:080:b/[0P0];Bd202HV9P80;Bd]0P0Y:BT202d];@@0;2`/0P0`<304
03@d=080:b/[0P0Z:RX202l_;`0303Ti>@0h>3P0>3Ph0080;bl_0P0`<30202`/;0808b<S0P0W9bL2
02HV9P@08b<S0P0R8R82024Q8@809RHV0P16ATH207alO080VIVI0P20P802069RHP80G5aL0P1oOgl2
0;>c/`80`l?30P2][Jd209nOW`80ZJVY0P2ZZZX40;>c/`80^;Rh0P31`L420<;2`P80b<S800<0b/[:
0<G5a@35aLD00P37alL20<71`@80UYJF0P1IFET205=CD`80JFUY0P1/K6`207AdM0@0OWin0P23Ph<2
08R8R080QHF50P2:RXX408f=S@80RXZ:102>SXh2092@T0@0Shn?0P2ATI4208j>SP80S8b<0P2ATI42
09FEU@80Shn?0P2<S8`2092@T00308f=S@2>SXh0SXj>0080QHF50P21PH4206e]K@80MgMg0P20P802
07YjNP80KVi^0P1LG5`40820P080RHV90P26QXH208^;R`80LG5a0P1^KVh20820P080Ng]k0P1VIVH2
07emO@80YZJV0P2HV9P209>CT`80W9bL0P2UYJD20::RXP80Xj>S0P2IVIT209NGU`80RXZ:0P23Ph<0
0`1nOWh0NWYj07YjNP0207MgM`80NWYj0P1lO7`208:2PP@0Q8B40P1mOGd208>3P`80P8200P21PH42
0820P080OWin0P2:RXX209BDU080UIFE9`38h=P202TY:@80;Rh^0P0_;bl202h^;P80:RXZ0P0X:2P2
02`/;080;Bd]0P0/;2`2034a<@80<30`0P0^;Rh00`0[:b/0;Rh^02h^;P0202l_;`@0=SHf0P0e=CD2
030`<080:BTY0P0W9bL202TY:@809bLW0P0V9RH202DU9@8071`L0P0M7Ad202h^;P80A4A40P1fMWH2
09nOW`80OGem0P1NGUh206MWI`80LW9b0P2k^k/20<30`080/[:b00<0W9bL0:NWY`2WYjL00P2/[:`2
0;6a/@80];Bd0P2h^;P20<71`@80a/K60P3;bl/20<S8b080a<C40P3:b/X20<71`@80W9bL0P1HF5P2
05EEE@80IVIV0P1[Jf/207IfMP80O7al0P1oOgl20861P@80QHF5102:RXX00`2;Rh/0Shn?08n?S`02
08V9R@80T92@0P2;Rh/4092@T080Ti>C0P2@T90208n?S`80SXj>0P2DU9@208n?S`80TY:B102@T902
09BDU080SHf=0P24Q8@207YjNP80NGUi0P1dM7@207IfMP80P8200P1/K6`205IFEP0308^;R`1jNWX0
NWYj0080RHV90P23Ph<209>CT`80KVi^0P1lO7`208F5Q@80MGEe0P1/K6`208R8R080WYjN0P2IVIT2
09BDU080WinO0P2UYJD20:BTY080XJ6Q0P2LW9`209:BTP80S8b<0P21PH4207alO0@0N7Qh0P1iNGT0
0`1oOgl0PX:208:2PP0208>3P`@0PX:20P20P80208B4Q080PX:20P1nOWh208:2PP80R8R80P2@T902
09BDU1h0b>3H000L0<SPf080:2PX0P0/;2`202l_;`80;Bd]200[:b/202`/;080;bl_0P0b<S8202l_
;`0302`/;00];Bd0;Bd]0080<30`0P0c<c<203Hf=P80=3@d0P0a<C4202/[:`@09RHV0P0W9bL202DU
9@808b<S100N7Qh202`/;080@d=30P1fMWH209jNWP80P8200P1NGUh206IVIP80M7Ad0P2l_;`20;fm
_@80/[:b00<0WIfM0:BTY02TY:@00P2_[jl20;:b/P80]KFe0P2j^[X20<30`080aLG50P39bLT20<S8
b080aLG50P39bLT20<;2`P80Vi^K0P1FEUH205QHF080IVIV0P1]KFd207EeM@80NWYj0P1nOWh208>3
P`80QhN70P28R8P208V9R@0308^;R`2<S8`0S8b<00@0S8b<0P2=SHd208n?S`80T92@0P2ATI4208n?
S`80SXj>0P2@T90209:BTP80TI6A102@T90208n?S`80T92@0P2>SXh208F5Q@80Ng]k0P1fMWH207Ad
M080NWYj0P1mOGd206][J`80F5QH00<0R8R807alO01lO7`00P25QHD20861P@80UYJF0P1/K6`207]k
N`80Ph>30P1gMgL206e]K@80QXJ60P2OWil209^KV`80Ti>C0P2LW9`20:FUY@80YZJV0P2RXZ8209bL
W080U9BD0P2:RXX208:2PP80O7al101hN7P207YjNP0307inOP22PX80PX:200@0Ph>30P22PX820861
P@@0PX:21020P80208V9R@80TY:B0P2DU9@W0<SPf080:2PX0P0[:b/202d];@809RHV0P0];Bd202TY
:@80;Bd]100/;2`2030`<0@0=3@d0P0[:b/202XZ:P80;bl_00<0>CTi03Ph>00h>3P00P0_;bl2030`
<080;2`/0P0S8b<202LW9`809RHV100S8b<2028R8P808B4Q0P0V9RH204I6AP80O7al0P2IVIT20820
P080HV9R0P1LG5`207moO`80/k>c0P33`l<20:f][@80WinO0P2YZJT20:ZZZP@0/k>c0P2h^;P20<71
`@80`/;20P38b<P00`3:b/X0aLG50<G5a@020<O7a`80`L710P2FUYH205UIF@80De=C0P1YJFT206a/
K080M7Ad101nOWh208>3P`80R8R80P25QHD208Z:RP@0SHf=0P2:RXX408j>SP80T92@102?Shl2096A
T@80SXj>0P2<S8`2096AT@80UIFE0P2?Shl208b<S080T92@00<0SHf=08j>SP2>SXh00P25QHD20861
P@80KFe]0P1gMgL20820P080NWYj0P1^KVh205aLG0@0P8200P29RHT208J6QP80Rh^;0P1aLG4206i^
KP80P8200P1kNg/206IVIP80OGem0P2VYZH209RHV080Ti>C0P2LW9`20:FUY@80XZ:R0P2SXj<209VI
V@80UiNG0P2:RXX208>3P`0307inOP1jNWX0NWYj0080MgMg0P1jNWX207alO080PX:21024Q8@207em
O@80Ph>30P20P8020861P@80P8200P1nOWh208Z:RP80U9BD0P2EUIDW0<SPf080:BTY0P0^;Rh202l_
;`80;Rh^0P0Z:RX202PX:080;2`/0P0];Bd202`/;080<C4a0P0`<30202h^;P0302/[:`0^;Rh0;Rh^
0080;bl_100f=SH203De=@80<30`0P0Y:BT202LW9`80:BTY0P0W9bL202HV9P809BDU0P0L71`201dM
7@80;Rh^0P14A4@207IfMP80WinO0P1mOGd205iNGP80IfMW0P1bLW820;^k^`80`<300P2b/[800`2L
W9`0YjNW0:NWY`020:b/[080/K6a0P2d];@20;Rh^080`L710P36a/H20<_;b`80b<S80P34a<@20<[:
bP80`L710P2LW9`205QHF080EEEE0P1VIVH206][J`80MWIf0P1lO7`207moO`80PH610P25QHD408Z:
RP0308^;R`2?Shl0Shn?0080RHV90P2@T90208^;R`@0T92@0P2CTi<2092@T080Shn?0P2>SXh209BD
U080Shn?0P2BTY84092@T080U9BD0P2=SHd208B4Q080NWYj0P1iNGT207AdM080MWIf0P20P80206a/
K080EUIF00<0Rh^;07YjNP1jNWX00P29RHT208>3P`80Ti>C0P1^KVh207alO080QHF50P1eMGD206a/
K080R8R80P2NWYh209VIV@80U9BD0P2OWil20:FUY@80Y:BT0P2QXJ4209bLW080TY:B0P2<S8`20861
P@80O7al101hN7P207UiN@0307moO`22PX80PX:20080Ph>31022PX820820P080Q8B40P22PX8207in
OP80PX:20P28R8P2092@T080U9BD7P38h=P001`0b>3H200Z:RX202/[:`80;2`/100];Bd202h^;P80
;bl_0P0`<30202h^;P<0;2`/0P0];Bd2030`<0@0<c<c0P0a<C4202l_;`80;2`/0P0X:2P602DU9@80
8B4Q0P0P8202028R8P80<30`0P1ADE42092@T080UiNG0P1cLg<205MGE`80IVIV0P2TY:@20<30`080
^[Zj00<0ZJVY0:RXZ02XZ:P00P2YZJT20:j^[P80];Bd0P2i^KT20;fm_@80`l?30P37alL20<W9b@80
b<S80P3;bl/20<W9b@80/[:b0P2=SHd2071`L080G5aL0P1RHV8206m_K`80MWIf0P1lO7`20820P080
Ph>30P25QHD208J6QP0308N7Q`28R8P0R8R800@0QhN70P2;Rh/208n?S`@0T92@0P2?Shl208j>SP80
T92@0P2BTY8208n?S`80S8b<0P27QhL208>3P`80QhN70P29RHT208B4Q080O7al0P1aLG4206UYJ@80
LW9b0P1jNWX206UYJ@80FUYJ00<0O7al0820P020P8000P2:RXX208N7Q`80Ph>30P1MGEd206a/K080
MWIf0P1XJ6P205iNGP80P8200P2SXj<20:FUY@80XJ6Q0P2VYZH20:b/[080[Jf]0P2[Zj/20:FUY@80
W9bL0P2ATI4208N7Q`80Ogmo0P1kNg/207YjNP<0O7al0P1mOGd207moO`80PH611020P8020861P@80
Ph>30P21PH4208:2PP80RXZ:0P2CTi<209BDU2L0b>3H0P0/;2`202HV9P80:RXZ0P0];Bd202h^;P80
:b/[0P0`<30202l_;`80:b/[0P0];Bd202h^;P80<C4a0P0_;bl4030`<00303<c<`0b<S80<S8b0080
>CTi0P0c<c<202h^;P80:b/[0P0a<C4202@T90809RHV0P0R8R8202<S8`@0820P0P0Z:RX205iNGP80
RHV90P2LW9`206m_K`80FEUI0P1WIfL209bLW080`<300P32`/820::RXP80Y:BT0P2XZ:P20:n_[`80
/;2`0P2k^k/20;fm_@80`/;20P38b<P00`3>c/h0a/K60<K6aP020<G5a@80a/K60P32`/8209JFUP@0
H61P0P1YJFT206i^KP80MWIf0P1hN7P207moO`80QHF50P23Ph<208J6QP80Rh^;0P24Q8@208N7Q`@0
RHV90P2?Shl208f=S@80TY:B0P2ATI42092@T080Shn?102BTY8208V9R@80QXJ60P24Q8@00`28R8P0
RXZ:08Z:RP0208>3P`80NWYj0P1]KFd206QXJ080MgMg0P1mOGd206ATI080FEUI0P1fMWH20861P@80
PX:20P24Q8@207moO`80JFUY0P1ZJVX20820P080Lg=c0P1UIFD207moO`80WinO0P2SXj<20:RXZ080
YjNW0P2c/k<40:n_[`80Z:RX0P2NWYh2092@T080R8R800<0OGem07MgM`1gMgL00P1mOGd207QhN080
OWin0P1lO7`40861P@80PX:20P23Ph<208B4Q080QhN70P22PX820861P@80RXZ:0P2?Shl209JFURL0
b>3H0P0T92@202PX:080:BTY0P0Z:RX202`/;080;Bd]0P0/;2`202l_;`80:b/[0P0c<c<2034a<@80
;Bd]0`0^;Rh202/[:`80<30`100d=3@2038b<P80;Bd]100Y:BT202<S8`809RHV0P0T92@2028R8P80
7alO0P0R8R8202h^;P80DE5A0P2@T90209FEU@80MWIf0P1GEeL206YZJP80YJFU0P2m_Kd20;Vi^@03
0:JVYP2YZJT0ZJVY0080YZJV0P2`/;020;Bd]080^k^k0P2o_kl20<71`@80alO70P3;bl/20<S8b080
c<c<0P3;bl/20;Fe]@80Rh^;0P1^KVh205mOG`80IFEU0P1]KFd207AdM080OGem0P23Ph<408F5Q@80
QhN700<0QHF508N7Q`27QhL00P23Ph<208J6QP80SHf=0P2BTY8408n?S`80S8b<0P2:RXX2096AT@80
T92@0P2?Shl208j>SP80R8R80P20P80208Z:RP80R8R80P23Ph<207]kN`80LG5a0P1[Jf/206m_K`80
NGUi0P1ZJVX205]KF`0307emO@1oOgl0Ogmo0080Rh^;0P25QHD208>3P`80GemO0P1XJ6P207IfMP80
JVYZ0P1QHF4207moO`80Xj>S0P2UYJD209nOW`80Y:BT0P2ZZZX20:f][@80[:b/0P2WYjL209^KV`80
Ti>C0P25QHD20820P080N7Qh0P1mOGd207alO00307moO`1lO7`0O7al0080Ogmo0P21PH4207inOP80
Ogmo0P27QhL20861P@80Ogmo0P20P80208Z:RP@0Ti>C7P38h=P001`0b>3H200Z:RX202/[:`80;2`/
100];Bd202h^;P80;bl_0P0`<30202h^;P<0;2`/0P0];Bd2030`<0@0<c<c0P0a<C4202l_;`80;2`/
0P0X:2P602DU9@808B4Q0P0P8202028R8P80<30`0P1ADE42092@T080UiNG0P1cLg<205MGE`80IVIV
0P2TY:@20<30`080^[Zj00<0ZJVY0:RXZ02XZ:P00P2YZJT20:j^[P80];Bd0P2i^KT20;fm_@80`l?3
0P37alL20<W9b@80b<S80P3;bl/20<W9b@80/[:b0P2=SHd2071`L080G5aL0P1RHV8206m_K`80MWIf
0P1lO7`20820P080Ph>30P25QHD208J6QP0308N7Q`28R8P0R8R800@0QhN70P2;Rh/208n?S`@0T92@
0P2?Shl208j>SP80T92@0P2BTY8208n?S`80S8b<0P27QhL208>3P`80QhN70P29RHT208B4Q080O7al
0P1aLG4206UYJ@80LW9b0P1jNWX206UYJ@80FUYJ00<0O7al0820P020P8000P2:RXX208N7Q`80Ph>3
0P1MGEd206a/K080MWIf0P1XJ6P205iNGP80P8200P2SXj<20:FUY@80XJ6Q0P2VYZH20:b/[080[Jf]
0P2[Zj/20:FUY@80W9bL0P2ATI4208N7Q`80Ogmo0P1kNg/207YjNP<0O7al0P1mOGd207moO`80PH61
1020P8020861P@80Ph>30P21PH4208:2PP80RXZ:0P2CTi<209BDU2L0b>3H0P0/;2`202HV9P80:RXZ
0P0];Bd202h^;P80:b/[0P0`<30202l_;`80:b/[0P0];Bd202h^;P80<C4a0P0_;bl4030`<00303<c
<`0b<S80<S8b0080>CTi0P0c<c<202h^;P80:b/[0P0a<C4202@T90809RHV0P0R8R8202<S8`@0820P
0P0Z:RX205iNGP80RHV90P2LW9`206m_K`80FEUI0P1WIfL209bLW080`<300P32`/820::RXP80Y:BT
0P2XZ:P20:n_[`80/;2`0P2k^k/20;fm_@80`/;20P38b<P00`3>c/h0a/K60<K6aP020<G5a@80a/K6
0P32`/8209JFUP@0H61P0P1YJFT206i^KP80MWIf0P1hN7P207moO`80QHF50P23Ph<208J6QP80Rh^;
0P24Q8@208N7Q`@0RHV90P2?Shl208f=S@80TY:B0P2ATI42092@T080Shn?102BTY8208V9R@80QXJ6
0P24Q8@00`28R8P0RXZ:08Z:RP0208>3P`80NWYj0P1]KFd206QXJ080MgMg0P1mOGd206ATI080FEUI
0P1fMWH20861P@80PX:20P24Q8@207moO`80JFUY0P1ZJVX20820P080Lg=c0P1UIFD207moO`80WinO
0P2SXj<20:RXZ080YjNW0P2c/k<40:n_[`80Z:RX0P2NWYh2092@T080R8R800<0OGem07MgM`1gMgL0
0P1mOGd207QhN080OWin0P1lO7`40861P@80PX:20P23Ph<208B4Q080QhN70P22PX820861P@80RXZ:
0P2?Shl209JFURL0b>3H0P0T92@202PX:080:BTY0P0Z:RX202`/;080;Bd]0P0/;2`202l_;`80:b/[
0P0c<c<2034a<@80;Bd]0`0^;Rh202/[:`80<30`100d=3@2038b<P80;Bd]100Y:BT202<S8`809RHV
0P0T92@2028R8P807alO0P0R8R8202h^;P80DE5A0P2@T90209FEU@80MWIf0P1GEeL206YZJP80YJFU
0P2m_Kd20;Vi^@030:JVYP2YZJT0ZJVY0080YZJV0P2`/;020;Bd]080^k^k0P2o_kl20<71`@80alO7
0P3;bl/20<S8b080c<c<0P3;bl/20;Fe]@80Rh^;0P1^KVh205mOG`80IFEU0P1]KFd207AdM080OGem
0P23Ph<408F5Q@80QhN700<0QHF508N7Q`27QhL00P23Ph<208J6QP80SHf=0P2BTY8408n?S`80S8b<
0P2:RXX2096AT@80T92@0P2?Shl208j>SP80R8R80P20P80208Z:RP80R8R80P23Ph<207]kN`80LG5a
0P1[Jf/206m_K`80NGUi0P1ZJVX205]KF`0307emO@1oOgl0Ogmo0080Rh^;0P25QHD208>3P`80GemO
0P1XJ6P207IfMP80JVYZ0P1QHF4207moO`80Xj>S0P2UYJD209nOW`80Y:BT0P2ZZZX20:f][@80[:b/
0P2WYjL209^KV`80Ti>C0P25QHD20820P080N7Qh0P1mOGd207alO00307moO`1lO7`0O7al0080Ogmo
0P21PH4207inOP80Ogmo0P27QhL20861P@80Ogmo0P20P80208Z:RP@0Ti>C7P38h=P001`0b>3H0P0/
;2`202PX:0809BDU0P0W9bL202/[:`80;Rh^1P0`<30202l_;`80;Rh^0`0_;bl202d];@80:b/[0P0]
;Bd2030`<0@0<C4a0P0c<c<2038b<P80:b/[0P0S8b<202@T90809RHV0P0T92@202<S8`807QhN0P0V
9RH2030`<080MgMg0P2TY:@208^;R`80DE5A0P1OGel208N7Q`80^[Zj0P2o_kl00`2i^KT0[Zj^0:j^
[P020:BTY080ZJVY0P2b/[820;Ng]`80^k^k0P30`<020<C4a080bLW90P3;bl/20<S8b080`/;20P36
a/H20<71`@80Shn?0P1OGel205eMG@80JFUY0P1aLG4207YjNP80OGem0P1oOgl20861P@80Ph>30`24
Q8@408:2PP80R8R80P2?Shl4092@T080Shn?0P2>SXh408n?S`80Rh^;0P25QHD207alO080MWIf0P1k
Ng/20861P@80P8200P1kNg/206i^KP80I6AT0P1^KVh207UiN@80Kfm_0P1VIVH00`1cLg<0QhN708N7
Q`0208f=S@@0Shn?0P2DU9@209nOW`80Z:RX0P2OWil209JFUP80W9bL0P2VYZH20:VYZ@80Zj^[0P2/
[:`20:j^[P@0[jn_0P2YZJT20:2PX080UYJF0P2<S8`208B4Q080OWin101mOGd00`1jNWX0MgMg07Mg
M`0207YjNP80OWin101oOgl20861P@@0Ph>30P24Q8@208^;R`80TY:B0P2DU9@W0<SPf080<30`0P0Z
:RX202<S8`80:BTY0P0Z:RX202l_;`80;2`/0P0f=SH202d];@80;Rh^0P0_;bl4030`<080:b/[0P0Z
:RX00`0[:b/0<S8b038b<P0202`/;080>SXj0P0];Bd203Ti>@80:2PX0P0T92@202DU9@8092@T0P0U
9BD202<S8`@08R8R0P0i>CT207MgM`80W9bL0P27QhL205mOG`80HF5Q0P21PH420;Ng]`80b/[:0P2i
^KT20:JVYP80YjNW0P2ZZZX20;6a/@80][Jf0P2j^[X20;jn_P80`l?300<0b/[:0<_;b`3;bl/00P39
bLT40<;2`P80_kno0P2:RXX205iNGP80GemO0P1XJ6P207EeM@80MgMg0P21PH4208:2PP80O7al0P22
PX8208Z:RP80PH610P27QhL208:2PP80QHF50P2BTY8208j>SP@0Shn?0P2=SHd408n?S`80SHf=0P26
QXH207QhN080MWIf00<0OGem07inOP1nOWh00P1oOgl207inOP80K6a/0P1]KFd206][J`80O7al0P1_
Kfl2061PH080NWYj0P25QHD208R8R080TY:B0P2FUYH2096AT@80Ti>C0P2WYjL20:2PX080SHf=0P2O
Wil20::RXP80Y:BT0P2_[jl40:b/[080Zj^[0P2^[Zh20:f][@80WinO0P2DU9@208b<S00308>3P`1n
OWh0OWin0080P8200P1lO7`207moO`80M7Ad0P1kNg/208:2PP80Ng]k0P1nOWh20820P0@0Ph>30P26
QXH208f=S@80TY:B0P2EUIDW0<SPf080;2`/0P0[:b/202@T9080:BTY0P0Z:RX202`/;080<30`0P0b
<S82034a<@80:RXZ0P0];Bd202l_;`0302h^;P0Z:RX0:RXZ0080:RXZ100a<C42030`<080<C4a0P0b
<S8203@d=080:2PX0P0T92@402DU9@809bLW0P0R8R8201dM7@809RHV0P0b<S8207MgM`80WinO0P2<
S8`2055AD@80GUiN0P2:RXX20;Zj^P80`<3000<0^;Rh0;:b/P2b/[800P2QXJ420:ZZZP80/;2`0P2d
];@20;bl_080`<300P35aLD40<_;b`80alO70P32`/820<O7a`80`L710P2>SXh405eMG@80J6QX0P1`
L70207QhN080PH610P20P80207inOP80QXJ60`23Ph<208B4Q080PH610P2:RXX208b<S080Shn?0P2B
TY8208j>SP80Shn?0P2@T902096AT@80RHV90P27QhL207UiN@80MgMg0P1jNWX20820P080Q8B40P1k
Ng/206e]K@80I6AT0P1^KVh207]kN`80Jf][0P1WIfL00`1bLW80QhN708N7Q`0208Z:RP80SXj>0P2C
Ti<209FEU@80Vi^K0P2ZZZX20:2PX080UiNG0P2HV9P20:JVYP80[jn_0P2YZJT20:b/[080[Zj^0P2b
/[820:f][@80ZJVY0P2PX:0209NGU`80Rh^;0P22PX8207moO`80Ng]k0P1mOGd00`1iNGT0MWIf07If
MP0207YjNP80PH610P1nOWh40861P@80PX:20P24Q8@208>3P`80SHf=102CTi<N0<SPf0007038h=P2
02`/;080:2PX0P0U9BD202LW9`80:b/[0P0^;Rh6030`<080;bl_0P0^;Rh302l_;`80;Bd]0P0[:b/2
02d];@80<30`100a<C4203<c<`80<S8b0P0[:b/202<S8`8092@T0P0V9RH202@T90808b<S0P0N7Qh2
02HV9P80<30`0P1gMgL20:BTY080Rh^;0P1ADE4205mOG`80QhN70P2j^[X20;no_`030;Vi^@2^[Zh0
[Zj^0080Y:BT0P2YZJT20;:b/P80]kNg0P2k^k/20<30`080a<C40P39bLT20<_;b`80b<S80P32`/82
0<K6aP80`L710P2?Shl205mOG`80GEeM0P1YJFT2075aL@80NWYj0P1mOGd207moO`80PH610P23Ph<3
08B4Q0@0PX:20P28R8P208n?S`@0T92@0P2?Shl208j>SP@0Shn?0P2;Rh/208F5Q@80O7al0P1fMWH2
07]kN`80PH610P20P80207]kN`80KVi^0P1TI6@206i^KP80NGUi0P1_Kfl206IVIP0307=cL`27QhL0
QhN70080SHf=102?Shl209BDU080WinO0P2XZ:P209nOW`80UYJF0P2LW9`20:JVYP80ZJVY0P2[Zj/2
0:b/[080[Zj^102_[jl20:VYZ@80X:2P0P2FUYH208b<S080Q8B40P1nOWh407emO@0307YjNP1gMgL0
MgMg0080NWYj0P1nOWh407moO`80PH611023Ph<208B4Q080Rh^;0P2BTY8209BDU2L0b>3H0P0`<302
02XZ:P808b<S0P0Y:BT202XZ:P80;bl_0P0/;2`203Hf=P80;Bd]0P0^;Rh202l_;`@0<30`0P0[:b/2
02XZ:P0302/[:`0b<S80<S8b0080;2`/0P0j>SX202d];@80>CTi0P0X:2P202@T90809BDU0P0T92@2
02DU9@808b<S100R8R8203Ti>@80MgMg0P2LW9`208N7Q`80GemO0P1QHF420861P@80]kNg0P3:b/X2
0;Vi^@80YZJV0P2WYjL20:ZZZP80/K6a0P2f][H20;Zj^P80_[jn0P33`l<00`3:b/X0bl_;0<_;b`02
0<W9b@@0`/;20P2o_kl208Z:RP80GUiN0P1OGel206QXJ080MGEe0P1gMgL20861P@80PX:20P1lO7`2
08:2PP80RXZ:0P21PH4208N7Q`80PX:20P25QHD209:BTP80SXj>102?Shl208f=S@@0Shn?0P2=SHd2
08J6QP80N7Qh0P1fMWH00`1mOGd0OWin07inOP0207moO`80OWin0P1/K6`206e]K@80Jf][0P1lO7`2
06m_K`80H61P0P1jNWX208F5Q@80R8R80P2BTY8209JFUP80TI6A0P2CTi<20:NWY`80X:2P0P2=SHd2
09nOW`80XZ:R0P2TY:@20:n_[`@0[:b/0P2[Zj/20:j^[P80[Jf]0P2OWil209BDU080S8b<00<0Ph>3
07inOP1nOWh00P20P80207alO080Ogmo0P1dM7@207]kN`80PX:20P1kNg/207inOP80P8201023Ph<2
08J6QP80SHf=0P2BTY8209FEUBL0b>3H0P0/;2`202/[:`8092@T0P0Y:BT202XZ:P80;2`/0P0`<302
038b<P80<C4a0P0Z:RX202d];@80;bl_00<0;Rh^02XZ:P0Z:RX00P0Z:RX4034a<@80<30`0P0a<C42
038b<P80=3@d0P0X:2P202@T90@09BDU0P0W9bL2028R8P807AdM0P0V9RH2038b<P80MgMg0P2OWil2
08b<S080DE5A0P1NGUh208Z:RP80^[Zj0P30`<000`2h^;P0/[:b0;:b/P020:6QX@80ZZZZ0P2`/;02
0;Bd]080_;bl0P30`<020<G5a@@0bl_;0P37alL20<;2`P80alO70P31`L4208j>SP@0GEeM0P1XJ6P2
071`L080N7Qh0P21PH420820P080OWin0P26QXH308>3P`80Q8B40P21PH4208Z:RP80S8b<0P2?Shl2
09:BTP80SXj>0P2?Shl2092@T080TI6A0P29RHT208N7Q`80NGUi0P1gMgL207YjNP80P8200P24Q8@2
07]kN`80KFe]0P1TI6@206i^KP80Ng]k0P1[Jf/206MWI`03079bLP27QhL0QhN70080RXZ:0P2>SXh2
09>CT`80UIFE0P2KVi/20:ZZZP80X:2P0P2GUiL209RHV080YZJV0P2_[jl20:VYZ@80[:b/0P2^[Zh2
0;:b/P80[Jf]0P2YZJT20:2PX080UiNG0P2;Rh/208:2PP80Ogmo0P1kNg/207emO@0307UiN@1fMWH0
MWIf0080NWYj0P21PH4207inOP@0PH610P22PX8208B4Q080Ph>30P2=SHd409>CTah0b>3H000L0<SP
f080:b/[0P0W9bL202<S8`809BDU0P0Y:BT202d];@80<30`0P0a<C42030`<0@0;bl_0P0d=3@00`0i
>CT0=3@d03@d=00402l_;`@0<C4a0P0b<S8203De=@80=cLg0P0`<30202TY:@809bLW0P0V9RH202@T
90808b<S0P0Q8B4202LW9`809RHV0P1FEUH208^;R`80UIFE0P1fMWH205MGE`80LG5a0P2LW9`20;bl
_0030<[:bP2e]KD0]KFe0080X:2P0P2SXj<20:f][@80/[:b0P2h^;P20;bl_080`<300P37alL20<_;
b`80bLW90P36a/H40<S8b080[Jf]0P2>SXh2075aL@80GEeM0P1VIVH207MgM`80Ng]k0P1nOWh207mo
O`80P82000<0PX:208>3P`23Ph<00P20P80207moO`80R8R8102ATI44092@T080Shn?0P2=SHd208^;
R`80QXJ60P1oOgl207MgM`80Kfm_0P1YJFT206MWI`80KFe]1P1dM7@207emO@80QXJ60P27QhL208R8
R00308f=S@2HV9P0V9RH0080Vi^K0P2OWil20:2PX080YjNW0P2_[jl20;Bd]080/K6a0P2][Jd20:ZZ
ZP80Zj^[0P2k^k/20<K6aP80];Bd0P2OWil409fMW@80TY:B0P2;Rh/208R8R080QhN70P24Q8@208:2
PP80Ogmo0P1lO7`00`1iNGT0MWIf07IfMP0207QhN080O7al0P1oOgl808:2PP80Ph>30P2<S8`209BD
U080UYJF9`38h=P202PX:08092@T0P0U9BD202/[:`809BDU0P0/;2`202l_;`80=3@d0P0b<S82034a
<@80<30`0P0a<C4203Ph>080<S8b0P0^;Rh00`0i>CT0<30`030`<002034a<@80;bl_0P0Z:RX203Ph
>080;bl_0P0W9bL202HV9P80;Bd]0P0R8R82024Q8@807alO0P0S8b<202`/;080DU9B0P24Q8@209nO
W`80KFe]0P1FEUH206a/K080Vi^K0P32`/820<_;b`80[jn_0P2SXj<20:NWY`80[:b/0P2f][H20;Vi
^@80_;bl0P2n_[h00`38b<P0bLW90<W9b@020<[:bP80a/K60P34a<@20<G5a@80_[jn0P2DU9@2069R
HP80G5aL0P1/K6`207QhN080Ng]k0P1lO7`207]kN`80PH610P26QXH207inOP80PH610P1mOGd208B4
Q0@0Ti>C0P2ATI42092@T080Shn?0P2=SHd208N7Q`80R8R80P21PH42071`L080KFe]00<0LW9b06UY
J@1YJFT00P1/K6`207QhN080LW9b0P1_Kfl207AdM0@0QHF50P2?Shl209NGU`80Vi^K0P2GUiL209jN
WP80ZJVY0P2WYjL20:b/[0@0/[:b0P2ZZZX20;6a/@80];Bd0P2k^k/20;fm_@80/K6a0P2PX:0209^K
V`80UiNG0P2DU9@408R8R080RHV900<0Q8B408>3P`23Ph<00P1nOWh207UiN@80MgMg0P1iNGT207=c
L`80N7Qh0P20P80208>3P`80PH610P20P80207UiN@80PX:20P2=SHd209BDU080UiNG9`38h=P202d]
;@809RHV0P0S8b<202HV9P80:b/[0P0X:2P203<c<`80<30`0P0a<C4202h^;P80<S8b0P0f=SH00`0l
?3`0=CDe03De=@02034a<@80<30`0P0];Bd2030`<080<S8b0P0h>3P203Lg=`80<30`0P0X:2P202HV
9P808b<S0P0U9BD202<S8`807AdM0P0X:2P202TY:@80F5QH0P27QhL209JFUP80N7Qh0P1CDe<2071`
L080Vi^K0P2n_[h00`37alL0][Jf0;Jf]P020::RXP80Xj>S102`/;020;Vi^@80^k^k0P2m_Kd20<O7
a`80b/[:0P37alL20<?3``80b/[:0P39bLT20:f][@80T92@0P1aLG42061PH080JFUY0P1cLg<207em
O@80N7Qh0P1oOgl20820P00308>3P`25QHD0QHF50080QHF50P1kNg/208b<S080Shn?0P2CTi<2096A
T@80Shn?0P2DU9@408^;R`80QXJ60P1mOGd207IfMP80KVi^0P1[Jf/206IVIP80KVi^0P1dM7@2079b
LP80MGEe0P1nOWh408N7Q`80R8R800<0Shn?09RHV02HV9P00P2MWId209jNWP80YZJV0P2UYJD20:n_
[`80]KFe0P2b/[820:f][@80YZJV0P2/[:`20;^k^`80alO70P2b/[8209nOW`80Vi^K0P2OWil2092@
T080S8b<0P25QHD208R8R080QhN70P23Ph<207inOP80Ng]k00<0O7al07IfMP1fMWH00P1iNGT407]k
N`80Ogmo0P23Ph<20861P@80PX:20P26QXH208b<S080U9BD0P2EUIDN0<SPf0007038h=P202/[:`80
9bLW0P0S8b<202DU9@80:BTY0P0];Bd2030`<080<C4a0P0`<30402l_;`80=3@d00<0>CTi03@d=00d
=3@0100_;bl4034a<@80<S8b0P0e=CD203Lg=`80<30`0P0Y:BT202LW9`809RHV0P0T92@202<S8`80
8B4Q0P0W9bL202HV9P80EUIF0P2;Rh/209FEU@80MWIf0P1GEeL2075aL@80W9bL0P2l_;`00`3:b/X0
]KFe0;Fe]@020:2PX080Xj>S0P2][Jd20;:b/P80^;Rh0P2l_;`20<30`080alO70P3;bl/20<W9b@80
a/K61038b<P20:f][@80SXj>0P1aLG4205eMG@80IVIV0P1gMgL207]kN`80OWin0P1oOgl20820P003
08:2PP23Ph<0Ph>30080P8200P1oOgl208R8R0@0TI6A102@T90208n?S`80SHf=0P2;Rh/208J6QP80
Ogmo0P1gMgL206m_K`80JFUY0P1WIfL206e]K@H0M7Ad0P1mOGd208J6QP80QhN70P28R8P00`2=SHd0
V9RH09RHV00209^KV`80WinO0P2PX:020:NWY`80[jn_0P2d];@20;6a/@80[Jf]0P2ZZZX20:^[Z`80
^k^k0P36a/H20;Bd]080WinO102MWId209:BTP80Rh^;0P28R8P208N7Q`80Q8B40P22PX8207moO`80
O7al00<0NGUi07IfMP1fMWH00P1hN7P207alO080Ogmo2022PX8208>3P`80S8b<0P2DU9@209JFURL0
b>3H0P0X:2P202@T90809BDU0P0[:b/202DU9@80;2`/0P0_;bl203@d=080<S8b0P0a<C42030`<080
<C4a0P0h>3P2038b<P80;Rh^00<0>CTi030`<00`<3000P0a<C4202l_;`80:RXZ0P0h>3P202l_;`80
9bLW0P0V9RH202d];@808R8R0P0Q8B4201lO7`808b<S0P0/;2`2059BDP80Q8B40P2OWil206e]K@80
EUIF0P1/K6`209^KV`80`/;20P3;bl/20:n_[`80Xj>S0P2WYjL20:b/[080][Jf0P2i^KT20;bl_080
_[jn00<0b<S80<W9b@39bLT00P3:b/X20<K6aP80a<C40P35aLD20;jn_P80U9BD0P1RHV8205aLG080
K6a/0P1hN7P207]kN`80O7al0P1kNg/20861P@80QXJ60P1nOWh20861P@80OGem0P24Q8@409>CT`80
TI6A0P2@T90208n?S`80SHf=0P27QhL208R8R080PH610P1`L70206e]K@03079bLP1YJFT0JFUY0080
K6a/0P1hN7P2079bLP80Kfm_0P1dM7@408F5Q@80Shn?0P2GUiL209^KV`80UiNG0P2NWYh20:VYZ@80
YjNW0P2/[:`40;:b/P80ZZZZ0P2a/K420;Bd]080^k^k0P2m_Kd20;6a/@80X:2P0P2KVi/209NGU`80
U9BD1028R8P208V9R@0308B4Q023Ph<0Ph>30080OWin0P1iNGT207MgM`80NGUi0P1cLg<207QhN080
P8200P23Ph<20861P@80P8200P1iNGT208:2PP80SHf=0P2DU9@209NGUbL0b>3H0P0];Bd202HV9P80
8b<S0P0V9RH202/[:`80:2PX0P0c<c<2030`<080<C4a0P0^;Rh2038b<P80=SHf00<0?3`l03De=@0e
=CD00P0a<C42030`<080;Bd]0P0`<302038b<P80>3Ph0P0g=cL2030`<080:2PX0P0V9RH202<S8`80
9BDU0P0S8b<201dM7@80:2PX0P0Y:BT205QHF080QhN70P2FUYH207QhN080De=C0P1`L70209^KV`80
_[jn00<0alO70;Jf]P2f][H00P2RXZ820:>SX`@0/;2`0P2i^KT20;^k^`80_Kfm0P37alL20<[:bP80
alO70P33`l<20<[:bP80bLW90P2][Jd2092@T080LG5a0P1PH60206UYJ@80Lg=c0P1mOGd207QhN080
Ogmo0P20P8000`23Ph<0QHF508F5Q@0208F5Q@80Ng]k0P2<S8`208n?S`80Ti>C0P2ATI4208n?S`80
U9BD102;Rh/208J6QP80OGem0P1fMWH206i^KP80Jf][0P1VIVH206i^KP80M7Ad0P1bLW8207EeM@80
OWin1027QhL208R8R00308n?S`2HV9P0V9RH0080WIfM0P2NWYh20:JVYP80YJFU0P2_[jl20;Fe]@80
/[:b0P2][Jd20:JVYP80[:b/0P2k^k/20<O7a`80/[:b0P2OWil209^KV`80WinO0P2@T90208b<S080
QHF50P28R8P208N7Q`80Ph>30P1nOWh207]kN`0307alO01fMWH0MWIf0080NGUi101kNg/207moO`80
Ph>30P21PH4208:2PP80QXJ60P2<S8`209BDU080UIFE7P38h=P001`0b>3H0P0[:b/202LW9`@092@T
0P0W9bL202`/;080<C4a0P0b<S82034a<@@0<30`0P0i>CT00`11@D40>c/k03/k>`0203<c<`H0<C4a
0P0b<S8203Hf=P80>CTi0P0d=3@202h^;P80:BTY0P0V9RH402<S8`809RHV0P0];Bd2028R8P80>c/k
0P1[Jf/209BDU080VYZJ0P1GEeL206=SH`80Ng]k0P2][Jd00`3Bd]80^k^k0;^k^`0209jNWP80WinO
0P2WYjL20:j^[P80]KFe0P2h^;P20;bl_080`l?3103:b/X20<S8b080a/K60P33`l<20<G5a@80_[jn
0P2=SHd205iNGP80Hf=S0P1dM7@207UiN@80O7al0P1mOGd207inOP030820P021PH40PH610080OWin
0P1mOGd208N7Q`@0TI6A102?Shl208f=S@80RHV90P23Ph<207alO080MGEe0P1_Kfl206QXJ080Fe]K
0P1CDe<205iNGP80KVi^0P1kNg/208F5Q@80Rh^;0P2?Shl209VIV@80XJ6Q00<0Xj>S0:BTY02TY:@0
0P2XZ:P20:j^[P80];Bd0P2k^k/20;no_`80`L711034a<@20;jn_P80][Jf0P2ZZZX209nOW`80V9RH
0P2BTY8208j>SP80RXZ:0P1lO7`207AdM080N7Qh0P20P80208>3P`80Q8B40P20P80207YjNP0307Mg
M`1fMWH0MWIf0080MgMg0P1jNWX207moO`80Q8B40P23Ph<40861P@80Ph>30P2<S8`209JFUP80V9RH
9`38h=P202`/;0809bLW0P0T92@202LW9`80:BTY0P0a<C4203@d=080;2`/0P0a<C4202d];@80<30`
0P0l?3`20410@080>SXj0P0f=SH00`0^;Rh0;2`/02`/;002030`<080<S8b0P14A4@203/k>`80;bl_
0P0d=3@202/[:`808b<S0P0W9bL202DU9@808R8R0P0/;2`202TY:@80>c/k0P1^KVh2096AT@80Ti>C
0P1OGel2061PH080O7al0P2/[:`20<k>cP80_kno0P2NWYh20:>SX`80YZJV0P2^[Zh20;Bd]080^[Zj
0P2k^k/00`35aLD0b<S80<S8b0020<[:bP80b<S80P36a/H20<C4a080_kno0P2l_;`208n?S`80H61P
0P1RHV8207MgM`80NGUi101kNg/207moO`@0PH610P20P80207inOP80R8R80P2@T90209>CT`80T92@
102=SHd208b<S080PX:20P1lO7`207AdM080Jf][0P1SHf<00`1YJFT0De=C05=CD`0204];B`80LG5a
0P1mOGd208N7Q`80RXZ:0P2BTY8209FEU@@0WIfM0P2OWil20:RXZ080[Jf]0P2`/;040;^k^`80`L71
0P34a<@20<71`@80^KVi0P2_[jl20:NWY`80ZZZZ0P2KVi/209:BTP80SXj>0P27QhL207alO080MGEe
0P1fMWH208:2PP030820P026QXH0QXJ60080OWin0P1mOGd207QhN080MgMg0P1iNGT207]kN`80P820
1022PX8208F5Q@80P8200P24Q8@208j>SP80U9BD0P2JVYXW0<SPf080:b/[0P0W9bL202@T90808B4Q
0P0Y:BT202XZ:P80<S8b0P0`<30203<c<`80;bl_0P0a<C4203Lg=`030492@P0l?3`0?3`l0080<C4a
0P0f=SH2034a<@80;Rh^0P0`<30203De=@80>3Ph0P0e=CD2030`<080:RXZ0P0V9RH202<S8`808B4Q
0P0U9BD202`/;080820P0P0k>c/206a/K080T92@0P2QXJ4205ADE080IfMW0P1jNWX20:j^[P030=;B
dP2m_Kd0_Kfm0080WYjN0P2LW9`20:RXZ080/;2`0P2c/k<20;Rh^080_Kfm0P32`/820<W9b@80b/[:
0P39bLT20<K6aP80`l?30P35aLD20;no_`80RXZ:0P1LG5`206IVIP80Lg=c101lO7`207inOP<0OGem
101nOWh207alO080R8R80P2?Shl4092@T080SHf=0P2<S8`208^;R`80PX:20P1jNWX207IfMP80LW9b
0P1XJ6P205UIF@80De=C0P1MGEd206m_K`80OGem0P27QhL208^;R`80T92@0P2HV9P20:2PX0030:>S
X`2RXZ80XZ:R0080ZZZZ0P2/[:`20;:b/P80_;bl0P2n_[h20<;2`P80`l?30P34a<@20;fm_@80]KFe
0P2ZZZX20:6QX@80U9BD0P2BTY82096AT@80RXZ:0P1kNg/207EeM@80NGUi0P1oOgl208F5Q@@0PX:2
0P1hN7P00`1iNGT0LW9b079bLP0207alO080NWYj0P20P80408F5Q@80Ph>30P1nOWh208B4Q080S8b<
102HV9PN0<SPf0007038h=P202/[:`809bLW100T92@202LW9`80;2`/0P0a<C42038b<P80<C4a100`
<30203Ti>@030451@@0k>c/0>c/k0080<c<c1P0a<C42038b<P80=SHf0P0i>CT203@d=080;Rh^0P0Y
:BT202HV9P@08b<S0P0V9RH202d];@808R8R0P0k>c/206][J`80U9BD0P2JVYX205MGE`80Hf=S0P1k
Ng/20:f][@030=;BdP2k^k/0^k^k0080WYjN0P2OWil20:NWY`80[Zj^0P2e]KD20;Rh^080_;bl0P33
`l<40<[:bP80b<S80P36a/H20<?3``80aLG50P2n_[h208f=S@80GUiN0P1SHf<207AdM080NGUi0P1l
O7`207emO@80OWin00<0P8200861P@21PH400P1nOWh207emO@80QhN7102ATI4408n?S`80SHf=0P29
RHT208>3P`80O7al0P1eMGD206m_K`80J6QX0P1KFe/205=CD`80GUiN0P1^KVh207]kN`80QHF50P2;
Rh/208n?S`80VIVI0P2QXJ400`2SXj<0Y:BT0:BTY0020:RXZ080[Zj^0P2d];@20;^k^`80_kno0P31
`L440<C4a080_[jn0P2f][H20:ZZZP80WinO0P2HV9P209:BTP80SXj>0P2:RXX207alO080M7Ad0P1h
N7P20820P080Ph>30P24Q8@20820P080NWYj00<0MgMg07IfMP1fMWH00P1gMgL207YjNP80Ogmo0P24
Q8@208>3P`@0PH610P23Ph<208b<S080UYJF0P2HV9PW0<SPf080;2`/0P0W9bL202@T90809bLW0P0Y
:BT2034a<@80=3@d0P0/;2`2034a<@80;Bd]0P0`<30203`l?080@4100P0j>SX203Hf=P0302h^;P0/
;2`0;2`/0080<30`0P0b<S8204A4A080>c/k0P0_;bl203@d=080:b/[0P0S8b<202LW9`809BDU0P0R
8R8202`/;080:BTY0P0k>c/206i^KP80TI6A0P2CTi<205mOG`80H61P0P1lO7`20:b/[080c/k>0P2o
_kl209jNWP80Xj>S0P2VYZH20:j^[P80];Bd0P2j^[X20;^k^`030<G5a@38b<P0b<S80080b/[:0P38
b<P20<K6aP80a<C40P2o_kl20;bl_080Shn?0P1PH602069RHP80MgMg0P1iNGT407]kN`80Ogmo1021
PH420820P080OWin0P28R8P2092@T080Ti>C0P2@T90408f=S@80S8b<0P22PX8207alO080M7Ad0P1[
Jf/206=SH`0306UYJ@1CDe<0De=C0080Bd];0P1aLG4207emO@80QhN70P2:RXX209:BTP80UIFE102M
WId209nOW`80Z:RX0P2][Jd20;2`/0@0^k^k0P31`L420<C4a080`L710P2i^KT20:n_[`80YjNW0P2Z
ZZX209^KV`80TY:B0P2>SXh208N7Q`80O7al0P1eMGD207IfMP80PX:200<0P82008J6QP26QXH00P1n
OWh207emO@80N7Qh0P1gMgL207UiN@80Ng]k0P20P80408:2PP80QHF50P20P80208B4Q080SXj>0P2D
U9@209ZJVRL0b>3H0P0[:b/202LW9`8092@T0P0Q8B4202TY:@80:RXZ0P0b<S82030`<080<c<c0P0_
;bl2034a<@80=cLg00<0@T9203`l?00l?3`00P0a<C4203Hf=P80<C4a0P0^;Rh2030`<080=CDe0P0h
>3P203De=@80<30`0P0Z:RX202HV9P808b<S0P0Q8B4202DU9@80;2`/0P0P820203/k>`80K6a/0P2@
T9020:6QX@80E5AD0P1WIfL207YjNP80[Zj^00<0d];B0;fm_@2m_Kd00P2NWYh209bLW080Z:RX0P2`
/;020;>c/`80^;Rh0P2m_Kd20<;2`P80bLW90P3:b/X20<W9b@80a/K60P33`l<20<G5a@80_kno0P2:
RXX205aLG080IVIV0P1cLg<407alO080OWin0`1mOGd407inOP80O7al0P28R8P208n?S`@0T92@0P2=
SHd208b<S080Rh^;0P22PX8207YjNP80MWIf0P1bLW8206QXJ080FEUI0P1CDe<205eMG@80Kfm_0P1m
OGd208N7Q`80Rh^;0P2@T90209RHV080X:2P00<0Xj>S0::RXP2RXZ800P2ZZZX20:b/[080/[:b0P2l
_;`20;jn_P80`/;20P33`l<20<C4a080_Kfm0P2e]KD20:ZZZP80XJ6Q0P2DU9@209:BTP80TI6A0P2:
RXX207]kN`80MGEe0P1iNGT207moO`80QHF51022PX8207QhN00307UiN@1bLW80LW9b0080O7al0P1j
NWX20820P0@0QHF50P23Ph<207inOP80Q8B40P2<S8`409RHV1h0b>3H000L0<SPf080;2`/0P0[:b/2
02XZ:P80:BTY0P0X:2P202d];@80<c<c100d=3@2030`<080;Bd]0P0f=SH00`0n?Sh0>SXj03Xj>P02
03<c<`80;bl_0P0];Bd202`/;080;Rh^0P0c<c<203Hf=P80<C4a0P0[:b/202TY:@80:2PX0P0V9RH2
02<S8`80820P0P0K6a/20451@@809bLW0P1CDe<207alO080UiNG0P1iNGT206MWI`80Hf=S0P25QHD0
0`30`<00a/K60<K6aP020:6QX@80WinO0P2QXJ420:b/[080]kNg102h^;P20<30`080alO71038b<P2
0<O7a`80aLG50P38b<P20<G5a@80[Jf]0P2@T90207YjNP80Jf][0P1_Kfl207QhN080Ng]k0`1lO7`2
07]kN`80O7al0P1nOWh208J6QP80SXj>0P2?Shl208f=S@80Rh^;0P27QhL207moO`80MGEe0P1WIfL2
05]KF`80FUYJ0P1LG5`205eMG@80HF5Q0P1XJ6P2075aL@80Ogmo0P2:RXX208N7Q`80PX:20P23Ph<2
08R8R003092@T02LW9`0W9bL0080[Jf]0P2m_Kd20<;2`P80`l?30P36a/H20<S8b080bl_;0P3=cLd2
0<W9b@80`/;20P2e]KD20:NWY`80UiNG0P2:RXX208b<S0@0SHf=0P1]KFd207=cL`80O7al0P21PH42
08>3P`80OGem0`1fMWH207MgM`80NGUi0P1lO7`207moO`80PH611P22PX8208B4Q080Rh^;0P2CTi<2
09BDU2L0b>3H0P0b<S8202`/;0@09bLW0P0T92@202TY:@80<30`0P0i>CT203Ph>080<S8b0P0^;Rh2
03Hf=P80@d=30P0o?cl302h^;P80=SHf0P0`<30202`/;080;Rh^0P0a<C4203Lg=`809bLW0P0T92@2
02PX:0809BDU0P0T92@2024Q8@80820P0P0i>CT202XZ:P80CDe=0P25QHD209^KV`80O7al0P1SHf<2
06IVIP80R8R80P32`/820<G5a@80W9bL0P2EUID209nOW`80[Jf]0P2a/K420;Vi^@80]KFe00<0`<30
0<O7a`37alL00P37alL20<K6aP80alO70P35aLD40<71`@80_;bl0P2BTY8206IVIP80JFUY0P1bLW82
07moO`80O7al0P1kNg/207YjNP80O7al0P1nOWh207]kN`80QhN70P2>SXh208^;R`80SHf=1026QXH2
08F5Q@80LW9b0P1ZJVX205mOG`80Fe]K0P1MGEd00`1OGel0GUiN05iNGP0206i^KP80MgMg0P22PX82
08^;R`80SHf=0P23Ph<208F5Q@80RXZ:0P2CTi<209jNWP80][Jf0P2k^k/20<71`@80aLG50P37alL2
0<_;b`80c/k>0P3AdM420<k>cP80alO70P2f][H209jNWP80T92@0P29RHT2096AT@80V9RH0P2;Rh/2
07=cL`80L71`0P1lO7`00`23Ph<0PX:208:2PP0207emO@80NGUi0P1bLW8207EeM@80NGUi0P1lO7`2
08B4Q080PH610P22PX820861P@80QHF50P24Q8@408f=S@80VIVI9`38h=P202XZ:P80:b/[0P0/;2`4
02TY:@80;bl_0P0e=CD203<c<`80=3@d0P0_;bl202`/;080=SHf00<0?3`l03Ph>00h>3P00P0^;Rh2
02l_;`80;Rh^0P0Z:RX203<c<`80>3Ph0P0f=SH202l_;`@0:2PX0P0V9RH202XZ:P8092@T0P0Q8B42
01`L7080@T920P0U9BD205=CD`80O7al0P2FUYH207MgM`80J6QX0P1QHF4208>3P`030<30`038b<P0
b<S80080XZ:R0P2MWId209nOW`80[Jf]0P2i^KT20;^k^`80^[Zj0P32`/820<_;b`80alO70P35aLD2
0<[:bP80`L710P37alL20<G5a@80[Zj^0P2@T90207YjNP80IfMW0P1]KFd207QhN080OWin0P1lO7`3
07moO`80NGUi0P21PH4208J6QP80TY:B0P2@T90208f=S@80RHV90P28R8P20861P@80MWIf0P1VIVH2
05UIF@80Fe]K0P1JFUX205aLG080Hf=S0P1]KFd206i^KP80Ogmo1024Q8@207moO`80QHF50P28R8P0
0`2<S8`0WIfM09fMW@020:j^[P80_Kfm0P32`/820<71`@80alO71039bLT40<k>cP80`l?30P2g]kL2
0:JVYP80UiNG0P2=SHd408b<S080SHf=0P1[Jf/207MgM`80NWYj1020P80207inOP80MgMg00<0MWIf
07MgM`1gMgL00P1iNGT207YjNP@0P8200P22PX820820P080PH610P24Q8@208Z:RP@0TI6A7P38h=P0
01`0b>3H0P0/;2`202/[:`80:RXZ0P0Y:BT202PX:080;Bd]0P0c<c<403@d=080<30`0P0];Bd203Hf
=P0303hn?P0j>SX0>SXj0080<c<c0P0_;bl202d];@80;2`/0P0^;Rh203<c<`80=SHf0P0a<C4202/[
:`80:BTY0P0X:2P202HV9P808b<S0P0P820201/K6`80@D510P0W9bL205=CD`80O7al0P2GUiL207Ui
N@80IfMW0P1SHf<208F5Q@030<30`036a/H0a/K60080XJ6Q0P2OWil20:6QX@80[:b/0P2g]kL40;Rh
^080`<300P37alL40<S8b080alO70P35aLD20<S8b080aLG50P2][Jd2092@T080NWYj0P1[Jf/206m_
K`80N7Qh0P1kNg/307alO080Ng]k0P1lO7`207inOP80QXJ60P2>SXh208n?S`80SHf=0P2;Rh/208N7
Q`80Ogmo0P1eMGD206MWI`80Fe]K0P1JFUX205aLG080GEeM0P1QHF4206QXJ080LG5a0P1oOgl208Z:
RP80QhN70P22PX8208>3P`80R8R800<0T92@09bLW02LW9`00P2][Jd20;fm_@80`/;20P33`l<20<K6
aP80b<S80P3;bl/20<g=c@80bLW90P32`/820;Fe]@80YjNW0P2GUiL208Z:RP80S8b<102=SHd206e]
K@80Lg=c0P1lO7`20861P@80Ph>30P1mOGd307IfMP80MgMg0P1iNGT207alO080Ogmo0P21PH4608:2
PP80Q8B40P2;Rh/209>CT`80U9BD9`38h=P2038b<P80;2`/100W9bL202@T9080:BTY0P0`<30203Ti
>@80>3Ph0P0b<S8202h^;P80=SHf0P13@d<203lo?`<0;Rh^0P0f=SH2030`<080;2`/0P0^;Rh2034a
<@80=cLg0P0W9bL202@T9080:2PX0P0U9BD202@T90808B4Q0P0P820203Ti>@80:RXZ0P1=CDd208F5
Q@80Vi^K0P1lO7`206=SH`80IVIV0P28R8P20<;2`P80aLG50P2LW9`209FEU@80WinO0P2][Jd20;6a
/@80^KVi0P2e]KD00`30`<00alO70<O7a`020<O7a`80a/K60P37alL20<G5a@@0`L710P2l_;`209:B
TP80IVIV0P1YJFT2079bLP80Ogmo0P1lO7`207]kN`80NWYj0P1lO7`207inOP80Ng]k0P27QhL208j>
SP80Rh^;0P2=SHd408J6QP80QHF50P1bLW8206YZJP80GemO0P1KFe/205eMG@0305mOG`1NGUh0GUiN
0080KVi^0P1gMgL208:2PP80Rh^;0P2=SHd208>3P`80QHF50P2:RXX209>CT`80WYjN0P2f][H20;^k
^`80`L710P35aLD20<O7a`80bl_;0P3>c/h20=7Ad@80c/k>0P37alL20;Jf]P80WYjN0P2@T90208V9
R@80TI6A0P2HV9P208^;R`80Lg=c0P1`L70207alO00308>3P`22PX80PX:20080OGem0P1iNGT2079b
LP80MGEe0P1iNGT207alO080Q8B40P21PH4208:2PP80PH610P25QHD208B4Q0@0SHf=0P2IVITW0<SP
f080:RXZ0P0[:b/202`/;0@0:BTY0P0_;bl203De=@80<c<c0P0d=3@202l_;`80;2`/0P0f=SH00`0l
?3`0>3Ph03Ph>00202h^;P80;bl_0P0^;Rh202XZ:P80<c<c0P0h>3P203Hf=P80;bl_100X:2P202HV
9P80:RXZ0P0T92@2024Q8@8071`L0P12@T8202DU9@80De=C0P1lO7`209JFUP80MgMg0P1XJ6P2065Q
H@80Ph>300<0`<300<S8b038b<P00P2RXZ8209fMW@80WinO0P2][Jd20;Vi^@80^k^k0P2j^[X20<;2
`P80bl_;0P37alL20<G5a@80b/[:0P31`L420<O7a`80aLG50P2^[Zh2092@T080NWYj0P1WIfL206e]
K@80N7Qh0P1nOWh207alO0<0Ogmo0P1iNGT20861P@80QXJ60P2BTY82092@T080SHf=0P29RHT208R8
R080PH610P1fMWH206IVIP80FEUI0P1KFe/205YJFP80G5aL0P1SHf<206e]K@80KVi^0P1oOgl408B4
Q080Ogmo0P25QHD208R8R00308b<S02MWId0WIfM0080[Zj^0P2m_Kd20<;2`P80`L710P37alL40<W9
b@@0c/k>0P33`l<20;Ng]`80YZJV0P2GUiL208f=S@@0S8b<0P2=SHd206][J`80MgMg0P1jNWX40820
P080OWin0P1gMgL00`1fMWH0MgMg07MgM`0207UiN@80NWYj1020P80208:2PP80P8200P21PH4208B4
Q080RXZ:102ATI4N0<SPf0007038h=P202l_;`@0<30`0P0/;2`202XZ:P80;Rh^0P0d=3@203Ti>@80
?3`l0P0b<S8202XZ:P80<30`00<0>3Ph03Hf=P0f=SH00P0a<C4202d];@80:BTY0P0X:2P202XZ:P80
;bl_0P0c<c<202d];@809bLW0P0X:2P202XZ:P809RHV0P0R8R8202<S8`80:BTY0P0N7Qh203Lg=`80
AdM70P1LG5`20820P080V9RH0P1bLW8205EEE@80G5aL00<0YJFU0<W9b@39bLT00P2VYZH20:6QX@80
Vi^K0P2YZJT40;Ng]`80]KFe0P2l_;`20<?3``80a/K61P37alL20<C4a080`/;20P37alL20<?3``80
V9RH0P1/K6`206][J`80M7Ad0P1gMgL207UiN@0307MgM`1fMWH0MWIf0080NWYj0P1oOgl208B4Q080
R8R80P2:RXX208V9R@80QXJ60P1oOgl207AdM080IVIV0P1ADE420451@@80ADE50P1@D50206=SH`80
M7Ad101fMWH207moO`80QHF50P1jNWX206e]K@80I6AT0P1SHf<00`1bLW80RHV908V9R@020:JVYP80
_kno0P36a/H20<O7a`80b/[:0P3<c<`20<o?c`@0dM7A0P3=cLd20;no_`80[Zj^0P2IVIT208R8R080
SHf=0P2?Shl209fMW@80Jf][0P1bLW8207YjNP@0OWin0P1iNGT207=cL`0307AdM01hN7P0N7Qh0080
NWYj0P1lO7`207emO@80OWin0P21PH4208>3P`80Q8B40P26QXH208^;R`80T92@0P2ATI4W0<SPf080
;2`/0P0[:b/203Hf=P80;2`/0P0_;bl202/[:`80=SHf0P0m?Cd203Xj>P80=SHf0P0];Bd202PX:080
=cLg0P10@402034a<@0302LW9`0V9RH09RHV0080:BTY0P0/;2`202l_;`80<30`0P0e=CD202HV9P80
9BDU0P0^;Rh202d];@808B4Q0P0S8b<2024Q8@80:RXZ0P0f=SH203`l?080F5QH0P28R8P209JFUP80
Hf=S0P1HF5P206IVIP80Xj>S0P32`/820:^[Z`80UYJF0P2LW9`20:b/[080]KFe0P2b/[820;Bd]003
0;fm_@33`l<0`l?30080`l?30P37alL20<W9b@80aLG50P37alL20<71`@80a<C40P31`L4209bLW080
K6a/0P1ZJVX207=cL`80MgMg0P1jNWX2079bLP80MWIf0P1nOWh207alO080Ph>30P2<S8`208>3P`80
Shn?0P28R8P207alO080MWIf0P1SHf<205=CD`@0@d=30P1BDU800`1SHf<0Lg=c07=cL`0407MgM`80
O7al0P24Q8@207QhN080K6a/0P1UIFD206IVIP80M7Ad0P29RHT20:>SX`80^[Zj0P35aLD20<K6aP80
b/[:0P3=cLd20<o?c`80dM7A0P3?cll20<[:bP80a/K60P2`/;0209NGU`80R8R80P2@T90208j>SP80
U9BD0P1aLG4206i^KP80NGUi00<0QHF507inOP1nOWh00P1dM7@2075aL@80NGUi0P1dM7@207alO080
Ng]k0P1lO7`207moO`@0PX:20P23Ph<408J6QP80T92@0P2DU9@W0<SPf080;Rh^0P0`<30202d];@80
;2`/0P0Y:BT2030`<080=3@d0P0g=cL203`l?080<c<c0P0Z:RX2034a<@0303Ti>@0e=CD0=CDe0080
<S8b0P0^;Rh202XZ:P809BDU0P0X:2P202l_;`80<C4a0P0`<30202HV9P80:RXZ0P0Y:BT202HV9P80
820P0P0T92@202PX:08071`L0P0h>3P204Q8B080GEeM0P1lO7`209ZJVP80MGEe0P1EEED2061PH003
0:FUY@37alL0alO70080YZJV0P2RXZ8209bLW080ZZZZ0P2f][H20;Ng]`80];Bd0P2h^;P20<?3``80
`<301039bLT20<_;b`80_Kfm0P34a<@20<S8b080a/K60P2EUID2071`L080JVYZ0P1gMgL207EeM@80
NWYj00<0MGEe07MgM`1gMgL00P1hN7P208:2PP80Ogmo0P29RHT208^;R`80R8R80P25QHD20820P080
MGEe0P1SHf<2055AD@80?Shn0P19BDT204i>CP80Hf=S0P1aLG4207AdM080MWIf0P22PX8208B4Q080
NWYj0P1`L70206ATI080Hf=S00<0Lg=c08V9R@29RHT00P2VYZH20;jn_P80`l?30P36a/H20<_;b`80
c<c<0P3>c/h20=7Ad@@0c/k>0P2m_Kd20:j^[P80VYZJ0P27QhL208^;R`80T92@0P2LW9`206][J`80
LW9b0P1hN7P20820P080Ogmo0P1fMWH2079bLP<0MgMg0P1jNWX207inOP80Ng]k0P1oOgl20861P@80
Q8B40P23Ph<208F5Q@80S8b<0P2?Shl209BDU1h0b>3H000L0<SPf080;bl_100`<30202`/;080:RXZ
0P0^;Rh203@d=080>CTi0P0l?3`2038b<P80:RXZ0P0`<3000`0h>3P0=SHf03Hf=P02034a<@80;Bd]
0P0Y:BT202PX:080:RXZ0P0_;bl203<c<`80;Bd]0P0W9bL202PX:080:RXZ0P0V9RH2028R8P808b<S
0P0Y:BT201hN7P80=cLg0P17AdL205aLG080P8200P2HV9P2079bLP80EEEE0P1LG5`00`2UYJD0bLW9
0<W9b@020:JVYP80XJ6Q0P2KVi/20:VYZ@@0]kNg0P2e]KD20;bl_080`l?30P36a/H60<O7a`80a<C4
0P32`/820<O7a`80`l?30P2HV9P206a/K080Jf][0P1dM7@207MgM`80NGUi00<0MgMg07IfMP1fMWH0
0P1jNWX207moO`80Q8B40P28R8P208Z:RP80RHV90P26QXH207moO`80M7Ad0P1VIVH2055AD@80@D51
0P15ADD2051@D080Hf=S0P1dM7@407IfMP80Ogmo0P25QHD207YjNP80KFe]0P1TI6@206=SH`03079b
LP29RHT0RHV90080YZJV0P2o_kl20<K6aP80alO70P3:b/X20<c<c080clo?103AdM420<g=c@80_kno
0P2^[Zh209VIV@80R8R80P2=SHd208n?S`80WIfM0P1[Jf/2079bLP80NWYj101nOWh207UiN@80Lg=c
00<0M7Ad07QhN01hN7P00P1jNWX207alO080OGem0P1nOWh20861P@80Ph>30P24Q8@208J6QP80Rh^;
0P2@T902096ATBL0b>3H0P0/;2`202/[:`80=SHf0P0/;2`202l_;`80:b/[0P0f=SH203dm?@80>SXj
0P0f=SH202d];@80:2PX0P0g=cL20410@080<C4a00<09bLW02HV9P0V9RH00P0Y:BT202`/;080;bl_
0P0`<30203De=@809RHV0P0U9BD202h^;P80;Bd]0P0Q8B4202<S8`808B4Q0P0Z:RX203Hf=P80?3`l
0P1HF5P208R8R080UYJF0P1SHf<205QHF080IVIV0P2SXj<20<;2`P80Zj^[0P2FUYH209bLW080[:b/
0P2e]KD20;:b/P80];Bd00<0_Kfm0<?3``33`l<00P33`l<20<O7a`80bLW90P35aLD20<O7a`80`L71
0P34a<@20<71`@80W9bL0P1/K6`206YZJP80Lg=c0P1gMgL207YjNP80LW9b0P1fMWH207inOP80O7al
0P23Ph<208b<S080Ph>30P2?Shl208R8R080O7al0P1fMWH206=SH`80De=C1013@d<2059BDP0306=S
H`1cLg<0Lg=c00@0MgMg0P1lO7`208B4Q080N7Qh0P1/K6`206EUI@80IVIV0P1dM7@208V9R@80Xj>S
0P2j^[X20<G5a@80a/K60P3:b/X20<g=c@80clo?0P3AdM420<o?c`80b/[:0P36a/H20;2`/080UiNG
0P28R8P2092@T080SXj>0P2DU9@2075aL@80KVi^0P1iNGT00`25QHD0OWin07inOP0207AdM080LG5a
0P1iNGT207AdM080O7al0P1kNg/207alO080Ogmo1022PX8208>3P`@0QXJ60P2@T90209BDU2L0b>3H
0P0^;Rh2030`<080;Bd]0P0/;2`202TY:@80<30`0P0d=3@203Lg=`80?3`l0P0c<c<202XZ:P80<C4a
00<0>CTi03De=@0e=CD00P0b<S8202h^;P80:RXZ0P0U9BD202PX:080;bl_0P0a<C42030`<0809RHV
0P0Z:RX202TY:@809RHV0P0P820202@T9080:2PX0P0L71`203Ph>080B4Q80P1MGEd207alO080VYZJ
0P1eMGD205EEE@80H61P00<0YJFU0<O7a`37alL00P2VYZH20::RXP80W9bL0P2ZZZX20;Jf]P80]kNg
0P2d];@20;Rh^080`l?30P30`<040<W9b@80bl_;0P2m_Kd20<C4a080b<S80P36a/H209FEU@80L71`
0P1ZJVX207MgM`80MGEe0P1jNWX00`1eMGD0MgMg07MgM`0207QhN080PX:20P1oOgl208V9R@80Rh^;
0P28R8P208F5Q@80P8200P1eMGD206=SH`80DE5A0P0n?Sh204U9B@80CTi>0P1SHf<2075aL@80M7Ad
0P1fMWH208:2PP80Q8B40P1jNWX2071`L080I6AT0P1SHf<00`1cLg<0RHV908V9R@020:JVYP80_[jn
0P33`l<20<K6aP80bl_;0P3<c<`20<k>cP80dM7A103>c/h20;fm_@80[Zj^0P2JVYX208N7Q`80Rh^;
0P2@T90209bLW080Jf][0P1bLW8207QhN080P8200P1oOgl207IfMP80LW9b0`1gMgL207YjNP80OWin
0P1kNg/207moO`80PH610P24Q8@208>3P`80QHF50P2<S8`208n?S`80U9BD7P38h=P001`0b>3H0P0f
=SH2038b<P80;2`/100Z:RX202d];@80=3@d0P16ATH205IFEP80@T920P0X:2P202`/;0<0=CDe0P0c
<c<202h^;P@0:BTY0P0[:b/2030`<080=3@d0P0_;bl402TY:@80:b/[0P0W9bL202@T90809BDU0P0Y
:BT202LW9`80<30`0P0e=CD204A4A080Fe]K0P2ATI4208B4Q080F5QH0P19BDT00`26QXH0[:b/0:b/
[0020:^[Z`80WYjN0P2CTi<209jNWP80[Jf]0P2`/;020;6a/@80^;Rh0P2o_kl20<C4a080alO71038
b<P20<K6aP80a<C41039bLT20;Bd]080VIVI0P1mOGd206QXJ080Jf][0P1dM7@00`1eMGD0MgMg07Mg
M`0207emO@80PX:20P21PH420820P0@0PH610P1mOGd207EeM@80J6QX0P1HF5P20451@@80<S8b0P0j
>SX204Y:BP80GEeM0P1_Kfl207QhN080Ng]k0P1gMgL206i^KP80GUiN0P1>CTh404Q8B003051@D01P
H600H61P0080NWYj0P2HV9P20;Rh^080cLg=103>c/h20=3@d080dM7A0P3@d=020<c<c080a<C40P2i
^KT20:FUY@80TY:B0P2:RXX208:2PP80Q8B40P1XJ6P2075aL@80Ogmo0P1jNWX2079bLP80LG5a0P1b
LW800`1fMWH0NWYj07YjNP0207UiN@80MgMg0P1kNg/207moO`80PX:20P25QHD208N7Q`80RHV90P2>
SXh209>CT`80U9BD9`38h=P203`l?080=CDe0P0X:2P202h^;P80:RXZ0P0^;Rh203@d=080ADE50P1?
Cdl203dm?@80:RXZ0P0Y:BT2034a<@80>SXj0P0b<S800`0];Bd0;2`/02`/;00202PX:0@0;Bd]0P0f
=SH203Ph>080:2PX100W9bL202@T90808B4Q0P0U9BD202XZ:P80<30`0P0b<S8203De=@80?clo0P1^
KVh209FEU@80O7al0P1CDe<205IFEP80OWin0P2_[jl20;Vi^@80WinO0P2HV9P20:VYZ@80/;2`0P2c
/k<20;Bd]0030;bl_02n_[h0_[jn0080`l?30P37alL20<W9b@80b/[:0P34a<@60<G5a@80a<C40P2P
X:0206e]K@80J6QX0P1aLG4207EeM@@0MWIf0P1oOgl208:2PP80Q8B40P22PX8207alO080PX:20P1l
O7`207EeM@80K6a/0P1FEUH20451@@@0;bl_0P19BDT00`1SHf<0LG5a075aL@02071`L080MGEe0P1h
N7P2075aL@80GemO0P1BDU8203lo?`80@T920P1;Bd/205QHF080Ogmo0P2NWYh20;bl_080b/[:0P3;
bl/40<[:bP80c/k>0P3<c<`20<K6aP80`l?30P2l_;`20:>SX`80U9BD0P2:RXX208B4Q080N7Qh0P1Z
JVX207AdM080OWin00<0NWYj071`L01`L7000P1`L70207=cL`80O7al0P1mOGd207QhN080MWIf0P1k
Ng/207YjNP80QXJ60P24Q8@208^;R`80RXZ:0P2?Shl209BDU080Vi^K9`38h=P203@d=080=CDe0P0/
;2`202d];@809bLW0P0[:b/2038b<P80AdM70P1GEeL204=3@`80:2PX0P0/;2`00`0h>3P0=3@d03@d
=00203De=@80<C4a0P0Y:BT202LW9`80:b/[100c<c<202d];@80:BTY0P0[:b/202XZ:P80:2PX0P0Q
8B4202<S8`80:BTY0P0X:2P202l_;`80=SHf0P13@d<205eMG@80T92@0P22PX8205ADE080Bd];00<0
Q8B40:^[Z`2[Zj/00P2[Zj/209nOW`80TI6A0P2LW9`20:f][@80/;2`0P2b/[820;^k^`80`l?30P35
aLD40<S8b080b/[:0P35aLD20<K6aP80b/[:0P39bLT20:n_[`80VYZJ0P1oOgl206IVIP80IFEU0P1g
MgL00`1cLg<0N7Qh07QhN00207emO@80P8200P1mOGd207inOP80PX:20P23Ph<207emO@80LG5a0P1X
J6P205QHF080A4A40P0d=3@203hn?P80BTY:0P1LG5`207=cL`80NGUi0P1kNg/207QhN080MWIf0P1K
Fe/204m?C`80ADE50P19BDT00`1@D500H61P061PH00207QhN080Vi^K0P2l_;`20<k>cP80clo?0P3<
c<`40=;BdP80cLg=0P3:b/X20<O7a`80^;Rh0P2VYZH2096AT@80RXZ:0P25QHD208:2PP80J6QX0P1a
LG420820P080O7al0P1dM7@206m_K`80Lg=c0`1gMgL207UiN@80MgMg0P1iNGT20861P@80QHF51026
QXH208b<S080SXj>102FUYHN0<SPf0007038h=P203Hf=P80<S8b0P0/;2`402XZ:P80;Bd]0P0d=3@2
04I6AP80EUIF0P12@T8202PX:080;2`/0`0e=CD203<c<`80;Rh^100Y:BT202/[:`80<30`0P0d=3@2
02l_;`@0:BTY0P0[:b/202LW9`8092@T0P0U9BD202TY:@809bLW0P0`<30203De=@80A4A40P1KFe/2
096AT@80Q8B40P1HF5P204U9B@0308J6QP2/[:`0[:b/0080Zj^[0P2NWYh209>CT`80WYjN0P2][Jd2
0;2`/080/K6a0P2h^;P20;no_`80a<C40P37alL40<S8b080a/K60P34a<@40<W9b@80];Bd0P2IVIT2
07emO@80J6QX0P1[Jf/207AdM00307EeM@1gMgL0MgMg0080OGem0P22PX820861P@80P8201021PH42
07emO@80MGEe0P1XJ6P205QHF080@D510P0b<S8203Xj>P80BTY:0P1MGEd206m_K`80N7Qh0P1kNg/2
07MgM`80KVi^0P1NGUh204i>CP@0B4Q800<0D51@061PH01PH6000P1jNWX209RHV080^;Rh0P3=cLd4
0<k>cP80d=3@0P3AdM420=3@d080c<c<0P34a<@20;Vi^@80YJFU0P2BTY8208Z:RP80PX:20P24Q8@2
06QXJ080LG5a0P1oOgl207YjNP80LW9b0P1aLG42079bLP0307IfMP1jNWX0NWYj0080NGUi0P1gMgL2
07]kN`80Ogmo0P22PX8208F5Q@80QhN70P29RHT208j>SP80Ti>C0P2DU9@W0<SPf080?3`l0P0e=CD2
02PX:080;Rh^0P0Z:RX202h^;P80=3@d0P15ADD204m?C`80?Cdm0P0Z:RX202TY:@80<C4a0P0j>SX2
038b<P0302d];@0/;2`0;2`/0080:2PX100];Bd203Hf=P80>3Ph0P0X:2P402LW9`8092@T0P0Q8B42
02DU9@80:RXZ0P0`<302038b<P80=CDe0P0o?cl206i^KP80UIFE0P1lO7`205=CD`80EUIF0P1nOWh2
0:n_[`80^KVi0P2OWil209RHV080ZJVY0P2`/;020;>c/`80];Bd00<0_;bl0;jn_P2n_[h00P33`l<2
0<O7a`80bLW90P3:b/X20<C4a0H0aLG50P34a<@20:2PX080KFe]0P1XJ6P2075aL@80MGEe101fMWH2
07moO`80PX:20P24Q8@208:2PP80O7al0P22PX8207alO080MGEe0P1/K6`205IFEP80@D51100_;bl2
04U9B@0306=SH`1aLG40LG5a0080L71`0P1eMGD207QhN080LG5a0P1OGel2059BDP80?clo0P12@T82
04];B`80F5QH0P1oOgl209jNWP80_;bl0P3:b/X20<_;b`@0b/[:0P3>c/h20<c<c080a/K60P33`l<2
0;bl_080Xj>S0P2DU9@208Z:RP80Q8B40P1hN7P206YZJP80M7Ad0P1nOWh00`1jNWX0L71`071`L002
071`L080Lg=c0P1lO7`207emO@80N7Qh0P1fMWH207]kN`80NWYj0P26QXH208B4Q080Rh^;0P2:RXX2
08n?S`80U9BD0P2KVi/W0<SPf080=3@d0P0e=CD202`/;080;Bd]0P0W9bL202/[:`80<S8b0P17AdL2
05MGE`80@d=30P0X:2P202`/;00303Ph>00d=3@0=3@d0080=CDe0P0a<C4202TY:@809bLW0P0[:b/4
03<c<`80;Bd]0P0Y:BT202/[:`80:RXZ0P0X:2P2024Q8@808b<S0P0Y:BT202PX:080;bl_0P0f=SH2
04=3@`80GEeM0P2@T90208:2PP80E5AD0P1;Bd/00`24Q8@0Zj^[0:^[Z`020:^[Z`80WinO0P2ATI42
09bLW080[Jf]0P2`/;020;:b/P80^k^k0P33`l<20<G5a@@0b<S80P3:b/X20<G5a@80a/K60P3:b/X2
0<W9b@80[jn_0P2JVYX207moO`80IVIV0P1UIFD207MgM`0307=cL`1hN7P0N7Qh0080OGem0P20P802
07emO@80OWin0P22PX8208>3P`80OGem0P1aLG4206QXJ080F5QH0P14A4@203@d=080?Shn0P1:BTX2
05aLG080Lg=c0P1iNGT207]kN`80N7Qh0P1fMWH205]KF`80Cdm?0P15ADD204U9B@03051@D01PH600
H61P0080N7Qh0P2KVi/20;bl_080c/k>0P3?cll20<c<c0@0d];B0P3=cLd20<[:bP80alO70P2h^;P2
0:JVYP80TI6A0P2:RXX208F5Q@80PX:20P1XJ6P2075aL@80P8200P1lO7`207AdM080Kfm_0P1cLg<3
07MgM`80NGUi0P1gMgL207UiN@80PH610P25QHD408J6QP80S8b<0P2>SXh409JFUQh0b>3H000L0<SP
f080?3`l0P0b<S8202LW9`809RHV0P0Y:BT202d];@80=SHf0P1EEED206m_K`80D51@0P0Y:BT202XZ
:P03038b<P0c<c<0<c<c0080<c<c0P0_;bl402/[:`80;Bd]0P0c<c<203Lg=`80<S8b0P0[:b/402XZ
:P80:2PX0P0W9bL202PX:080:RXZ100[:b/202PX:080<30`0P0i>CT207alO080T92@0P1SHf<204E5
A@0306][J`2:RXX0RXZ:0080[:b/0P2OWil2092@T080UiNG0P2QXJ420:NWY`80[Jf]0P2c/k<20;Zj
^P80`<300P35aLD20<O7a`80b<S80P37alL20<K6aP80a<C40P33`l<20<W9b@80a/K60P2GUiL206QX
J080IVIV0P1_Kfl00`1cLg<0N7Qh07QhN00207moO`80PX:20P1mOGd407IfMP80MGEe0P1`L70206QX
J080FUYJ0P1:BTX203Hf=P80:BTY0P0e=CD204Q8B080FEUI0P1XJ6P207IfMP80Ng]k0P1[Jf/205EE
E@80A4A40P0h>3P403<c<`0303De=@0m?Cd0?Cdm0080Cdm?0P1ZJVX209jNWP80b/[:0P3@d=020<k>
cP@0d=3@0P3>c/h20<[:bP80b<S80P32`/820;:b/P80WIfM0P24Q8@206m_K`80IFEU0P1WIfL207=c
L`80PX:20P1eMGD206IVIP80Jf][0P1cLg<00`1hN7P0Ng]k07]kN`0207IfMP80LW9b0P1hN7P20820
P080Q8B40P26QXH208R8R080Rh^;0P2ATI4209NGU`80V9RH9`38h=P20410@080;Rh^0P0/;2`202PX
:080;2`/0P0X:2P203Xj>P80DU9B0P1dM7@204e=C@80:RXZ0P0/;2`203@d=080<30`0P0e=CD00`0/
;2`0;Bd]02d];@0402/[:`80=CDe0P0d=3@2030`<080:RXZ0P0`<30202`/;0809bLW0P0X:2P202/[
:`809bLW0P0^;Rh202PX:0809BDU0P0/;2`20410@080OGem0P2:RXX206MWI`80DE5A0P1VIVH208V9
R@80YZJV0P2QXJ42092@T080UiNG0P2SXj<20:RXZ080Zj^[00<0^k^k0;Vi^@2i^KT00P31`L420<K6
aP80aLG50P38b<P20<O7a`80aLG50P34a<@20<;2`P80alO70P33`l<209RHV080K6a/0P1SHf<2071`
L080LW9b0P1jNWX207inOP80PH610P1mOGd207AdM080MGEe0P1iNGT206e]K@80I6AT0P1PH60204Y:
BP80<S8b0P0[:b/203<c<`80A4A400<0G5aL06UYJ@1YJFT00P1bLW8207emO@80LG5a0P1IFET203hn
?P80>CTi0P0f=SH203dm?@80>SXj0P11@D4204e=C@80Jf][0P2PX:020<K6aP80d=3@0P3>c/h20=3@
d080clo?0P3AdM420<[:bP80b<S80P30`<020;2`/080WYjN0P23Ph<2079bLP80HF5Q0P1VIVH407em
O@0307AdM01VIVH0IVIV0080Kfm_0P1bLW8207MgM`80O7al0P1eMGD2075aL@80Ng]k0P21PH4208:2
PP80QXJ60P29RHT208Z:RP80SXj>0P2CTi<209^KVbL0b>3H0P0k>c/203<c<`809RHV0P0X:2P202TY
:@80<C4a0P0e=CD205UIF@80K6a/0P1BDU8202LW9`80:BTY00<0<S8b02l_;`0_;bl00P0b<S82030`
<080:RXZ0P0];Bd202h^;P80<30`0P0h>3P2034a<@80;2`/0P0W9bL402XZ:P80:BTY0P0V9RH202PX
:080<c<c0P0X:2P202LW9`80;Rh^0P0n?Sh207]kN`80Rh^;0P1UIFD204M7A`0306a/K026QXH0QXJ6
0080/;2`0P2MWId209FEU@80UYJF0P2SXj<20:ZZZP80Zj^[0P2d];@20;Rh^080`L710P35aLD20<S8
b080bLW90P34a<@60<K6aP80alO70P38b<P209RHV080JVYZ0P1UIFD2071`L003079bLP1iNGT0NGUi
00H0PH610P1fMWH407=cL`80LG5a0P1XJ6P205UIF@80B4Q80P0c<c<202TY:@80=SHf0P18B4P205QH
F080JFUY0P1eMGD207]kN`80JVYZ0P1BDU820492@P80>SXj100d=3@00`0c<c<0?3`l03`l?002051@
D080IfMW0P2NWYh20<_;b`80d=3@0P3>c/h20<o?c`80c/k>0P3<c<`20<S8b080b/[:0P32`/820;2`
/080Vi^K0P25QHD206a/K080IFEU0P1XJ6P207EeM@80PX:20P1cLg<406MWI`80LW9b00<0O7al07Qh
N01hN7P00P1kNg/2079bLP80MgMg0P20P80208J6QP80Q8B40P28R8P208Z:RP80Shn?102IVITN0<SP
f0007038h=P203`l?080<S8b0P0W9bL202HV9P80:BTY0P0];Bd203Hf=P80EEEE0P1_Kfl2051@D080
:BTY0P0Z:RX00`0b<S80<c<c03<c<`0203<c<`80;bl_100[:b/202d];@80<c<c0P0g=cL2038b<P80
:b/[100Z:RX202PX:0809bLW0P0X:2P202XZ:P@0:b/[0P0X:2P2030`<080>CTi0P1lO7`2092@T080
Hf=S0P15ADD00`1[Jf/0RXZ:08Z:RP020:b/[080WinO0P2@T90209NGU`80XJ6Q0P2WYjL20:f][@80
/k>c0P2j^[X20<30`080aLG50P37alL20<S8b080alO70P36a/H20<C4a080`l?30P39bLT20<K6aP80
UiNG0P1XJ6P206IVIP80Kfm_00<0Lg=c07QhN01hN7P00P1oOgl208:2PP80OGem101fMWH207EeM@80
L71`0P1XJ6P205YJFP80BTY:0P0f=SH202TY:@80=CDe0P18B4P205UIF@80J6QX0P1fMWH207]kN`80
Jf][0P1EEED204A4A080>3Ph100c<c<00`0e=CD0?Cdm03dm?@0204m?C`80JVYZ0P2NWYh20<[:bP80
d=3@0P3>c/h40=3@d080c/k>0P3:b/X20<S8b080`/;20P2b/[8209fMW@80Q8B40P1_Kfl206EUI@80
IfMW0P1cLg<208:2PP80MGEe0P1VIVH206][J`80Lg=c00<0N7Qh07]kN`1kNg/00P1fMWH2079bLP80
N7Qh0P20P80208B4Q080QXJ60P28R8P208^;R`80TI6A0P2GUiL209RHV2L0b>3H0P10@40202h^;P80
;2`/0P0X:2P202`/;080:2PX0P0j>SX2059BDP80M7Ad0P1=CDd202XZ:P80;2`/0P0d=3@2030`<080
=CDe00<0;2`/02d];@0];Bd0100[:b/203De=@80=3@d0P0`<30202XZ:P80<30`0P0/;2`202LW9`80
:2PX0P0[:b/202LW9`80;Rh^0P0X:2P202DU9@80;2`/0P10@40207emO@80RXZ:0P1WIfL2055AD@80
IVIV0P29RHT20:JVYP80XJ6Q0P2@T90209NGU`80Xj>S0P2XZ:P20:^[Z`030;^k^`2i^KT0^KVi0080
`L710P36a/H20<G5a@80b<S80P37alL20<G5a@80a<C40P32`/820<O7a`80`l?30P2HV9P206a/K080
Hf=S0P1`L702079bLP80NWYj0P1nOWh20861P@80OGem0P1dM7@207EeM@80NGUi0P1]KFd206ATI080
H61P0P1:BTX2038b<P80:b/[0P0c<c<204A4A00305aLG01YJFT0JFUY0080LW9b0P1mOGd2075aL@80
FEUI0P0n?Sh203Ti>@80=SHf0P0m?Cd203Xj>P80@D510P1=CDd206][J`80X:2P0P36a/H20=3@d080
c/k>0P3@d=020<o?c`80dM7A0P3:b/X20<S8b080`<300P2`/;0209jNWP80Ph>30P1bLW82065QH@80
IVIV101mOGd00`1dM7@0IVIV06IVIP0206m_K`80LW9b0P1gMgL207alO080MGEe0P1aLG4207]kN`80
PH610P22PX8208J6QP80RHV90P2:RXX208j>SP80Ti>C0P2KVi/W0<SPf080>c/k0P0c<c<202HV9P80
:2PX0P0Y:BT2034a<@80=CDe0P1IFET206a/K080DU9B0P0W9bL202TY:@03038b<P0_;bl0;bl_0080
<S8b0P0`<30202XZ:P80;Bd]0P0^;Rh2030`<080>3Ph0P0a<C4202`/;0809bLW100Z:RX202TY:@80
9RHV0P0X:2P203<c<`80:2PX0P0W9bL202h^;P80?Shn0P1kNg/208^;R`80IFEU0P17AdL00`1/K6`0
QXJ608J6QP020;2`/080WIfM0P2EUID209JFUP80Xj>S0P2ZZZX20:^[Z`80];Bd0P2h^;P20<71`@80
aLG50P38b<P20<W9b@80a<C41P36a/H20<O7a`80b<S80P2HV9P206YZJP80IFEU0P1`L7000`1bLW80
NGUi07UiN@060861P@80MWIf101cLg<2075aL@80J6QX0P1IFET204Q8B080<c<c0P0Y:BT203Hf=P80
B4Q80P1HF5P206UYJ@80MGEe0P1kNg/206YZJP80DU9B0P12@T8203Xj>P@0=3@d00<0<c<c03`l?00l
?3`00P1@D50206MWI`80WYjN0P3;bl/20=3@d080c/k>0P3?cll20<k>cP80c<c<0P38b<P20<[:bP80
`/;20P2`/;0209^KV`80QHF50P1/K6`206EUI@80J6QX0P1eMGD208:2PP80Lg=c101WIfL2079bLP03
07alO01hN7P0N7Qh0080Ng]k0P1bLW8207MgM`80P8200P26QXH208B4Q080R8R80P2:RXX208n?S`@0
VIVI7P38h=P001`0b>3H0P0h>3P2030`<0809bLW0P0U9BD202PX:080<C4a0P0j>SX206UYJ@80MgMg
0P1<C4`203@d=080;2`/00<0;Bd]02h^;P0^;Rh00P0_;bl202d];@@0:b/[0P0/;2`203<c<`80>3Ph
0P0a<C4202TY:@80:2PX0P0Y:BT202XZ:P80:b/[0P0Y:BT202LW9`@0:2PX0P0R8R8202DU9@80<C4a
0P1QHF4208>3P`80MgMg0P1GEeL00`1LG5`0NGUi07UiN@0209jNWP80]KFe0P2RXZ820:2PX0@0W9bL
0P2OWil20:JVYP80[jn_0P2f][H20;fm_@80`l?30P37alL40<W9b@80a/K60P34a<@40<[:bP80/k>c
0P2FUYH207UiN@80I6AT00<0JFUY07=cL`1cLg<00P1iNGT207]kN`80Lg=c0P1ZJVX206IVIP80Hf=S
0P1MGEd205EEE@80B4Q80P0k>c/2030`<080;Bd]0P0i>CT204];B`80GemO0P1_Kfl207EeM@80LG5a
0P1LG5`20451@@80@T920P1;Bd/205QHF080HV9R00<0EEEE04M7A`17AdL00P10@40204e=C@80Jf][
0P2YZJT40<o?c`80dm?C0P3@d=020<o?c`80c<c<0P3=cLd20<W9b@80]kNg0P2NWYh207UiN@80FUYJ
0P1GEeL2069RHP80OGem0P1dM7@206][J`80HF5Q0P1XJ6P2075aL@0307AdM01eMGD0MGEe00@0M7Ad
0P1iNGT207inOP80Ph>30P26QXH208N7Q`80RHV90P2ATI4209RHV080VIVI9`38h=P203Ph>080:2PX
0P0V9RH202LW9`809RHV0P0];Bd20410@080IFEU0P1oOgl204m?C`80=CDe0P0^;Rh2034a<@80:BTY
0P0e=CD00`0[:b/0:BTY02TY:@02034a<@80;Bd]0P0a<C4203dm?@80;Bd]0P0X:2P202d];@809RHV
0P0/;2`202/[:`80:2PX0P0S8b<202d];@809bLW0P0T92@202HV9P80;bl_0P1JFUX207QhN080Lg=c
0P1ADE4205aLG080OGem0P2GUiL20;6a/@80WYjN0P2CTi<209NGU`80Ti>C0P2IVIT00`2RXZ80ZZZZ
0:ZZZP020;Bd]080^k^k0P33`l<20<K6aP80bLW90P3:b/X20<S8b0@0aLG50P33`l<20<;2`P80V9RH
0P1WIfL206e]K@80IFEU0P1cLg<207QhN080NWYj0P1eMGD206i^KP80I6AT0P1QHF4205mOG`80EUIF
0P1>CTh203Lg=`80;bl_0P0c<c<204E5A@80De=C00<0FUYJ06a/K01/K6`00P1oOgl207=cL`80F5QH
0P0k>c/203`l?080Cdm?0P1GEeL205YJFP80D51@0P1=CDd203Lg=`80@D510P1aLG420:f][@80clo?
0P3Cdm<20=;BdP@0dm?C0P3=cLd20<k>cP80b/[:0P2f][H209jNWP80Ng]k0P1MGEd205ADE080Hf=S
0P1nOWh207IfMP0306IVIP1RHV80HV9R0080Jf][101_Kfl207EeM@80LW9b0P1fMWH207YjNP@0P820
0P26QXH208R8R080RHV90P2@T90209NGU`80XZ:R9`38h=P203@d=080<S8b0P0S8b<202@T90809BDU
0P0c<c<203Hf=P80J6QX0P1dM7@204i>CP80=3@d0P0b<S8502l_;`80;Rh^0P0Z:RX202TY:@80:b/[
0P0e=CD203Ti>@80<c<c0P0/;2`202LW9`80;2`/0P0X:2P202/[:`@09bLW0P0[:b/202LW9`808b<S
0P0Q8B4203De=@80I6AT0P1nOWh207YjNP80Fe]K00<0GEeM07MgM`1gMgL00P2MWId20;:b/P80X:2P
0P2OWil209RHV080Vi^K0P2NWYh20:BTY080[Zj^0P2e]KD20;fm_@80`/;20P37alL20<S8b080b/[:
0P34a<@20<?3``80bLW90P38b<P20;>c/`80V9RH0P1hN7P206ATI00306UYJ@1aLG40LG5a0080N7Qh
0P1kNg/207=cL`80Jf][0P1WIfL206ATI080GUiN0P1GEeL204Y:BP80?Shn0P0`<30202/[:`80=cLg
0P19BDT205mOG`80K6a/0P1dM7@2079bLP80GemO0P11@D4204=3@`80B4Q80P1HF5P2069RHP0305MG
E`1:BTX0BTY:0080@d=30P1>CTh206][J`80YZJV0P3:b/X20<o?c`80e]KF0P3Cdm<40<o?c`80d=3@
0P37alL20;Bd]080Xj>S0P1mOGd205aLG080EEEE0P1QHF4207emO@80LW9b0P1/K6`2069RHP80JVYZ
0P1`L7000`1gMgL0M7Ad07AdM00207EeM@80LW9b0P1fMWH207alO080QHF50P26QXH208R8R080Rh^;
0P2>SXh209BDU080V9RH7P38h=P001`0b>3H0P0h>3P2030`<0809bLW0P0U9BD202PX:080<C4a0P0j
>SX206UYJ@80MgMg0P1<C4`203@d=080;2`/00<0;Bd]02h^;P0^;Rh00P0_;bl202d];@@0:b/[0P0/
;2`203<c<`80>3Ph0P0a<C4202TY:@80:2PX0P0Y:BT202XZ:P80:b/[0P0Y:BT202LW9`@0:2PX0P0R
8R8202DU9@80<C4a0P1QHF4208>3P`80MgMg0P1GEeL00`1LG5`0NGUi07UiN@0209jNWP80]KFe0P2R
XZ820:2PX0@0W9bL0P2OWil20:JVYP80[jn_0P2f][H20;fm_@80`l?30P37alL40<W9b@80a/K60P34
a<@40<[:bP80/k>c0P2FUYH207UiN@80I6AT00<0JFUY07=cL`1cLg<00P1iNGT207]kN`80Lg=c0P1Z
JVX206IVIP80Hf=S0P1MGEd205EEE@80B4Q80P0k>c/2030`<080;Bd]0P0i>CT204];B`80GemO0P1_
Kfl207EeM@80LG5a0P1LG5`20451@@80@T920P1;Bd/205QHF080HV9R00<0EEEE04M7A`17AdL00P10
@40204e=C@80Jf][0P2YZJT40<o?c`80dm?C0P3@d=020<o?c`80c<c<0P3=cLd20<W9b@80]kNg0P2N
WYh207UiN@80FUYJ0P1GEeL2069RHP80OGem0P1dM7@206][J`80HF5Q0P1XJ6P2075aL@0307AdM01e
MGD0MGEe00@0M7Ad0P1iNGT207inOP80Ph>30P26QXH208N7Q`80RHV90P2ATI4209RHV080VIVI9`38
h=P203Ph>080:2PX0P0V9RH202LW9`809RHV0P0];Bd20410@080IFEU0P1oOgl204m?C`80=CDe0P0^
;Rh2034a<@80:BTY0P0e=CD00`0[:b/0:BTY02TY:@02034a<@80;Bd]0P0a<C4203dm?@80;Bd]0P0X
:2P202d];@809RHV0P0/;2`202/[:`80:2PX0P0S8b<202d];@809bLW0P0T92@202HV9P80;bl_0P1J
FUX207QhN080Lg=c0P1ADE4205aLG080OGem0P2GUiL20;6a/@80WYjN0P2CTi<209NGU`80Ti>C0P2I
VIT00`2RXZ80ZZZZ0:ZZZP020;Bd]080^k^k0P33`l<20<K6aP80bLW90P3:b/X20<S8b0@0aLG50P33
`l<20<;2`P80V9RH0P1WIfL206e]K@80IFEU0P1cLg<207QhN080NWYj0P1eMGD206i^KP80I6AT0P1Q
HF4205mOG`80EUIF0P1>CTh203Lg=`80;bl_0P0c<c<204E5A@80De=C00<0FUYJ06a/K01/K6`00P1o
Ogl207=cL`80F5QH0P0k>c/203`l?080Cdm?0P1GEeL205YJFP80D51@0P1=CDd203Lg=`80@D510P1a
LG420:f][@80clo?0P3Cdm<20=;BdP@0dm?C0P3=cLd20<k>cP80b/[:0P2f][H209jNWP80Ng]k0P1M
GEd205ADE080Hf=S0P1nOWh207IfMP0306IVIP1RHV80HV9R0080Jf][101_Kfl207EeM@80LW9b0P1f
MWH207YjNP@0P8200P26QXH208R8R080RHV90P2@T90209NGU`80XZ:R9`38h=P203@d=080<S8b0P0S
8b<202@T90809BDU0P0c<c<203Hf=P80J6QX0P1dM7@204i>CP80=3@d0P0b<S8502l_;`80;Rh^0P0Z
:RX202TY:@80:b/[0P0e=CD203Ti>@80<c<c0P0/;2`202LW9`80;2`/0P0X:2P202/[:`@09bLW0P0[
:b/202LW9`808b<S0P0Q8B4203De=@80I6AT0P1nOWh207YjNP80Fe]K00<0GEeM07MgM`1gMgL00P2M
WId20;:b/P80X:2P0P2OWil209RHV080Vi^K0P2NWYh20:BTY080[Zj^0P2e]KD20;fm_@80`/;20P37
alL20<S8b080b/[:0P34a<@20<?3``80bLW90P38b<P20;>c/`80V9RH0P1hN7P206ATI00306UYJ@1a
LG40LG5a0080N7Qh0P1kNg/207=cL`80Jf][0P1WIfL206ATI080GUiN0P1GEeL204Y:BP80?Shn0P0`
<30202/[:`80=cLg0P19BDT205mOG`80K6a/0P1dM7@2079bLP80GemO0P11@D4204=3@`80B4Q80P1H
F5P2069RHP0305MGE`1:BTX0BTY:0080@d=30P1>CTh206][J`80YZJV0P3:b/X20<o?c`80e]KF0P3C
dm<40<o?c`80d=3@0P37alL20;Bd]080Xj>S0P1mOGd205aLG080EEEE0P1QHF4207emO@80LW9b0P1/
K6`2069RHP80JVYZ0P1`L7000`1gMgL0M7Ad07AdM00207EeM@80LW9b0P1fMWH207alO080QHF50P26
QXH208R8R080Rh^;0P2>SXh209BDU080V9RH7P38h=P001`0b>3H0P0c<c<202h^;P80:BTY100V9RH2
03@d=080@D510P1kNg/207EeM@80@D510P10@402030`<00302XZ:P0X:2P0:2PX0080:RXZ0P0[:b/2
02`/;080:RXZ0P0[:b/203<c<`80>3Ph0P0a<C4202LW9`809RHV0P0X:2P202`/;080;bl_0P0[:b/4
02DU9@809RHV0P0R8R8202@T9080=3@d0P18B4P206a/K080QhN70P1aLG400`1IFET0KVi^06i^KP02
08Z:RP80aLG50P2f][H20:j^[P80W9bL0P2FUYH209FEU@80WIfM0P2WYjL20:j^[P80]KFe0P2m_Kd2
0<G5a@80bLW90P3<c<`20<W9b@H0aLG50P3;bl/20<K6aP80UIFE0P1UIFD00`1SHf<0Jf][06][J`02
06m_K`80LG5a0P1YJFT205iNGP80EeMG0P1@D50204Y:BP80@d=30P0h>3P202l_;`80;Rh^0P0c<c<2
03hn?P80CTi>0P1UIFD207IfMP80L71`0P1RHV8204];B`80>CTi0P1=CDd206ATI080G5aL0P1@D500
0`1FEUH0G5aL05aLG00204I6AP80?Cdm0P0l?3`208:2PP80bLW90P3>c/h20=GEe@@0d=3@0P3>c/h2
0<o?c`80b/[:0P2e]KD209NGU`80Jf][0P17AdL2059BDP80HV9R0P24Q8@406=SH`80HF5Q0P1YJFT2
075aL@03071`L01_Kfl0Kfm_0080Lg=c0P1gMgL207YjNP80OGem0P22PX8208J6QP80QhN70P28R8P2
092@T080UiNG0P2IVITW0<SPf080>3Ph0P0^;Rh202/[:`80:BTY0P0[:b/2034a<@80ADE50P1iNGT2
07MgM`80ATI60P0n?Sh202`/;080:BTY0P0Z:RX202`/;00302XZ:P0];Bd0;Bd]0080;2`/0P0Z:RX2
030`<080>SXj0P0^;Rh202XZ:P809RHV0P0X:2P202TY:@@0:b/[0P0U9BD202LW9`808b<S100U9BD2
02h^;P80BTY:0P1YJFT208B4Q080LW9b0P1FEUH206a/K080Ti>C0P2l_;`20;no_`80Z:RX0P2QXJ42
09VIV@80UIFE00<0VIVI0:RXZ02XZ:P00P2][Jd20;>c/`80_[jn0P33`l<40<[:bP80bl_;0P36a/H2
0<71`@80a/K61037alL209>CT`80JFUY0P1RHV8206MWI`80M7Ad0P1^KVh206UYJ@80G5aL0P1DE5@2
059BDP80CTi>0P12@T8203/k>`80;Rh^0P0[:b/202d];@80ADE50P1:BTX00`1MGEd0MGEe07EeM@02
07UiN@80Hf=S0P13@d<203Xj>P80E5AD0P1RHV8405IFEP80Fe]K0P1CDe<204Q8B080>CTi0P12@T82
07inOP80aLG50P3AdM420<k>cP80d=3@0P3Bd]820<g=c@80c/k>0P38b<P20;Jf]P80UIFE0P1/K6`2
04a<C080ATI60P1/K6`207inOP80JVYZ00<0G5aL061PH01PH600101`L70206e]K@80L71`0P1fMWH2
07UiN@80NWYj0P1mOGd20861P@80QHF50P2:RXX208R8R080SHf=0P2EUID209bLW2L0b>3H0P0c<c<2
034a<@80:2PX0P0W9bL202PX:080<c<c0P13@d<207]kN`80MGEe0P13@d<20451@@80<S8b00<09bLW
02HV9P0V9RH00P0Y:BT402/[:`80:RXZ0P0/;2`2034a<@80>SXj0P0^;Rh202PX:0809bLW0P0Y:BT2
02XZ:P80<30`0P0];Bd202@T90809BDU0P0T92@202DU9@8092@T0P0_;bl204a<C080JVYZ0P28R8P2
075aL@0305UIF@1[Jf/0Jf][0080Rh^;0P38b<P20;Jf]P80[Zj^0P2LW9`409NGU`80VYZJ0P2YZJT2
0:^[Z`80][Jf0P2l_;`20<C4a0@0bl_;0P37alL40<K6aP80alO70P3:b/X20<O7a`80Ti>C0P1UIFD0
0`1WIfL0Jf][06][J`0206i^KP80LW9b0P1YJFT205iNGP80EeMG0P1?Cdl204];B`80@d=30P0d=3@2
02h^;P80:b/[0P0d=3@203lo?`80CDe=0P1SHf<207IfMP80Kfm_0P1SHf<204Y:BP80>3Ph0P1?Cdl2
06=SH`80GEeM0P1@D5000`1FEUH0FUYJ05YJFP0204=3@`80>c/k0P11@D4208F5Q@80aLG50P3=cLd2
0=OGe`80d=3@0P3=cLd40<k>cP80b/[:0P2e]KD209JFUP80JFUY0P18B4P2059BDP80Hf=S0P25QHD2
06ATI080H61P0P1TI6@206=SH`80LW9b00<0Lg=c06a/K01/K6`00P1dM7@207IfMP80Ng]k0P1nOWh2
0820P080Q8B40P29RHT208R8R080T92@0P2HV9P209^KVah0b>3H000L0<SPf080<c<c0P0^;Rh202TY
:@@09RHV0P0d=3@20451@@80Ng]k0P1eMGD20451@@80@4100P0`<3000`0Z:RX0:2PX02PX:00202XZ
:P80:b/[0P0/;2`202XZ:P80:b/[0P0c<c<203Ph>080<C4a0P0W9bL202HV9P80:2PX0P0/;2`202l_
;`80:b/[100U9BD202HV9P808R8R0P0T92@203@d=080B4Q80P1/K6`208N7Q`80LG5a00<0FEUI06i^
KP1^KVh00P2:RXX20<G5a@80][Jf0P2^[Zh209bLW080UYJF0P2EUID209fMW@80YjNW0P2^[Zh20;Fe
]@80_Kfm0P35aLD20<W9b@80c<c<0P39bLT60<G5a@80bl_;0P36a/H209FEU@80IFEU00<0Hf=S06][
J`1[Jf/00P1_Kfl2075aL@80JFUY0P1NGUh205MGE`80D51@0P1:BTX204=3@`80>3Ph0P0_;bl202h^
;P80<c<c0P0n?Sh204i>CP80IFEU0P1fMWH2071`L080HV9R0P1;Bd/203Ti>@80CDe=0P1TI6@205aL
G080D51@00<0EUIF05aLG01LG5`00P16ATH203dm?@80?3`l0P22PX820<W9b@80c/k>0P3EeMD40=3@
d080c/k>0P3?cll20<[:bP80]KFe0P2GUiL206][J`80AdM70P1BDU82069RHP80Q8B4101SHf<2065Q
H@80JFUY0P1aLG400`1`L700Kfm_06m_K`0207=cL`80MgMg0P1jNWX207emO@80PX:20P26QXH208N7
Q`80R8R80P2@T90209NGU`80VIVI9`38h=P203Ph>080;Rh^0P0[:b/202TY:@80:b/[0P0a<C4204E5
A@80NGUi0P1gMgL204I6AP80?Shn0P0/;2`202TY:@80:RXZ0P0/;2`00`0Z:RX0;Bd]02d];@0202`/
;080:RXZ0P0`<30203Xj>P80;Rh^0P0Z:RX202HV9P80:2PX0P0Y:BT402/[:`809BDU0P0W9bL202<S
8`@09BDU0P0^;Rh204Y:BP80JFUY0P24Q8@2079bLP80EUIF0P1/K6`209>CT`80_;bl0P2o_kl20:RX
Z080XJ6Q0P2IVIT209FEU@0309VIV@2XZ:P0Z:RX0080[Jf]0P2c/k<20;jn_P80`l?3103:b/X20<_;
b`80a/K60P31`L420<K6aP@0alO70P2CTi<206UYJ@80HV9R0P1WIfL207AdM080KVi^0P1YJFT205aL
G080E5AD0P1BDU8204i>CP80@T920P0k>c/202h^;P80:b/[0P0];Bd204E5A@80BTY:00<0GEeM07Ee
M@1eMGD00P1iNGT206=SH`80@d=30P0j>SX205ADE080HV9R101FEUH205]KF`80De=C0P18B4P203Ti
>@80@T920P1nOWh20<G5a@80dM7A0P3>c/h20=3@d080d];B0P3=cLd20<k>cP80b<S80P2f][H209FE
U@80K6a/0P1<C4`204I6AP80K6a/0P1nOWh206YZJP0305aLG01PH600H61P00@0L71`0P1]KFd2071`
L080MWIf0P1iNGT207YjNP80OGem0P21PH4208F5Q@80RXZ:0P28R8P208f=S@80UIFE0P2LW9`W0<SP
f080<c<c0P0a<C4202PX:0809bLW0P0X:2P203<c<`80@d=30P1kNg/207EeM@80@d=30P11@D42038b
<P0302LW9`0V9RH09RHV0080:BTY100[:b/202XZ:P80;2`/0P0a<C4203Xj>P80;Rh^0P0X:2P202LW
9`80:BTY0P0Z:RX2030`<080;Bd]0P0T92@202DU9@8092@T0P0U9BD202@T9080;bl_0P1<C4`206YZ
JP80R8R80P1aLG400`1IFET0Jf][06][J`0208^;R`80b<S80P2f][H20:j^[P80W9bL102GUiL209ZJ
VP80ZJVY0P2[Zj/20;Jf]P80_;bl0P34a<@40<_;b`80alO71036a/H20<O7a`80b/[:0P37alL209>C
T`80IFEU00<0IfMW06][J`1[Jf/00P1^KVh2079bLP80JFUY0P1NGUh205MGE`80Cdm?0P1;Bd/204=3
@`80=3@d0P0^;Rh202/[:`80=3@d0P0o?cl204e=C@80Hf=S0P1fMWH206m_K`80Hf=S0P1:BTX203Ph
>080Cdm?0P1SHf<205eMG@80D51@00<0EUIF05YJFP1JFUX00P13@d<203/k>`80@D510P25QHD20<G5
a@80cLg=0P3GemL20=3@d080cLg=103>c/h20<[:bP80]KFe0P2FUYH206UYJ@80B4Q80P1BDU8206=S
H`80QHF50P1TI6@2061PH080I6AT0P1SHf<2079bLP0307=cL`1/K6`0K6a/0080M7Ad0P1fMWH207]k
N`80OWin0P20P80208B4Q080RHV90P28R8P2092@T080V9RH0P2KVi/N0<SPf0007038h=P2030`<080
;bl_0P0];Bd202PX:080:BTY0P0`<302059BDP80SHf=0P1OGel203@d=080@T920P0c<c<00`0Y:BT0
9RHV02HV9P0202LW9`80:BTY1P0/;2`203<c<`80=cLg0P0a<C4202XZ:P@09bLW0P0];Bd2034a<@80
;Rh^0P0Z:RX402LW9`80;Rh^0P0h>3P203`l?080@d=30P1CDe<208B4Q080T92@00<0L71`06UYJ@1Y
JFT00P1^KVh20:f][@80aLG50P2k^k/20:JVYP@0XZ:R0P2XZ:P20:n_[`80/k>c0P2g]kL20;Zj^P80
_[jn0P36a/H20<g=c@80bl_;0P38b<P40<O7a`80cLg=0P3;bl/20;6a/@80TI6A00<0K6a/05MGE`1G
EeL00P1OGel206UYJ@80HV9R0P1FEUH204];B`80@D510P0l?3`203Lg=`80<C4a0P0];Bd202h^;P80
<S8b0P0m?Cd204];B`80Hf=S0P1dM7@2069RHP80CTi>0P0l?3`2059BDP80EeMG0P1JFUX204Y:BP80
?3`l00<0BDU9055AD@1ADE400P1KFe/204M7A`80:b/[0P1LG5`20;Fe]@80bl_;0P3Bd]820<[:bP80
cLg=0P3>c/h20<[:bP80`l?30P2UYJD20861P@80Fe]K0P13@d<205aLG080MgMg0P1kNg/205UIF@80
H61P0P1ZJVX2071`L080Lg=c00<0LG5a06m_K`1_Kfl00P1eMGD207alO080Ogmo0P20P80208B4Q080
QhN70P29RHT208^;R`80Shn?0P2CTi<209BDU2L0b>3H0P0e=CD202XZ:P80<30`0P0V9RH202LW9`80
;Rh^0P1BDU8208R8R080E5AD0P0f=SH204A4A0@0<30`0P0S8b<202@T900302HV9P0_;bl0;bl_0080
9RHV0P0^;Rh203Lg=`80>3Ph0P0_;bl202/[:`80:BTY0P0W9bL203@d=080>CTi0P0b<S8202/[:`80
9BDU0P0X:2P202d];@80=CDe0P18B4P204Y:BP80HV9R0P29RHT209fMW@80MGEe0P1PH60207AdM080
ZJVY0P3=cLd20;no_`80ZZZZ0P2TY:@20:f][@030:ZZZP2b/[80/[:b0080^k^k0P2f][H20;fm_@80
_;bl0P38b<P20<W9b@80bl_;1036a/H20<g=c@80bLW90P38b<P20<;2`P80SHf=0P1MGEd2065QH@80
Jf][0P1UIFD2065QH@80EUIF0P1CDe<20410@080=CDe0P0c<c<2030`<080<C4a0P0];Bd202l_;`80
@T920P17AdL00`1OGel0Lg=c07=cL`0206][J`80AdM70P0d=3@205aLG080HV9R0P1JFUX204Q8B0@0
@T920P1JFUX206a/K080BTY:0P0e=CD205MGE`80/K6a0P3?cll40<c<c080c/k>0P3;bl/20<S8b080
_kno0P2[Zj/20820P080F5QH0P16ATH205QHF080O7al0P1hN7P205iNGP0305YJFP1/K6`0K6a/0080
MgMg0P1bLW82071`L080LG5a0P1cLg<207QhN080Ng]k0P21PH4208J6QP80QhN70P28R8P208^;R`80
SHf=0P2ATI4209VIVBL0b>3H0P0/;2`202h^;P80;Bd]100Y:BT202l_;`80De=C0P2@T902061PH080
<30`0P0o?cl202h^;P0302XZ:P0X:2P0:2PX00809RHV0P0Y:BT202`/;080;bl_0P0/;2`2034a<@80
=cLg0P0a<C4202PX:0809BDU0P0W9bL202XZ:P80<C4a0P0b<S8202LW9`809BDU0P0W9bL202d];@80
?Shn0P0i>CT20492@P80DU9B0P23Ph<2092@T00306m_K`1[Jf/0Jf][0080L71`0P2/[:`20<K6aP80
^k^k0P2WYjL40:BTY080YZJV0P2b/[820;Fe]@80]kNg0P2h^;P20;no_`80alO70P3@d=040<S8b080
b/[:0P35aLD40<W9b@80];Bd0P2>SXh00`1]KFd0EUIF05IFEP02065QH@80J6QX0P1SHf<205EEE@80
BTY:0P10@40203lo?`80=3@d0P0b<S8202l_;`80<30`0P0d=3@203/k>`80CDe=0P1WIfL207QhN080
HF5Q0P1>CTh203Ti>@80DE5A0P1GEeL205UIF@80CTi>0P0g=cL00`1:BTX0DE5A055AD@0205eMG@80
AdM70P0/;2`205UIF@80][Jf0P3?cll20=3@d080b<S80P3>c/h20=3@d080b<S80P36a/H20:FUY@80
Ogmo0P1JFUX203lo?`80GemO0P1gMgL207]kN`80Fe]K0P1OGel206e]K@80K6a/0P1dM7@00`1bLW80
KVi^06i^KP0207EeM@80OGem0P21PH420820P0@0QXJ60P2:RXX208J6QP80TI6A102DU9@N0<SPf000
7038h=P2030`<080;bl_0P0];Bd202PX:080:BTY0P0`<302059BDP80SHf=0P1OGel203@d=080@T92
0P0c<c<00`0Y:BT09RHV02HV9P0202LW9`80:BTY1P0/;2`203<c<`80=cLg0P0a<C4202XZ:P@09bLW
0P0];Bd2034a<@80;Rh^0P0Z:RX402LW9`80;Rh^0P0h>3P203`l?080@d=30P1CDe<208B4Q080T92@
00<0L71`06UYJ@1YJFT00P1^KVh20:f][@80aLG50P2k^k/20:JVYP@0XZ:R0P2XZ:P20:n_[`80/k>c
0P2g]kL20;Zj^P80_[jn0P36a/H20<g=c@80bl_;0P38b<P40<O7a`80cLg=0P3;bl/20;6a/@80TI6A
00<0K6a/05MGE`1GEeL00P1OGel206UYJ@80HV9R0P1FEUH204];B`80@D510P0l?3`203Lg=`80<C4a
0P0];Bd202h^;P80<S8b0P0m?Cd204];B`80Hf=S0P1dM7@2069RHP80CTi>0P0l?3`2059BDP80EeMG
0P1JFUX204Y:BP80?3`l00<0BDU9055AD@1ADE400P1KFe/204M7A`80:b/[0P1LG5`20;Fe]@80bl_;
0P3Bd]820<[:bP80cLg=0P3>c/h20<[:bP80`l?30P2UYJD20861P@80Fe]K0P13@d<205aLG080MgMg
0P1kNg/205UIF@80H61P0P1ZJVX2071`L080Lg=c00<0LG5a06m_K`1_Kfl00P1eMGD207alO080Ogmo
0P20P80208B4Q080QhN70P29RHT208^;R`80Shn?0P2CTi<209BDU2L0b>3H0P0e=CD202XZ:P80<30`
0P0V9RH202LW9`80;Rh^0P1BDU8208R8R080E5AD0P0f=SH204A4A0@0<30`0P0S8b<202@T900302HV
9P0_;bl0;bl_00809RHV0P0^;Rh203Lg=`80>3Ph0P0_;bl202/[:`80:BTY0P0W9bL203@d=080>CTi
0P0b<S8202/[:`809BDU0P0X:2P202d];@80=CDe0P18B4P204Y:BP80HV9R0P29RHT209fMW@80MGEe
0P1PH60207AdM080ZJVY0P3=cLd20;no_`80ZZZZ0P2TY:@20:f][@030:ZZZP2b/[80/[:b0080^k^k
0P2f][H20;fm_@80_;bl0P38b<P20<W9b@80bl_;1036a/H20<g=c@80bLW90P38b<P20<;2`P80SHf=
0P1MGEd2065QH@80Jf][0P1UIFD2065QH@80EUIF0P1CDe<20410@080=CDe0P0c<c<2030`<080<C4a
0P0];Bd202l_;`80@T920P17AdL00`1OGel0Lg=c07=cL`0206][J`80AdM70P0d=3@205aLG080HV9R
0P1JFUX204Q8B0@0@T920P1JFUX206a/K080BTY:0P0e=CD205MGE`80/K6a0P3?cll40<c<c080c/k>
0P3;bl/20<S8b080_kno0P2[Zj/20820P080F5QH0P16ATH205QHF080O7al0P1hN7P205iNGP0305YJ
FP1/K6`0K6a/0080MgMg0P1bLW82071`L080LG5a0P1cLg<207QhN080Ng]k0P21PH4208J6QP80QhN7
0P28R8P208^;R`80SHf=0P2ATI4209VIVBL0b>3H0P0/;2`202h^;P80;Bd]100Y:BT202l_;`80De=C
0P2@T902061PH080<30`0P0o?cl202h^;P0302XZ:P0X:2P0:2PX00809RHV0P0Y:BT202`/;080;bl_
0P0/;2`2034a<@80=cLg0P0a<C4202PX:0809BDU0P0W9bL202XZ:P80<C4a0P0b<S8202LW9`809BDU
0P0W9bL202d];@80?Shn0P0i>CT20492@P80DU9B0P23Ph<2092@T00306m_K`1[Jf/0Jf][0080L71`
0P2/[:`20<K6aP80^k^k0P2WYjL40:BTY080YZJV0P2b/[820;Fe]@80]kNg0P2h^;P20;no_`80alO7
0P3@d=040<S8b080b/[:0P35aLD40<W9b@80];Bd0P2>SXh00`1]KFd0EUIF05IFEP02065QH@80J6QX
0P1SHf<205EEE@80BTY:0P10@40203lo?`80=3@d0P0b<S8202l_;`80<30`0P0d=3@203/k>`80CDe=
0P1WIfL207QhN080HF5Q0P1>CTh203Ti>@80DE5A0P1GEeL205UIF@80CTi>0P0g=cL00`1:BTX0DE5A
055AD@0205eMG@80AdM70P0/;2`205UIF@80][Jf0P3?cll20=3@d080b<S80P3>c/h20=3@d080b<S8
0P36a/H20:FUY@80Ogmo0P1JFUX203lo?`80GemO0P1gMgL207]kN`80Fe]K0P1OGel206e]K@80K6a/
0P1dM7@00`1bLW80KVi^06i^KP0207EeM@80OGem0P21PH420820P0@0QXJ60P2:RXX208J6QP80TI6A
102DU9@N0<SPf0007038h=P202h^;P80;bl_0P0a<C4202XZ:P80;2`/0P0_;bl206EUI@80UIFE0P16
ATH202PX:080@D510P0c<c<00`0Y:BT09RHV02HV9P0202DU9@80:2PX0P0/;2`202d];@80;Rh^0P0b
<S8203Hf=P80<c<c0P0^;Rh202XZ:P80:2PX0P0^;Rh403De=@80<c<c0P0/;2`202TY:@80>c/k0P1=
CDd204A4A080?clo0P0j>SX207EeM@80Y:BT00<0RXZ:06a/K01/K6`00P1HF5P208b<S080alO70P33
`l<20;>c/`@0/;2`0P2d];@20;Rh^080^KVi0P2j^[X40;Ng]`80`/;20P3<c<`20<g=c@@0b/[:0P39
bLT20<S8b080a/K60P39bLT20<71`@0307UiN@1BDU80DU9B0080E5AD0P1QHF4205]KF`80DE5A0P15
ADD203Ti>@80=3@d0P0b<S8202l_;`@0;Rh^0P0a<C4203Ti>@80ADE50P1MGEd206e]K@80DU9B0P0k
>c/2034a<@80JFUY0P1KFe/204Q8B080<S8b0P0S8b<00`0g=cL0BTY:04Y:BP02071`L080E5AD0P0/
;2`204Q8B080Y:BT0P38b<P20<k>cP80a<C40P38b<P20<W9b@80`<300P2b/[8208b<S080IFEU0P1;
Bd/20492@P80I6AT0P25QHD206a/K080DU9B0P1PH60207AdM080N7Qh0P1gMgL00`1cLg<0LG5a075a
L@0207UiN@80PH610P23Ph<208B4Q080QhN70P2:RXX208b<S080SXj>0P2@T904096ATBL0b>3H0P0X
:2P203De=@80:b/[100/;2`203@d=080IVIV0P2=SHd204U9B@80<C4a0P0m?Cd203De=@80:BTY0P0W
9bL202TY:@0302PX:00^;Rh0;Rh^0080;Rh^0P0_;bl202`/;080>SXj100b<S8202XZ:P80:b/[0P0Z
:RX203@d=080>SXj0P0d=3@202XZ:P80:BTY0P0_;bl204U9B@80Bd];0P0i>CT203/k>`80M7Ad0P2H
V9P208j>SP80IfMW0P1LG5`208b<S080`/;20P39bLT20;Bd]080Y:BT0P2_[jl00`2f][H0/k>c0;>c
/`040;Vi^@80^;Rh0P2g]kL20<30`080c<c<0P3?cll20<_;b`80alO71039bLT20<C4a080bLW90P2m
_Kd207YjNP80D51@0P1KFe/205iNGP80EUIF0P1ADE4204A4A0@0>3Ph0P0e=CD203<c<`80:RXZ0P0^
;Rh203@d=080>3Ph0P16ATH00`1LG5`0IfMW06MWI`0205YJFP80<S8b0P0i>CT205iNGP80GEeM0P1<
C4`2030`<080:BTY0P0[:b/204E5A@80L71`0P1=CDd203Ph>080@T920P2MWId40<c<c0H0a/K60P31
`L420:b/[080T92@0P1RHV8204I6AP80A4A40P1MGEd208>3P`80KVi^0P1DE5@00`1KFe/0M7Ad07Ad
M00207YjNP80MGEe0P1dM7@2075aL@80Lg=c0P28R8P208:2PP80Q8B40P29RHT208^;R`80RHV90P2@
T90208b<S080Shn?0P2IVITW0<SPf080;bl_0P0a<C42030`<080;2`/100];Bd206IVIP80UIFE0P17
AdL202TY:@80AdM70P0`<3000`0Z:RX0:2PX02PX:00202<S8`80:BTY0P0];Bd202TY:@80;Bd]0P0e
=CD403@d=080;Rh^0P0/;2`202TY:@80;Bd]0P0d=3@203De=@80<30`0P0^;Rh202XZ:P80=cLg0P1>
CTh204=3@`80@D510P0l?3`207IfMP80XZ:R00<0R8R806e]K@1]KFd00P1FEUH208f=S@80bLW90P2n
_[h20;Jf]P80[Jf]102a/K420;Jf]P80^[Zj0P2f][H20;Vi^@80][Jf0P2m_Kd20<g=c@@0bLW90P3=
cLd20<_;b`80a/K60P38b<P20<[:bP80`/;200<0MgMg055AD@1ADE400P1EEED205iNGP80FEUI0P1D
E5@20451@@80>CTi0P0g=cL2034a<@80<30`0P0Z:RX2034a<@80;Rh^0P0j>SX204A4A080G5aL0P1[
Jf/2059BDP80>c/k0P0d=3@206QXJ080FEUI0P18B4P203@d=0808R8R00<0>CTi04M7A`17AdL00P1a
LG4205=CD`80;2`/0P18B4P20:NWY`80alO70P3;bl/20<K6aP80bl_;0P36a/H20<?3``80[jn_0P2<
S8`2069RHP80DU9B0P0n?Sh206ATI080QXJ60P1/K6`2059BDP80GemO0P1gMgL207EeM@80Ng]k00<0
LW9b075aL@1aLG400P1iNGT208:2PP80P8200P23Ph<408Z:RP80R8R80P2ATI4208n?S`@0TI6A7P38
h=P001`0b>3H0P0^;Rh202l_;`80<C4a0P0Z:RX202`/;080;bl_0P1UIFD209FEU@80ATI60P0X:2P2
0451@@80<c<c00<0:BTY02HV9P0V9RH00P0U9BD202PX:080;2`/0P0];Bd202h^;P80<S8b0P0f=SH2
03<c<`80;Rh^0P0Z:RX202PX:080;Rh^100e=CD203<c<`80;2`/0P0Y:BT203/k>`80CDe=0P14A4@2
03lo?`80>SXj0P1eMGD20:BTY00308Z:RP1/K6`0K6a/0080F5QH0P2<S8`20<O7a`80`l?30P2c/k<4
0;2`/080];Bd0P2h^;P20;Vi^@80^[Zj102g]kL20<;2`P80c<c<0P3=cLd40<[:bP80bLW90P38b<P2
0<K6aP80bLW90P31`L400`1iNGT0DU9B059BDP0205ADE080HF5Q0P1KFe/2055AD@80ADE50P0i>CT2
03@d=080<S8b0P0_;bl402h^;P80<C4a0P0i>CT204E5A@80GEeM0P1]KFd2059BDP80>c/k0P0a<C42
06UYJ@80Fe]K0P18B4P2038b<P808b<S00<0=cLg04Y:BP1:BTX00P1`L70205ADE080;2`/0P18B4P2
0:BTY080b<S80P3>c/h20<C4a080b<S80P39bLT20<30`080/[:b0P2<S8`206EUI@80Bd];0P12@T82
06ATI080QHF50P1/K6`2059BDP80H61P0P1dM7@207QhN080MgMg00<0Lg=c075aL@1aLG400P1iNGT2
0861P@80Ph>30P24Q8@208N7Q`80RXZ:0P2<S8`208j>SP80T92@102ATI4W0<SPf080:2PX0P0e=CD2
02/[:`@0;2`/0P0d=3@206IVIP80SHf=0P19BDT2034a<@80?Cdm0P0e=CD202TY:@809bLW0P0Y:BT0
0`0X:2P0;Rh^02h^;P0202h^;P80;bl_0P0/;2`203Xj>P@0<S8b0P0Z:RX202/[:`80:RXZ0P0d=3@2
03Xj>P80=3@d0P0Z:RX202TY:@80;bl_0P19BDT204];B`80>CTi0P0k>c/207AdM080V9RH0P2>SXh2
06MWI`80G5aL0P2<S8`20<;2`P80bLW90P2d];@20:BTY080[jn_00<0][Jf0;>c/`2c/k<0102i^KT2
0;Rh^080]kNg0P30`<020<c<c080clo?0P3;bl/20<O7a`@0bLW90P34a<@20<W9b@80_Kfm0P1jNWX2
051@D080Fe]K0P1NGUh205IFEP80DE5A0P14A4@403Ph>080=CDe0P0c<c<202XZ:P80;Rh^0P0d=3@2
03Ph>080ATI600<0G5aL06MWI`1WIfL00P1JFUX2038b<P80>CTi0P1NGUh205eMG@80C4a<0P0`<302
02TY:@80:b/[0P15ADD2071`L080CDe=0P0h>3P20492@P80WIfM103<c<`60<K6aP80`L710P2/[:`2
092@T080HV9R0P16ATH204A4A080GEeM0P23Ph<206i^KP80E5AD00<0Fe]K07AdM01dM7@00P1jNWX2
07EeM@80M7Ad0P1aLG4207=cL`80R8R80P22PX8208B4Q080RHV90P2;Rh/208V9R@80T92@0P2<S8`2
08n?S`80VIVI9`38h=P202l_;`80<C4a0P0`<30202`/;0@0;Bd]0P1VIVH209FEU@80AdM70P0Y:BT2
04M7A`80<30`00<0:RXZ02PX:00X:2P00P0S8b<202TY:@80;Bd]0P0Y:BT202d];@80=CDe100d=3@2
02h^;P80;2`/0P0Y:BT202d];@80=3@d0P0e=CD2030`<080;Rh^0P0Z:RX203Lg=`80CTi>0P13@d<2
0451@@80?3`l0P1fMWH20::RXP0308R8R01]KFd0KFe]0080EUIF0P2=SHd20<W9b@80_[jn0P2f][H2
0:f][@@0/K6a0P2f][H20;Zj^P80][Jf0P2i^KT20;Jf]P80_Kfm0P3=cLd40<W9b@80cLg=0P3;bl/2
0<K6aP80b<S80P3:b/X20<;2`P0307MgM`1ADE40DE5A0080EEEE0P1NGUh205UIF@80E5AD0P11@D42
03Ti>@80=cLg0P0a<C42030`<080:RXZ0P0a<C4202h^;P80>SXj0P14A4@205aLG080Jf][0P1BDU82
03/k>`80=3@d0P1XJ6P205UIF@80B4Q80P0d=3@2028R8P0303Ti>@17AdL0AdM70080LG5a0P1CDe<2
02`/;080B4Q80P2WYjL20<O7a`80bl_;0P36a/H20<_;b`80a/K60P33`l<20:n_[`80S8b<0P1RHV82
059BDP80?Shn0P1TI6@208J6QP80K6a/0P1BDU8205mOG`80MgMg0P1eMGD207]kN`03079bLP1aLG40
LG5a0080NGUi0P22PX820820P080Ph>3102:RXX208R8R080TI6A0P2?Shl4096ATAh0b>3H000L0<SP
f080;bl_100^;Rh202LW9`80<30`0P0g=cL207QhN080OGem0P0i>CT202PX:080=SHf0P0a<C400`0]
;Bd0:RXZ02XZ:P0202PX:080:RXZ100];Bd202h^;P80;bl_0P0`<302034a<@80<S8b0P0/;2`202TY
:@80=cLg0P16ATH204Q8B080A4A40P0h>3P202/[:`808R8R0P0M7Ad2024Q8@@0;Rh^0P1CDe<208n?
S`0309RHV029RHT0RHV90080EUIF0P1fMWH20::RXP80]kNg0P32`/820;Bd]080ZJVY0P2][Jd20;Bd
]080][Jf0P2g]kL40;Fe]@80^k^k0P33`l<20<W9b@80cLg=0P3;bl/40<O7a`80a/K60P38b<P20;fm
_@030;^k^`1aLG40LG5a0080F5QH0P1=CDd205ADE080EEEE0P1<C4`20492@P80>c/k0P0f=SH2030`
<0@0:b/[0P0^;Rh203@d=080?Cdm0P1@D50205eMG@80ATI6100b<S8205IFEP80BTY:0P0i>CT202/[
:`809BDU00<071`L03Ph>00h>3P00P1DE5@204m?C`80=SHf0P14A4@209NGU`80clo?0P3Cdm<20<C4
a080`/;20P2i^KT20;Fe]@80RHV90P1UIFD204E5A@80?3`l0P0o?cl205EEE@80JVYZ0P1HF5P204a<
C080HF5Q0P1kNg/207emO@80NWYj00<0MWIf07AdM01dM7@00P1jNWX20861P@80Q8B40P26QXH208R8
R080Rh^;0P2>SXh2092@T080TY:B102CTi<W0<SPf0809bLW0P0h>3P202h^;P809bLW0P0/;2`203hn
?P80NWYj0P1mOGd203lo?`80:b/[0P0e=CD202/[:`80;2`/0P0X:2P202XZ:P0302/[:`0Y:BT0:BTY
0080<c<c0P0`<30202l_;`80<C4a0P0^;Rh202l_;`@0:b/[0P0];Bd20410@080B4Q80P11@D4203Ph
>080>SXj0P0U9BD202HV9P809bLW0P0Q8B4202DU9@80DU9B0P2=SHd20:6QX@80OWin0P1PH60206a/
K080W9bL0P36a/H20;fm_@80Y:BT0P2][Jd00`2_[jl0/K6a0;6a/@020;Ng]`80/[:b0P2a/K420;Ng
]`80^KVi0P33`l<20<k>cP80bl_;0P3:b/X20<O7a`80`L710P38b<P20<G5a@80bl_;0P2g]kL206][
J`80DE5A0P1BDU8205QHF080EEEE0P1>CTh204A4A080>3Ph0P0a<C4203De=@80;2`/0P0Z:RX202`/
;080<c<c0P11@D400`1BDU80FUYJ05YJFP02055AD@80<S8b0P0l?3`2051@D080Cdm?0P0`<30202HV
9P8092@T0P0W9bL203Ph>080FUYJ0P11@D42038b<P80B4Q80P2SXj<40<c<c080alO71030`<020;Vi
^@80Rh^;0P1[Jf/204Q8B080?3`l0P0n?Sh206QXJ080K6a/0P1DE5@204];B`0306ATI01kNg/0Ng]k
0080O7al0P1hN7P207YjNP80MgMg0P1iNGT20820P080QhN70P22PX8208N7Q`@0Rh^;0P2FUYH208f=
S@80TI6A0P2JVYXW0<SPf080;Rh^100];Bd202HV9P80<30`0P0d=3@207UiN@80O7al0P0i>CT202DU
9@80=cLg0P0/;2`00`0_;bl0:RXZ02XZ:P0202XZ:P80;2`/0P0Z:RX202l_;`80<30`0P0b<S8202l_
;`80<S8b0P0`<30202d];@80:RXZ0P0g=cL204Q8B080BTY:0P19BDT203/k>`80:b/[0P0S8b<201dM
7@807alO100];Bd2059BDP80TI6A00<0Vi^K08R8R028R8P00P1GEeL207EeM@80YJFU0P2e]KD20<71
`@80^;Rh0P2YZJT20:j^[P80];Bd0P2j^[X20;Ng]`80][Jf0P2h^;P20;bl_080alO70P3<c<`20<o?
c`80c<c<0P35aLD40<C4a080b/[:0P2n_[h00`2l_;`0M7Ad07AdM00205UIF@80Cdm?0P1FEUH205EE
E@80Bd];0P12@T8203lo?`80<S8b0P0`<30202XZ:P80;Bd]0P0[:b/203Hf=P80>SXj0P1>CTh205aL
G080B4Q80P0`<30203Hf=P80EUIF0P1:BTX203Ph>080;2`/0P0T92@00`0N7Qh0>SXj03Xj>P02055A
D@80D51@0P0i>CT204=3@`80UiNG0P3?cll20=7Ad@80a<C40P31`L420;Vi^@80][Jf0P28R8P206IV
IP80@d=30P0n?Sh20410@080EUIF0P1XJ6P205IFEP80BTY:0P1RHV8207YjNP80O7al0`1gMgL207Ad
M080NGUi0P20P80208B4Q080QXJ60P27QhL408b<S0H0TI6A0P2EUIDN0<SPf0007038h=P202l_;`@0
;Rh^0P0W9bL2030`<080=cLg0P1hN7P207emO@80>CTi0P0X:2P203Hf=P80<C4a00<0;Bd]02XZ:P0Z
:RX00P0X:2P202XZ:P@0;Bd]0P0^;Rh202l_;`80<30`0P0a<C42038b<P80;2`/0P0Y:BT203Lg=`80
ATI60P18B4P204A4A080>3Ph0P0[:b/2028R8P807AdM0P0Q8B4402h^;P80De=C0P2?Shl00`2HV9P0
RHV908V9R@0205IFEP80MWIf0P2RXZ820;Ng]`80`/;20P2d];@20:VYZ@80[Jf]0P2d];@20;Jf]P80
]kNg102e]KD20;^k^`80`l?30P39bLT20<g=c@80bl_;1037alL20<K6aP80b<S80P2m_Kd00`2k^k/0
LG5a075aL@0205QHF080CDe=0P1DE5@205EEE@80C4a<0P12@T8203/k>`80=SHf0P0`<30402/[:`80
;Rh^0P0d=3@203dm?@80D51@0P1MGEd204I6AP@0<S8b0P1FEUH204Y:BP80>CTi0P0[:b/202DU9@03
01`L700h>3P0>3Ph0080E5AD0P1?Cdl203Hf=P80A4A40P2GUiL20<o?c`80dm?C0P34a<@20<;2`P80
^KVi0P2e]KD208V9R@80IFEU0P15ADD203`l?080?clo0P1EEED206YZJP80F5QH0P1<C4`2065QH@80
Ng]k0P1mOGd207YjNP0307IfMP1dM7@0M7Ad0080NWYj0P21PH4208B4Q080QXJ60P28R8P208^;R`80
SXj>0P2@T90209:BTP@0Ti>C9`38h=P202LW9`80>3Ph0P0^;Rh202LW9`80;2`/0P0n?Sh207YjNP80
OGem0P0o?cl202/[:`80=CDe0P0[:b/202`/;080:2PX0P0Z:RX00`0[:b/0:BTY02TY:@0203<c<`80
<30`0P0_;bl2034a<@80;Rh^0P0_;bl402/[:`80;Bd]0P10@40204Q8B080@D510P0h>3P203Xj>P80
9BDU0P0V9RH202LW9`808B4Q0P0U9BD2059BDP80SHf=0P2QXJ4207inOP80H61P0P1/K6`209bLW080
a/K60P2m_Kd20:BTY080[Jf]00<0[jn_0;6a/@2a/K400P2g]kL20;:b/P80/K6a0P2g]kL20;Vi^@80
`l?30P3>c/h20<_;b`80b/[:0P37alL20<71`@80b<S80P35aLD20<_;b`80]kNg0P1[Jf/2055AD@80
DU9B0P1HF5P205EEE@80CTi>0P14A4@203Ph>080<C4a0P0e=CD202`/;080:RXZ0P0/;2`203<c<`80
@D5100<0DU9B05YJFP1JFUX00P1ADE42038b<P80?3`l0P1@D50204m?C`80<30`0P0V9RH202@T9080
9bLW0P0h>3P205YJFP80@D510P0b<S8204Q8B080Xj>S103<c<`20<O7a`@0`<300P2i^KT208^;R`80
Jf][0P18B4P203`l?080?Shn0P1XJ6P206a/K080E5AD0P1;Bd/00`1TI6@0Ng]k07]kN`0207alO080
N7Qh0P1jNWX207MgM`80NGUi0P20P80208N7Q`80PX:20P27QhL408^;R`80UYJF0P2=SHd2096AT@80
VYZJ9`38h=P202h^;P@0;Bd]0P0V9RH2030`<080=3@d0P1iNGT207alO080>CTi0P0U9BD203Lg=`80
;2`/00<0;bl_02XZ:P0Z:RX00P0Z:RX202`/;080:RXZ0P0_;bl2030`<080<S8b0P0_;bl2038b<P80
<30`0P0];Bd202XZ:P80=cLg0P18B4P204Y:BP80BDU90P0k>c/202/[:`808b<S0P0M7Ad201lO7`@0
;Bd]0P1BDU82096AT@0309^KV`28R8P0R8R80080EeMG0P1eMGD20:FUY@80]KFe0P31`L420;Rh^080
ZJVY0P2^[Zh20;Bd]080^[Zj0P2g]kL20;Jf]P80^;Rh0P2l_;`20<O7a`80c<c<0P3?cll20<c<c080
aLG51034a<@20<[:bP80_[jn00<0_;bl07AdM01dM7@00P1IFET204m?C`80EUIF0P1EEED204];B`80
@T920P0o?cl2038b<P80<30`0P0Z:RX202d];@80:b/[0P0f=SH203Xj>P80CTi>0P1LG5`204Q8B080
<30`0P0f=SH205IFEP80BTY:0P0h>3P202`/;08092@T00<07QhN03Xj>P0j>SX00P1ADE42051@D080
>CTi0P13@d<209NGU`80clo?0P3AdM420<C4a080`L710P2i^KT20;Jf]P80R8R80P1VIVH204=3@`80
?Shn0P10@40205IFEP80J6QX0P1FEUH204Y:BP80HV9R0P1jNWX207alO0<0MgMg0P1dM7@207UiN@80
P8200P24Q8@208J6QP80QhN7102<S8`6096AT@80UIFE7P38h=P001`0b>3H0P0_;bl402h^;P80:2PX
0P0c<c<204A4A080R8R80P1NGUh2034a<@80:b/[0P0/;2`202h^;P0302l_;`0^;Rh0;Rh^00@0;2`/
100];Bd202h^;P80;bl_0P0b<S8203Lg=`80>c/k0P0d=3@202l_;`80?clo0P1@D50205=CD`80CTi>
0P0l?3`202XZ:P80:2PX0P0Y:BT2020P80806a/K0P0R8R82038b<P80KFe]00<0Vi^K0:>SX`2SXj<0
0P1RHV8206MWI`80N7Qh0P2UYJD20<_;b`80^;Rh0P2RXZ820:FUY@80[Zj^0P2a/K440;>c/`80];Bd
0P2e]KD20;Vi^@80aLG50P3?cll20<_;b`80a<C41033`l<20<S8b080c<c<00<0]kNg0;Jf]P2f][H0
0P1/K6`204M7A`80C4a<0P1IFET205ADE080CDe=0P16ATH203dm?@80<S8b0P0Z:RX202TY:@80;2`/
0P0_;bl203De=@80@T920P1;Bd/203`l?080;Bd]0P0f=SH203dm?@80=SHf0P0];Bd202DU9@80:BTY
00<09bLW06=SH`1SHf<00P1>CTh20451@@80GEeM0P23Ph<20:b/[080clo?0P3>c/h20<30`080]KFe
102PX:0205eMG@80@D510P0[:b/202l_;`80>c/k0P12@T8404M7A`80BTY:0P1UIFD207moO`80PH61
0P1lO7`00`1jNWX0N7Qh07QhN00207]kN`80PH610P24Q8@208N7Q`80RXZ:0P2<S8`208n?S`80TI6A
0P2DU9@409JFURL0b>3H0P0/;2`2030`<080;Bd]0P0^;Rh2030`<080AdM70P20P80206EUI@80:RXZ
0P0_;bl202d];@@0<C4a0P0^;Rh202/[:`03038b<P0_;bl0;bl_0080:b/[0P0];Bd2030`<080<S8b
100k>c/202d];@80<c<c0P0o?cl2051@D080FUYJ0P1EEED2038b<P80:RXZ0P0W9bL2028R8P808B4Q
0P0O7al2024Q8@80<S8b0P1bLW8209RHV080W9bL0P1[Jf/205mOG`80NGUi0P2a/K420<S8b080/;2`
0P2TY:@00`2XZ:P0[:b/0:b/[0020;>c/`80]KFe0P2_[jl20;Fe]@80^;Rh0P2f][H20<[:bP80c/k>
0P39bLT20<O7a`80`L711P35aLD20<C4a080[jn_0P1YJFT204a<C080D51@0P1GEeL205EEE@80C4a<
0P14A4@203`l?080<S8b0P0Z:RX202TY:@80:RXZ0P0c<c<203De=@0303dm?@1=CDd0CDe=0080@d=3
0P0[:b/202l_;`80?Shn0P0l?3`202d];@809bLW0P0T92@202PX:080F5QH0P1GEeL20451@@80EUIF
0P1iNGT20:j^[P80b/[:0P3<c<`20;no_`80/;2`0P2SXj<209ZJVP80HF5Q0P15ADD402/[:`80>c/k
0P1<C4`204Y:BP80?clo0P1?Cdl00`1]KFd0Ng]k07]kN`0208:2PP80O7al0P1iNGT207IfMP80NGUi
0P20P80208Z:RP80QXJ60P2<S8`208^;R`80TY:B0P2@T902096AT@80U9BD0P2IVITW0<SPf080;Rh^
0P0_;bl202d];@80:BTY0P0c<c<20492@P80R8R80P1OGel2038b<P80:b/[0P0_;bl202`/;003034a
<@0`<300<30`0080;Bd]0P0T92@2030`<080;Bd]0P0/;2`202l_;`80<S8b0P0h>3P203Ti>@80=SHf
0P0^;Rh203hn?P80Cdm?0P1CDe<204];B`80?Shn0P0Y:BT202HV9P80:2PX0P0Q8B4201XJ6P8092@T
0P0a<C4206a/K0<0W9bL0P1SHf<206a/K080NGUi0P2QXJ420<[:bP80_;bl0P2PX:020:>SX`80[Zj^
0P2`/;020;:b/P80];Bd0P2c/k<20;Ng]`80]KFe0P33`l<20<c<c080c/k>1033`l<20<C4a080b/[:
0P3<c<`00`2c/k<0];Bd0;Bd]00206e]K@80AdM70P1:BTX205]KF`80EUIF0P1;Bd/204I6AP80?Cdm
0P0c<c<202LW9`80:RXZ0P0[:b/202l_;`80=SHf0P12@T8204];B`80>c/k0P0^;Rh203De=@80>c/k
0P0d=3@202h^;P809bLW0P0Z:RX00`0X:2P0HF5Q065QH@02059BDP80@4100P1LG5`208>3P`80ZZZZ
0P3@d=020<g=c@80`l?30P2f][H20:>SX`80XJ6Q0P1MGEd20451@@80:2PX0P0b<S8203Lg=`80A4A4
0P16ATH204a<C080BDU90P1WIfL208:2PP80PH610P1oOgl00`1hN7P0NWYj07YjNP0207]kN`80PH61
0P27QhL208J6QP80Rh^;0P2=SHd2092@T0@0Ti>C0P2FUYH209RHV1h0b>3H000L0<SPf080;bl_100^
;Rh202PX:080<c<c0P14A4@208R8R080GUiN0P0a<C4202/[:`80;2`/0P0^;Rh00`0_;bl0;Rh^02h^
;P0402`/;0@0;Bd]0P0^;Rh202l_;`80<S8b0P0g=cL203/k>`80=3@d0P0_;bl203lo?`80D51@0P1C
De<204i>CP80?3`l0P0Z:RX202PX:080:BTY0P0P820201/K6`808R8R0P0b<S8206e]K@0309^KV`2S
Xj<0Xj>S0080HV9R0P1WIfL207QhN080YJFU0P3;bl/20;Rh^080XZ:R0P2UYJD20:j^[P80/K6a102c
/k<20;Bd]080]KFe0P2i^KT20<G5a@80clo?0P3;bl/20<C4a0@0`l?30P38b<P20<c<c0030;Ng]`2f
][H0][Jf0080K6a/0P17AdL204a<C080FEUI0P1DE5@204e=C@80ATI60P0m?Cd2038b<P80:RXZ0P0Y
:BT202`/;080;bl_0P0e=CD20492@P80Bd];0P0l?3`202d];@80=SHf0P0m?Cd203Hf=P80;Bd]0P0U
9BD202TY:@0302LW9`1SHf<0Hf=S0080CTi>0P11@D4205eMG@80Ph>30P2/[:`20<o?c`80c/k>0P30
`<020;Fe]@@0X:2P0P1MGEd20451@@80:b/[0P0_;bl203/k>`80@T921017AdL204Y:BP80IFEU0P1o
Ogl20861P@80O7al00<0NWYj07QhN01hN7P00P1kNg/20861P@80Q8B40P27QhL208Z:RP80S8b<0P2?
Shl2096AT@80U9BD102FUYHW0<SPf080;2`/0P0`<30202d];@80;Rh^0P0`<30204M7A`80P8200P1U
IFD202XZ:P80;bl_0P0];Bd4034a<@80;Rh^0P0[:b/00`0b<S80;bl_02l_;`0202/[:`80;Bd]0P0`
<302038b<P@0>c/k0P0];Bd203<c<`80?clo0P1@D50205YJFP80EEEE0P0b<S8202XZ:P809bLW0P0R
8R82024Q8@807alO0P0Q8B42038b<P80LW9b0P2HV9P209bLW080Jf][0P1OGel207UiN@80/K6a0P38
b<P20;2`/080Y:BT00<0Z:RX0:b/[02/[:`00P2c/k<20;Fe]@80[jn_0P2e]KD20;Rh^080][Jf0P3:
b/X20<k>cP80bLW90P37alL20<71`@H0aLG50P34a<@20:n_[`80JFUY0P1<C4`2051@D080EeMG0P1E
EED204a<C080A4A40P0l?3`2038b<P80:RXZ0P0Y:BT202XZ:P80<c<c0P0e=CD00`0m?Cd0CDe=04e=
C@0204=3@`80:b/[0P0_;bl203hn?P80?3`l0P0];Bd202LW9`8092@T0P0X:2P205QHF080EeMG0P11
@D4205IFEP80NGUi0P2^[Zh20<[:bP80c<c<0P2o_kl20;2`/080Xj>S0P2JVYX2065QH@80ADE5100[
:b/203/k>`80C4a<0P1:BTX203lo?`80Cdm?00<0KFe]07]kN`1kNg/00P22PX8207alO080NGUi0P1f
MWH207UiN@80P8200P2:RXX208J6QP80S8b<0P2;Rh/209:BTP80T92@0P2ATI4209BDU080VIVI9`38
h=P202h^;P80;bl_0P0];Bd202TY:@80<c<c0P12@T8208R8R080GemO0P0b<S8202/[:`80;bl_0P0/
;2`00`0a<C40<30`030`<00202d];@8092@T0P0`<30202d];@80;2`/0P0_;bl2038b<P80>3Ph0P0i
>CT203Hf=P80;Rh^0P0n?Sh204m?C`80De=C0P1;Bd/203hn?P80:BTY0P0V9RH202PX:0808B4Q0P0J
6QX202@T9080<C4a0P1/K6`309bLW080Hf=S0P1/K6`207UiN@80XJ6Q0P3:b/X20;bl_080X:2P0P2S
Xj<20:j^[P80/;2`0P2b/[820;Bd]080/k>c0P2g]kL20;Fe]@80`l?30P3<c<`20<k>cP@0`l?30P34
a<@20<[:bP80c<c<00<0/k>c0;Bd]02d];@00P1]KFd204M7A`80BTY:0P1KFe/205IFEP80Bd];0P16
ATH203dm?@80<c<c0P0W9bL202XZ:P80:b/[0P0_;bl203Hf=P80@T920P1;Bd/203/k>`80;Rh^0P0e
=CD203/k>`80=3@d0P0^;Rh202LW9`80:RXZ00<0:2PX065QH@1QHF400P1BDU820410@080G5aL0P23
Ph<20:ZZZP80d=3@0P3=cLd20<?3``80][Jf0P2SXj<20:6QX@80GEeM0P11@D4202PX:080<S8b0P0g
=cL204A4A080ATI60P1<C4`204U9B@80IfMW0P22PX820861P@80Ogmo00<0N7Qh07YjNP1jNWX00P1k
Ng/20861P@80QhN70P26QXH208^;R`80SHf=0P2@T90409>CT`80UYJF0P2HV9PN0<SPf0007038h=P2
02`/;080<S8b0P0n?Sh204=3@`80<30`0P1DE5@208b<S080CDe=0P0];Bd202/[:`80;bl_0P0^;Rh0
0`0];Bd0;2`/02`/;00402XZ:P80:b/[0P0Y:BT202LW9`80>CTi0P1>CTh205MGE`80Fe]K0P1CDe<2
04a<C080G5aL0P1WIfL2059BDP80>3Ph0P0_;bl202/[:`809RHV0P0R8R8401lO7`80820P0P0Y:BT2
04U9B@0308b<S02PX:00X:2P0080Q8B40P1/K6`2069RHP80T92@0P2m_Kd20<[:bP80ZZZZ102YZJT2
0:b/[080[jn_0P2b/[820;Bd]080][Jf0P2i^KT20<C4a080cLg=0P3;bl/20<K6aP80a<C40P33`l<4
0<C4a0030;no_`2g]kL0]kNg0080];Bd0P1/K6`20492@PH0C4a<0P17AdL203lo?`80=SHf0P0^;Rh2
02d];@80;Rh^0P0_;bl2034a<@80=SHf0P0j>SX203De=@80;bl_100d=3@2034a<@80;2`/0P0Y:BT2
02/[:`0302TY:@19BDT0BDU900@0?Shn0P1HF5P207IfMP80W9bL0P2n_[h20;^k^`80ZJVY0P2CTi<2
07IfMP80JFUY0P0n?Sh2030`<0809bLW0P0Z:RX402l_;`80<S8b0P10@40205=CD`80KFe]0P23Ph<2
08F5Q@80PX:200<0OWin07alO01lO7`00P1nOWh208:2PP80QHF50P29RHT208Z:RP80S8b<0P2?Shl2
09:BTP80UIFE0P2FUYH209NGUbL0b>3H0P0a<C42030`<080>3Ph0P10@40203<c<`80Cdm?0P2=SHd2
05=CD`80:2PX0P0^;Rh402`/;080;bl_0P0[:b/202PX:00302TY:@0X:2P0:2PX00809BDU0P0[:b/2
03@d=080B4Q80P1WIfL2061PH080BTY:0P1JFUX205=CD`80KFe]0P1NGUh202l_;`80:BTY0P0Z:RX2
02PX:0808b<S0P0U9BD2028R8P80820P0P0V9RH205=CD`80S8b<0P2OWil208F5Q@@0IFEU0P2BTY82
0<?3``80a/K60P2[Zj/00`2/[:`0YZJV0:JVYP020:n_[`80/[:b0P2^[Zh40;Fe]@80];Bd0P34a<@2
0<W9b@80b/[:0P34a<@20<O7a`80aLG50P30`<020;jn_P80`<300P38b<P20:j^[P80HF5Q0P14A4@2
04Q8B080D51@101;Bd/204I6AP80>SXj0P0Y:BT202l_;`80<C4a0P0`<302034a<@03030`<00e=CD0
=CDe0080=CDe0P0_;bl202/[:`80=SHf0P0a<C42038b<P80:2PX0P0^;Rh2030`<080C4a<0P0n?Sh2
04E5A@80GUiN0P20P8020::RXP80`L710P30`<020:n_[`80UIFE0P1gMgL2069RHP80>c/k0P0Z:RX2
02LW9`809RHV0P0W9bL202XZ:P80;2`/0P0c<c<2055AD@0306i^KP21PH40PH610080QhN70P21PH42
07inOP80OGem0P20P80207inOP80QhN70P28R8P208F5Q@80SXj>0P2<S8`209>CT`80UIFE0P2HV9P2
09VIVBL0b>3H0P0Y:BT203De=@80>c/k0P17AdL2030`<080E5AD0P2=SHd2055AD@80;Rh^0P0X:2P2
034a<@80;Bd]0`0[:b/202XZ:P80:b/[0P0];Bd202PX:0809bLW0P0g=cL204e=C@80EeMG0P1KFe/2
05ADE080C4a<0P1NGUh206IVIP80DE5A0P0e=CD202l_;`80:b/[0P0X:2P402<S8`807AdM0P0O7al2
02TY:@80Bd];00<0SXj>09bLW02LW9`00P27QhL206][J`80HV9R0P2=SHd20;fm_@80clo?0P2WYjL2
0:ZZZP80Z:RX102][Jd20;Fe]@80[Zj^0P2h^;P20;Ng]`80aLG50P3=cLd20<W9b@80alO70P36a/H4
0<;2`P80alO700<0_[jn0;Zj^P2j^[X00P2e]KD206a/K080?Shn0P19BDT204e=C@80C4a<0P15ADD2
03lo?`80=SHf0P0`<30402l_;`80:BTY0P0c<c<203Ph>080>SXj0P0c<c<202l_;`80=CDe0P0g=cL2
038b<P80:b/[1@0X:2P204M7A`80?clo0P0k>c/205MGE`80MWIf0P2OWil20;no_`80^[Zj0P2VYZH2
09BDU080LW9b0P1WIfL203hn?P80<c<c0P0W9bL202d];@80;Rh^0P0/;2`2030`<080@T920P1ADE42
06UYJ@80OWin0P27QhL208:2PPD0Ng]k0P22PX8208>3P`80RHV90P2:RXX208R8R080T92@0P2?Shl2
09BDU080UYJF0P2GUiLN0<SPf0007038h=P202`/;080<S8b0P0n?Sh204=3@`80<30`0P1DE5@208b<
S080CDe=0P0];Bd202/[:`80;bl_0P0^;Rh00`0];Bd0;2`/02`/;00402XZ:P80:b/[0P0Y:BT202LW
9`80>CTi0P1>CTh205MGE`80Fe]K0P1CDe<204a<C080G5aL0P1WIfL2059BDP80>3Ph0P0_;bl202/[
:`809RHV0P0R8R8401lO7`80820P0P0Y:BT204U9B@0308b<S02PX:00X:2P0080Q8B40P1/K6`2069R
HP80T92@0P2m_Kd20<[:bP80ZZZZ102YZJT20:b/[080[jn_0P2b/[820;Bd]080][Jf0P2i^KT20<C4
a080cLg=0P3;bl/20<K6aP80a<C40P33`l<40<C4a0030;no_`2g]kL0]kNg0080];Bd0P1/K6`20492
@PH0C4a<0P17AdL203lo?`80=SHf0P0^;Rh202d];@80;Rh^0P0_;bl2034a<@80=SHf0P0j>SX203De
=@80;bl_100d=3@2034a<@80;2`/0P0Y:BT202/[:`0302TY:@19BDT0BDU900@0?Shn0P1HF5P207If
MP80W9bL0P2n_[h20;^k^`80ZJVY0P2CTi<207IfMP80JFUY0P0n?Sh2030`<0809bLW0P0Z:RX402l_
;`80<S8b0P10@40205=CD`80KFe]0P23Ph<208F5Q@80PX:200<0OWin07alO01lO7`00P1nOWh208:2
PP80QHF50P29RHT208Z:RP80S8b<0P2?Shl209:BTP80UIFE0P2FUYH209NGUbL0b>3H0P0a<C42030`
<080>3Ph0P10@40203<c<`80Cdm?0P2=SHd205=CD`80:2PX0P0^;Rh402`/;080;bl_0P0[:b/202PX
:00302TY:@0X:2P0:2PX00809BDU0P0[:b/203@d=080B4Q80P1WIfL2061PH080BTY:0P1JFUX205=C
D`80KFe]0P1NGUh202l_;`80:BTY0P0Z:RX202PX:0808b<S0P0U9BD2028R8P80820P0P0V9RH205=C
D`80S8b<0P2OWil208F5Q@@0IFEU0P2BTY820<?3``80a/K60P2[Zj/00`2/[:`0YZJV0:JVYP020:n_
[`80/[:b0P2^[Zh40;Fe]@80];Bd0P34a<@20<W9b@80b/[:0P34a<@20<O7a`80aLG50P30`<020;jn
_P80`<300P38b<P20:j^[P80HF5Q0P14A4@204Q8B080D51@101;Bd/204I6AP80>SXj0P0Y:BT202l_
;`80<C4a0P0`<302034a<@03030`<00e=CD0=CDe0080=CDe0P0_;bl202/[:`80=SHf0P0a<C42038b
<P80:2PX0P0^;Rh2030`<080C4a<0P0n?Sh204E5A@80GUiN0P20P8020::RXP80`L710P30`<020:n_
[`80UIFE0P1gMgL2069RHP80>c/k0P0Z:RX202LW9`809RHV0P0W9bL202XZ:P80;2`/0P0c<c<2055A
D@0306i^KP21PH40PH610080QhN70P21PH4207inOP80OGem0P20P80207inOP80QhN70P28R8P208F5
Q@80SXj>0P2<S8`209>CT`80UIFE0P2HV9P209VIVBL0b>3H0P0Y:BT203De=@80>c/k0P17AdL2030`
<080E5AD0P2=SHd2055AD@80;Rh^0P0X:2P2034a<@80;Bd]0`0[:b/202XZ:P80:b/[0P0];Bd202PX
:0809bLW0P0g=cL204e=C@80EeMG0P1KFe/205ADE080C4a<0P1NGUh206IVIP80DE5A0P0e=CD202l_
;`80:b/[0P0X:2P402<S8`807AdM0P0O7al202TY:@80Bd];00<0SXj>09bLW02LW9`00P27QhL206][
J`80HV9R0P2=SHd20;fm_@80clo?0P2WYjL20:ZZZP80Z:RX102][Jd20;Fe]@80[Zj^0P2h^;P20;Ng
]`80aLG50P3=cLd20<W9b@80alO70P36a/H40<;2`P80alO700<0_[jn0;Zj^P2j^[X00P2e]KD206a/
K080?Shn0P19BDT204e=C@80C4a<0P15ADD203lo?`80=SHf0P0`<30402l_;`80:BTY0P0c<c<203Ph
>080>SXj0P0c<c<202l_;`80=CDe0P0g=cL2038b<P80:b/[1@0X:2P204M7A`80?clo0P0k>c/205MG
E`80MWIf0P2OWil20;no_`80^[Zj0P2VYZH209BDU080LW9b0P1WIfL203hn?P80<c<c0P0W9bL202d]
;@80;Rh^0P0/;2`2030`<080@T920P1ADE4206UYJ@80OWin0P27QhL208:2PPD0Ng]k0P22PX8208>3
P`80RHV90P2:RXX208R8R080T92@0P2?Shl209BDU080UYJF0P2GUiLN0<SPf0007038h=P202TY:@80
>SXj0P1<C4`205YJFP80;2`/0P1PH60208Z:RP80@D510P0[:b/202TY:@80<c<c0P0_;bl00`0Z:RX0
:2PX02PX:00402PX:080:BTY0P0V9RH202PX:080BDU90P1[Jf/407IfMP80LG5a0P1UIFD204m?C`80
>3Ph0P0[:b/202@T90809bLW0P0[:b/202PX:0@092@T0P0W9bL2024Q8@809RHV0P0Z:RX00`1cLg<0
T92@092@T0020:>SX`80NWYj0P1HF5P207alO080YjNW0P3Cdm<20;Fe]@80[jn_0P2UYJD20:RXZ080
[Jf]0P2`/;020;Bd]080]kNg0P2j^[X20<?3``80b/[:0P3;bl/20<W9b@80a/K60P33`l<20;jn_P80
^k^k00<0aLG50<c<c03<c<`0102f][H204a<C080BDU90P13@d<204Y:BP80ATI60P11@D4203Xj>P80
=CDe0P0b<S82034a<@@0<30`0P0_;bl202h^;P80<C4a100c<c<2034a<@80<30`0P0^;Rh402d];@<0
;bl_0P0c<c<203/k>`80Bd];0P1QHF4208J6QP80Xj>S0P2NWYh208Z:RP80K6a/0P1<C4`203De=@80
:BTY0P0X:2P202/[:`80:2PX0P0U9BD202@T9080:BTY0P12@T82061PH080MWIf0P25QHD208R8R080
QXJ600<0PX:207moO`1oOgl00P20P80208:2PP80QXJ60P2:RXX208^;R`80S8b<0P2?Shl209>CT`80
UYJF0P2GUiL209RHV2L0b>3H0P0_;bl203Xj>P80DU9B0P1FEUH203De=@80G5aL0P27QhL204M7A`80
9BDU0P0];Bd203@d=080<S8b0P0/;2`202DU9@80:b/[00<0:BTY02/[:`0[:b/00P0Z:RX2030`<080
?Shn0P1^KVh207YjNP80L71`0P1]KFd206IVIP80DU9B0P0k>c/202/[:`@09bLW0P0];Bd202TY:@@0
8R8R0P0V9RH4024Q8@80<c<c0P1ZJVX209>CT`80YZJV0P1aLG4205mOG`80OWin0P2/[:`20<W9b@80
_Kfm00<0YjNW0:VYZ@2YZJT00P2ZZZX20:^[Z`80[jn_0P2c/k<40;Vi^@80a<C40P39bLT20<g=c@80
b/[:0P32`/820<C4a0@0_[jn0P33`l<20<71`@80aLG50P2VYZH205UIF@80@d=30P1;Bd/204U9B@80
?Shn0P0k>c/20492@P80<c<c100`<30203@d=080;bl_0`0`<30202l_;`80=cLg0P0_;bl203<c<`80
<30`0P0^;Rh202`/;080;Rh^0P0_;bl202`/;080<S8b0P0h>3P204I6AP80FUYJ0P2:RXX20::RXP80
UYJF0P2>SXh206QXJ080CTi>0P0h>3P202XZ:P@0:BTY0P0[:b/202HV9P80:RXZ0P0^;Rh204=3@`80
I6AT00<0MGEe08B4Q024Q8@00P28R8P208B4Q080PH610P1nOWh20820P080PX:20P28R8P208Z:RP80
Rh^;0P2:RXX208n?S`80TY:B0P2FUYH209BDU080VIVI9`38h=P202@T9080?clo0P18B4P205aLG080
:RXZ0P1LG5`208Z:RP80@T920P0];Bd202LW9`80<c<c0P0a<C400`0X:2P0:BTY02TY:@0402LW9`80
9RHV0P0U9BD202LW9`80C4a<0P1[Jf/207AdM0@0MGEe0P1TI6@204i>CP80>CTi0P0Y:BT202DU9@80
9RHV0P0Z:RX202PX:08092@T0P0S8b<202PX:080820P0P0T92@202/[:`0307=cL`2=SHd0SHf=0080
Xj>S0P21PH4205IFEP80N7Qh0P2XZ:P20=?Cd`80];Bd0P2`/;020:JVYP80YJFU0P2[Zj/20;Fe]@80
/[:b102h^;P20<K6aP80c<c<0P3;bl/40<W9b@80a<C40P2k^k/20;bl_0030<K6aP3<c<`0c<c<0080
/k>c0P2g]kL204e=C@80Bd];0P10@40204Y:BP80ATI60P11@D4203Hf=P80=3@d0P0g=cL203<c<`80
:b/[0P0a<C42038b<P@0;Rh^0P0c<c<203De=@80;Bd]0P0`<30202h^;P@0;Bd]00<0<c<c02l_;`0_
;bl00P0`<30203lo?`80Bd];0P1RHV8208B4Q080XJ6Q0P2OWil208N7Q`80Kfm_0P1=CDd203Ph>080
:RXZ0P0V9RH202XZ:P809RHV0P0T92@202HV9P80:2PX0P15ADD205iNGP80MGEe0P28R8P208V9R@80
QHF500<0Q8B407moO`1oOgl00P22PX8408F5Q@80RXZ:0P29RHT208^;R`80T92@0P2CTi<209RHV080
VIVI0P2FUYHN0<SPf0007038h=P202XZ:P80C4a<0P15ADD204U9B@80;bl_0P1KFe/20820P080>SXj
0P0Z:RX202HV9P80;bl_0P0[:b/00`0W9bL09BDU02DU9@0202DU9@8092@T0P0Z:RX202DU9@80CDe=
0P1UIFD207UiN@80NWYj0P1`L70205iNGP80BDU90P0i>CT202`/;0809RHV0P0T92@202XZ:P80;bl_
0P0[:b/202DU9@809bLW0P0X:2P4028R8P807alO00<0BDU907UiN@1iNGT00P2SXj<209BDU080HV9R
0P1bLW8208b<S080_[jn0P31`L420;Bd]080YJFU0P2YZJT20:b/[080[jn_0P2b/[820;Fe]@80^;Rh
0P30`<020<O7a`@0b/[:0P36a/H20<71`@80_Kfm0P2k^k/00`32`/80a<C40<C4a0020;fm_@80/[:b
0P2^[Zh206IVIP80@4100P16ATH20492@P80@d=30P0n?Sh203Ph>080=CDe0P0c<c<4034a<@@0<30`
0P0b<S8403<c<`80<S8b0P0a<C4202l_;`80;Rh^0P0];Bd00`0_;bl0;2`/02`/;00202l_;`80=CDe
0P0n?Sh204Y:BP80I6AT0P1iNGT2075aL@80GemO0P1;Bd/203Ph>080:b/[100W9bL202TY:@809RHV
0P0S8b<202d];@80?Cdm0P1HF5P207=cL`80P8201027QhL208B4Q0030861P@1oOgl0Ogmo0080P820
0P22PX8208N7Q`80Rh^;0P2<S8`208f=S@80T92@0P2CTi<209JFUP80VIVI0P2JVYXW0<SPf080:RXZ
0P0o?cl205EEE@80?Cdm0P0];Bd205iNGP80PX:20P0h>3P402`/;080:RXZ0P0X:2P202HV9P@092@T
00<0:BTY02DU9@0U9BD00P0Z:RX20451@@80JFUY101iNGT2079bLP80IfMW0P18B4P202PX:08092@T
0P0Y:BT202HV9P809bLW0P0];Bd202l_;`809BDU0P0Y:BT202LW9`808R8R0P0Q8B4202<S8`80ADE5
0P20P8020:6QX@80UIFE101TI6@2092@T080^KVi0P36a/H00`2_[jl0YjNW0:NWY`020:BTY080[:b/
0P2a/K420;2`/0@0^;Rh0P32`/820<G5a@80cLg=0P3:b/X20<?3``80`/;20P30`<020;fm_@@0_kno
0P2m_Kd20<G5a@80YjNW0P1NGUh204Y:BP@0@D511013@d<203Ti>@80=CDe0P0b<S8202l_;`80<30`
0`0e=CD203<c<`80=CDe0P0g=cL203<c<`80=CDe0P0];Bd202`/;080:RXZ0P0_;bl202h^;P80;bl_
0P0`<30204m?C`80@T920P1RHV8207MgM`80Kfm_0P1LG5`204I6AP80>CTi0P0^;Rh202XZ:P809bLW
0P0^;Rh202TY:@809RHV0P0^;Rh203`l?080EUIF0P1cLg<00`21PH40Rh^;08^;R`0408N7Q`80Ph>3
0P1mOGd408:2PP80QHF5102=SHd2092@T080UiNG0P2CTi<209BDU080VIVI0P2MWIdW0<SPf0809bLW
0P1=CDd204A4A080CTi>0P0_;bl205eMG@80PH610P0h>3P202LW9`80:BTY0P0^;Rh202`/;00302PX
:00T92@092@T00809RHV0P0W9bL202d];@809bLW0P1=CDd206IVIP80NWYj0P1kNg/2071`L080GemO
0P17AdL203Lg=`80;Rh^0P0T92@202LW9`80;Bd]0P0a<C4202HV9P8092@T0P0W9bL202PX:0808b<S
0P0T92@2028R8P0304Q8B01gMgL0MgMg0080WYjN0P2HV9P206EUI@80LW9b0P2<S8`20<30`080`L71
0P2d];@20:BTY080YZJV0P2][Jd20;>c/`80[Zj^0P2h^;P20;Jf]P80`/;20P33`l<20<G5a@80bl_;
0P35aLD20<C4a0@0^k^k0`32`/820;no_`80/[:b0P2][Jd206QXJ0@0ATI60P14A4@204E5A@80?clo
0P0g=cL203De=@@0<C4a0P0^;Rh203De=@80<30`0P0a<C42038b<P80=SHf0P0`<30203De=@80;Rh^
0P0_;bl202d];@03034a<@0[:b/0:b/[0080<30`0P0d=3@203`l?080BTY:0P1UIFD207UiN@80M7Ad
0P1QHF4204U9B@80=SHf0P0Z:RX202HV9P809BDU0P0/;2`202LW9`8092@T0P0_;bl203Xj>P80EeMG
0P1gMgL207inOP80QhN70P26QXH208:2PP0308>3P`1oOgl0Ogmo0080OGem0P1oOgl208J6QP80Shn?
102@T902096AT@80Ti>C0P2DU9@209RHV080UiNG7P38h=P001`0b>3H0P0Z:RX204a<C080ADE50P19
BDT202l_;`80Fe]K0P20P80203Xj>P80:RXZ0P0V9RH202l_;`80:b/[00<09bLW02DU9@0U9BD00P0U
9BD202@T9080:RXZ0P0U9BD204e=C@80IFEU0P1iNGT207YjNP80L71`0P1NGUh204U9B@80>CTi0P0/
;2`202HV9P8092@T0P0Z:RX202l_;`80:b/[0P0U9BD202LW9`80:2PX100R8R8201lO7`0304U9B@1i
NGT0NGUi0080Xj>S0P2DU9@2069RHP80LW9b0P2<S8`20;jn_P80`L710P2d];@20:FUY@80ZJVY0P2/
[:`20:n_[`80/[:b0P2e]KD20;Rh^080`<300P37alL40<[:bP80a/K60P31`L420;fm_@80^k^k00<0
`/;20<C4a034a<@00P2m_Kd20;:b/P80[Zj^0P1VIVH20410@080ATI60P12@T8204=3@`80?Shn0P0h
>3P203De=@80<c<c100a<C44030`<080<S8b100c<c<2038b<P80<C4a0P0_;bl202h^;P80;Bd]00<0
;bl_02`/;00/;2`00P0_;bl203De=@80?Shn0P1:BTX206ATI080NGUi0P1aLG4205mOG`80Bd];0P0h
>3P202/[:`@09bLW0P0Y:BT202HV9P808b<S0P0];Bd203dm?@80F5QH0P1cLg<20820P0@0QhN70P24
Q8@00`21PH40Ogmo07moO`020820P080PX:20P27QhL208^;R`80S8b<0P2=SHd2092@T080Ti>C0P2F
UYH209VIV@80VYZJ9`38h=P202XZ:P80?clo0P1EEED203dm?@80;Bd]0P1NGUh208:2PP80>3Ph100/
;2`202XZ:P80:2PX0P0V9RH402@T900302TY:@0U9BD09BDU0080:RXZ0P11@D4206UYJ@@0NGUi0P1b
LW8206MWI`80B4Q80P0X:2P202@T9080:BTY0P0V9RH202LW9`80;Bd]0P0_;bl202DU9@80:BTY0P0W
9bL2028R8P808B4Q0P0S8b<204E5A@80P8200P2QXJ4209FEU@@0I6AT0P2@T9020;Vi^@80a/K600<0
[jn_0:NWY`2WYjL00P2TY:@20:b/[080/K6a0P2`/;040;Rh^080`/;20P35aLD20<g=c@80b/[:0P33
`l<20<;2`P80`<300P2m_Kd40;no_`80_Kfm0P35aLD20:NWY`80GUiN0P1:BTX40451@@@0@d=30P0i
>CT203De=@80<S8b0P0_;bl2030`<0<0=CDe0P0c<c<203De=@80=cLg0P0c<c<203De=@80;Bd]0P0/
;2`202XZ:P80;bl_0P0^;Rh202l_;`80<30`0P1?Cdl20492@P80HV9R0P1gMgL206m_K`80G5aL0P16
ATH203Ti>@80;Rh^0P0Z:RX202LW9`80;Rh^0P0Y:BT202HV9P80;Rh^0P0l?3`205IFEP80Lg=c00<0
PH6108^;R`2;Rh/01027QhL208>3P`80OGem1022PX8208F5Q@@0SHf=0P2@T90209NGU`80Ti>C0P2D
U9@209VIV@80WIfM9`38h=P202LW9`80CDe=0P14A4@204i>CP80;bl_0P1MGEd20861P@80>3Ph0P0W
9bL202TY:@80;Rh^0P0/;2`00`0X:2P092@T02@T900202HV9P809bLW0P0];Bd202LW9`80CDe=0P1V
IVH207YjNP80Ng]k0P1`L70205mOG`80AdM70P0g=cL202h^;P8092@T0P0W9bL202d];@80<C4a0P0V
9RH202@T90809bLW0P0X:2P202<S8`8092@T0P0R8R800`18B4P0MgMg07MgM`0209jNWP80V9RH0P1U
IFD2079bLP80S8b<0P30`<020<71`@80];Bd0P2TY:@20:JVYP80[Jf]0P2c/k<20:j^[P80^;Rh0P2f
][H20<;2`P80`l?30P35aLD20<_;b`80aLG50P34a<@40;^k^`<0`/;20P2o_kl20;:b/P80[Jf]0P1X
J6P404I6AP80A4A40P15ADD203lo?`80=cLg0P0e=CD4034a<@80;Rh^0P0e=CD2030`<080<C4a0P0b
<S8203Hf=P80<30`0P0e=CD202h^;P80;bl_0P0];Bd00`0a<C40:b/[02/[:`02030`<080=3@d0P0l
?3`204Y:BP80IFEU0P1iNGT207AdM080HF5Q0P19BDT203Hf=P80:RXZ0P0V9RH202DU9@80;2`/0P0W
9bL202@T9080;bl_0P0j>SX205MGE`80MgMg0P1nOWh208N7Q`80QXJ60P22PX800`23Ph<0Ogmo07mo
O`0207emO@80Ogmo0P26QXH208n?S`@0T92@0P2ATI4209>CT`80U9BD0P2HV9P209NGUah0b>3H000L
0<SPf080<30`0P1HF5P203Ph>0@0<S8b0P1DE5@207AdM080=CDe0P0Y:BT202<S8`80:BTY0P0V9RH0
0`0U9BD08b<S02<S8`0402<S8`@0;Rh^0P1bLW8207YjNP80Ng]k0P1_Kfl205eMG@80@D510P0W9bL2
024Q8@808R8R0P0U9BD202XZ:P80;bl_0P0b<S8202h^;P@0:2PX0P0Y:BT202@T90808B4Q0P0M7Ad0
0`0S8b<0GUiN05iNGP0209:BTP80Z:RX0P1eMGD2071`L080M7Ad0P2NWYh20<G5a@80^[Zj0P2YZJT2
0:^[Z`80[Jf]0P2_[jl20;6a/@80/k>c0P2f][H20;fm_@80a<C40P38b<P20<[:bP80a/K60P31`L42
0;jn_P80_Kfm00<0^[Zj0;Rh^02h^;P00P30`<020<71`@80b/[:0P2VYZH205MGE`80C4a<0P12@T82
04I6AP80@D510P0m?Cd203Ti>@80=SHf0P0e=CD203@d=080=CDe0P0f=SH203De=@H0=3@d0P0c<c<2
034a<@80;bl_0`0^;Rh402l_;`80<30`0P0b<S8203Lg=`80ADE50P1@D50204Q8B080>SXj0P0c<c<2
02d];@@0;2`/0P0Z:RX202TY:@809bLW0P0Y:BT203lo?`80FUYJ0P1aLG4208B4Q080R8R80P27QhL2
08F5Q@80PH6100<0Ogmo07inOP1nOWh00P1oOgl208:2PP80QhN70P2<S8`208j>SP80Shn?0P2ATI42
09>CT`80V9RH0P2KVi/209bLW2L0b>3H0P0g=cL205IFEP80>SXj0P0_;bl2038b<P80FEUI0P1cLg<2
02h^;P809RHV0P0Y:BT202LW9`8092@T0P0W9bL402DU9@03020P800`<300<30`0080=CDe0P1`L702
07UiN@80LG5a0P1bLW82061PH080@410100V9RH202@T90809bLW0P0[:b/202l_;`80<c<c0P0d=3@2
02XZ:P80820P0P0V9RH202XZ:P806a/K0P0O7al202HV9P80FUYJ0P2@T9020:f][@80MWIf0P1WIfL2
07]kN`80VYZJ0P31`L400`33`l<0YZJV0:JVYP020:JVYP80[:b/0P2`/;020:f][@80][Jf0P2d];@2
0;Vi^@80a<C40P38b<P20<_;b`80`l?30P31`L420<;2`P80^[Zj0P2l_;`20;jn_P80^KVi0P32`/82
0<K6aP80XZ:R0P1HF5P204I6AP80@4100P0o?cl204];B`80>c/k0P0f=SH203Lg=`80>CTi0P0e=CD0
0`0b<S80=CDe03De=@0403@d=080>SXj0P0c<c<202l_;`80<S8b0P0d=3@202h^;P80<30`0P0^;Rh2
02l_;`80;2`/0P0c<c<203Lg=`80?clo0P1DE5@204M7A`80=cLg0P0c<c<202h^;P80:2PX0P0^;Rh4
02LW9`80<30`0P0X:2P203Lg=`80F5QH0P1_Kfl208>3P`0308R8R029RHT0RHV90080PH610P20P802
08>3P`80Ng]k0P1nOWh208>3P`80PX:20P2<S8`208n?S`80Rh^;0P2BTY8409BDU080W9bL0P2MWIdW
0<SPf080<c<c0P1FEUH203Xj>P80<c<c0P0a<C42059BDP80Lg=c0P0e=CD202PX:0809BDU100V9RH0
0`0U9BD08B4Q024Q8@02028R8P809RHV0P0[:b/202h^;P80Lg=c0P1iNGT207QhN080LW9b0P1KFe/2
03lo?`80:BTY0P0P820202DU9@808b<S0P0[:b/202`/;080<S8b0P0^;Rh202LW9`@0:RXZ0P0U9BD2
020P80806QXJ00<092@T061PH01PH6000P2CTi<20:JVYP@0LG5a0P1bLW8209jNWP80a/K60P2l_;`2
0:VYZ@80ZZZZ0P2[Zj/20;6a/@80/;2`0P2b/[820;Jf]P80_[jn0P34a<@20<c<c080b/[:1033`l<2
0;jn_P80_Kfm00<0^KVi0;Ng]`2g]kL00P32`/820<30`080b<S80P2UYJD205MGE`80BTY:0P13@d<2
04A4A080@4100P0o?cl203Ti>@80=cLg100e=CD203@d=080>CTi0P0d=3@203De=@80=SHf0P0b<S82
03De=@@0<30`0P0^;Rh00`0];Bd0<S8b038b<P0202l_;`80<c<c0P0b<S8203De=@80ATI60P1?Cdl2
04M7A`80>CTi0P0a<C4202l_;`80;2`/0P0^;Rh402/[:`808R8R0P0[:b/203hn?P80Fe]K0P1`L704
08F5Q@80RXZ:0P26QXH208:2PP0307moO`1nOWh0OWin0080PH610P23Ph<208V9R@80RXZ:0P2<S8`2
08n?S`80RXZ:0P2EUID209RHV080WIfM0P2KVi/N0<SPf0007038h=P2030`<080F5QH0P0h>3P4038b
<P80E5AD0P1dM7@203De=@80:BTY0P0S8b<202TY:@809RHV00<09BDU02<S8`0S8b<0100S8b<402h^
;P80LW9b0P1jNWX207]kN`80Kfm_0P1MGEd20451@@809bLW0P0Q8B42028R8P809BDU0P0Z:RX202l_
;`80<S8b0P0^;Rh402PX:080:BTY0P0T92@2024Q8@807AdM00<08b<S05iNGP1NGUh00P2BTY820:RX
Z080MGEe0P1`L70207AdM080WYjN0P35aLD20;Zj^P80ZJVY0P2[Zj/20:f][@80[jn_0P2a/K420;>c
/`80][Jf0P2m_Kd20<C4a080b<S80P3:b/X20<K6aP80`L710P2n_[h20;fm_@030;Zj^P2h^;P0^;Rh
0080`<300P31`L420<[:bP80YZJV0P1GEeL204a<C080@T920P16ATH20451@@80?Cdm0P0i>CT203Hf
=P80=CDe0P0d=3@203De=@80=SHf0P0e=CD603@d=080<c<c0P0a<C4202l_;`<0;Rh^100_;bl2030`
<080<S8b0P0g=cL204E5A@80D51@0P18B4P203Xj>P80<c<c0P0];Bd402`/;080:RXZ0P0Y:BT202LW
9`80:BTY0P0o?cl205YJFP80LG5a0P24Q8@208R8R080QhN70P25QHD20861P@0307moO`1nOWh0OWin
0080Ogmo0P22PX8208N7Q`80S8b<0P2>SXh208n?S`80TI6A0P2CTi<209RHV080Vi^K0P2LW9`W0<SP
f080=cLg0P1FEUH203Xj>P80;bl_0P0b<S8205UIF@80Lg=c0P0^;Rh202HV9P80:BTY0P0W9bL202@T
90809bLW100U9BD00`0P8200<30`030`<00203De=@80L71`0P1iNGT2075aL@80LW9b0P1PH6020410
@0@09RHV0P0T92@202LW9`80:b/[0P0_;bl203<c<`80=3@d0P0Z:RX2020P80809RHV0P0Z:RX201/K
6`807alO0P0V9RH205YJFP80T92@0P2][Jd207IfMP80IfMW0P1kNg/209ZJVP80`L7100<0`l?30:JV
YP2VYZH00P2VYZH20:b/[080/;2`0P2][Jd20;Jf]P80];Bd0P2i^KT20<C4a080b<S80P3;bl/20<?3
``80`L710P32`/820;Zj^P80_;bl0P2n_[h20;Vi^@80`/;20P36a/H20::RXP80F5QH0P16ATH20410
@080?clo0P1;Bd/203/k>`80=SHf0P0g=cL203Ti>@80=CDe00<0<S8b03De=@0e=CD0100d=3@203Xj
>P80<c<c0P0_;bl2038b<P80=3@d0P0^;Rh2030`<080;Rh^0P0_;bl202`/;080<c<c0P0g=cL203lo
?`80E5AD0P17AdL203Lg=`80<c<c0P0^;Rh202PX:080;Rh^100W9bL2030`<080:2PX0P0g=cL205QH
F080Kfm_0P23Ph<00`28R8P0RHV908V9R@020861P@80P8200P23Ph<207]kN`80OWin0P23Ph<208:2
PP80S8b<0P2?Shl208^;R`80TY:B102DU9@209bLW080WIfM9`38h=P203<c<`80EUIF0P0j>SX203<c
<`80<C4a0P1BDU8207=cL`80=CDe0P0X:2P202DU9@@09RHV00<09BDU024Q8@0Q8B400P0R8R8202HV
9P80:b/[0P0^;Rh207=cL`80NGUi0P1hN7P2079bLP80Fe]K0P0o?cl202TY:@80820P0P0U9BD202<S
8`80:b/[0P0/;2`2038b<P80;Rh^0P0W9bL402XZ:P809BDU0P0P820201XJ6P0302@T901PH600H61P
0080Ti>C0P2VYZH4075aL@80LW9b0P2NWYh20<K6aP80_;bl0P2YZJT20:ZZZP80Zj^[0P2a/K420;2`
/080/[:b0P2f][H20;jn_P80a<C40P3<c<`20<[:bP@0`l?30P2n_[h20;fm_@030;Vi^@2g]kL0]kNg
0080`/;20P30`<020<S8b080YJFU0P1GEeL204Y:BP80@d=30P14A4@20410@080?clo0P0i>CT203Lg
=`@0=CDe0P0d=3@203Ti>@80=3@d0P0e=CD203Hf=P80<S8b0P0e=CD4030`<080;Rh^00<0;Bd]038b
<P0b<S800P0_;bl203<c<`80<S8b0P0e=CD204I6AP80Cdm?0P17AdL203Ti>@80<C4a0P0_;bl202`/
;080;Rh^100[:b/2028R8P80:b/[0P0n?Sh205]KF`80L71`1025QHD208Z:RP80QXJ60P22PX800`1o
Ogl0OWin07inOP020861P@80Ph>30P29RHT208Z:RP80S8b<0P2?Shl208Z:RP80UIFE0P2HV9P209fM
W@80Vi^K7P38h=P001`0b>3H0P1;Bd/20410@080<c<c0P0[:b/202l_;`80GUiN0P1XJ6P202l_;`80
:2PX0P0R8R8702HV9P809bLW0P0/;2`203Lg=`80FUYJ0P1iNGT207=cL`80HV9R0P1@D50203hn?P80
<C4a0P0W9bL202DU9@809RHV0P0Z:RX202d];@80<30`0P0a<C4202`/;0809RHV100W9bL202DU9@80
7QhN0P0L71`00`0N7Qh0ATI604I6AP0206e]K@80YZJV0P2>SXh207]kN`80KVi^0P1jNWX20:b/[080
aLG50P2h^;P20:6QX@80[Zj^0P2][Jd20;2`/080/[:b0P2e]KD20;bl_080`l?30P38b<P20<_;b`80
b<S80P34a<@20;no_`80^k^k00<0^KVi0;Rh^02h^;P00P2l_;`20;^k^`80dM7A0P2l_;`208N7Q`80
CTi>1012@T8204M7A`80BDU90P16ATH20451@@80?Shn0P0j>SX203De=@80<S8b0P0e=CD203Ti>@80
=cLg0P0d=3@203<c<`80<S8b0P0`<30502l_;`80<C4a0P0b<S82034a<@80<30`0P0d=3@203Lg=`80
=CDe0P0a<C4202`/;080:2PX100W9bL202XZ:P80;Rh^0P0/;2`203Xj>P80Fe]K0P1hN7P208:2PP80
RHV90P26QXH408:2PP80Ph>300<0Ogmo07emO@1mOGd00P20P80208F5Q@80RHV90P2<S8`208j>SP80
T92@0P2DU9@209RHV080VYZJ0P2LW9`209fMWBL0b>3H0P1:BTX204M7A`80;Bd]0P0`<302034a<@80
Hf=S0P1WIfL202h^;P80:b/[0P0V9RH202/[:`8092@T0P0X:2P202HV9P809bLW00<0:b/[030`<00`
<3000P1LG5`207]kN`80O7al0P1^KVh204m?C`80<S8b0P0];Bd202XZ:P80;Rh^0P0X:2P202/[:`80
:BTY0P0_;bl202h^;P80;2`/0P0U9BD202@T9080;2`/0P0c<c<201dM7@@07alO0P0i>CT207QhN080
X:2P0P2HV9P20820P080KFe]0P1mOGd20:ZZZP030<_;b`2d];@0];Bd0080YjNW0P2][Jd20;>c/`80
[jn_0P2a/K420;Ng]`80^k^k0P34a<@20<S8b080bl_;0P35aLD20<;2`P80_[jn0P2i^KT20;Ng]`80
^[Zj0P2d];@20;^k^`80a/K60P38b<P209fMW@80D51@0P11@D4204M7A`80ATI60P17AdL204A4A080
@d=30P0o?cl203Xj>P0303De=@0c<c<0<c<c0080=SHf0P0d=3@203<c<`@0=3@d0P0a<C42038b<P80
;bl_0P0a<C42030`<080;Rh^0P0b<S8203/k>`80<30`0P0h>3P203Ti>@80=SHf0P11@D4202`/;080
;Rh^0P0X:2P202HV9P80;2`/0P0Y:BT202XZ:P80>3Ph0P1NGUh208>3P`80RXZ:0P2=SHd308:2PP80
Ogmo0P24Q8@207emO@80OWin0P23Ph<208:2PP80Shn?0P2<S8`208j>SP80T92@0P2ATI4209NGU`80
VIVI0P2LW9`209jNWRL0b>3H0P1;Bd/203hn?P80<30`0P0Z:RX2030`<080GUiN0P1XJ6P203<c<`@0
9RHV1@0W9bL202<S8`809RHV0P0a<C4203De=@80EUIF0P1iNGT207EeM@80HF5Q0P1ADE4203dm?@80
<S8b0P0Z:RX202@T90809RHV0P0Z:RX202`/;080<C4a0P0b<S8202`/;0809bLW0P0[:b/2028R8P80
8b<S0P0Q8B4201TI6@0301dM7@1<C4`0C4a<0080K6a/0P2WYjL209>CT`80O7al0P1]KFd207emO@80
Z:RX0P34a<@20;Vi^@80XJ6Q0P2^[Zh40;6a/@80/;2`0P2g]kL20;bl_080`l?30P38b<P20<g=c@80
alO70P34a<@40;jn_P030;Vi^@2g]kL0]kNg0080_kno0P2k^k/20=3@d080^k^k0P2;Rh/204a<C080
?clo0P14A4@404U9B@80@d=30P12@T820410@080>c/k0P0a<C42030`<080=CDe0P0h>3P203Lg=`80
<S8b0P0c<c<2030`<080;Rh^0P0`<3000`0];Bd0;2`/02`/;00402l_;`80;2`/0P0e=CD203<c<`80
=cLg0P0f=SH203@d=080;2`/0P0[:b/202LW9`809BDU0P0X:2P202d];@80;2`/0P0j>SX205aLG080
NWYj0P21PH4208Z:RP80Ph>30P22PX8208>3P`80PX:200<0OWin07YjNP1jNWX01021PH4208V9R@80
Rh^;0P2?Shl209:BTP80U9BD0P2JVYX209nOW`80VYZJ0P2LW9`N0<SPf0007038h=P204];B`80@410
0P0c<c<202/[:`80;bl_0P1NGUh206QXJ080;bl_0P0X:2P2028R8PL09RHV0P0W9bL202`/;080=cLg
0P1JFUX207UiN@80Lg=c0P1RHV82051@D080?Shn0P0a<C4202LW9`809BDU0P0V9RH202XZ:P80;Bd]
0P0`<302034a<@80;2`/0P0V9RH402LW9`809BDU0P0N7Qh201`L700301hN7P16ATH0ATI60080KFe]
0P2VYZH208j>SP80Ng]k0P1^KVh207YjNP80[:b/0P35aLD20;Rh^080XJ6Q0P2^[Zh20:f][@80/;2`
0P2b/[820;Fe]@80_;bl0P33`l<20<S8b080bl_;0P38b<P20<C4a080_kno0P2k^k/00`2i^KT0^;Rh
0;Rh^0020;bl_080^k^k0P3AdM420;bl_080QhN70P1>CTh40492@P80AdM70P19BDT204I6AP80@D51
0P0n?Sh203Xj>P80=CDe0P0b<S8203De=@80>CTi0P0g=cL203@d=080<c<c0P0b<S82030`<0D0;bl_
0P0a<C42038b<P80<C4a0P0`<30203@d=080=cLg0P0e=CD2034a<@80;2`/0P0X:2P402LW9`80:RXZ
0P0^;Rh202`/;080>SXj0P1KFe/207QhN080PX:20P29RHT208J6QP@0PX:20P23Ph<00`1oOgl0OGem
07emO@020820P080QHF50P29RHT208b<S080SXj>0P2@T90209BDU080V9RH0P2JVYX209bLW080WIfM
9`38h=P204Y:BP80AdM70P0];Bd2030`<080<C4a0P1SHf<206MWI`80;Rh^0P0[:b/202HV9P80:b/[
0P0T92@202PX:0809RHV0P0W9bL00`0[:b/0<30`030`<00205aLG080Ng]k0P1lO7`206i^KP80Cdm?
0P0b<S8202d];@80:RXZ0P0^;Rh202PX:080:b/[0P0Y:BT202l_;`80;Rh^0P0/;2`202DU9@8092@T
0P0/;2`203<c<`807AdM100O7al203Ti>@80N7Qh0P2PX:0209RHV080P8200P1]KFd207emO@80ZZZZ
00<0bl_;0;Bd]02d];@00P2WYjL20:f][@80/k>c0P2_[jl20;6a/@80]kNg0P2k^k/20<C4a080b<S8
0P3;bl/20<G5a@80`/;20P2n_[h20;Vi^@80]kNg0P2j^[X20;Bd]080^k^k0P36a/H20<S8b080WIfM
0P1@D5020451@@80AdM70P16ATH204M7A`80A4A40P13@d<203lo?`80>SXj00<0=CDe03<c<`0c<c<0
0P0f=SH203@d=080<c<c100d=3@2034a<@80<S8b0P0_;bl2034a<@80<30`0P0^;Rh2038b<P80>c/k
0P0`<30203Ph>080>CTi0P0f=SH20451@@80;2`/0P0^;Rh202PX:0809RHV0P0/;2`202TY:@80:RXZ
0P0h>3P205iNGP80Ph>30P2:RXX208f=S@<0PX:20P1oOgl208B4Q080OGem0P1nOWh208>3P`80PX:2
0P2?Shl208b<S080SXj>0P2@T902096AT@80UiNG0P2IVIT209bLW080WYjN9`38h=P204];B`80?Shn
0P0`<30202XZ:P80<30`0P1NGUh206QXJ080<c<c100V9RH502LW9`808b<S0P0V9RH2034a<@80=CDe
0P1FEUH207UiN@80MGEe0P1QHF42055AD@80?Cdm0P0b<S8202XZ:P8092@T0P0V9RH202XZ:P80;2`/
0P0a<C42038b<P80;2`/0P0W9bL202/[:`808R8R0P0S8b<2024Q8@806ATI00<07AdM04a<C01<C4`0
0P1/K6`20:NWY`80Ti>C0P1lO7`206e]K@80OGem0P2XZ:P20<C4a080^KVi0P2QXJ420:j^[P@0/K6a
0P2`/;020;Ng]`80_;bl0P33`l<20<S8b080cLg=0P37alL20<C4a0@0_[jn00<0^KVi0;Ng]`2g]kL0
0P2o_kl20;^k^`80d=3@0P2k^k/208^;R`80C4a<0P0o?cl204A4A0@0BDU90P13@d<20492@P80@410
0P0k>c/2034a<@80<30`0P0e=CD203Ph>080=cLg0P0b<S8203<c<`80<30`0P0^;Rh2030`<00302d]
;@0/;2`0;2`/00@0;bl_0P0/;2`203De=@80<c<c0P0g=cL203Hf=P80=3@d0P0/;2`202/[:`809bLW
0P0U9BD202PX:080;Bd]0P0/;2`203Xj>P80G5aL0P1jNWX20861P@80RXZ:0P23Ph<208:2PP80Ph>3
0P22PX800`1nOWh0NWYj07YjNP040861P@80RHV90P2;Rh/208n?S`80TY:B0P2DU9@209ZJVP80WinO
0P2JVYX209bLW1h0b>3H000L0<SPf080GemO0P0V9RH202l_;`80:BTY0P0];Bd206QXJ080GemO0P0[
:b/202TY:@808R8R0P0U9BD202HV9P0302PX:00Z:RX0:RXZ0080;Rh^0P0i>CT204A4A080PX:20P1c
Lg<2065QH@80@d=30P0`<30202<S8`809RHV1P0^;Rh202l_;`@0<30`0P0^;Rh202TY:@809BDU0P0V
9RH202LW9`809RHV0P0R8R8201lO7`03028R8P0`<300<30`0080ADE50P2EUID209nOW`80RXZ:0P1b
LW8205eMG@80SHf=0P37alL20<?3``80W9bL0P2`/;020:b/[080[Zj^0P2`/;020;Bd]080^k^k0P33
`l<20<O7a`@0b/[:0P38b<P20<71`@80^[Zj0`2i^KT20;Fe]@80/k>c0P2o_kl20<C4a080d];B0P2C
Ti<206a/K080BDU90P1<C4`205ADE080DU9B0P1>CTh204U9B@80@d=30P0j>SX203<c<`80>CTi0P10
@40203`l?080=SHf100e=CD203@d=080<c<c0`0b<S8203<c<`80=3@d0P0c<c<2038b<P80;bl_0P0]
;Bd202l_;`80<C4a0P0^;Rh202XZ:P809RHV0P0U9BD202h^;P80?3`l0P0e=CD2055AD@80LG5a0P2<
S8`208f=S@80R8R80P21PH4207]kN`80Ogmo0P23Ph<00`1oOgl0Ng]k07]kN`020820P080QhN70P2:
RXX208b<S080Shn?0P2BTY8209NGU`80W9bL1P2MWIdW0<SPf080F5QH0P0_;bl202`/;080:RXZ0P0_
;bl205eMG@80IFEU0P0_;bl202PX:0809RHV0P0R8R8202<S8`809RHV0P0a<C42030`<00303Xj>P19
BDT0BDU90080OGem0P1hN7P206EUI@80@D510P0_;bl202PX:0809BDU100[:b/202`/;080>CTi100_
;bl2030`<080:2PX0P0V9RH402@T90809bLW0P0O7al202DU9@808b<S0P0X:2P204m?C`80TI6A0P2P
X:0208R8R080KVi^0P1VIVH208f=S@030;bl_030`<00`<300080YZJV0P2/[:`20:ZZZP80[Jf]0P2`
/;020;>c/`80^k^k0P33`l<20<K6aP80bl_;0P37alL20<W9b@80`/;20P2k^k/20;Vi^@80^k^k102f
][H20;no_`80aLG50P39bLT209nOW`80FUYJ0P18B4P204i>CP80EUIF0P1=CDd2051@D080B4Q80P17
AdL00`0l?3`0=3@d03@d=00203/k>`80@4100P0h>3P203Hf=P80>CTi0P0e=CD2038b<P80>3Ph0P0a
<C42038b<P80=CDe0P0c<c<403De=@80<S8b0P0a<C4202d];@80:b/[0P0];Bd202/[:`80:BTY0P0X
:2P202`/;080=CDe0P14A4@204];B`80JVYZ0P2:RXX208b<S080R8R80`20P80207YjNP80QHF50P23
Ph<207emO@80NWYj1P29RHT409:BTP80UiNG0P2KVi/209jNWP80W9bL0P2OWilW0<SPf080GUiN0P0X
:2P202l_;`809bLW0P0];Bd206YZJP80GEeM0P0/;2`202HV9P808B4Q100U9BD00`0X:2P0:b/[02/[
:`0202h^;P80>SXj0P15ADD207moO`80MGEe0P1PH60204A4A080<C4a0P0R8R8202HV9P80;Rh^0P0[
:b/2030`<080;Rh^0P0_;bl2030`<080;Rh^0P0W9bL2028R8P80:2PX100U9BD4020P8003024Q8@0d
=3@0=3@d0080ADE50P2EUID209nOW`80QhN70P1cLg<205mOG`80Rh^;0P38b<P20<?3``80WIfM0P2a
/K420:j^[P80[:b/0P2`/;020;>c/`80^k^k0P31`L420<[:bP80b<S80P3;bl/20<[:bP80_kno0P2m
_Kd00`2h^;P0^k^k0;^k^`020;Rh^080/k>c0P2l_;`20<?3``80emOG0P2BTY8206e]K@80AdM70P1=
CDd205MGE`80DE5A0P1@D50204M7A`80A4A40P0i>CT203@d=080>3Ph0P10@40203/k>`80=3@d0P0k
>c/203Hf=P@0<S8b00<0=3@d034a<@0a<C400P0e=CD203@d=0@0<S8b0P0a<C4202`/;080;Bd]0P0a
<C4202l_;`80:RXZ0P0W9bL202@T9080;Bd]100j>SX204m?C`80Kfm_0P2=SHd208^;R`80R8R80P20
P80407alO080Q8B400<0OWin07alO01lO7`00P23Ph<208N7Q`80Rh^;0P2<S8`208j>SP80Ti>C0P2H
V9P209VIV@80WYjN102LW9`N0<SPf0007038h=P205mOG`809RHV0P0_;bl202TY:@80;Bd]0P1XJ6P2
05mOG`80:b/[0P0Y:BT2028R8P809BDU0P0V9RH00`0X:2P0:RXZ02XZ:P0202h^;P80>CTi0P14A4@2
08:2PP80Lg=c0P1QHF4204=3@`80<30`0P0S8b<202HV9PH0;Rh^0P0_;bl4030`<080;Rh^0P0Y:BT2
02DU9@809RHV0P0W9bL202HV9P808R8R0P0O7al00`0R8R80<30`030`<00204E5A@80UIFE0P2OWil2
08Z:RP80LW9b0P1MGEd208f=S@80alO70P33`l<209bLW080/;2`0P2/[:`20:j^[P80/;2`0P2d];@2
0;^k^`80`l?30P37alL40<[:bP80b<S80P31`L420;Zj^P<0^KVi0P2e]KD20;>c/`80_kno0P34a<@2
0=;BdP80Ti>C0P1/K6`204U9B@80C4a<0P1DE5@2059BDP80CTi>0P19BDT204=3@`80>SXj0P0c<c<2
03Ti>@80@4100P0l?3`203Hf=P@0=CDe0P0d=3@203<c<`<0<S8b0P0c<c<203@d=080<c<c0P0b<S82
02l_;`80;Bd]0P0_;bl2034a<@80;Rh^0P0Z:RX202HV9P809BDU0P0^;Rh203`l?080=CDe0P1ADE42
075aL@80S8b<0P2=SHd208R8R080PH610P1kNg/207moO`80Ph>300<0Ogmo07]kN`1kNg/00P20P802
08N7Q`80RXZ:0P2<S8`208n?S`80TY:B0P2GUiL209bLW0H0WIfM9`38h=P205QHF080;bl_0P0/;2`2
02XZ:P80;bl_0P1MGEd206EUI@80;bl_0P0X:2P202HV9P808R8R0P0S8b<202HV9P80<C4a0P0`<300
0`0j>SX0BDU904U9B@0207emO@80N7Qh0P1UIFD20451@@80;bl_0P0X:2P202DU9@@0:b/[0P0/;2`2
03Ti>@@0;bl_0P0`<30202PX:0809RHV100T92@202LW9`807alO0P0U9BD202<S8`80:2PX0P1?Cdl2
096AT@80X:2P0P28R8P206i^KP80IVIV0P2=SHd00`2l_;`0`<300<30`0020:JVYP80[:b/0P2ZZZX2
0:f][@80/;2`0P2c/k<20;^k^`80`l?30P36a/H20<_;b`80alO70P39bLT20<;2`P80^k^k0P2i^KT2
0;^k^`@0][Jf0P2o_kl20<G5a@80bLW90P2OWil205YJFP80B4Q80P1>CTh205IFEP80CDe=0P1@D502
04Q8B080AdM700<0?3`l03@d=00d=3@00P0k>c/20410@080>3Ph0P0f=SH203Ti>@80=CDe0P0b<S82
03Ph>080<C4a0P0b<S8203De=@80<c<c100e=CD2038b<P80<C4a0P0];Bd202/[:`80;Bd]0P0[:b/2
02TY:@80:2PX0P0/;2`203De=@80A4A40P1;Bd/206YZJP80RXZ:0P2<S8`208R8R0<0P8200P1jNWX2
08F5Q@80Ph>30P1mOGd207YjNPH0RHV9102BTY8209NGU`80Vi^K0P2NWYh209bLW080WinO9`38h=P2
05iNGP80:2PX0P0_;bl202LW9`80;Bd]0P1ZJVX205eMG@80;2`/0P0V9RH2024Q8@@09BDU00<0:2PX
02/[:`0[:b/00P0^;Rh203Xj>P80ADE50P1oOgl207EeM@80H61P0P14A4@2034a<@808R8R0P0V9RH2
02h^;P80:b/[0P0`<30202h^;P80;bl_0P0`<30202h^;P809bLW0P0R8R8202PX:0@09BDU100P8200
0`0Q8B40=3@d03@d=00204E5A@80UIFE0P2OWil208N7Q`80Lg=c0P1OGel208^;R`80b<S80P33`l<2
09fMW@80/K6a0P2^[Zh20:b/[080/;2`0P2c/k<20;^k^`80`L710P3:b/X20<S8b080bl_;0P3:b/X2
0;no_`80_Kfm00<0^;Rh0;^k^`2k^k/00P2h^;P20;>c/`80_;bl0P33`l<20=OGe`80TY:B0P1]KFd2
04M7A`80CDe=0P1GEeL2055AD@80D51@0P17AdL204A4A080>CTi0P0d=3@203Ph>080@4100P0k>c/2
03@d=080>c/k0P0f=SH4038b<P0303@d=00a<C40<C4a0080=CDe0P0d=3@4038b<P80<C4a0P0/;2`2
02d];@80<C4a0P0_;bl202XZ:P809bLW0P0T92@202d];@@0>SXj0P1?Cdl206m_K`80SHf=0P2;Rh/2
08R8R080P820101lO7`208B4Q00307inOP1lO7`0O7al0080Ph>30P27QhL208^;R`80S8b<0P2>SXh2
09>CT`80V9RH0P2IVIT209jNWP@0W9bL7P38h=P001`0b>3H0P19BDT202LW9`80;Bd]0P0/;2`203@d
=080Fe]K0P1QHF4202`/;080;Rh^1P0U9BD00`0W9bL0;Bd]02d];@0203Hf=P80BDU90P1HF5P207Mg
M`80I6AT0P1<C4`202l_;`809bLW0P0V9RH202TY:@@0;Rh^200_;bl202h^;P80:b/[0P0X:2P202HV
9P80:2PX0P0P820203Ph>080;2`/00<08b<S024Q8@0Q8B400P0/;2`2071`L080TY:B0P2OWil20820
P080EUIF0P1fMWH20:RXZ080^[Zj0P2h^;P20:f][@80Zj^[0P2ZZZX20:b/[080/;2`0P2h^;P20<30
`080aLG50P38b<P40<_;b`80a<C40P2m_Kd00`2i^KT0]KFe0;Fe]@020;6a/@80[jn_0P2e]KD20;fm
_@80h^;R0P3@d=0209NGU`80FEUI0P17AdL204e=C@80DU9B0P1IFET205IFEP80DE5A0P1=CDd204];
B`80C4a<0P1=CDd204E5A@80?Cdm0P0l?3`203dm?@@0?clo00<0>c/k03De=@0e=CD00P0a<C4202l_
;`80=SHf0P0n?Sh20451@@80@4100P0f=SH202/[:`80<30`0P0c<c<202l_;`80<S8b0P0o?cl204Y:
BP80MgMg101PH60207YjNP80Shn?0P1oOgl207emO@80NGUi0P1kNg/207alO00307YjNP1hN7P0N7Qh
0080OGem0P23Ph<208N7Q`80Rh^;0P2ATI4209JFUP80VYZJ0P2MWId609jNWRL0b>3H0P10@40202LW
9`80:BTY0P0];Bd203Hf=P80FEUI0P1MGEd202/[:`809bLW100V9RH202@T9080:BTY0P0^;Rh2030`
<00304=3@`1LG5`0G5aL0080MWIf0P1PH60203Xj>P80:RXZ0P0Y:BT202`/;080;bl_0P0b<S8202d]
;@80:2PX0P0_;bl202d];@80;Rh^0P0c<c<202TY:@80<30`0P0V9RH202@T90808b<S0P0X:2P203dm
?@808B4Q0P0R8R8202LW9`80KVi^0P2?Shl209nOW`80MgMg0P1UIFD206m_K`030::RXP2o_kl0_kno
0080^KVi0P2XZ:P40:ZZZP80/;2`0P2^[Zh20;Jf]P80_kno0P34a<@20<_;b`80c<c<0P3;bl/20<O7
a`80_;bl0P2i^KT20;Fe]@80[:b/0P2a/K420;Ng]`80_kno0P36a/H20<g=c@80YZJV0P1NGUh204m?
C`80DE5A0P1?Cdl205iNGP80EeMG0P1=CDd00`15ADD0ATI604I6AP0205MGE`80E5AD1010@40204=3
@`80?Shn0P0i>CT203/k>`80>CTi0P0f=SH2038b<P80;2`/0P0b<S8203De=@80?3`l0P0g=cL203Ph
>080;bl_0P0[:b/202l_;`@0<30`0P0h>3P205=CD`80Ng]k0P1TI6@2065QH@80N7Qh0P28R8P20861
P@0307alO01iNGT0NGUi0080NWYj0P1kNg/207alO080MgMg0P1jNWX208B4Q080RHV90P2<S8`208n?
S`80UYJF0P2JVYX209nOW`80XJ6Q0P2JVYX209fMWBL0b>3H0P17AdL202XZ:P@0;Rh^0P0e=CD205QH
F080H61P0P0];Bd2030`<0809bLW0P0U9BD2028R8P0302XZ:P0^;Rh0;Rh^0080=SHf0P17AdL205QH
F080Ng]k0P1UIFD204Y:BP80;Rh^100V9RH202TY:@80;bl_0P0/;2`8030`<080;Bd]0P0Z:RX202TY
:@80:2PX0P0];Bd2028R8P80>3Ph0P0`<3000`0P82007QhN01hN7P0202/[:`80KFe]0P2EUID209bL
W080Ogmo0P1HF5P207UiN@80Z:RX0P2j^[X20;Fe]@80ZJVY0P2ZZZX40:b/[080[jn_0P2k^k/20;no
_`80`/;20P3;bl/20<[:bP80cLg=0P30`<020;fm_@030;Rh^02a/K40/K6a0080/;2`0P2^[Zh20;:b
/P80_Kfm0P3Rh^820<k>cP80UYJF0P1GEeL204];B`80BTY:0P1=CDd205aLG080E5AD0P1CDe<204i>
CP@0Cdm?0P1=CDd204M7A`80>c/k0P10@40203/k>`80?3`l0P11@D400`0m?Cd0=SHf03Hf=P0203<c
<`80<30`0P0h>3P203`l?080@d=30P10@40203Hf=P80:RXZ0P0`<302038b<P80:b/[0P0i>CT203lo
?`80BTY:0P1kNg/205mOG`80GUiN0P1kNg/2092@T080PX:20P1oOgl407]kN`80OWin00<0NWYj07Ui
N@1iNGT00P1nOWh208>3P`80QhN70P2;Rh/2096AT@80TY:B0P2KVi/209ZJVP80XZ:R0P2NWYh209ZJ
VQh0b>3H000L0<SPf080BDU90P0W9bL202d];@80;2`/0P0d=3@205]KF`80HF5Q0P0/;2`202h^;PH0
9BDU00<09bLW02d];@0];Bd00P0f=SH204U9B@80F5QH0P1gMgL206ATI080C4a<0P0_;bl202LW9`80
9RHV0P0Y:BT402h^;PP0;bl_0P0^;Rh202/[:`80:2PX0P0V9RH202PX:080820P0P0h>3P202`/;003
02<S8`0Q8B408B4Q0080;2`/0P1`L70209:BTP80WinO0P20P80205IFEP80MWIf0P2XZ:P20;Zj^P80
^;Rh0P2][Jd20:^[Z`80ZZZZ0P2/[:`20;2`/080^;Rh0P30`<020<G5a@80b<S8103;bl/20<C4a080
_Kfm00<0^KVi0;Fe]@2e]KD00P2a/K420:n_[`80]KFe0P2m_Kd20>;RhP80d=3@0P2GUiL205UIF@80
AdM70P1=CDd2059BDP80FEUI0P1FEUH2055AD@80CDe=0P1;Bd/204a<C080CDe=0P15ADD203dm?@80
?3`l0P0m?Cd403lo?`0303/k>`0e=CD0=CDe0080<C4a0P0_;bl203Hf=P80?Shn0P11@D420410@080
=SHf0P0[:b/2030`<080<c<c0P0_;bl2038b<P80?clo0P1:BTX207MgM`@0H61P0P1jNWX208n?S`80
Ogmo0P1mOGd207UiN@80Ng]k0P1lO7`00`1jNWX0N7Qh07QhN00207emO@80Ph>30P27QhL208^;R`80
TI6A0P2FUYH209ZJVP80WIfM1P2NWYhW0<SPf080@4100P0W9bL202TY:@80;Bd]0P0f=SH205UIF@80
GEeM0P0[:b/202LW9`@09RHV0P0T92@202TY:@80;Rh^0P0`<3000`13@d<0G5aL05aLG00207IfMP80
H61P0P0j>SX202XZ:P80:BTY0P0/;2`202l_;`80<S8b0P0];Bd202PX:080;bl_0P0];Bd202h^;P80
<c<c0P0Y:BT2030`<0809RHV0P0T92@202<S8`80:2PX0P0m?Cd2024Q8@808R8R0P0W9bL206i^KP80
Shn?0P2OWil207MgM`80IFEU0P1_Kfl00`2RXZ80_kno0;no_`020;Vi^@80Z:RX102ZZZX20;2`/080
[Zj^0P2f][H20;no_`80a<C40P3;bl/20<c<c080bl_;0P37alL20;bl_080^KVi0P2e]KD20:b/[080
/K6a0P2g]kL20;no_`80a/K60P3=cLd20:JVYP80GUiN0P1?Cdl2055AD@80Cdm?0P1NGUh205MGE`80
CDe=00<0ADE504I6AP16ATH00P1GEeL205ADE0@0@4100P13@d<203hn?P80>CTi0P0k>c/203Ti>@80
=SHf0P0b<S8202`/;080<S8b0P0e=CD203`l?080=cLg0P0h>3P202l_;`80:b/[0P0_;bl4030`<080
>3Ph0P1CDe<207]kN`80I6AT0P1QHF4207QhN080R8R80P21PH400`1lO7`0NGUi07UiN@0207YjNP80
Ng]k0P1lO7`207MgM`80NWYj0P24Q8@208V9R@80S8b<0P2?Shl209JFUP80VYZJ0P2OWil20:6QX@80
VYZJ0P2MWIdW0<SPf080AdM70P0Z:RX402h^;P80=CDe0P1HF5P2061PH080;Bd]0P0`<30202LW9`80
9BDU0P0R8R800`0Z:RX0;Rh^02h^;P0203Hf=P80AdM70P1HF5P207]kN`80IFEU0P1:BTX202h^;P@0
9RHV0P0Y:BT202l_;`80;2`/200`<30202d];@80:RXZ0P0Y:BT202PX:080;Bd]0P0R8R8203Ph>080
<30`00<0820P01hN7P0N7Qh00P0[:b/206e]K@80UIFE0P2LW9`207moO`80F5QH0P1iNGT20:RXZ080
^[Zj0P2e]KD20:VYZ@80ZZZZ102/[:`20:n_[`80^k^k0P2o_kl20<;2`P80bl_;0P3:b/X20<g=c@80
`<300P2m_Kd00`2h^;P0/K6a0;6a/@020;2`/080[Zj^0P2b/[820;fm_@80h^;R0P3>c/h209JFUP80
EeMG0P1;Bd/204Y:BP80CDe=0P1LG5`205ADE080De=C0P1>CTh404m?C`80CDe=0P17AdL203/k>`80
@4100P0k>c/203`l?080@D5100<0?Cdm03Hf=P0f=SH00P0c<c<2030`<080>3Ph0P0l?3`204=3@`80
@4100P0f=SH202XZ:P80<30`0P0b<S8202/[:`80>CTi0P0o?cl204Y:BP80Ng]k0P1OGel205iNGP80
Ng]k0P2@T90208:2PP80Ogmo101kNg/207inOP0307YjNP1iNGT0NGUi0080OWin0P23Ph<208N7Q`80
Rh^;0P2ATI4209:BTP80Vi^K0P2JVYX20::RXP80WYjN0P2JVYXN0<SPf0007038h=P402d];@80;2`/
0P0a<C4203/k>`80CDe=0P1RHV8202h^;P80<S8b0P0X:2P202LW9`8092@T00<09RHV034a<@0a<C40
0P10@40205QHF080Jf][0P1QHF42051@D080=cLg0P0S8b<202HV9P80;bl_0P0^;Rh202d];@H0;Rh^
1P0];Bd402`/;080:b/[0P0a<C42024Q8@80C4a<0P0h>3P00`0T92@061PH01PH600201`L7080B4Q8
0P1iNGT20:ZZZP80T92@0P1MGEd206QXJ080Q8B40P2XZ:P20<o?c`80[:b/0P2[Zj/20:NWY`80Z:RX
0P2/[:`20;Bd]080_;bl0P31`L420<K6aP80b/[:0P3<c<`20<O7a`80`L7100<0^;Rh0;6a/@2a/K40
0P2][Jd20:^[Z`80[jn_0P2d];@20;bl_080`l?30P2n_[h20:j^[P80K6a/0P1>CTh2059BDP80HV9R
0P1QHF4205mOG`80HV9R0P1UIFD2065QH@80Fe]K0P1ADE4204U9B@80B4Q80P1:BTX204i>CP80D51@
00<0BDU903lo?`0o?cl00P0b<S8202/[:`80?Cdm0P1BDU8405]KF`80ADE50P0`<30203Ph>080@T92
0P0n?Sh20451@@80FEUI0P1dM7@2079bLP80QhN70P1DE5@2061PH080QhN70P1dM7@207QhN080MWIf
0P1eMGD207AdM00307=cL`1dM7@0M7Ad0080NGUi0P20P80208J6QP80SHf=0P2DU9@209ZJVP80WIfM
0P2NWYh209nOW`@0X:2P9`38h=P2034a<@80<30`100];Bd203`l?080E5AD0P1NGUh2034a<@80;bl_
0P0];Bd202HV9P8092@T0P0Y:BT203<c<`80?Shn00<0GemO061PH01PH6000P1/K6`205MGE`80=3@d
0P0U9BD2030`<0@0:b/[0P0/;2`202h^;P80;Bd]0P0d=3@202XZ:P80;Rh^100[:b/202XZ:P80;Rh^
100W9bL204A4A080?clo0P0N7Qh201dM7@808R8R0P0n?Sh20861P@80XZ:R0P2=SHd206YZJP80JFUY
00<0O7al0;2`/02`/;000P36a/H20;Fe]@80Y:BT0P2ZZZX20:RXZ080[Jf]0P2a/K420;^k^`80`L71
0P35aLD40<S8b080b/[:0P30`<020;Fe]@80/k>c0P2YZJT20:j^[P80[Jf]0P2g]kL20;fm_@80a/K6
0P3:b/X20:f][@80I6AT0P1DE5@205EEE@80GemO0P1RHV82061PH00306ATI01WIfL0IfMW0080I6AT
0P1PH60204Y:BP80Bd];0P19BDT204=3@`80DU9B0P19BDT2055AD@80>c/k0P0f=SH202l_;`80>3Ph
0P1ADE4206UYJ@80GUiN0P1;Bd/2030`<080;Rh^0P13@d<204E5A@80@4100P1DE5@206m_K`80NGUi
0P20P80205MGE`80IFEU0P20P80207MgM`0307YjNP1eMGD0MGEe0080Lg=c101dM7@207MgM`80NWYj
0P20P80208J6QP80SHf=0P2CTi<209VIV@80W9bL0P2MWId20::RXP80X:2P0P2MWIdW0<SPf080;bl_
100Z:RX2030`<080>c/k0P1:BTX206EUI@80;Rh^0P0a<C4402TY:@808B4Q00<0:BTY02l_;`0_;bl0
0P11@D4205MGE`80JVYZ0P1QHF42051@D080=CDe0P0U9BD202HV9P@0;bl_0P0^;Rh202`/;0@0;bl_
0P0[:b/202`/;080;Bd]100[:b/202TY:@80;Rh^0P0S8b<204];B`80>3Ph00<09BDU01PH600H61P0
0P0M7Ad204U9B@80NGUi0P2[Zj/209>CT`80FEUI0P1WIfL208V9R@80YJFU0P3@d=020:j^[P80ZZZZ
102WYjL20:ZZZP80/k>c0P2l_;`20<30`080aLG50P3<c<`20<_;b`80a/K60P2o_kl00`2l_;`0[jn_
0:n_[`020:j^[P80ZZZZ0P2^[Zh20;Bd]080_;bl0P33`l<20<30`080ZZZZ0P1_Kfl204a<C080E5AD
0P1RHV8205iNGP80GemO0P1SHf<206ATI080HF5Q0P1JFUX205=CD`80B4Q80P1<C4`204Q8B080DE5A
0P1>CTh00`19BDT0?3`l03`l?00203@d=080:RXZ0P0k>c/2055AD@80GUiN0P1HF5P204M7A`80<C4a
0P0g=cL204I6AP80?clo0P10@40205YJFP80LG5a0P1eMGD208>3P`80De=C0P1OGel208F5Q@80MgMg
0P1dM7@207QhN080M7Ad0P1eMGD00`1cLg<0MGEe07EeM@0207YjNP80P8200P23Ph<208^;R`80UIFE
0P2JVYX409fMW@80XZ:R102NWYhN0<SPf0007038h=P402d];@80;2`/0P0a<C4203/k>`80CDe=0P1R
HV8202h^;P80<S8b0P0X:2P202LW9`8092@T00<09RHV034a<@0a<C400P10@40205QHF080Jf][0P1Q
HF42051@D080=cLg0P0S8b<202HV9P80;bl_0P0^;Rh202d];@H0;Rh^1P0];Bd402`/;080:b/[0P0a
<C42024Q8@80C4a<0P0h>3P00`0T92@061PH01PH600201`L7080B4Q80P1iNGT20:ZZZP80T92@0P1M
GEd206QXJ080Q8B40P2XZ:P20<o?c`80[:b/0P2[Zj/20:NWY`80Z:RX0P2/[:`20;Bd]080_;bl0P31
`L420<K6aP80b/[:0P3<c<`20<O7a`80`L7100<0^;Rh0;6a/@2a/K400P2][Jd20:^[Z`80[jn_0P2d
];@20;bl_080`l?30P2n_[h20:j^[P80K6a/0P1>CTh2059BDP80HV9R0P1QHF4205mOG`80HV9R0P1U
IFD2065QH@80Fe]K0P1ADE4204U9B@80B4Q80P1:BTX204i>CP80D51@00<0BDU903lo?`0o?cl00P0b
<S8202/[:`80?Cdm0P1BDU8405]KF`80ADE50P0`<30203Ph>080@T920P0n?Sh20451@@80FEUI0P1d
M7@2079bLP80QhN70P1DE5@2061PH080QhN70P1dM7@207QhN080MWIf0P1eMGD207AdM00307=cL`1d
M7@0M7Ad0080NGUi0P20P80208J6QP80SHf=0P2DU9@209ZJVP80WIfM0P2NWYh209nOW`@0X:2P9`38
h=P2034a<@80<30`100];Bd203`l?080E5AD0P1NGUh2034a<@80;bl_0P0];Bd202HV9P8092@T0P0Y
:BT203<c<`80?Shn00<0GemO061PH01PH6000P1/K6`205MGE`80=3@d0P0U9BD2030`<0@0:b/[0P0/
;2`202h^;P80;Bd]0P0d=3@202XZ:P80;Rh^100[:b/202XZ:P80;Rh^100W9bL204A4A080?clo0P0N
7Qh201dM7@808R8R0P0n?Sh20861P@80XZ:R0P2=SHd206YZJP80JFUY00<0O7al0;2`/02`/;000P36
a/H20;Fe]@80Y:BT0P2ZZZX20:RXZ080[Jf]0P2a/K420;^k^`80`L710P35aLD40<S8b080b/[:0P30
`<020;Fe]@80/k>c0P2YZJT20:j^[P80[Jf]0P2g]kL20;fm_@80a/K60P3:b/X20:f][@80I6AT0P1D
E5@205EEE@80GemO0P1RHV82061PH00306ATI01WIfL0IfMW0080I6AT0P1PH60204Y:BP80Bd];0P19
BDT204=3@`80DU9B0P19BDT2055AD@80>c/k0P0f=SH202l_;`80>3Ph0P1ADE4206UYJ@80GUiN0P1;
Bd/2030`<080;Rh^0P13@d<204E5A@80@4100P1DE5@206m_K`80NGUi0P20P80205MGE`80IFEU0P20
P80207MgM`0307YjNP1eMGD0MGEe0080Lg=c101dM7@207MgM`80NWYj0P20P80208J6QP80SHf=0P2C
Ti<209VIV@80W9bL0P2MWId20::RXP80X:2P0P2MWIdW0<SPf080;bl_100Z:RX2030`<080>c/k0P1:
BTX206EUI@80;Rh^0P0a<C4402TY:@808B4Q00<0:BTY02l_;`0_;bl00P11@D4205MGE`80JVYZ0P1Q
HF42051@D080=CDe0P0U9BD202HV9P@0;bl_0P0^;Rh202`/;0@0;bl_0P0[:b/202`/;080;Bd]100[
:b/202TY:@80;Rh^0P0S8b<204];B`80>3Ph00<09BDU01PH600H61P00P0M7Ad204U9B@80NGUi0P2[
Zj/209>CT`80FEUI0P1WIfL208V9R@80YJFU0P3@d=020:j^[P80ZZZZ102WYjL20:ZZZP80/k>c0P2l
_;`20<30`080aLG50P3<c<`20<_;b`80a/K60P2o_kl00`2l_;`0[jn_0:n_[`020:j^[P80ZZZZ0P2^
[Zh20;Bd]080_;bl0P33`l<20<30`080ZZZZ0P1_Kfl204a<C080E5AD0P1RHV8205iNGP80GemO0P1S
Hf<206ATI080HF5Q0P1JFUX205=CD`80B4Q80P1<C4`204Q8B080DE5A0P1>CTh00`19BDT0?3`l03`l
?00203@d=080:RXZ0P0k>c/2055AD@80GUiN0P1HF5P204M7A`80<C4a0P0g=cL204I6AP80?clo0P10
@40205YJFP80LG5a0P1eMGD208>3P`80De=C0P1OGel208F5Q@80MgMg0P1dM7@207QhN080M7Ad0P1e
MGD00`1cLg<0MGEe07EeM@0207YjNP80P8200P23Ph<208^;R`80UIFE0P2JVYX409fMW@80XZ:R102N
WYhN0<SPf0007038h=P202`/;080;Bd]0P0Z:RX202l_;`80=cLg0P1EEED205IFEP80=3@d0P0Z:RX2
02HV9P80:2PX0P0U9BD00`0V9RH0=SHf03Hf=P0204U9B@80HF5Q0P1_Kfl205YJFP80?Cdm0P0];Bd2
02<S8`809BDU0P0Z:RX202/[:`80;2`/0P0_;bl2030`<080;Bd]0P0Y:BT202XZ:P809bLW0P0Y:BT2
02XZ:P808b<S0P0V9RH202`/;080Bd];0P0d=3@00`0L71`061PH01PH600201`L7080=CDe0P1HF5P2
096AT@80WIfM0P1gMgL206QXJ080LW9b0P2;Rh/20;Zj^P80_;bl0P2d];@20:JVYP80YjNW0P2[Zj/2
0;2`/080][Jf0P2m_Kd20<;2`P80a/K60P38b<P20<O7a`80`l?300<0^KVi0:j^[P2^[Zh00P2XZ:P2
0:JVYP80ZJVY0P2_[jl20;Jf]P80`l?30P3AdM420=3@d080aLG50P1aLG4206ATI080GUiN0P1PH602
06IVIP80JVYZ0P1]KFd206][J`80IfMW0P1TI6@4065QH@80HV9R0P1UIFD206MWI`0306ATI01KFe/0
Fe]K0080?clo0P0];Bd204M7A`80Jf][0P28R8P209RHV080MWIf0P1CDe<204I6AP80GemO0P1SHf<2
04];B`80H61P0P1bLW8207UiN@80Ph>3101RHV8207QhN080LG5a0P1`L70406a/K080KVi^00<0KFe]
06m_K`1_Kfl00P1gMgL208:2PP80S8b<0P2DU9@209VIV@80Vi^K0P2NWYh20:2PX080XJ6Q102RXZ8W
0<SPf0@0;2`/0P0a<C4202XZ:P80<30`0P1KFe/205MGE`80=3@d0P0^;Rh202TY:@809BDU0P0S8b<2
02@T9080<30`0P1=CDd00`1WIfL0K6a/06a/K002069RHP80=3@d0P0X:2P202/[:`809BDU0P0X:2P2
02HV9P80:b/[0P0d=3@2038b<P80;Rh^0P0];Bd202HV9P80;2`/0P0Z:RX202DU9@80:2PX0P0];Bd2
03/k>`80EEEE0P0V9RH201`L70807QhN0P0Q8B4202`/;080HF5Q0P2DU9@20:6QX@80Lg=c0P1XJ6P0
0`1[Jf/0S8b<08b<S0020;Vi^@80`L710P2`/;020:BTY080[:b/0P2WYjL20;:b/P80^k^k0P2m_Kd2
0<;2`P80a<C40P3;bl/20<S8b080`l?30P2i^KT20;6a/@@0Z:RX0P2VYZH20;:b/P80^[Zj0P2l_;`2
0<C4a080c<c<0P2b/[8207EeM@80EEEE0P1TI6@2061PH080J6QX00<0K6a/06][J`1[Jf/00P1UIFD2
05iNGP80GemO0P1RHV8406IVIP80JFUY0P1]KFd206][J`80EeMG0P0n?Sh202l_;`80ADE50P1_Kfl2
096AT@80Q8B40P1lO7`205=CD`80A4A40P1UIFD2071`L080BDU90P1WIfL206i^KP80Ng]k0P1lO7`2
06][J`80GemO0P1eMGD207AdM00306m_K`1]KFd0KFe]0080LG5a0P1`L70206IVIP80KFe]0P1iNGT2
0861P@80RXZ:0P2CTi<209^KV`80WinO0P2JVYX209jNWP@0Xj>S0P2RXZ8W0<SPf080;2`/0P0^;Rh2
02`/;080<S8b0P0i>CT205ADE080EUIF0P0c<c<202PX:08092@T0P0W9bL202<S8`0302LW9`0e=CD0
=CDe0080BDU90P1QHF4206m_K`80G5aL0P0m?Cd202l_;`8092@T0P0R8R8202XZ:P80;2`/0P0];Bd2
02XZ:P80<C4a0P0^;Rh202/[:`80:2PX0P0W9bL202d];@80;2`/0P0Q8B4202LW9`80;2`/0P18B4P2
03De=@0301`L700E5AD05ADE00807QhN0P0d=3@205MGE`80TY:B0P2NWYh207AdM080IVIV0P1cLg<2
08f=S@80^KVi0P2l_;`20;Ng]`80YJFU0P2XZ:P20:f][@80/[:b0P2h^;P20;jn_P80`<300P36a/H2
0<S8b080bl_;0P34a<@00`2j^[X0[Jf]0:f][@020:j^[P80YZJV0P2[Zj/20;6a/@80][Jf0P35aLD2
0=;BdP80d=3@0P37alL2075aL@80I6AT0P1NGUh2061PH080IFEU101ZJVX206][J`80IVIV0P1RHV82
05mOG`80GUiN0P1PH60206QXJ080IFEU00<0IVIV05eMG@1MGEd00P0n?Sh202d];@80ATI60P1ZJVX2
08j>SP80UYJF0P1bLW82055AD@80BDU90P1MGEd205mOG`80BDU90P1PH602071`L080NGUi0P23Ph<2
06QXJ080I6AT0P1fMWH2071`L0H0K6a/0P1]KFd00`1/K6`0KFe]06e]K@0207YjNP80PX:20P2=SHd2
09NGU`@0W9bL0P2MWId209nOW`80YJFU0P2SXj<20:6QXAh0b>3H000L0<SPf080;2`/0P0];Bd202XZ
:P80;bl_0P0g=cL205EEE@80EUIF0P0d=3@202XZ:P809RHV0P0X:2P202DU9@0302HV9P0f=SH0=SHf
0080BDU90P1QHF4206m_K`80FUYJ0P0m?Cd202d];@808b<S0P0U9BD202XZ:P80:b/[0P0/;2`202l_
;`80<30`0P0];Bd202TY:@80:RXZ0P0W9bL202TY:@80:RXZ0P0S8b<202HV9P80;2`/0P1;Bd/203@d
=00301`L700H61P061PH008071`L0P0e=CD205QHF080TI6A0P2MWId207MgM`80J6QX0P1bLW8208^;
R`80^[Zj0P2l_;`20;Bd]080YZJV0P2WYjL20:^[Z`80/;2`0P2f][H20;fm_@80`/;20P36a/H20<S8
b080alO70P33`l<00`2i^KT0[Zj^0:j^[P020:RXZ080YZJV0P2YZJT20:n_[`80][Jf0P33`l<20=7A
d@80d=3@0P35aLD2075aL@80I6AT0P1NGUh2061PH080IVIV0P1ZJVX206e]K@80Jf][0P1WIfL206AT
I0@0HF5Q0P1RHV8206EUI@80IfMW00<0I6AT05]KF`1KFe/00P0o?cl202d];@80AdM70P1[Jf/208R8
R080V9RH0P1fMWH205=CD`80ATI60P1OGel206=SH`80Bd];0P1PH602079bLP80NGUi0P23Ph<4069R
HP80N7Qh0P1aLG42071`L0@0K6a/0P1^KVh00`1]KFd0Kfm_06m_K`0207MgM`80PX:20P2<S8`209BD
U080VIVI0P2KVi/209jNWP80X:2P0P2QXJ440::RXRL0b>3H100/;2`2034a<@80:RXZ0P0`<30205]K
F`80EeMG0P0d=3@202h^;P80:BTY0P0U9BD202<S8`8092@T0P0`<30204e=C@0306MWI`1/K6`0K6a/
0080HV9R0P0d=3@202PX:080:b/[0P0U9BD202PX:0809RHV0P0[:b/203@d=080<S8b0P0^;Rh202d]
;@809RHV0P0/;2`202XZ:P809BDU0P0X:2P202d];@80>c/k0P1EEED202HV9P8071`L0P0N7Qh2024Q
8@80;2`/0P1QHF4209BDU080XJ6Q0P1cLg<206QXJ00306][J`2<S8`0S8b<0080^KVi0P31`L420;2`
/080Y:BT0P2/[:`20:NWY`80/[:b0P2k^k/20;fm_@80`/;20P34a<@20<_;b`80b<S80P33`l<20;Vi
^@80/K6a102XZ:P20:JVYP80/[:b0P2j^[X20;bl_080a<C40P3<c<`20;:b/P80MGEe0P1EEED206AT
I080H61P0P1XJ6P00`1/K6`0Jf][06][J`0206EUI@80GUiN0P1OGel2069RHP@0IVIV0P1YJFT206e]
K@80Jf][0P1GEeL203hn?P80;bl_0P15ADD206m_K`80TI6A0P24Q8@207alO080De=C0P14A4@206EU
I@80L71`0P19BDT206MWI`80KVi^0P1kNg/207alO080Jf][0P1OGel207EeM@80M7Ad00<0Kfm_06e]
K@1]KFd00P1aLG42071`L080IVIV0P1]KFd207UiN@80PH610P2:RXX209>CT`80Vi^K0P2OWil209ZJ
VP80WYjN102SXj<20::RXRL0b>3H0P0/;2`202h^;P80;2`/0P0b<S8203Ti>@80E5AD0P1FEUH203<c
<`80:2PX0P0T92@202LW9`808b<S00<09bLW03De=@0e=CD00P19BDT2065QH@80Kfm_0P1LG5`203dm
?@80;bl_0P0T92@2028R8P80:RXZ0P0/;2`202d];@80:RXZ0P0a<C4202h^;P80:b/[0P0X:2P202LW
9`80;Bd]0P0/;2`2024Q8@809bLW0P0/;2`204Q8B080=CDe00<071`L01DE5@0E5AD00P0N7Qh203@d
=080EeMG0P2BTY8209jNWP80M7Ad0P1VIVH207=cL`80SHf=0P2i^KT20;bl_080]kNg0P2UYJD20:RX
Z080[Jf]0P2b/[820;Rh^080_[jn0P30`<020<K6aP80b<S80P3;bl/20<C4a0030;Zj^P2][Jd0[Jf]
0080[Zj^0P2VYZH20:^[Z`80/K6a0P2f][H20<G5a@80d];B0P3@d=020<O7a`80LG5a0P1TI6@205iN
GP80H61P0P1UIFD406YZJP80Jf][0P1VIVH2069RHP80GemO0P1NGUh2061PH080J6QX0P1UIFD00`1V
IVH0GEeM05eMG@0203hn?P80;Bd]0P16ATH206YZJP80SXj>0P2FUYH2079bLP80DE5A0P19BDT205eM
G@80GemO0P19BDT2061PH080L71`0P1iNGT208>3P`80J6QX0P1TI6@207IfMP80L71`1P1/K6`206e]
K@0306a/K01]KFd0KFe]0080NWYj0P22PX8208f=S@80UiNG102LW9`209fMW@80WinO0P2UYJD20:>S
X`80XJ6Q7P38h=P001`0b>3H0P0_;bl202`/;080:BTY0P0];Bd2034a<@80GEeM0P17AdL203Ti>@80
8b<S0P0T92@202TY:@809RHV00<09bLW03/k>`0k>c/00P1ADE4206EUI@80KVi^0P1BDU8202l_;`@0
:2PX100V9RH202PX:080:b/[0P0_;bl2030`<080;2`/0P0V9RH402PX:0809RHV0P0Z:RX20410@080
EUIF0P1CDe<20410@080;2`/00<06a/K01`L700L71`00P0R8R8202PX:080>3Ph0P1^KVh20:2PX080
T92@0P1cLg<206a/K080Lg=c0P2KVi/20<C4a080^[Zj0P2YZJT20:RXZ080ZZZZ0P2][Jd20;6a/@80
^;Rh0P2o_kl20<;2`P80a<C40P36a/H20<G5a@030;^k^`2^[Zh0[Zj^0080YZJV0P2QXJ420:>SX`80
ZJVY0P2a/K420;Vi^@80`/;20P37alL20;Jf]P80^KVi0P2;Rh/4065QH@80K6a/0P1_Kfl6079bLP80
MGEe0P1hN7P207UiN@80NWYj0P1lO7`307emO@80MWIf0P1ADE4203Hf=P80Fe]K0P27QhL2096AT@80
T92@0P25QHD207]kN`80G5aL0P1iNGT208F5Q@80EeMG0P1QHF4206YZJP80M7Ad0P1hN7P2075aL@80
IVIV0P1WIfL206a/K080IVIV0P1PH602069RHP80IfMW00<0J6QX06][J`1[Jf/00P1hN7P208N7Q`80
U9BD102NWYh209fMW@80WinO0P2RXZ820:>SX`80Y:BT0P2UYJDW0<SPf080<30`0P0_;bl202TY:@80
:RXZ0P0l?3`205=CD`80DE5A0P0b<S8402HV9P80:2PX0P0Z:RX2030`<080<C4a0P1EEED00`1UIFD0
J6QX06QXJ00205]KF`80;Bd]0P0W9bL402PX:08092@T100Z:RX2030`<080;bl_100X:2P202XZ:P80
:2PX0P0a<C4202d];@80>3Ph0P1BDU82069RHP80?Cdm0P0Y:BT2028R8P809RHV100Q8B4203De=@80
Ng]k0P2FUYH209VIV@80LG5a00<0KFe]07MgM`1gMgL00P2NWYh20;bl_080`/;20P2WYjL20:>SX`80
[:b/0P2^[Zh20:n_[`80^;Rh1030`<020<?3``80alO70P35aLD20;^k^`80[:b/0P2SXj<20:6QX@80
XZ:R0P2VYZH20;Ng]`80^[Zj0P32`/840<S8b080][Jf0P22PX8206ATI080HV9R0P1/K6`3075aL@80
LW9b0P1hN7P207EeM@80MWIf0P1mOGd207QhN080MGEe0P1lO7`20861P@80KVi^0P1HF5P203<c<`80
FUYJ0P21PH4209FEU@80TY:B0P2;Rh/207AdM080H61P0P1gMgL207emO@80Fe]K0P1IFET2075aL@80
Lg=c0P1lO7`2075aL@80JFUY0P1TI6@206i^KP0306=SH`1MGEd0GEeM0080I6AT0P1QHF4206QXJ080
KFe]0P1jNWX208F5Q@80V9RH0P2LW9`209fMW@80W9bL0P2MWId20:6QX@80YZJV0P2TY:@20:FUYBL0
b>3H0P0_;bl202/[:`80:2PX0P0/;2`202l_;`80G5aL0P17AdL203Ti>@808b<S0P0U9BD202XZ:P80
8R8R00<0:b/[03Ti>@0i>CT00P1ADE4206EUI@80KVi^0P1?Cdl202h^;P80:b/[0P0W9bL402DU9@80
9bLW0P0Z:RX2034a<@80;bl_0P0W9bL202PX:0809RHV0P0Z:RX202DU9@80:2PX0P0o?cl205MGE`80
D51@0P11@D4202d];@0301XJ6P0M7Ad07AdM00808B4Q0P0X:2P203Ti>@80KFe]0P2PX:02096AT@80
Lg=c0P1YJFT2079bLP80W9bL0P33`l<20;Vi^@80ZZZZ0P2YZJT40:ZZZP80/;2`0P2i^KT20;no_`80
`L711035aLD20<K6aP030;Rh^02^[Zh0[Zj^0080YZJV0P2PX:020:FUY@80YjNW0P2a/K420;^k^`80
_Kfm0P35aLD20;^k^`80]kNg0P28R8P406=SH`80KFe]0P1^KVh207EeM@80Lg=c0P1dM7@2079bLP80
N7Qh0P1jNWX207]kN`80O7al0P1nOWh00`20P800M7Ad07AdM00205=CD`80=CDe0P1MGEd208B4Q080
TI6A0P2>SXh208F5Q@80Ng]k0P1LG5`207UiN@80R8R80P1GEeL205mOG`80KFe]0P1dM7@207MgM`80
KFe]0P1TI6@206IVIP80KFe]0P1WIfL205iNGP@0IFEU00<0JFUY06a/K01/K6`00P1gMgL208J6QP80
UYJF0P2MWId209bLW080WIfM0P2OWil20::RXP80YJFU102TY:@N0<SPf0007038h=P202l_;`80;2`/
0P0Y:BT202d];@80<C4a0P1MGEd204M7A`80>CTi0P0S8b<202@T9080:BTY0P0V9RH00`0W9bL0>c/k
03/k>`02055AD@80IFEU0P1^KVh2059BDP80;bl_100X:2P402HV9P80:2PX0P0[:b/202l_;`80<30`
0P0/;2`202HV9P@0:2PX0P0V9RH202XZ:P80@4100P1FEUH205=CD`80@4100P0/;2`00`0K6a/071`L
01`L7002028R8P80:2PX0P0h>3P206i^KP80X:2P0P2@T90207=cL`80K6a/0P1cLg<209^KV`80a<C4
0P2j^[X20:VYZ@80Z:RX0P2ZZZX20:f][@80/K6a0P2h^;P20;no_`80`/;20P34a<@20<K6aP80aLG5
00<0^k^k0:j^[P2^[Zh00P2VYZH20:6QX@80Xj>S0P2YZJT20;6a/@80^KVi0P32`/820<O7a`80][Jf
0P2i^KT208^;R`@0HF5Q0P1/K6`206m_K`H0LW9b0P1eMGD207QhN080NGUi0P1jNWX207alO0<0OGem
0P1fMWH2055AD@80=SHf0P1KFe/208N7Q`80TI6A0P2@T90208F5Q@80Ng]k0P1LG5`207UiN@80QHF5
0P1GEeL2065QH@80JVYZ0P1dM7@207QhN080LG5a0P1VIVH206MWI`80K6a/0P1VIVH2061PH080HV9R
0P1WIfL00`1XJ6P0Jf][06][J`0207QhN080QhN70P2DU9@409jNWP80WIfM0P2OWil20::RXP80Xj>S
0P2TY:@20:FUYBL0b>3H0P0`<30202l_;`80:BTY0P0Z:RX203`l?080De=C0P1ADE42038b<P@09RHV
0P0X:2P202XZ:P80<30`0P0a<C4205EEE@0306EUI@1XJ6P0J6QX0080Fe]K0P0];Bd202LW9`@0:2PX
0P0T92@402XZ:P80<30`0P0_;bl402PX:080:RXZ0P0X:2P2034a<@80;Bd]0P0h>3P2059BDP80HV9R
0P0m?Cd202TY:@808R8R0P0V9RH4024Q8@80=CDe0P1kNg/209JFUP80VIVI0P1aLG400`1]KFd0MgMg
07MgM`0209jNWP80_;bl0P32`/820:NWY`80Xj>S0P2/[:`20:j^[P80[jn_0P2h^;P40<30`080`l?3
0P37alL20<G5a@80^k^k0P2/[:`20:>SX`80XJ6Q0P2RXZ820:JVYP80]kNg0P2j^[X20<;2`P@0b<S8
0P2f][H208:2PP80I6AT0P1RHV8206a/K0<0LG5a0P1bLW8207QhN080MGEe0P1fMWH207emO@80N7Qh
0P1eMGD207alO080PH610P1^KVh205QHF080<c<c0P1JFUX20861P@80UIFE0P2BTY8208^;R`80M7Ad
0P1PH60207MgM`80OGem0P1KFe/205UIF@80LG5a0P1cLg<207alO080LG5a0P1YJFT206ATI080KVi^
00<0Hf=S05eMG@1MGEd00P1TI6@2065QH@80J6QX0P1]KFd207YjNP80QHF50P2HV9P209bLW080WIfM
0P2LW9`209fMW@80XJ6Q0P2VYZH20:BTY080YJFU9`38h=P202l_;`80:b/[0P0X:2P202`/;080;bl_
0P1LG5`204M7A`80>CTi0P0S8b<202DU9@80:RXZ0P0R8R800`0[:b/0>CTi03Ti>@02055AD@80IFEU
0P1^KVh204m?C`80;Rh^0P0[:b/202LW9`@09BDU0P0W9bL202XZ:P80<C4a0P0_;bl202LW9`80:2PX
0P0V9RH202XZ:P809BDU0P0X:2P203lo?`80EeMG0P1@D5020451@@80;Bd]00<06QXJ01dM7@0M7Ad0
0P0Q8B4202PX:080>CTi0P1]KFd20:2PX080TI6A0P1cLg<206UYJ@80LW9b0P2LW9`20<?3``80^KVi
0P2ZZZX20:VYZ@@0ZZZZ0P2`/;020;Vi^@80_kno0P31`L440<G5a@80a/K600<0^;Rh0:j^[P2^[Zh0
0P2VYZH20:2PX080YJFU0P2WYjL20;6a/@80^k^k0P2m_Kd20<G5a@80^k^k0P2g]kL208R8R0@0Hf=S
0P1]KFd206i^KP80MGEe0P1cLg<207AdM080LW9b0P1hN7P207YjNP80Ng]k0P1lO7`207inOP030820
P01dM7@0M7Ad0080De=C0P0e=CD205eMG@80Q8B40P2ATI4208j>SP80QHF50P1kNg/205aLG080NGUi
0P28R8P205MGE`80GemO0P1]KFd207AdM080MgMg0P1]KFd206ATI080IVIV0P1]KFd206MWI`80GUiN
101UIFD00`1YJFT0K6a/06a/K00207MgM`80QXJ60P2FUYH209fMW@80W9bL0P2MWId209nOW`80XZ:R
0P2UYJD40:BTY1h0b>3H000L0<SPf080:BTY0P0Z:RX202/[:`@0;Bd]0P1FEUH203`l?080>SXj0P0/
;2`202TY:@80:2PX0P0U9BD00`0/;2`0@4100410@00205IFEP80Hf=S0P1[Jf/20451@@80=SHf0P0X
:2P202LW9`809BDU0P0V9RH202PX:080:RXZ0P0/;2`202d];@80:RXZ0P0/;2`202@T9080?clo0P0n
?Sh204=3@`80KFe]0P1dM7@204];B`80=3@d0P0c<c<00`0n?Sh08B4Q024Q8@02024Q8@806a/K0P0U
9BD2055AD@80PX:20P2BTY82092@T080P8200P1dM7@208N7Q`80YJFU0P2c/k<20;Zj^P80/;2`0P2T
Y:@20:RXZ080/;2`0P2d];@20;Vi^@80_Kfm0P31`L420<K6aP80alO700<0_kno0;Bd]02d];@00P2V
YZH209bLW080WIfM0P2RXZ820:^[Z`80]KFe0P2o_kl20<K6aP@0aLG50P2^[Zh209:BTP80O7al0P1/
K6`206m_K`80MgMg0P1jNWX207emO@80OWin0P1oOgl208B4Q080RHV90P2:RXX208V9R@0308N7Q`22
PX80PX:20080J6QX0P1FEUH207EeM@80VYZJ0P2QXJ4209jNWP80U9BD0P29RHT207EeM@80Ph>30P2:
RXX207=cL`80GUiN101/K6`206YZJP80IVIV0P1NGUh205YJFP80G5aL0P1FEUH2059BDP80De=C0P1G
EeL00`1PH600KFe]06e]K@0207emO@80SXj>0P2KVi/40:FUY@80XZ:R0P2SXj<20:FUY@@0YjNW0P2X
Z:PW0<SPf080:2PX0P0U9BD202`/;080:BTY0P0d=3@204a<C080@4100P0g=cL202/[:`809bLW0P0V
9RH2030`<080:2PX0P0h>3P205MGE`<0IVIV0P1<C4`203De=@80:RXZ0P0S8b<2028R8P80;2`/0P0]
;Bd202`/;080:RXZ0P0a<C4202PX:0809bLW0P0Z:RX203<c<`80=CDe0P13@d<206a/K080KVi^0P11
@D4202/[:`80<C4a0P0_;bl2028R8P807QhN0P0P8202024Q8@80BTY:0P1kNg/209jNWP80SXj>00<0
Ng]k079bLP1bLW800P21PH420:>SX`80_kno0P2i^KT40:RXZ080ZJVY0P2[Zj/20;:b/P80^;Rh0P2m
_Kd20<71`@80a/K60P35aLD20;no_`80]KFe0P2YZJT209ZJVP80XJ6Q0P2LW9`20;6a/@80]KFe0P2n
_[h20<C4a0@0alO70P2m_Kd209FEU@80K6a/0P1_Kfl00`1aLG40N7Qh07QhN00207inOP80OGem0P1k
Ng/207alO080RXZ:0P27QhL208J6QP80Q8B40P2:RXX208>3P`80Lg=c0P1?Cdl207]kN`80Vi^K0P2M
WId209^KV`80WIfM0P29RHT2075aL@80Q8B40P29RHT207IfMP80Fe]K0P1/K6`206EUI@80JVYZ0P1T
I6@205iNGP80EeMG0P1MGEd00`1JFUX0DE5A055AD@0205YJFP80G5aL0P1RHV8206m_K`80MgMg0P2?
Shl209jNWP80YJFU0P2TY:@40:>SX`80YjNW0P2ZZZX20::RXP80YJFU9`38h=P202`/;080:BTY0P0[
:b/202h^;P80;Bd]0P1GEeL203dm?@80?3`l100/;2`202/[:`8092@T00<0;Bd]0451@@11@D400P1G
EeL206ATI080KFe]0P12@T8203Hf=P80:BTY0P0W9bL202@T9080:b/[0P0Y:BT202`/;080;Rh^0P0a
<C4202/[:`80;Bd]0P0S8b<203Xj>P80@d=30P14A4@206m_K`80MGEe0P1=CDd203@d=080<c<c00<0
?Cdm028R8P0R8R800P0P820201/K6`808b<S0P1EEED20861P@80T92@0P2EUID208F5Q@80MgMg0P25
QHD20:BTY080][Jf0P2h^;P20:j^[P80YJFU0P2WYjL20:n_[`80]kNg0P2h^;P40;no_`80alO70P36
a/H00`30`<00]KFe0;Fe]@020:6QX@80VIVI0P2PX:020:6QX@80[:b/0P2e]KD20;^k^`80a/K60P3=
cLd20<G5a@80ZZZZ0P2@T90207]kN`80K6a/0P1_Kfl207AdM080N7Qh0P1mOGd207inOP80PX:20P26
QXH208R8R080RHV90P26QXH00`24Q8@0PH610861P@0206QXJ080EUIF0P1fMWH209^KV`80Y:BT0P2Q
XJ4209JFUP80RXZ:0P1gMgL208>3P`80RXZ:0P1fMWH205eMG@80Jf][0P1^KVh206e]K@80J6QX0P1P
H60205UIF@80GEeM0P1HF5P205=CD`80DU9B0P1IFET00`1PH600Jf][06][J`020820P080S8b<0P2J
VYX40:>SX`80Y:BT0P2QXJ480:JVYQh0b>3H000L0<SPf080:BTY0P0Z:RX202/[:`@0;Bd]0P1FEUH2
03`l?080>SXj0P0/;2`202TY:@80:2PX0P0U9BD00`0/;2`0@4100410@00205IFEP80Hf=S0P1[Jf/2
0451@@80=SHf0P0X:2P202LW9`809BDU0P0V9RH202PX:080:RXZ0P0/;2`202d];@80:RXZ0P0/;2`2
02@T9080?clo0P0n?Sh204=3@`80KFe]0P1dM7@204];B`80=3@d0P0c<c<00`0n?Sh08B4Q024Q8@02
024Q8@806a/K0P0U9BD2055AD@80PX:20P2BTY82092@T080P8200P1dM7@208N7Q`80YJFU0P2c/k<2
0;Zj^P80/;2`0P2TY:@20:RXZ080/;2`0P2d];@20;Vi^@80_Kfm0P31`L420<K6aP80alO700<0_kno
0;Bd]02d];@00P2VYZH209bLW080WIfM0P2RXZ820:^[Z`80]KFe0P2o_kl20<K6aP@0aLG50P2^[Zh2
09:BTP80O7al0P1/K6`206m_K`80MgMg0P1jNWX207emO@80OWin0P1oOgl208B4Q080RHV90P2:RXX2
08V9R@0308N7Q`22PX80PX:20080J6QX0P1FEUH207EeM@80VYZJ0P2QXJ4209jNWP80U9BD0P29RHT2
07EeM@80Ph>30P2:RXX207=cL`80GUiN101/K6`206YZJP80IVIV0P1NGUh205YJFP80G5aL0P1FEUH2
059BDP80De=C0P1GEeL00`1PH600KFe]06e]K@0207emO@80SXj>0P2KVi/40:FUY@80XZ:R0P2SXj<2
0:FUY@@0YjNW0P2XZ:PW0<SPf080:2PX0P0U9BD202`/;080:BTY0P0d=3@204a<C080@4100P0g=cL2
02/[:`809bLW0P0V9RH2030`<080:2PX0P0h>3P205MGE`<0IVIV0P1<C4`203De=@80:RXZ0P0S8b<2
028R8P80;2`/0P0];Bd202`/;080:RXZ0P0a<C4202PX:0809bLW0P0Z:RX203<c<`80=CDe0P13@d<2
06a/K080KVi^0P11@D4202/[:`80<C4a0P0_;bl2028R8P807QhN0P0P8202024Q8@80BTY:0P1kNg/2
09jNWP80SXj>00<0Ng]k079bLP1bLW800P21PH420:>SX`80_kno0P2i^KT40:RXZ080ZJVY0P2[Zj/2
0;:b/P80^;Rh0P2m_Kd20<71`@80a/K60P35aLD20;no_`80]KFe0P2YZJT209ZJVP80XJ6Q0P2LW9`2
0;6a/@80]KFe0P2n_[h20<C4a0@0alO70P2m_Kd209FEU@80K6a/0P1_Kfl00`1aLG40N7Qh07QhN002
07inOP80OGem0P1kNg/207alO080RXZ:0P27QhL208J6QP80Q8B40P2:RXX208>3P`80Lg=c0P1?Cdl2
07]kN`80Vi^K0P2MWId209^KV`80WIfM0P29RHT2075aL@80Q8B40P29RHT207IfMP80Fe]K0P1/K6`2
06EUI@80JVYZ0P1TI6@205iNGP80EeMG0P1MGEd00`1JFUX0DE5A055AD@0205YJFP80G5aL0P1RHV82
06m_K`80MgMg0P2?Shl209jNWP80YJFU0P2TY:@40:>SX`80YjNW0P2ZZZX20::RXP80YJFU9`38h=P2
02`/;080:BTY0P0[:b/202h^;P80;Bd]0P1GEeL203dm?@80?3`l100/;2`202/[:`8092@T00<0;Bd]
0451@@11@D400P1GEeL206ATI080KFe]0P12@T8203Hf=P80:BTY0P0W9bL202@T9080:b/[0P0Y:BT2
02`/;080;Rh^0P0a<C4202/[:`80;Bd]0P0S8b<203Xj>P80@d=30P14A4@206m_K`80MGEe0P1=CDd2
03@d=080<c<c00<0?Cdm028R8P0R8R800P0P820201/K6`808b<S0P1EEED20861P@80T92@0P2EUID2
08F5Q@80MgMg0P25QHD20:BTY080][Jf0P2h^;P20:j^[P80YJFU0P2WYjL20:n_[`80]kNg0P2h^;P4
0;no_`80alO70P36a/H00`30`<00]KFe0;Fe]@020:6QX@80VIVI0P2PX:020:6QX@80[:b/0P2e]KD2
0;^k^`80a/K60P3=cLd20<G5a@80ZZZZ0P2@T90207]kN`80K6a/0P1_Kfl207AdM080N7Qh0P1mOGd2
07inOP80PX:20P26QXH208R8R080RHV90P26QXH00`24Q8@0PH610861P@0206QXJ080EUIF0P1fMWH2
09^KV`80Y:BT0P2QXJ4209JFUP80RXZ:0P1gMgL208>3P`80RXZ:0P1fMWH205eMG@80Jf][0P1^KVh2
06e]K@80J6QX0P1PH60205UIF@80GEeM0P1HF5P205=CD`80DU9B0P1IFET00`1PH600Jf][06][J`02
0820P080S8b<0P2JVYX40:>SX`80Y:BT0P2QXJ480:JVYQh0b>3H000L0<SPf0808b<S0P0X:2P202d]
;@80;2`/0P0X:2P204U9B@80<S8b100h>3P202l_;`809RHV0P0U9BD00`0];Bd0@T920492@P0205QH
F080GUiN0P1RHV82038b<P80?clo0P0];Bd402DU9@@0:2PX0P0Y:BT402PX:080:BTY0P0b<S8202LW
9`@0Fe]K0P1IFET207AdM080DU9B0P0O7al202d];@80@T9200<0GUiN02DU9@0U9BD00P0S8b<201HF
5P806a/K0P0g=cL205aLG080RHV90P2YZJT209NGU`80O7al0P1hN7P207moO`80YJFU0P37alL20;Rh
^080XZ:R0P2VYZH20:j^[P80/K6a0P2c/k<20;Vi^@80_[jn0P34a<@20<S8b0030<C4a02k^k/0^k^k
0080ZJVY0P2IVIT209NGU`80W9bL0P2UYJD20;2`/080^;Rh0P2o_kl20<G5a@80alO70P3:b/X20<?3
``80VYZJ0P1dM7@207IfMP80PH611023Ph<208:2PP80Ph>30P2;Rh/409:BTP80T92@00<0SHf=08R8
R028R8P00P1mOGd207QhN080SHf=0P2UYJD20:JVYP80XJ6Q0P2HV9P208j>SP80RHV91023Ph<208N7
Q`80FEUI0P1ZJVX2061PH080Fe]K0P1FEUH205=CD`80Cdm?0P1;Bd/204U9B@80B4Q80P19BDT204m?
C`03061PH01eMGD0MGEe0080QXJ60P2FUYH20:>SX`80Zj^[0P2ZZZX20:JVYP80YjNW102YZJT40:ZZ
ZRL0b>3H0P0T92@202TY:@80<C4a0P0V9RH203@d=080AdM70P0k>c/203hn?P80=cLg0P0^;Rh202XZ
:P80;2`/0P0c<c<203Ti>@80Fe]K00<0GEeM065QH@1QHF400P0l?3`203Ph>080<30`1P0T92@202TY
:@80:2PX0P0Y:BT202LW9`80:RXZ0P0`<302034a<@80FEUI0P1CDe<2061PH080QHF50P1BDU8202DU
9@80:b/[0P19BDT205aLG0809bLW0P0P820201dM7@807alO0P0b<S82069RHP80SXj>0P2WYjL00`2F
UYH0PX:208:2PP02075aL@80PX:20P2XZ:P20<?3``80]kNg0P2QXJ420:RXZ080[:b/0P2a/K420;>c
/`80^;Rh0P2k^k/20<O7a`80a/K60P34a<@20;^k^`80YjNW0P2FUYH209ZJVP80VIVI0P2XZ:P20:^[
Z`80^[Zj0P2o_kl20<71`@80aLG50P37alL20<30`080WYjN0P1_Kfl00`1^KVh0Ng]k07]kN`0408:2
PP80Ph>30P25QHD208V9R@80TY:B0P2CTi<208j>SP80TY:B0P2:RXX207EeM@80NWYj0P2@T9020:FU
Y@80Xj>S0P2PX:0209^KV`80Shn?0P1oOgl20861P@80RXZ:0P1nOWh205]KF`80J6QX0P1JFUX205iN
GP80EEEE0P1DE5@204m?C`80Bd];00<0CTi>04Q8B018B4P0101>CTh2061PH080MWIf0P27QhL209JF
UP80YZJV0P2ZZZX20:VYZ@80YZJV0P2XZ:P20:NWY`80Zj^[0P2ZZZX20:f][BL0b>3H0P0W9bL202DU
9@80;Bd]0P0_;bl202HV9P80BTY:0P0_;bl403Ph>080;bl_0P0U9BD202<S8`03038b<P10@400@410
0080F5QH0P1OGel2061PH080<S8b0P0o?cl202d];@809BDU0P0V9RH202LW9`80:2PX200W9bL2038b
<P809BDU0P1HF5P2061PH080F5QH0P1bLW82051@D0808R8R0P0[:b/203lo?`0305mOG`0V9RH09RHV
00808b<S0P0F5QH201/K6`80=cLg0P1KFe/208Z:RP80YjNW0P2GUiL207alO080MWIf0P1oOgl20:NW
Y`80b<S80P2a/K420:FUY@80Xj>S0P2_[jl20;:b/P80];Bd0P2h^;P20;no_`80`l?30P39bLT00`33
`l<0_Kfm0;fm_@020:NWY`80VYZJ102IVIT20:RXZ080/K6a0P2f][H20;bl_080alO70P35aLD20<_;
b`80`l?30P2LW9`2079bLP80MgMg0P20P80208:2PP80Q8B40P25QHD20861P@80Rh^;0P2ATI4209JF
UP80TI6A00<0RHV908Z:RP2:RXX00P1oOgl207UiN@80RHV90P2SXj<20:FUY@80WinO0P2FUYH208j>
SP80R8R80P24Q8@20861P@80QXJ60P1LG5`206YZJP80H61P0P1KFe/205IFEP80De=C0P1>CTh204Y:
BP80BDU90P17AdL204U9B@80Cdm?00<0Hf=S079bLP1bLW800P29RHT209NGU`80XJ6Q0P2^[Zh20:b/
[080YZJV0P2UYJD60:VYZ@80[Zj^7P38h=P001`0b>3H0P0S8b<202PX:080;Bd]0P0/;2`202PX:080
BDU90P0b<S8403Ph>080;bl_0P0V9RH202DU9@0302d];@12@T80@T920080F5QH0P1NGUh2069RHP80
<S8b0P0o?cl202d];@@09BDU100X:2P202TY:@@0:2PX0P0Y:BT2038b<P809bLW101KFe/205UIF@80
M7Ad0P1BDU8201lO7`80;Bd]0P12@T800`1NGUh09BDU02DU9@0202<S8`805QHF0P0K6a/203Lg=`80
G5aL0P29RHT20:VYZ@80UiNG0P1lO7`207QhN080Ogmo0P2UYJD20<O7a`80^;Rh0P2RXZ820:JVYP80
[Zj^0P2a/K420;>c/`80^KVi0P2n_[h20<C4a080b<S800<0a<C40;^k^`2k^k/00P2YZJT209VIV@80
UiNG0P2LW9`20:FUY@80/;2`0P2h^;P20;no_`80aLG50P37alL20<[:bP80`l?30P2JVYX207AdM080
MWIf0P21PH4408>3P`80PX:20P23Ph<208^;R`@0TY:B0P2@T9000`2=SHd0R8R808R8R00207emO@80
N7Qh0P2=SHd20:FUY@80YZJV0P2QXJ4209RHV080SXj>0P29RHT408>3P`80QhN70P1IFET206YZJP80
H61P0P1KFe/205IFEP80De=C0P1?Cdl204];B`80BDU90P18B4P204U9B@80Cdm?00<0H61P07EeM@1e
MGD00P26QXH209JFUP80Xj>S0P2[Zj/20:ZZZP80YZJV0P2WYjL40:VYZ@@0ZZZZ9`38h=P202@T9080
:BTY0P0a<C4202HV9P80=3@d0P17AdL203/k>`80?Shn0P0g=cL202h^;P80:RXZ0P0/;2`203<c<`80
>CTi0P1KFe/00`1MGEd0HF5Q065QH@0203`l?080>3Ph0P0`<30602@T9080:BTY0P0X:2P202TY:@80
9bLW0P0Z:RX2030`<080<C4a0P1IFET205=CD`80H61P0P25QHD2059BDP809BDU0P0[:b/204U9B@80
G5aL0P0W9bL2020P80807AdM0P0O7al2038b<P80HV9R0P2>SXh20:NWY`0309JFUP22PX80PX:20080
LG5a0P22PX820:RXZ080`l?30P2g]kL20:6QX@80Z:RX0P2/[:`20;6a/@80/k>c0P2h^;P20;^k^`80
alO70P36a/H20<C4a080^k^k0P2WYjL209JFUP80VYZJ0P2IVIT20:RXZ080Zj^[0P2j^[X20;no_`80
`L710P35aLD20<O7a`80`<300P2NWYh206m_K`0306i^KP1kNg/0Ng]k00@0PX:20P23Ph<208F5Q@80
RHV90P2BTY8209>CT`80SXj>0P2BTY8208Z:RP80MGEe0P1jNWX2092@T080YJFU0P2SXj<20:2PX080
Vi^K0P2?Shl207moO`80PH610P2:RXX207inOP80Fe]K0P1XJ6P205YJFP80GUiN0P1EEED205ADE080
Cdm?0P1;Bd/00`1>CTh0B4Q804Q8B00404i>CP80H61P0P1fMWH208N7Q`80UYJF0P2VYZH20:ZZZP80
ZJVY0P2VYZH20:RXZ080YjNW0P2[Zj/20:ZZZP80[Jf]9`38h=P202LW9`809BDU0P0];Bd202l_;`80
9RHV0P1:BTX202l_;`@0>3Ph0P0_;bl202DU9@808b<S00<0<S8b0410@010@4000P1HF5P205mOG`80
H61P0P0b<S8203lo?`80;Bd]0P0U9BD202HV9P809bLW0P0X:2P802LW9`80<S8b0P0U9BD205QHF080
H61P0P1HF5P2079bLP80D51@0P0R8R8202/[:`80?clo00<0GemO02HV9P0V9RH00P0S8b<201HF5P80
6a/K0P0g=cL205]KF`80RXZ:0P2WYjL209NGU`80O7al0P1fMWH207moO`80YjNW0P38b<P20;6a/@80
YJFU0P2SXj<20:n_[`80/[:b0P2d];@20;Rh^080_kno0P33`l<20<W9b@030<?3``2m_Kd0_Kfm0080
YjNW0P2JVYX409VIV@80Z:RX0P2a/K420;Jf]P80_;bl0P37alL20<G5a@80bl_;0P33`l<209bLW080
LW9b0P1gMgL20820P080PX:20P24Q8@208F5Q@80PH610P2;Rh/2096AT@80UYJF0P2ATI400`29RHT0
RXZ:08Z:RP0207moO`80NGUi0P29RHT20:>SX`80YJFU0P2OWil209JFUP80SXj>0P28R8P208B4Q080
PH610P26QXH205aLG080JVYZ0P1PH60205]KF`80EUIF0P1CDe<204i>CP80BTY:0P19BDT204M7A`80
BDU90P1?Cdl00`1SHf<0LW9b079bLP0208V9R@80UiNG0P2QXJ420:j^[P80[:b/0P2VYZH20:FUY@H0
ZJVY0P2^[ZhN0<SPf0007038h=P402@T9080:2PX0P0h>3P204I6AP80L71`0P1EEED204M7A`80=SHf
0P10@40204];B`80FUYJ00<0ATI604a<C01<C4`00P1>CTh205aLG080ATI60P0_;bl203De=@80?3`l
0P0T92@202DU9@@09bLW0P0X:2P202HV9P809BDU0P0Y:BT2038b<P809bLW0P15ADD2061PH080K6a/
0P26QXH205IFEP8092@T0P0];Bd204i>CP0305MGE`0W9bL09bLW0080;Rh^0P0P820201dM7@809bLW
0P0o?cl207=cL`80XJ6Q0P2LW9`208V9R@80LG5a0P1ZJVX208n?S`80^;Rh0P2i^KT20;6a/@80ZZZZ
0P2TY:@20:ZZZP80/k>c0P2g]kL20;^k^`80`L710`35aLD20<30`080[jn_0P2NWYh409NGU`80WinO
0P2ZZZX20;:b/P80^KVi0P30`<020<?3``@0bLW90P2g]kL209jNWP80Ogmo0P1XJ6P206i^KP80OGem
0P24Q8@208^;R`80TI6A0P2EUID409RHV00309BDU02?Shl0Shn?0080SHf=0P2?Shl209ZJVP80YJFU
0P2TY:@209nOW`80UYJF0P2<S8`208F5Q@80Ng]k0P1eMGD207AdM080EUIF0P1JFUX2059BDP80CDe=
0P18B4P204A4A0@0@T920P15ADD204Y:BP80EEEE0P1TI6@00`1gMgL0RXZ:08Z:RP0209RHV080XZ:R
0P2XZ:P40:^[Z`H0ZJVY0P2ZZZX20:b/[080[Jf]9`38h=P202HV9P8092@T0P0_;bl203<c<`80ADE5
0P1QHF4204a<C080ATI60P0l?3`203Lg=`80?Cdm0P1SHf<204I6AP80?clo0P1KFe/00`1LG5`0@d=3
04=3@`0202LW9`80=CDe0P0k>c/402TY:@80:2PX0P0[:b/202LW9`809BDU0P0Y:BT202<S8`80;Bd]
0P0c<c<204m?C`80GemO0P1VIVH207IfMP80E5AD0P0V9RH202d];@80Fe]K0P1IFET202h^;P80:RXZ
0P0O7al201dM7@8092@T0P0i>CT207EeM@80VYZJ00<0YjNW08R8R028R8P00P1^KVh206QXJ080Shn?
0P2g]kL20<?3``80[:b/0P2WYjL20:ZZZP80[Jf]102d];@20;jn_P80`/;20P36a/H20<O7a`80_kno
0P2/[:`20:>SX`@0UYJF0P2QXJ420:VYZ@80/k>c0P2l_;`20;jn_P80a<C40P35aLD20<O7a`80`L71
0P2[Zj/00`1lO7`0M7Ad07AdM00207QhN080NWYj0P26QXH208V9R@80SXj>0P2GUiL209VIV@80VYZJ
0P2EUID208j>SP80Ng]k0P2FUYH209fMW@80WinO0P2SXj<20:2PX080VYZJ0P2;Rh/208F5Q@@0OWin
0P1cLg<4065QH@80EUIF0P1CDe<404Q8B080A4A40`0o?cl20451@@80Cdm?0P1KFe/207UiN@80R8R8
0P2EUID20:6QX@80YjNW0P2[Zj/20:NWY`80Zj^[0P2TY:@20:NWY`@0Zj^[0P2][JdW0<SPf080820P
0P0S8b<202TY:@80>SXj0P17AdL206m_K`80EeMG0P17AdL203De=@80@D510P1:BTX205YJFP0304=3
@`19BDT0BDU90080Cdm?0P1KFe/204I6AP80<30`0P0c<c<203/k>`8092@T0P0U9BD202<S8`80:2PX
0P0W9bL202PX:0808b<S0P0[:b/2038b<P80:BTY0P18B4P2061PH080JFUY0P21PH4205MGE`80:2PX
0P0`<30204];B`0305YJFP0S8b<08b<S0080;Bd]0P0R8R8201`L7080:2PX0P0n?Sh207AdM080WYjN
0P2KVi/208N7Q`80L71`0P1XJ6P209:BTP80_;bl0P2h^;P20;Jf]P80ZJVY0P2UYJD20:VYZ@80/K6a
0P2f][H20;fm_@80_kno0P38b<P00`34a<@0`/;20<;2`P020:f][@80X:2P0P2IVIT209RHV080Vi^K
0P2XZ:P20;Fe]@80^[Zj0P30`<020;no_`80b/[:0P39bLT20;Ng]`80WYjN0P21PH4206][J`80LG5a
0P1kNg/20820P080R8R80P2DU9@2096AT@80Vi^K0P2JVYX00`2DU9@0Shn?08n?S`0208^;R`80Shn?
0P2KVi/20:RXZ080YJFU0P2PX:0209FEU@80S8b<0P24Q8@207emO@80LW9b0P1dM7@205MGE`80FEUI
0P1?Cdl204U9B@80BTY:1013@d<20492@P80ADE50P19BDT205IFEP80HF5Q00<0MGEe08b<S02<S8`0
0P2HV9P20::RXP80YZJV0P2[Zj/20:VYZ@80Zj^[0P2YZJT20:NWY`80[Zj^0P2/[:`20:f][Ah0b>3H
000L0<SPf0@092@T0P0X:2P203Ph>080ATI60P1`L70205EEE@80AdM70P0f=SH20410@080Bd];0P1J
FUX00`16ATH0C4a<04a<C00204i>CP80G5aL0P16ATH202l_;`80=CDe0P0l?3`202@T90809BDU100W
9bL202PX:0809RHV0P0U9BD202TY:@80<S8b0P0W9bL204E5A@80H61P0P1/K6`208J6QP80EUIF0P0T
92@202d];@80CTi>00<0EeMG02LW9`0W9bL00P0^;Rh2020P80807AdM0P0W9bL203lo?`80Lg=c0P2Q
XJ4209bLW080RHV90P1aLG4206YZJP80Shn?0P2h^;P20;Vi^@80/K6a0P2ZZZX20:BTY080ZZZZ0P2c
/k<20;Ng]`80^k^k0P31`L430<G5a@80`<300P2_[jl209jNWP@0UiNG0P2OWil20:ZZZP80/[:b0P2i
^KT20<30`080`l?31039bLT20;Ng]`80WYjN0P1oOgl206QXJ080KVi^0P1mOGd208B4Q080Rh^;0P2A
TI4209FEU@@0V9RH00<0U9BD08n?S`2?Shl00P2=SHd208n?S`80VYZJ0P2UYJD20:BTY080WinO0P2F
UYH208b<S080QHF50P1kNg/207EeM@80M7Ad0P1FEUH205YJFP80DU9B0P1=CDd204Q8B080A4A41012
@T8204E5A@80BTY:0P1EEED206ATI00307MgM`2:RXX0RXZ:0080V9RH0P2RXZ820:RXZ0@0Zj^[1P2Y
ZJT20:ZZZP80[:b/0P2][JdW0<SPf0809RHV0P0T92@202l_;`80<c<c0P15ADD2065QH@80C4a<0P16
ATH203`l?080=cLg0P0m?Cd206=SH`80ATI60P0o?cl205]KF`0305aLG013@d<0@d=300809bLW0P0e
=CD203/k>`@0:BTY0P0X:2P202/[:`809bLW0P0U9BD202TY:@808b<S0P0];Bd203<c<`80Cdm?0P1O
Gel206IVIP80MWIf0P1DE5@202HV9P80;Bd]0P1KFe/205UIF@80;Rh^0P0Z:RX201lO7`807AdM0P0T
92@203Ti>@80MGEe0P2JVYX00`2WYjL0R8R808R8R00206i^KP80J6QX0P2?Shl20;Ng]`80`l?30P2/
[:`20:NWY`80ZZZZ0P2][Jd40;Bd]080_[jn0P32`/820<K6aP80alO70P2o_kl20:b/[080Xj>S102F
UYH20:6QX@80ZJVY0P2c/k<20;bl_080_[jn0P34a<@20<G5a@80alO70P31`L420:^[Z`0307alO01d
M7@0M7Ad0080N7Qh0P1jNWX208J6QP80RHV90P2>SXh209NGU`80VIVI0P2JVYX209FEU@80SXj>0P1k
Ng/209JFUP80WIfM0P2OWil20:>SX`80X:2P0P2JVYX208^;R`80QHF5101nOWh207=cL`@0HF5Q0P1F
EUH205=CD`@0B4Q80P14A4@303lo?`80@D510P1?Cdl205]KF`80NGUi0P28R8P209FEU@80XJ6Q0P2W
YjL20:^[Z`80YjNW0P2[Zj/20:BTY080YjNW102[Zj/20:f][BL0b>3H0P0P820202<S8`80:BTY0P0j
>SX204M7A`80Kfm_0P1GEeL204M7A`80=CDe0P11@D4204Y:BP80FUYJ00<0@d=304U9B@19BDT00P1?
Cdl205]KF`80ATI60P0`<30203<c<`80>c/k0P0T92@202DU9@808b<S0P0X:2P202LW9`80:2PX0P0S
8b<202/[:`80<S8b0P0Y:BT204Q8B080H61P0P1YJFT20861P@80EeMG0P0X:2P2030`<080Bd];00<0
FUYJ02<S8`0S8b<00P0];Bd2028R8P8071`L0P0X:2P203hn?P80M7Ad0P2NWYh209^KV`80QhN70P1`
L70206QXJ080TY:B0P2l_;`20;Rh^080][Jf0P2YZJT20:FUY@80ZJVY0P2a/K420;Jf]P80_Kfm0P2o
_kl20<S8b0030<C4a032`/80`/;20080[Jf]0P2PX:0209VIV@80V9RH0P2KVi/20:RXZ080]KFe0P2j
^[X20<30`080_kno0P3:b/X20<W9b@80]kNg0P2NWYh20861P@80Jf][0P1aLG4207]kN`80P8200P28
R8P209BDU080TI6A0P2KVi/209ZJVP0309BDU02?Shl0Shn?0080Rh^;0P2?Shl209^KV`80Z:RX0P2U
YJD20:2PX080UIFE0P2<S8`208B4Q080OGem0P1bLW8207AdM080EeMG0P1IFET204m?C`80BDU90P1:
BTX404=3@`80@T920P15ADD204U9B@80EUIF0P1QHF400`1eMGD0S8b<08b<S00209RHV080XZ:R0P2V
YZH20:^[Z`80ZJVY0P2[Zj/20:VYZ@80YjNW0P2^[Zh20:b/[080[Jf]7P38h=P001`0b>3H100V9RH2
02LW9`@0:2PX0P1ADE4203`l?080?Shn100j>SX203@d=080BDU900<08b<S03Ti>@0i>CT00P17AdL2
05aLG080;2`/0P0_;bl202XZ:P80B4Q80P0U9BD202LW9`809RHV0P0W9bL202PX:0809BDU0P0T92@2
02PX:080<S8b0P1ADE4206QXJ080HV9R0P0g=cL206IVIP80FUYJ0P0`<30203@d=080EeMG00<0ADE5
02PX:00X:2P00P0m?Cd202d];@808R8R0P0N7Qh202PX:080FEUI0P2:RXX209RHV080UIFE0P1eMGD2
05eMG@80N7Qh0P2MWId20;Bd]080_kno0P2_[jl209fMW@80YZJV0P2b/[820;Jf]P80^;Rh0P2m_Kd2
0<71`@030<G5a@34a<@0a<C40080][Jf0P2VYZH209ZJVP80U9BD0P2KVi/20:FUY@80[Jf]0P2d];@2
0;Vi^@80_Kfm0P31`L420<C4a080alO70P34a<@20:f][@80U9BD0P20P80207AdM080Ogmo0P2?Shl2
09:BTP80Ti>C0P2HV9P209bLW00309NGU`2CTi<0Ti>C0080UiNG0P2MWId209jNWP80WIfM0P2KVi/2
09NGU`80SXj>0P24Q8@207UiN@80KVi^0P1SHf<205UIF@80De=C0P1;Bd/204M7A`80A4A40P10@402
03dm?@80?clo0P14A4@204a<C080EeMG0P1[Jf/20820P00309:BTP2QXJ40XJ6Q0080ZJVY102][Jd2
0:ZZZP80Zj^[0P2/[:`20:ZZZP80ZJVY0P2[Zj/20:f][@80[Zj^9`38h=P202DU9@80:2PX100W9bL2
03<c<`80CDe=0P0o?cl20492@P80>SXj0P0[:b/203dm?@80De=C0P0Z:RX203<c<`80BTY:00<0E5AD
03@d=00d=3@00P0Y:BT203Hf=P80?Shn0P0Z:RX202PX:0808b<S0P0/;2`202TY:@80820P0P0X:2P2
02TY:@80=3@d0P1@D50206IVIP80FEUI0P0m?Cd206UYJ@80HF5Q0P0U9BD203<c<`80GEeM0P0j>SX2
02d];@80?Shn0P0R8R8202PX:0809bLW0P0Z:RX2051@D080QHF500<0XZ:R092@T02@T9000P1bLW82
06ATI080Lg=c0P2JVYX20;no_`80_Kfm0P2VYZH209jNWP80ZZZZ0P2`/;020;:b/P80^;Rh0P2k^k/2
0<71`@80a/K60P34a<@20;>c/`80YZJV0P2KVi/209BDU080W9bL0P2UYJD20:RXZ080/[:b0P2k^k/2
0;fm_@80`<300P35aLD20<?3``80_Kfm00<0/K6a08R8R028R8P00P1fMWH207UiN@80Ph>30P2;Rh/4
096AT@80V9RH102IVIT209RHV080TY:B0P2MWId20::RXP80Vi^K0P2FUYH209FEU@80Shn?0P21PH42
07YjNP80KFe]0P1PH60205eMG@80DU9B0P16ATH204e=C@80@d=30P11@D4203lo?`80>CTi0P16ATH0
0`1?Cdl0FEUI05UIF@0206MWI`80PH610P2FUYH20:2PX080ZJVY0P2_[jl20:^[Z`80ZZZZ0P2][Jd2
0:^[Z`80Z:RX0P2[Zj/20:ZZZP80Zj^[0P2`/;0W0<SPf0809BDU0P0W9bL202DU9@80:BTY0P0X:2P2
04e=C@80>c/k0P0m?Cd203Xj>P80?Cdm0P0a<C4204];B`0302DU9@0h>3P0>3Ph0080B4Q80P1LG5`2
02XZ:P80<30`0P0Y:BT204E5A@@09BDU0P0W9bL2024Q8@80:2PX0P0W9bL202<S8`80:2PX0P0c<c<2
05ADE080IfMW0P1PH60203Xj>P80J6QX0P1IFET2034a<@80<c<c0P1DE5@00`15ADD0:2PX02PX:002
03/k>`80<C4a0P0Q8B42020P8080:BTY0P1HF5P208Z:RP80VYZJ0P2GUiL2075aL@80GUiN0P1hN7P2
09bLW080];Bd0P30`<020:j^[P80WYjN0P2UYJD20;:b/P80]KFe0P2g]kL20;fm_@80`/;20`36a/H2
0;Jf]P80YjNW0P2HV9P209FEU@80VYZJ0P2VYZH20:b/[080/K6a0P2j^[X20;jn_P80`L710P33`l<2
0<S8b080`/;20P2/[:`2096AT@80P8200P1dM7@20861P@80T92@0P2DU9@209:BTP80VIVI0P2LW9`0
0`2FUYH0UIFE09FEU@0209NGU`80WYjN102MWId209VIV@80UiNG0P2=SHd208J6QP80NWYj0P1`L702
069RHP80FUYJ0P1CDe<204Y:BP80BDU90P14A4@20451@@@0?Cdm0P14A4@204];B`80E5AD0P1^KVh2
07moO`0309BDU02QXJ40XJ6Q0080Z:RX0P2][Jd20;6a/@80[Jf]0P2XZ:P20:b/[0@0ZJVY0P2[Zj/2
0:j^[P80Zj^[7P38h=P001`0b>3H100V9RH202LW9`@0:2PX0P1ADE4203`l?080?Shn100j>SX203@d
=080BDU900<08b<S03Ti>@0i>CT00P17AdL205aLG080;2`/0P0_;bl202XZ:P80B4Q80P0U9BD202LW
9`809RHV0P0W9bL202PX:0809BDU0P0T92@202PX:080<S8b0P1ADE4206QXJ080HV9R0P0g=cL206IV
IP80FUYJ0P0`<30203@d=080EeMG00<0ADE502PX:00X:2P00P0m?Cd202d];@808R8R0P0N7Qh202PX
:080FEUI0P2:RXX209RHV080UIFE0P1eMGD205eMG@80N7Qh0P2MWId20;Bd]080_kno0P2_[jl209fM
W@80YZJV0P2b/[820;Jf]P80^;Rh0P2m_Kd20<71`@030<G5a@34a<@0a<C40080][Jf0P2VYZH209ZJ
VP80U9BD0P2KVi/20:FUY@80[Jf]0P2d];@20;Vi^@80_Kfm0P31`L420<C4a080alO70P34a<@20:f]
[@80U9BD0P20P80207AdM080Ogmo0P2?Shl209:BTP80Ti>C0P2HV9P209bLW00309NGU`2CTi<0Ti>C
0080UiNG0P2MWId209jNWP80WIfM0P2KVi/209NGU`80SXj>0P24Q8@207UiN@80KVi^0P1SHf<205UI
F@80De=C0P1;Bd/204M7A`80A4A40P10@40203dm?@80?clo0P14A4@204a<C080EeMG0P1[Jf/20820
P00309:BTP2QXJ40XJ6Q0080ZJVY102][Jd20:ZZZP80Zj^[0P2/[:`20:ZZZP80ZJVY0P2[Zj/20:f]
[@80[Zj^9`38h=P202DU9@80:2PX100W9bL203<c<`80CDe=0P0o?cl20492@P80>SXj0P0[:b/203dm
?@80De=C0P0Z:RX203<c<`80BTY:00<0E5AD03@d=00d=3@00P0Y:BT203Hf=P80?Shn0P0Z:RX202PX
:0808b<S0P0/;2`202TY:@80820P0P0X:2P202TY:@80=3@d0P1@D50206IVIP80FEUI0P0m?Cd206UY
J@80HF5Q0P0U9BD203<c<`80GEeM0P0j>SX202d];@80?Shn0P0R8R8202PX:0809bLW0P0Z:RX2051@
D080QHF500<0XZ:R092@T02@T9000P1bLW8206ATI080Lg=c0P2JVYX20;no_`80_Kfm0P2VYZH209jN
WP80ZZZZ0P2`/;020;:b/P80^;Rh0P2k^k/20<71`@80a/K60P34a<@20;>c/`80YZJV0P2KVi/209BD
U080W9bL0P2UYJD20:RXZ080/[:b0P2k^k/20;fm_@80`<300P35aLD20<?3``80_Kfm00<0/K6a08R8
R028R8P00P1fMWH207UiN@80Ph>30P2;Rh/4096AT@80V9RH102IVIT209RHV080TY:B0P2MWId20::R
XP80Vi^K0P2FUYH209FEU@80Shn?0P21PH4207YjNP80KFe]0P1PH60205eMG@80DU9B0P16ATH204e=
C@80@d=30P11@D4203lo?`80>CTi0P16ATH00`1?Cdl0FEUI05UIF@0206MWI`80PH610P2FUYH20:2P
X080ZJVY0P2_[jl20:^[Z`80ZZZZ0P2][Jd20:^[Z`80Z:RX0P2[Zj/20:ZZZP80Zj^[0P2`/;0W0<SP
f0809BDU0P0W9bL202DU9@80:BTY0P0X:2P204e=C@80>c/k0P0m?Cd203Xj>P80?Cdm0P0a<C4204];
B`0302DU9@0h>3P0>3Ph0080B4Q80P1LG5`202XZ:P80<30`0P0Y:BT204E5A@@09BDU0P0W9bL2024Q
8@80:2PX0P0W9bL202<S8`80:2PX0P0c<c<205ADE080IfMW0P1PH60203Xj>P80J6QX0P1IFET2034a
<@80<c<c0P1DE5@00`15ADD0:2PX02PX:00203/k>`80<C4a0P0Q8B42020P8080:BTY0P1HF5P208Z:
RP80VYZJ0P2GUiL2075aL@80GUiN0P1hN7P209bLW080];Bd0P30`<020:j^[P80WYjN0P2UYJD20;:b
/P80]KFe0P2g]kL20;fm_@80`/;20`36a/H20;Jf]P80YjNW0P2HV9P209FEU@80VYZJ0P2VYZH20:b/
[080/K6a0P2j^[X20;jn_P80`L710P33`l<20<S8b080`/;20P2/[:`2096AT@80P8200P1dM7@20861
P@80T92@0P2DU9@209:BTP80VIVI0P2LW9`00`2FUYH0UIFE09FEU@0209NGU`80WYjN102MWId209VI
V@80UiNG0P2=SHd208J6QP80NWYj0P1`L702069RHP80FUYJ0P1CDe<204Y:BP80BDU90P14A4@20451
@@@0?Cdm0P14A4@204];B`80E5AD0P1^KVh207moO`0309BDU02QXJ40XJ6Q0080Z:RX0P2][Jd20;6a
/@80[Jf]0P2XZ:P20:b/[0@0ZJVY0P2[Zj/20:j^[P80Zj^[7P38h=P001`0b>3H0P0U9BD202LW9`H0
:BTY0P10@40203/k>`80A4A40P16ATH20451@@80>3Ph0P12@T800`0_;bl0?Shn03hn?P0204Q8B080
C4a<0P0[:b/202h^;P80;2`/0P0n?Sh202h^;P80;2`/0P0X:2P202TY:@80:b/[100W9bL203Ph>080
ATI60P1^KVh206MWI`8092@T0P0U9BD204];B`80G5aL0P0[:b/204U9B@80Fe]K00<0=3@d02DU9@0U
9BD00P1;Bd/203@d=0807QhN0P0L71`202HV9P80@T920P1TI6@208V9R@80VYZJ0P2?Shl205iNGP80
IVIV0P1iNGT209bLW080^k^k0P2c/k<20:FUY@80Z:RX0P2][Jd20;6a/@80]KFe0P2i^KT20;bl_003
0<?3``35aLD0aLG50080_;bl0P2_[jl20:6QX@80UYJF0P2HV9P209nOW`80YZJV0P2_[jl20;Ng]`80
_Kfm0P30`<020<71`@80a/K60P37alL20;fm_@80[Jf]0P2EUID20861P@80OGem0P1oOgl208J6QP80
SXj>0P2DU9@209^KV`0309RHV02CTi<0Ti>C0080UYJF0P2GUiL209:BTP80Rh^;0P28R8P208B4Q080
O7al0P1bLW8206MWI`80G5aL0P1?Cdl204E5A@80AdM70P15ADD204A4A080@d=30P18B4P204m?C`80
EEEE0P1MGEd206][J`80O7al0P2:RXX209NGU`030:>SX`2/[:`0[:b/00P0[jn_0P2`/;020;6a/@80
[Zj^102/[:`20:f][@80[Zj^9`38h=P2024Q8@80:2PX0P0W9bL202HV9P80:RXZ0P0l?3`204a<C080
@T920P1>CTh204a<C080>c/k0P0e=CD202TY:@80>c/k0P1?Cdl00`18B4P0=CDe03De=@02030`<080
:b/[0P0l?3`202d];@@09bLW0P0X:2P202XZ:P809bLW0P0Z:RX202h^;P80BTY:0P1]KFd2061PH080
<c<c0P0X:2P204i>CP80Hf=S0P0X:2P204];B`80G5aL0P0[:b/203Hf=P80CTi>0P0X:2P2028R8P80
7AdM0P0_;bl203Xj>P80KVi^00<0SHf=09jNWP2NWYh00P21PH4206EUI@80HV9R0P1iNGT209^KV`80
_kno0P2a/K420:6QX@80Zj^[0P2_[jl20;2`/080]kNg0P2i^KT20;Zj^P80`l?30P37alL20;fm_@80
[jn_0P2KVi/209NGU`80VYZJ0P2LW9`20:^[Z`80[:b/0P2l_;`20;fm_@80^[Zj0P36a/H40<?3``03
0<30`02i^KT0^KVi0080TY:B0P1kNg/207emO@80Q8B40P29RHT208n?S`80UYJF0P2LW9`409JFUP@0
UiNG0P2DU9@2096AT@80S8b<0P24Q8@207emO@80M7Ad0P1XJ6P205aLG080Bd];0P13@d<203/k>`80
ATI6100m?Cd204A4A080C4a<0P1HF5P205iNGP03075aL@24Q8@0Q8B40080SHf=0P2KVi/20:NWY`80
ZJVY0P2_[jl20;2`/080[Jf]0P2_[jl20;Fe]@80/K6a0P2^[Zh20:b/[0@0[Zj^0P2a/K4W0<SPf080
9bLW100Y:BT202PX:080:b/[0P12@T8203lo?`80A4A40P15ADD20451@@80>CTi0P0o?cl00`0^;Rh0
@T920492@P0204Q8B080Bd];0P0];Bd4030`<080?clo0P0b<S82030`<080;Bd]0P0/;2`202/[:`80
9bLW0P0V9RH203Ph>080@4100P1[Jf/206IVIP@09RHV0P18B4P205]KF`80:b/[0P1:BTX205]KF`03
03Hf=P0W9bL09bLW0080BTY:0P0e=CD401/K6`8092@T0P15ADD206IVIP80QhN70P2JVYX208n?S`80
HV9R0P1UIFD207QhN080WIfM0P2h^;P20;:b/P80Y:BT0P2^[Zh20:n_[`80/;2`0P2f][H20;Vi^@80
^k^k00<0`<300<G5a@35aLD00P2h^;P20;2`/080WYjN0P2IVIT209NGU`80XZ:R0P2WYjL20;2`/080
^[Zj0P2l_;`20<71`@80`/;20P37alL20<S8b080_kno0P2][Jd209>CT`80PH610P1nOWh207alO080
QHF50P2?Shl2096AT@80VIVI00<0UiNG096AT@2ATI400P2HV9P209FEU@80TY:B0P2;Rh/208N7Q`80
QXJ60P1jNWX2075aL@80I6AT0P1JFUX204m?C`80B4Q80P16ATH204M7A`80A4A40P13@d<204U9B@80
Cdm?0P1EEED205eMG@80KVi^0P1lO7`208f=S@80UYJF00<0Xj>S0:^[Z`2[Zj/00P2[Zj/40;2`/080
[:b/0P2_[jl20;Bd]0P0[Jf]0P2[Zj/N0<SPf0007038h=P202DU9@809bLW1P0Y:BT20410@080>c/k
0P14A4@204I6AP80@D510P0h>3P20492@P0302l_;`0n?Sh0?Shn0080B4Q80P1<C4`202/[:`80;Rh^
0P0/;2`203hn?P80;Rh^0P0/;2`202PX:080:BTY0P0[:b/402LW9`80>3Ph0P16ATH206i^KP80IfMW
0P0T92@202DU9@80Bd];0P1LG5`202/[:`80BDU90P1KFe/00`0d=3@09BDU02DU9@0204];B`80=3@d
0P0N7Qh201`L70809RHV0P12@T8206ATI080RHV90P2JVYX208n?S`80GUiN0P1VIVH207UiN@80W9bL
0P2k^k/20;>c/`80YJFU0P2XZ:P20:f][@80/K6a0P2e]KD20;Vi^@80_;bl00<0`l?30<G5a@35aLD0
0P2l_;`20:n_[`80XJ6Q0P2FUYH209RHV080WinO0P2VYZH20:n_[`80]kNg0P2m_Kd20<30`080`L71
0P36a/H20<O7a`80_Kfm0P2][Jd209FEU@80PH610P1mOGd207moO`80QXJ60P2>SXh209BDU080Vi^K
00<0V9RH09>CT`2CTi<00P2FUYH209NGU`80TY:B0P2;Rh/208R8R080Q8B40P1lO7`2079bLP80IfMW
0P1LG5`204m?C`80ADE50P17AdL204E5A@80A4A40P13@d<204Q8B080Cdm?0P1EEED205eMG@80Jf][
0P1lO7`208Z:RP80UiNG00<0Xj>S0:b/[02/[:`0202_[jl20;2`/080/K6a0P2^[Zh40:b/[080[Jf]
0P2^[ZhW0<SPf0808B4Q0P0X:2P202LW9`809RHV0P0Z:RX203`l?080C4a<0P12@T8204i>CP80C4a<
0P0k>c/203De=@80:BTY0P0k>c/204m?C`0304Q8B00e=CD0=CDe0080<30`0P0[:b/203`l?080;Bd]
100W9bL202PX:080:RXZ0P0W9bL202XZ:P80;Rh^0P1:BTX206e]K@80H61P0P0c<c<202PX:080CTi>
0P1SHf<202PX:080Bd];0P1LG5`202/[:`80=SHf0P1>CTh202PX:0808R8R0P0M7Ad202l_;`80>SXj
0P1^KVh00`2=SHd0WYjN09jNWP020861P@80IFEU0P1RHV8207UiN@80Vi^K0P2o_kl20;6a/@80XJ6Q
0P2[Zj/20:n_[`80/;2`0P2g]kL20;Vi^@80^[Zj0P33`l<20<O7a`80_Kfm0P2_[jl209^KV`80UiNG
0P2JVYX209bLW080Zj^[0P2/[:`20;bl_080_Kfm0P2j^[X20<K6aP@0`l?300<0`<300;Vi^@2i^KT0
0P2BTY8207]kN`80OGem0P24Q8@208V9R@80Shn?0P2FUYH209bLW0@0UYJF102GUiL209BDU080TI6A
0P2<S8`208B4Q080OGem0P1dM7@206QXJ080G5aL0P1;Bd/204=3@`80>c/k0P16ATH403dm?@80A4A4
0P1<C4`205QHF080GUiN00<0LG5a08B4Q024Q8@00P2=SHd209^KV`80YjNW0P2YZJT20:n_[`80/;2`
0P2][Jd20:n_[`80]KFe0P2a/K420:j^[P80[:b/102^[Zh20;6a/BL0b>3H0P0W9bL402TY:@80:2PX
0P0[:b/20492@P80?clo0P14A4@204E5A@80@D510P0i>CT203lo?`0302h^;P12@T80@T920080B4Q8
0P1;Bd/202d];@@0<30`0P0o?cl2038b<P80<30`0P0];Bd202`/;080:b/[0P0W9bL202HV9P80>3Ph
0P10@40206][J`80IVIV100V9RH204Q8B080Fe]K0P0[:b/204Y:BP80Fe]K00<0=SHf02LW9`0W9bL0
0P1:BTX203De=@@06a/K0P0T92@204E5A@80IVIV0P27QhL209ZJVP80Shn?0P1RHV8206EUI@80N7Qh
0P2MWId20;Rh^080/[:b0P2TY:@20:j^[P80[jn_0P2`/;020;Jf]P80^KVi0P2k^k/00`30`<00aLG5
0<G5a@020;Rh^080/;2`0P2NWYh209VIV@80UiNG0P2RXZ820:NWY`80/;2`0P2j^[X20;bl_080`L71
0P32`/820<O7a`80b<S80P2o_kl20:f][@80Ti>C0P21PH4207inOP80O7al0P25QHD208n?S`80TI6A
0P2IVIT00`2GUiL0TI6A096AT@0209RHV080UIFE0P2BTY8208^;R`80QhN70P26QXH207YjNP80LG5a
0P1TI6@205YJFP80Cdm?0P18B4P204I6AP80AdM70P14A4@204=3@`80BDU90P1?Cdl205EEE@80GEeM
0P1^KVh207alO080SHf=0P2FUYH00`2SXj<0Zj^[0:^[Z`020:^[Z`@0/;2`0P2/[:`20:n_[`80];Bd
202][Jd20:^[Zah0b>3H000L0<SPf08092@T0P0Y:BT202h^;P80:RXZ0P0X:2P202`/;080=SHf0P15
ADD204m?C`80A4A40P0g=cL203@d=00303Ph>012@T80@T920080BDU90P0k>c/202l_;`80;Bd]0P0_
;bl2038b<P80=SHf0P0`<30202/[:`80;2`/0P0_;bl202XZ:P80:BTY0P16ATH205YJFP80Lg=c0P13
@d<204Y:BP80=CDe0P16ATH205aLG0809RHV0P1MGEd205UIF@0302HV9P0S8b<08b<S0080EUIF0P0i
>CT201`L70807QhN0P0Y:BT202l_;`80?Cdm0P1aLG4209NGU`80YZJV0P1YJFT205eMG@80FUYJ0P22
PX820:^[Z`80/k>c0P2`/;020:f][@80ZJVY0P2][Jd20;:b/P80];Bd0P2g]kL00`2o_kl0aLG50<G5
a@020<30`080][Jf0P2WYjL209ZJVP80UiNG0P2JVYX20:6QX@80ZZZZ0P2d];@20;fm_@@0_[jn0P2o
_kl20<71`@@0alO70P2][Jd2096AT@80PH610P1hN7P207]kN`80Ph>30P2:RXX209:BTP03096AT@2>
SXh0SXj>0080S8b<0P29RHT20861P@80N7Qh0P1dM7@2071`L080JVYZ0P1SHf<205QHF080CTi>0P13
@d<203`l?080@D511019BDT204a<C080FUYJ0P1YJFT2079bLP80O7al0P2?Shl20:2PX080YjNW0P2[
Zj/00`2`/;00/k>c0;>c/`020;6a/@80[jn_0P2`/;020;>c/`80];Bd0P2e]KD20;:b/P80/;2`0P2^
[Zh40:f][BL0b>3H0P0T92@202/[:`80=3@d0P0S8b<202XZ:P80=3@d0P0e=CD203`l?080EUIF0P12
@T82038b<P80>c/k0P0d=3@204M7A`80ATI600<0>CTi02l_;`0_;bl00P0Z:RX202`/;080>SXj0P0g
=cL202l_;`80<S8b0P0[:b/4030`<080;2`/0P12@T82061PH080J6QX0P1>CTh204I6AP80<S8b0P0l
?3`2061PH080;Rh^0P1KFe/205=CD`809BDU0P0];Bd205EEE@80<C4a0P0O7al202LW9`809BDU0P0S
8b<203hn?P0307EeM@2GUiL0UiNG0080WinO0P1^KVh205]KF`80H61P0P1kNg/20:ZZZP80^KVi0P2^
[Zh20:JVYP80[Jf]0P2/[:`20;Bd]080/[:b0P2h^;P20<30`080`/;20P34a<@20;Fe]@80YJFU0P2J
VYX209bLW080V9RH0P2OWil20:RXZ080][Jf0P2l_;`20;^k^`80_Kfm0P32`/820<?3``030<;2`P31
`L40`L710080^[Zj0P2IVIT207UiN@80MWIf0P1jNWX208:2PP80RHV90P2@T90208b<S080SXj>0P2=
SHd208V9R@80Ogmo0P1iNGT207EeM@80KVi^0P1[Jf/206ATI080Fe]K0P1@D50403lo?`80A4A40P17
AdL204U9B@80Bd];0P1IFET206YZJP80Kfm_0P1jNWX00`2=SHd0WYjN09jNWP020:FUY@80Z:RX0P2`
/;020;>c/`80/;2`0P2_[jl20;6a/@80/k>c0P2d];@20;>c/`80];Bd0P2`/;060:b/[2L0b>3H0P0N
7Qh202/[:`80;Bd]100X:2P202`/;080=CDe0P14A4@204e=C@80ATI60P0h>3P2034a<@0303Ti>@14
A4@0A4A40080B4Q80P0l?3`202h^;P80;2`/0P0];Bd2034a<@80=3@d0P0a<C4202PX:080:b/[100]
;Bd202LW9`80A4A40P1MGEd207EeM@80@T920P1:BTX203Hf=P80A4A40P1NGUh202LW9`80G5aL0P1H
F5P00`0U9BD08b<S02<S8`0205IFEP80>SXj100N7Qh202PX:080<c<c0P0l?3`206m_K`80UiNG0P2W
YjL206IVIP80GUiN0P1JFUX208>3P`80ZZZZ0P2g]kL40:j^[P80[:b/0P2VYZH20;Jf]P80/k>c0P2i
^KT00`2o_kl0b<S80<S8b0020;jn_P80^[Zj0P2TY:@209VIV@80UiNG0P2IVIT20:2PX080YjNW0P2e
]KD20;bl_080_kno0P2m_Kd40<30`0@0aLG50P2b/[82096AT@80Ph>30P1hN7P207emO@80QHF50P28
R8P209BDU00309:BTP2=SHd0SHf=0080SXj>0P2;Rh/207moO`80NWYj0P1iNGT206i^KP80JVYZ0P1U
IFD205YJFP80D51@0P11@D440410@080BTY:101;Bd/205QHF080JFUY0P1`L70207alO080T92@0P2O
Wil20:JVYP80ZZZZ00<0/K6a0;Bd]02d];@00P2c/k<20;2`/080[Zj^0P2f][H20;:b/P80][Jf102a
/K420:f][@80[jn_0P2][JdN0<SPf0007038h=P202@T9080:BTY0P0^;Rh202XZ:P80:2PX0P0/;2`2
03Hf=P80ADE50P1?Cdl204A4A080=cLg0P0d=3@00`0h>3P0@T920492@P0204U9B@80>c/k0P0_;bl2
02d];@80;bl_0P0b<S8203Hf=P80<30`0P0[:b/202`/;080;bl_0P0Z:RX202TY:@80ATI60P1JFUX2
07=cL`80@d=30P1:BTX203De=@80ATI60P1LG5`202HV9P80GEeM0P1IFET00`0V9RH08b<S02<S8`02
05IFEP80>CTi0P0L71`201hN7P80:BTY0P0_;bl203dm?@80LG5a0P2GUiL20:JVYP80JFUY0P1MGEd2
05YJFP80PX:20P2[Zj/20;>c/`80/;2`0P2][Jd20:VYZ@80[Jf]0P2b/[820;Bd]080]kNg00<0_kno
0<G5a@35aLD00P30`<020;Jf]P80YjNW0P2JVYX209NGU`80VYZJ0P2QXJ420:ZZZP80];Bd0P2m_Kd4
0;jn_P80_kno0P31`L440<O7a`80[Jf]0P2ATI420861P@80N7Qh0P1kNg/208>3P`80RXZ:0P2BTY80
0`2ATI40SXj>08j>SP0208b<S080RHV90P21PH4207QhN080M7Ad0P1`L70206YZJP80Hf=S0P1HF5P2
04i>CP80@d=30P0l?3`20451@@@0BDU90P1<C4`205YJFP80JFUY0P1bLW8207alO080Shn?0P2PX:02
0:NWY`80Zj^[00<0/;2`0;>c/`2c/k<00P2a/K420:n_[`80/;2`0P2c/k<20;Bd]080]KFe0P2b/[82
0;2`/080[Zj^102][JdW0<SPf08092@T0P0[:b/203@d=0808b<S0P0Z:RX203@d=080=CDe0P0l?3`2
05IFEP80@T920P0b<S8203/k>`80=3@d0P17AdL204I6AP0303Ti>@0_;bl0;bl_0080:RXZ0P0/;2`2
03Xj>P80=cLg0P0_;bl2038b<P80:b/[100`<30202`/;080@T920P1PH60206QXJ080CTi>0P16ATH2
038b<P80?3`l0P1PH60202h^;P80Fe]K0P1CDe<202DU9@80;Bd]0P1EEED2034a<@807alO0P0W9bL2
02DU9@808b<S0P0n?Sh00`1eMGD0UiNG09NGU`0209nOW`80KVi^0P1KFe/2061PH080Ng]k0P2ZZZX2
0;Vi^@80[Zj^0P2VYZH20:f][@80[:b/0P2d];@20;:b/P80^;Rh0P30`<020<;2`P80a<C40P2e]KD2
0:FUY@80VYZJ0P2LW9`209RHV080WinO0P2XZ:P20;Jf]P80_;bl0P2k^k/20;fm_@80`/;20P33`l<0
0`32`/80`L710<71`@020;Zj^P80VIVI0P1iNGT207IfMP80NWYj0P22PX8208V9R@80T92@0P2<S8`2
08j>SP80SHf=0P29RHT207moO`80NGUi0P1eMGD206i^KP80Jf][0P1TI6@205]KF`80D51@100o?cl2
04A4A080AdM70P19BDT204];B`80FEUI0P1ZJVX206m_K`80NWYj00<0SHf=09jNWP2NWYh00P2UYJD2
0:RXZ080/;2`0P2c/k<20;2`/080[jn_0P2a/K420;>c/`80];Bd0P2c/k<20;Bd]080/;2`1P2/[:`W
0<SPf0807QhN0P0[:b/202d];@@0:2PX0P0/;2`203De=@80A4A40P1=CDd204I6AP80>3Ph0P0a<C40
0`0i>CT0A4A404A4A00204Q8B080?3`l0P0^;Rh202`/;080;Bd]0P0a<C4203@d=080<C4a0P0X:2P2
02/[:`@0;Bd]0P0W9bL204A4A080GEeM0P1eMGD20492@P80BTY:0P0f=SH204A4A080GUiN0P0W9bL2
05aLG080F5QH00<09BDU02<S8`0S8b<00P1FEUH203Xj>P@07QhN0P0X:2P203<c<`80?3`l0P1_Kfl2
09NGU`80YjNW0P1VIVH205iNGP80FUYJ0P23Ph<20:ZZZP80]kNg102^[Zh20:b/[080YZJV0P2f][H2
0;>c/`80^KVi00<0_kno0<S8b038b<P00P2n_[h20;Zj^P80Y:BT0P2IVIT209NGU`80VIVI0P2PX:02
0:NWY`80]KFe0P2l_;`20;no_`80_Kfm1030`<040<G5a@80/[:b0P2ATI4208>3P`80N7Qh0P1mOGd2
08F5Q@80R8R80P2DU9@00`2BTY80SHf=08f=S@0208j>SP80Rh^;0P1oOgl207YjNP80NGUi0P1^KVh2
06YZJP80IFEU0P1JFUX2051@D080@D511010@40204Y:BP@0Bd];0P1HF5P206UYJ@80L71`0P1lO7`2
092@T080WinO0P2VYZH20:ZZZP030;6a/@2d];@0];Bd0080/k>c0P2`/;020:j^[P80][Jf0P2b/[82
0;Jf]P@0/K6a0P2][Jd20:n_[`80[Jf]7P38h=P001`0b>3H0P0R8R8202`/;080=SHf0P0_;bl202PX
:080:b/[0P0e=CD203/k>`80?clo0P0h>3P2038b<P80<c<c0`0k>c/203lo?`80<c<c0P0^;Rh202`/
;080;Rh^0P0b<S8203Xj>P80<c<c0P0[:b/202`/;080<S8b0P11@D42051@D080B4Q80P1EEED205MG
E`80>3Ph0P0g=cL203De=@80=cLg0P1PH60203Lg=`80IFEU0P1?Cdl00`0Y:BT0:2PX02PX:00205mO
G`80?Shn0P0P820201dM7@808b<S0P0Q8B4202/[:`80BTY:0P27QhL209jNWP80QXJ60P1/K6`205MG
E`80Jf][0P2:RXX20:JVYP80^[Zj0P2d];@20:VYZ@80ZZZZ0P2^[Zh20;2`/080/k>c00<0^k^k0<71
`@31`L400P30`<020;Zj^P80ZZZZ0P2KVi/209RHV080VYZJ0P2MWId20:>SX`80[jn_0P2k^k/20;jn
_P80_kno0P31`L420<?3``@0aLG50P3=cLd20<W9b@80WYjN0P1`L70206EUI@80IVIV0P1^KVh2075a
L@0307IfMP1iNGT0NGUi0080N7Qh0P1dM7@206m_K`80JVYZ0P1WIfL206ATI080Hf=S0P1QHF4205QH
F080D51@0P1?Cdl2059BDP80F5QH0P1PH60206ATI080JFUY0P1fMWH208B4Q080SHf=0P2EUID20:6Q
X@80Zj^[0P2`/;020;:b/P030;Fe]@2f][H0][Jf0080];Bd102a/K460;>c/`80/[:b0P2a/K420:n_
[`@0[:b/9`38h=P402PX:080=SHf0P0^;Rh202LW9`@0<30`0P0_;bl203Ph>080=cLg0P0h>3P203@d
=080?clo0P1:BTX203Ti>@0303<c<`0Y:BT0:BTY0080<30`0P0_;bl203Hf=P80>CTi0P0];Bd202/[
:`809bLW0P0_;bl204Q8B080ATI60P1?Cdl205YJFP80DU9B0P0b<S8403dm?@80=3@d0P1GEeL203<c
<`80JFUY0P1>CTh202HV9P80;bl_0P1LG5`203@d=0807AdM100W9bL2020P8080:RXZ00<0C4a<08B4
Q024Q8@00P2VYZH208>3P`80K6a/0P1LG5`206ATI080R8R80P2`/;020;no_`80[Zj^0P2YZJT20:ZZ
ZP80[:b/0P2_[jl20;Fe]@80^;Rh0P2n_[h20<;2`P80^k^k0P2YZJT209NGU`80VYZJ0P2HV9P409jN
WP80][Jf0P2j^[X40;jn_P80`/;20P34a<@00`32`/80`L710<71`@020<;2`P80`L710P2NWYh207If
MP80IVIV0P1XJ6P206i^KP80MWIf0P1hN7P207UiN@80MgMg0P1eMGD206a/K080IVIV0P1PH60206MW
I`80IFEU0P1KFe/205=CD`80CDe=0P1GEeL205EEE@80GEeM0P1UIFD206][J`80LW9b0P1mOGd208F5
Q@80TY:B0P2HV9P00`2OWil0YjNW0:NWY`020:j^[P80/;2`0P2i^KT40;Fe]@80/;2`0P2][Jd20;6a
/@80/k>c0P2b/[820;6a/@@0[jn_0P2][Jd20:ZZZRL0b>3H0P0U9BD202/[:`80=cLg0P0`<30202XZ
:P809bLW0P0c<c<203dm?@80@T920P0h>3P2034a<@80=SHf00<0>SXj03Ti>@0i>CT00P10@402038b
<P80;Rh^0P0/;2`202h^;P80<C4a0P0j>SX2038b<P80:RXZ0P0[:b/203De=@80@d=30P1BDU8204a<
C080EEEE0P1FEUH203Ti>@@0=SHf0P0c<c<205mOG`80>3Ph0P1VIVH204m?C`0302PX:00/;2`0;2`/
0080GemO0P0h>3P201lO7`807AdM0P0P820202<S8`80:2PX0P19BDT208B4Q080Xj>S0P25QHD206][
J`80F5QH0P1/K6`208R8R080Zj^[0P2i^KT20;:b/P80ZZZZ0P2UYJD20:n_[`80/k>c0P2d];@00`2i
^KT0`l?30<?3``040;fm_@80ZZZZ0P2MWId209^KV`80UYJF0P2RXZ820:>SX`80[Zj^0P2l_;`20;fm
_@@0_[jn0P35aLD20<K6aP80aLG50P3:b/X20<C4a080WIfM0P1`L70206IVIP80I6AT0P1_Kfl2071`
L00307EeM@1jNWX0NWYj0080N7Qh0P1bLW8206a/K0@0IVIV0P1RHV8206EUI@80H61P0P1GEeL2059B
DP80CDe=0P1ADE4205ADE080GUiN0P1RHV8206UYJ@80O7al0P28R8P208Z:RP80UiNG0P2RXZ820:VY
Z@80[Zj^0P2d];@00`2f][H0]kNg0;Ng]`060;6a/@@0];Bd102b/[820:n_[`80[Zj^0P2/[:`20:RX
Z1h0b>3H000L0<SPf0808R8R0P0/;2`203Hf=P80;bl_0P0X:2P202/[:`80=CDe0P0k>c/203lo?`80
>3Ph0P0b<S8203<c<`<0>c/k0P0o?cl203<c<`80;Rh^0P0/;2`202h^;P80<S8b0P0j>SX203<c<`80
:b/[0P0/;2`2038b<P80@D510P1@D50204Q8B080EEEE0P1GEeL203Ph>080=cLg0P0e=CD203Lg=`80
H61P0P0g=cL206EUI@80Cdm?00<0:BTY02PX:00X:2P00P1OGel203hn?P80820P0P0M7Ad202<S8`80
8B4Q0P0[:b/204Y:BP80QhN70P2NWYh208J6QP80K6a/0P1GEeL206][J`80RXZ:0P2VYZH20;Zj^P80
];Bd0P2YZJT20:ZZZP80[Zj^0P2`/;020;>c/`030;^k^`31`L40`L710080`<300P2j^[X20:ZZZP80
Vi^K0P2HV9P209ZJVP80WIfM0P2SXj<20:n_[`80^k^k0P2n_[h20;no_`80`L710P33`l<40<G5a@80
cLg=0P39bLT209jNWP80L71`0P1UIFD206IVIP80KVi^0P1aLG400`1fMWH0NGUi07UiN@0207QhN080
M7Ad0P1_Kfl206YZJP80IfMW0P1TI6@206=SH`80HF5Q0P1HF5P2051@D080Cdm?0P1BDU8205QHF080
H61P0P1TI6@206UYJ@80MWIf0P24Q8@208f=S@80UIFE0P2QXJ420:^[Z`80/;2`0P2b/[800`2e]KD0
][Jf0;Jf]P020;Bd]0@0/K6a1P2c/k<20;:b/P80/K6a0P2_[jl40:b/[2L0b>3H100X:2P203Hf=P80
;Rh^0P0W9bL4030`<080;bl_0P0h>3P203Lg=`80>3Ph0P0d=3@203lo?`80BTY:0P0i>CT00`0c<c<0
:BTY02TY:@02030`<080;bl_0P0f=SH203Ti>@80;Bd]0P0[:b/202LW9`80;bl_0P18B4P204I6AP80
Cdm?0P1JFUX2059BDP80<S8b100m?Cd203@d=080EeMG0P0c<c<206UYJ@80CTi>0P0V9RH202l_;`80
G5aL0P0d=3@201dM7@@09bLW0P0P820202XZ:P0304a<C024Q8@0Q8B40080YZJV0P23Ph<206a/K080
G5aL0P1TI6@208R8R080/;2`0P2o_kl20:j^[P80ZJVY0P2ZZZX20:b/[080[jn_0P2e]KD20;Rh^080
_[jn0P32`/820;^k^`80ZJVY0P2GUiL209ZJVP80V9RH102NWYh20;Jf]P80^[Zj102n_[h20<;2`P80
a<C400<0`/;20<71`@31`L400P32`/820<71`@80WYjN0P1fMWH206IVIP80J6QX0P1^KVh207IfMP80
N7Qh0P1iNGT207MgM`80MGEe0P1/K6`206IVIP80H61P0P1WIfL206EUI@80Fe]K0P1CDe<204e=C@80
EeMG0P1EEED205eMG@80IFEU0P1[Jf/2079bLP80OGem0P25QHD209:BTP80V9RH00<0WinO0:NWY`2W
YjL00P2^[Zh20;2`/080^KVi102e]KD20;2`/080[Jf]0P2a/K420;>c/`80/[:b0P2a/K440:n_[`80
[Jf]0P2ZZZXW0<SPf0809BDU0P0[:b/203Lg=`80<30`0P0Z:RX202LW9`80<c<c0P0m?Cd20492@P80
>3Ph0P0a<C4203Hf=P0303Xj>P0i>CT0>CTi0080@4100P0b<S8202h^;P80;2`/0P0^;Rh2034a<@80
>SXj0P0b<S8202XZ:P80:b/[0P0e=CD204=3@`80DU9B0P1<C4`205EEE@80EUIF0P0i>CT403Hf=P80
<c<c0P1OGel203Ph>080IVIV0P1?Cdl00`0X:2P0;2`/02`/;00205mOG`80>3Ph0P0O7al201dM7@80
820P0P0S8b<202PX:080BDU90P24Q8@20:>SX`80QHF50P1[Jf/205QHF080K6a/0P28R8P20:^[Z`80
^KVi0P2b/[820:ZZZP80YJFU0P2_[jl20;>c/`80];Bd00<0^KVi0<?3``33`l<0102m_Kd20:ZZZP80
WIfM0P2KVi/209JFUP80XZ:R0P2SXj<20:j^[P80_;bl0P2m_Kd40;jn_P80aLG50P36a/H20<G5a@80
b/[:0P34a<@209fMW@80L71`0P1VIVH206ATI080Kfm_0P1`L7000`1eMGD0NWYj07YjNP0207QhN080
LW9b0P1/K6`406IVIP80HV9R0P1UIFD2061PH080EeMG0P1BDU8204e=C@80DE5A0P1DE5@205iNGP80
HV9R0P1YJFT207alO080R8R80P2:RXX209NGU`80XZ:R0P2YZJT20:j^[P80];Bd00<0][Jf0;Ng]`2g
]kL01P2a/K440;Bd]0@0/[:b0P2_[jl20:j^[P80[:b/0P2XZ:PN0<SPf0007038h=P2024Q8@80;Rh^
0P0k>c/203<c<`80:RXZ0P0_;bl203De=@80<S8b0P0^;Rh202d];@80;Rh^0P0e=CD00`0j>SX0=SHf
03Hf=P0203<c<`80;bl_0P0/;2`202/[:`80;Bd]0P0d=3@203Xj>P80<c<c0P0/;2`2034a<@80>3Ph
0P0e=CD203Hf=P809RHV0P1?Cdl203dm?@80<30`0P0/;2`203Hf=P80;2`/0P1RHV8204];B`80IfMW
0P14A4@00`0_;bl0:b/[02/[:`02069RHP80ADE50P0Y:BT4024Q8@806a/K0P0S8b<202HV9P80Kfm_
0P2:RXX209fMW@80PH610P1QHF4205iNGP80JVYZ0P2CTi<20;Zj^P80^;Rh0P2][Jd40:ZZZP80[:b/
0P2_[jl00`2f][H0_Kfm0;fm_@020;no_`80_;bl0P2/[:`209bLW080VYZJ102KVi/209fMW@80Zj^[
0P2i^KT20;jn_P80`L710P33`l<40<C4a080`/;20P2o_kl20;^k^`80^[Zj0P2`/;020820P080D51@
0P1LG5`205EEE@0305eMG@1SHf<0Hf=S0080Hf=S1P1QHF44061PH080I6AT0P1WIfL2061PH080G5aL
0P1UIFD2071`L080MGEe0P1jNWX20861P@80RHV90P2CTi<209bLW080Xj>S0P2XZ:P20:b/[080[jn_
0P2b/[820;Bd]0030;Jf]P2g]kL0]kNg0080]KFe0P2c/k<40;:b/P80/K6a0P2`/;020;6a/@80/[:b
0P2_[jl20:f][@80[:b/9`38h=P202HV9P80:b/[0P11@D4402`/;080;Rh^0P0h>3P203@d=080<c<c
0P0i>CT202XZ:P80=3@d0P0e=CD203Xj>P80<30`00<0:b/[02l_;`0_;bl00P0Z:RX202`/;080=CDe
0P0j>SX203Lg=`80;Rh^0P0b<S8203Ph>080>CTi0P0e=CD202h^;P80BTY:0P16ATH202l_;`80:b/[
0P0/;2`203Ph>080H61P0P19BDT206a/K080?Shn0P0`<302038b<P80GemO0P12@T8202XZ:P809BDU
0P0P820201dM7@808b<S00<0:b/[06e]K@1]KFd00P2;Rh/209VIV@80PX:20P1SHf<205eMG@80K6a/
0P2?Shl20;Fe]@80`L710P2/[:`20:FUY@80[:b/0P2^[Zh20;>c/`80/[:b0P2o_kl20<30`080^k^k
0P2][Jd209ZJVP80WIfM0P2IVIT209bLW080WIfM0P2][Jd20;Rh^080_Kfm0P30`<020<?3``80a<C4
00<0a/K60<G5a@35aLD01030`<020;no_`80ZZZZ0P1hN7P405EEE@80EeMG0P1HF5P4065QH@80H61P
0P1VIVH206=SH`80Fe]K0P1PH60206QXJ0@0I6AT0P1FEUH206IVIP80KVi^0P1cLg<207YjNP80O7al
0P26QXH2092@T080W9bL0P2SXj<20:JVYP030:f][@2_[jl0[jn_00@0/k>c102f][H20;Fe]@80/K6a
0P2b/[820;>c/`@0/;2`0P2_[jl20;Fe]@80[Jf]0P2ZZZX20:n_[bL0b>3H0P0Q8B4202d];@80>c/k
0P0d=3@202XZ:P80;Bd]0P0e=CD203@d=080;Bd]0P0[:b/2034a<@80=SHf00<0>c/k038b<P0b<S80
0P0e=CD402h^;P@0;2`/0P0g=cL203Ti>@80<S8b0P0^;Rh203<c<`80>3Ph0P0c<c<203Hf=P809bLW
0P1?Cdl203Xj>P80;bl_0P0/;2`203Lg=`80:b/[0P1UIFD204U9B@80J6QX0P13@d<00`0_;bl0:RXZ
02XZ:P0206ATI080@T920P0/;2`2024Q8@807alO0P0L71`2028R8P809bLW0P1]KFd208V9R@80Vi^K
0P23Ph<2065QH@80GEeM0P1VIVH209RHV080]kNg0P2i^KT20:b/[080[Zj^0P2YZJT20:^[Z`80/;2`
00<0^;Rh0;jn_P2n_[h00P2l_;`20;jn_P80[Zj^0P2JVYX209^KV`80UiNG0P2NWYh209^KV`80ZZZZ
0P2k^k/20;jn_P80`/;20P36a/H20<71`@80alO70P33`l<20;fm_@80_[jn0P2k^k/20:j^[P80Ogmo
0P1?Cdl2065QH@80EUIF00<0F5QH06ATI01TI6@00P1VIVH2069RHP80H61P0P1UIFD205]KF`80HF5Q
0P1UIFD206QXJ080GUiN0P1KFe/206][J`80L71`0P1eMGD207alO080QHF50P26QXH209FEU@80VYZJ
0P2QXJ420:JVYP@0[Zj^102b/[830;Vi^@80/k>c0P2d];@20:n_[`80/;2`0P2d];@20:j^[P80/k>c
0P2a/K420;2`/0@0[:b/7P38h=P001`0b>3H0P0Q8B4202h^;P80>c/k0P0c<c<202XZ:P80;bl_0P0e
=CD2038b<P80;Rh^0P0];Bd202h^;P80=CDe00<0>SXj03Hf=P0f=SH00P0c<c<202l_;`80;2`/0P0[
:b/202d];@80=3@d0P0j>SX203<c<`80;2`/0P0a<C4203Ph>080=CDe0P0f=SH202HV9P80Cdm?0P0m
?Cd2030`<080;2`/0P0f=SH202`/;080HV9R0P1;Bd/206MWI`80A4A400<0;bl_02/[:`0[:b/00P1R
HV8204E5A@80:BTY100Q8B4201/K6`808b<S0P0V9RH206m_K`80RXZ:0P2MWId20861P@80HF5Q0P1N
GUh206YZJP80Ti>C0P2j^[X20;Rh^080[Jf]102ZZZX20:b/[080[jn_00<0][Jf0;fm_@2m_Kd00P2o
_kl20;bl_080[:b/0P2LW9`209ZJVP@0Vi^K0P2MWId20:^[Z`80^KVi0P2n_[h20<71`@80`l?31034
a<@20<;2`P80_kno0P2k^k/20;Zj^P80/;2`0P20P802051@D080G5aL0P1EEED00`1MGEd0Hf=S06=S
H`0206=SH`H0HF5Q101PH60206ATI080IfMW0P1PH60205aLG080IFEU0P1`L70207EeM@80NWYj0P21
PH4208V9R@80Ti>C0P2LW9`20:>SX`80Z:RX0P2/[:`20:n_[`80/[:b0P2d];@00`2f][H0]kNg0;Ng
]`020;Fe]@80/k>c102b/[820;6a/@80/;2`0P2a/K420;:b/P80[jn_0P2][Jd20:b/[2L0b>3H0P0V
9RH202/[:`80@D51100/;2`202h^;P80>3Ph0P0d=3@203<c<`80>CTi0P0Z:RX203@d=080=CDe0P0j
>SX2030`<00302/[:`0_;bl0;bl_0080:RXZ0P0/;2`203De=@80>SXj0P0g=cL202h^;P80<S8b0P0h
>3P203Ti>@80=CDe0P0^;Rh204Y:BP80ATI60P0_;bl202/[:`80;2`/0P0h>3P2061PH080BDU90P1/
K6`203hn?P80<30`0P0b<S8205mOG`80@T920P0Z:RX202DU9@80820P0P0M7Ad202<S8`0302/[:`1]
KFd0KFe]0080Rh^;0P2IVIT208:2PP80Hf=S0P1MGEd206a/K080Shn?0P2e]KD20<71`@80[:b/0P2U
YJD20:b/[080[Zj^0P2c/k<20;:b/P80_kno0P30`<020;^k^`80[Jf]0P2JVYX209fMW@80VIVI0P2L
W9`209fMW@80[Jf]0P2h^;P20;fm_@80`<300P33`l<20<C4a0030<K6aP35aLD0aLG500@0`<300P2o
_kl20:ZZZP80N7Qh101EEED205MGE`80F5QH101QHF42061PH080IVIV0P1SHf<205]KF`80H61P0P1X
J6P406ATI080EUIF0P1VIVH206i^KP80Lg=c0P1jNWX207alO080QXJ60P2@T90209bLW080Xj>S0P2V
YZH00`2][Jd0[jn_0:n_[`040;>c/`@0][Jf0P2e]KD20;6a/@80/[:b0P2c/k<40;2`/080[jn_0P2e
]KD20:f][@80ZZZZ0P2_[jlW0<SPf0808B4Q0P0];Bd203/k>`80=3@d0P0Z:RX202d];@80=CDe0P0d
=3@202d];@80:b/[0P0a<C4203Hf=P0303/k>`0b<S80<S8b0080=CDe100^;Rh402`/;080=cLg0P0i
>CT2038b<P80;Rh^0P0c<c<203Ph>080<c<c0P0f=SH202LW9`80Cdm?0P0j>SX202l_;`80;2`/0P0g
=cL202/[:`80IFEU0P19BDT206QXJ080@d=300<0;bl_02XZ:P0Z:RX00P1TI6@20492@P80;2`/0P0Q
8B4201lO7`8071`L0P0R8R8202LW9`80KFe]0P29RHT209^KV`80Ph>30P1QHF4205eMG@80IVIV0P2H
V9P20;Ng]`80^KVi0P2/[:`20:j^[P80ZJVY0P2[Zj/20;2`/0030;Rh^02n_[h0_[jn0080_;bl0P2n
_[h20:j^[P80VYZJ0P2KVi/209NGU`80WYjN0P2KVi/20:ZZZP80^k^k0P2n_[h20<;2`P80a/K60P31
`L420<O7a`80`l?30P2m_Kd20;jn_P80^k^k0P2^[Zh207moO`80Cdm?0P1QHF4205IFEP0305QHF01T
I6@0I6AT0080IVIV0P1RHV82061PH080IFEU0P1KFe/2065QH@80IFEU0P1XJ6P205iNGP80Fe]K0P1[
Jf/2071`L080MGEe0P1lO7`208F5Q@80QXJ60P2EUID209ZJVP80XJ6Q0P2VYZH40:j^[P@0/[:b0`2i
^KT20;>c/`80];Bd0P2_[jl20;2`/080];Bd0P2^[Zh20;>c/`80/K6a0P2`/;040:b/[1h0b>3H000L
0<SPf0808B4Q0P0[:b/203Lg=`80<c<c0P0^;Rh203Hf=P80?Cdm0P0k>c/203Lg=`80=3@d0P0a<C43
03@d=080@4101P0Z:RX402TY:@80;Bd]0P0a<C4202l_;`80;Bd]0P0a<C4203Hf=P80=CDe0P0h>3P2
02TY:@80EEEE0P0g=cL202/[:`809BDU0P0`<30202DU9@80GemO0P1JFUX206EUI@80@d=300<0:BTY
02<S8`0S8b<00P1MGEd205UIF@80=CDe100f=SH202XZ:P808b<S0P0O7al204M7A`80KVi^0P2EUID2
092@T080Ogmo0P1XJ6P205]KF`80NGUi0P2NWYh20;Bd]080_kno0P2d];@20:JVYP80YjNW0P2/[:`0
0`2b/[80]kNg0;Ng]`020;Zj^P80^KVi0P2][Jd20:2PX080Vi^K0P2JVYX209VIV@80Vi^K0P2WYjL2
0;Fe]@80_;bl0P31`L440<;2`P@0`l?30P32`/820;no_`80_Kfm0P2g]kL20:FUY@80T92@0P17AdL2
04Q8B00304A4A01>CTh0CTi>0080EUIF0P1OGel206ATI080J6QX0P1YJFT206][J`80LG5a0P1hN7P4
07MgM`80OWin0P25QHD208R8R080S8b<0P2CTi<209ZJVP80X:2P0P2VYZH20:ZZZP80[Jf]0P2_[jl2
0;6a/@80/[:b0P2d];@00`2f][H0]kNg0;Ng]`020;Fe]@80/k>c0P2a/K460;2`/0@0/K6a102`/;02
0:n_[bL0b>3H0P0S8b<202HV9P80?Cdm0P0b<S8203<c<`80>CTi0P0o?cl203Ti>@80=3@d1P0_;bl2
03<c<`80@4100P0b<S800`0X:2P0<C4a034a<@0202TY:@80:RXZ0P0[:b/203@d=080;2`/0P0^;Rh2
03De=@80<c<c0P0e=CD2034a<@80;2`/0P17AdL203Lg=`80:RXZ100Y:BT2030`<080IFEU0P1EEED2
06a/K080>CTi0P0Y:BT2038b<P@0Fe]K0P0g=cL2038b<P80;Rh^0P0Y:BT201hN7P0302<S8`0k>c/0
>c/k0080NGUi0P2<S8`20:2PX080N7Qh0P1OGel206ATI080LW9b0P2GUiL20<K6aP80^[Zj0P2YZJT2
0:^[Z`80YZJV0P2WYjL20;2`/0@0^KVi0P2g]kL20:^[Z`80Xj>S0P2JVYX209^KV`80UYJF0P2KVi/2
0:BTY080/k>c0P2m_Kd20<?3``80`L710P30`<000`32`/80aLG50<G5a@020<30`080_[jn0P2k^k/2
0;Vi^@80/;2`0P29RHT204m?C`80ADE50P17AdL205EEE@80FEUI0P1MGEd206EUI@80JVYZ0P1^KVh2
06QXJ080M7Ad0P1iNGT207emO@80OWin0P1mOGd208B4Q080QhN70P29RHT209BDU080V9RH0P2NWYh4
0:JVYP80[:b/00<0/K6a0:n_[`2_[jl00P2e]KD40;Bd]080]kNg102e]KD20;Bd]080[Zj^102c/k<4
0:n_[`80/[:b0P2_[jl20;Bd]2L0b>3H0P0M7Ad202d];@80=SHf0P0a<C4202l_;`80=SHf100n?Sh2
03De=@80<S8b0P0];Bd203De=@0303@d=011@D40@D510080:b/[100X:2P202TY:@809bLW0P0_;bl2
034a<@80<30`0P0/;2`2034a<@80=SHf0P0`<30203Lg=`80:2PX0P1DE5@203Ph>080;Rh^0P0U9BD2
034a<@809BDU0P1OGel205YJFP80IVIV0P14A4@00`0[:b/08b<S02<S8`0205aLG080FUYJ0P0f=SH2
03De=@80>c/k0P0];Bd202@T90808R8R0P15ADD207IfMP80U9BD0P2BTY8207alO080J6QX0P1MGEd2
07YjNP80WYjN0P2c/k<20;jn_P80]KFe0P2UYJD20:JVYP80ZZZZ00<0/k>c0;Ng]`2g]kL00P2k^k/2
0;Ng]`80Zj^[102LW9`209VIV@80WYjN0P2IVIT20:BTY080/[:b0P2n_[h20;no_`80`/;20P31`L42
0<30`080a<C40P2n_[h20<30`080`l?30P2i^KT20:6QX@80TY:B0P15ADD204Q8B0030451@@1<C4`0
C4a<0080FEUI0P1MGEd206=SH`80Jf][101/K6`2071`L080MWIf0P1iNGT207AdM080Ogmo1026QXH2
08f=S@80TI6A0P2HV9P40:>SX`80[:b/0P2][Jd20;Jf]P80[jn_0P2b/[820;Bd]0030;Fe]@2d];@0
];Bd0080]KFe0P2h^;P20;6a/@80/[:b0P2c/k<20:n_[`80/[:b0P2_[jl20;>c/`80/K6a0P2b/[8N
0<SPf0007038h=P2024Q8@80:b/[0P0g=cL203<c<`80;Rh^0P0f=SH203dm?@80>c/k0P0g=cL203@d
=080<C4a0`0d=3@20410@0H0:RXZ100Y:BT202d];@80<C4a0P0_;bl202d];@80<C4a0P0f=SH203De
=@80>3Ph0P0Y:BT205EEE@80=cLg0P0[:b/202DU9@80<30`0P0U9BD205mOG`80FUYJ0P1UIFD204=3
@`0302TY:@0S8b<08b<S0080GEeM0P1IFET203De=@@0=SHf0P0Z:RX202<S8`807alO0P17AdL206i^
KP80UIFE0P2@T90207moO`80J6QX0P1KFe/207UiN@80WYjN0P2d];@20;no_`80];Bd0P2VYZH20:NW
Y`80[:b/00<0/[:b0;Ng]`2g]kL00P2j^[X20;Vi^@80[Jf]0P2PX:0209^KV`80VYZJ0P2IVIT209^K
V`80YjNW0P2e]KD20;bl_080`L711032`/840<?3``80`/;20P2o_kl20;fm_@80]kNg0P2UYJD2092@
T080AdM70P18B4P00`14A4@0CTi>04i>CP0205IFEP80GemO0P1TI6@206QXJ080JFUY0P1[Jf/2075a
L@80N7Qh101gMgL207inOP80QHF50P28R8P208b<S080Ti>C0P2JVYX20:2PX080YZJV0P2ZZZX20:f]
[@80[jn_0P2a/K420;:b/P80];Bd00<0][Jf0;Ng]`2g]kL00P2e]KD20;>c/`80/K6a1P2`/;040;6a
/@@0/;2`0P2_[jlW0<SPf0808b<S0P0V9RH203dm?@80<S8b0P0c<c<203Ti>@80?clo0P0i>CT203@d
=0H0;bl_0P0c<c<20410@080<S8b00<0:2PX034a<@0a<C400P0Y:BT202XZ:P80:b/[0P0d=3@202`/
;080;Rh^0P0e=CD203<c<`80=CDe0P0a<C4202`/;080AdM70P0g=cL202XZ:P@0:BTY0P0`<30206EU
I@80EEEE0P1/K6`203Ti>@80:BTY0P0b<S8405]KF`80=cLg0P0b<S8202h^;P80:BTY0P0N7Qh00`0S
8b<0>c/k03/k>`0207UiN@80S8b<0P2PX:0207QhN080GemO0P1TI6@2079bLP80UiNG0P36a/H20;Zj
^P80ZJVY0P2[Zj/20:JVYP80YjNW0P2`/;040;Vi^@80]kNg0P2[Zj/20:>SX`80VYZJ0P2KVi/209JF
UP80Vi^K0P2TY:@20;>c/`80_Kfm0P33`l<20<71`@80`<3000<0`/;20<G5a@35aLD00P30`<020;jn
_P80^k^k0P2i^KT20;2`/080RHV90P1?Cdl204E5A@80AdM70P1EEED205UIF@80GEeM0P1UIFD206YZ
JP80KVi^0P1XJ6P207AdM080NGUi0P1mOGd207inOP80OGem0P24Q8@208N7Q`80RHV90P2DU9@209RH
V080WYjN102VYZH20:b/[0030;6a/@2_[jl0[jn_0080]KFe102d];@20;Ng]`@0]KFe0P2d];@20:j^
[P@0/k>c102_[jl20;:b/P80[jn_0P2d];@W0<SPf0807AdM0P0];Bd203Hf=P80<C4a0P0_;bl203Hf
=P@0?Shn0P0e=CD2038b<P80;Bd]0P0e=CD00`0d=3@0@D510451@@0202/[:`@0:2PX0P0Y:BT202LW
9`80;bl_0P0a<C42030`<080;2`/0P0a<C4203Hf=P80<30`0P0g=cL202PX:080E5AD0P0h>3P202h^
;P809BDU0P0a<C4202DU9@80GemO0P1JFUX206IVIP80A4A400<0:b/[02<S8`0S8b<00P1LG5`205YJ
FP80=SHf0P0e=CD203/k>`80;Bd]0P0T92@2028R8P80ADE50P1fMWH209BDU080TY:B0P1lO7`206QX
J080GEeM0P1jNWX209jNWP80/k>c0P2n_[h20;Fe]@80YJFU0P2VYZH20:ZZZP030;>c/`2g]kL0]kNg
0080^k^k0P2g]kL20:^[Z`@0W9bL0P2IVIT209jNWP80VIVI0P2TY:@20;:b/P80_[jn0P2o_kl20<;2
`P80`L710P30`<020<C4a080_[jn0P30`<020<?3``80^KVi0P2QXJ4209:BTP80ADE50P18B4P00`11
@D40C4a<04a<C00205UIF@80GEeM0P1SHf<206][J`@0K6a/0P1`L70207IfMP80NGUi0P1dM7@207mo
O`@0QXJ60P2=SHd2096AT@80V9RH102SXj<20:b/[080[Jf]0P2f][H20:n_[`80/[:b0P2d];@00`2e
]KD0];Bd0;Bd]0020;Fe]@80^;Rh0P2a/K420;:b/P80/k>c0P2_[jl20;:b/P80[jn_0P2c/k<20;6a
/@80/[:b7P38h=P001`0b>3H0P0P820202PX:080<S8b0P0a<C42038b<P80>c/k0P14A4@204=3@`80
@4100P0n?Sh203/k>`80>3Ph00<0<S8b04a<C01<C4`00P0W9bL202XZ:P80:b/[0P0X:2P202HV9P80
9bLW0P0Y:BT202`/;080;bl_0P0b<S8203De=@80<S8b0P0e=CD202d];@80FUYJ0P0o?cl202XZ:P80
8b<S0P0Z:RX2028R8P80F5QH101TI6@20492@P0302@T900K6a/06a/K0080DU9B0P1/K6`204I6AP80
Bd];0P18B4P203Ti>@80:BTY0P0R8R8202DU9@80D51@0P1nOWh209FEU@80Vi^K0P1iNGT205QHF080
HV9R0P1mOGd20:NWY`80bLW90P2k^k/20:FUY@80Y:BT0P2XZ:P00`2][Jd0/[:b0;:b/P040;Fe]@80
[Jf]0P2TY:@209fMW@80VIVI0P2HV9P209^KV`80YJFU0P2a/K420;Zj^P@0`<300P2n_[h20<71`@80
a<C40P30`<020;^k^`@0_;bl0P2m_Kd20;Bd]080WinO0P1XJ6P00`1BDU80AdM704M7A`0205=CD`80
IFEU0P1^KVh207AdM080N7Qh0P1lO7`208>3P`80RXZ:0P2?Shl209>CT`80U9BD0P2EUID209NGU`80
VIVI0P2OWil20:FUY@80Z:RX0P2ZZZX20:b/[080[Jf]0P2_[jl60;6a/@030;Bd]02f][H0][Jf0080
]KFe0P2b/[820;6a/@80[jn_0P2`/;060;6a/@80/[:b102c/k<W0<SPf0809RHV0P0R8R82030`<080
=cLg0P0b<S8203De=@80B4Q80P1=CDd204I6AP80?Shn0P0l?3`2038b<P80?Shn0P13@d<202d];@03
02PX:00/;2`0;2`/0080:2PX0P0U9BD202XZ:P80:2PX0P0];Bd2034a<@80<S8b0P0c<c<203Xj>P80
<c<c0P0_;bl205MGE`80AdM7100T92@202HV9P80;2`/0P1DE5@206EUI@80K6a/0P0l?3`402<S8`80
BTY:0P1]KFd20451@@80ADE50P1@D50203/k>`809bLW00<08B4Q02XZ:P0Z:RX00P15ADD207emO@80
WIfM0P2GUiL207AdM080Fe]K0P1UIFD207emO@80ZZZZ0P36a/H20;Vi^@80Y:BT0P2XZ:P20:NWY`80
Zj^[102c/k<20;Ng]`80Zj^[0P2VYZH209ZJVP80W9bL0P2FUYH209fMW@80YZJV0P2b/[820;Rh^0H0
`<3000<0_[jn0<K6aP36a/H00P2o_kl20;jn_P80_kno0P2k^k/20;Jf]P80^;Rh0P2SXj<206e]K@80
CTi>0P1:BTX2059BDP80IVIV0P1eMGD206i^KP@0NGUi0P26QXH208V9R@80SXj>0P2CTi<2096AT@80
U9BD102HV9P209jNWP80Y:BT0P2[Zj/20:ZZZP@0[Zj^00<0ZZZZ0;6a/@2a/K400P2d];@20;2`/080
];Bd0P2f][H20;Bd]080/;2`0P2d];@40:j^[P80/K6a0P2`/;020;6a/@80/[:b0P2_[jl20;Fe]BL0
b>3H0P0R8R8202LW9`@0<S8b0P0_;bl203hn?P80@T920P16ATH203hn?P@0?3`l0P0j>SX00`0];Bd0
DE5A055AD@0202@T9080:BTY0P0/;2`202XZ:P@09RHV0P0Y:BT202XZ:P80<30`0P0d=3@203Lg=`80
<c<c0P0e=CD202h^;P80FEUI0P10@40202PX:0808B4Q0P0^;Rh201`L7080G5aL0P1WIfL206ATI080
@D5100<092@T01TI6@0I6AT00P1DE5@206][J`80ATI60P1:BTX204M7A`80>CTi0P0W9bL202<S8`80
92@T0P1>CTh207]kN`@0VYZJ0P1eMGD205MGE`80HV9R0P1nOWh20::RXP80b/[:0P2l_;`20:BTY080
YZJV0P2YZJT00`2][Jd0/;2`0;2`/0020;Rh^080/k>c0P2_[jl20:>SX`80WinO0P2HV9P209JFUP80
WIfM0P2TY:@20;6a/@80_;bl0P31`L420;fm_@80`L710P30`<020<K6aP80_Kfm0P2l_;`20;fm_@80
^k^k0P2m_Kd20;Jf]P80XJ6Q0P1VIVH00`1EEED0ADE504E5A@0205=CD`80IVIV0P1_Kfl407AdM080
Ng]k0P22PX8208Z:RP80TI6A0P2BTY8209FEU@80V9RH0P2DU9@209bLW080WYjN0P2TY:@40:ZZZP80
Zj^[0P2/[:`40;2`/0@0/[:b00<0]KFe0;Jf]P2f][H00P2e]KD20;Bd]0@0[Zj^0P2b/[820;2`/080
[jn_0P2b/[820;2`/080]KFe0P2b/[8N0<SPf0007038h=P2020P8080:2PX0P0b<S82034a<@80<S8b
0P0k>c/204A4A080@d=30P10@40203hn?P80>c/k0P0h>3P00`0b<S80C4a<04a<C00202LW9`80:RXZ
0P0[:b/202PX:0809RHV0P0W9bL202TY:@80;2`/0P0_;bl2038b<P80=CDe0P0b<S8203De=@80;Bd]
0P1JFUX203lo?`80:RXZ0P0S8b<202XZ:P808R8R0P1HF5P406ATI080@T9200<092@T01/K6`0K6a/0
0P1BDU8206a/K080ATI60P1;Bd/204Q8B080>CTi0P0Y:BT2028R8P809BDU0P1@D50207inOP80UIFE
0P2KVi/207UiN@80F5QH0P1RHV8207emO@80YjNW0P39bLT20;^k^`80YJFU0P2TY:@20:RXZ0030:f]
[@2b/[80/[:b00@0]KFe0P2][Jd20:BTY080WIfM0P2IVIT209RHV080Vi^K0P2UYJD20;6a/@80^[Zj
1030`<020;jn_P80`L710P34a<@20<30`080^k^k102l_;`20;fm_@80];Bd0P2OWil206QXJ003059B
DP17AdL0AdM70080De=C0P1UIFD206i^KP80M7Ad0P1hN7P207alO080Ph>30P2:RXX208n?S`80Ti>C
0P2DU9@209FEU@80UiNG0P2IVIT209nOW`80YJFU0P2XZ:P20:ZZZP80[:b/0P2][Jd20:n_[`H0/K6a
00<0];Bd0;Jf]P2f][H00P2e]KD20;:b/P80/K6a0P2_[jl20;2`/0H0/K6a0P2b/[840;>c/bL0b>3H
0P0V9RH2028R8P80<30`0P0g=cL2038b<P80=CDe0P18B4P204e=C@80ATI60P0n?Sh203`l?080<S8b
0P0n?Sh204=3@`80;Bd]00<0:2PX02`/;00/;2`00P0X:2P202DU9@80:RXZ0P0X:2P202d];@80<C4a
0P0b<S8203<c<`80>SXj0P0c<c<202l_;`80EeMG0P17AdL402@T90809RHV0P0/;2`205ADE080IFEU
0P1/K6`203`l?0@08b<S0P1:BTX206e]K@80@D510P15ADD2051@D080>c/k0P0W9bL00`0Q8B40:RXZ
02XZ:P0204E5A@80OGem0P2MWId209NGU`80M7Ad0P1KFe/206EUI@80OGem0P2ZZZX20<K6aP80^KVi
0P2TY:@20:RXZ080YjNW0P2[Zj/40;>c/`80]kNg0P2[Zj/20:JVYP80VYZJ0P2LW9`209JFUP80WIfM
0P2VYZH20;:b/P80^;Rh1P30`<000`2n_[h0a/K60<K6aP020;no_`80_[jn0P2o_kl20;^k^`80][Jf
0P2h^;P20:>SX`80KFe]0P1>CTh204Y:BP80DU9B0P1VIVH207EeM@80KVi^101iNGT208J6QP80RHV9
0P2>SXh209>CT`80TI6A0P2DU9@409RHV080WYjN0P2TY:@20:^[Z`80ZZZZ102^[Zh00`2ZZZX0/K6a
0;6a/@020;Bd]080/;2`0P2d];@20;Jf]P80];Bd0P2`/;020;Bd]0@0[Zj^0P2a/K420;2`/080/K6a
0P2b/[820:n_[`80]KFe9`38h=P2028R8P809bLW100b<S8202l_;`80?Shn0P12@T8204I6AP80?Shn
100l?3`203Xj>P0302d];@1ADE40DE5A008092@T0P0Y:BT202`/;080:RXZ100V9RH202TY:@80:RXZ
0P0`<30203@d=080=cLg0P0c<c<203De=@80;Rh^0P1IFET20410@080:2PX0P0Q8B4202h^;P8071`L
0P1LG5`206MWI`80I6AT0P11@D400`0T92@06ATI01TI6@0205ADE080Jf][0P16ATH204Y:BP80AdM7
0P0i>CT202LW9`808b<S0P0T92@204i>CP80Ng]k102JVYX207EeM@80EeMG0P1RHV8207inOP80XZ:R
0P3:b/X20;bl_080Y:BT0P2VYZH20:VYZ@030:f][@2`/;00/;2`0080^;Rh0P2c/k<20:n_[`80Xj>S
0P2OWil209RHV080UYJF0P2MWId20:BTY080/K6a0P2l_;`20<71`@80_Kfm0P31`L420<30`080a/K6
0P2m_Kd20;bl_080_Kfm0P2k^k/20;fm_@80][Jf0P2QXJ4206IVIP0305EEE@15ADD0ADE50080De=C
0P1VIVH206m_K`@0M7Ad0P1kNg/208:2PP80RXZ:0P2ATI4209:BTP80UIFE0P2HV9P209BDU080W9bL
0P2NWYh20:BTY0@0ZZZZ0P2[Zj/20:b/[0@0/;2`102b/[800`2e]KD0][Jf0;Jf]P020;Fe]@80];Bd
102^[Zh20;:b/P80/;2`0P2_[jl20;:b/P80/;2`0P2e]KD20;:b/Qh0b>3H000L0<SPf0807alO0P0V
9RH202l_;`80;Rh^0P0];Bd2034a<@80=CDe0P1=CDd206=SH`80GemO0P1EEED204i>CP0304E5A@1>
CTh0CTi>0080?3`l0P0i>CT203@d=080;Bd]100X:2P202XZ:P80;2`/0P0_;bl203@d=080>CTi100c
<c<202PX:080E5AD0P1MGEd202HV9P809BDU100V9RH204M7A`80HV9R0P1_Kfl203dm?@0302HV9P0P
8200820P0080?Cdm0P1OGel203Ti>@80:b/[100g=cL2038b<P80:b/[0P0T92@203Lg=`80De=C0P20
P8020:6QX@80R8R80P1WIfL205iNGP80Hf=S0P2;Rh/20;>c/`80^;Rh0P2c/k<20:RXZ080Xj>S00<0
Z:RX0:n_[`2_[jl0102a/K420:j^[P80Z:RX0P2RXZ8209fMW@80Vi^K0P2NWYh20:NWY`80/K6a0P2j
^[X20<30`080_kno0P2l_;`20;jn_P80_kno0P2n_[h20;bl_080^[Zj0P2h^;P20;Vi^@80^;Rh0P2i
^KT20:^[Z`0308f=S@1aLG40LG5a0080K6a/0P1_Kfl207MgM`80P8200P26QXH208^;R`80T92@0P2D
U9@209VIV@80W9bL0P2NWYh209nOW`80X:2P0P2RXZ820:FUY@80Z:RX0P2YZJT20:ZZZP80[:b/0P2_
[jl40;2`/0@0/K6a00<0/k>c0;Bd]02d];@0102d];@20;:b/PH0/K6a0P2b/[820;>c/`80]KFe102f
][HW0<SPf0808R8R0P0Y:BT202l_;`80<c<c0P0Y:BT202XZ:P80<S8b0P10@40205YJFP80HF5Q0P1O
Gel2051@D080@d=30P16ATH303Xj>P80<C4a0P0[:b/202LW9`80;2`/0P0Y:BT202XZ:P80;2`/0P0d
=3@203De=@80>3Ph0P0[:b/2034a<@80FUYJ0P1HF5P202d];@808b<S100V9RH203`l?080JFUY0P1S
Hf<203dm?@809BDU0P0T92@203Xj>P80JVYZ0P11@D4202`/;080=3@d0P10@40203Hf=P0302h^;P0_
;bl0;bl_0080:b/[0P1HF5P208>3P`80YZJV0P29RHT2061PH080GEeM0P1QHF4208N7Q`80];Bd0P32
`/820:n_[`80Xj>S0P2VYZH20;2`/080[:b/0P2c/k<20;:b/P80[Zj^0P2UYJD20:JVYP80Vi^K0P2L
W9`209jNWP80YjNW0P2c/k<20;Ng]`80_kno102n_[h00`2j^[X0_kno0;no_`020;fm_@80^KVi0P2d
];@20;Vi^@80];Bd0P2f][H20;Fe]@80YJFU0P29RHT206a/K080I6AT0P1XJ6P207alO080Ng]k102:
RXX208j>SP80Ti>C0P2DU9@209VIV@80X:2P102SXj<40:FUY@80Z:RX0P2YZJT20:JVYP80[Zj^0P2a
/K400`2_[jl0/[:b0;:b/P020:n_[`80/;2`102c/k<20;Bd]080/[:b0P2`/;020;:b/P80/;2`0P2a
/K420:n_[`80];Bd0P2g]kL20;Fe]@80^;Rh9`38h=P201hN7P80:2PX0P0];Bd203<c<`80;bl_0P0]
;Bd2038b<P80CTi>0P1TI6@206=SH`80EEEE0P1;Bd/00`15ADD0E5AD05ADE00203Ph>080>c/k0P0c
<c<202/[:`80:BTY0P0V9RH202`/;080;Bd]0P0_;bl2038b<P@0=CDe0P0b<S8202TY:@80EEEE0P1J
FUX402LW9`80:BTY0P0M7Ad204M7A`80HF5Q0P1^KVh203`l?00302LW9`0Q8B408B4Q0080?3`l0P1Q
HF4203Ti>@80:b/[0P0f=SH203De=@80<S8b0P0[:b/202<S8`80=3@d0P1ADE4208>3P`80WinO0P29
RHT206QXJ080GemO0P1VIVH208V9R@80]KFe0P2k^k/20;6a/@80ZZZZ0P2OWil00`2YZJT0[jn_0:n_
[`020;Bd]080/;2`0P2b/[820:RXZ080XZ:R102NWYh20:2PX080YZJV0P2d];@20;Zj^P80_[jn0P2o
_kl20;jn_P80^[Zj0P32`/820<71`@80^KVi102f][H20;Rh^080]KFe0P2k^k/20:^[Z`0308f=S@1b
LW80LW9b0080K6a/0P1^KVh207IfMP80P8200P25QHD4092@T080Ti>C0P2JVYX209bLW0@0WYjN0P2L
W9`20:JVYP80XZ:R0P2[Zj/20:b/[080Z:RX0P2[Zj/20:j^[PH0[jn_0`2`/;020;Ng]`80/k>c0P2`
/;020;:b/P@0/K6a0P2`/;020;Fe]@80];Bd0P2a/K420;>c/`80]KFe7P38h=P001`0b>3H0P0O7al2
02HV9P80;bl_0P0^;Rh202d];@80<C4a0P0e=CD204e=C@80Hf=S0P1OGel205EEE@80CTi>00<0ADE5
04i>CP1>CTh00P0l?3`203Ti>@80=3@d0P0];Bd402PX:080:RXZ0P0/;2`202l_;`80=3@d0P0i>CT4
03<c<`80:2PX0P1DE5@205eMG@809RHV0P0U9BD402HV9P80AdM70P1RHV8206m_K`80?Cdm00<09RHV
020P800P82000P0m?Cd205mOG`80>CTi0P0[:b/403Lg=`80<S8b0P0[:b/202@T9080=cLg0P1CDe<2
0820P080XJ6Q0P28R8P206MWI`80GUiN0P1SHf<208^;R`80/k>c0P2h^;P20;>c/`80Z:RX0P2SXj<0
0`2XZ:P0[jn_0:n_[`040;6a/@80[Zj^0P2XZ:P20::RXP80WIfM0P2KVi/209jNWP80YjNW0P2a/K42
0;Zj^P80`<300P2o_kl20;bl_080_[jn0P2o_kl20;jn_P80_;bl0P2j^[X20;Rh^080^KVi0P2h^;P2
0;Vi^@80Zj^[00<0SHf=075aL@1aLG400P1/K6`206m_K`80MgMg0P20P80208J6QP80Rh^;0P2@T902
09BDU080VIVI0P2LW9`209jNWP80WinO0P2PX:020::RXP80YJFU0P2XZ:P20:VYZ@80ZZZZ0P2/[:`2
0:n_[`@0/;2`102a/K400`2c/k<0];Bd0;Bd]0040;Bd]080/[:b1P2a/K420;:b/P80/k>c0P2e]KD4
0;Jf]RL0b>3H0P0R8R8202TY:@80;bl_0P0c<c<202TY:@80:RXZ0P0b<S820410@080FUYJ0P1QHF42
05mOG`80D51@0P13@d<204I6AP<0>SXj0P0a<C4202/[:`809bLW0P0/;2`202TY:@80:RXZ0P0/;2`2
03@d=080=CDe0P0h>3P202/[:`80<C4a0P1JFUX205QHF080;Bd]0P0S8b<402HV9P80?3`l0P1YJFT2
06=SH`80?Cdm0P0U9BD202@T9080>SXj0P1ZJVX20451@@80;2`/0P0d=3@20410@080=SHf00<0;Rh^
02l_;`0_;bl00P0[:b/205QHF080Ph>30P2VYZH208V9R@80H61P0P1MGEd2065QH@80QhN70P2d];@2
0<;2`P80[jn_0P2SXj<20:JVYP80/;2`0P2/[:`20;>c/`80/[:b0P2^[Zh20:FUY@80YZJV0P2KVi/2
09bLW080WYjN0P2WYjL20;>c/`80]kNg0P2o_kl40;jn_P030;Zj^P2o_kl0_kno0080_Kfm0P2i^KT2
0;Bd]080^KVi0P2d];@20;Jf]P80]KFe0P2UYJD208V9R@80K6a/0P1TI6@206QXJ080O7al0P1kNg/4
08Z:RP80SXj>0P2CTi<209BDU080VIVI0P2PX:040:>SX`@0YJFU0P2XZ:P20:VYZ@80YZJV0P2^[Zh2
0;6a/@030:n_[`2b/[80/[:b0080[jn_0P2`/;040;>c/`80];Bd0P2b/[820;2`/080/[:b0P2`/;02
0;6a/@80[jn_0P2d];@20;Ng]`80]KFe0P2h^;PW0<SPf0807QhN0P0X:2P202d];@80<c<c0P0_;bl2
02d];@80<S8b0P1>CTh206ATI080Hf=S0P1EEED204];B`0304E5A@1DE5@0E5AD0080>3Ph0P0k>c/2
03<c<`80:b/[0P0Y:BT202HV9P80;2`/0P0];Bd202l_;`80<S8b100e=CD2038b<P80:BTY0P1EEED2
05YJFP@09bLW0P0Y:BT201dM7@80AdM70P1QHF4206i^KP80?3`l00<09bLW024Q8@0Q8B400P0l?3`2
065QH@80>CTi0P0[:b/203Hf=P80=CDe0P0b<S8202/[:`808b<S0P0d=3@2055AD@80Ph>30P2OWil2
08V9R@80J6QX0P1OGel206IVIP80RHV90P2e]KD20;^k^`80/K6a0P2ZZZX209nOW`030:VYZ@2_[jl0
[jn_0080];Bd0P2`/;020;:b/P80Z:RX0P2RXZ8409jNWP80X:2P0P2VYZH20;Bd]080^[Zj0P2n_[h2
0;no_`80_[jn0P2j^[X20<;2`P80`L710P2i^KT40;Jf]P80^;Rh0P2e]KD20;^k^`80Zj^[00<0SHf=
079bLP1bLW800P1/K6`206i^KP80MWIf0P20P80208F5Q@@0T92@0P2CTi<209ZJVP80W9bL102NWYh2
09bLW080YZJV0P2RXZ820:^[Z`80[:b/0P2XZ:P20:^[Z`80[Zj^1P2_[jl30;2`/080]kNg0P2c/k<2
0;2`/080/[:b102a/K420;2`/080]KFe0P2d];@20;6a/@80/k>c0P2e]KDN0<SPf0007038h=P2024Q
8@809RHV0P0/;2`202/[:`80:BTY100Z:RX203@d=080@d=30P1IFET206][J`80IVIV00<0Fe]K059B
DP1BDU800P1@D50204M7A`80?Shn0P0d=3@202/[:`80:RXZ0P0/;2`202d];@80;bl_0P0g=cL203`l
?080=3@d0P0_;bl202<S8`80Bd];0P1iNGT202PX:0809bLW0P0T92@202`/;080=cLg0P1LG5`207Ui
N@80>3Ph00<0;2`/02<S8`0S8b<00P0W9bL206QXJ080IFEU0P0d=3@2024Q8@80;2`/0P0j>SX203@d
=080:b/[0P0T92@202/[:`80Hf=S0P2HV9P2096AT@80NWYj0P1QHF42059BDP80KVi^0P2CTi<20:f]
[@80_[jn0P2_[jl20:2PX0030:BTY02/[:`0[:b/00H0[Jf]0P2[Zj/20:JVYP80X:2P0P2OWil20:2P
X080Z:RX0P2b/[820;Zj^P80`<300P2n_[h20;^k^`80^[Zj0P2k^k/40;bl_080]kNg0P2b/[820;6a
/@80/[:b0P2_[jl20:f][@030:VYZ@2RXZ80XZ:R0080Shn?0P1nOWh208>3P`80S8b<0P2CTi<209RH
V080VYZJ0P2KVi/209jNWP80X:2P0P2SXj<20:FUY@80YZJV102WYjL40:RXZ080ZJVY0P2/[:`20:j^
[P@0[jn_0P2`/;030;:b/P80/K6a0P2c/k<20;Fe]@80];Bd0P2c/k<40;6a/@80/k>c0P2e]KD20;Ng
]`@0^;Rh9`38h=P202HV9P808B4Q0P0U9BD203Lg=`809BDU0P0X:2P202l_;`80>3Ph0P18B4P205=C
D`80IVIV0P1^KVh205IFEP80D51@0P1FEUH00`13@d<0?Shn03hn?P02034a<@@0;2`/100];Bd2034a
<@80?Shn0P0h>3P203<c<`80;Bd]0P0[:b/204M7A`80Kfm_0P0_;bl202LW9`80:2PX0P0V9RH203Ph
>080I6AT0P1eMGD203dm?@80:BTY0P0U9BD202`/;080G5aL0P1VIVH202XZ:P80:b/[0P0`<30203Ph
>003038b<P0V9RH09RHV008092@T0P0^;Rh206ATI080SXj>0P2JVYX207=cL`80GemO0P1IFET206UY
J@80U9BD0P2d];@20;Vi^@80[:b/0P2PX:020:VYZ@80YZJV0P2`/;020:^[Z`80[Zj^0P2YZJT20:FU
Y@80WinO0P2QXJ4209jNWP80YjNW0P2`/;020;fm_@80_kno0P2n_[h30;Zj^P80^KVi0P2o_kl20;bl
_080]kNg0P2b/[820;Jf]P80/[:b0P2`/;020;Bd]080[:b/0P2RXZ8208b<S080O7al0P25QHD208^;
R`80Ti>C0P2GUiL209JFUP80WYjN0P2OWil20::RXP80XJ6Q0P2SXj<20:BTY080YjNW0P2TY:@20:JV
YP80[jn_0P2YZJT20:RXZ080[Zj^00<0/;2`0:j^[P2^[Zh0102a/K420;:b/P80/K6a0P2c/k<20;Jf
]P80]kNg0P2_[jl20;Fe]@80/[:b0P2_[jl40;Jf]P@0]kNg9`38h=P201hN7P80:2PX100/;2`202/[
:`809bLW0P0`<302038b<P80A4A40P1GEeL206YZJP80J6QX00<0G5aL051@D01@D5000P1@D50204Y:
BP80?Shn0P0c<c<202d];@80:BTY0P0/;2`2034a<@80:RXZ0P0h>3P203/k>`80=cLg0P0`<30201lO
7`80CDe=0P1gMgL202HV9P80:2PX0P0T92@202XZ:P80>SXj0P1NGUh207IfMP80>c/k0`0X:2P202<S
8`80JVYZ0P1SHf<203@d=0808R8R0P0a<C4203/k>`80=CDe0P0/;2`2020P8080;bl_0P1TI6@209NG
U`80TY:B0P1iNGT205mOG`80De=C0P1[Jf/209:BTP80[Jf]0P2n_[h20;2`/080WinO00<0YjNW0:VY
Z@2YZJT00P2/[:`20:VYZ@80/k>c0P2XZ:P20:FUY@80XJ6Q0P2NWYh20:2PX080ZZZZ0P2c/k<20;Vi
^@80`<30102m_Kd20;Rh^080^k^k0P2o_kl20;fm_@80][Jf0P2c/k<20;Ng]`80/;2`0P2a/K420:j^
[P030:BTY02RXZ80XZ:R0080UYJF0P1nOWh20861P@80S8b<0P2CTi<209RHV080VIVI0P2LW9`20:2P
X080WYjN0P2VYZH20::RXP80YZJV0P2WYjL20:JVYPH0ZJVY0P2/[:`20:j^[P80[jn_102`/;020;Bd
]0030;2`/02b/[80/[:b0080/k>c0P2g]kL20;Bd]080/[:b102`/;020;Fe]@80/k>c0P2i^KT20;Rh
^080^[Zj7P38h=P001`0b>3H0P0Q8B4202HV9P80;2`/0P0[:b/202TY:@@0:RXZ0P0d=3@204=3@`80
FEUI0P1[Jf/206IVIP0305]KF`1BDU80DU9B0080D51@0P17AdL203hn?P80=3@d0P0[:b/202XZ:P80
;2`/0P0];Bd202l_;`80=cLg0P0l?3`203@d=080;bl_0P0S8b<204];B`80NGUi0P0X:2P202LW9`80
92@T0P0/;2`203Lg=`80G5aL0P1iNGT203Ph>00302`/;00S8b<08b<S00809bLW0P1XJ6P206EUI@80
=3@d0P0Q8B4202`/;080>SXj0P0d=3@202/[:`8092@T0P0[:b/206=SH`80V9RH0P2ATI4207YjNP80
HF5Q0P1BDU8206i^KP80Ti>C0P2][Jd20;jn_P80[jn_0P2PX:000`2TY:@0[:b/0:b/[0060:f][@80
Zj^[0P2VYZH20:2PX080WinO0P2PX:020:RXZ080/[:b0P2j^[X20<30`080_[jn0P2k^k/20;Zj^P80
^k^k102l_;`20;Ng]`80/[:b0P2a/K420;:b/P80[jn_0P2][Jd00`2YZJT0XZ:R0::RXP0208n?S`80
OWin0P23Ph<208b<S080Ti>C0P2HV9P209ZJVP80Vi^K0P2NWYh20:2PX080Xj>S0P2UYJD20:JVYP@0
YjNW102XZ:P20:VYZ@80[:b/0P2^[Zh40:n_[`80/;2`0`2b/[820;6a/@80/k>c0P2e]KD20;Bd]080
/k>c102a/K420;>c/`80]KFe0P2g]kL40;Rh^2L0b>3H0P0V9RH2024Q8@809BDU0P0g=cL202DU9@80
:2PX0P0_;bl203Ph>080B4Q80P1CDe<206IVIP80KVi^0P1FEUH2051@D080EUIF00<0@d=303hn?P0n
?Sh00P0a<C4402`/;0@0;Bd]0P0a<C4203hn?P80>3Ph0P0c<c<202d];@80:b/[0P17AdL206m_K`80
;bl_0P0W9bL202PX:0809RHV0P0h>3P206ATI080MGEe0P0m?Cd202TY:@809BDU0P0/;2`205aLG080
IVIV0P0Z:RX202/[:`80<30`0P0h>3P00`0b<S809RHV02HV9P0202@T9080;Rh^0P1TI6@208j>SP80
VYZJ0P1cLg<205mOG`80FEUI0P1YJFT209BDU080];Bd0P2i^KT20:b/[080X:2P0P2YZJT20:JVYP80
/;2`0P2[Zj/20:j^[P80ZJVY0P2UYJD209nOW`80XJ6Q0P2NWYh20:NWY`80/;2`0P2m_Kd20;no_`80
_[jn0`2j^[X20;Vi^@80_kno0P2l_;`20;Ng]`80/[:b0P2f][H20;:b/P80/;2`0P2d];@20:b/[080
XZ:R0P2<S8`207alO080QHF50P2;Rh/209>CT`80UiNG0P2FUYH209jNWP80WinO0P2RXZ820:6QX@80
Xj>S0P2TY:@20:NWY`80Y:BT0P2VYZH20:n_[`80ZJVY0P2XZ:P20:j^[P030;2`/02^[Zh0[Zj^00@0
/K6a0P2b/[820;6a/@80/k>c0P2f][H20;Ng]`80[jn_0P2e]KD20;:b/P80[jn_102f][H40;Ng]bL0
b>3H0P0N7Qh202PX:0@0;2`/0P0[:b/202LW9`80<30`0P0b<S8204A4A080EeMG0P1ZJVX206QXJ003
05aLG01@D500D51@0080D51@0P1:BTX203hn?P80<c<c0P0];Bd202TY:@80;2`/0P0a<C4202XZ:P80
>3Ph0P0k>c/203Lg=`80<30`0P0O7al204e=C@80MgMg0P0V9RH202PX:08092@T0P0Z:RX203Xj>P80
GUiN0P1fMWH203/k>`<0:2PX0P0S8b<206YZJP80Hf=S0P0d=3@2028R8P80<C4a0P0k>c/203De=@80
;2`/0P0P820202l_;`80I6AT0P2GUiL209:BTP80NGUi0P1OGel205=CD`80Jf][0P2BTY820:f][@80
_[jn0P2`/;0209nOW`030:NWY`2YZJT0ZJVY0080[:b/0P2YZJT20;>c/`80Z:RX0P2UYJD20:6QX@80
WYjN0P2PX:020:ZZZP80/k>c0P2i^KT20<30`0@0_Kfm0P2h^;P20;^k^`80_kno0P2m_Kd20;Jf]P80
/k>c0P2g]kL20;2`/080/K6a0P2^[Zh00`2TY:@0XZ:R0::RXP0209JFUP80OWin0P21PH4208b<S080
Ti>C0P2HV9P209VIV@80W9bL0P2PX:0209jNWP80YZJV0P2RXZ820:JVYP80YjNW0P2VYZH60:VYZ@80
[:b/0P2^[Zh20:n_[`@0/;2`0P2d];@00`2`/;00/[:b0;:b/P020;>c/`80]kNg0P2d];@20;:b/P@0
/;2`0P2e]KD20;>c/`80^KVi0P2h^;P20;Zj^Qh0b>3H000L0<SPf080;Rh^100W9bL202d];@80=SHf
0P0R8R8203Lg=`80?3`l0P15ADD204Y:BP80DE5A0P1PH60306QXJ080ATI60P13@d<203lo?`80=SHf
0P0^;Rh202XZ:P80:BTY0P0[:b/202l_;`80=SHf0P0k>c/2030`<0809bLW0P0X:2P20492@P80Lg=c
0P0l?3`202@T90809bLW0P0_;bl203/k>`80FUYJ0P1cLg<203Ti>@0303Xj>P0Z:RX0:RXZ00809bLW
0P1:BTX2079bLP80=SHf0P0i>CT2028R8P80=SHf0P0^;Rh202TY:@80820P0P0R8R8204U9B@80Lg=c
0P23Ph<208F5Q@80Jf][0P1CDe<205iNGP80M7Ad0P2DU9@20:j^[P80_Kfm0P2SXj<30:BTY080YZJV
102YZJT20:NWY`80Xj>S0P2OWil209jNWP80XJ6Q0P2XZ:P20;6a/@80^[Zj0P30`<020;no_`80_;bl
0P2i^KT20;Ng]`80^[Zj0P2k^k/20;Jf]P@0/;2`0P2c/k<20;Bd]080]kNg00<0/K6a0:ZZZP2ZZZX0
0P2OWil209JFUP80U9BD0P2EUID209RHV080Vi^K0P2NWYh20:6QX@80Xj>S0P2TY:@20:FUY@X0YZJV
0P2WYjL20:VYZ@80ZZZZ0P2[Zj/20:f][@80[Zj^0P2`/;020;:b/P030;6a/@2`/;00/;2`0080/K6a
102c/k<40;:b/PH0/K6a0P2d];@40;Rh^2L0b>3H0P0W9bL202TY:@80:RXZ0P0d=3@203Lg=`808b<S
0P0d=3@204M7A`80Bd];0P14A4@204i>CP80J6QX0P1hN7P205MGE`80BDU900<0Cdm?04Q8B018B4P0
0P0e=CD2034a<@809bLW0P0X:2P202l_;`80:2PX0P0h>3P203dm?@80<C4a0P0U9BD202/[:`80A4A4
0P1bLW8203<c<`80:RXZ0P0X:2P202/[:`80?clo0P1NGUh2079bLP80?Shn0P0f=SH202TY:@80:b/[
0P11@D4207emO@80>SXj0P0Y:BT202@T9080;Bd]00<0=3@d02h^;P0^;Rh00P0Q8B42028R8P80?Shn
0P1fMWH208b<S080T92@0P1YJFT205IFEP80FEUI0P1bLW82092@T080^KVi0P2h^;P209nOW`80X:2P
102WYjL20:FUY@80Z:RX0P2ZZZX20:FUY@80WIfM0P2OWil20:6QX@80ZJVY0P2_[jl60;jn_P80_Kfm
00<0^[Zj0;Fe]@2e]KD00P30`<020;Zj^P80]kNg0P2][Jd20:n_[`80/[:b0P2h^;P20:n_[`80[Zj^
0P2b/[820:RXZ080WYjN102EUID209RHV0@0X:2P0P2QXJ440:>SX`80YjNW102UYJD20:NWY`80Xj>S
0P2WYjL20:VYZ@80YjNW0P2YZJT30:^[Z`80[Zj^0P2_[jl20;Bd]0@0/K6a0P2_[jl20;6a/@@0/[:b
0P2a/K440;2`/080];Bd0P2b/[840;Rh^2L0b>3H0P0];Bd202LW9`8092@T0P0/;2`203@d=0807QhN
0P0f=SH203Xj>P80AdM70P1:BTX205=CD`80GUiN00<0IfMW06ATI01TI6@00P16ATH204A4A080?Cdm
0P0i>CT202`/;0809bLW0P0X:2P202d];@80<S8b0P0i>CT203dm?@80;Bd]0P0X:2P202HV9P80@T92
0P1fMWH203dm?@809BDU0P0V9RH202d];@80>c/k0P1IFET207MgM`<0>CTi0P0Y:BT202LW9`80C4a<
0P1aLG4203Ph>080=CDe0P0P820203<c<`80;Bd]0P0[:b/202<S8`80820P0P16ATH2079bLP80QHF5
0P24Q8@206a/K080E5AD0P1LG5`207IfMP80UYJF0P2[Zj/20;jn_P80Xj>S1@2UYJD40:VYZ@80YZJV
0P2RXZ8209fMW@@0WYjN0P2YZJT20:b/[080^[Zj0P34a<@20;bl_080_Kfm0P2i^KT20;Fe]@80]kNg
0P2l_;`20;Jf]P80[:b/0P2_[jl20;Bd]080/k>c0P2h^;P00`2b/[80Z:RX0:RXZ00209nOW`80UIFE
0P2ATI4209VIV@80Vi^K0P2GUiL209bLW080XZ:R0P2PX:020:6QX@80Z:RX0P2VYZH20:ZZZP80YZJV
0P2SXj<20:FUY@80YjNW102XZ:P20:b/[080/;2`0P2^[Zh20:n_[`80]KFe0`2`/;020;Bd]080/k>c
0P2d];@20;:b/P80];Bd0P2a/K420:n_[`80/[:b0P2d];@20;Jf]P80]kNg7P38h=P001`0b>3H0P0^
;Rh402LW9`80;Bd]0P0f=SH2028R8P80=cLg0P0l?3`204E5A@80BTY:0P1ADE42061PH0<0J6QX0P16
ATH204=3@`80?clo0P0f=SH202h^;P80:RXZ0P0Y:BT202/[:`80;bl_0P0f=SH203/k>`80<30`0P0W
9bL202PX:080@T920P1cLg<203`l?08092@T0P0W9bL202l_;`80>c/k0P1JFUX207=cL`80>CTi00<0
>SXj02XZ:P0Z:RX00P0W9bL204Y:BP80LW9b0P0f=SH203Ti>@808R8R0P0f=SH202h^;P80:BTY0P0P
8202028R8P80BDU90P1cLg<208>3P`80QHF50P1[Jf/205=CD`80GUiN0P1dM7@209BDU080[Zj^0P2m
_Kd20:>SX`<0Y:BT0P2VYZH40:VYZ@80YjNW0P2SXj<209nOW`80WYjN0P2QXJ420:RXZ080/K6a0P2j
^[X20<30`080_kno0P2l_;`20;Vi^@80]kNg0P2j^[X20;^k^`80][Jf102`/;020;>c/`80];Bd0P2g
]kL00`2a/K40ZZZZ0:ZZZP0209nOW`80UYJF0P2DU9@209FEU@80V9RH0P2KVi/209jNWP80XJ6Q0P2S
Xj<20:BTY080YJFU2P2VYZH20:NWY`80ZJVY0P2ZZZX20:^[Z`80[Jf]0P2^[Zh20;2`/080/[:b00<0
/K6a0;2`/02`/;000P2a/K440;>c/`@0/[:b1P2a/K420;Bd]0@0^;Rh9`38h=P202LW9`80:BTY0P0Z
:RX203@d=080=cLg0P0S8b<203@d=080AdM70P1;Bd/204A4A080CTi>0P1XJ6P207QhN080EeMG0P19
BDT00`1?Cdl0B4Q804Q8B00203De=@80<C4a0P0W9bL202PX:080;bl_0P0X:2P203Ph>080?Cdm0P0a
<C4202DU9@80:b/[0P14A4@2079bLP80<c<c0P0Z:RX202PX:080:b/[0P0o?cl205iNGP80LW9b0P0n
?Sh203Hf=P80:BTY0P0[:b/20451@@80OGem0P0j>SX202TY:@8092@T0P0];Bd00`0d=3@0;Rh^02h^
;P02024Q8@808R8R0P0n?Sh207IfMP80S8b<0P2@T90206UYJ@80EUIF0P1IFET2079bLP80T92@0P2i
^KT20;Rh^080WinO0P2PX:040:NWY`80YJFU0P2XZ:P20:ZZZP80YJFU0P2MWId209nOW`80XJ6Q0P2Y
ZJT20:n_[`H0_[jn0P2m_Kd00`2j^[X0]KFe0;Fe]@020<30`080^[Zj0P2g]kL20:f][@80[jn_0P2b
/[820;Rh^080[jn_0P2^[Zh20;:b/P80Z:RX0P2NWYh409FEU@80V9RH102PX:020:6QX@@0Xj>S0P2W
YjL40:FUY@80YjNW0P2SXj<20:NWY`80ZJVY0P2WYjL20:VYZ@<0Zj^[0P2^[Zh20:n_[`80];Bd102a
/K420:n_[`80/K6a102b/[820;6a/@@0/;2`0P2d];@20;:b/P@0^;Rh9`38h=P202d];@809bLW0P0T
92@202`/;080=3@d0P0N7Qh203Hf=P80>SXj0P17AdL204Y:BP80De=C0P1NGUh00`1WIfL0I6AT06AT
I00204I6AP80A4A40P0m?Cd203Ti>@80;2`/0P0W9bL202PX:080;Bd]0P0b<S8203Ti>@80?Cdm0P0]
;Bd202PX:0809RHV0P12@T8207IfMP80?Cdm0P0U9BD202HV9P80;Bd]0P0k>c/205UIF@80MgMg0`0i
>CT202TY:@809bLW0P1<C4`2075aL@80>3Ph0P0e=CD2020P8080<c<c0P0];Bd202/[:`808b<S0P0P
820204I6AP80LW9b0P25QHD208B4Q080K6a/0P1DE5@205aLG080MWIf0P2FUYH20:^[Z`80_[jn0P2S
Xj<50:FUY@@0ZJVY0P2VYZH20::RXP80WIfM102NWYh20:VYZ@80[:b/0P2j^[X20<C4a080_;bl0P2m
_Kd20;Vi^@80]KFe0P2g]kL20;bl_080][Jf0P2/[:`20:n_[`80];Bd0P2c/k<20;Rh^0030;:b/P2X
Z:P0Z:RX0080WinO0P2EUID2096AT@80VIVI0P2KVi/209NGU`80W9bL0P2RXZ820:2PX080XJ6Q0P2X
Z:P20:JVYP80ZZZZ0P2VYZH20:>SX`80YJFU0P2WYjL40:RXZ080[:b/0P2`/;020:j^[P80[jn_0P2e
]KD30;2`/080];Bd0P2c/k<20;Bd]080/[:b0P2d];@20;6a/@80[jn_0P2b/[820;Bd]080][Jf0P2g
]kLN0<SPf0007038h=P203/k>`80;Rh^0P0U9BD202l_;`80@4100P0Q8B4204=3@`80@D510P10@402
03De=@80<C4a0P1DE5@00`1_Kfl0MgMg07MgM`0203Ti>@80?Cdm0P12@T8203Xj>P80<C4a0P0Y:BT2
02DU9@80:2PX0P0^;Rh203De=@80>CTi0P0];Bd2024Q8@80;Rh^0P0i>CT206EUI@80DU9B0P0Q8B42
02XZ:P80<C4a0P13@d<205IFEP80IVIV0P0j>SX00`15ADD0<S8b038b<P0202l_;`809RHV0P1LG5`2
07inOP80?Shn0P0I6AT2034a<@80:BTY0P0U9BD2020P80808B4Q0P0b<S8204Y:BP80KVi^0P2:RXX2
07QhN080GemO0P1IFET205mOG`80Ng]k0P2FUYH20<?3``80Z:RX00<0YJFU09jNWP2NWYh00P2QXJ44
0:BTY080Xj>S0P2PX:0209fMW@80WYjN0P2QXJ420:RXZ080/;2`0P2i^KT40<30`080_Kfm0P2i^KT2
0;Fe]@80^;Rh0P2j^[X20;Bd]0@0[Zj^0P2`/;020;>c/`80]KFe00<0[jn_0:VYZ@2YZJT00P2YZJT2
0:ZZZP80Xj>S0P2LW9`209ZJVP80Vi^K0P2OWil20:BTY0P0YJFU0P2TY:@60:>SX`80YZJV102XZ:P2
0:NWY`80ZZZZ0P2][Jd20;2`/080/[:b00<0/;2`0:n_[`2_[jl00P2_[jl20;2`/0@0/K6a102b/[82
0;2`/080[Zj^0P2b/[820;Rh^080^KVi9`38h=P203Hf=P80=3@d0P0T92@202PX:080?Cdm0P0/;2`2
03Xj>P80?clo100k>c/203<c<`80AdM70P1]KFd2075aL@80@T9200<0>CTi04I6AP16ATH00P0f=SH2
03@d=0809BDU0P0W9bL202h^;P80;2`/0P0l?3`203Lg=`80:BTY0P0X:2P202LW9`80=cLg0P1[Jf/2
04e=C@809bLW0P0Z:RX202`/;080?clo101MGEd203Xj>P@0>c/k0P0X:2P202XZ:P80GEeM0P1eMGD2
03hn?P80:2PX0P0/;2`00`0X:2P09BDU02DU9@02020P8080:BTY0P0[:b/204U9B@80N7Qh0P27QhL2
07EeM@80Hf=S0P1LG5`206IVIP80NGUi0P2JVYX20;^k^`80/;2`0P2QXJ420:2PX080Y:BT0P2SXj<2
0:FUY@80XZ:R0P2LW9`409jNWP80Xj>S0P2VYZH20:n_[`80_;bl0P2n_[h20<;2`P80_;bl00<0]kNg
0;Bd]02d];@00P2l_;`20;Ng]`80^;Rh0P2b/[820:ZZZP80[Zj^0P2i^KT20;Fe]@80[:b/0P2YZJT4
0:JVYP80YjNW0P2KVi/209RHV080VYZJ0P2QXJ420:BTY080Z:RX0P2RXZ820:BTY080YZJV102TY:@2
0:6QX@80YZJV0P2SXj<20:VYZ@@0YjNW00<0[:b/0:^[Z`2[Zj/00P2d];@20;:b/P80[Jf]1P2`/;02
0;:b/P80/;2`0P2b/[820;Bd]0@0[Zj^0P2a/K420;Jf]P80_;bl9`38h=P203Ti>@80;bl_0P0V9RH2
02l_;`80@d=30P0P820204I6AP80@T920P0o?cl203Lg=`80<30`0P1DE5@00`1_Kfl0N7Qh07QhN002
03Xj>P80?Cdm0P12@T8203hn?P80;bl_0P0/;2`2028R8P809bLW0P0/;2`203@d=080>3Ph0P0_;bl2
020P8080;Bd]0P0i>CT206=SH`80D51@0P0S8b<202PX:080=CDe0P12@T8205EEE@80IFEU0P0j>SX0
0`15ADD0=3@d03@d=00202/[:`809bLW0P1HF5P208>3P`80?Cdm0P0J6QX203@d=0809BDU0P0X:2P4
02@T9080;Bd]0P1=CDd206m_K`80Rh^;0P1eMGD2069RHP80EeMG0P1MGEd207moO`80UiNG0P31`L42
0:VYZ@030:JVYP2OWil0WinO0080XZ:R0P2UYJD209jNWP80Y:BT0P2QXJ4209fMW@80WinO0P2QXJ42
0:^[Z`80/;2`0P2k^k/20<71`@80^k^k0P2n_[h20;^k^`80]KFe0P2i^KT20;^k^`80];Bd0P2c/k<2
0:b/[080/K6a0P2b/[820;Bd]0030;2`/02YZJT0ZJVY0080ZZZZ0P2/[:`20::RXP80Vi^K0P2OWil2
09ZJVP80WYjN1P2UYJD20:NWY`H0XZ:R102TY:@20:>SX`80ZZZZ0P2YZJT20:JVYP80Z:RX0P2`/;02
0:f][@80/k>c00<0/K6a0:n_[`2_[jl00P2_[jl20;6a/@80/;2`0P2^[Zh20;Fe]@80/K6a0P2][Jd2
0:j^[P80/k>c0P2h^;P20;^k^ah0b>3H000L0<SPf080>c/k0P0^;Rh202DU9@80;bl_0P10@402024Q
8@80@d=30P11@D420410@080=CDe0P0a<C4205ADE00306m_K`1gMgL0MgMg0080>CTi0P0m?Cd20492
@P80>SXj0P0a<C4202TY:@809BDU0P0X:2P202h^;P80=CDe0P0i>CT202d];@808B4Q0P0^;Rh203Ti
>@80IFEU0P1BDU82024Q8@80:RXZ0P0a<C4204=3@`80EUIF0P1VIVH203Xj>P0304E5A@0b<S80<S8b
0080;bl_0P0V9RH205aLG080OWin0P0n?Sh201TI6@80<C4a0P0Y:BT202DU9@80820P0P0Q8B42038b
<P80BTY:0P1^KVh208Z:RP80N7Qh0P1OGel205UIF@80GemO0P1kNg/209JFUP80`l?30P2XZ:P00`2U
YJD0WYjN09jNWP020:6QX@@0Y:BT0P2SXj<20:2PX080WIfM0P2NWYh20:6QX@80Z:RX0P2`/;020;Vi
^@@0`<300P2m_Kd20;Vi^@80]KFe0P2h^;P20;Zj^P80];Bd102^[Zh20;2`/080/k>c0P2e]KD00`2_
[jl0ZJVY0:VYZ@020:VYZ@80ZZZZ0P2SXj<209bLW080VYZJ0P2KVi/209nOW`80Y:BT202UYJD20:BT
Y0H0Xj>S0P2VYZH40:RXZ080YjNW0P2ZZZX20:f][@80/;2`0P2b/[800`2`/;00[jn_0:n_[`020:n_
[`80/;2`102a/K440;:b/P80/;2`0P2^[Zh20;:b/P80^;Rh0P2i^KTW0<SPf080=SHf0P0d=3@202@T
9080:2PX0P0m?Cd202`/;080>SXj0P0o?cl403/k>`80<c<c0P17AdL206e]K@80LG5a0P12@T800`0i
>CT0ATI604I6AP0203Hf=P80=3@d0P0U9BD202LW9`80;Rh^0P0/;2`203`l?080=cLg0P0Y:BT202PX
:0809bLW0P0g=cL206][J`80CDe=0P0W9bL202XZ:P80;2`/0P0o?cl405eMG@80>SXj100k>c/202PX
:080:RXZ0P1MGEd207EeM@80?Shn0P0X:2P202`/;00302PX:00U9BD09BDU0080820P0P0Y:BT202/[
:`80BDU90P1hN7P208N7Q`80MGEe0P1SHf<205aLG080IVIV0P1iNGT209ZJVP80^k^k0P2`/;020:6Q
X@80X:2P0P2TY:@20:>SX`80YJFU0P2RXZ8209bLW0@0WYjN0P2SXj<20:JVYP80[jn_0P2l_;`20;jn
_P80`/;20P2l_;`00`2g]kL0];Bd0;Bd]0020;bl_080]kNg0P2h^;P20;:b/P80ZZZZ0P2^[Zh20;Vi
^@80]KFe0P2/[:`20:VYZ@@0YZJV0P2WYjL209^KV`80V9RH0P2JVYX20:6QX@80Y:BT0P2XZ:P20::R
XP80Y:BT0P2VYZH40:BTY080XJ6Q0P2VYZH20:>SX`80ZJVY102WYjL00`2/[:`0Zj^[0:^[Z`020;Bd
]080/[:b0P2][Jd60;2`/080/[:b0P2`/;020;:b/P80];Bd102^[Zh20;6a/@80][Jf0P2l_;`W0<SP
f080>CTi0P0_;bl202HV9P80;bl_0P13@d<2020P8080ATI60P12@T8203lo?`80=cLg0P0`<30205AD
E00306m_K`1hN7P0N7Qh0080>SXj0P0m?Cd20492@P80?Shn0P0_;bl202`/;0808R8R0P0W9bL202`/
;080=3@d0P0h>3P202l_;`80820P0P0];Bd203Ti>@80Hf=S0P1@D50202<S8`80:2PX0P0e=CD20492
@P80EEEE0P1UIFD203Xj>P0304E5A@0d=3@0=3@d0080:b/[0P0W9bL205QHF080Ph>30P0m?Cd201XJ
6P80=3@d0P0U9BD202PX:0@092@T0P0];Bd204e=C@80Kfm_0P2;Rh/207EeM@80HV9R0P1GEeL205eM
G@80Ogmo0P2GUiL20<71`@80ZJVY00<0YZJV09nOW`2OWil00P2RXZ820:FUY@80WYjN0P2TY:@20:6Q
X@80WIfM0P2OWil20:6QX@80Zj^[0P2`/;020;^k^`80`L710P2k^k/20;jn_P80^k^k0P2e]KD20;Vi
^@80^k^k0P2d];@20;>c/`80[:b/0P2a/K420;:b/P80];Bd00<0/;2`0:VYZ@2YZJT00P2ZZZX20:b/
[080XZ:R0P2KVi/209nOW`80VYZJ0P2NWYh60:FUY@80YjNW1P2RXZ840:BTY080Xj>S0P2ZZZX20:VY
Z@80YZJV0P2XZ:P20;2`/080[Jf]0P2c/k<00`2a/K40[jn_0:n_[`020:n_[`80/K6a0P2`/;020:j^
[P80]KFe0P2a/K420:f][@80[Zj^0P2c/k<20;Rh^080^k^k7P38h=P001`0b>3H0P0o?cl204U9B@80
;Bd]0P0_;bl2034a<@80=3@d0P0e=CD203@d=080<S8b0P0];Bd202/[:`80;Rh^00<0>c/k06UYJ@1Y
JFT00P1_Kfl206ATI080Cdm?0P10@40203<c<`80:RXZ0P0V9RH202PX:080;Bd]0P0e=CD203Xj>P80
;bl_0P0T92@202`/;080=3@d0P1IFET2065QH@8092@T0P0W9bL202l_;`80@d=30P1>CTh2055AD@80
=cLg00<0>c/k03<c<`0c<c<00P0c<c<202HV9P80A4A40P1cLg<206][J`80?clo0P0];Bd202<S8`80
8B4Q0P0N7Qh201lO7`808b<S0P0a<C4205ADE080Ng]k0P23Ph<207moO`80Kfm_0P1VIVH206m_K`80
Ogmo0P2YZJT20:b/[0030:f][@2VYZH0YZJV0080XZ:R0P2OWil20:2PX080XJ6Q0P2PX:0209nOW`80
X:2P0P2RXZ820:VYZ@80/;2`0P2h^;P40;no_`80_;bl0P2i^KT20;Ng]`80^[Zj0P2k^k/20;Bd]080
[:b/0P2WYjL20:6QX@80Zj^[0P2j^[X00`2f][H0[jn_0:n_[`020:b/[080ZJVY0P2VYZH20::RXP80
WYjN0P2KVi/209fMW@80X:2P0P2RXZ820:>SX`80YJFU0P2VYZH20:BTY0@0XJ6Q0P2RXZ820:BTY080
YjNW102VYZH20:ZZZP80[Jf]0P2_[jl20;2`/0030:n_[`2^[Zh0[Zj^0080[Zj^0P2_[jl20;6a/@80
/[:b0P2c/k<20;Bd]080/[:b0P2a/K420;Fe]@80^KVi0P2j^[XW0<SPf080@4100P1?Cdl202/[:`80
92@T0P0c<c<203Lg=`80?Cdm0P0_;bl2038b<P80;Bd]0P0^;Rh203Lg=`80@T920P1[Jf/206QXJ003
06EUI@17AdL0AdM70080=SHf0P0k>c/202XZ:P809BDU0P0R8R8202/[:`80>c/k0P0g=cL202h^;P80
9RHV0P0Y:BT203Lg=`80FEUI0P1TI6@202XZ:P809BDU0P0Z:RX204M7A`80DE5A0P1HF5P203Ti>@80
@4100P13@d<202l_;`809bLW0P0l?3`207QhN080LG5a0P11@D42030`<00302<S8`0M7Ad07AdM0080
7QhN100P8202038b<P80De=C0P1bLW8207IfMP80OWin0P1/K6`206=SH`80JVYZ0P23Ph<209jNWP80
];Bd0P2^[Zh20::RXP80WIfM102QXJ420:2PX080WinO102QXJ420:2PX080YZJV0P2][Jd20;bl_080
^k^k102n_[h00`2e]KD0]kNg0;Ng]`020;Vi^@80]kNg0P2d];@20:b/[080W9bL0P2RXZ820;Jf]P80
^KVi0P2f][H20:b/[080Xj>S0P2WYjL20:JVYP80Y:BT0P2KVi/409ZJVP80W9bL0P2QXJ420:JVYP80
ZJVY0P2TY:@20:6QX@80Xj>S0P2RXZ8209jNWP80Y:BT0P2YZJT20:NWY`80YZJV00<0Z:RX0:f][@2]
[Jd00P2`/;020:f][@80[Zj^0P2][Jd20:j^[P80[jn_0P2a/K420;:b/P@0];Bd0P2a/K420;:b/P80
];Bd0P2h^;P20;jn_RL0b>3H0P12@T8204Y:BP80;Bd]0P0_;bl2038b<P@0<c<c0P0b<S82034a<@80
;2`/0P0Z:RX2030`<00303hn?P1WIfL0IfMW0080Kfm_0P1SHf<204a<C080?Shn0P0a<C4202d];@80
9BDU0P0^;Rh202/[:`80=3@d0P0j>SX2030`<08092@T0P0`<30203<c<`80F5QH0P1SHf<2028R8P80
9bLW0P0_;bl20492@P80CTi>0P1ADE4203Hf=P0303`l?00d=3@0=3@d0080=SHf0P0W9bL204A4A080
M7Ad0P1ZJVX204A4A080;bl_0P0Q8B4201dM7@806a/K0P0N7Qh202HV9P80<30`0P1EEED207YjNP80
Ph>30P1nOWh206i^KP80IVIV0P1aLG4207alO080Z:RX0P2][Jd00`2YZJT0YJFU0:FUY@020:2PX080
XZ:R0P2PX:020:BTY080XZ:R0P2OWil209jNWP80XJ6Q0P2/[:`20:j^[P80^;Rh0P2n_[h20;no_`80
_[jn0P2j^[X20;Vi^@80]KFe0P2l_;`20;Fe]@80[:b/0P2VYZH20:>SX`80[Jf]0P2j^[X00`2g]kL0
[jn_0:n_[`020:ZZZP80YjNW0P2VYZH209bLW080XZ:R0P2MWId209ZJVP80XJ6Q0P2RXZ820:BTY080
YjNW0P2XZ:P20:NWY`80XZ:R0P2SXj<20:BTY080XJ6Q0P2XZ:P20:VYZ@80YjNW0P2XZ:P20:j^[P80
[jn_0P2a/K400`2][Jd0[Zj^0:j^[P020:^[Z`80[:b/0P2c/k<20;:b/P80^;Rh0P2b/[820;Fe]@80
/K6a0P2e]KD20;Rh^080^[Zj7P38h=P001`0b>3H0P0o?cl204U9B@80;Bd]0P0_;bl2034a<@80=3@d
0P0e=CD203@d=080<S8b0P0];Bd202/[:`80;Rh^00<0>c/k06UYJ@1YJFT00P1_Kfl206ATI080Cdm?
0P10@40203<c<`80:RXZ0P0V9RH202PX:080;Bd]0P0e=CD203Xj>P80;bl_0P0T92@202`/;080=3@d
0P1IFET2065QH@8092@T0P0W9bL202l_;`80@d=30P1>CTh2055AD@80=cLg00<0>c/k03<c<`0c<c<0
0P0c<c<202HV9P80A4A40P1cLg<206][J`80?clo0P0];Bd202<S8`808B4Q0P0N7Qh201lO7`808b<S
0P0a<C4205ADE080Ng]k0P23Ph<207moO`80Kfm_0P1VIVH206m_K`80Ogmo0P2YZJT20:b/[0030:f]
[@2VYZH0YZJV0080XZ:R0P2OWil20:2PX080XJ6Q0P2PX:0209nOW`80X:2P0P2RXZ820:VYZ@80/;2`
0P2h^;P40;no_`80_;bl0P2i^KT20;Ng]`80^[Zj0P2k^k/20;Bd]080[:b/0P2WYjL20:6QX@80Zj^[
0P2j^[X00`2f][H0[jn_0:n_[`020:b/[080ZJVY0P2VYZH20::RXP80WYjN0P2KVi/209fMW@80X:2P
0P2RXZ820:>SX`80YJFU0P2VYZH20:BTY0@0XJ6Q0P2RXZ820:BTY080YjNW102VYZH20:ZZZP80[Jf]
0P2_[jl20;2`/0030:n_[`2^[Zh0[Zj^0080[Zj^0P2_[jl20;6a/@80/[:b0P2c/k<20;Bd]080/[:b
0P2a/K420;Fe]@80^KVi0P2j^[XW0<SPf080@4100P1?Cdl202/[:`8092@T0P0c<c<203Lg=`80?Cdm
0P0_;bl2038b<P80;Bd]0P0^;Rh203Lg=`80@T920P1[Jf/206QXJ00306EUI@17AdL0AdM70080=SHf
0P0k>c/202XZ:P809BDU0P0R8R8202/[:`80>c/k0P0g=cL202h^;P809RHV0P0Y:BT203Lg=`80FEUI
0P1TI6@202XZ:P809BDU0P0Z:RX204M7A`80DE5A0P1HF5P203Ti>@80@4100P13@d<202l_;`809bLW
0P0l?3`207QhN080LG5a0P11@D42030`<00302<S8`0M7Ad07AdM00807QhN100P8202038b<P80De=C
0P1bLW8207IfMP80OWin0P1/K6`206=SH`80JVYZ0P23Ph<209jNWP80];Bd0P2^[Zh20::RXP80WIfM
102QXJ420:2PX080WinO102QXJ420:2PX080YZJV0P2][Jd20;bl_080^k^k102n_[h00`2e]KD0]kNg
0;Ng]`020;Vi^@80]kNg0P2d];@20:b/[080W9bL0P2RXZ820;Jf]P80^KVi0P2f][H20:b/[080Xj>S
0P2WYjL20:JVYP80Y:BT0P2KVi/409ZJVP80W9bL0P2QXJ420:JVYP80ZJVY0P2TY:@20:6QX@80Xj>S
0P2RXZ8209jNWP80Y:BT0P2YZJT20:NWY`80YZJV00<0Z:RX0:f][@2][Jd00P2`/;020:f][@80[Zj^
0P2][Jd20:j^[P80[jn_0P2a/K420;:b/P@0];Bd0P2a/K420;:b/P80];Bd0P2h^;P20;jn_RL0b>3H
0P12@T8204Y:BP80;Bd]0P0_;bl2038b<P@0<c<c0P0b<S82034a<@80;2`/0P0Z:RX2030`<00303hn
?P1WIfL0IfMW0080Kfm_0P1SHf<204a<C080?Shn0P0a<C4202d];@809BDU0P0^;Rh202/[:`80=3@d
0P0j>SX2030`<08092@T0P0`<30203<c<`80F5QH0P1SHf<2028R8P809bLW0P0_;bl20492@P80CTi>
0P1ADE4203Hf=P0303`l?00d=3@0=3@d0080=SHf0P0W9bL204A4A080M7Ad0P1ZJVX204A4A080;bl_
0P0Q8B4201dM7@806a/K0P0N7Qh202HV9P80<30`0P1EEED207YjNP80Ph>30P1nOWh206i^KP80IVIV
0P1aLG4207alO080Z:RX0P2][Jd00`2YZJT0YJFU0:FUY@020:2PX080XZ:R0P2PX:020:BTY080XZ:R
0P2OWil209jNWP80XJ6Q0P2/[:`20:j^[P80^;Rh0P2n_[h20;no_`80_[jn0P2j^[X20;Vi^@80]KFe
0P2l_;`20;Fe]@80[:b/0P2VYZH20:>SX`80[Jf]0P2j^[X00`2g]kL0[jn_0:n_[`020:ZZZP80YjNW
0P2VYZH209bLW080XZ:R0P2MWId209ZJVP80XJ6Q0P2RXZ820:BTY080YjNW0P2XZ:P20:NWY`80XZ:R
0P2SXj<20:BTY080XJ6Q0P2XZ:P20:VYZ@80YjNW0P2XZ:P20:j^[P80[jn_0P2a/K400`2][Jd0[Zj^
0:j^[P020:^[Z`80[:b/0P2c/k<20;:b/P80^;Rh0P2b/[820;Fe]@80/K6a0P2e]KD20;Rh^080^[Zj
7P38h=P001`0b>3H0P0l?3`205iNGP80>3Ph0P0`<302028R8P80ADE50P0U9BD202HV9P8092@T0P0V
9RH202`/;080=cLg00<0AdM7059BDP1BDU800P1MGEd2065QH@80GUiN0P1;Bd/203Hf=P80;2`/0P0X
:2P202TY:@80;2`/0P0e=CD203/k>`80<c<c0P0Z:RX202PX:080;bl_0P1=CDd206YZJP80:RXZ0P0U
9BD2030`<0@0ADE50P0m?Cd203@d=00302h^;P0a<C40<C4a0080=SHf0P0_;bl202h^;P80HF5Q0P2>
SXh2069RHP80:2PX100N7Qh201dM7@807QhN0P0M7Ad202DU9@80@d=30P1ZJVX208N7Q`80VYZJ0P2:
RXX207MgM`@0KFe]0P29RHT20:ZZZP030;2`/02^[Zh0[Zj^0080YJFU0P2MWId209jNWPH0XJ6Q0P2R
XZ820:BTY080ZZZZ0P2a/K420;Rh^0@0_Kfm0P2k^k/40;Zj^P@0^k^k0P2c/k<20:VYZ@80Vi^K0P2A
TI420:>SX`<0^k^k0P2e]KD20:f][@@0YJFU0P2VYZH20:6QX@80W9bL0P2JVYX209^KV`80WIfM0P2P
X:020:BTY080YZJV0P2SXj<409nOW`80XJ6Q0P2SXj<40:FUY@80YZJV0P2ZZZX20:f][@D0[Zj^0P2]
[Jd20:j^[P80[jn_0P2a/K420;:b/P80];Bd1P2e]KD20;Rh^0@0^k^k9`38h=P203Xj>P80HV9R0P0d
=3@202TY:@80:2PX0P0i>CT202PX:0809BDU0P0T92@202LW9`80;2`/0P0f=SH203hn?P80CDe=0P1S
Hf<00`1YJFT0HV9R069RHP0203lo?`80=SHf0P0g=cL202PX:080:BTY0P0`<30203Ti>@80?3`l0P0^
;Rh202/[:`80;2`/0P0];Bd2059BDP80I6AT0P0];Bd202HV9P80;Bd]0P1:BTX203`l?080?Shn0P0i
>CT202TY:@80<C4a0P0b<S8202d];@80;Rh^0P1SHf<208b<S080HF5Q0P0Y:BT301lO7`807AdM0P0O
7al2024Q8@80:2PX0P0n?Sh206a/K080SXj>0P2GUiL208B4Q080O7al0P1aLG4206i^KP80QXJ60P2W
YjL20;bl_080[Jf]0P2MWId209jNWP80Xj>S0P2PX:0209nOW`80XZ:R0P2QXJ420:JVYP80[:b/0P2_
[jl20;^k^`80_;bl0P2j^[X20;^k^`030;bl_02k^k/0^k^k00@0^k^k0P2b/[820:j^[P80T92@0P2?
Shl20:^[Z`80]KFe0P2l_;`20;Rh^080YjNW0P2YZJT20:NWY`80YZJV0P2QXJ4209jNWP80VYZJ0P2K
Vi/209bLW080X:2P0P2UYJD20:JVYP80Xj>S0P2NWYh209fMW@80Xj>S0P2QXJ420:JVYP80XJ6Q0`2X
Z:P20;2`/080Zj^[0P2`/;040:f][@@0/;2`0P2^[Zh20;Bd]080]KFe0P2f][H20;:b/P80][Jf0P2h
^;P20;Vi^@80_[jn9`38h=P203Ph>080GemO0P0h>3P202d];@808R8R0P13@d<202HV9P80:BTY100U
9BD202d];@80>CTi00<0ATI6051@D01@D5000P1OGel2069RHP80GemO0P1;Bd/203De=@80;bl_0P0S
8b<402`/;080<C4a0P0m?Cd203@d=0@0:2PX0P0b<S8204];B`80JVYZ0P0Z:RX202@T9080=3@d0P14
A4@204I6AP80?Cdm0P0d=3@00`0_;bl0;Rh^02h^;P0203Hf=P80:b/[0P0^;Rh205mOG`80S8b<0P1S
Hf<202PX:0807alO0P0Q8B42020P80807QhN0P0T92@202<S8`80A4A40P1VIVH208Z:RP80Vi^K0P29
RHT207QhN080Kfm_0P1[Jf/208N7Q`80ZJVY00<0/k>c0:n_[`2_[jl00P2QXJ4209bLW080WYjN0P2P
X:020:6QX@80X:2P0P2RXZ820:BTY080[:b/0P2a/K420;Rh^0@0_[jn0P2j^[X20;Rh^080_Kfm0P2h
^;P20;^k^`80][Jf0P2XZ:P209^KV`80TI6A0P2SXj<20;bl_0030;Zj^P2e]KD0]KFe0080[Zj^0P2U
YJD20:RXZ080YZJV0P2RXZ8209^KV`80VIVI102KVi/20:BTY080XJ6Q0P2TY:@20:FUY@80VYZJ0P2N
WYh20:2PX080WinO0P2VYZH20:>SX`@0YjNW0P2^[Zh20;2`/080[jn_00<0Z:RX0:n_[`2_[jl0102_
[jl20;:b/P80];Bd0P2b/[820;Jf]P@0];Bd102j^[X20;^k^ah0b>3H000L0<SPf080?3`l0P1NGUh2
03Ph>080<30`0P0R8R8204E5A@809BDU0P0V9RH202@T90809RHV0P0/;2`203Lg=`0304M7A`1BDU80
DU9B0080GEeM0P1QHF4205iNGP80Bd];0P0f=SH202`/;080:2PX0P0Y:BT202`/;080=CDe0P0k>c/2
03<c<`80:RXZ0P0X:2P202l_;`80CDe=0P1ZJVX202XZ:P809BDU0P0`<30404E5A@80?Cdm0P0d=3@0
0`0^;Rh0<C4a034a<@0203Hf=P80;bl_0P0^;Rh2065QH@80SXj>0P1RHV8202PX:0@07QhN0P0M7Ad2
01hN7P807AdM0P0U9BD204=3@`80JVYZ0P27QhL209ZJVP80RXZ:0P1gMgL406e]K@80RHV90P2ZZZX0
0`2`/;00[Zj^0:j^[P020:FUY@80WIfM0P2NWYh60:6QX@80XZ:R0P2TY:@20:ZZZP80/K6a0P2h^;P4
0;fm_@80^k^k102j^[X40;^k^`80/k>c0P2YZJT209^KV`80TI6A0P2SXj<30;^k^`80]KFe0P2][Jd4
0:FUY@80YZJV0P2QXJ4209bLW080VYZJ0P2KVi/209fMW@80X:2P0P2TY:@20:JVYP80Xj>S102OWil2
0:6QX@80Xj>S102UYJD20:JVYP80ZZZZ0P2][Jd50:j^[P80[Jf]0P2^[Zh20:n_[`80/K6a0P2b/[82
0;Bd]0H0]KFe0P2h^;P40;^k^bL0b>3H0P0j>SX2069RHP80=3@d0P0Y:BT202PX:080>CTi0P0X:2P2
02DU9@8092@T0P0W9bL202`/;080=SHf0P0n?Sh204e=C@80Hf=S00<0JFUY069RHP1RHV800P0o?cl2
03Hf=P80=cLg0P0X:2P202TY:@80<30`0P0i>CT203`l?080;Rh^0P0[:b/202`/;080;Bd]0P1BDU82
06ATI080;Bd]0P0V9RH202d];@80BTY:0P0l?3`203hn?P80>CTi0P0Y:BT2034a<@80<S8b0P0];Bd2
02h^;P80Hf=S0P2<S8`2065QH@80:BTY0`0O7al201dM7@807alO0P0Q8B4202PX:080?Shn0P1/K6`2
08j>SP80UiNG0P24Q8@207alO080LG5a0P1^KVh208J6QP80YjNW0P2l_;`20:f][@80WIfM0P2NWYh2
0:>SX`80X:2P0P2OWil20::RXP80XJ6Q0P2VYZH20:b/[080[jn_0P2k^k/20;bl_080^[Zj0P2k^k/0
0`2l_;`0^k^k0;^k^`040;^k^`80/[:b0P2^[Zh2092@T080Shn?0P2[Zj/20;Fe]@80_;bl0P2h^;P2
0:NWY`80ZJVY0P2WYjL20:JVYP80XJ6Q0P2NWYh209ZJVP80Vi^K0P2LW9`20:2PX080YJFU0P2VYZH2
0:>SX`80WYjN0P2MWId20:>SX`80XJ6Q0P2VYZH20:6QX@<0Z:RX0P2`/;020:^[Z`80/;2`102][Jd4
0;2`/080[Zj^0P2d];@20;Fe]@80][Jf0P2b/[820;Jf]P80^;Rh0P2i^KT20;jn_RL0b>3H0P0h>3P2
05mOG`80>3Ph0P0];Bd2028R8P80@d=30P0V9RH202TY:@@09BDU0P0];Bd203Ti>@0304I6AP1@D500
D51@0080GemO0P1RHV8205mOG`80Bd];0P0e=CD202l_;`808b<S100/;2`2034a<@80?Cdm0P0d=3@4
02PX:080<S8b0P1;Bd/206YZJP80:RXZ0P0T92@203@d=080A4A40P16ATH203dm?@80=3@d00<0;bl_
02h^;P0^;Rh00P0f=SH202/[:`80;Rh^0P1OGel208b<S080Hf=S0P0X:2P201lO7`808B4Q0P0P8202
01hN7P8092@T0P0S8b<204A4A080IVIV0P2:RXX209^KV`80RHV90P1hN7P206m_K`80Jf][0P27QhL2
0:VYZ@030;>c/`2_[jl0[jn_0080XJ6Q0P2LW9`209jNWP80X:2P0P2QXJ420:2PX080XZ:R0P2TY:@2
0:b/[080/K6a0P2h^;P40;jn_P80^[Zj0P2h^;P20;fm_@80^;Rh0P2k^k/20;Jf]P80Z:RX0P2KVi/2
096AT@80Xj>S0P2l_;`00`2j^[X0]KFe0;Fe]@020:j^[P80YJFU0P2XZ:P20:JVYP80XZ:R0P2KVi/2
09VIV@@0Vi^K0P2TY:@20:6QX@80Y:BT0P2UYJD209ZJVP80WYjN0P2PX:0209nOW`80YZJV0P2SXj<4
0:NWY`80[Zj^0P2`/;020:n_[`030:RXZ02_[jl0[jn_00@0[jn_0P2b/[820;Bd]080/[:b0P2f][H4
0;Bd]0@0^[Zj0P2k^k/N0<SPf0007038h=P202l_;`80Bd];0P12@T8203Hf=P809BDU0P0i>CT202TY
:@809BDU0P0Q8B4202XZ:P80=cLg0P1?Cdl303hn?P80A4A40P1CDe<205eMG@80D51@0P0n?Sh2038b
<P80:BTY0P0Z:RX202l_;`80=3@d0P0h>3P203<c<`80;Bd]0P0X:2P202XZ:P80AdM70P1UIFD203Hf
=P809bLW0P0l?3`205IFEP80=cLg0P0b<S8203/k>`0302@T900[:b/0:b/[0080<C4a0P0d=3@2038b
<P80F5QH0P1kNg/205IFEP8092@T0P0N7Qh2020P80807AdM0P0L71`202LW9`80<C4a0P1MGEd206MW
I`80Ogmo0P29RHT209nOW`80Rh^;0P1iNGT206YZJP80MWIf0P2?Shl00`2QXJ40[jn_0:n_[`020:VY
Z@@0X:2P102QXJ420::RXP80Y:BT0P2WYjL20:j^[P80]KFe0P2j^[X20;bl_080^k^k0P2i^KT40;^k
^`80^[Zj0P2f][H20:n_[`80XZ:R0P22PX8208J6QP80Z:RX0P2c/k<00`2m_Kd0_[jn0;jn_P020;Ng
]`80[Jf]0P2YZJT20:JVYP80XJ6Q0P2MWId209ZJVP80VIVI0P2JVYX209fMW@80WinO0P2PX:0209jN
WP80W9bL0P2NWYh20:6QX@80XZ:R0P2SXj<20:BTY080YZJV0P2YZJT20:b/[0@0[Jf]0`2/[:`20:j^
[P80/;2`0P2a/K420;:b/P80/k>c1P2e]KD20;Rh^080_;bl0P2m_KdW0<SPf0809bLW0P1:BTX205AD
E080<S8b0P0a<C4203`l?080:RXZ100U9BD202PX:080=3@d0P1BDU8204Q8B080?Shn0P0i>CT00`1J
FUX0HV9R069RHP0205=CD`80?Cdm0P0b<S8202HV9P80:2PX0P0Y:BT2038b<P80>CTi0P0g=cL202`/
;0@0:BTY0P10@40206IVIP80>c/k0P0W9bL203/k>`80FUYJ0P0a<C4203@d=080<S8b0P0U9BD202HV
9P80<S8b0P15ADD203@d=080Cdm?0P1jNWX205=CD`808B4Q00<0820P02<S8`0S8b<0100N7Qh2020P
8080<C4a0P1RHV8206MWI`@0SXj>0P2QXJ4208R8R080OGem0P1ZJVX207AdM080R8R80P2SXj<20;:b
/P80YJFU0P2PX:020:BTY080XJ6Q0P2LW9`40::RXP80YJFU0P2_[jl20;>c/`80`<300P2l_;`20;Zj
^P80^KVi00<0^k^k0;Rh^02h^;P00P2k^k/20;Vi^@80[jn_0P2TY:@208Z:RP80Q8B40P2[Zj/20;2`
/080^KVi0P33`l<20;Rh^080[Zj^0P2XZ:P20:JVYP80WinO0P2LW9`209jNWP80W9bL0P2KVi/209RH
V080WYjN0P2PX:0609jNWP80Xj>S0P2PX:020::RXP80YZJV0P2UYJD00`2/[:`0ZZZZ0:ZZZP020:j^
[P80[jn_0P2[Zj/40:b/[080/;2`102_[jl40;Bd]080/k>c0P2g]kL20;Jf]P80_;bl0P2m_KdW0<SP
f080<S8b0P1;Bd/204=3@`80=CDe0P0X:2P203dm?@@09bLW0P0O7al202PX:080>CTi0P1?Cdl00`0o
?cl0>c/k03/k>`0204A4A080EEEE0P1OGel204];B`80?clo0P0e=CD202PX:080:BTY0P0a<C4203@d
=080=SHf0P0e=CD202`/;0809bLW0P0X:2P204A4A080J6QX0P0h>3P202HV9P80?Cdm0P1DE5@203@d
=080<C4a0P0n?Sh00`0U9BD0:BTY02TY:@0203<c<`80=SHf0P0d=3@205MGE`80OWin0P1EEED2024Q
8@806QXJ0P0O7al201dM7@805ADE0P0X:2P202h^;P80FEUI0P1[Jf/208F5Q@80QhN70P2MWId208R8
R080O7al0P1]KFd207QhN080SHf=00<0Y:BT0:j^[P2^[Zh00P2ZZZX20:BTY080WIfM0P2OWil20:>S
X`80YJFU0P2PX:020:RXZ080[jn_0P2g]kL20;Vi^@80_;bl0P2i^KT20;bl_080^KVi102l_;`20;Jf
]P80[Zj^0P2SXj<207inOP80QHF50P2VYZH20;:b/P030;^k^`2n_[h0_[jn0080^[Zj0P2YZJT20:b/
[080YjNW0P2PX:0209bLW080WIfM0P2JVYX409^KV`80VYZJ102PX:0209jNWP80XJ6Q0P2RXZ820:>S
X`80YjNW0P2SXj<20:NWY`80Z:RX0P2ZZZX20;:b/P80[:b/00<0[Zj^0:f][@2][Jd00P2][Jd20;:b
/P80/K6a0P2_[jl20:j^[P80]KFe0P2h^;P20;>c/`@0^k^k0P30`<0N0<SPf0007038h=P202l_;`80
Bd];0P12@T8203Hf=P809BDU0P0i>CT202TY:@809BDU0P0Q8B4202XZ:P80=cLg0P1?Cdl303hn?P80
A4A40P1CDe<205eMG@80D51@0P0n?Sh2038b<P80:BTY0P0Z:RX202l_;`80=3@d0P0h>3P203<c<`80
;Bd]0P0X:2P202XZ:P80AdM70P1UIFD203Hf=P809bLW0P0l?3`205IFEP80=cLg0P0b<S8203/k>`03
02@T900[:b/0:b/[0080<C4a0P0d=3@2038b<P80F5QH0P1kNg/205IFEP8092@T0P0N7Qh2020P8080
7AdM0P0L71`202LW9`80<C4a0P1MGEd206MWI`80Ogmo0P29RHT209nOW`80Rh^;0P1iNGT206YZJP80
MWIf0P2?Shl00`2QXJ40[jn_0:n_[`020:VYZ@@0X:2P102QXJ420::RXP80Y:BT0P2WYjL20:j^[P80
]KFe0P2j^[X20;bl_080^k^k0P2i^KT40;^k^`80^[Zj0P2f][H20:n_[`80XZ:R0P22PX8208J6QP80
Z:RX0P2c/k<00`2m_Kd0_[jn0;jn_P020;Ng]`80[Jf]0P2YZJT20:JVYP80XJ6Q0P2MWId209ZJVP80
VIVI0P2JVYX209fMW@80WinO0P2PX:0209jNWP80W9bL0P2NWYh20:6QX@80XZ:R0P2SXj<20:BTY080
YZJV0P2YZJT20:b/[0@0[Jf]0`2/[:`20:j^[P80/;2`0P2a/K420;:b/P80/k>c1P2e]KD20;Rh^080
_;bl0P2m_KdW0<SPf0809bLW0P1:BTX205ADE080<S8b0P0a<C4203`l?080:RXZ100U9BD202PX:080
=3@d0P1BDU8204Q8B080?Shn0P0i>CT00`1JFUX0HV9R069RHP0205=CD`80?Cdm0P0b<S8202HV9P80
:2PX0P0Y:BT2038b<P80>CTi0P0g=cL202`/;0@0:BTY0P10@40206IVIP80>c/k0P0W9bL203/k>`80
FUYJ0P0a<C4203@d=080<S8b0P0U9BD202HV9P80<S8b0P15ADD203@d=080Cdm?0P1jNWX205=CD`80
8B4Q00<0820P02<S8`0S8b<0100N7Qh2020P8080<C4a0P1RHV8206MWI`@0SXj>0P2QXJ4208R8R080
OGem0P1ZJVX207AdM080R8R80P2SXj<20;:b/P80YJFU0P2PX:020:BTY080XJ6Q0P2LW9`40::RXP80
YJFU0P2_[jl20;>c/`80`<300P2l_;`20;Zj^P80^KVi00<0^k^k0;Rh^02h^;P00P2k^k/20;Vi^@80
[jn_0P2TY:@208Z:RP80Q8B40P2[Zj/20;2`/080^KVi0P33`l<20;Rh^080[Zj^0P2XZ:P20:JVYP80
WinO0P2LW9`209jNWP80W9bL0P2KVi/209RHV080WYjN0P2PX:0609jNWP80Xj>S0P2PX:020::RXP80
YZJV0P2UYJD00`2/[:`0ZZZZ0:ZZZP020:j^[P80[jn_0P2[Zj/40:b/[080/;2`102_[jl40;Bd]080
/k>c0P2g]kL20;Jf]P80_;bl0P2m_KdW0<SPf080<S8b0P1;Bd/204=3@`80=CDe0P0X:2P203dm?@@0
9bLW0P0O7al202PX:080>CTi0P1?Cdl00`0o?cl0>c/k03/k>`0204A4A080EEEE0P1OGel204];B`80
?clo0P0e=CD202PX:080:BTY0P0a<C4203@d=080=SHf0P0e=CD202`/;0809bLW0P0X:2P204A4A080
J6QX0P0h>3P202HV9P80?Cdm0P1DE5@203@d=080<C4a0P0n?Sh00`0U9BD0:BTY02TY:@0203<c<`80
=SHf0P0d=3@205MGE`80OWin0P1EEED2024Q8@806QXJ0P0O7al201dM7@805ADE0P0X:2P202h^;P80
FEUI0P1[Jf/208F5Q@80QhN70P2MWId208R8R080O7al0P1]KFd207QhN080SHf=00<0Y:BT0:j^[P2^
[Zh00P2ZZZX20:BTY080WIfM0P2OWil20:>SX`80YJFU0P2PX:020:RXZ080[jn_0P2g]kL20;Vi^@80
_;bl0P2i^KT20;bl_080^KVi102l_;`20;Jf]P80[Zj^0P2SXj<207inOP80QHF50P2VYZH20;:b/P03
0;^k^`2n_[h0_[jn0080^[Zj0P2YZJT20:b/[080YjNW0P2PX:0209bLW080WIfM0P2JVYX409^KV`80
VYZJ102PX:0209jNWP80XJ6Q0P2RXZ820:>SX`80YjNW0P2SXj<20:NWY`80Z:RX0P2ZZZX20;:b/P80
[:b/00<0[Zj^0:f][@2][Jd00P2][Jd20;:b/P80/K6a0P2_[jl20:j^[P80]KFe0P2h^;P20;>c/`@0
^k^k0P30`<0N0<SPf0007038h=P2028R8P80<S8b0P16ATH203Xj>P80:b/[0P0Z:RX202h^;P80:2PX
0P0U9BD203Hf=P80ATI60P1VIVH00`0l?3`0;bl_02l_;`0202DU9@80?Cdm0P1FEUH205=CD`80B4Q8
0P0h>3P202XZ:P80;2`/0P0a<C4203@d=080=CDe0P0c<c<202l_;`80:2PX0P0W9bL204=3@`80Fe]K
0P13@d<202/[:`80ADE50P1QHF4402/[:`80@41000<0820P02TY:@0Y:BT00P0a<C4203Hf=P80>SXj
0P1@D50205iNGP80@D510P0Q8B4201lO7`808b<S100M7Ad203De=@80Bd];0P1jNWX206ATI080K6a/
0P1[Jf/20:JVYP80Vi^K0P29RHT2071`L080KFe]0P1cLg<00`2?Shl0ZJVY0:VYZ@020:^[Z`80YZJV
0P2SXj<40:6QX@80Xj>S0P2VYZH20:^[Z`80/[:b0P2h^;P20;^k^`80_;bl0P2j^[X20;Rh^080^k^k
0P2l_;`20;Rh^080/;2`0P2WYjL209^KV`80KFe]0P1oOgl20:n_[`80Zj^[00<0_;bl0<C4a034a<@0
0P30`<020;Ng]`80[Zj^0P2VYZH20::RXP80WinO0P2KVi/409VIV@@0VYZJ0P2KVi/409ZJVP80WIfM
1P2QXJ420:>SX`80YZJV0P2YZJT20:^[Z`@0[:b/0`2[Zj/20:j^[PH0/K6a0P2c/k<60;Bd]080^KVi
0P2l_;`20;fm_BL0b>3H0P0Y:BT2034a<@80ADE50P0c<c<202LW9`80<30`0P0/;2`202HV9P80:BTY
0P0d=3@204U9B@80HF5Q0P0k>c/202h^;P80:BTY00<0>c/k05EEE@1EEED00P1HF5P204Y:BP80>CTi
0P0^;Rh202/[:`80;bl_0P0h>3P2034a<@80>CTi0P0Z:RX202`/;080:RXZ0P0l?3`205mOG`80@D51
0P0[:b/204E5A@80GEeM0P0c<c<202d];@80=cLg0P0W9bL202/[:`80;Rh^0P0m?Cd203Hf=P80Cdm?
0P1UIFD203lo?`8092@T00<07alO024Q8@0Q8B40100P820202`/;080Cdm?0P1mOGd206MWI`80GemO
0P1bLW8209^KV`80XJ6Q0P27QhL207AdM080Kfm_0P1jNWX208B4Q080Zj^[0P2_[jl20:>SX`80Y:BT
0P2RXZ8209fMW@@0YZJV0P2ZZZX20;Bd]080]KFe0P2m_Kd20;^k^`80^[Zj0P2f][H00`2o_kl0^k^k
0;^k^`020;Rh^080/K6a0P2PX:0209RHV080M7Ad0P1mOGd20:VYZ@80/;2`0P2l_;`20<?3``80`<30
0P2f][H20:n_[`80YZJV0P2RXZ820:6QX@80VIVI0P2GUiL209^KV`80UYJF0P2KVi/209ZJVP80Vi^K
0P2IVIT209^KV`80X:2P0P2TY:@20:6QX@80Xj>S0P2UYJD00`2YZJT0ZZZZ0:ZZZP020:f][@80ZZZZ
0P2YZJT20:b/[080[jn_102a/K420;Bd]080/;2`0P2g]kL20;Fe]@80]kNg0P2e]KD20;fm_@80`L71
9`38h=P2028R8P80<C4a0P17AdL203Xj>P809bLW0P0/;2`202d];@@09RHV0P0e=CD204Q8B080IFEU
00<0?3`l02`/;00/;2`00P0U9BD203lo?`80EUIF0P1?Cdl204U9B@80>CTi0P0[:b/202PX:080=3@d
0P0b<S8203Lg=`80<c<c0P0_;bl202XZ:P80:2PX0P12@T8205]KF`80@d=30P0[:b/204I6AP80HV9R
100[:b/203hn?P03024Q8@0W9bL09bLW0080;bl_0P0k>c/203Ti>@80Cdm?0P1MGEd20492@P80820P
0P0Q8B4202@T90807QhN0P0M7Ad203Hf=P80CDe=0P1iNGT206MWI`80IVIV0P1]KFd20:VYZ@80W9bL
0P28R8P2071`L080Jf][0P1eMGD00`2<S8`0ZZZZ0:ZZZP020:b/[080Y:BT102SXj<209jNWP80Y:BT
0P2WYjL20:b/[080[jn_0P2g]kL20;jn_P80_;bl0P2m_Kd40;Vi^@80^[Zj0P2m_Kd20;2`/080XZ:R
0P2MWId206i^KP80Ogmo0P2_[jl20:b/[0030;fm_@35aLD0aLG50080`/;20P2g]kL20:n_[`80YJFU
0P2NWYh209nOW`80WYjN0P2HV9P209FEU@H0Vi^K0P2GUiL209bLW080VYZJ0P2QXJ420::RXP80XJ6Q
0P2RXZ820:JVYP80Z:RX0P2ZZZX20;6a/@80ZJVY00<0[Jf]0:ZZZP2ZZZX00P2^[Zh20;2`/080/K6a
0P2b/[820;6a/@80/k>c0P2f][H20;Bd]080/k>c0P2j^[X20<;2`Qh0b>3H000L0<SPf0808R8R0P0b
<S8204I6AP80>SXj0P0[:b/202XZ:P80;Rh^0P0X:2P202DU9@80=SHf0P16ATH206IVIP0303`l?00_
;bl0;bl_00809BDU0P0m?Cd205IFEP80De=C0P18B4P203Ph>080:RXZ0P0/;2`2034a<@80=3@d0P0e
=CD203<c<`80;bl_0P0X:2P202LW9`80@d=30P1KFe/204=3@`80:b/[0P15ADD2065QH@@0:b/[0P10
@4000`0P8200:BTY02TY:@02034a<@80=SHf0P0j>SX2051@D080GUiN0P11@D42024Q8@807alO0P0S
8b<401dM7@80=CDe0P1;Bd/207YjNP80I6AT0P1/K6`206][J`80YZJV0P2KVi/208V9R@80L71`0P1]
KFd207=cL`0308n?S`2YZJT0ZJVY0080Zj^[0P2VYZH20:>SX`@0XJ6Q0P2SXj<20:JVYP80Zj^[0P2b
/[820;Rh^080^k^k0P2l_;`20;Zj^P80^;Rh0P2k^k/20;bl_080^;Rh0P2`/;020:NWY`80Vi^K0P1]
KFd207moO`80[jn_0P2[Zj/00`2l_;`0a<C40<C4a0020<30`080]kNg0P2^[Zh20:JVYP80XZ:R0P2O
Wil209^KV`@0VIVI102JVYX209^KV`@0VYZJ0P2MWId60:6QX@80Xj>S0P2VYZH20:VYZ@80Zj^[102/
[:`30:^[Z`80[Zj^1P2a/K420;>c/`H0];Bd0P2i^KT20;bl_080_Kfm9`38h=P202TY:@80<C4a0P15
ADD203<c<`809bLW0P0`<30202`/;0809RHV0P0Y:BT203@d=080BDU90P1QHF4203/k>`80;Rh^0P0Y
:BT00`0k>c/0EEEE05EEE@0205QHF080BTY:0P0i>CT202h^;P80:b/[0P0_;bl203Ph>080<C4a0P0i
>CT202XZ:P80;2`/0P0Z:RX203`l?080GemO0P11@D4202/[:`80ADE50P1MGEd203<c<`80;Bd]0P0g
=cL202LW9`80:b/[0P0^;Rh203dm?@80=SHf0P1?Cdl206EUI@80?clo0P0T92@00`0O7al08B4Q024Q
8@04020P8080;2`/0P1?Cdl207emO@80IfMW0P1OGel2079bLP80Vi^K0P2QXJ4208N7Q`80M7Ad0P1_
Kfl207YjNP80Q8B40P2[Zj/20:n_[`80Xj>S0P2TY:@20::RXP80WIfM102VYZH20:ZZZP80];Bd0P2e
]KD20;fm_@80^k^k0P2j^[X20;Jf]P030;no_`2k^k/0^k^k0080^;Rh0P2a/K420:2PX080V9RH0P1d
M7@207emO@80ZJVY0P2`/;020;bl_080`l?30P30`<020;Jf]P80[jn_0P2VYZH20::RXP80XJ6Q0P2I
VIT209NGU`80Vi^K0P2FUYH209^KV`80VYZJ0P2KVi/209VIV@80Vi^K0P2PX:020:BTY080XJ6Q0P2S
Xj<20:FUY@030:VYZ@2ZZZX0ZZZZ0080[Jf]0P2ZZZX20:VYZ@80[:b/0P2_[jl40;6a/@80];Bd0P2`
/;020;Ng]`80]KFe0P2g]kL20;Fe]@80_Kfm0P31`L4W0<SPf0808R8R0P0a<C4204M7A`80>SXj0P0W
9bL202`/;080;Bd]100V9RH203De=@80B4Q80P1UIFD00`0l?3`0;2`/02`/;00202DU9@80?clo0P1F
EUH204m?C`80BDU90P0i>CT202/[:`80:2PX0P0d=3@2038b<P80=cLg0P0c<c<202l_;`80:RXZ0P0X
:2P20492@P80Fe]K0P13@d<202/[:`80ATI60P1RHV8402/[:`80?Shn00<08B4Q02LW9`0W9bL00P0_
;bl203/k>`80>CTi0P1?Cdl205eMG@80@T920P0P8202024Q8@8092@T0P0N7Qh201dM7@80=SHf0P1=
CDd207UiN@80IfMW0P1VIVH206e]K@80ZJVY0P2LW9`208R8R080L71`0P1[Jf/207EeM@0308b<S02Z
ZZX0ZZZZ0080[:b/0P2TY:@40:>SX`80WYjN0P2TY:@20:NWY`80[:b/0P2_[jl20;Ng]`80_[jn0P2l
_;`20;fm_@@0^KVi0P2j^[X20;fm_@80/;2`0P2RXZ8209fMW@80KVi^0P1oOgl20:n_[`80[:b/00<0
_Kfm0<G5a@35aLD00P32`/820;Ng]`80[jn_0P2UYJD209jNWP80WinO0P2NWYh209RHV080UIFE1P2K
Vi/209NGU`80W9bL0P2JVYX20:6QX@80XZ:R0P2QXJ420::RXP80YZJV0P2XZ:P20:ZZZP80/K6a0P2Y
ZJT00`2][Jd0ZZZZ0:ZZZP020:j^[P80/;2`0P2a/K420;:b/P80/K6a0P2c/k<20;Jf]P80];Bd0P2c
/k<20;Zj^P80`/;27P38h=P001`0b>3H0P0S8b<202/[:`80>CTi0P0c<c<202/[:`80:2PX0P0[:b/2
02`/;080<30`0P1HF5P205UIF@80Bd];00<0=SHf02/[:`0[:b/00P0W9bL203De=@80AdM70P1ADE42
05=CD`80@D510P0^;Rh202d];@80<30`0P0d=3@203Lg=`80=CDe0P0`<30202TY:@809bLW0P0m?Cd2
04m?C`80DE5A0P0[:b/203dm?@80CTi>0P0^;Rh202/[:`80>3Ph00<0:b/[03Hf=P0f=SH00P15ADD2
02l_;`80=SHf0P19BDT205UIF@80?clo0P0R8R8201lO7`808R8R0P0L71`2020P8080>CTi0P1eMGD2
07alO080Fe]K0P10@40204i>CP80QXJ60P2LW9`209BDU080PH610P1cLg<2071`L0030820P02EUID0
UIFE0080Y:BT0P2^[Zh20:NWY`80WinO0P2QXJ420:JVYP80ZZZZ0P2_[jl20;6a/@80];Bd0P2k^k/2
0<30`080_;bl0P2h^;P20;^k^`80_Kfm0P2g]kL20:n_[`80UiNG0P2MWId206a/K080Ph>30P2b/[82
0:ZZZP030;Vi^@30`<00`<300080`/;20P2o_kl20;Ng]`80[Jf]0P2XZ:P20:BTY080WinO102KVi/2
09fMW@@0WYjN0P2KVi/209RHV080Vi^K0P2PX:020::RXPH0Xj>S0P2WYjL20:^[Z`D0[:b/0P2][Jd2
0:j^[P80/;2`1P2a/K420;:b/P80];Bd0P2g]kL20;Zj^P80_;bl0P2m_KdW0<SPf080:BTY0P0V9RH2
03Hf=P80=cLg0P0X:2P202TY:@80:b/[0P0/;2`203<c<`80B4Q80P1XJ6P204];B`80=SHf0P0U9BD2
038b<P0302h^;P0n?Sh0?Shn0080EeMG0P1>CTh203De=@80=3@d0P0];Bd203`l?080=SHf0P0_;bl2
03/k>`80:RXZ0P0`<30202XZ:P80=SHf0P1IFET204];B`80<S8b0P0m?Cd204i>CP80;bl_0P0a<C42
03Lg=`80<C4a0P0^;Rh20492@P80;Bd]0P0d=3@204i>CP80De=C0P0o?cl302<S8`807alO0P0P8202
02@T9080<c<c0P1cLg<208J6QP80FUYJ0P0a<C4205IFEP80PH610P2OWil209BDU080OGem0P1_Kfl2
07MgM`80NWYj0P2@T9020;Ng]`80ZJVY0P2MWId20::RXP@0YJFU0P2[Zj/20:j^[P@0/k>c0P2j^[X2
0;jn_P80^[Zj0P2i^KT30;^k^`80^[Zj0P2^[Zh209:BTP80VYZJ0P1fMWH20861P@80[:b/0P2[Zj/2
0;Rh^080`<300P32`/820;jn_P80^;Rh0P2ZZZX20:^[Z`80XJ6Q0P2MWId209VIV@80W9bL0P2RXZ82
0:FUY@80VYZJ0P2HV9P209^KV`80V9RH102QXJ420:2PX080Xj>S0P2RXZ800`2XZ:P0ZZZZ0:ZZZP02
0:j^[P80[Jf]0P2/[:`20:j^[P80[Jf]0P2c/k<20:j^[P80/k>c102`/;020;:b/P80]KFe0P2g]kL2
0;^k^`80_Kfm9`38h=P202DU9@80:RXZ0P0h>3P203@d=080;2`/0P0V9RH202/[:`@0;bl_0P1JFUX2
05MGE`80CDe=00<0>3Ph02XZ:P0Z:RX00P0Y:BT203Hf=P80AdM70P1ADE4205IFEP80?clo0P0`<302
02h^;P80<S8b0P0a<C4203Hf=P80=3@d0P0`<30202PX:0809RHV0P0l?3`204m?C`80D51@0P0[:b/2
03hn?P80CDe=0P0/;2`202d];@80>SXj00<0:RXZ03Hf=P0f=SH00P14A4@202h^;P80<c<c0P1:BTX2
05IFEP80A4A4100S8b<201hN7P807alO0P0Q8B4203Xj>P80MgMg0P1jNWX205]KF`80?3`l0P1ADE42
08R8R080VYZJ0P2BTY820820P080MGEe0P1bLW800`1mOGd0UIFE09FEU@020:RXZ080[Jf]0P2WYjL2
09nOW`80XJ6Q0P2TY:@20:^[Z`80[:b/0P2h^;P20;:b/P80^k^k0P2o_kl20;Vi^@80]kNg0P2m_Kd2
0;bl_080^;Rh0P2^[Zh209FEU@80WYjN0P1^KVh208F5Q@80];Bd0P2[Zj/00`2g]kL0`<300<30`002
0;bl_080`<300P2h^;P20:j^[P80Z:RX0P2TY:@209nOW`80Vi^K0P2LW9`20:2PX080WIfM0P2RXZ82
09RHV080UiNG0P2JVYX20:6QX@80WinO0P2SXj<20:2PX080YJFU0P2ZZZX20:JVYP80/;2`0P2WYjL0
0`2[Zj/0[Zj^0:j^[P020:f][@80/K6a0P2g]kL20;Fe]@80/k>c0P2b/[820;Rh^080]kNg0P2m_Kd2
0;bl_080`/;27P38h=P001`0b>3H0P0S8b<202/[:`80>CTi0P0c<c<202/[:`80:2PX0P0[:b/202`/
;080<30`0P1HF5P205UIF@80Bd];00<0=SHf02/[:`0[:b/00P0W9bL203De=@80AdM70P1ADE4205=C
D`80@D510P0^;Rh202d];@80<30`0P0d=3@203Lg=`80=CDe0P0`<30202TY:@809bLW0P0m?Cd204m?
C`80DE5A0P0[:b/203dm?@80CTi>0P0^;Rh202/[:`80>3Ph00<0:b/[03Hf=P0f=SH00P15ADD202l_
;`80=SHf0P19BDT205UIF@80?clo0P0R8R8201lO7`808R8R0P0L71`2020P8080>CTi0P1eMGD207al
O080Fe]K0P10@40204i>CP80QXJ60P2LW9`209BDU080PH610P1cLg<2071`L0030820P02EUID0UIFE
0080Y:BT0P2^[Zh20:NWY`80WinO0P2QXJ420:JVYP80ZZZZ0P2_[jl20;6a/@80];Bd0P2k^k/20<30
`080_;bl0P2h^;P20;^k^`80_Kfm0P2g]kL20:n_[`80UiNG0P2MWId206a/K080Ph>30P2b/[820:ZZ
ZP030;Vi^@30`<00`<300080`/;20P2o_kl20;Ng]`80[Jf]0P2XZ:P20:BTY080WinO102KVi/209fM
W@@0WYjN0P2KVi/209RHV080Vi^K0P2PX:020::RXPH0Xj>S0P2WYjL20:^[Z`D0[:b/0P2][Jd20:j^
[P80/;2`1P2a/K420;:b/P80];Bd0P2g]kL20;Zj^P80_;bl0P2m_KdW0<SPf080:BTY0P0V9RH203Hf
=P80=cLg0P0X:2P202TY:@80:b/[0P0/;2`203<c<`80B4Q80P1XJ6P204];B`80=SHf0P0U9BD2038b
<P0302h^;P0n?Sh0?Shn0080EeMG0P1>CTh203De=@80=3@d0P0];Bd203`l?080=SHf0P0_;bl203/k
>`80:RXZ0P0`<30202XZ:P80=SHf0P1IFET204];B`80<S8b0P0m?Cd204i>CP80;bl_0P0a<C4203Lg
=`80<C4a0P0^;Rh20492@P80;Bd]0P0d=3@204i>CP80De=C0P0o?cl302<S8`807alO0P0P820202@T
9080<c<c0P1cLg<208J6QP80FUYJ0P0a<C4205IFEP80PH610P2OWil209BDU080OGem0P1_Kfl207Mg
M`80NWYj0P2@T9020;Ng]`80ZJVY0P2MWId20::RXP@0YJFU0P2[Zj/20:j^[P@0/k>c0P2j^[X20;jn
_P80^[Zj0P2i^KT30;^k^`80^[Zj0P2^[Zh209:BTP80VYZJ0P1fMWH20861P@80[:b/0P2[Zj/20;Rh
^080`<300P32`/820;jn_P80^;Rh0P2ZZZX20:^[Z`80XJ6Q0P2MWId209VIV@80W9bL0P2RXZ820:FU
Y@80VYZJ0P2HV9P209^KV`80V9RH102QXJ420:2PX080Xj>S0P2RXZ800`2XZ:P0ZZZZ0:ZZZP020:j^
[P80[Jf]0P2/[:`20:j^[P80[Jf]0P2c/k<20:j^[P80/k>c102`/;020;:b/P80]KFe0P2g]kL20;^k
^`80_Kfm9`38h=P202DU9@80:RXZ0P0h>3P203@d=080;2`/0P0V9RH202/[:`@0;bl_0P1JFUX205MG
E`80CDe=00<0>3Ph02XZ:P0Z:RX00P0Y:BT203Hf=P80AdM70P1ADE4205IFEP80?clo0P0`<30202h^
;P80<S8b0P0a<C4203Hf=P80=3@d0P0`<30202PX:0809RHV0P0l?3`204m?C`80D51@0P0[:b/203hn
?P80CDe=0P0/;2`202d];@80>SXj00<0:RXZ03Hf=P0f=SH00P14A4@202h^;P80<c<c0P1:BTX205IF
EP80A4A4100S8b<201hN7P807alO0P0Q8B4203Xj>P80MgMg0P1jNWX205]KF`80?3`l0P1ADE4208R8
R080VYZJ0P2BTY820820P080MGEe0P1bLW800`1mOGd0UIFE09FEU@020:RXZ080[Jf]0P2WYjL209nO
W`80XJ6Q0P2TY:@20:^[Z`80[:b/0P2h^;P20;:b/P80^k^k0P2o_kl20;Vi^@80]kNg0P2m_Kd20;bl
_080^;Rh0P2^[Zh209FEU@80WYjN0P1^KVh208F5Q@80];Bd0P2[Zj/00`2g]kL0`<300<30`0020;bl
_080`<300P2h^;P20:j^[P80Z:RX0P2TY:@209nOW`80Vi^K0P2LW9`20:2PX080WIfM0P2RXZ8209RH
V080UiNG0P2JVYX20:6QX@80WinO0P2SXj<20:2PX080YJFU0P2ZZZX20:JVYP80/;2`0P2WYjL00`2[
Zj/0[Zj^0:j^[P020:f][@80/K6a0P2g]kL20;Fe]@80/k>c0P2b/[820;Rh^080]kNg0P2m_Kd20;bl
_080`/;27P38h=P001`0b>3H0P0V9RH202PX:080:RXZ100[:b/402PX:080<c<c0P10@40207EeM@80
I6AT0P0^;Rh00`0d=3@0;Bd]02d];@02030`<080<C4a0P0g=cL204Y:BP80FEUI0P18B4P203<c<`@0
;Rh^0P0d=3@203Xj>P80=cLg0P0a<C4202/[:`80:BTY0P0i>CT204=3@`80FUYJ0P0^;Rh203@d=080
=cLg0P0c<c<202`/;080;Rh^00<0>CTi04Q8B018B4P00P1IFET202TY:@80=SHf0P15ADD205IFEP80
@T920P0Y:BT4028R8P807AdM0P0X:2P204=3@`80V9RH0P1fMWH204i>CP805aLG0P0c<c<205aLG080
Shn?0P2GUiL2096AT@80PH610P1eMGD00`1fMWH0P8200820P00209VIV@80[jn_0P2ZZZX20:2PX080
Xj>S0P2YZJT20:f][@80/K6a102`/;020;Zj^P80`l?30P2n_[h20;Rh^080^[Zj0P2l_;`20;Fe]@80
/;2`0P28R8P20:2PX080M7Ad0P2:RXX20;>c/`80ZZZZ00<0];Bd0;Vi^@2i^KT00P31`L420<K6aP80
`<300P2g]kL20;2`/080ZJVY0P2SXj<409nOW`80X:2P0P2RXZ820:>SX`80WIfM0P2HV9P209ZJVP80
WYjN0P2QXJ420:BTY080XZ:R0P2PX:020:FUY@80ZZZZ0P2[Zj/20:b/[0030:f][@2^[Zh0[Zj^0080
[Zj^0P2][Jd20:n_[`80/K6a102`/;020;Fe]@80^KVi0P2k^k/40;bl_2L0b>3H0P0S8b<202PX:080
:BTY0P0^;Rh202TY:@@0:RXZ0P0d=3@204M7A`80Jf][0P1OGel203/k>`80<C4a0P0[:b/202l_;`03
030`<00c<c<0<c<c0080CDe=0P1LG5`204I6AP80=SHf0P0];Bd202`/;080=CDe0P0h>3P203Xj>P80
;Bd]0P0/;2`202h^;P80<c<c0P1:BTX205ADE080;bl_0P0d=3@203/k>`80:2PX0P0_;bl202h^;P80
=3@d0P1ADE4205IFEP80:RXZ0P0b<S8204e=C@80DE5A0P11@D4202/[:`0302PX:00S8b<08b<S0080
820P0P0[:b/204E5A@80U9BD0P1kNg/204];B`80820P0P0/;2`206IVIP80QhN70P2PX:02092@T080
NWYj0P1gMgL207moO`80P8200P2EUID20;6a/@80ZZZZ0P2MWId40:NWY`80[Zj^0P2a/K420:j^[P80
/;2`0P2l_;`20<?3``80^k^k0P2h^;P00`2k^k/0^KVi0;Vi^@020;Vi^@80[:b/0P2<S8`209^KV`80
OGem0P28R8P20;2`/080[Jf]0P2a/K420;Zj^P80`<300P35aLD20<71`@80][Jf0P2_[jl20:VYZ@80
Y:BT0P2PX:0209bLW080Vi^K0P2YZJT20::RXP80Ti>C0P2LW9`209fMW@80WinO0P2MWId20:VYZ@80
WIfM0P2QXJ400`2XZ:P0ZJVY0:VYZ@020:VYZ@80Zj^[102^[Zh20:f][@@0[Zj^0P2c/k<40;2`/080
^KVi102h^;P20;Zj^P80`l?39`38h=P202<S8`H0:b/[0P0/;2`202PX:0809RHV0P0g=cL203dm?@80
MWIf0P1TI6@202d];@0303@d=00a<C40<C4a0080;bl_0P0`<30203Hf=P80AdM70P1LG5`204E5A@80
=3@d0P0^;Rh202l_;`80<S8b0P0l?3`203Hf=P80<c<c0P0Z:RX202TY:@80>SXj0P13@d<205QHF080
;Rh^0P0e=CD203Hf=P80=CDe0P0/;2`202d];@0303Ti>@17AdL0AdM70080FUYJ0P0Y:BT203De=@80
BDU90P1EEED20410@080:RXZ0P0R8R8202<S8`806a/K0P0X:2P20451@@80UiNG0P1gMgL204m?C`80
61PH0P0b<S8205]KF`80SXj>0P2IVIT208n?S`80PX:20P1gMgL00`1bLW80PX:208:2PP0209ZJVP80
[jn_0P2/[:`20:6QX@80X:2P0P2ZZZX20:f][@80[jn_0P2e]KD20:^[Z`80^k^k0P32`/820<71`@80
^KVi0P2l_;`20;fm_@80/K6a0P2`/;0208R8R080WYjN0P1fMWH208^;R`80/[:b0P2[Zj/00`2e]KD0
^k^k0;^k^`020<30`080b<S80P30`<020;Jf]P80[jn_0P2XZ:P20:2PX080WinO0P2QXJ4209nOW`80
W9bL0P2SXj<209fMW@80VYZJ0P2HV9P209nOW`80XZ:R0P2SXj<20::RXP80WIfM0P2XZ:P20:FUY@80
[:b/0`2[Zj/20:j^[P80[jn_0P2[Zj/40;2`/080Zj^[0P2`/;020;Jf]P80^;Rh0P2f][H20;fm_@80
_kno7P38h=P001`0b>3H0P0V9RH202PX:080:RXZ100[:b/402PX:080<c<c0P10@40207EeM@80I6AT
0P0^;Rh00`0d=3@0;Bd]02d];@02030`<080<C4a0P0g=cL204Y:BP80FEUI0P18B4P203<c<`@0;Rh^
0P0d=3@203Xj>P80=cLg0P0a<C4202/[:`80:BTY0P0i>CT204=3@`80FUYJ0P0^;Rh203@d=080=cLg
0P0c<c<202`/;080;Rh^00<0>CTi04Q8B018B4P00P1IFET202TY:@80=SHf0P15ADD205IFEP80@T92
0P0Y:BT4028R8P807AdM0P0X:2P204=3@`80V9RH0P1fMWH204i>CP805aLG0P0c<c<205aLG080Shn?
0P2GUiL2096AT@80PH610P1eMGD00`1fMWH0P8200820P00209VIV@80[jn_0P2ZZZX20:2PX080Xj>S
0P2YZJT20:f][@80/K6a102`/;020;Zj^P80`l?30P2n_[h20;Rh^080^[Zj0P2l_;`20;Fe]@80/;2`
0P28R8P20:2PX080M7Ad0P2:RXX20;>c/`80ZZZZ00<0];Bd0;Vi^@2i^KT00P31`L420<K6aP80`<30
0P2g]kL20;2`/080ZJVY0P2SXj<409nOW`80X:2P0P2RXZ820:>SX`80WIfM0P2HV9P209ZJVP80WYjN
0P2QXJ420:BTY080XZ:R0P2PX:020:FUY@80ZZZZ0P2[Zj/20:b/[0030:f][@2^[Zh0[Zj^0080[Zj^
0P2][Jd20:n_[`80/K6a102`/;020;Fe]@80^KVi0P2k^k/40;bl_2L0b>3H0P0S8b<202PX:080:BTY
0P0^;Rh202TY:@@0:RXZ0P0d=3@204M7A`80Jf][0P1OGel203/k>`80<C4a0P0[:b/202l_;`03030`
<00c<c<0<c<c0080CDe=0P1LG5`204I6AP80=SHf0P0];Bd202`/;080=CDe0P0h>3P203Xj>P80;Bd]
0P0/;2`202h^;P80<c<c0P1:BTX205ADE080;bl_0P0d=3@203/k>`80:2PX0P0_;bl202h^;P80=3@d
0P1ADE4205IFEP80:RXZ0P0b<S8204e=C@80DE5A0P11@D4202/[:`0302PX:00S8b<08b<S0080820P
0P0[:b/204E5A@80U9BD0P1kNg/204];B`80820P0P0/;2`206IVIP80QhN70P2PX:02092@T080NWYj
0P1gMgL207moO`80P8200P2EUID20;6a/@80ZZZZ0P2MWId40:NWY`80[Zj^0P2a/K420:j^[P80/;2`
0P2l_;`20<?3``80^k^k0P2h^;P00`2k^k/0^KVi0;Vi^@020;Vi^@80[:b/0P2<S8`209^KV`80OGem
0P28R8P20;2`/080[Jf]0P2a/K420;Zj^P80`<300P35aLD20<71`@80][Jf0P2_[jl20:VYZ@80Y:BT
0P2PX:0209bLW080Vi^K0P2YZJT20::RXP80Ti>C0P2LW9`209fMW@80WinO0P2MWId20:VYZ@80WIfM
0P2QXJ400`2XZ:P0ZJVY0:VYZ@020:VYZ@80Zj^[102^[Zh20:f][@@0[Zj^0P2c/k<40;2`/080^KVi
102h^;P20;Zj^P80`l?39`38h=P202<S8`H0:b/[0P0/;2`202PX:0809RHV0P0g=cL203dm?@80MWIf
0P1TI6@202d];@0303@d=00a<C40<C4a0080;bl_0P0`<30203Hf=P80AdM70P1LG5`204E5A@80=3@d
0P0^;Rh202l_;`80<S8b0P0l?3`203Hf=P80<c<c0P0Z:RX202TY:@80>SXj0P13@d<205QHF080;Rh^
0P0e=CD203Hf=P80=CDe0P0/;2`202d];@0303Ti>@17AdL0AdM70080FUYJ0P0Y:BT203De=@80BDU9
0P1EEED20410@080:RXZ0P0R8R8202<S8`806a/K0P0X:2P20451@@80UiNG0P1gMgL204m?C`8061PH
0P0b<S8205]KF`80SXj>0P2IVIT208n?S`80PX:20P1gMgL00`1bLW80PX:208:2PP0209ZJVP80[jn_
0P2/[:`20:6QX@80X:2P0P2ZZZX20:f][@80[jn_0P2e]KD20:^[Z`80^k^k0P32`/820<71`@80^KVi
0P2l_;`20;fm_@80/K6a0P2`/;0208R8R080WYjN0P1fMWH208^;R`80/[:b0P2[Zj/00`2e]KD0^k^k
0;^k^`020<30`080b<S80P30`<020;Jf]P80[jn_0P2XZ:P20:2PX080WinO0P2QXJ4209nOW`80W9bL
0P2SXj<209fMW@80VYZJ0P2HV9P209nOW`80XZ:R0P2SXj<20::RXP80WIfM0P2XZ:P20:FUY@80[:b/
0`2[Zj/20:j^[P80[jn_0P2[Zj/40;2`/080Zj^[0P2`/;020;Jf]P80^;Rh0P2f][H20;fm_@80_kno
7P38h=P001`0b>3H0P0V9RH202LW9`80:2PX0P0Y:BT202XZ:P809bLW0P0Y:BT20410@080E5AD0P1X
J6P2051@D080=cLg00<0@T9203Xj>P0j>SX00P0d=3@202l_;`80;Rh^0P0n?Sh204a<C080@T920P0e
=CD202l_;`80;Rh^0P0d=3@203Xj>P80>3Ph0P0d=3@2030`<080;Rh^0P0f=SH203hn?P80D51@0P0m
?Cd203Xj>P80=3@d0P0^;Rh202HV9P80;2`/00<0>SXj05eMG@1MGEd00P1NGUh203@d=080BDU90P1:
BTX204U9B@80@T920P0i>CT202d];@809BDU0P0[:b/203Ti>@80JVYZ0P2DU9@206MWI`80=SHf0P0C
4a<202DU9@80@4100P1YJFT208J6QP80UYJF0P2LW9`207UiN@<0M7Ad0P26QXH209ZJVP80YjNW0P2_
[jl20:b/[080Z:RX0P2ZZZX20:j^[P80/;2`0P2c/k<20;Zj^P80`<300P2m_Kd20;Vi^@80]kNg0P2f
][H40;Bd]080QhN70P2NWYh208>3P`80Rh^;0P2c/k<20::RXP030:b/[02c/k<0/k>c0080_[jn0P36
a/H20<G5a@80_kno0P2f][H20:^[Z`80YZJV0P2RXZ820:6QX@80XZ:R0P2SXj<20:BTY080XJ6Q0P2N
WYh209VIV@80UiNG0P2LW9`20:6QX@80X:2P0P2OWil20:>SX`80YjNW102YZJT00`2[Zj/0[Jf]0:f]
[@040:f][@80[Zj^0P2_[jl20;6a/@80/k>c0P2f][H20;Vi^@80_;bl0P2m_Kd20;jn_RL0b>3H0P0[
:b/202PX:0@0:b/[0P0Y:BT202XZ:P80:b/[0P0c<c<205YJFP80K6a/0P1=CDd203lo?`80?Shn0P0m
?Cd203@d=00302l_;`0o?cl0?clo0080@D510P18B4P204];B`80<C4a0P0_;bl202XZ:P80<S8b0P0i
>CT204M7A`80<S8b0P0a<C4202`/;080<30`0P0m?Cd2059BDP80?clo100h>3P202l_;`80:2PX0P0/
;2`203Ph>080J6QX0P1QHF4202h^;P80BTY:0P1ADE4204a<C080B4Q80P0_;bl00`0W9bL08R8R028R
8P0202@T9080;Rh^0P1^KVh2096AT@80JFUY0P0^;Rh201dM7@808b<S0P0f=SH206UYJ@80RXZ:0P2R
XZ8208Z:RP80N7Qh0P1jNWX2079bLP80Ng]k0P2FUYH20;Zj^P80Zj^[102VYZH20:b/[080[Jf]0P2/
[:`20;>c/`80_kno0P32`/820;bl_0<0^[Zj0P2d];@20;Vi^@80[jn_0P29RHT209RHV080QhN70P2;
Rh/20:ZZZP80YZJV0P2][Jd20;Bd]080_;bl0P35aLD20<W9b@80`<300P2b/[820:b/[080YjNW0P2R
XZ820:6QX@80WinO0P2QXJ420:ZZZP80XZ:R0P2LW9`209JFUP80VIVI0P2KVi/20:6QX@80X:2P0P2L
W9`00`2SXj<0YZJV0:JVYP020:VYZ@80ZZZZ0P2[Zj/20:j^[P80ZZZZ0P2^[Zh20:b/[080/;2`0P2[
Zj/20;:b/P80_Kfm0P2k^k/20;Rh^080_kno0P31`L4W0<SPf0808R8R100W9bL202HV9P80:RXZ0P0V
9RH202XZ:P80@4100P1CDe<206YZJP80Cdm?0P0h>3P00`0m?Cd0=CDe03De=@0203<c<`80<S8b0P0d
=3@203/k>`80Bd];0P12@T8203@d=080<C4a0P0^;Rh203@d=080?Cdm0P0g=cL203@d=0@0<30`0P0f
=SH20410@080DE5A0P0k>c/203`l?080<S8b0P0[:b/202<S8`80;Bd]00<0>c/k05eMG@1MGEd00P1N
GUh203Lg=`80B4Q80P1;Bd/204Q8B080A4A40P0e=CD202/[:`809RHV0P0];Bd203Ph>080JVYZ0P2F
UYH206EUI@80<c<c0P0J6QX202<S8`80?Shn0P1[Jf/208N7Q`80UiNG0P2LW9`207UiN@03071`L01f
MWH0MWIf0080QXJ60P2HV9P20:VYZ@80[Zj^0P2][Jd20:ZZZP80YjNW0P2][Jd20;6a/@80][Jf0P2i
^KT20<71`@80^k^k0P2h^;P20;Jf]P@0]kNg0P2e]KD208Z:RP80X:2P0P1oOgl208R8R080/;2`0P2P
X:000`2ZZZX0/k>c0;>c/`020;fm_@80alO70P32`/820;no_`80^[Zj0P2][Jd40:>SX`@0Y:BT0P2R
XZ820:RXZ080XJ6Q0P2MWId209ZJVP80UiNG0P2LW9`20:>SX`80XJ6Q0P2JVYX20:RXZ080ZZZZ0P2/
[:`50:j^[P80[Jf]0P2/[:`20;6a/@80[Zj^0P2`/;020;>c/`80^k^k0P2i^KT20;^k^`80_Kfm0P2j
^[XN0<SPf0007038h=P202HV9P809bLW0P0X:2P202TY:@80:RXZ0P0W9bL202TY:@80@4100P1DE5@2
06QXJ080D51@0P0g=cL00`12@T80>SXj03Xj>P0203@d=080;bl_0P0^;Rh203hn?P80C4a<0P12@T82
03De=@80;bl_0P0^;Rh203@d=080>SXj0P0h>3P203@d=080<30`0P0^;Rh203Hf=P80?Shn0P1@D502
03dm?@80>SXj0P0d=3@202h^;P809RHV0P0/;2`00`0j>SX0GEeM05eMG@0205iNGP80=3@d0P19BDT2
04Y:BP80BDU90P12@T8203Ti>@80;Bd]0P0U9BD202/[:`80>CTi0P1ZJVX209BDU080IfMW0P0f=SH2
01<C4`809BDU0P10@40206UYJ@80QXJ60P2FUYH209bLW080NGUi0`1dM7@208J6QP80VYZJ0P2WYjL2
0:n_[`80[:b/0P2XZ:P20:ZZZP80[Zj^0P2`/;020;>c/`80^[Zj0P30`<020;fm_@80^KVi0P2g]kL2
0;Jf]P@0];Bd0P27QhL209jNWP80Ph>30P2;Rh/20;>c/`80XZ:R00<0[:b/0;>c/`2c/k<00P2n_[h2
0<K6aP80aLG50P2o_kl20;Jf]P80Zj^[0P2VYZH20::RXP80XJ6Q0P2RXZ820:>SX`80Y:BT0P2QXJ42
09jNWP80VIVI0P2GUiL209bLW080XJ6Q0P2PX:0209nOW`80Xj>S0P2WYjL40:VYZ@030:^[Z`2][Jd0
[Jf]00@0[Jf]0P2^[Zh20:n_[`80/K6a0P2c/k<20;Jf]P80^KVi0P2l_;`20;fm_@80_[jn9`38h=P2
02/[:`80:2PX100[:b/202TY:@80:RXZ0P0[:b/203<c<`80FUYJ0P1/K6`204e=C@80?clo0P0n?Sh2
03dm?@80=3@d00<0;bl_03lo?`0o?cl00P11@D4204Q8B080Bd];0P0a<C4202l_;`80:RXZ0P0b<S82
03Ti>@80AdM70P0b<S82034a<@80;2`/0P0`<30203dm?@80DU9B0P0o?cl403Ph>080;bl_0P0X:2P2
02`/;080>3Ph0P1XJ6P2065QH@80;Rh^0P1:BTX2055AD@80C4a<0P18B4P202l_;`0302LW9`0R8R80
8R8R008092@T0P0^;Rh206i^KP80TI6A0P1YJFT202h^;P807AdM0P0S8b<203Hf=P80JFUY0P2:RXX2
0::RXP80RXZ:0P1hN7P207YjNP80LW9b0P1kNg/209JFUP80^[Zj0P2[Zj/40:JVYP80[:b/0P2][Jd2
0:b/[080/k>c0P2o_kl20<;2`P80_;bl0`2j^[X20;Bd]080^KVi0P2_[jl208V9R@80V9RH0P27QhL2
08^;R`80ZZZZ0P2VYZH20:f][@80];Bd0P2l_;`20<G5a@80bLW90P30`<020;:b/P80[:b/0P2WYjL2
0::RXP80XJ6Q0P2OWil20:6QX@80ZZZZ0P2RXZ8209bLW080UYJF0P2IVIT209^KV`80XJ6Q0P2PX:02
09bLW0030:>SX`2VYZH0YZJV0080ZJVY0P2ZZZX20:^[Z`80[Zj^0P2ZZZX20:j^[P80[:b/0P2`/;02
0:^[Z`80/[:b0P2m_Kd20;^k^`80^;Rh0P2o_kl20<71`BL0b>3H0P0R8R8402LW9`809RHV0P0Z:RX2
02HV9P80:RXZ0P10@40205=CD`80JVYZ0P1?Cdl203Ph>00303dm?@0e=CD0=CDe0080<c<c0P0b<S82
03@d=080>c/k0P1;Bd/20492@P80=3@d0P0a<C4202h^;P80=3@d0P0m?Cd203Lg=`80=3@d100`<302
03Hf=P80@4100P1ADE4203/k>`80?3`l0P0b<S8202/[:`808b<S0P0];Bd00`0k>c/0GEeM05eMG@02
05iNGP80=cLg0P18B4P204];B`80B4Q80P14A4@203De=@80:b/[0P0V9RH202d];@80>3Ph0P1ZJVX2
09JFUP80IFEU0P0c<c<201XJ6P808b<S0P0n?Sh206][J`80QhN70P2GUiL209bLW080NGUi00<0L71`
07IfMP1fMWH00P26QXH209RHV080ZJVY0P2^[Zh20:f][@80ZZZZ0P2WYjL20:f][@80/K6a0P2f][H2
0;Vi^@80`L710P2k^k/20;Rh^080][Jf102g]kL20;Fe]@80RXZ:0P2PX:0207moO`80R8R80P2`/;02
0:2PX0030:ZZZP2c/k<0/k>c0080_Kfm0P37alL20<;2`P80_kno0P2j^[X20:f][@@0Xj>S102TY:@2
0::RXP80Z:RX0P2QXJ4209fMW@80VYZJ0P2GUiL209bLW080Xj>S0P2QXJ4209ZJVP80Z:RX0P2ZZZX2
0:b/[0D0[Zj^0P2][Jd20:b/[080/K6a0P2^[Zh20;2`/080/k>c0P2k^k/20;Vi^@80^k^k0P2m_Kd2
0;Zj^Qh0b>3H000L0<SPf0@09bLW0P0X:2P202TY:@80:RXZ0P0W9bL202/[:`80C4a<0P1WIfL2059B
DP80>3Ph0P13@d<00`1=CDd0A4A404A4A00203Ph>080<30`0P0[:b/203<c<`80?3`l0P0k>c/203Lg
=`80<C4a0P0];Bd2038b<P@0>CTi0P0h>3P203@d=080<S8b0P0e=CD203Xj>P80@T920P1:BTX20451
@@80=CDe0P0Y:BT2028R8P80;2`/00<0>SXj06][J`1[Jf/00P1MGEd204A4A080GEeM0P1?Cdl20451
@@80AdM70P1<C4`203Ti>@80:BTY0P0g=cL204U9B@80Shn?0P27QhL205YJFP808b<S0P0J6QX201dM
7@80:BTY0P0o?cl206a/K080T92@0P2_[jl20861P@0307QhN01`L700L71`0080MGEe0P23Ph<20:2P
X080^KVi0P2d];@20:VYZ@80YjNW0P2YZJT20;2`/080]kNg0P2k^k/20;bl_080^k^k0P2i^KT20;Bd
]080/;2`0P2c/k<20;Ng]`80Rh^;0P2JVYX209:BTP80SHf=0P2`/;0209^KV`030:JVYP2_[jl0[jn_
0080^k^k0P35aLD20<S8b080a/K60P2k^k/20:n_[`80Z:RX2P2TY:@20:FUY@80Y:BT0P2JVYX209:B
TP80UYJF102MWId209jNWP80XJ6Q0P2TY:@20:FUY@80YZJV00<0ZJVY0:^[Z`2[Zj/0102/[:`20:f]
[@80[Zj^0P2b/[820;Ng]`80^;Rh0P2i^KT20;bl_080_kno0P30`<0W0<SPf0809BDU0P0W9bL202TY
:@808b<S0P0];Bd202PX:080;bl_0P15ADD206QXJ080EeMG0P0c<c<204M7A`80Bd];0P1>CTh203De
=@0302/[:`0/;2`0;2`/0080;bl_0P0j>SX20492@PH0<C4a0P0`<30203Ti>@80>3Ph0P0e=CD203Hf
=P80<c<c0P0b<S8203Ti>@80B4Q80P1;Bd/203Xj>P80>CTi0P0V9RH202LW9`80;2`/0P0h>3P206YZ
JP80Fe]K0P0l?3`206MWI`80@d=30P12@T82055AD@80AdM700<0=cLg03<c<`0c<c<00P0d=3@204m?
C`80VYZJ0P28R8P2055AD@80:RXZ0P0O7al2024Q8@80820P0P11@D4207QhN080Rh^;0P2ZZZX208F5
Q@80NGUi0P1`L70207MgM`80PH610P2RXZ820;Jf]P80/k>c1P2ZZZX20:f][@80^k^k0P2h^;P20;^k
^`80_[jn0`2d];@20:f][@80][Jf0P2b/[8209>CT`80VYZJ0P2?Shl209FEU@80YjNW0P2QXJ420:BT
Y080/[:b0P2i^KT40<K6aP80aLG50P2l_;`20:j^[P80ZZZZ0P2RXZ820:FUY@80YZJV0P2QXJ420:BT
Y080YZJV0P2WYjL209NGU`80Ti>C102JVYX209jNWP80Vi^K00<0YJFU0::RXP2RXZ800P2YZJT20:FU
Y@80Z:RX0P2[Zj/20:f][@80[jn_0P2[Zj/20:f][@80];Bd0P2e]KD20;Rh^080]kNg0P2l_;`20;jn
_P80`l?39`38h=P202/[:`809bLW0P0Y:BT402XZ:P80:BTY0P0Z:RX204a<C080J6QX0P1ADE4203Lg
=`80AdM700<0CTi>04I6AP16ATH00P0i>CT2030`<080:BTY0P0`<30203dm?@80?Shn0P0e=CD2030`
<080;Bd]0P0d=3@203Hf=P80>CTi0P0f=SH203Lg=`80<C4a0P0d=3@203Xj>P80@T920P19BDT204E5
A@80=3@d0P0W9bL202<S8`80;2`/00<0?3`l06MWI`1WIfL00P1KFe/204Y:BP80FUYJ0P1?Cdl20410
@080B4Q80P1=CDd203Ph>080:2PX0P0j>SX204M7A`80TI6A0P26QXH205eMG@808B4Q0P0M7Ad201`L
7080:b/[0P0n?Sh206m_K`80U9BD0P2[Zj/208:2PP0307YjNP1_Kfl0Kfm_0080Lg=c0P23Ph<209nO
W`80^KVi0P2e]KD20:VYZ@80YJFU0P2[Zj/20;6a/@80]kNg0P2i^KT20;^k^`80_[jn0P2j^[X20;:b
/P80/k>c0P2a/K420;Ng]`80SXj>0P2IVIT209>CT`80Shn?0P2b/[8209bLW0030:RXZ02_[jl0[jn_
0080^;Rh0P38b<P20<O7a`80a/K60P2n_[h20:f][@80YjNW0P2TY:@20:FUY@80YjNW0P2OWil20:JV
YP80Xj>S0P2UYJD209VIV@80T92@0P2GUiL209bLW0@0WinO0P2PX:020:JVYP80XJ6Q0P2UYJD00`2[
Zj/0ZJVY0:VYZ@020:ZZZP80[:b/102^[Zh20;>c/`80];Bd0P2i^KT20;Jf]P80_kno0P2n_[h20<;2
`Qh0b>3H000L0<SPf0@09bLW0P0X:2P202TY:@80:RXZ0P0W9bL202/[:`80C4a<0P1WIfL2059BDP80
>3Ph0P13@d<00`1=CDd0A4A404A4A00203Ph>080<30`0P0[:b/203<c<`80?3`l0P0k>c/203Lg=`80
<C4a0P0];Bd2038b<P@0>CTi0P0h>3P203@d=080<S8b0P0e=CD203Xj>P80@T920P1:BTX20451@@80
=CDe0P0Y:BT2028R8P80;2`/00<0>SXj06][J`1[Jf/00P1MGEd204A4A080GEeM0P1?Cdl20451@@80
AdM70P1<C4`203Ti>@80:BTY0P0g=cL204U9B@80Shn?0P27QhL205YJFP808b<S0P0J6QX201dM7@80
:BTY0P0o?cl206a/K080T92@0P2_[jl20861P@0307QhN01`L700L71`0080MGEe0P23Ph<20:2PX080
^KVi0P2d];@20:VYZ@80YjNW0P2YZJT20;2`/080]kNg0P2k^k/20;bl_080^k^k0P2i^KT20;Bd]080
/;2`0P2c/k<20;Ng]`80Rh^;0P2JVYX209:BTP80SHf=0P2`/;0209^KV`030:JVYP2_[jl0[jn_0080
^k^k0P35aLD20<S8b080a/K60P2k^k/20:n_[`80Z:RX2P2TY:@20:FUY@80Y:BT0P2JVYX209:BTP80
UYJF102MWId209jNWP80XJ6Q0P2TY:@20:FUY@80YZJV00<0ZJVY0:^[Z`2[Zj/0102/[:`20:f][@80
[Zj^0P2b/[820;Ng]`80^;Rh0P2i^KT20;bl_080_kno0P30`<0W0<SPf0809BDU0P0W9bL202TY:@80
8b<S0P0];Bd202PX:080;bl_0P15ADD206QXJ080EeMG0P0c<c<204M7A`80Bd];0P1>CTh203De=@03
02/[:`0/;2`0;2`/0080;bl_0P0j>SX20492@PH0<C4a0P0`<30203Ti>@80>3Ph0P0e=CD203Hf=P80
<c<c0P0b<S8203Ti>@80B4Q80P1;Bd/203Xj>P80>CTi0P0V9RH202LW9`80;2`/0P0h>3P206YZJP80
Fe]K0P0l?3`206MWI`80@d=30P12@T82055AD@80AdM700<0=cLg03<c<`0c<c<00P0d=3@204m?C`80
VYZJ0P28R8P2055AD@80:RXZ0P0O7al2024Q8@80820P0P11@D4207QhN080Rh^;0P2ZZZX208F5Q@80
NGUi0P1`L70207MgM`80PH610P2RXZ820;Jf]P80/k>c1P2ZZZX20:f][@80^k^k0P2h^;P20;^k^`80
_[jn0`2d];@20:f][@80][Jf0P2b/[8209>CT`80VYZJ0P2?Shl209FEU@80YjNW0P2QXJ420:BTY080
/[:b0P2i^KT40<K6aP80aLG50P2l_;`20:j^[P80ZZZZ0P2RXZ820:FUY@80YZJV0P2QXJ420:BTY080
YZJV0P2WYjL209NGU`80Ti>C102JVYX209jNWP80Vi^K00<0YJFU0::RXP2RXZ800P2YZJT20:FUY@80
Z:RX0P2[Zj/20:f][@80[jn_0P2[Zj/20:f][@80];Bd0P2e]KD20;Rh^080]kNg0P2l_;`20;jn_P80
`l?39`38h=P202/[:`809bLW0P0Y:BT402XZ:P80:BTY0P0Z:RX204a<C080J6QX0P1ADE4203Lg=`80
AdM700<0CTi>04I6AP16ATH00P0i>CT2030`<080:BTY0P0`<30203dm?@80?Shn0P0e=CD2030`<080
;Bd]0P0d=3@203Hf=P80>CTi0P0f=SH203Lg=`80<C4a0P0d=3@203Xj>P80@T920P19BDT204E5A@80
=3@d0P0W9bL202<S8`80;2`/00<0?3`l06MWI`1WIfL00P1KFe/204Y:BP80FUYJ0P1?Cdl20410@080
B4Q80P1=CDd203Ph>080:2PX0P0j>SX204M7A`80TI6A0P26QXH205eMG@808B4Q0P0M7Ad201`L7080
:b/[0P0n?Sh206m_K`80U9BD0P2[Zj/208:2PP0307YjNP1_Kfl0Kfm_0080Lg=c0P23Ph<209nOW`80
^KVi0P2e]KD20:VYZ@80YJFU0P2[Zj/20;6a/@80]kNg0P2i^KT20;^k^`80_[jn0P2j^[X20;:b/P80
/k>c0P2a/K420;Ng]`80SXj>0P2IVIT209>CT`80Shn?0P2b/[8209bLW0030:RXZ02_[jl0[jn_0080
^;Rh0P38b<P20<O7a`80a/K60P2n_[h20:f][@80YjNW0P2TY:@20:FUY@80YjNW0P2OWil20:JVYP80
Xj>S0P2UYJD209VIV@80T92@0P2GUiL209bLW0@0WinO0P2PX:020:JVYP80XJ6Q0P2UYJD00`2[Zj/0
ZJVY0:VYZ@020:ZZZP80[:b/102^[Zh20;>c/`80];Bd0P2i^KT20;Jf]P80_kno0P2n_[h20<;2`Qh0
b>3H000L0<SPf080:b/[0P0X:2P202HV9P80:2PX0P0[:b/202PX:080;Bd]0P1?Cdl2075aL@80@410
0P0`<30203De=@0303`l?00k>c/0>c/k0080>CTi0P0f=SH203<c<`80<S8b0P0c<c<203Xj>P80?clo
0P0e=CD202/[:`80;bl_0P0e=CD203Ti>@80>SXj0P0f=SH2038b<P80<C4a0P0c<c<203`l?080AdM7
0P0o?cl203<c<`80:RXZ0P0W9bL203De=@0304E5A@1NGUh0GUiN0080EEEE0P1=CDd2061PH080AdM7
0P1ADE4205EEE@80F5QH0P1GEeL205]KF`80G5aL0P1hN7P20:ZZZP80Rh^;0P1PH60202TY:@807alO
0P0L71`201dM7@80:BTY0P1=CDd2079bLP80Vi^K0P2FUYH00`29RHT0MWIf07IfMP02079bLP80MgMg
0P2>SXh20:JVYP80/k>c0P2i^KT20:n_[`80YJFU0P2][Jd20;Rh^080^[Zj0P2i^KT20;Rh^080][Jf
0P2b/[820;2`/080];Bd0P2f][H209JFUP80TY:B0P2EUID209NGU`80ZJVY0P2NWYh00`2WYjL0[jn_
0:n_[`020;Zj^P80`l?31038b<P20<71`@80^;Rh0P2^[Zh20:FUY@80YZJV102XZ:P20:JVYP80YJFU
0P2SXj<209jNWP80VIVI0P2GUiL209JFUP80V9RH0P2LW9`209nOW`H0Xj>S00<0YjNW0:^[Z`2[Zj/0
202[Zj/20;6a/@80][Jf0P2h^;P20;Zj^P80_Kfm1030`<0W0<SPf080:b/[0P0W9bL202DU9@80;2`/
100Y:BT2034a<@80CDe=0P1^KVh204U9B@80;2`/0P0c<c<203Hf=P80>3Ph0P0n?Sh00`0c<c<0;Rh^
02h^;P0202d];@80=CDe0P0m?Cd204M7A`80<30`0P0];Bd203<c<`80=cLg0P0c<c<203Xj>P80@T92
100a<C4203Lg=`80>c/k0P18B4P203dm?@80=CDe0P0V9RH202@T9080;Rh^0P17AdL206UYJ@80FEUI
0P1>CTh206ATI080?3`l0P1;Bd/205UIF@80HF5Q00<0GEeM05IFEP1FEUH00P1FEUH207MgM`80YZJV
0P2:RXX205iNGP809bLW0P0M7Ad201hN7P80820P0P0Z:RX204I6AP80MWIf0P2JVYX209^KV`80Ph>3
0P1hN7P207]kN`80N7Qh0P21PH420:ZZZP80_[jn0P2f][H20:FUY@80ZZZZ0P2/[:`20;Vi^@80/k>c
0P2h^;P20;^k^`80][Jf00<0]KFe0:b/[02/[:`00P2e]KD20;>c/`80VIVI0P2ATI4209:BTP80V9RH
0P2WYjL20:2PX080Xj>S0P2^[Zh20;Jf]P80`l?30P39bLT20<O7a`80`l?30P2f][H20:f][@80YJFU
0P2WYjL20:RXZ080ZJVY0P2TY:@209nOW`80X:2P0P2VYZH209BDU080Ti>C0P2HV9P209^KV`80W9bL
00<0X:2P09nOW`2OWil00P2SXj<20::RXP80YZJV0P2][Jd20:ZZZP80ZJVY0P2XZ:P20:j^[P80/k>c
0P2g]kL20;Bd]080^[Zj0P2k^k/20;fm_@80_kno9`38h=P202/[:`809BDU0P0T92@202XZ:P@0:2PX
0P0Z:RX2051@D080Kfm_0P11@D4202l_;`80=3@d00<0>c/k03dm?@0m?Cd00P0g=cL203Hf=P80=cLg
0P0`<302038b<P80?Shn0P0o?cl203Lg=`80:BTY0P0^;Rh203Ti>@80=CDe0P0l?3`203Ti>@80;bl_
0P0`<30203@d=080>SXj0P16ATH203hn?P80=CDe0P0Y:BT202XZ:P80=cLg00<0A4A405eMG@1MGEd0
0P1CDe<204m?C`80GemO0P15ADD205=CD`80DE5A0P1KFe/205EEE@80FEUI0P1LG5`207EeM@80ZZZZ
0P28R8P205mOG`809bLW0P0U9BD401TI6@80:2PX0P1<C4`2071`L080UIFE0P2IVIT00`2=SHd0MgMg
07MgM`02079bLP80NWYj0P2@T9020:JVYP80];Bd0P2j^[X20:^[Z`80YZJV0P2[Zj/20;Vi^@80]kNg
0P2k^k/20;Zj^P80][Jf0P2`/;020:n_[`@0/[:b0P2FUYH208n?S`80UIFE0P2HV9P20:FUY@80W9bL
00<0ZJVY0:n_[`2_[jl00P2i^KT20<?3``80alO70P36a/H20<G5a@80]KFe0P2^[Zh20:FUY@80YjNW
102UYJD20:NWY`80Y:BT0P2UYJD209jNWP80WIfM102FUYH209>CT`80WIfM0P2OWil20:>SX`80Vi^K
0P2SXj<00`2[Zj/0ZZZZ0:ZZZP020:b/[080Zj^[0P2YZJT20:^[Z`80[jn_0P2h^;P20;Ng]`80^;Rh
102o_kl20<30`1h0b>3H000L0<SPf080:b/[0P0X:2P202HV9P80:2PX0P0[:b/202PX:080;Bd]0P1?
Cdl2075aL@80@4100P0`<30203De=@0303`l?00k>c/0>c/k0080>CTi0P0f=SH203<c<`80<S8b0P0c
<c<203Xj>P80?clo0P0e=CD202/[:`80;bl_0P0e=CD203Ti>@80>SXj0P0f=SH2038b<P80<C4a0P0c
<c<203`l?080AdM70P0o?cl203<c<`80:RXZ0P0W9bL203De=@0304E5A@1NGUh0GUiN0080EEEE0P1=
CDd2061PH080AdM70P1ADE4205EEE@80F5QH0P1GEeL205]KF`80G5aL0P1hN7P20:ZZZP80Rh^;0P1P
H60202TY:@807alO0P0L71`201dM7@80:BTY0P1=CDd2079bLP80Vi^K0P2FUYH00`29RHT0MWIf07If
MP02079bLP80MgMg0P2>SXh20:JVYP80/k>c0P2i^KT20:n_[`80YJFU0P2][Jd20;Rh^080^[Zj0P2i
^KT20;Rh^080][Jf0P2b/[820;2`/080];Bd0P2f][H209JFUP80TY:B0P2EUID209NGU`80ZJVY0P2N
WYh00`2WYjL0[jn_0:n_[`020;Zj^P80`l?31038b<P20<71`@80^;Rh0P2^[Zh20:FUY@80YZJV102X
Z:P20:JVYP80YJFU0P2SXj<209jNWP80VIVI0P2GUiL209JFUP80V9RH0P2LW9`209nOW`H0Xj>S00<0
YjNW0:^[Z`2[Zj/0202[Zj/20;6a/@80][Jf0P2h^;P20;Zj^P80_Kfm1030`<0W0<SPf080:b/[0P0W
9bL202DU9@80;2`/100Y:BT2034a<@80CDe=0P1^KVh204U9B@80;2`/0P0c<c<203Hf=P80>3Ph0P0n
?Sh00`0c<c<0;Rh^02h^;P0202d];@80=CDe0P0m?Cd204M7A`80<30`0P0];Bd203<c<`80=cLg0P0c
<c<203Xj>P80@T92100a<C4203Lg=`80>c/k0P18B4P203dm?@80=CDe0P0V9RH202@T9080;Rh^0P17
AdL206UYJ@80FEUI0P1>CTh206ATI080?3`l0P1;Bd/205UIF@80HF5Q00<0GEeM05IFEP1FEUH00P1F
EUH207MgM`80YZJV0P2:RXX205iNGP809bLW0P0M7Ad201hN7P80820P0P0Z:RX204I6AP80MWIf0P2J
VYX209^KV`80Ph>30P1hN7P207]kN`80N7Qh0P21PH420:ZZZP80_[jn0P2f][H20:FUY@80ZZZZ0P2/
[:`20;Vi^@80/k>c0P2h^;P20;^k^`80][Jf00<0]KFe0:b/[02/[:`00P2e]KD20;>c/`80VIVI0P2A
TI4209:BTP80V9RH0P2WYjL20:2PX080Xj>S0P2^[Zh20;Jf]P80`l?30P39bLT20<O7a`80`l?30P2f
][H20:f][@80YJFU0P2WYjL20:RXZ080ZJVY0P2TY:@209nOW`80X:2P0P2VYZH209BDU080Ti>C0P2H
V9P209^KV`80W9bL00<0X:2P09nOW`2OWil00P2SXj<20::RXP80YZJV0P2][Jd20:ZZZP80ZJVY0P2X
Z:P20:j^[P80/k>c0P2g]kL20;Bd]080^[Zj0P2k^k/20;fm_@80_kno9`38h=P202/[:`809BDU0P0T
92@202XZ:P@0:2PX0P0Z:RX2051@D080Kfm_0P11@D4202l_;`80=3@d00<0>c/k03dm?@0m?Cd00P0g
=cL203Hf=P80=cLg0P0`<302038b<P80?Shn0P0o?cl203Lg=`80:BTY0P0^;Rh203Ti>@80=CDe0P0l
?3`203Ti>@80;bl_0P0`<30203@d=080>SXj0P16ATH203hn?P80=CDe0P0Y:BT202XZ:P80=cLg00<0
A4A405eMG@1MGEd00P1CDe<204m?C`80GemO0P15ADD205=CD`80DE5A0P1KFe/205EEE@80FEUI0P1L
G5`207EeM@80ZZZZ0P28R8P205mOG`809bLW0P0U9BD401TI6@80:2PX0P1<C4`2071`L080UIFE0P2I
VIT00`2=SHd0MgMg07MgM`02079bLP80NWYj0P2@T9020:JVYP80];Bd0P2j^[X20:^[Z`80YZJV0P2[
Zj/20;Vi^@80]kNg0P2k^k/20;Zj^P80][Jf0P2`/;020:n_[`@0/[:b0P2FUYH208n?S`80UIFE0P2H
V9P20:FUY@80W9bL00<0ZJVY0:n_[`2_[jl00P2i^KT20<?3``80alO70P36a/H20<G5a@80]KFe0P2^
[Zh20:FUY@80YjNW102UYJD20:NWY`80Y:BT0P2UYJD209jNWP80WIfM102FUYH209>CT`80WIfM0P2O
Wil20:>SX`80Vi^K0P2SXj<00`2[Zj/0ZZZZ0:ZZZP020:b/[080Zj^[0P2YZJT20:^[Z`80[jn_0P2h
^;P20;Ng]`80^;Rh102o_kl20<30`1h0b>3H000L0<SPf080;bl_0P0Z:RX202DU9@80:2PX0P0];Bd2
02XZ:P80;bl_0P1BDU8207=cL`80=3@d0P0];Bd202DU9@0302TY:@0_;bl0;bl_0080=cLg0P0l?3`2
03hn?P80=SHf0P0_;bl203/k>`80ADE50P0i>CT202XZ:P80;2`/0P0b<S8203Lg=`80>c/k0P0g=cL2
038b<P80;Rh^0P0];Bd203Lg=`80@4100P0k>c/203<c<`@0;Rh^0P0l?3`304a<C080CTi>0P1FEUH2
061PH080A4A40P1WIfL206EUI@80H61P0P1BDU8204];B`80>CTi0P1VIVH209bLW080SHf=0P1WIfL2
03<c<`808b<S0P0M7Ad201PH60807AdM0P0a<C4204m?C`80Ng]k0P2QXJ400`2HV9P0Ph>308>3P`02
07MgM`80LW9b0P1lO7`208j>SP80[:b/0P33`l<20;Jf]P80Y:BT0P2/[:`20;Ng]`80^;Rh0P2g]kL2
0;Bd]080/K6a102`/;020;>c/`80/[:b0P2OWil208^;R`80U9BD102RXZ820:FUY@030:ZZZP2`/;00
/;2`0080^KVi0P31`L420<G5a@80alO70P35aLD20<30`080/[:b0P2VYZH20:RXZ080[:b/0P2[Zj/2
0:VYZ@80YJFU0P2RXZ840:>SX`80Vi^K0P2CTi<209FEU@80VIVI0P2MWId60:6QX@030:JVYP2ZZZX0
ZZZZ0080ZZZZ102YZJT20:ZZZP80[jn_0P2e]KD20;Rh^080^k^k0P2n_[h20<30`080`L719`38h=P2
02d];@80:BTY0P0V9RH202LW9`80;Rh^0P0X:2P202/[:`80EeMG0P1^KVh203hn?P809bLW0P0[:b/2
02h^;P80:RXZ0P0h>3P00`10@400?clo03lo?`0202l_;`80=CDe0P0g=cL204A4A080=3@d0P0/;2`2
02l_;`80=3@d0P0h>3P203dm?@80=cLg0P0a<C42038b<P80<C4a0P0^;Rh204A4A080?3`l0P0a<C42
02h^;P80<C4a0P0l?3`204];B`80EEEE0P18B4P205UIF@80Fe]K0P15ADD206QXJ080IFEU0P1OGel0
0`1BDU80De=C05=CD`0203hn?P80J6QX0P2TY:@208b<S080Kfm_0P0f=SH202<S8`@07AdM0P0P8202
02TY:@80DU9B0P25QHD209NGU`80Vi^K0P20P80207UiN@80LW9b0P1kNg/208j>SP80[jn_0P30`<02
0;Ng]`80YZJV0P2/[:`20;Rh^080]KFe0P2j^[X20;2`/080/[:b00<0/;2`0;>c/`2c/k<00P2c/k<2
0;6a/@80XJ6Q0P2=SHd2092@T080Y:BT102VYZH20:ZZZP80/K6a0P2g]kL20<30`080alO70P35aLD2
0<[:bP80_[jn0P2`/;020:RXZ080YZJV102][Jd20:^[Z`80Y:BT0P2RXZ820:>SX`80Y:BT0P2MWId2
09FEU@80TY:B0P2KVi/00`2LW9`0XJ6Q0:6QX@020:2PX080XZ:R0P2VYZH20:ZZZP@0Zj^[0P2ZZZX2
0:RXZ080[:b/0P2d];@20;Rh^080^k^k0P2m_Kd20<30`080`L719`38h=P2038b<P80:2PX0P0T92@2
02/[:`@0;Bd]0P0^;Rh2051@D080MGEe0P0c<c<202/[:`809BDU00<0:RXZ038b<P0b<S800P0e=CD2
03lo?`80?Shn0P0e=CD2030`<080>c/k0P15ADD203/k>`80:2PX0P0^;Rh403<c<`80?Shn0P0g=cL2
038b<P80<30`0P0];Bd203De=@80@d=30P0k>c/203<c<`80;Bd]0P0Z:RX203lo?`0304e=C@1;Bd/0
Bd];0080CDe=0P1JFUX2065QH@80A4A40P1XJ6P206=SH`80HF5Q0P1CDe<204Y:BP80?3`l0P1UIFD2
09bLW080SHf=0P1XJ6P203<c<`8092@T0P0N7Qh201PH608071`L0P0d=3@2051@D080N7Qh0P2QXJ40
0`2HV9P0Q8B408B4Q00207AdM080LW9b0P1jNWX208^;R`80[:b/0P32`/820;Ng]`80YJFU0P2YZJT4
0;Rh^080]kNg102a/K420:n_[`@0/[:b0P2f][H20:2PX080S8b<0P2DU9@20:>SX`80Y:BT0P2SXj<0
0`2^[Zh0[Jf]0:f][@020;Zj^P80`/;20P38b<P20<O7a`80`l?30P31`L420:n_[`@0Z:RX0P2_[jl2
0:JVYP80ZZZZ0P2XZ:P20:6QX@80X:2P0P2SXj<209RHV0@0UYJF0P2JVYX209nOW`80Y:BT0P2SXj<2
0::RXP030:>SX`2YZJT0ZJVY0080Zj^[0P2XZ:P40:ZZZP80[Zj^0P2f][H20;Ng]`80_;bl0P31`L42
0;jn_P80_kno7P38h=P001`0b>3H0P0^;Rh202XZ:P809BDU0P0X:2P202d];@80;Rh^0P0c<c<206=S
H`80Jf][0P0m?Cd202PX:08092@T00<0:BTY02d];@0];Bd00P0c<c<20410@080BDU90P0m?Cd2030`
<080=cLg0P0o?cl203Lg=`80;Rh^0P0_;bl2038b<P80=SHf100i>CT203Lg=`80;bl_0P0Z:RX2038b
<P@0>c/k0P0h>3P203De=@80<c<c0P0f=SH00`0m?Cd0ATI604I6AP0205EEE@80HF5Q0P1/K6`206IV
IP80MgMg0P1GEeL2059BDP80@d=30P11@D4203De=@80JFUY0P2ATI4207MgM`80@d=30P0/;2`2020P
80807alO0P0L71`201hN7P8092@T0P0d=3@205UIF@80Ph>300<0UYJF09fMW@2MWId00P29RHT207Qh
N080MWIf0P1nOWh209RHV080/[:b0P2e]KD20;6a/@80[jn_0P2^[Zh20;>c/`80]kNg0P2b/[820:f]
[@@0Zj^[0P2^[Zh20:f][@80W9bL0P28R8P209FEU@@0YjNW0P2ZZZX00`2][Jd0/K6a0;6a/@020;Jf
]P80_;bl0P31`L420<G5a@80a<C40P2o_kl20;Bd]0@0ZJVY0P2/[:`20:ZZZP80ZJVY0P2XZ:P40:NW
Y`80YZJV0P2QXJ4209bLW080V9RH0P2FUYH209NGU`80VIVI0P2MWId20:2PX0030:FUY@2YZJT0ZJVY
00H0ZJVY0P2[Zj/20:n_[`80];Bd0P2h^;P20;^k^`80_[jn0P30`<020<71`BL0b>3H0P0j>SX202LW
9`80:BTY0P0U9BD202h^;P80>CTi0P0d=3@205]KF`80JFUY0P0o?cl202DU9@@09bLW0P0_;bl2030`
<00304M7A`1ADE40DE5A0080?Shn0P0`<30203Ph>080@4100P12@T8202/[:`80:BTY0P0];Bd203Ph
>080=3@d0P0h>3P203Hf=P80:RXZ0P0[:b/202h^;P80>SXj0P18B4P203/k>`80;Bd]0P0i>CT203Ph
>080<c<c0P16ATH204U9B@80IVIV0P1/K6`206m_K`80NGUi0P1IFET204a<C0<0>c/k0P0];Bd205iN
GP80V9RH0P1ZJVX20451@@809BDU0P0O7al201`L7080820P0P0M7Ad202DU9@80;Rh^0P1IFET208>3
P`80XJ6Q0P2FUYH208F5Q@80O7al0P1cLg<207]kN`80Ti>C0P2d];@20;fm_@80ZJVY0P2ZZZX20;2`
/080^;Rh0P2i^KT40:j^[P030:VYZ@2XZ:P0Z:RX0080Zj^[0P2^[Zh209VIV@80RXZ:0P2@T9020:NW
Y`80Z:RX0P2WYjL20:JVYP80][Jf0P2j^[X20;fm_@@0_kno0P34a<@20;no_`80/k>c0P2[Zj/20:FU
Y@80ZJVY0P2/[:`40:NWY`80ZJVY0P2WYjL20::RXP80YJFU0P2IVIT2096AT@80UYJF00<0Vi^K09fM
W@2MWId00P2LW9`209nOW`@0YZJV0P2XZ:P20:NWY`80ZJVY0P2][Jd20:n_[`80]kNg0P2h^;P20;Zj
^P80`L710P32`/820;jn_RL0b>3H0P0a<C4202PX:080:BTY0P0V9RH202/[:`80;Rh^0P0e=CD2069R
HP80Jf][0P10@40202XZ:P<09RHV0P0];Bd203@d=080?clo0P15ADD203lo?`80<30`0P0f=SH203/k
>`80>3Ph100_;bl203@d=080<S8b0P0i>CT203Xj>P80=CDe0P0b<S8202TY:@80<S8b0P0i>CT203hn
?P80=CDe0P0c<c<203De=@80<c<c00<0?3`l04M7A`17AdL00P1EEED2061PH080JFUY0P1TI6@207Ui
N@80EeMG0P1BDU840492@P80=cLg0P1[Jf/208j>SP80N7Qh0P18B4P202XZ:P807AdM0P0Q8B4201`L
7080820P0P0V9RH203Ti>@80FEUI0P23Ph<00`2GUiL0Vi^K09^KV`0208R8R080NGUi0P1hN7P20861
P@80VYZJ0P2c/k<20;Jf]P80];Bd102_[jl20;Bd]080^KVi102`/;020:n_[`80[Jf]0P2/[:`20:VY
Z@80WinO0P26QXH209NGU`@0YZJV0P2XZ:P00`2c/k<0[jn_0:n_[`020;>c/`80^KVi1032`/820<K6
aP80`<300P2h^;P40:VYZ@80/K6a0P2UYJD20:^[Z`80[:b/0P2WYjL20:>SX`80ZZZZ0P2RXZ8209bL
W080UYJF1P2EUID209bLW080Xj>S00<0XZ:R0:^[Z`2[Zj/00P2/[:`20:VYZ@80Zj^[0P2_[jl20:ZZ
ZP80]kNg0P2d];@20;Vi^@80`/;20P2o_kl20<;2`Qh0b>3H000L0<SPf080;Rh^0P0Z:RX202DU9@80
:2PX0P0];Bd202h^;P80<c<c0P1SHf<206][J`80?Cdm0P0X:2P202@T900302TY:@0];Bd0;Bd]0080
<c<c0P10@40204U9B@80?Cdm0P0`<30203Lg=`80?clo0P0g=cL202h^;P80;bl_0P0b<S8203Hf=P@0
>CTi0P0g=cL202l_;`80:RXZ0P0b<S8403/k>`80>3Ph0P0e=CD203<c<`80=SHf00<0?Cdm04I6AP16
ATH00P1EEED2065QH@80K6a/0P1VIVH207MgM`80EeMG0P1BDU8204=3@`80@D510P0e=CD206UYJ@80
TI6A0P1gMgL204=3@`80;2`/0P0P820201lO7`8071`L0P0N7Qh202@T9080=3@d0P1IFET208>3P`03
09JFUP2MWId0WIfM0080RHV90P1hN7P207IfMP80OWin0P2HV9P20;:b/P80]KFe0P2a/K420:n_[`80
[Zj^0P2c/k<20;Ng]`80/[:b0P2][Jd40:^[Z`80[Zj^0P2][Jd209bLW080R8R80P2EUID40:NWY`80
ZZZZ00<0[Jf]0;6a/@2a/K400P2f][H20;bl_080`L710P35aLD20<C4a080_kno0P2d];@40:VYZ@80
[:b/0P2ZZZX20:VYZ@80Z:RX102WYjL20:JVYP80XJ6Q0P2LW9`209RHV080UYJF0P2GUiL209VIV@80
WIfM0P2PX:000`2UYJD0ZJVY0:VYZ@060:VYZ@80Zj^[0P2_[jl20;Bd]080^;Rh0P2k^k/20;jn_P80
`<300P31`L4W0<SPf080>SXj0P0W9bL202TY:@809BDU0P0^;Rh203Ti>@80=3@d0P1KFe/206UYJ@80
?clo0P0U9BD402LW9`80;bl_0P0`<3000`17AdL0DE5A055AD@0203hn?P80<30`0P0h>3P20410@080
@T920P0[:b/202TY:@80;Bd]0P0h>3P203@d=080>3Ph0P0f=SH202XZ:P80:b/[0P0^;Rh203Xj>P80
B4Q80P0k>c/202d];@80>CTi0P0h>3P203<c<`80ATI60P19BDT206IVIP80K6a/0P1_Kfl207UiN@80
FEUI0P1<C4`303/k>`80;Bd]0P1NGUh209RHV080JVYZ0P11@D4202DU9@807alO0P0L71`2020P8080
7AdM0P0U9BD202h^;P80FEUI0P23Ph<20:6QX@80UYJF0P25QHD207alO080Lg=c0P1kNg/209>CT`80
];Bd0P2m_Kd20:VYZ@80ZZZZ0P2`/;020;Rh^080^KVi102^[Zh00`2YZJT0Z:RX0:RXZ0020:^[Z`80
[Zj^0P2IVIT208Z:RP80T92@0P2WYjL20:RXZ080YjNW0P2VYZH20;Jf]P80^[Zj0P2m_Kd40;no_`80
a<C40P2o_kl20;>c/`80Zj^[0P2UYJD20:VYZ@80[:b/102WYjL20:VYZ@80YjNW0P2RXZ820:FUY@80
VIVI0P2ATI4209JFUP0309^KV`2MWId0WIfM0080W9bL0P2OWil40:JVYP80Z:RX0P2WYjL20:VYZ@80
[Jf]0P2_[jl20;Ng]`80^;Rh0P2j^[X20<71`@80`/;20P2n_[hW0<SPf080<C4a0P0X:2P202TY:@80
9RHV0P0[:b/202h^;P80=CDe0P1RHV8206][J`80@4100P0Z:RX302HV9P80;Bd]0P0d=3@203lo?`80
ADE50P0o?cl2030`<080=SHf0P0k>c/203Ph>0@0;bl_0P0d=3@2038b<P80>CTi0P0j>SX203De=@80
<S8b0P0Y:BT2038b<P80>CTi0P0n?Sh203De=@80<c<c0P0e=CD203<c<`0303`l?017AdL0AdM70080
EEEE0P1PH60206UYJ@80I6AT0P1iNGT205MGE`80DU9B1012@T8203Lg=`80Jf][0P2>SXh207QhN080
B4Q80P0Z:RX201dM7@808B4Q0P0L71`2020P80809RHV0P0i>CT205UIF@80Ph>300<0UiNG09^KV`2K
Vi/00P28R8P207UiN@80N7Qh0P21PH4209ZJVP80/k>c0P2f][H20;Bd]0@0[jn_0P2d];@20;Vi^@@0
/;2`0P2_[jl20:f][@80[:b/0P2YZJT209nOW`80QXJ60P2GUiL40:JVYP80Z:RX00<0/k>c0:n_[`2_
[jl00P2c/k<20;Vi^@@0`/;20P36a/H20<30`080^;Rh102YZJT20;6a/@80YJFU0P2[Zj/20:b/[080
YjNW0P2SXj<20:ZZZP80XZ:R0P2LW9`209JFUPH0UIFE0P2LW9`20:>SX`030::RXP2[Zj/0Zj^[0080
[:b/0P2YZJT20:^[Z`80[jn_0P2ZZZX20;Ng]`80];Bd0P2i^KT20<;2`P80_kno0P32`/8N0<SPf000
7038h=P2030`<080;2`/0P0X:2P202XZ:P80;Rh^0P0b<S8203Hf=P80LG5a0P1SHf<204Y:BP@09RHV
00<0;Bd]02`/;00/;2`00P0^;Rh20410@080Cdm?0P13@d<403@d=080=SHf0P0d=3@6038b<P80=3@d
0P0f=SH203Xj>P80?3`l0P0a<C4202PX:080;bl_0P0h>3P203`l?080?Shn0P0k>c/203Lg=`80;bl_
00<0;Bd]04A4A014A4@00P1OGel206UYJ@80LW9b0P20P80208:2PP80A4A40P10@40202h^;P80<30`
0P0a<C4206UYJ@80Ph>30P1LG5`2020P80808b<S0P0N7Qh4028R8P808b<S0P0O7al2024Q8@80>SXj
0P1KFe/00`29RHT0Zj^[0:^[Z`0209^KV`80Ph>30P1gMgL207=cL`80Ph>30P2IVIT20:f][@80_;bl
0P2b/[820:JVYP80[Zj^0P2f][H20;2`/080ZJVY0P2VYZH20:FUY@@0Z:RX0P2FUYH208N7Q`80UYJF
0P2YZJT20:j^[PD0[jn_0P2c/k<20;Ng]`80_Kfm0P32`/820<71`@80_;bl0P2d];@20:b/[0@0ZZZZ
0P2YZJT20:RXZ080Zj^[0P2][Jd20:ZZZP@0Z:RX0P2WYjL209jNWP80UYJF0P2CTi<209BDU080VIVI
0P2OWil00`2TY:@0YjNW0:NWY`020:RXZ080ZJVY0P2ZZZX20:b/[080[jn_0P2c/k<20;Ng]`80^k^k
0P2n_[h40<30`2L0b>3H0P0b<S8202/[:`80<S8b0P0V9RH202l_;`80=CDe0P0h>3P206UYJ@80KFe]
0P11@D4202LW9`80:RXZ0P0Y:BT202l_;`80;Rh^00<0@D5104a<C01<C4`00P17AdL203Ph>080;2`/
0P0f=SH203dm?@80<30`0P0];Bd203<c<`80=cLg0P0b<S820492@P80=CDe0P0g=cL202TY:@80;Rh^
0P0f=SH20451@@80?3`l0P0h>3P203Lg=`80=3@d0P0b<S8203lo?`80H61P0P1bLW8206UYJ@80N7Qh
0P1nOWh2051@D080@41000<0:RXZ03De=@0e=CD00P0f=SH206QXJ080RHV90P1HF5P202TY:@80820P
0P0V9RH2020P808092@T0P0R8R8201hN7P8092@T0P0f=SH205eMG@80TI6A0P2YZJT209BDU080Q8B4
0P1kNg/207MgM`80OGem0P2EUID20;Jf]P80^KVi0P2YZJT20:RXZ080][Jf0P2c/k<20:j^[P80ZZZZ
00<0YZJV0:>SX`2SXj<00P2`/;020:>SX`80U9BD0P2;Rh/208n?S`80ZJVY0P2e]KD20:f][@80[:b/
0P2_[jl20:j^[P80^KVi0P2n_[h20<?3``80_kno0P2j^[X20;Jf]P80[:b/0P2WYjL20:b/[080Zj^[
0P2WYjL20:^[Z`80[Jf]0P2XZ:P20:NWY`80Zj^[0P2UYJD20:2PX080UIFE00<0Ti>C09BDU02DU9@0
0P2GUiL209fMW@80YJFU0P2VYZH20:VYZ@80Zj^[0P2XZ:P40:f][@80/k>c0P2g]kL20;Vi^@80_[jn
0P2o_kl20;jn_RL0b>3H0P0_;bl202h^;P80:2PX0P0W9bL2034a<@80;Rh^0P0g=cL2079bLP80I6AT
0P1:BTX202<S8`809RHV00<0;2`/02d];@0];Bd00P0];Bd20410@080CTi>0P14A4@203@d=080=CDe
0P0g=cL203Ph>080;bl_0P0b<S82030`<080=SHf0P0e=CD203Xj>P80?3`l0P0c<c<202LW9`80;2`/
0P0f=SH20451@@80?Shn0P0h>3P203Xj>P80:b/[00<0<C4a04I6AP16ATH00P1MGEd206YZJP80MGEe
1020P80204I6AP80@410100`<30202h^;P80Jf][0P21PH4205]KF`@08R8R0P0O7al2024Q8@808b<S
0P0R8R8201lO7`80820P0P0i>CT205eMG@0308V9R@2[Zj/0Zj^[0080W9bL0P21PH4207EeM@80L71`
0P26QXH209JFUP80[Zj^0P2l_;`20;>c/`80ZJVY0P2ZZZX20;Rh^080[Zj^0P2XZ:P20:FUY@80Y:BT
0P2VYZH20:ZZZP80VIVI0P27QhL209:BTP80[:b/0P2`/;020:n_[`030;:b/P2^[Zh0[Zj^0080];Bd
0P2h^;P20<30`080`L710P30`<020;Zj^P80^;Rh0P2[Zj/20:FUY@80[Jf]0P2WYjL20:ZZZP80ZJVY
0P2^[Zh20:NWY`@0Z:RX0P2ZZZX209fMW@80UiNG0P2DU9@209FEU@80VYZJ0`2PX:020:FUY@80Zj^[
0P2UYJD20:VYZ@80[:b/0P2][Jd20;Fe]@80]kNg0P2j^[X20<?3``80_[jn0P2o_klN0<SPf0007038
h=P2030`<080;2`/0P0X:2P202XZ:P80;Rh^0P0b<S8203Hf=P80LG5a0P1SHf<204Y:BP@09RHV00<0
;Bd]02`/;00/;2`00P0^;Rh20410@080Cdm?0P13@d<403@d=080=SHf0P0d=3@6038b<P80=3@d0P0f
=SH203Xj>P80?3`l0P0a<C4202PX:080;bl_0P0h>3P203`l?080?Shn0P0k>c/203Lg=`80;bl_00<0
;Bd]04A4A014A4@00P1OGel206UYJ@80LW9b0P20P80208:2PP80A4A40P10@40202h^;P80<30`0P0a
<C4206UYJ@80Ph>30P1LG5`2020P80808b<S0P0N7Qh4028R8P808b<S0P0O7al2024Q8@80>SXj0P1K
Fe/00`29RHT0Zj^[0:^[Z`0209^KV`80Ph>30P1gMgL207=cL`80Ph>30P2IVIT20:f][@80_;bl0P2b
/[820:JVYP80[Zj^0P2f][H20;2`/080ZJVY0P2VYZH20:FUY@@0Z:RX0P2FUYH208N7Q`80UYJF0P2Y
ZJT20:j^[PD0[jn_0P2c/k<20;Ng]`80_Kfm0P32`/820<71`@80_;bl0P2d];@20:b/[0@0ZZZZ0P2Y
ZJT20:RXZ080Zj^[0P2][Jd20:ZZZP@0Z:RX0P2WYjL209jNWP80UYJF0P2CTi<209BDU080VIVI0P2O
Wil00`2TY:@0YjNW0:NWY`020:RXZ080ZJVY0P2ZZZX20:b/[080[jn_0P2c/k<20;Ng]`80^k^k0P2n
_[h40<30`2L0b>3H0P0b<S8202/[:`80<S8b0P0V9RH202l_;`80=CDe0P0h>3P206UYJ@80KFe]0P11
@D4202LW9`80:RXZ0P0Y:BT202l_;`80;Rh^00<0@D5104a<C01<C4`00P17AdL203Ph>080;2`/0P0f
=SH203dm?@80<30`0P0];Bd203<c<`80=cLg0P0b<S820492@P80=CDe0P0g=cL202TY:@80;Rh^0P0f
=SH20451@@80?3`l0P0h>3P203Lg=`80=3@d0P0b<S8203lo?`80H61P0P1bLW8206UYJ@80N7Qh0P1n
OWh2051@D080@41000<0:RXZ03De=@0e=CD00P0f=SH206QXJ080RHV90P1HF5P202TY:@80820P0P0V
9RH2020P808092@T0P0R8R8201hN7P8092@T0P0f=SH205eMG@80TI6A0P2YZJT209BDU080Q8B40P1k
Ng/207MgM`80OGem0P2EUID20;Jf]P80^KVi0P2YZJT20:RXZ080][Jf0P2c/k<20:j^[P80ZZZZ00<0
YZJV0:>SX`2SXj<00P2`/;020:>SX`80U9BD0P2;Rh/208n?S`80ZJVY0P2e]KD20:f][@80[:b/0P2_
[jl20:j^[P80^KVi0P2n_[h20<?3``80_kno0P2j^[X20;Jf]P80[:b/0P2WYjL20:b/[080Zj^[0P2W
YjL20:^[Z`80[Jf]0P2XZ:P20:NWY`80Zj^[0P2UYJD20:2PX080UIFE00<0Ti>C09BDU02DU9@00P2G
UiL209fMW@80YJFU0P2VYZH20:VYZ@80Zj^[0P2XZ:P40:f][@80/k>c0P2g]kL20;Vi^@80_[jn0P2o
_kl20;jn_RL0b>3H0P0_;bl202h^;P80:2PX0P0W9bL2034a<@80;Rh^0P0g=cL2079bLP80I6AT0P1:
BTX202<S8`809RHV00<0;2`/02d];@0];Bd00P0];Bd20410@080CTi>0P14A4@203@d=080=CDe0P0g
=cL203Ph>080;bl_0P0b<S82030`<080=SHf0P0e=CD203Xj>P80?3`l0P0c<c<202LW9`80;2`/0P0f
=SH20451@@80?Shn0P0h>3P203Xj>P80:b/[00<0<C4a04I6AP16ATH00P1MGEd206YZJP80MGEe1020
P80204I6AP80@410100`<30202h^;P80Jf][0P21PH4205]KF`@08R8R0P0O7al2024Q8@808b<S0P0R
8R8201lO7`80820P0P0i>CT205eMG@0308V9R@2[Zj/0Zj^[0080W9bL0P21PH4207EeM@80L71`0P26
QXH209JFUP80[Zj^0P2l_;`20;>c/`80ZJVY0P2ZZZX20;Rh^080[Zj^0P2XZ:P20:FUY@80Y:BT0P2V
YZH20:ZZZP80VIVI0P27QhL209:BTP80[:b/0P2`/;020:n_[`030;:b/P2^[Zh0[Zj^0080];Bd0P2h
^;P20<30`080`L710P30`<020;Zj^P80^;Rh0P2[Zj/20:FUY@80[Jf]0P2WYjL20:ZZZP80ZJVY0P2^
[Zh20:NWY`@0Z:RX0P2ZZZX209fMW@80UiNG0P2DU9@209FEU@80VYZJ0`2PX:020:FUY@80Zj^[0P2U
YJD20:VYZ@80[:b/0P2][Jd20;Fe]@80]kNg0P2j^[X20<?3``80_[jn0P2o_klN0<SPf0007038h=P2
0451@@80?Cdm0P0f=SH202l_;`80;2`/0P0`<30203Ti>@80IfMW0P1YJFT204m?C`80:RXZ0P0X:2P0
0`0];Bd0:b/[02/[:`0202/[:`80>3Ph1013@d<203lo?`80>SXj100f=SH203De=@80<C4a0P0^;Rh2
02l_;`80<S8b0P0h>3P203/k>`80<S8b0P0Y:BT2030`<080>c/k0P0n?Sh203lo?`80>SXj0P0d=3@2
038b<P0303De=@1>CTh0CTi>0080GemO0P1/K6`205]KF`80HF5Q0P1nOWh203Ti>@80=SHf0P0Z:RX2
030`<080>SXj0P1nOWh208F5Q@80ATI60P0T92@202LW9`808b<S100T92@202<S8`@0820P0P0W9bL2
03Ph>00306=SH`2;Rh/0Rh^;0080YjNW0P2EUID20861P@80LG5a0P1cLg<207inOP80VIVI0P2b/[82
0;>c/`@0[jn_0P2^[Zh20:ZZZP80YZJV102UYJD20:NWY`80YZJV0P2CTi<208F5Q@80UIFE0P2YZJT4
0:n_[`030:ZZZP2VYZH0YZJV0080[jn_0P2j^[X20;jn_P80`<300P2o_kl20;^k^`80]KFe0P2^[Zh2
0:^[Z`80ZJVY0P2XZ:P20:VYZ@80Zj^[0P2][Jd20:^[Z`80ZZZZ0P2[Zj/20:b/[080Z:RX0P2RXZ82
09^KV`@0UIFE0P2HV9P00`2OWil0YZJV0:JVYP020:NWY`80Z:RX0P2ZZZX20:b/[080[Zj^0P2a/K42
0;Bd]080^;Rh0P2k^k/20;jn_P80_kno9`38h=P203lo?`80=cLg0P0^;Rh202XZ:P@0;2`/0P0l?3`2
06QXJ080KFe]0P1=CDd202h^;P80<C4a0P0/;2`402/[:`03030`<00n?Sh0?Shn0080AdM70P0o?cl2
038b<P80<c<c0P0k>c/203De=@80<S8b0P0e=CD2034a<@80=cLg0P0f=SH204A4A080;Rh^0P0[:b/2
02h^;P80>c/k0P0n?Sh20410@080>CTi100b<S8203Lg=`80CTi>0P1SHf<206i^KP80IfMW0P1LG5`2
07YjNP80?clo0P0g=cL00`0];Bd0<c<c03<c<`0203/k>`80P8200P29RHT204M7A`809BDU0P0T92@2
02PX:0807alO0P0T92@202<S8`80:2PX0P0S8b<202TY:@80:b/[0P1RHV82096AT@80YJFU0P2EUID2
0861P@80M7Ad0P1bLW8207]kN`80X:2P0P2e]KD20;Vi^@80YJFU0P2^[Zh20:f][@80Z:RX0P2YZJT0
0`2QXJ40Z:RX0:RXZ0020:RXZ080ZZZZ0P2FUYH208N7Q`80SXj>0P2YZJT20;Jf]P80/K6a0P2YZJT2
0:RXZ080[jn_0P2i^KT20;bl_080`<300P36a/H20;Vi^@80^;Rh0P2_[jl20:NWY`80ZZZZ0P2[Zj/2
0:VYZ@80ZZZZ0P2/[:`20:VYZ@80Zj^[0P2^[Zh20:ZZZP80[jn_0P2QXJ400`2FUYH0Ti>C09>CT`02
09FEU@80W9bL0P2SXj<20:JVYP80YJFU0P2YZJT20:NWY`80[Zj^0P2/[:`20;:b/P80/;2`0P2j^[X2
0;fm_@80_kno0P2i^KTW0<SPf080@4100P0i>CT203De=@80<S8b0P0];Bd2034a<@80>CTi0P1XJ6P2
06IVIP80CDe=0P0Y:BT202`/;00302h^;P0];Bd0;Bd]0080:b/[0P0i>CT204Q8B080@T920P0n?Sh2
03/k>`80=SHf0P0c<c<203Lg=`80<C4a0P0^;Rh203@d=080<S8b0P0f=SH203`l?080<30`0P0/;2`2
03<c<`80>SXj0P12@T820410@080>CTi0P0f=SH2034a<@0303De=@1>CTh0CTi>0080HF5Q0P1ZJVX2
05YJFP80H61P0P1oOgl203Ti>@80=CDe0P0X:2P2038b<P80=cLg0P1mOGd208V9R@80A4A40P0T92@2
02PX:0808R8R100T92@2028R8P8071`L0P0Q8B4202HV9P80>3Ph00<0H61P08f=S@2=SHd00P2UYJD2
09JFUP80Q8B40P1/K6`207QhN080Ng]k0P2EUID40;2`/0@0[Jf]0P2_[jl20:VYZ@80YjNW0P2UYJD2
0:JVYP80Z:RX0P2SXj<209JFUP80QHF50P2@T9020:VYZ@80[Jf]0P2/[:`00`2YZJT0YJFU0:FUY@02
0:j^[P80^KVi0P2o_kl20<71`@80^k^k0P2h^;P20;Vi^@80[:b/0P2^[Zh20:RXZ080YZJV0P2XZ:P2
0:b/[080[jn_102ZZZX20:b/[080ZJVY0P2UYJD20:>SX`80VYZJ0P2GUiL209FEU@80VIVI00<0WYjN
0:JVYP2VYZH00P2XZ:P40:ZZZP@0[Jf]0P2c/k<20;Bd]080][Jf0P2n_[h20;Zj^P80`<307P38h=P0
01`0b>3H0P11@D4203dm?@80=SHf0P0_;bl202`/;080<30`0P0i>CT206MWI`80JFUY0P1?Cdl202XZ
:P80:2PX00<0;Bd]02/[:`0[:b/00P0[:b/203Ph>0@0@d=30P0o?cl203Xj>P@0=SHf0P0e=CD2034a
<@80;Rh^0P0_;bl2038b<P80>3Ph0P0k>c/2038b<P80:BTY0P0`<30203/k>`80?Shn0P0o?cl203Xj
>P80=3@d0P0b<S800`0e=CD0CTi>04i>CP0205mOG`80K6a/0P1KFe/2065QH@80OWin0P0i>CT203Hf
=P80:RXZ0P0`<30203Xj>P80OWin0P25QHD204I6AP8092@T0P0W9bL202<S8`@092@T0P0S8b<4020P
80809bLW0P0h>3P00`1SHf<0Rh^;08^;R`020:NWY`80UIFE0P21PH42075aL@80Lg=c0P1nOWh209VI
V@80/[:b0P2c/k<40:n_[`80[Zj^0P2ZZZX20:JVYP@0YJFU0P2WYjL20:JVYP80Ti>C0P25QHD209FE
U@80ZJVY102_[jl00`2ZZZX0YZJV0:JVYP020:n_[`80^[Zj0P2n_[h20<30`080_kno0P2k^k/20;Fe
]@80[Zj^0P2[Zj/20:VYZ@80Z:RX0P2YZJT20:^[Z`80[Jf]0P2[Zj/20:ZZZP80Zj^[0P2/[:`20:RX
Z080XZ:R0P2KVi/409FEU@80V9RH00<0WinO0:JVYP2VYZH00P2WYjL20:RXZ080ZZZZ0P2/[:`20:j^
[P80/K6a0P2d];@20;Rh^080^k^k0P2n_[h20;no_bL0b>3H0P0o?cl203Lg=`80;Rh^0P0Z:RX402`/
;080?3`l0P1XJ6P206e]K@80CDe=0P0^;Rh2034a<@80;2`/100[:b/00`0`<300?Shn03hn?P0204M7
A`80?clo0P0b<S8203<c<`80>c/k0P0e=CD2038b<P80=CDe0P0a<C4203Lg=`80=SHf0P14A4@202h^
;P80:b/[0P0^;Rh203/k>`80?Shn0P10@40203Ti>@@0<S8b0P0g=cL204i>CP80Hf=S0P1^KVh206MW
I`80G5aL0P1jNWX203lo?`80=cLg00<0;Bd]03<c<`0c<c<00P0k>c/20820P080RHV90P17AdL202DU
9@8092@T0P0X:2P201lO7`8092@T0P0S8b<202PX:0808b<S0P0Y:BT202/[:`80HV9R0P2ATI420:FU
Y@80UIFE0P21PH4207AdM080LW9b0P1kNg/20:2PX080]KFe0P2i^KT20:FUY@80[Zj^0P2][Jd20:RX
Z080ZJVY00<0XJ6Q0:RXZ02XZ:P00P2XZ:P20:ZZZP80UYJF0P27QhL208j>SP80ZJVY0P2f][H20;6a
/@80ZJVY0P2XZ:P20:n_[`80^KVi0P2l_;`20<30`080a/K60P2i^KT20;Rh^080[jn_0P2WYjL20:ZZ
ZP80Zj^[0P2YZJT20:ZZZP80[:b/0P2YZJT20:^[Z`80[Zj^0P2ZZZX20:n_[`80XJ6Q00<0UYJF09>C
T`2CTi<00P2EUID209bLW080Xj>S0P2VYZH20:FUY@80ZJVY0P2WYjL20:j^[P80[:b/0P2b/[820;2`
/080^[Zj0P2m_Kd20;no_`80^KVi9`38h=P20410@080>CTi0P0e=CD2038b<P80;Bd]0P0a<C4203Ti
>@80J6QX0P1VIVH204e=C@80:BTY0P0/;2`00`0^;Rh0;Bd]02d];@0202/[:`80>CTi0P18B4P20492
@P80?Shn0P0k>c/203Hf=P80<c<c0P0g=cL2034a<@80;Rh^0P0d=3@2038b<P80=SHf0P0l?3`2030`
<080;2`/0P0c<c<203Xj>P80@T920P10@40203Ti>@80=SHf0P0a<C400`0e=CD0CTi>04i>CP02065Q
H@80JVYZ0P1JFUX2061PH080Ogmo0P0i>CT203De=@80:2PX0P0b<S8203Lg=`80OGem0P29RHT204A4
A08092@T0P0X:2P2028R8P@092@T0P0R8R8201`L70808B4Q0P0V9RH203Ph>003061PH02=SHd0SHf=
0080YJFU0P2FUYH208B4Q080K6a/0P1hN7P207]kN`80UIFE102`/;040:f][@80[jn_0P2YZJT20:NW
Y`80YJFU0P2VYZH20:RXZ080Xj>S0P2FUYH208F5Q@80T92@0P2YZJT20:f][@80[:b/00<0ZJVY0:FU
Y@2UYJD00P2^[Zh20;Vi^@80_kno0P31`L420;^k^`80^;Rh0P2i^KT20:b/[080[Zj^0P2XZ:P20:JV
YP80Z:RX0P2/[:`20:n_[`@0ZZZZ0P2/[:`20:VYZ@80YJFU0P2SXj<209ZJVP80UiNG0P2EUID209VI
V@0309jNWP2VYZH0YZJV0080Z:RX102ZZZX40:f][@80/k>c0P2d];@20;Jf]P80_[jn0P2j^[X20<30
`1h0b>3H000L0<SPf080CTi>0P19BDT203lo?`80<c<c0P0[:b/202l_;`80>c/k0P1HF5P206m_K`80
De=C0P0a<C4302/[:`@0:RXZ0P0^;Rh203@d=080?clo0P17AdL20410@0@0=cLg0P0h>3P2034a<@@0
:b/[0P0_;bl203@d=080>CTi0P0c<c<202h^;P80=SHf0P10@4020451@@80?clo0P0g=cL2038b<P80
>3Ph00<0@T9205IFEP1FEUH00P1NGUh206YZJP80?clo0P0j>SX2079bLP80<c<c0P0`<30202XZ:P80
=cLg0P1;Bd/2096AT@80QHF50P0d=3@202h^;P80;2`/0P0X:2P202HV9P8092@T0P0S8b<402@T90@0
7AdM00<0?3`l05mOG`1OGel00P2UYJD209nOW`80Shn?0P1gMgL206YZJP80J6QX0P22PX820:2PX080
[jn_0P2g]kL20;6a/@80Z:RX0P2VYZH20:FUY@@0YZJV0P2WYjL20:FUY@80TI6A0P23Ph<209>CT`80
Z:RX102][Jd00`2UYJD0WYjN09jNWP020:f][@80_Kfm0P30`<020;no_`80_Kfm0P2i^KT20;Fe]@80
/;2`0P2[Zj/40:RXZ080ZJVY0P2ZZZX40:^[Z`80ZZZZ0P2/[:`20:f][@80[jn_0P2^[Zh20:JVYP80
W9bL0P2FUYH209>CT`0309ZJVP2SXj<0Xj>S0080YJFU0P2WYjL20:VYZ@80[:b/0P2][Jd20:j^[P80
/K6a0P2e]KD20;Vi^@80_;bl0P2m_KdW0<SPf080Cdm?0P1BDU8204M7A`80<c<c0P0[:b/202`/;080
=CDe0P1VIVH206e]K@80BDU90P0d=3@202d];@@0:RXZ0P0/;2`00`0^;Rh0=SHf03Hf=P0404I6AP80
>SXj0P0k>c/203`l?080>CTi0P0Z:RX202/[:`80;Rh^100_;bl203/k>`80=CDe0P0a<C4203@d=080
@d=30P0n?Sh20492@P80>CTi0P0f=SH203@d=080A4A40P1JFUX2061PH080Hf=S0P0k>c/204=3@`80
JVYZ0P0g=cL202`/;00302l_;`0d=3@0=3@d0080D51@0P2@T9020861P@80=cLg0P0Y:BT202d];@80
:RXZ0P0W9bL202@T90808B4Q0P0S8b<2020P80808B4Q0P0T92@203@d=080Jf][0P2KVi/20:2PX080
Shn?0P1hN7P206][J`80JVYZ0P1mOGd209^KV`@0]KFe0P2/[:`20:^[Z`@0YJFU0`2VYZH20:NWY`80
Xj>S0P2DU9@208B4Q080SHf=0P2WYjL20;6a/@80[Jf]0P2SXj<209nOW`80/K6a0P2j^[X20<71`@80
_[jn0P2m_Kd20;Rh^080]kNg0P2a/K460:NWY`80Z:RX0P2ZZZX40:^[Z`80ZZZZ0P2[Zj/20:f][@80
[Zj^0P2/[:`00`2WYjL0W9bL09bLW00209>CT`80UIFE0P2RXZ820:2PX080XZ:R0P2YZJT20:ZZZP80
[Jf]0P2_[jl20;2`/080[Zj^0P2f][H20;Zj^P80_;bl0P2k^k/W0<SPf080CDe=0P1;Bd/20451@@80
<C4a0P0[:b/2030`<080>CTi0P1HF5P2071`L080E5AD0P0`<30202l_;`0302/[:`0U9BD09BDU0080
;2`/0P0];Bd2034a<@80@D510P17AdL203lo?`80>CTi0P0f=SH203Lg=`80<c<c0P0Z:RX202/[:`80
;bl_0P0`<30203`l?080<C4a0P0/;2`203Hf=P80@4100P11@D4203hn?P80=cLg0P0d=3@203`l?003
0492@P1DE5@0E5AD0080GemO0P1ZJVX20451@@80?Cdm0P1bLW82030`<080<C4a0P0];Bd203Lg=`80
Bd];0P2>SXh208b<S080<S8b0P0`<30202TY:@809RHV0P0X:2P2024Q8@8092@T0P0U9BD202<S8`80
8B4Q0P0L71`00`0j>SX0GemO05mOG`020:JVYP80WYjN0P2?Shl207MgM`80Jf][0P1ZJVX20820P080
XJ6Q0P2c/k<20;Jf]P80/;2`0P2UYJD20:RXZ080YJFU0P2SXj<20:FUY@80ZJVY0P2TY:@208n?S`80
PX:20P2CTi<20:VYZ@80[jn_0P2[Zj/00`2WYjL0WinO09nOW`020:f][@80_[jn0P2m_Kd20<30`080
_Kfm0P2i^KT20;:b/P80/;2`0P2/[:`20:NWY`80ZJVY0P2XZ:P20:^[Z`80[:b/102YZJT20:j^[P80
[Jf]0P2a/K420:j^[P80YJFU0P2MWId209:BTP80U9BD00<0W9bL0:BTY02TY:@00P2QXJ420:JVYP80
Zj^[0P2ZZZX20:n_[`80[Jf]0P2a/K420;Fe]@80^[Zj102n_[hN0<SPf0007038h=P204i>CP80BDU9
0P0o?cl203<c<`80:b/[0P0_;bl203/k>`80F5QH0P1_Kfl205=CD`80<C4a0`0[:b/402XZ:P80;Rh^
0P0d=3@203lo?`80AdM70P10@40403Lg=`80>3Ph0P0a<C4402/[:`80;bl_0P0d=3@203Ti>@80<c<c
0P0^;Rh203Hf=P80@4100P11@D4203lo?`80=cLg0P0b<S8203Ph>0030492@P1FEUH0EUIF0080GUiN
0P1ZJVX203lo?`80>SXj0P1bLW8203<c<`80<30`0P0Z:RX203Lg=`80Bd];0P2ATI4208F5Q@80=3@d
0P0^;Rh202`/;080:2PX0P0V9RH202@T90808b<S100T92@401dM7@0303`l?01OGel0GemO0080YJFU
0P2OWil208n?S`80MgMg0P1ZJVX206QXJ080PX:20P2PX:020:n_[`80]kNg0P2a/K420:RXZ080YZJV
0P2UYJD40:JVYP80YjNW0P2UYJD2096AT@80Ph>30P2CTi<20:RXZ0@0[Jf]00<0YJFU09jNWP2NWYh0
0P2][Jd20;fm_@80`<300P2o_kl20;fm_@80^KVi0P2e]KD20;2`/080Zj^[102XZ:P20:VYZ@80ZZZZ
102[Zj/20:ZZZP80[:b/0P2][Jd20:n_[`80[Zj^0P2VYZH209bLW080UYJF0P2CTi<00`2JVYX0Xj>S
0:>SX`020:FUY@80YjNW0P2YZJT20:b/[080[Jf]0P2^[Zh20;6a/@80]KFe0P2i^KT20;bl_080_Kfm
9`38h=P204m?C`80DU9B0P17AdL203<c<`80:b/[0P0/;2`203De=@80IVIV0P1]KFd204U9B@80=3@d
0P0];Bd402XZ:P80;2`/00<0;Rh^03Hf=P0f=SH01016ATH203Xj>P80>c/k0P0l?3`203Ti>@80:RXZ
0P0[:b/202h^;P@0;bl_0P0k>c/203De=@80<C4a0P0d=3@204=3@`80?Shn0P12@T8203Ti>@80=SHf
0P0d=3@204A4A080FUYJ0P1PH60206=SH`80>c/k0P13@d<206YZJP80=cLg0P0/;2`00`0_;bl0=3@d
03@d=002051@D080T92@0P21PH4203Lg=`80:BTY0P0];Bd202XZ:P809bLW0P0T92@2024Q8@808b<S
0P0P8202024Q8@8092@T0P0d=3@206][J`80Vi^K0P2PX:0208n?S`80N7Qh0P1[Jf/206YZJP80OGem
0P2KVi/40;Fe]@80[:b/0P2[Zj/40:FUY@<0YZJV0P2WYjL20:>SX`80U9BD0P24Q8@208f=S@80YjNW
0P2a/K420:f][@80Xj>S0P2OWil20;6a/@80^[Zj0P31`L420;jn_P80_Kfm0P2h^;P20;Ng]`80/K6a
1P2WYjL20:RXZ080ZZZZ102[Zj/20:ZZZP80Zj^[0P2][Jd20:j^[P80[:b/00<0YjNW09bLW02LW9`0
0P2CTi<209FEU@80XZ:R0P2PX:020::RXP80ZJVY0P2ZZZX20:f][@80[jn_0P2`/;020:j^[P80][Jf
0P2j^[X20;bl_080^k^k9`38h=P204e=C@80Bd];0P11@D42034a<@80:b/[0P0`<30203Ti>@80F5QH
0P1`L70205ADE080<30`0P0_;bl00`0[:b/09BDU02DU9@0202`/;080;Bd]0P0a<C420451@@80AdM7
0P0o?cl203Ti>@80=SHf0P0g=cL203<c<`80:RXZ0P0[:b/202l_;`80<30`0P0l?3`2034a<@80;2`/
0P0f=SH20410@080@D510P0n?Sh203Lg=`80=3@d0P0l?3`00`12@T80E5AD05ADE00205mOG`80JVYZ
0P11@D4203dm?@80LW9b0P0`<302034a<@80;Bd]0P0g=cL204];B`80SXj>0P2<S8`2038b<P80<30`
0P0Y:BT202HV9P80:2PX0P0Q8B4202@T90809BDU0P0S8b<2024Q8@8071`L00<0>SXj05mOG`1OGel0
0P2VYZH209jNWP80Shn?0P1gMgL206][J`80JVYZ0P20P8020:6QX@80/k>c0P2f][H20;2`/080YJFU
0P2XZ:P20:FUY@80Xj>S0P2UYJD20:VYZ@80Y:BT0P2?Shl208:2PP80Ti>C0P2YZJT20:n_[`80Zj^[
00<0YjNW09nOW`2OWil00P2][Jd20;jn_P80_Kfm0P30`<020;fm_@80^KVi0P2b/[820;2`/080[:b/
0P2WYjL20:VYZ@80Z:RX0P2[Zj/20:b/[0@0ZJVY0P2^[Zh20:f][@80/K6a0P2^[Zh20:FUY@80WIfM
0P2BTY8209BDU00309bLW02TY:@0Y:BT0080XJ6Q0P2VYZH20:^[Z`80ZZZZ0P2_[jl20:f][@80/K6a
0P2e]KD20;Zj^P@0_[jn7P38h=P001`0b>3H0P1QHF42069RHP80GUiN0P15ADD202l_;`80;Bd]0P0g
=cL205=CD`80KVi^0P1FEUH203Lg=`80<30`00<0:BTY02PX:00X:2P00P0Z:RX202/[:`80;Rh^0P0i
>CT20492@P80>SXj0P0b<S8203Lg=`80?3`l0P0e=CD202`/;080;Bd]100a<C4203<c<`80>3Ph0P0n
?Sh204=3@`80ATI60P13@d<203hn?P80>3Ph0P0f=SH203hn?P0304];B`18B4P0B4Q80080G5aL0P1Q
HF4202d];@80=3@d0P1LG5`203Ti>@80=3@d0P0V9RH204Q8B080LW9b0P2?Shl2075aL@80;2`/0P0W
9bL202HV9P@09BDU0P0S8b<2024Q8@808R8R0P0S8b<201`L70806QXJ00<09bLW03`l?00l?3`00P1g
MgL208^;R`80YjNW0P2@T90207YjNP80I6AT0P1aLG4208J6QP80WIfM0P2a/K420;Ng]`80]KFe0P2/
[:`20::RXP80Y:BT102WYjL20:>SX`80T92@0P21PH4208j>SP80WinO0P2WYjL20:ZZZP030:FUY@2R
XZ80XZ:R0080Zj^[0P2f][H20;fm_@80`<300P2i^KT20;6a/@80/k>c0P2e]KD20:j^[P@0Z:RX1P2Z
ZZX20:RXZ080YjNW0P2XZ:P20:VYZ@80[Jf]102_[jl20:b/[080X:2P0`2FUYH209^KV`80X:2P0P2V
YZH20:VYZ@80[:b/0P2][Jd20:n_[`80/[:b0P2e]KD20;Rh^0@0^[Zj9`38h=P405aLG080FUYJ0P13
@d<203Ti>@80;Rh^0P0g=cL205ADE080J6QX0P1JFUX2038b<P80;Bd]0P0Y:BT202XZ:P80;Bd]00<0
9RHV02d];@0];Bd00P10@40204=3@`80=cLg0P0^;Rh20451@@80>SXj0P0b<S8202`/;080;Rh^0P0d
=3@202/[:`80<30`0P0j>SX203`l?080@D510P1<C4`203Xj>P80>c/k0P11@D4203De=@80=3@d0P18
B4P205ADE080G5aL0P1?Cdl2034a<@80=cLg0P1QHF4203Xj>P80;2`/00<0;Rh^0410@010@4000P1_
Kfl208n?S`80LG5a0P0/;2`202h^;P80:BTY0P0S8b<202LW9`809RHV0P0S8b<2028R8P808B4Q0P0O
7al2020P80809BDU0P0f=SH2071`L080UiNG0P2XZ:P208j>SP80M7Ad0P1WIfL2079bLP80Ph>30P2P
X:020;>c/`80_kno0P2a/K420:VYZ@80Y:BT00<0YJFU0:BTY02TY:@00P2UYJD20:2PX080SXj>0P24
Q8@208V9R@80Y:BT0P2YZJT20:FUY@80WYjN0P2OWil20:VYZ@80][Jf0P31`L420;^k^`80]KFe0P2]
[Jd20;Jf]P80];Bd0P2[Zj/40:b/[0@0ZJVY0P2/[:`20:JVYP80Z:RX0P2TY:@20:ZZZP80Z:RX0P2b
/[800`2c/k<0[jn_0:n_[`0209fMW@80RXZ:0P2CTi<209fMW@80WinO0P2VYZH20:NWY`80ZJVY0P2/
[:`40:n_[`80];Bd0P2i^KT20;^k^`80]kNg9`38h=P206ATI080H61P0P1NGUh204=3@`@0;Bd]0P0h
>3P2059BDP80K6a/0P1IFET203<c<`80:b/[0`0X:2P402/[:`80;bl_0P0i>CT20492@P80>3Ph0P0e
=CD203<c<`80@4100P0f=SH202d];@80:b/[100c<c<2034a<@80?3`l0P0o?cl20492@P80ATI60P10
@40203lo?`80=cLg0P0_;bl203hn?P0304Y:BP18B4P0B4Q80080FUYJ0P1RHV8202XZ:P80<C4a0P1L
G5`203Xj>P80=SHf0P0X:2P204E5A@80MGEe0P2>SXh2075aL@@0:BTY0P0Z:RX202HV9P80:2PX0P0Q
8B4202@T90@08R8R0P0K6a/201dM7@0302HV9P0l?3`0?3`l0080N7Qh0P2;Rh/20:BTY080Shn?0P1m
OGd206=SH`80KVi^0P29RHT20:6QX@80/[:b0P2e]KD20;Ng]`80/;2`0P2PX:020:BTY080ZJVY0P2X
Z:P20:FUY@80TI6A0P24Q8@2092@T080X:2P0P2VYZH20:n_[`030:JVYP2OWil0WinO0080[Jf]0P2f
][H20;bl_080`L710P2i^KT20;Bd]0@0][Jf0P2/[:`20:VYZ@80Z:RX0P2ZZZX20:^[Z`80YJFU0P2[
Zj/20:JVYP80ZZZZ0P2WYjL20:b/[080/K6a102^[Zh20:2PX080V9RH00<0UIFE09bLW02LW9`00P2O
Wil20:RXZ080ZJVY102/[:`20:f][@80/k>c0P2e]KD20;Rh^080^KVi0P2g]kLN0<SPf0007038h=P2
065QH@80HV9R0P1NGUh204E5A@80;bl_0P0];Bd203Lg=`80De=C0P1^KVh205IFEP80=cLg0P0`<300
0`0Y:BT0:2PX02PX:00202XZ:P80:b/[0P0^;Rh203Ti>@80@T920P0j>SX2038b<P80=cLg0P0l?3`2
03De=@80;2`/0P0];Bd4034a<@80<c<c0P0h>3P203hn?P80@d=30P16ATH204=3@`80?Shn0P0h>3P2
03Hf=P80?Shn00<0Bd];04Q8B018B4P00P1LG5`2065QH@80;Bd]0P0d=3@205aLG080>CTi0P0d=3@2
02HV9P80B4Q80P1bLW8208n?S`80LG5a0P0/;2`202LW9`809RHV100U9BD202<S8`808B4Q0P0R8R82
02<S8`8071`L0P0J6QX00`0W9bL0?3`l03`l?00207MgM`80Rh^;0P2WYjL2092@T080NWYj0P1TI6@2
075aL@80QXJ60P2MWId20;6a/@80]kNg0P2e]KD20:b/[080XZ:R0P2TY:@40:NWY`80Xj>S0P2@T902
0861P@80SXj>0P2OWil20:NWY`80ZZZZ00<0YJFU0::RXP2RXZ800P2[Zj/20;Jf]P80_Kfm0P30`<02
0;Vi^@80/K6a0P2c/k<20;Fe]@80[Zj^102XZ:P60:ZZZP80Z:RX0P2WYjL20:RXZ080ZJVY0P2][Jd4
0:n_[`80[:b/0P2PX:0309JFUP80Vi^K0P2PX:020:JVYP80ZJVY0P2/[:`20:f][@80[jn_0P2b/[82
0;Fe]@80^;Rh102j^[XW0<SPf0@0G5aL0P1JFUX204=3@`80>CTi0P0^;Rh203Lg=`80E5AD0P1XJ6P2
05YJFP80<S8b0P0];Bd202TY:@80:RXZ0P0];Bd00`0V9RH0;Bd]02d];@020410@080@d=30P0g=cL2
02h^;P80@D510P0j>SX2038b<P80;2`/0P0^;Rh203@d=080:b/[0P0`<30203Xj>P80?3`l0P11@D42
04a<C080>SXj0P0k>c/20451@@80=CDe0P0d=3@204Q8B080E5AD0P1LG5`204m?C`80<C4a0P0g=cL2
065QH@80>SXj0P0/;2`00`0^;Rh0@4100410@00206m_K`80Shn?0P1aLG4202`/;080;Rh^0P0Y:BT2
02<S8`809bLW0P0V9RH202<S8`808R8R0P0Q8B4201lO7`80820P0P0U9BD203Hf=P80L71`0P2GUiL2
0:RXZ080SXj>0P1dM7@206MWI`80LW9b0P23Ph<20:2PX080/k>c0P2o_kl20;6a/@80ZJVY0P2TY:@0
0`2UYJD0Y:BT0:BTY0020:FUY@80X:2P0P2>SXh208B4Q080RHV90P2TY:@20:VYZ@80YJFU0P2NWYh2
09nOW`80ZJVY0P2f][H20<71`@80^k^k0P2e]KD20:f][@80][Jf0P2d];@20:^[Z`@0[:b/102YZJT2
0:b/[080YZJV0P2XZ:P20:BTY080ZZZZ0P2XZ:P20;:b/P030;>c/`2_[jl0[jn_0080WIfM0P2:RXX2
09>CT`80WIfM0P2OWil20:JVYP80YjNW0P2YZJT20:b/[0@0[jn_0P2d];@20;Vi^@80^k^k0P2g]kLW
0<SPf080I6AT0P1PH60205iNGP80@d=3100];Bd203Ph>080DU9B0P1/K6`205UIF@80<c<c0P0[:b/3
02PX:0@0:b/[0P0_;bl203Ti>@80@T920P0h>3P203De=@80<c<c0P10@40203Hf=P80;Bd]0P0[:b/4
03<c<`80<C4a0P0l?3`203lo?`80@T920P16ATH20410@080?clo0P0g=cL202l_;`80?Shn00<0BTY:
04Q8B018B4P00P1JFUX2069RHP80:RXZ0P0a<C4205aLG080>SXj0P0f=SH202PX:080ADE50P1eMGD2
08j>SP80LG5a100Y:BT202XZ:P809RHV0P0X:2P2024Q8@8092@T100R8R8201/K6`807AdM00<09RHV
03`l?00l?3`00P1hN7P208^;R`80Y:BT0P2?Shl207emO@80Hf=S0P1^KVh208V9R@80XJ6Q0P2b/[82
0;Fe]@80]kNg0P2`/;020:2PX080Y:BT0P2YZJT20:RXZ080YJFU0P2ATI4208B4Q080T92@0P2PX:02
0:JVYP80[jn_00<0YZJV09nOW`2OWil00P2][Jd20;Jf]P80_;bl0P31`L420;Vi^@80];Bd102f][H2
0:b/[080ZJVY0P2XZ:P20:ZZZP80Zj^[0P2UYJD20:^[Z`80YZJV0P2ZZZX20:NWY`80[:b/0P2a/K44
0:j^[P80X:2P0P2HV9P00`2EUID0W9bL09bLW00209nOW`80Z:RX0P2YZJT40:b/[080[Jf]0P2c/k<2
0;Fe]@80^;Rh0P2i^KT20;Ng]ah0b>3H000L0<SPf0H0?Cdm0P0h>3P203@d=080<30`0P0c<c<2051@
D080J6QX0P1HF5P203lo?`80<c<c0`0X:2P402XZ:P80:b/[0P0c<c<203Xj>P80<c<c0P0];Bd203Hf
=P80?Shn0P0g=cL202l_;`80<30`0P0c<c<4030`<080@410101?Cdl204Y:BP80A4A40P0n?Sh403/k
>`80@d=300<0Cdm?03Xj>P0j>SX00P1JFUX205QHF0808B4Q0P0d=3@204I6AP80@4100P0i>CT202HV
9P80EeMG0P2EUID208R8R080G5aL0P0Z:RX2028R8P8092@T0P0U9BD202LW9`8092@T100Q8B42028R
8P80820P0P0O7al00`0K6a/08B4Q024Q8@0204A4A080KFe]0P2a/K420:FUY@80SHf=0P1/K6`206QX
J080L71`0P28R8P20:>SX`80][Jf0P30`<020;>c/`80XZ:R0P2SXj<40:JVYP80XJ6Q0P2?Shl20820
P080RXZ:0P2IVIT20::RXP<0ZJVY0P2XZ:P20:^[Z`80/;2`0P2j^[X20<71`@80][Jf0P2[Zj/20;6a
/@80^KVi0P2b/[840:VYZ@80ZZZZ0P2YZJT20:RXZ080YJFU102SXj<20:BTY080Z:RX0P2/[:`20;Fe
]@80^[Zj0P2][Jd209fMW@0309JFUP2EUID0UIFE0080W9bL0P2UYJD20:RXZ080Zj^[0P2][Jd20:n_
[`80/[:b0P2f][H20;Ng]`@0^;Rh9`38h=P204=3@`80@T920P14A4@203De=@80=3@d100^;Rh205EE
E@80HF5Q0P1RHV8203hn?P80;Bd]0P0Z:RX202LW9`80;Bd]00<0:BTY02d];@0];Bd00P0d=3@203/k
>`@0;Rh^0P0h>3P203hn?P80<c<c0P0a<C4202l_;`80=SHf0P0a<C4203<c<`80@4100P1ADE4204a<
C080BTY:0P11@D4203dm?@80A4A40P0i>CT20451@@80CDe=0P16ATH205UIF@80D51@0P0Y:BT202/[
:`80Bd];0P0k>c/203De=@0302d];@1IFET0FEUI0080R8R80P2:RXX205iNGP809bLW0P0Y:BT202HV
9P8092@T0P0^;Rh202PX:0@08b<S0P0Q8B4201dM7@807QhN0P0O7al202HV9P80@D510P1cLg<20:BT
Y080[:b/0P28R8P2075aL@80IfMW0P1dM7@208N7Q`80WinO0P2f][H20;no_`80[Jf]0P2VYZH00`2T
Y:@0YZJV0:JVYP020:FUY@80Xj>S0P2=SHd208J6QP80P8200P2KVi/20:NWY`80Y:BT102/[:`20::R
XP80/;2`0P30`<020;no_`80][Jf0P2][Jd20:b/[080_Kfm0P2^[Zh20:NWY`80[Jf]0P2ZZZX20:VY
Z@80ZZZZ0P2QXJ420:NWY`80X:2P0P2XZ:P20:>SX`80[Zj^00<0/;2`0;Ng]`2g]kL00P2e]KD209jN
WP80Shn?0P2IVIT209nOW`80YZJV0P2UYJD20:ZZZP80/[:b0P2][Jd20:n_[`80];Bd0P2k^k/20;Bd
]080^KVi9`38h=P20410@080>CTi0P0o?cl203Xj>P80=SHf100a<C42051@D080IfMW0P1LG5`203lo
?`80=CDe00<09bLW02`/;00/;2`00P0Z:RX202TY:@80:RXZ0P0e=CD203Ph>080=cLg0P0[:b/203De
=@80?Cdm0P0k>c/402d];@80<S8b0P0^;Rh202l_;`80@T92101>CTh204a<C080ADE50P0m?Cd203Xj
>P80?3`l0P15ADD00`1>CTh0>3Ph03Ph>00205YJFP80GEeM0P0O7al203<c<`80AdM70P10@40203Ti
>@809BDU0P1DE5@209fMW@80QXJ60P1HF5P402TY:@808b<S0P0O7al202XZ:P808R8R100S8b<2028R
8P80820P0P0N7Qh00`0M7Ad0820P020P800204=3@`80L71`0P2^[Zh20:RXZ080SHf=0P1]KFd206QX
J080L71`0P27QhL20:>SX`80]KFe0P2o_kl20;>c/`80XZ:R0P2TY:@20:JVYP80YjNW0P2RXZ8208^;
R`80PX:20P29RHT209VIV@80XJ6Q0P2WYjL00`2XZ:P0YjNW0:NWY`020;2`/080[Jf]0P2i^KT20<30
`080]KFe0P2YZJT20;:b/P80^KVi0P2^[Zh20:b/[080Z:RX0P2ZZZX20:VYZ@80Z:RX0P2UYJD20:>S
X`80XZ:R0P2YZJT20:JVYP80[:b/0P2g]kL20;Zj^P80ZJVY0P2OWil00`2CTi<0V9RH09RHV00209VI
V@80Y:BT0P2[Zj/20:b/[080ZJVY0P2`/;020;:b/P80/k>c0P2h^;P40;Vi^Ah0b>3H000L0<SPf0H0
?Cdm0P0h>3P203@d=080<30`0P0c<c<2051@D080J6QX0P1HF5P203lo?`80<c<c0`0X:2P402XZ:P80
:b/[0P0c<c<203Xj>P80<c<c0P0];Bd203Hf=P80?Shn0P0g=cL202l_;`80<30`0P0c<c<4030`<080
@410101?Cdl204Y:BP80A4A40P0n?Sh403/k>`80@d=300<0Cdm?03Xj>P0j>SX00P1JFUX205QHF080
8B4Q0P0d=3@204I6AP80@4100P0i>CT202HV9P80EeMG0P2EUID208R8R080G5aL0P0Z:RX2028R8P80
92@T0P0U9BD202LW9`8092@T100Q8B42028R8P80820P0P0O7al00`0K6a/08B4Q024Q8@0204A4A080
KFe]0P2a/K420:FUY@80SHf=0P1/K6`206QXJ080L71`0P28R8P20:>SX`80][Jf0P30`<020;>c/`80
XZ:R0P2SXj<40:JVYP80XJ6Q0P2?Shl20820P080RXZ:0P2IVIT20::RXP<0ZJVY0P2XZ:P20:^[Z`80
/;2`0P2j^[X20<71`@80][Jf0P2[Zj/20;6a/@80^KVi0P2b/[840:VYZ@80ZZZZ0P2YZJT20:RXZ080
YJFU102SXj<20:BTY080Z:RX0P2/[:`20;Fe]@80^[Zj0P2][Jd209fMW@0309JFUP2EUID0UIFE0080
W9bL0P2UYJD20:RXZ080Zj^[0P2][Jd20:n_[`80/[:b0P2f][H20;Ng]`@0^;Rh9`38h=P204=3@`80
@T920P14A4@203De=@80=3@d100^;Rh205EEE@80HF5Q0P1RHV8203hn?P80;Bd]0P0Z:RX202LW9`80
;Bd]00<0:BTY02d];@0];Bd00P0d=3@203/k>`@0;Rh^0P0h>3P203hn?P80<c<c0P0a<C4202l_;`80
=SHf0P0a<C4203<c<`80@4100P1ADE4204a<C080BTY:0P11@D4203dm?@80A4A40P0i>CT20451@@80
CDe=0P16ATH205UIF@80D51@0P0Y:BT202/[:`80Bd];0P0k>c/203De=@0302d];@1IFET0FEUI0080
R8R80P2:RXX205iNGP809bLW0P0Y:BT202HV9P8092@T0P0^;Rh202PX:0@08b<S0P0Q8B4201dM7@80
7QhN0P0O7al202HV9P80@D510P1cLg<20:BTY080[:b/0P28R8P2075aL@80IfMW0P1dM7@208N7Q`80
WinO0P2f][H20;no_`80[Jf]0P2VYZH00`2TY:@0YZJV0:JVYP020:FUY@80Xj>S0P2=SHd208J6QP80
P8200P2KVi/20:NWY`80Y:BT102/[:`20::RXP80/;2`0P30`<020;no_`80][Jf0P2][Jd20:b/[080
_Kfm0P2^[Zh20:NWY`80[Jf]0P2ZZZX20:VYZ@80ZZZZ0P2QXJ420:NWY`80X:2P0P2XZ:P20:>SX`80
[Zj^00<0/;2`0;Ng]`2g]kL00P2e]KD209jNWP80Shn?0P2IVIT209nOW`80YZJV0P2UYJD20:ZZZP80
/[:b0P2][Jd20:n_[`80];Bd0P2k^k/20;Bd]080^KVi9`38h=P20410@080>CTi0P0o?cl203Xj>P80
=SHf100a<C42051@D080IfMW0P1LG5`203lo?`80=CDe00<09bLW02`/;00/;2`00P0Z:RX202TY:@80
:RXZ0P0e=CD203Ph>080=cLg0P0[:b/203De=@80?Cdm0P0k>c/402d];@80<S8b0P0^;Rh202l_;`80
@T92101>CTh204a<C080ADE50P0m?Cd203Xj>P80?3`l0P15ADD00`1>CTh0>3Ph03Ph>00205YJFP80
GEeM0P0O7al203<c<`80AdM70P10@40203Ti>@809BDU0P1DE5@209fMW@80QXJ60P1HF5P402TY:@80
8b<S0P0O7al202XZ:P808R8R100S8b<2028R8P80820P0P0N7Qh00`0M7Ad0820P020P800204=3@`80
L71`0P2^[Zh20:RXZ080SHf=0P1]KFd206QXJ080L71`0P27QhL20:>SX`80]KFe0P2o_kl20;>c/`80
XZ:R0P2TY:@20:JVYP80YjNW0P2RXZ8208^;R`80PX:20P29RHT209VIV@80XJ6Q0P2WYjL00`2XZ:P0
YjNW0:NWY`020;2`/080[Jf]0P2i^KT20<30`080]KFe0P2YZJT20;:b/P80^KVi0P2^[Zh20:b/[080
Z:RX0P2ZZZX20:VYZ@80Z:RX0P2UYJD20:>SX`80XZ:R0P2YZJT20:JVYP80[:b/0P2g]kL20;Zj^P80
ZJVY0P2OWil00`2CTi<0V9RH09RHV00209VIV@80Y:BT0P2[Zj/20:b/[080ZJVY0P2`/;020;:b/P80
/k>c0P2h^;P40;Vi^Ah0b>3H000L0<SPf080Fe]K0P1BDU8204=3@`80=cLg0P0^;Rh202/[:`80<30`
0P19BDT2065QH@80G5aL0P1?Cdl202/[:`0302XZ:P0W9bL09bLW00@0:RXZ0P0[:b/2034a<@80=SHf
0P0a<C4202`/;080<C4a0P0h>3P203@d=080;bl_0P0`<302038b<P80=SHf0P0k>c/204U9B@80E5AD
0P1<C4`40451@@80@d=31014A4@203lo?`0303hn?P12@T80@T920080Fe]K0P1JFUX2024Q8@80<S8b
0P0o?cl203/k>`80<c<c0P0`<302059BDP80UYJF0P25QHD205YJFP@0:RXZ0P0c<c<403De=@80<30`
0P0Z:RX202HV9P8092@T0P0R8R82024Q8@0301`L700M7Ad07AdM0080;2`/0P19BDT208N7Q`80W9bL
0P2JVYX208V9R@80N7Qh0P1[Jf/207=cL`80Q8B40P2OWil20;Jf]P80]KFe0P2^[Zh20:RXZ0@0XJ6Q
0P2MWId208b<S080NGUi0P28R8P209fMW@80ZZZZ0P2c/k<00`2`/;00Zj^[0:^[Z`020:b/[080/K6a
0P2k^k/20<;2`P80^k^k0P2c/k<20;Jf]P80^[Zj0P2b/[820:ZZZP@0Z:RX0P2WYjL20:FUY@80Xj>S
0P2RXZ820:2PX080XJ6Q0P2UYJD20:ZZZP80/[:b0P2h^;P20;Fe]@80[Zj^00<0YZJV09nOW`2OWil0
102MWId20::RXP80Z:RX0P2ZZZX20:b/[080[jn_0P2b/[820;Bd]080][Jf0P2g]kLW0<SPf080D51@
0P1FEUH203lo?`80;bl_0P0^;Rh2038b<P80<c<c0P1ADE4205iNGP80H61P0P1=CDd2038b<P80:b/[
0P0Z:RX202TY:@0302LW9`0];Bd0;Bd]0080<S8b0P0g=cL203<c<`80;bl_0P0a<C4203/k>`80<c<c
0P0b<S8203De=@80;Rh^0P0c<c<203Ph>080De=C0P1DE5@404Q8B080ADE50P12@T8204E5A@80@D51
0P13@d<203Xj>P80@4100P1QHF4205IFEP80:b/[0P0^;Rh203hn?P80@4100P0g=cL00`0l?3`0EeMG
05MGE`0209:BTP80SXj>0P1KFe/202PX:0809bLW0P0/;2`202d];@80:b/[0P0Z:RX202DU9@8092@T
0P0Z:RX2024Q8@@07QhN0P0Q8B4202DU9@80BTY:0P25QHD20:BTY080W9bL0P29RHT2071`L080JVYZ
0P1bLW8208B4Q080X:2P0P2j^[X20;fm_@80YjNW00<0Y:BT0:FUY@2UYJD00P2TY:@20:>SX`80QXJ6
0P20P80208>3P`80VIVI0P2_[jl20;Fe]@80][Jf0P2^[Zh20:BTY080/[:b0P31`L420<30`080^;Rh
0P2i^KT20;>c/`80^k^k0P2c/k<20:VYZ@80YjNW0P2VYZH20:2PX080Z:RX0P2PX:020:BTY080XJ6Q
0P2UYJD20:BTY080[Zj^00<0[jn_0;Bd]02d];@00P2k^k/20;Fe]@80YJFU0P2KVi/209bLW080Vi^K
0P2TY:@20:NWY`80[Zj^0P2/[:`20:f][@80]KFe0P2f][H20;>c/`80_Kfm9`38h=P205eMG@80DU9B
0P13@d<203Hf=P80:RXZ0P0];Bd203<c<`80BTY:0P1PH60205UIF@80Cdm?0P0/;2`00`0Y:BT092@T
02@T900202LW9`80:b/[0P0];Bd2030`<080=cLg0P0c<c<202`/;080<30`0P0e=CD2038b<P80=CDe
0P0_;bl203Lg=`80>3Ph0P0j>SX204];B`80De=C0P1:BTX20451@@80?Shn1015ADD204M7A`80@D51
00<0@4100492@P12@T800P1IFET205]KF`808R8R0P0b<S820451@@80>3Ph0P0c<c<2030`<080DE5A
0P2IVIT208B4Q080F5QH0P0/;2`202/[:`80<c<c0P0a<C4203De=@80<S8b0P0U9BD202LW9`8092@T
100O7al00`0N7Qh07AdM01dM7@0202XZ:P80Bd];0P26QXH209^KV`80V9RH0P2;Rh/207QhN080JFUY
0P1bLW8208>3P`80X:2P0P2f][H20;Ng]`80[Zj^0P2XZ:P209nOW`80X:2P0P2NWYh208R8R080N7Qh
0P28R8P209fMW@80Zj^[0P2b/[800`2^[Zh0ZJVY0:VYZ@040;2`/080^k^k0P34a<@20;Rh^080/k>c
0P2h^;P20;^k^`80[jn_0P2ZZZX20:b/[080YJFU0P2VYZH20:FUY@80Z:RX0P2RXZ8209bLW080XJ6Q
0P2RXZ820:^[Z`80/k>c102f][H20:j^[P030:NWY`2NWYh0WYjN0080Vi^K0P2MWId20:BTY080YjNW
0P2XZ:P20:f][@80];Bd0P2b/[820;Fe]@80][Jf0P2e]KDN0<SPf0007038h=P205]KF`80DU9B0P13
@d<203Lg=`80;Rh^0P0[:b/2030`<080BDU90P1QHF4205aLG080Cdm?0P0[:b/00`0Z:RX09bLW02LW
9`0402XZ:P80:b/[0P0a<C4203Hf=P80<C4a0P0/;2`2034a<@80>3Ph0P0d=3@202l_;`80<30`0P0b
<S8203Hf=P80>c/k0P19BDT205ADE080C4a<1011@D4204=3@`@0A4A40P0o?cl00`0n?Sh0@T920492
@P0205]KF`80FUYJ0P0Q8B42038b<P80?clo0P0k>c/203<c<`80<30`0P1BDU8209JFUP80QHF50P1J
FUX402XZ:P80<c<c100e=CD2030`<080:RXZ0P0V9RH202@T90808R8R0P0Q8B400`0L71`07AdM01dM
7@0202`/;080BDU90P27QhL209bLW080VYZJ0P29RHT207QhN080Jf][0P1cLg<208B4Q080WinO0P2f
][H20;Fe]@80[Zj^0P2XZ:P40:6QX@80WIfM0P2<S8`207UiN@80R8R80P2MWId20:ZZZP80/k>c00<0
/;2`0:^[Z`2[Zj/00P2/[:`20;6a/@80^k^k0P32`/820;^k^`80/k>c0P2f][H20;Zj^P80/[:b0P2Z
ZZX40:RXZ080YjNW0P2UYJD20:>SX`80XZ:R0P2PX:020:6QX@80YJFU0P2ZZZX20;:b/P80^;Rh0P2e
]KD20:j^[P030:JVYP2OWil0WinO00@0WIfM0P2RXZ820:RXZ080ZZZZ0P2/[:`20:n_[`80/[:b0P2d
];@20;Jf]P80]kNg9`38h=P2051@D080EUIF0P0o?cl202l_;`80;Rh^0P0b<S8203<c<`80DE5A0P1N
GUh2061PH080CDe=0P0b<S8202/[:`80:RXZ0P0Y:BT00`0W9bL0;Bd]02d];@02038b<P80=cLg0P0c
<c<202l_;`80<C4a0P0k>c/203<c<`80<S8b0P0e=CD202h^;P80<c<c0P0h>3P205=CD`80E5AD1018
B4P204E5A@80@T920P15ADD20451@@80@d=30P0j>SX20410@080HF5Q0P1FEUH202/[:`80;Rh^0P0n
?Sh20410@080=cLg00<0?3`l05MGE`1GEeL00P2BTY8208j>SP80Fe]K0P0X:2P202LW9`80;2`/0P0]
;Bd202/[:`80:RXZ0P0U9BD202@T9080:RXZ0P0Q8B4401hN7P808B4Q0P0U9BD204Y:BP80QHF50P2T
Y:@209bLW080RHV90P1`L70206YZJP80LW9b0P24Q8@20:2PX080^[Zj0P2m_Kd20:NWY`030:BTY02U
YJD0YJFU0080Y:BT0P2SXj<208J6QP80P8200P23Ph<209VIV@80[jn_0P2e]KD20;Jf]P80[Zj^0P2T
Y:@20;:b/P80`L710P30`<020;Rh^080^KVi0P2c/k<20;^k^`80/k>c0P2YZJT20:NWY`80YZJV0P2P
X:020:RXZ080X:2P0P2TY:@20:6QX@80YJFU0P2TY:@20:j^[P030:n_[`2d];@0];Bd0080^k^k0P2e
]KD20:FUY@80Vi^K0P2LW9`209^KV`80Y:BT0P2WYjL20:j^[P80[:b/0P2][Jd20;Fe]@80][Jf0P2c
/k<20;fm_BL0b>3H0P1MGEd2059BDP80@d=30P0f=SH202XZ:P80;Bd]0P0c<c<204Y:BP80H61P0P1I
FET204m?C`80;2`/00<0:BTY02@T900T92@00P0W9bL202/[:`80;Bd]0P0`<30203Lg=`80<c<c0P0/
;2`2030`<080=CDe0P0b<S8203De=@80;bl_0P0g=cL203Ph>080>SXj0P1;Bd/205=CD`80BTY:0P11
@D4203hn?P@0ADE50P17AdL20451@@030410@012@T80@T920080FEUI0P1KFe/2028R8P80<S8b0P11
@D4203Ph>080<c<c0P0`<302055AD@80VIVI0P24Q8@205QHF080;2`/0P0[:b/203<c<`80<C4a0P0e
=CD2038b<P809BDU0P0W9bL202@T90@07alO00<07QhN01dM7@0M7Ad00P0Z:RX204];B`80QXJ60P2K
Vi/209RHV080Rh^;0P1hN7P206UYJ@80LW9b0P23Ph<20:2PX080][Jf0P2g]kL20:j^[P80Z:RX0P2O
Wil20:2PX080WYjN0P28R8P207QhN080R8R80P2MWId20:^[Z`80/[:b00<0[Zj^0:VYZ@2YZJT0102`
/;020;^k^`80a<C40P2h^;P20;>c/`80^;Rh0P2k^k/20:n_[`80ZZZZ0P2/[:`20:FUY@80YZJV0P2U
YJD20:RXZ080XZ:R0P2LW9`20:6QX@80XZ:R0P2[Zj/20;>c/`@0][Jf0P2^[Zh00`2WYjL0WYjN09jN
WP0209^KV`80WIfM0P2TY:@20:NWY`80Z:RX0P2][Jd20;Bd]080/[:b0P2e]KD20;Jf]P80]KFe7P38
h=P001`0b>3H0P1hN7P2065QH@80@D510P0a<C4402LW9`80;Rh^0P12@T8205IFEP@0GEeM0P0V9RH0
0`0_;bl0:2PX02PX:00202/[:`80:RXZ0P0[:b/2030`<080<c<c0P0`<30202`/;080;Rh^0P0a<C42
030`<080;bl_0P0`<30203<c<`80?Shn0P19BDT2055AD@80De=C0P16ATH203Ti>@80@4100P1:BTX2
04e=C@80BTY:0P0i>CT00`0];Bd0Bd];04];B`0205aLG080GemO0P0U9BD202l_;`80?3`l0P0d=3@2
02h^;P80?Shn0P1>CTh208j>SP80Q8B40P1NGUh2034a<@80>3Ph0P17AdL204I6AP80@D510P0j>SX2
034a<@80:b/[0P0V9RH202@T90808b<S00<08B4Q020P800P82000P0O7al202TY:@80E5AD0P23Ph<2
09^KV`80Xj>S0P2;Rh/206m_K`80IFEU0P1VIVH208:2PP80XJ6Q0P2`/;020;Jf]P80[:b/0P2OWil2
09fMW@80V9RH0P26QXH207IfMP80RXZ:0P2UYJD20;Bd]080_Kfm00<0][Jf0:f][@2][Jd00P2_[jl2
0;Bd]080_;bl0P33`l<20<71`@80_Kfm0P2l_;`20;^k^`80/k>c0P2/[:`20:VYZ@80YjNW0P2UYJD2
0:>SX`80XJ6Q0P2PX:0409nOW`80XZ:R0P2XZ:P20:f][@80/[:b0P2i^KT20;fm_@030;Jf]P2/[:`0
[:b/0080X:2P0P2HV9P209fMW@80Y:BT0P2WYjL20:RXZ080Zj^[0P2^[Zh20;:b/P80]KFe0P2f][HW
0<SPf080MGEe0P1YJFT204M7A`80;Bd]0P0W9bL202/[:`80;Bd]0P0n?Sh205MGE`80GemO0P1FEUH2
02`/;080;Bd]0P0Y:BT202l_;`0302HV9P0[:b/0:b/[0080;bl_0P0f=SH203@d=080;Bd]0P0[:b/2
038b<P80<30`0P0];Bd2034a<@80=3@d0P0h>3P204Y:BP80EUIF0P1?Cdl204E5A@80>SXj0P0o?cl2
04U9B@80Bd];0P15ADD20410@080<C4a0P15ADD2069RHP80F5QH0P0[:b/202d];@@0?3`l0P0/;2`0
0`0b<S80DE5A055AD@0208j>SP80QHF50P1HF5P2034a<@80?Shn0P10@40204];B`80@d=30P0n?Sh2
02h^;P80:BTY0P0V9RH202@T90@08b<S0P0O7al2024Q8@80:BTY0P1FEUH208:2PP80VYZJ0P2PX:02
08R8R080LG5a0P1/K6`206QXJ080N7Qh0P2OWil20;Rh^080]KFe00<0X:2P0:NWY`2WYjL00P2RXZ82
09RHV080P8200P1kNg/208j>SP80X:2P0P2k^k/20;Zj^P80/K6a0P2d];@20:JVYP80]kNg0P2l_;`2
0<?3``@0_;bl0P2n_[h20;Rh^080]KFe0P2][Jd20:ZZZP80[:b/0P2RXZ820:BTY080Xj>S0P2OWil2
0:6QX@80WYjN0P2OWil20:NWY`030;6a/@2d];@0];Bd0080][Jf0P2l_;`20;6a/@80/;2`0P2OWil2
09RHV080W9bL0P2TY:@40:RXZ080YjNW0P2_[jl20;2`/080];Bd0P2j^[XW0<SPf080M7Ad0P1RHV82
03dm?@80=SHf0P0V9RH202DU9@80;Bd]0P11@D4205QHF080EeMG0P1OGel202/[:`03034a<@0T92@0
92@T0080;Bd]0P0[:b/202TY:@80;bl_0P0b<S8202h^;P80;Bd]0P0[:b/203<c<`@0;Rh^0P0a<C42
03<c<`80>SXj0P1:BTX204m?C`80E5AD0P15ADD203`l?080@4100P1>CTh204];B`80BDU90P0h>3P0
0`0^;Rh0ATI604I6AP0205iNGP80GEeM0P0V9RH202d];@80?Shn0P0d=3@2030`<080?clo0P1<C4`2
09:BTP80PX:20P1KFe/2034a<@80=cLg0P16ATH204M7A`80?Shn0P0l?3`2038b<P80;2`/0P0V9RH5
02<S8`808B4Q0P0L71`202TY:@80EUIF0P23Ph<209fMW@80XJ6Q0P2>SXh206e]K@@0I6AT0P23Ph<2
09fMW@80/[:b0P2d];@20:f][@80WIfM0P2PX:0209NGU`80RXZ:0P1fMWH208Z:RP80YJFU0P2a/K42
0;no_`030;Rh^02][Jd0[Jf]0080[Zj^0P2c/k<20;bl_080`/;20P2n_[h20<30`0@0^k^k0P2d];@2
0:^[Z`80[:b/0P2WYjL20:>SX`80XJ6Q0P2SXj<409jNWP80WinO0P2UYJD20:JVYP80[jn_0P2`/;02
0;jn_P80^[Zj00<0][Jf0:n_[`2_[jl00P2MWId209^KV`80WYjN102TY:@20:RXZ080[:b/0P2[Zj/4
0;>c/`80];Bd7P38h=P001`0b>3H0P1hN7P2065QH@80@D510P0a<C4402LW9`80;Rh^0P12@T8205IF
EP@0GEeM0P0V9RH00`0_;bl0:2PX02PX:00202/[:`80:RXZ0P0[:b/2030`<080<c<c0P0`<30202`/
;080;Rh^0P0a<C42030`<080;bl_0P0`<30203<c<`80?Shn0P19BDT2055AD@80De=C0P16ATH203Ti
>@80@4100P1:BTX204e=C@80BTY:0P0i>CT00`0];Bd0Bd];04];B`0205aLG080GemO0P0U9BD202l_
;`80?3`l0P0d=3@202h^;P80?Shn0P1>CTh208j>SP80Q8B40P1NGUh2034a<@80>3Ph0P17AdL204I6
AP80@D510P0j>SX2034a<@80:b/[0P0V9RH202@T90808b<S00<08B4Q020P800P82000P0O7al202TY
:@80E5AD0P23Ph<209^KV`80Xj>S0P2;Rh/206m_K`80IFEU0P1VIVH208:2PP80XJ6Q0P2`/;020;Jf
]P80[:b/0P2OWil209fMW@80V9RH0P26QXH207IfMP80RXZ:0P2UYJD20;Bd]080_Kfm00<0][Jf0:f]
[@2][Jd00P2_[jl20;Bd]080_;bl0P33`l<20<71`@80_Kfm0P2l_;`20;^k^`80/k>c0P2/[:`20:VY
Z@80YjNW0P2UYJD20:>SX`80XJ6Q0P2PX:0409nOW`80XZ:R0P2XZ:P20:f][@80/[:b0P2i^KT20;fm
_@030;Jf]P2/[:`0[:b/0080X:2P0P2HV9P209fMW@80Y:BT0P2WYjL20:RXZ080Zj^[0P2^[Zh20;:b
/P80]KFe0P2f][HW0<SPf080MGEe0P1YJFT204M7A`80;Bd]0P0W9bL202/[:`80;Bd]0P0n?Sh205MG
E`80GemO0P1FEUH202`/;080;Bd]0P0Y:BT202l_;`0302HV9P0[:b/0:b/[0080;bl_0P0f=SH203@d
=080;Bd]0P0[:b/2038b<P80<30`0P0];Bd2034a<@80=3@d0P0h>3P204Y:BP80EUIF0P1?Cdl204E5
A@80>SXj0P0o?cl204U9B@80Bd];0P15ADD20410@080<C4a0P15ADD2069RHP80F5QH0P0[:b/202d]
;@@0?3`l0P0/;2`00`0b<S80DE5A055AD@0208j>SP80QHF50P1HF5P2034a<@80?Shn0P10@40204];
B`80@d=30P0n?Sh202h^;P80:BTY0P0V9RH202@T90@08b<S0P0O7al2024Q8@80:BTY0P1FEUH208:2
PP80VYZJ0P2PX:0208R8R080LG5a0P1/K6`206QXJ080N7Qh0P2OWil20;Rh^080]KFe00<0X:2P0:NW
Y`2WYjL00P2RXZ8209RHV080P8200P1kNg/208j>SP80X:2P0P2k^k/20;Zj^P80/K6a0P2d];@20:JV
YP80]kNg0P2l_;`20<?3``@0_;bl0P2n_[h20;Rh^080]KFe0P2][Jd20:ZZZP80[:b/0P2RXZ820:BT
Y080Xj>S0P2OWil20:6QX@80WYjN0P2OWil20:NWY`030;6a/@2d];@0];Bd0080][Jf0P2l_;`20;6a
/@80/;2`0P2OWil209RHV080W9bL0P2TY:@40:RXZ080YjNW0P2_[jl20;2`/080];Bd0P2j^[XW0<SP
f080M7Ad0P1RHV8203dm?@80=SHf0P0V9RH202DU9@80;Bd]0P11@D4205QHF080EeMG0P1OGel202/[
:`03034a<@0T92@092@T0080;Bd]0P0[:b/202TY:@80;bl_0P0b<S8202h^;P80;Bd]0P0[:b/203<c
<`@0;Rh^0P0a<C4203<c<`80>SXj0P1:BTX204m?C`80E5AD0P15ADD203`l?080@4100P1>CTh204];
B`80BDU90P0h>3P00`0^;Rh0ATI604I6AP0205iNGP80GEeM0P0V9RH202d];@80?Shn0P0d=3@2030`
<080?clo0P1<C4`209:BTP80PX:20P1KFe/2034a<@80=cLg0P16ATH204M7A`80?Shn0P0l?3`2038b
<P80;2`/0P0V9RH502<S8`808B4Q0P0L71`202TY:@80EUIF0P23Ph<209fMW@80XJ6Q0P2>SXh206e]
K@@0I6AT0P23Ph<209fMW@80/[:b0P2d];@20:f][@80WIfM0P2PX:0209NGU`80RXZ:0P1fMWH208Z:
RP80YJFU0P2a/K420;no_`030;Rh^02][Jd0[Jf]0080[Zj^0P2c/k<20;bl_080`/;20P2n_[h20<30
`0@0^k^k0P2d];@20:^[Z`80[:b/0P2WYjL20:>SX`80XJ6Q0P2SXj<409jNWP80WinO0P2UYJD20:JV
YP80[jn_0P2`/;020;jn_P80^[Zj00<0][Jf0:n_[`2_[jl00P2MWId209^KV`80WYjN102TY:@20:RX
Z080[:b/0P2[Zj/40;>c/`80];Bd7P38h=P001`0b>3H0P1fMWH206a/K080F5QH0P0k>c/202@T9080
9BDU0P0`<30203Xj>P80ADE50P1CDe<205aLG080=SHf00<0<c<c02d];@0];Bd00P0];Bd402`/;080
;Rh^0P0_;bl402h^;P80<30`0P0a<C4202h^;P80;Bd]0P0d=3@203dm?@80Bd];0P1DE5@2051@D080
B4Q80P12@T8203lo?`80BDU90P1CDe<204i>CP80ADE50P0d=3@00`0/;2`0>c/k03/k>`0205mOG`80
HF5Q0P0Q8B4202TY:@80<c<c0P0_;bl202h^;P80B4Q80P1PH60208V9R@80R8R80P1]KFd204e=C@80
Cdm?0P1IFET206EUI@80JFUY0P1<C4`202`/;0@09BDU100T92@00`0R8R808B4Q024Q8@0201lO7`80
8b<S0P0g=cL205MGE`80OWin0P2MWId209NGU`80Q8B40P1/K6`205]KF`80IVIV0P21PH4209RHV080
[:b/0P2a/K420:n_[`80WinO0P2CTi<207MgM`80P8200P2CTi<20:b/[080][Jf0P2n_[h00`2g]kL0
[jn_0:n_[`020;:b/P80]kNg0P2l_;`20<30`080`L711030`<020;jn_P80^;Rh0P2a/K420:b/[080
YjNW0P2UYJD20:BTY080XZ:R0P2PX:0209nOW`80X:2P0P2SXj<20:NWY`80Zj^[0P2`/;020;Jf]P80
^[Zj00<0^;Rh0;:b/P2b/[800P2ZZZX20::RXP80XJ6Q0P2RXZ820:BTY080YjNW0P2[Zj/20:j^[P80
/[:b0P2d];@20;Fe]BL0b>3H0P1hN7P206QXJ080EeMG0P0`<30202`/;0809RHV0P0[:b/203Hf=P80
?clo0P1KFe/205eMG@80=SHf0P0];Bd202l_;`80;2`/00<0:b/[03De=@0e=CD01P0Z:RX202/[:`80
;Rh^0P0`<302034a<@80:b/[0P0g=cL204=3@`80C4a<0P1DE5@2051@D080CTi>0P0k>c/203lo?`80
B4Q80P1FEUH205EEE@80ADE50P0h>3P202PX:080>3Ph0P1WIfL205=CD`8092@T0P0S8b<202d];@80
>CTi0P0[:b/00`0k>c/0HV9R069RHP02096AT@80QhN70P1SHf<205IFEP80DE5A0P1TI6@206m_K`80
Hf=S0P1IFET203<c<`809BDU0P0Q8B4202XZ:P808R8R0P0T92@201lO7`808R8R0P0X:2P202h^;P80
D51@0P26QXH209nOW`80XZ:R0P21PH4206IVIP80GEeM0P1SHf<207alO080WYjN0P2e]KD00`2[Zj/0
XJ6Q0:6QX@020:BTY080SXj>0P1jNWX207]kN`80QXJ60P2`/;020;jn_P80^[Zj0P2^[Zh20:n_[`80
];Bd0P2e]KD20<30`080`L71102o_kl20<71`@80_kno0P2e]KD20:j^[P80ZZZZ0P2VYZH20::RXP80
YJFU0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`80YZJV00<0ZZZZ0:f][@2][Jd00P2e]KD20;Vi^@80
][Jf0P2b/[820;2`/080XZ:R0P2NWYh20:2PX080Y:BT0P2WYjL60:f][@80/;2`0P2k^k/W0<SPf080
NGUi0P1]KFd205YJFP80?clo0P0U9BD202<S8`80<30`0P0k>c/204U9B@80DE5A0P1KFe/203Ti>@03
038b<P0X:2P0:2PX0080<C4a0P0^;Rh202d];@80<C4a0P0_;bl2038b<P80;Bd]0P0a<C4203Hf=P80
:RXZ0P0/;2`203<c<`80?Cdm0P19BDT205IFEP80DU9B0P19BDT204A4A080?Shn0P18B4P204m?C`80
CDe=0P14A4@203Hf=P0302`/;00m?Cd0?Cdm0080Hf=S0P1OGel2028R8P809bLW0P0c<c<202/[:`80
;2`/0P16ATH2061PH0@0RXZ:0P1`L70204i>CP80D51@0P1JFUX406YZJP80Bd];0P0X:2P202@T9080
9RHV0P0T92@202DU9@0302<S8`0R8R808R8R00807QhN0P0U9BD203Hf=P80EEEE0P1mOGd409ZJVP80
QXJ60P1^KVh205aLG080JFUY0P24Q8@209RHV080[:b/0P2_[jl20;:b/P80WinO0P2@T90207IfMP80
Ogmo0P2DU9@20:n_[`80/k>c0P2n_[h00`2i^KT0/;2`0;2`/0020;6a/@80^KVi0P2k^k/20<30`080
a/K60P2m_Kd20;bl_080_[jn0P2g]kL20:n_[`80[Jf]0P2UYJD20:NWY`80Xj>S0P2UYJD20::RXP@0
X:2P0P2UYJD20:BTY080ZZZZ0P2/[:`20;Ng]`80^KVi00<0^;Rh0;>c/`2c/k<00P2XZ:P40:2PX0@0
YJFU0P2VYZH20:ZZZP80[:b/0P2d];@20;Jf]P80^KVi7P38h=P001`0b>3H0P1fMWH206a/K080F5QH
0P0k>c/202@T90809BDU0P0`<30203Xj>P80ADE50P1CDe<205aLG080=SHf00<0<c<c02d];@0];Bd0
0P0];Bd402`/;080;Rh^0P0_;bl402h^;P80<30`0P0a<C4202h^;P80;Bd]0P0d=3@203dm?@80Bd];
0P1DE5@2051@D080B4Q80P12@T8203lo?`80BDU90P1CDe<204i>CP80ADE50P0d=3@00`0/;2`0>c/k
03/k>`0205mOG`80HF5Q0P0Q8B4202TY:@80<c<c0P0_;bl202h^;P80B4Q80P1PH60208V9R@80R8R8
0P1]KFd204e=C@80Cdm?0P1IFET206EUI@80JFUY0P1<C4`202`/;0@09BDU100T92@00`0R8R808B4Q
024Q8@0201lO7`808b<S0P0g=cL205MGE`80OWin0P2MWId209NGU`80Q8B40P1/K6`205]KF`80IVIV
0P21PH4209RHV080[:b/0P2a/K420:n_[`80WinO0P2CTi<207MgM`80P8200P2CTi<20:b/[080][Jf
0P2n_[h00`2g]kL0[jn_0:n_[`020;:b/P80]kNg0P2l_;`20<30`080`L711030`<020;jn_P80^;Rh
0P2a/K420:b/[080YjNW0P2UYJD20:BTY080XZ:R0P2PX:0209nOW`80X:2P0P2SXj<20:NWY`80Zj^[
0P2`/;020;Jf]P80^[Zj00<0^;Rh0;:b/P2b/[800P2ZZZX20::RXP80XJ6Q0P2RXZ820:BTY080YjNW
0P2[Zj/20:j^[P80/[:b0P2d];@20;Fe]BL0b>3H0P1hN7P206QXJ080EeMG0P0`<30202`/;0809RHV
0P0[:b/203Hf=P80?clo0P1KFe/205eMG@80=SHf0P0];Bd202l_;`80;2`/00<0:b/[03De=@0e=CD0
1P0Z:RX202/[:`80;Rh^0P0`<302034a<@80:b/[0P0g=cL204=3@`80C4a<0P1DE5@2051@D080CTi>
0P0k>c/203lo?`80B4Q80P1FEUH205EEE@80ADE50P0h>3P202PX:080>3Ph0P1WIfL205=CD`8092@T
0P0S8b<202d];@80>CTi0P0[:b/00`0k>c/0HV9R069RHP02096AT@80QhN70P1SHf<205IFEP80DE5A
0P1TI6@206m_K`80Hf=S0P1IFET203<c<`809BDU0P0Q8B4202XZ:P808R8R0P0T92@201lO7`808R8R
0P0X:2P202h^;P80D51@0P26QXH209nOW`80XZ:R0P21PH4206IVIP80GEeM0P1SHf<207alO080WYjN
0P2e]KD00`2[Zj/0XJ6Q0:6QX@020:BTY080SXj>0P1jNWX207]kN`80QXJ60P2`/;020;jn_P80^[Zj
0P2^[Zh20:n_[`80];Bd0P2e]KD20<30`080`L71102o_kl20<71`@80_kno0P2e]KD20:j^[P80ZZZZ
0P2VYZH20::RXP80YJFU0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`80YZJV00<0ZZZZ0:f][@2][Jd0
0P2e]KD20;Vi^@80][Jf0P2b/[820;2`/080XZ:R0P2NWYh20:2PX080Y:BT0P2WYjL60:f][@80/;2`
0P2k^k/W0<SPf080NGUi0P1]KFd205YJFP80?clo0P0U9BD202<S8`80<30`0P0k>c/204U9B@80DE5A
0P1KFe/203Ti>@03038b<P0X:2P0:2PX0080<C4a0P0^;Rh202d];@80<C4a0P0_;bl2038b<P80;Bd]
0P0a<C4203Hf=P80:RXZ0P0/;2`203<c<`80?Cdm0P19BDT205IFEP80DU9B0P19BDT204A4A080?Shn
0P18B4P204m?C`80CDe=0P14A4@203Hf=P0302`/;00m?Cd0?Cdm0080Hf=S0P1OGel2028R8P809bLW
0P0c<c<202/[:`80;2`/0P16ATH2061PH0@0RXZ:0P1`L70204i>CP80D51@0P1JFUX406YZJP80Bd];
0P0X:2P202@T90809RHV0P0T92@202DU9@0302<S8`0R8R808R8R00807QhN0P0U9BD203Hf=P80EEEE
0P1mOGd409ZJVP80QXJ60P1^KVh205aLG080JFUY0P24Q8@209RHV080[:b/0P2_[jl20;:b/P80WinO
0P2@T90207IfMP80Ogmo0P2DU9@20:n_[`80/k>c0P2n_[h00`2i^KT0/;2`0;2`/0020;6a/@80^KVi
0P2k^k/20<30`080a/K60P2m_Kd20;bl_080_[jn0P2g]kL20:n_[`80[Jf]0P2UYJD20:NWY`80Xj>S
0P2UYJD20::RXP@0X:2P0P2UYJD20:BTY080ZZZZ0P2/[:`20;Ng]`80^KVi00<0^;Rh0;>c/`2c/k<0
0P2XZ:P40:2PX0@0YJFU0P2VYZH20:ZZZP80[:b/0P2d];@20;Jf]P80^KVi7P38h=P001`0b>3H0P1e
MGD205IFEP80;bl_0P0V9RH202LW9`80;2`/100c<c<203@d=080AdM70P1FEUH204Y:BP0303Ti>@0c
<c<0<c<c0080<30`0P0^;Rh202d];@@0;2`/0P0];Bd202l_;`80<S8b0P0c<c<202h^;P80;2`/0P0j
>SX204Y:BP80EUIF0P1KFe/204a<C080?3`l0P10@40204Q8B080De=C0P1JFUX204a<C080>c/k0`0_
;bl202`/;080HF5Q0P1OGel201hN7P808b<S0P0];Bd202h^;P80=SHf0P1EEED207EeM@80Ph>30P29
RHT207IfMP80HF5Q0P1TI6@206QXJ080GUiN0P1>CTh203Xj>P80:BTY1P0U9BD202@T90D08b<S0P0U
9BD202@T9080;Bd]0P1JFUX208R8R080V9RH0P2FUYH207QhN080FEUI0P1EEED2069RHP80O7al0P2H
V9P20:n_[`80^[Zj0P2SXj<208j>SP80K6a/0P2?Shl209bLW080[jn_0P2f][H20;bl_0030;Jf]P2`
/;00/;2`0080];Bd0P2j^[X20;^k^`80_Kfm0P2o_kl40<;2`P80`L710P2m_Kd20;Ng]`80/;2`0P2Z
ZZX20:NWY`80YZJV0P2RXZ8209nOW`80X:2P0P2RXZ820:BTY080YZJV0P2YZJT20:f][@80/;2`0P2c
/k<30;Jf]P80/k>c0P2^[Zh20:NWY`80XJ6Q0P2RXZ820:JVYP80ZZZZ0P2^[Zh20;6a/@80/k>c0P2d
];@W0<SPf080LW9b0P1MGEd203@d=080;Bd]0P0V9RH202TY:@80;bl_0P0l?3`203<c<`80@d=30P1H
F5P204M7A`80@D510P0c<c<3030`<080:b/[0P0];Bd2034a<@80;Bd]0P0a<C42038b<P80>3Ph0P0_
;bl2034a<@80=3@d0P16ATH205aLG080D51@0P1CDe<203/k>`80?clo0P1;Bd/204i>CP80FEUI0P1;
Bd/203dm?@80;2`/0P0^;Rh203Xj>P80HV9R0P1CDe<202DU9@808b<S0P0Z:RX203Lg=`80<C4a00<0
De=C079bLP1bLW800P28R8P208N7Q`80Jf][0P1XJ6P205iNGP80GemO0P1MGEd204Q8B080=CDe0P0U
9BD202<S8`809RHV0P0Z:RX202@T90808B4Q0P0U9BD202@T90809BDU0P0Q8B42038b<P80Fe]K0P23
Ph<209ZJVP80U9BD0P1eMGD205YJFP80De=C0P1VIVH207IfMP80UYJF00<0];Bd0;Jf]P2f][H00P2U
YJD208V9R@80N7Qh0P2=SHd209FEU@80[:b/0P2k^k/20;bl_080][Jf0P2`/;020;Fe]@80^k^k0P2j
^[X20;bl_080`<300P32`/840<71`@80_Kfm0P2f][H20;>c/`80YjNW0P2YZJT40:FUY@H0XJ6Q0P2V
YZH20:FUY@030:ZZZP2_[jl0[jn_0080[:b/0P2d];@20;Ng]`80][Jf0P2b/[820:f][@80YjNW0P2T
Y:@20:6QX@80YZJV0P2[Zj/20:f][@80[:b/0P2a/K420;Rh^2L0b>3H0P1eMGD205MGE`80;bl_0P0S
8b<202TY:@80;Bd]0P0d=3@202h^;P80=CDe0P16ATH205EEE@80CTi>00<0>CTi034a<@0a<C400P0_
;bl2030`<080;Bd]0P0[:b/402d];@80;Rh^0P0f=SH203<c<`80:b/[0P0Z:RX203/k>`80C4a<0P1D
E5@205]KF`80C4a<0P0j>SX20410@080AdM70P1ADE4205aLG080Cdm?0P0j>SX202`/;00302d];@0`
<300<30`0080HV9R0P1JFUX2020P80809RHV0P0];Bd2034a<@80=SHf0P1EEED207MgM`80Q8B40P28
R8P207EeM@@0HF5Q0P1YJFT205aLG080Cdm?0P0h>3P202XZ:P@09RHV0P0S8b<202DU9@03020P800S
8b<08b<S00808R8R0P0V9RH2020P8080;Rh^0P1IFET208J6QP80WYjN0P2DU9@207AdM080F5QH0P1I
FET2061PH080N7Qh0P2IVIT20;2`/080^KVi0P2QXJ42096AT@80K6a/0P2?Shl209fMW@80[Zj^0P2f
][H20;fm_@030;Bd]02_[jl0[jn_0080][Jf0P2l_;`20;Jf]P80_kno0P32`/820<71`@80`l?30P30
`<020;^k^`80^KVi0P2_[jl20:ZZZP80Zj^[0P2UYJD20::RXP80X:2P0P2LW9`20:2PX080Z:RX0P2S
Xj<20:^[Z`80[:b/0P2_[jl20;Fe]@030;Jf]P2h^;P0^;Rh0080]KFe0P2^[Zh20:NWY`80WinO0P2S
Xj<40:RXZ080[jn_0P2`/;020;:b/P80];Bd7P38h=P001`0b>3H0P1eMGD205IFEP80;bl_0P0V9RH2
02LW9`80;2`/100c<c<203@d=080AdM70P1FEUH204Y:BP0303Ti>@0c<c<0<c<c0080<30`0P0^;Rh2
02d];@@0;2`/0P0];Bd202l_;`80<S8b0P0c<c<202h^;P80;2`/0P0j>SX204Y:BP80EUIF0P1KFe/2
04a<C080?3`l0P10@40204Q8B080De=C0P1JFUX204a<C080>c/k0`0_;bl202`/;080HF5Q0P1OGel2
01hN7P808b<S0P0];Bd202h^;P80=SHf0P1EEED207EeM@80Ph>30P29RHT207IfMP80HF5Q0P1TI6@2
06QXJ080GUiN0P1>CTh203Xj>P80:BTY1P0U9BD202@T90D08b<S0P0U9BD202@T9080;Bd]0P1JFUX2
08R8R080V9RH0P2FUYH207QhN080FEUI0P1EEED2069RHP80O7al0P2HV9P20:n_[`80^[Zj0P2SXj<2
08j>SP80K6a/0P2?Shl209bLW080[jn_0P2f][H20;bl_0030;Jf]P2`/;00/;2`0080];Bd0P2j^[X2
0;^k^`80_Kfm0P2o_kl40<;2`P80`L710P2m_Kd20;Ng]`80/;2`0P2ZZZX20:NWY`80YZJV0P2RXZ82
09nOW`80X:2P0P2RXZ820:BTY080YZJV0P2YZJT20:f][@80/;2`0P2c/k<30;Jf]P80/k>c0P2^[Zh2
0:NWY`80XJ6Q0P2RXZ820:JVYP80ZZZZ0P2^[Zh20;6a/@80/k>c0P2d];@W0<SPf080LW9b0P1MGEd2
03@d=080;Bd]0P0V9RH202TY:@80;bl_0P0l?3`203<c<`80@d=30P1HF5P204M7A`80@D510P0c<c<3
030`<080:b/[0P0];Bd2034a<@80;Bd]0P0a<C42038b<P80>3Ph0P0_;bl2034a<@80=3@d0P16ATH2
05aLG080D51@0P1CDe<203/k>`80?clo0P1;Bd/204i>CP80FEUI0P1;Bd/203dm?@80;2`/0P0^;Rh2
03Xj>P80HV9R0P1CDe<202DU9@808b<S0P0Z:RX203Lg=`80<C4a00<0De=C079bLP1bLW800P28R8P2
08N7Q`80Jf][0P1XJ6P205iNGP80GemO0P1MGEd204Q8B080=CDe0P0U9BD202<S8`809RHV0P0Z:RX2
02@T90808B4Q0P0U9BD202@T90809BDU0P0Q8B42038b<P80Fe]K0P23Ph<209ZJVP80U9BD0P1eMGD2
05YJFP80De=C0P1VIVH207IfMP80UYJF00<0];Bd0;Jf]P2f][H00P2UYJD208V9R@80N7Qh0P2=SHd2
09FEU@80[:b/0P2k^k/20;bl_080][Jf0P2`/;020;Fe]@80^k^k0P2j^[X20;bl_080`<300P32`/84
0<71`@80_Kfm0P2f][H20;>c/`80YjNW0P2YZJT40:FUY@H0XJ6Q0P2VYZH20:FUY@030:ZZZP2_[jl0
[jn_0080[:b/0P2d];@20;Ng]`80][Jf0P2b/[820:f][@80YjNW0P2TY:@20:6QX@80YZJV0P2[Zj/2
0:f][@80[:b/0P2a/K420;Rh^2L0b>3H0P1eMGD205MGE`80;bl_0P0S8b<202TY:@80;Bd]0P0d=3@2
02h^;P80=CDe0P16ATH205EEE@80CTi>00<0>CTi034a<@0a<C400P0_;bl2030`<080;Bd]0P0[:b/4
02d];@80;Rh^0P0f=SH203<c<`80:b/[0P0Z:RX203/k>`80C4a<0P1DE5@205]KF`80C4a<0P0j>SX2
0410@080AdM70P1ADE4205aLG080Cdm?0P0j>SX202`/;00302d];@0`<300<30`0080HV9R0P1JFUX2
020P80809RHV0P0];Bd2034a<@80=SHf0P1EEED207MgM`80Q8B40P28R8P207EeM@@0HF5Q0P1YJFT2
05aLG080Cdm?0P0h>3P202XZ:P@09RHV0P0S8b<202DU9@03020P800S8b<08b<S00808R8R0P0V9RH2
020P8080;Rh^0P1IFET208J6QP80WYjN0P2DU9@207AdM080F5QH0P1IFET2061PH080N7Qh0P2IVIT2
0;2`/080^KVi0P2QXJ42096AT@80K6a/0P2?Shl209fMW@80[Zj^0P2f][H20;fm_@030;Bd]02_[jl0
[jn_0080][Jf0P2l_;`20;Jf]P80_kno0P32`/820<71`@80`l?30P30`<020;^k^`80^KVi0P2_[jl2
0:ZZZP80Zj^[0P2UYJD20::RXP80X:2P0P2LW9`20:2PX080Z:RX0P2SXj<20:^[Z`80[:b/0P2_[jl2
0;Fe]@030;Jf]P2h^;P0^;Rh0080]KFe0P2^[Zh20:NWY`80WinO0P2SXj<40:RXZ080[jn_0P2`/;02
0;:b/P80];Bd7P38h=P001`0b>3H0P1cLg<205QHF080=CDe0P0^;Rh202XZ:P80;bl_0P0e=CD202h^
;P80:RXZ0P0n?Sh204m?C`80GEeM00<0?Shn03Lg=`0g=cL00P0`<30202h^;P80;Bd]0P0/;2`202d]
;@80;Rh^0P0`<304034a<@80;Rh^0P0_;bl204A4A0@0F5QH0P1BDU8204I6AP80?Cdm0P13@d<204i>
CP80FEUI0P1NGUh204M7A`80<30`0P0/;2`00`0c<c<0>SXj03Xj>P0205]KF`80Cdm?0P0T92@2024Q
8@80:2PX0P0n?Sh205=CD`80Jf][0P1oOgl20820P080Ng]k0P1RHV8204M7A`80>SXj0P0a<C4202TY
:@809BDU0P0Y:BT202l_;`80;2`/1P0X:2P00`0U9BD08R8R028R8P0202<S8`8092@T0P0P820202<S
8`80?Shn0P1MGEd207alO080Shn?0P1lO7`2061PH080IfMW0P1GEeL206ATI080MgMg0P2EUID20:^[
Z`80ZZZZ0P2<S8`207EeM@@0WinO0P2PX:020;bl_0<0][Jf0P2c/k<20;Fe]@80^;Rh0P2i^KT20;Zj
^P80_Kfm0P2o_kl40<30`080_;bl0P2g]kL20;>c/`80[Zj^0P2YZJT20:FUY@80XZ:R0P2OWil20:2P
X080XJ6Q0P2SXj<20:FUY@80YjNW0P2YZJT20:b/[080[jn_00<0];Bd0;Rh^02h^;P00P2e]KD20;2`
/080Z:RX0P2RXZ840:2PX080Xj>S0P2WYjL20:f][@80/K6a0P2c/k<W0<SPf080MWIf0P1BDU8202h^
;P809bLW0P0[:b/2034a<@80>c/k0P0d=3@202/[:`80?3`l0P1DE5@2051@D080?Cdm0P0i>CT2034a
<@0302`/;00[:b/0:b/[0080;Bd]100_;bl203De=@80;bl_0P0^;Rh202/[:`80;bl_0P0n?Sh205QH
F080GemO0P1HF5P20492@P80>SXj0P11@D4205EEE@80EeMG0P1PH60204e=C@80:b/[0P0W9bL202l_
;`80@4100P1GEeL2051@D0809BDU0P0Z:RX202`/;080>SXj0P1LG5`00`1XJ6P0OGem07emO@0208f=
S@80QXJ60P1LG5`204I6AP80?clo0P0f=SH202l_;`80;Rh^0P0Z:RX2034a<@80:BTY0P0Z:RX202HV
9P80:BTY0P0S8b<4028R8P8092@T0P0X:2P202HV9P80;bl_0P1OGel207inOP80Ti>C0P1jNWX206IV
IP80JFUY0P1PH60205aLG080MgMg00<0UIFE0;Fe]@2e]KD00P2^[Zh208J6QP80MgMg0P2VYZH209jN
WP80YjNW0P2l_;`20;Jf]P@0];Bd0P2e]KD20;Jf]P80]KFe0P2j^[X20;bl_080`L710P2n_[h20;no
_`80_[jn0P2i^KT20;Bd]080/K6a0P2YZJT20::RXP80Y:BT0P2KVi/209bLW080XZ:R0P2TY:@20:FU
Y@030:RXZ02[Zj/0Zj^[0080[:b/0P2`/;020;Fe]@80][Jf0P2c/k<20;6a/@80YZJV0P2RXZ8209^K
V`80X:2P0P2UYJD20:b/[080[Zj^102f][HW0<SPf080LG5a0P1FEUH203Hf=P80:2PX0P0Z:RX2030`
<080=SHf0P0^;Rh202XZ:P80?3`l0P1>CTh205]KF`0303lo?`0f=SH0=SHf00@0;bl_0P0[:b/202TY
:@80:b/[100^;Rh2030`<080;Rh^0P0`<30203<c<`80AdM70P1FEUH205MGE`80DU9B0P14A4@203lo
?`80A4A40P1?Cdl205YJFP80GEeM0P19BDT2030`<080;2`/00<0=3@d03Ti>@0i>CT00P1JFUX204];
B`809RHV0P0P820202PX:080?Shn0P1EEED206a/K080O7al0P1nOWh207]kN`80I6AT0P16ATH203Ph
>080<S8b0P0W9bL202HV9P80:2PX0P0`<30202h^;P809RHV0P0Y:BT202XZ:P0302<S8`0V9RH09RHV
00H08b<S0P0T92@203lo?`80G5aL0P1mOGd208j>SP80MGEe0P1OGel206][J`80EEEE0P1SHf<207Ui
N@80UiNG0P2[Zj/20:ZZZP80SHf=0P1fMWH209jNWP80WIfM0P2PX:020;fm_@80^KVi00<0];Bd0;Ng
]`2g]kL00P2d];@20;Rh^0@0]kNg0P2n_[h20<30`080`L710P33`l<20;fm_@80]kNg0P2b/[820:^[
Z`80ZJVY0P2QXJ420:>SX`80X:2P0P2MWId20:>SX`80Z:RX0P2SXj<20:ZZZP80[:b/0P2[Zj/20:j^
[P030;:b/P2h^;P0^;Rh0080/;2`0P2a/K420:b/[080XZ:R102NWYh20:FUY@80ZJVY0P2XZ:P20;2`
/080][Jf7P38h=P001`0b>3H0P1cLg<205QHF080=CDe0P0^;Rh202XZ:P80;bl_0P0e=CD202h^;P80
:RXZ0P0n?Sh204m?C`80GEeM00<0?Shn03Lg=`0g=cL00P0`<30202h^;P80;Bd]0P0/;2`202d];@80
;Rh^0P0`<304034a<@80;Rh^0P0_;bl204A4A0@0F5QH0P1BDU8204I6AP80?Cdm0P13@d<204i>CP80
FEUI0P1NGUh204M7A`80<30`0P0/;2`00`0c<c<0>SXj03Xj>P0205]KF`80Cdm?0P0T92@2024Q8@80
:2PX0P0n?Sh205=CD`80Jf][0P1oOgl20820P080Ng]k0P1RHV8204M7A`80>SXj0P0a<C4202TY:@80
9BDU0P0Y:BT202l_;`80;2`/1P0X:2P00`0U9BD08R8R028R8P0202<S8`8092@T0P0P820202<S8`80
?Shn0P1MGEd207alO080Shn?0P1lO7`2061PH080IfMW0P1GEeL206ATI080MgMg0P2EUID20:^[Z`80
ZZZZ0P2<S8`207EeM@@0WinO0P2PX:020;bl_0<0][Jf0P2c/k<20;Fe]@80^;Rh0P2i^KT20;Zj^P80
_Kfm0P2o_kl40<30`080_;bl0P2g]kL20;>c/`80[Zj^0P2YZJT20:FUY@80XZ:R0P2OWil20:2PX080
XJ6Q0P2SXj<20:FUY@80YjNW0P2YZJT20:b/[080[jn_00<0];Bd0;Rh^02h^;P00P2e]KD20;2`/080
Z:RX0P2RXZ840:2PX080Xj>S0P2WYjL20:f][@80/K6a0P2c/k<W0<SPf080MWIf0P1BDU8202h^;P80
9bLW0P0[:b/2034a<@80>c/k0P0d=3@202/[:`80?3`l0P1DE5@2051@D080?Cdm0P0i>CT2034a<@03
02`/;00[:b/0:b/[0080;Bd]100_;bl203De=@80;bl_0P0^;Rh202/[:`80;bl_0P0n?Sh205QHF080
GemO0P1HF5P20492@P80>SXj0P11@D4205EEE@80EeMG0P1PH60204e=C@80:b/[0P0W9bL202l_;`80
@4100P1GEeL2051@D0809BDU0P0Z:RX202`/;080>SXj0P1LG5`00`1XJ6P0OGem07emO@0208f=S@80
QXJ60P1LG5`204I6AP80?clo0P0f=SH202l_;`80;Rh^0P0Z:RX2034a<@80:BTY0P0Z:RX202HV9P80
:BTY0P0S8b<4028R8P8092@T0P0X:2P202HV9P80;bl_0P1OGel207inOP80Ti>C0P1jNWX206IVIP80
JFUY0P1PH60205aLG080MgMg00<0UIFE0;Fe]@2e]KD00P2^[Zh208J6QP80MgMg0P2VYZH209jNWP80
YjNW0P2l_;`20;Jf]P@0];Bd0P2e]KD20;Jf]P80]KFe0P2j^[X20;bl_080`L710P2n_[h20;no_`80
_[jn0P2i^KT20;Bd]080/K6a0P2YZJT20::RXP80Y:BT0P2KVi/209bLW080XZ:R0P2TY:@20:FUY@03
0:RXZ02[Zj/0Zj^[0080[:b/0P2`/;020;Fe]@80][Jf0P2c/k<20;6a/@80YZJV0P2RXZ8209^KV`80
X:2P0P2UYJD20:b/[080[Zj^102f][HW0<SPf080LG5a0P1FEUH203Hf=P80:2PX0P0Z:RX2030`<080
=SHf0P0^;Rh202XZ:P80?3`l0P1>CTh205]KF`0303lo?`0f=SH0=SHf00@0;bl_0P0[:b/202TY:@80
:b/[100^;Rh2030`<080;Rh^0P0`<30203<c<`80AdM70P1FEUH205MGE`80DU9B0P14A4@203lo?`80
A4A40P1?Cdl205YJFP80GEeM0P19BDT2030`<080;2`/00<0=3@d03Ti>@0i>CT00P1JFUX204];B`80
9RHV0P0P820202PX:080?Shn0P1EEED206a/K080O7al0P1nOWh207]kN`80I6AT0P16ATH203Ph>080
<S8b0P0W9bL202HV9P80:2PX0P0`<30202h^;P809RHV0P0Y:BT202XZ:P0302<S8`0V9RH09RHV00H0
8b<S0P0T92@203lo?`80G5aL0P1mOGd208j>SP80MGEe0P1OGel206][J`80EEEE0P1SHf<207UiN@80
UiNG0P2[Zj/20:ZZZP80SHf=0P1fMWH209jNWP80WIfM0P2PX:020;fm_@80^KVi00<0];Bd0;Ng]`2g
]kL00P2d];@20;Rh^0@0]kNg0P2n_[h20<30`080`L710P33`l<20;fm_@80]kNg0P2b/[820:^[Z`80
ZJVY0P2QXJ420:>SX`80X:2P0P2MWId20:>SX`80Z:RX0P2SXj<20:ZZZP80[:b/0P2[Zj/20:j^[P03
0;:b/P2h^;P0^;Rh0080/;2`0P2a/K420:b/[080XZ:R102NWYh20:FUY@80ZJVY0P2XZ:P20;2`/080
][Jf7P38h=P001`0b>3H0P1bLW8205]KF`80?Shn0P0g=cL203<c<`80=cLg0P0j>SX202l_;`809RHV
0P0h>3P204Q8B080JFUY00<0A4A403`l?00l?3`00P0a<C4202h^;P@0;Bd]300_;bl203<c<`80C4a<
0P1QHF4205MGE`80ATI60P12@T820451@@80BDU90P1BDU8205aLG080GUiN0P12@T8202LW9`80:RXZ
00<0=SHf04U9B@19BDT00P1DE5@203hn?P80:BTY0P0T92@202/[:`80Cdm?0P1aLG4207moO`80PX:2
0P1iNGT206IVIP80A4A40P0U9BD202PX:080<S8b100d=3@203<c<`80<S8b0P0^;Rh202XZ:P80:b/[
0P0/;2`00`0X:2P092@T02@T900202<S8`8092@T0P0S8b<202@T9080:2PX0P0d=3@205YJFP80Ng]k
0P1jNWX206YZJP80OWin0P1FEUH205=CD`80EUIF0P1fMWH209:BTP80Zj^[0P27QhL20820P080[Jf]
0P2NWYh208n?S`80_[jn0P2a/K400`2f][H0]KFe0;Fe]@020;Fe]@@0][Jf0P2h^;P20;Zj^P80_;bl
102m_Kd20;Zj^P80]kNg0P2e]KD20;>c/`80[:b/0P2UYJD20::RXP@0X:2P0P2QXJ420:>SX`@0YJFU
0P2VYZH20:RXZ080[:b/00<0/k>c0;Rh^02h^;P00P2e]KD20:n_[`80ZZZZ0P2TY:@209jNWP80Vi^K
0P2MWId20::RXP80ZJVY0P2_[jl20;6a/BL0b>3H0P1fMWH205eMG@80@d=3100e=CD203dm?@80>CTi
0P0^;Rh202/[:`80>3Ph0P1>CTh205mOG`80BTY:0P0f=SH203@d=00302/[:`0];Bd0;Bd]0080<c<c
0P0a<C4202TY:@80<C4a0P0_;bl2038b<P80<c<c0P0i>CT204Y:BP80HV9R0P1IFET204Y:BP80?Shn
0P15ADD204M7A`80DU9B0P1DE5@2065QH@80>c/k0P0[:b/202l_;`80=SHf0P18B4P205IFEP80@D51
0P0W9bL202PX:080;Rh^0P17AdL207IfMP0307EeM@1nOWh0OWin0080PH610P1RHV8203Ti>@@0:RXZ
0P0];Bd202l_;`80;Rh^0P0`<302034a<@80=3@d0P0[:b/202l_;`80;2`/0P0^;Rh202<S8`@08R8R
0P0T92@202HV9P80:BTY0P0g=cL205mOG`80MWIf0P1lO7`206a/K080MGEe0P1LG5`204i>CP80Fe]K
00<0MgMg09>CT`2CTi<00P2SXj<208^;R`80NWYj0P2a/K4209RHV080Ti>C0P2i^KT20;Fe]@80/k>c
0P2f][H20;Bd]080^;Rh0P2f][H20;Rh^080^[Zj0P2l_;`20;^k^`80_Kfm0P2k^k/20;Jf]P80]KFe
0P2c/k<20:ZZZP@0YJFU0P2QXJ420:2PX080XJ6Q0P2PX:020:JVYP030:BTY02VYZH0YZJV0080Zj^[
0P2/[:`20;>c/`80^KVi0P2d];@20:n_[`80[:b/0P2WYjL209VIV@80W9bL0P2SXj<209jNWP80YJFU
0P2^[Zh20;Fe]BL0b>3H0P1bLW8205eMG@80@4100P0d=3@203De=@@0>CTi0P0a<C4202HV9P80>SXj
0P19BDT206QXJ00304E5A@0m?Cd0?Cdm0080<C4a0P0`<30202`/;080:b/[100a<C42038b<P80:b/[
0P0`<30202h^;P80<C4a0P1:BTX2069RHP80FEUI0P14A4@204E5A@80@D510P17AdL2059BDP80GemO
0P1MGEd20492@P809BDU0P0];Bd00`0e=CD0BTY:04Y:BP0205EEE@80?clo0P0Y:BT202@T9080;2`/
0P1?Cdl206i^KP80PX:20P25QHD207QhN080IfMW0P12@T8202PX:08092@T0P0d=3@2038b<P80=CDe
0P0d=3@202l_;`80<C4a0P0X:2P202/[:`80;2`/00<09bLW028R8P0R8R801P0S8b<2024Q8@80:BTY
0P0b<S8205QHF080Ogmo0P1hN7P206e]K@80OWin0P1EEED205=CD`80EeMG0P1eMGD209:BTP80[Zj^
0P27QhL207inOP80[jn_0P2RXZ8208n?S`80_Kfm0P2a/K400`2e]KD0][Jf0;Jf]P020;Fe]@@0]kNg
0P2i^KT20;Zj^P@0^k^k0P2n_[h20;Vi^@80]kNg0P2f][H20;>c/`80[Jf]0P2SXj<20:BTY080X:2P
0P2MWId20:6QX@80Y:BT0P2UYJD20:6QX@80YjNW0P2ZZZX20:^[Z`030;Jf]P2k^k/0^k^k0080/[:b
0P2`/;020:n_[`80Xj>S0P2OWil209VIV@80WinO0P2RXZ820:FUY@80[jn_0P2e]KDN0<SPf0007038
h=P2079bLP80Fe]K0P0n?Sh203Lg=`80<c<c0P0g=cL203Xj>P80;bl_0P0V9RH203Ph>080B4Q80P1Y
JFT00`14A4@0?3`l03`l?002034a<@80;Rh^100];Bd<02l_;`80<c<c0P1<C4`2065QH@80EeMG0P16
ATH20492@P80@D510P19BDT2059BDP80G5aL0P1NGUh20492@P809bLW0P0Z:RX00`0f=SH0BDU904U9
B@0205ADE080?Shn0P0Y:BT202@T9080:b/[0P1?Cdl2075aL@80Ogmo0P22PX8207UiN@80IVIV0P14
A4@202DU9@80:2PX0P0b<S8403@d=080<c<c0P0b<S8202h^;P80:RXZ0P0[:b/202`/;00302PX:00T
92@092@T00808b<S0P0T92@202<S8`8092@T0P0X:2P203@d=080FUYJ0P1kNg/207YjNP80JVYZ0P1n
OWh205IFEP80De=C0P1FEUH207IfMP80TY:B0P2[Zj/208N7Q`80P8200P2][Jd209jNWP80Shn?0P2n
_[h20;6a/@030;Jf]P2e]KD0]KFe0080]KFe102f][H20;Rh^080^[Zj0P2l_;`40;fm_@80^[Zj0P2g
]kL20;Fe]@80/k>c0P2/[:`20:FUY@80XZ:R102PX:020:6QX@80Xj>S102UYJD20:JVYP80Z:RX0P2/
[:`00`2c/k<0^;Rh0;Rh^0020;Fe]@80[jn_0P2ZZZX20:BTY080WYjN0P2KVi/209fMW@80XZ:R0P2Y
ZJT20:n_[`80/K6a9`38h=P207IfMP80GEeM0P13@d<403De=@80?Cdm0P0i>CT202h^;P80:b/[0P0h
>3P204i>CP80GemO0P1:BTX203Hf=P80=3@d00<0:b/[02d];@0];Bd00P0c<c<2034a<@80:BTY0P0a
<C4202l_;`80<S8b0P0c<c<203Ti>@80BTY:0P1RHV8205UIF@80BTY:0P0n?Sh204E5A@80AdM70P1B
DU8205ADE080HF5Q0P0k>c/202/[:`80;bl_0P0f=SH204Q8B080EUIF0P11@D4202LW9`80:2PX0P0^
;Rh204M7A`80MWIf00<0MGEe07inOP1nOWh00P21PH42069RHP80>CTi100Z:RX202d];@80;bl_0P0^
;Rh2030`<080<C4a0P0d=3@202/[:`80;bl_0P0/;2`202h^;P808b<S100R8R8202@T90809RHV0P0Y
:BT203Lg=`80GemO0P1fMWH207alO080K6a/0P1eMGD205aLG080CTi>0P1KFe/00`1gMgL0Ti>C09>C
T`020:>SX`80Rh^;0P1jNWX20;6a/@80V9RH0P2CTi<20;Vi^@80]KFe0P2c/k<20;Jf]P80];Bd0P2h
^;P20;Jf]P80^;Rh0P2j^[X20;bl_080^k^k0P2m_Kd20;^k^`80][Jf0P2e]KD20;>c/`80ZZZZ102U
YJD20:6QX@80X:2P0P2QXJ420:2PX080YZJV00<0Y:BT0:JVYP2VYZH00P2[Zj/20:b/[080/k>c0P2i
^KT20;Bd]080[jn_0P2/[:`20:NWY`80VIVI0P2LW9`20:>SX`80WYjN0P2UYJD20:j^[P80]KFe9`38
h=P2079bLP80GEeM0P10@40203@d=080=CDe100i>CT2034a<@809RHV0P0j>SX204U9B@80J6QX00<0
ADE503dm?@0m?Cd00P0a<C42030`<080;2`/0P0[:b/4034a<@80<S8b0P0[:b/2030`<080;Rh^0P0a
<C4204Y:BP80HV9R0P1IFET204A4A080ADE50P11@D4204M7A`80DU9B0P1OGel205eMG@80@T920P0U
9BD202d];@0303De=@1:BTX0BTY:0080EEEE0P0o?cl202TY:@8092@T0P0/;2`204m?C`80KVi^0P22
PX8208F5Q@80N7Qh0P1WIfL20492@P80:2PX0P0T92@203@d=080<S8b0P0e=CD203@d=080;bl_0P0a
<C4202PX:080:b/[0P0/;2`00`0W9bL08R8R028R8P0602<S8`808B4Q0P0Y:BT2038b<P80F5QH0P1o
Ogl207QhN080KFe]0P1nOWh205EEE@80De=C0P1GEeL207EeM@80TY:B0P2^[Zh208N7Q`80OWin0P2_
[jl20::RXP80Shn?0P2m_Kd20;6a/@030;Fe]@2f][H0][Jf0080]KFe102g]kL20;Vi^@80^[Zj102k
^k/20;jn_P80^KVi0P2g]kL20;Jf]P80/k>c0P2][Jd20:>SX`80Y:BT0P2PX:0209fMW@80XJ6Q0P2T
Y:@20:FUY@80XJ6Q0P2WYjL20:ZZZP80Zj^[00<0][Jf0;^k^`2k^k/00P2b/[820;2`/080[jn_0P2S
Xj<209nOW`80VIVI0P2OWil20::RXP80YJFU0P2_[jl20;Fe]Ah0b>3H000L0<SPf080L71`0P1QHF42
051@D080@D510P1BDU8204m?C`80C4a<0P0m?Cd2034a<@80>c/k0P17AdL205mOG`03051@D017AdL0
AdM70080>SXj0P0d=3@2034a<@@0;bl_0P0^;Rh202d];@80;Rh^0P0`<30203<c<`80>CTi0P1<C4`2
05]KF`80DU9B0P15ADD204=3@`80A4A40P1<C4`205EEE@80FEUI0P1FEUH20410@080:b/[0P0];Bd0
0`0f=SH0BDU904U9B@02059BDP80>CTi0P0V9RH202l_;`80A4A40P1CDe<207]kN`80P8200P1jNWX2
06IVIP80CDe=0P0f=SH202DU9@809bLW0P0];Bd202l_;`80<30`0P0a<C42038b<P80<30`0P0];Bd7
02`/;080:BTY0P0V9RH402DU9@8092@T0P0Y:BT20410@080FEUI0P1WIfL206i^KP80PX:20P1VIVH2
05MGE`80BTY:0P1NGUh207=cL`80TY:B0P1gMgL207]kN`80/K6a0P2MWId208V9R@80[jn_0P2f][H0
0`2h^;P0/k>c0;>c/`020;>c/`80];Bd0P2e]KD20;Jf]P80]kNg0P2h^;P20;^k^`80_;bl0P2k^k/2
0;Vi^@80^;Rh0P2e]KD20;2`/080ZZZZ0P2VYZH20:BTY0@0XZ:R0P2TY:@20:NWY`@0Z:RX0P2[Zj/2
0:f][@030;:b/P2f][H0][Jf0080];Bd0P2a/K420:j^[P80Zj^[0P2RXZ8209bLW080WinO0P2UYJD2
0:VYZ@80[:b/0P2][JdW0<SPf080KFe]0P1NGUh205IFEP80@d=30P1:BTX205=CD`80A4A40P0c<c<2
034a<@80<S8b0P19BDT206IVIP80FEUI0P19BDT20451@@0302h^;P0c<c<0<c<c0080=3@d100Z:RX2
030`<080:b/[0P0_;bl203@d=080<c<c0P16ATH2065QH@80Bd];0P0k>c/204E5A@80A4A40P1HF5P2
05EEE@80Fe]K0P1IFET204E5A@80:BTY0P0];Bd203Lg=`80B4Q80P1@D50203Hf=P808R8R0P0_;bl2
03/k>`80FUYJ0P1fMWH00`25QHD0O7al07alO00206m_K`80Bd];0P0Z:RX202/[:`80;2`/0P0`<302
02h^;P80<c<c0P0j>SX2034a<@80:b/[1P0Y:BT202`/;080;Bd]0P0X:2P202XZ:P808b<S100T92@2
02LW9`80=SHf0P1LG5`206UYJ@80KVi^0P1jNWX206][J`@0Cdm?00<0GemO06m_K`1_Kfl00P29RHT2
08:2PP80OGem0P2a/K4209NGU`80QHF50P2c/k<20;Ng]`80];Bd0P2g]kL20;6a/@80][Jf0P2b/[82
0;Jf]P80^k^k0P2f][H20;^k^`80_Kfm0P2k^k/20;Rh^0@0];Bd0P2_[jl20:VYZ@80YjNW0P2QXJ42
0::RXP80Xj>S0P2UYJD20:NWY`<0YZJV0P2UYJD20:^[Z`80/K6a102f][H20;2`/080[:b/0P2[Zj/2
0:>SX`80VYZJ0P2MWId20:FUY@80YjNW0P2YZJT20:NWYbL0b>3H0P1]KFd206IVIP80DE5A0P0n?Sh4
059BDP80BTY:0P0j>SX2030`<080>SXj0P17AdL205aLG00304i>CP18B4P0B4Q80080>3Ph0P0f=SH2
03<c<`80<C4a0P0^;Rh402`/;080;Bd]0P0c<c<203De=@80=cLg0P1?Cdl205QHF080EEEE0P13@d<2
04E5A@80@d=30P18B4P205EEE@80EeMG0P1FEUH20492@P80:RXZ0`0_;bl204e=C@80D51@0P0k>c/2
02DU9@80<30`0P13@d<2059BDP80Ng]k0P1oOgl207MgM`80IFEU0P1;Bd/203Ti>@809BDU0P0V9RH2
030`<080;Bd]0P0_;bl2034a<@80<S8b0P0a<C4202l_;`80<30`1@0];Bd202XZ:P809BDU0P0X:2P2
02@T90809RHV0P0];Bd20410@080FUYJ0P1TI6@206m_K`80PH610P1XJ6P205QHF080B4Q80P1NGUh2
06m_K`80Ti>C0P1fMWH207QhN080[jn_0P2OWil208F5Q@80/;2`0P2f][H00`2h^;P0/[:b0;:b/P02
0;6a/@80]KFe0P2b/[820;Fe]@80^[Zj0P2i^KT40;^k^`80^;Rh0P2k^k/20;Zj^P80]KFe0P2`/;02
0:ZZZP80Zj^[0P2RXZ820:6QX@80X:2P0P2TY:@20:VYZ@80Y:BT0P2VYZH20:RXZ080[Jf]00<0][Jf
0;Fe]@2e]KD00P2`/;020:n_[`80[Jf]0P2WYjL20:>SX`80WIfM0P2QXJ420:FUY@80YjNW0P2][Jd2
0;:b/Qh0b>3H000L0<SPf080L71`0P1QHF42051@D080@D510P1BDU8204m?C`80C4a<0P0m?Cd2034a
<@80>c/k0P17AdL205mOG`03051@D017AdL0AdM70080>SXj0P0d=3@2034a<@@0;bl_0P0^;Rh202d]
;@80;Rh^0P0`<30203<c<`80>CTi0P1<C4`205]KF`80DU9B0P15ADD204=3@`80A4A40P1<C4`205EE
E@80FEUI0P1FEUH20410@080:b/[0P0];Bd00`0f=SH0BDU904U9B@02059BDP80>CTi0P0V9RH202l_
;`80A4A40P1CDe<207]kN`80P8200P1jNWX206IVIP80CDe=0P0f=SH202DU9@809bLW0P0];Bd202l_
;`80<30`0P0a<C42038b<P80<30`0P0];Bd702`/;080:BTY0P0V9RH402DU9@8092@T0P0Y:BT20410
@080FEUI0P1WIfL206i^KP80PX:20P1VIVH205MGE`80BTY:0P1NGUh207=cL`80TY:B0P1gMgL207]k
N`80/K6a0P2MWId208V9R@80[jn_0P2f][H00`2h^;P0/k>c0;>c/`020;>c/`80];Bd0P2e]KD20;Jf
]P80]kNg0P2h^;P20;^k^`80_;bl0P2k^k/20;Vi^@80^;Rh0P2e]KD20;2`/080ZZZZ0P2VYZH20:BT
Y0@0XZ:R0P2TY:@20:NWY`@0Z:RX0P2[Zj/20:f][@030;:b/P2f][H0][Jf0080];Bd0P2a/K420:j^
[P80Zj^[0P2RXZ8209bLW080WinO0P2UYJD20:VYZ@80[:b/0P2][JdW0<SPf080KFe]0P1NGUh205IF
EP80@d=30P1:BTX205=CD`80A4A40P0c<c<2034a<@80<S8b0P19BDT206IVIP80FEUI0P19BDT20451
@@0302h^;P0c<c<0<c<c0080=3@d100Z:RX2030`<080:b/[0P0_;bl203@d=080<c<c0P16ATH2065Q
H@80Bd];0P0k>c/204E5A@80A4A40P1HF5P205EEE@80Fe]K0P1IFET204E5A@80:BTY0P0];Bd203Lg
=`80B4Q80P1@D50203Hf=P808R8R0P0_;bl203/k>`80FUYJ0P1fMWH00`25QHD0O7al07alO00206m_
K`80Bd];0P0Z:RX202/[:`80;2`/0P0`<30202h^;P80<c<c0P0j>SX2034a<@80:b/[1P0Y:BT202`/
;080;Bd]0P0X:2P202XZ:P808b<S100T92@202LW9`80=SHf0P1LG5`206UYJ@80KVi^0P1jNWX206][
J`@0Cdm?00<0GemO06m_K`1_Kfl00P29RHT208:2PP80OGem0P2a/K4209NGU`80QHF50P2c/k<20;Ng
]`80];Bd0P2g]kL20;6a/@80][Jf0P2b/[820;Jf]P80^k^k0P2f][H20;^k^`80_Kfm0P2k^k/20;Rh
^0@0];Bd0P2_[jl20:VYZ@80YjNW0P2QXJ420::RXP80Xj>S0P2UYJD20:NWY`<0YZJV0P2UYJD20:^[
Z`80/K6a102f][H20;2`/080[:b/0P2[Zj/20:>SX`80VYZJ0P2MWId20:FUY@80YjNW0P2YZJT20:NW
YbL0b>3H0P1]KFd206IVIP80DE5A0P0n?Sh4059BDP80BTY:0P0j>SX2030`<080>SXj0P17AdL205aL
G00304i>CP18B4P0B4Q80080>3Ph0P0f=SH203<c<`80<C4a0P0^;Rh402`/;080;Bd]0P0c<c<203De
=@80=cLg0P1?Cdl205QHF080EEEE0P13@d<204E5A@80@d=30P18B4P205EEE@80EeMG0P1FEUH20492
@P80:RXZ0`0_;bl204e=C@80D51@0P0k>c/202DU9@80<30`0P13@d<2059BDP80Ng]k0P1oOgl207Mg
M`80IFEU0P1;Bd/203Ti>@809BDU0P0V9RH2030`<080;Bd]0P0_;bl2034a<@80<S8b0P0a<C4202l_
;`80<30`1@0];Bd202XZ:P809BDU0P0X:2P202@T90809RHV0P0];Bd20410@080FUYJ0P1TI6@206m_
K`80PH610P1XJ6P205QHF080B4Q80P1NGUh206m_K`80Ti>C0P1fMWH207QhN080[jn_0P2OWil208F5
Q@80/;2`0P2f][H00`2h^;P0/[:b0;:b/P020;6a/@80]KFe0P2b/[820;Fe]@80^[Zj0P2i^KT40;^k
^`80^;Rh0P2k^k/20;Zj^P80]KFe0P2`/;020:ZZZP80Zj^[0P2RXZ820:6QX@80X:2P0P2TY:@20:VY
Z@80Y:BT0P2VYZH20:RXZ080[Jf]00<0][Jf0;Fe]@2e]KD00P2`/;020:n_[`80[Jf]0P2WYjL20:>S
X`80WIfM0P2QXJ420:FUY@80YjNW0P2][Jd20;:b/Qh0b>3H000L0<SPf080Kfm_0P1VIVH2061PH080
BDU90P1^KVh206MWI`80GEeM0P1:BTX203/k>`80?Shn0P17AdL2055AD@0305]KF`1@D500D51@0080
@T920P0k>c/203De=@80<C4a0P0_;bl202`/;080:b/[0P0];Bd2034a<@80=SHf0P0m?Cd204U9B@80
De=C0P1=CDd204I6AP80ADE50P17AdL204m?C`80EUIF0P1EEED204i>CP80?clo0P0b<S82030`<003
03De=@16ATH0ATI60080DU9B0P0h>3P2028R8P80>SXj0P1MGEd205=CD`80OWin0P1kNg/2075aL@80
E5AD0P0g=cL202d];@80:b/[0P0];Bd2034a<@@0<S8b100a<C42030`<080;bl_0P0];Bd202/[:`03
030`<00c<c<0<c<c0080;bl_0P0Y:BT202PX:0@09bLW0P0X:2P202d];@80>CTi0P1GEeL2075aL@80
QhN70P1eMGD205aLG080@d=30P1;Bd/205QHF080Ng]k0P1[Jf/207IfMP80/K6a0P2LW9`208N7Q`80
WYjN0P2l_;`00`2i^KT0/K6a0;6a/@020;6a/@80/[:b0P2d];@20;Jf]P@0]KFe0P2i^KT20;bl_080
_Kfm0P2l_;`20;Zj^P80]kNg0P2c/k<20:j^[P80ZZZZ0P2WYjL20:BTY080Xj>S0P2VYZH20:ZZZP80
Zj^[0P2/[:`20:j^[P80/;2`00<0/[:b0;>c/`2c/k<00P2c/k<40;:b/P80/K6a0P2WYjL209jNWP80
Xj>S0P2ZZZX20:^[Z`@0ZJVY9`38h=P206YZJP80IVIV0P1HF5P204m?C`80IfMW0P1RHV8205eMG@80
CTi>0P16ATH203/k>`80A4A40P1GEeL205YJFP80Cdm?0P12@T800`0c<c<0=3@d03@d=00202h^;P80
;bl_0P0];Bd202h^;P80:b/[0P0a<C4203De=@80?Cdm0P1:BTX205EEE@80DE5A0P16ATH205EEE@80
A4A40P18B4P205EEE@80H61P0P1<C4`203dm?@80>3Ph0P0U9BD203Ph>080Bd];0P1?Cdl203lo?`80
:2PX0P0/;2`205iNGP80FEUI0P1kNg/00`20P800K6a/06a/K00205iNGP80=CDe0P0Y:BT202d];@80
;bl_0P0b<S8202d];@80<C4a100b<S8203@d=080<30`0P0/;2`202XZ:P80<C4a0P0c<c<202/[:`80
;bl_0P0Q8B4202LW9`80;2`/0P0V9RH203De=@80?3`l0P1CDe<206m_K`80RXZ:0P1fMWH205IFEP80
BDU900<0E5AD05eMG@1MGEd00P1/K6`206EUI@80O7al0P2a/K4209ZJVP80QXJ60P2WYjL20;fm_@@0
]kNg0P2_[jl20;>c/`80]kNg102f][H20;Ng]`80^KVi0P2m_Kd20;no_`80_;bl0P2i^KT40;Jf]P80
[Jf]0P2/[:`20:BTY080XZ:R0P2PX:020:VYZ@80Z:RX00<0ZJVY0:j^[P2^[Zh00P2^[Zh20;2`/080
/k>c0P2a/K420;Rh^080/;2`0P2^[Zh20;6a/@80Zj^[102MWId20:ZZZP80[Jf]0P2XZ:P20:JVYRL0
b>3H0P1^KVh206IVIP80HF5Q0P14A4@206m_K`80J6QX0P1MGEd204M7A`80?3`l0P0o?cl204Q8B080
D51@00<0FEUI055AD@1ADE400P12@T8203dm?@80=SHf0P0];Bd2038b<P80;bl_0P0];Bd202/[:`80
<30`0P0f=SH203Xj>P80CDe=0P1@D50204i>CP80ADE50P17AdL204E5A@80De=C0P1FEUH2059BDP80
CTi>0P11@D42034a<@80<30`00<0=CDe04M7A`17AdL00P1BDU8203Lg=`808R8R0P0h>3P2061PH080
DE5A0P1nOWh20820P080LW9b0P1CDe<203Hf=P80;Bd]0P0Y:BT202d];@80<C4a0P0c<c<2038b<P80
<30`0P0_;bl203@d=080;bl_0P0Y:BT202`/;003034a<@0b<S80<S8b0080;2`/0P0W9bL2030`<080
:BTY0P0P820202/[:`80;Bd]0P0i>CT205IFEP80L71`0P27QhL207EeM@80GemO0P13@d<204];B`80
FUYJ0P1mOGd206e]K@80M7Ad0P2c/k<209fMW@80R8R80P2PX:020;^k^`030;Ng]`2d];@0];Bd0080
/K6a0P2e]KD20;>c/`80]kNg0P2h^;P20;Bd]080^;Rh0P2n_[h40;Zj^P80_Kfm0P2e]KD20;2`/080
[Zj^0P2][Jd20:ZZZP@0Xj>S0P2XZ:P20:NWY`80[:b/0P2][Jd20;6a/@80[Jf]00<0/[:b0;6a/@2a
/K400P2e]KD20;:b/P@0/K6a0P2ZZZX209fMW@80XZ:R102ZZZX20:VYZ@80YjNW7P38h=P001`0b>3H
0P1_Kfl206IVIP80H61P0P19BDT206i^KP80IfMW0P1MGEd204Y:BP80>c/k0P0n?Sh204M7A`80DE5A
00<0Fe]K051@D01@D5000P12@T8203/k>`80=CDe0P0a<C4202l_;`80;2`/0P0[:b/202d];@80<C4a
0P0f=SH203dm?@80BDU90P1CDe<204e=C@80ATI60P15ADD204M7A`80Cdm?0P1FEUH205EEE@80CTi>
0P0o?cl2038b<P80<30`00<0=CDe04I6AP16ATH00P1BDU8203Ph>0808R8R0P0j>SX205eMG@80De=C
0P1nOWh207]kN`80LG5a0P1DE5@203Lg=`80;Bd]0P0[:b/202d];@80<C4a100b<S84034a<@80<30`
0P0_;bl202d];@80:b/[00<0<30`03<c<`0c<c<00P0_;bl202TY:@80:2PX100W9bL202PX:080;Bd]
0P0i>CT205MGE`80LG5a0P27QhL207EeM@80G5aL0P13@d<204];B`80F5QH0P1kNg/206][J`80MWIf
0P2a/K4209bLW080QhN70P2NWYh20;bl_0030;Vi^@2a/K40/K6a0080/K6a0P2b/[820;Bd]080][Jf
102e]KD20;Vi^@80_;bl0P2m_Kd20;bl_080^[Zj0P2g]kL20;>c/`80[Zj^0P2ZZZX20:NWY`80Y:BT
0P2SXj<20:JVYP80ZZZZ0P2[Zj/20:b/[080[Zj^0P2`/;000`2b/[80/k>c0;>c/`020;>c/`@0/[:b
0P2a/K420:NWY`80WYjN0P2SXj<20:ZZZP80Zj^[102YZJTW0<SPf080JVYZ0P1VIVH205QHF080Cdm?
0P1WIfL2069RHP80GEeM0P1>CTh204I6AP80>c/k0P14A4@205MGE`80FUYJ0P1?Cdl20492@P0303<c
<`0d=3@0=3@d0080;Rh^0P0_;bl202d];@80;Rh^0P0[:b/2034a<@80=CDe0P0m?Cd204Y:BP80EEEE
0P1ADE4204I6AP80EEEE0P14A4@204Q8B080EEEE0P1PH60204a<C080?Cdm0P0h>3P202DU9@80>3Ph
0P1;Bd/204m?C`80?clo0P0X:2P202`/;080GUiN0P1IFET207]kN`030820P01/K6`0K6a/0080GUiN
0P0e=CD202TY:@80;Bd]0P0_;bl2038b<P80;Bd]0P0a<C44038b<P80=3@d0P0`<30202`/;080:RXZ
0P0a<C4203<c<`80:b/[0P0_;bl2024Q8@809bLW0P0/;2`202HV9P80=CDe0P0l?3`205=CD`80Kfm_
0P2:RXX207IfMP80EUIF0P19BDT00`1DE5@0GEeM05eMG@0206a/K080IFEU0P1lO7`20;6a/@80VYZJ
0P26QXH20:NWY`80_Kfm102g]kL20:n_[`80/k>c0P2g]kL40;Jf]P80]kNg0P2i^KT20;fm_@80_kno
0P2l_;`20;Vi^@@0][Jf0P2][Jd20:b/[080Y:BT0P2RXZ820:2PX080ZJVY0P2XZ:P00`2YZJT0[Zj^
0:j^[P020:j^[P80/;2`0P2c/k<20;6a/@80^;Rh0P2`/;020:j^[P80/K6a0P2[Zj/409fMW@80ZZZZ
0P2][Jd20:RXZ080YZJV9`38h=P206i^KP80IVIV0P1QHF4204A4A080Kfm_0P1XJ6P205eMG@80AdM7
0P0l?3`203lo?`80B4Q80P1@D5000`1IFET0DE5A055AD@020492@P80?Cdm0P0f=SH202d];@80<S8b
0P0_;bl202d];@80:b/[0P0`<30203Hf=P80>SXj0P1=CDd2051@D080CTi>0P15ADD204M7A`80ADE5
0P1CDe<205IFEP80DU9B0P1>CTh20451@@80<C4a0P0`<3000`0e=CD0AdM704M7A`02059BDP80=cLg
0P0R8R8203Ph>080H61P0P1ADE4207inOP80P8200P1bLW8205=CD`80=SHf0P0];Bd202TY:@80;Bd]
0P0a<C4203<c<`80<S8b0P0`<30202l_;`80=3@d0P0_;bl202TY:@80;2`/00<0<C4a038b<P0b<S80
0P0/;2`202LW9`80<30`0P0Y:BT2020P8080:b/[0P0];Bd203Ti>@80EUIF0P1`L70208N7Q`80MGEe
0P1OGel204=3@`80Bd];0P1JFUX207emO@80KFe]0P1dM7@20;>c/`80WIfM0P28R8P20:2PX080^k^k
00<0]kNg0;Bd]02d];@00P2a/K420;Fe]@80/k>c0P2g]kL20;Rh^080];Bd0P2h^;P20;jn_P@0^[Zj
0P2m_Kd20;Fe]@80/;2`0P2^[Zh20:f][@80ZZZZ102SXj<20:RXZ080YjNW0P2/[:`20:f][@80/K6a
0P2][Jd00`2b/[80/K6a0;6a/@020;Fe]@80/[:b102a/K420:ZZZP80WIfM0P2RXZ840:ZZZP80ZJVY
0P2WYjLN0<SPf0007038h=P206m_K`80IfMW0P1TI6@204];B`80MGEe0P1YJFT205mOG`@0GUiN0P1@
D50204E5A@80C4a<00<0GEeM05=CD`1CDe<00P14A4@203`l?080=SHf0P0b<S8202l_;`80;2`/0P0[
:b/202d];@80<C4a0P0g=cL203lo?`80BDU90P1ADE4204a<C080ATI60P15ADD204M7A`80D51@0P1G
EeL205ADE080C4a<0P0o?cl203<c<`80<C4a00<0=3@d04I6AP16ATH00P1BDU8203Lg=`808B4Q0P0l
?3`206=SH`80E5AD0P20P80207]kN`80Kfm_0P1@D502034a<@80:RXZ0P0[:b/202d];@P0<C4a1P0`
<30202d];@80:b/[00<0<30`03De=@0e=CD00P0`<30202XZ:P@0:2PX100V9RH202TY:@80<S8b0P16
ATH2065QH@80DE5A0P28R8P207EeM@80H61P0P1HF5P2059BDP80HF5Q0P18B4P206ATI080/k>c0P2N
WYh208J6QP80Vi^K0P2m_Kd00`2i^KT0/;2`0;2`/0020;2`/080/[:b0P2d];@20;Jf]P@0]KFe0P2h
^;P20;bl_080_Kfm0P2l_;`20;Zj^P80]kNg0P2c/k<20:n_[`80Zj^[0P2XZ:P20:BTY080Xj>S0P2V
YZH20:ZZZP80Zj^[0P2/[:`20:j^[P80/;2`00<0/[:b0;>c/`2c/k<00P2c/k<20;:b/P80/k>c0P2b
/[820:RXZ080WinO0P2TY:@40:^[Z`@0ZJVY9`38h=P207IfMP80Kfm_0P1LG5`205]KF`80O7al0P1a
LG4206YZJP80FEUI0P1EEED205=CD`80BDU90P1:BTX2055AD@80CDe=0P1<C4`00`0m?Cd0?Shn03hn
?P0203/k>`80<S8b0P0`<30202TY:@80:RXZ0P0h>3P203Xj>P80B4Q80P1=CDd204Q8B080CTi>0P13
@d<20451@@@0ADE50P1EEED2055AD@80AdM70P0n?Sh203/k>`809bLW0P0f=SH204a<C080DE5A0P0h
>3P202HV9P80=SHf0P1aLG4205]KF`80NGUi00<0N7Qh05mOG`1OGel00P1HF5P2038b<P80:2PX0P0/
;2`202/[:`80;bl_0P0j>SX202l_;`80;2`/0P0];Bd4030`<080=SHf0P0a<C42030`<080>SXj0P0_
;bl202TY:@80:RXZ0P0/;2`202TY:@809bLW0P0Y:BT202`/;080@D510P1OGel206a/K080Q8B40P1[
Jf/205QHF00305EEE@1IFET0FEUI0080HF5Q0P1?Cdl2079bLP80YjNW0P2QXJ4208>3P`80WIfM0P2f
][H20;2`/080[Zj^0P2YZJT20;6a/@80]kNg0P2a/K420;2`/080/k>c0P2e]KD20;Ng]`80^k^k102l
_;`20;Ng]`80/[:b0P2[Zj/40:f][@80YJFU0P2SXj<20:JVYP80Zj^[00<0[:b/0:n_[`2_[jl00P2/
[:`40;>c/`80[jn_0P2b/[820;Bd]080/k>c0P2`/;020:VYZ@80YjNW0P2PX:020:n_[`80/k>c0P2/
[:`20:f][BL0b>3H0P1`L70206EUI@80IfMW0P17AdL207MgM`80KFe]101OGel2065QH@80CTi>0P17
AdL204e=C@03061PH01GEeL0EeMG0080@D510P0j>SX203@d=080:b/[0P0`<30202`/;0@0:RXZ0P0a
<C4203Xj>P80?Shn0P1=CDd2051@D080CTi>0P13@d<204Q8B080ATI60P1ADE4205QHF080EUIF0P1<
C4`20410@080<S8b0P0`<3000`0e=CD0Bd];04];B`02055AD@80>3Ph0P0R8R8203lo?`80Hf=S0P1B
DU8207moO`80OWin0P1_Kfl204i>CP80=SHf0P0Z:RX202d];@80<30`0P0_;bl2030`<080<S8b0P0a
<C4202h^;P80=3@d0P0/;2`202TY:@80;2`/00<0<c<c03De=@0e=CD00P0/;2`202PX:080;Bd]0P0U
9BD201/K6`80:2PX0P0Y:BT203<c<`80BDU90P1SHf<2055AD@80Q8B40P1eMGD2061PH080EEEE0P1B
DU8206=SH`80B4Q80P1SHf<20;Fe]@80VYZJ0P25QHD209jNWP80_Kfm00<0^KVi0;6a/@2a/K400P2^
[Zh20;Bd]080[Zj^0P2e]KD20;Ng]`80];Bd0P2g]kL40;fm_@80^k^k0P2m_Kd20;Vi^@80[Jf]0P2^
[Zh20:b/[080XJ6Q0P2RXZ820:>SX`80ZZZZ0P2[Zj/20:ZZZP80Zj^[0P2^[Zh20;2`/0030;Bd]02b
/[80/[:b0080^;Rh0P2b/[820;Fe]@80/[:b0P2YZJT209fMW@80Y:BT0P2^[Zh40:ZZZP80ZJVY7P38
h=P001`0b>3H0P1_Kfl206MWI`80I6AT0P1;Bd/207EeM@80JFUY0P1OGel405iNGP80D51@0P15ADD2
04a<C00305eMG@1CDe<0De=C0080A4A40P0l?3`203Hf=P80<S8b0P0_;bl202`/;080:b/[0P0];Bd2
034a<@80=cLg0P0o?cl204U9B@80DE5A0P1<C4`204I6AP80ADE50P17AdL2051@D080EeMG0P1DE5@2
04a<C080?clo0P0c<c<2034a<@0303@d=016ATH0ATI60080DU9B0P0g=cL2024Q8@80?3`l0P1SHf<2
05ADE080P8200P1kNg/206m_K`80D51@0P0a<C4202XZ:P80:b/[0P0];Bd8034a<@H0<30`0P0];Bd2
02/[:`03030`<00e=CD0=CDe0080<30`0P0Z:RX402PX:0@09RHV0P0Y:BT2038b<P80ATI60P1QHF42
055AD@80R8R80P1eMGD2061PH080F5QH0P1BDU82065QH@80B4Q80P1TI6@20;>c/`80WYjN0P26QXH2
09^KV`80_Kfm00<0^KVi0;2`/02`/;000P2`/;020;:b/P80];Bd0P2f][H40;Fe]@80^;Rh0P2l_;`2
0;fm_@80_;bl0P2j^[X20;Ng]`80/k>c0P2_[jl20:^[Z`80Z:RX0P2TY:@20:>SX`80YZJV0P2ZZZX2
0:^[Z`80[:b/0P2^[Zh20;2`/0030;:b/P2c/k<0/k>c0080/k>c0P2b/[820;>c/`80/[:b0P2XZ:P2
09nOW`80Y:BT102[Zj/40:VYZBL0b>3H0P1fMWH206m_K`80G5aL0P1KFe/207alO080LG5a0P1ZJVX2
05UIF@80EEEE0P1CDe<204U9B@80BTY:0P1ADE4204e=C@80C4a<00<0?Cdm03hn?P0n?Sh00P0k>c/2
038b<P80<30`0P0Y:BT202XZ:P80>3Ph0P0j>SX204Q8B080CDe=0P18B4P204i>CP80@d=30P11@D44
04E5A@80EEEE0P1ADE4204M7A`80?Shn0P0k>c/202LW9`80=SHf0P1<C4`2055AD@80>3Ph0P0V9RH2
03Hf=P80LG5a0P1KFe/207UiN@0307QhN01OGel0GemO0080F5QH0P0b<S8202PX:080;2`/0P0[:b/2
02l_;`80>SXj0P0_;bl202`/;080;Bd]100`<30203Hf=P80<C4a0P0`<30203Xj>P80;bl_0P0Y:BT2
02XZ:P80;2`/0P0Y:BT202LW9`80:BTY0P0/;2`20451@@80GemO0P1/K6`208B4Q080Jf][0P1HF5P0
0`1EEED0FEUI05UIF@02065QH@80Cdm?0P1bLW820:NWY`80XJ6Q0P23Ph<209fMW@80][Jf0P2`/;02
0:j^[P80ZJVY0P2a/K420;Ng]`80/K6a0P2`/;020;>c/`80]KFe0P2g]kL20;^k^`@0_;bl0P2g]kL2
0;:b/P80Zj^[102][Jd20:FUY@80Xj>S0P2VYZH20:^[Z`030:b/[02_[jl0[jn_0080[:b/102c/k<2
0:n_[`80/[:b0P2d];@20;>c/`80/;2`0P2YZJT20:NWY`80X:2P0P2_[jl20;>c/`80[:b/0P2][JdW
0<SPf080L71`0P1UIFD206MWI`80AdM70P1gMgL206e]K@@0GemO0P1QHF4204i>CP80AdM70P1=CDd0
0`1PH600EeMG05MGE`020451@@80>SXj0P0d=3@202/[:`80<30`0P0/;2`402XZ:P80<C4a0P0j>SX2
03hn?P80CDe=0P1@D50204i>CP80@d=30P18B4P204I6AP80DE5A0P1HF5P205IFEP80C4a<0P10@402
038b<P80<30`00<0=CDe04];B`1;Bd/00P1ADE4203Ph>0808R8R0P0o?cl206=SH`80DU9B0P1oOgl2
07inOP80Kfm_0P1>CTh203Hf=P80:RXZ0P0];Bd2030`<080;bl_0P0`<302038b<P80<C4a0P0^;Rh2
03@d=080;2`/0P0Y:BT202`/;00303<c<`0e=CD0=CDe0080;2`/0P0X:2P202d];@809BDU0P0K6a/2
02PX:080:BTY0P0c<c<204U9B@80Hf=S0P1ADE4208B4Q080MGEe0P1PH60205EEE@80DU9B0P1SHf<2
04Q8B080Hf=S0P2e]KD209ZJVP80QHF50P2NWYh20;fm_@030;Vi^@2a/K40/K6a0080[Zj^0P2d];@2
0:j^[P80]KFe0P2g]kL20;Bd]080]kNg102m_Kd20;^k^`80_Kfm0P2i^KT20:f][@80[Zj^0P2/[:`2
0:6QX@80XZ:R0P2SXj<20:ZZZP80Zj^[0P2ZZZX20:^[Z`80[Zj^0P2`/;000`2d];@0/[:b0;:b/P02
0;Rh^080/[:b0P2e]KD20;:b/P80ZJVY0P2MWId20:BTY080[Zj^102ZZZX20:VYZAh0b>3H003o0<SP
f?l0b>3Ho`38h=Qm0<SPf000o`38h=So0<SPf?l0b>3HO@38h=P00?l0b>3Ho`38h=So0<SPf7d0b>3H
003o0<SPf?l0b>3Ho`38h=Qm0<SPf000o`38h=So0<SPf?l0b>3HO@38h=P00?l0b>3Ho`38h=So0<SP
f7d0b>3H003o0<SPf?l0b>3Ho`38h=Qm0<SPf000o`38h=So0<SPf?l0b>3HO@38h=P00?l0b>3Ho`38
h=So0<SPf7d0b>3H003o0<SPf?l0b>3Ho`38h=Qm0<SPf000o`38h=So0<SPf?l0b>3HO@38h=P00?l0
b>3Ho`38h=So0<SPf7d0b>3H0000\
\>"],
  ImageRangeCache->{{{0, 889}, {277.125, 0}} -> {-0.0789231, -0.0234425, \
0.00355214, 0.00355214}, {{22.1875, 286.125}, {270.5, 6.5625}} -> {-14.4989, \
-6.57422, 0.509216, 0.509216}, {{312.5, 576.438}, {270.5, 6.5625}} -> \
{-162.331, -6.57422, 0.509216, 0.509216}, {{602.813, 866.75}, {270.5, \
6.5625}} -> {-310.163, -6.57422, 0.509216, 0.509216}}]
}, Open  ]],

Cell["\<\
Although the en-noised image does look better than the de-noised one, we note \
that there is more noise than  there was in the beginning. This is partly \
because we equated some information lost in quantization with noise, and \
partly because there are noiser and less noisy areas on the image. For \
example, the skin as a less noisy part of the image has received more noise \
than there was in the beginning, whereas the edges and sharp features \
received too little. We corrected this by introducing the correction factor \
of 2 (we divided the standard deviation by 2) which makes the skin \
appropriately smooth, but the hat feathers excessively smooth.\
\>", "Text"],

Cell["\<\
We would have achieved better results by decomposing in the spatial domain. \
For example, the texture of the hat is noisier than the texture of the skin, \
so the noise distribution should be computed differently there. There is \
another important but yet unsolved problem: a part of the quantization noise \
is indeed noise, but a part is lost information. The lost information \
shouldn't be considered a part of noise - as we cannot reintroduce it.\
\>", "Text"],

Cell[BoxData[
    \(\(diff\  = \ ImgIDWT[Interleave2[qdecomp]] - sub;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Variance map", "Section"],

Cell["\<\
Now, we compute the standard deviations of quantization residuals at \
different resolutions. We will call these \"variance maps\".\
\>", "Text"],

Cell["\<\
We will need a routine which will bunch together neighboring pixels\
\>", "Text"],

Cell[BoxData[{
    \(\(Whack[M_, res_] := 
        Map[Map[Flatten, #] &, 
          Transpose[
            Map[Partition[#, res] &, Transpose[Map[Partition[#, res] &, M]], 
              2]]];\)\), "\[IndentingNewLine]", 
    \(FiltO[x_] := 0 /; x != 0; \ FiltO[x_] := 1 /; x == 0; 
    Filter[C_, res_] := 
      Map[FiltO, 
        Map[Map[Flatten, #] &, 
          Transpose[
            Map[Partition[#, res] &, Transpose[Map[Partition[#, res] &, C]], 
              2]]], {3}];\), "\[IndentingNewLine]", 
    \(\(VarianceMap[{M_, C_}, res_] := 
        Map[StandardDeviation, 
          Whack[M, res]*Filter[C, res], {2}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Map[Block[{res = #}, 
                GraphicsArray[
                  Map[Graphics[Raster[\((VarianceMap[#, res] + 16)\)/32], 
                        AspectRatio \[Rule] 1] &, 
                    Table[{mcomp[\([i, j]\)], qdecomp[\([i, j]\)]}, {i, 1, 
                        2}, {j, 1, 2}], {2}], 
                  GraphicsSpacing \[Rule] 0]] &, {2, 4, 8, 16, 32, 64}], 
          GraphicsSpacing \[Rule] 0]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.00396825 0.15873 [
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00396825 0.18254 0.162698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B5C1C595A08F9B8B8D98A494A0909D88878383898F928694998B918E8F968F8F
9BAEB7B6A29998ADB2AB9FAE979192948A8694848A8C88898E91839489979388
E99EA3BCAF9FB0978C8691958A8E8A91A1938E8E9C8885939B8B8B958D8B938B
BEAAB6F8C4A8DCA091BA939C9C8DA4948D8E9B90A89A9495898F978E9B9498A7
C6A0B09BA3A49A849BAA9385899389878A90998597899086898F938A95B8C7A6
9D9CA0C3A6CAB1B08B91969F9090878D898C8F95998B8B868995959F96AD8696
9F87B9AFC4B8B39EC0AD9B9DA38E8E8A849998908E8E9390949899938E91968E
95B8AC929AB5B8B09A9FA08B998D978B878F9684898C8C909188888F91928A88
9BBE8E979E9296C4AA928D989696928E8D94909E8D96A0949A8D93958E8B9088
BF958F9F8D8B8396A5A99CAA9391949D9F968994828991928D889C8C918A9592
90A9959692A7928CB9B58C989B94A08D918E939B909A9C899A8D8C8A85928F8D
8F8D8EA19CB29C9397D4918C868E8C968D8A959191919D96878E8E9699929287
AD9895A29D9F999184ABA8A38D9A838F9183868D8AA290968A9393929785998C
A99993939AA7A2889289DBC1919B868B928F8D8D8D84879091A090948C969D8F
97A2A69797919D929E9B97E2C792978A96988D8E8998989B8B95888F9A8C8C8C
BC9FAEA39B9F939A8C90958FC29691919C8F8D9A8AA18B869C97939C98868698
A6969B9AB5A1A39EAB98879090A5A4908D8F908B9BA6BCAE89C4A38B959EA891
BB9CB1A9BA9D94A79A9BCFA3888CB6B38E948BA3B687CDA6ABCFB08C91979694
9A97B6A5918CA991D0D0B0D4AA8D91969CA1B5B1A7CAB4D48C8D868E93A18791
B097A08FA3ADA0CBBA9D8596969088C0E489BBA1B4AE94DFA4B5BBC4889A858E
C6AF9F8AA6E8C696A69AA69696878292D2CBA28BA392968BC2889ABD9984998A
A9A9A0B0C4BCAD929AB9A59BA68C9C8C91B3AAA4C193B3BFBEB99F8D91939394
9C919CA6A8A58AA3A2DB949FA7989C90918EACB9938CBA9A9595B69AC6888998
8EBACCCAA38D8BB4D593A7A58D95A88C958E9092DE9E95ACA2AFCF97AD899392
99B0CAAB8E928FBAA2A590BCAAAD9E9D92898F9397ADB1A494AB8C9889969293
AEA0A4BCC69596AB94A6B7C3B6CB95B99F949089919DBFB1A69791908B8C8C87
DB9DB1D7B5BF98958AA2AE9491A1B19E8A898D8E969497839CAC878E8B8B8989
91968BADC9A5919A8DABA3DDB29D95AA909B87958D858F8688A5908B8C939394
C892A395B3A8AB9D919FC3A9B9AD97CE99A9BF889F87A59C879390949E8D9188
9FA89495968F96969E9397B3A4A9BA9DC7A9ABAC9899B09292A38794CF98938E
B5A79F9FB6A5A8AFA7A59FA0B8C2B39397C59CB8D0BC919687A08F88918E919D
C5D5BBD6B39DC4BDB49095C0BE93AEB392ADA591B594AC8F998AA6879994A1A6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.18254 0.00396825 0.34127 0.162698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0595238 0.0238095 0.0595238 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CAAFAAC0B3A79E94959696929A9496B5
ACB6989FAFB0908F97929A91949494A9
BAA8A39EB7A59A90959F969090A5A0A1
AFBFB89FBCBC95939E9499989299969E
ABB9B6B9AFAF9C9598999492988C9591
A6A4C0B0B39E93969191949693959697
AE9AABB99FAC979C959797938E949DA9
A1A397B9BAB1AE9399969998A3A095A5
9EA5B0ADC6A99BA8A4AAABB1AC9E9B97
AD9AA4B0B3C89CAAA3ABC1ACA6C0A1A6
ABA2B5A3BABBA095C5ADA9B0ABA79894
AFC1B4ABB0D1C09AA3AEA4B1B09B9B94
B4B5A6A7B798C8BA9897A6A399958F99
B0B0B3BAAFBCBCC3A89FAD999F9B939B
B1B3B5A9B8AFA2B5B2A9B3A99FA1A29B
AFAA9AB4B8C0C896A3BDB4A0959494A5
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0595238 0.0238095 0.0595238 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D8E2AFA3A3A3A7A79B9C96999A98A296
CAD2C3D7AEABA19D9CA79A97A097A490
C3AAD7B8A3BCA59C9DA4A099A69FAFAB
D8A9BEA5B7ADA299A19C9993999C94A1
ABB0BAD0B59DA09EA2A4A49899A0A09D
A2AAB9A8D8A9999798A2A49BA0A09FAF
AA97B9CCB2CA9BA6A0A09B9A9B9AA1A7
C0A0AFCBB6E0BDA0AAA09EA8A297979E
AFA6C7C0C29FF8E090A3C0A9A69BA7A3
BAA5CDCAC5C09BFFA8A8C1CFA1B29AA0
C8B4CFBCE0EBB495F7C1AECED9BBB69C
C1ECA4BFD6C6BCB2A7E9B4B9B2ADA29E
BCE2AEC4CBD1EDC7A299C2AB9BA79F96
BFC3C3BBB9BAD4E3F89BA1A1A6B793A6
C1ADABCCBDC5B1B2ABB0A0A7A0A29F9B
B2C2A6D9C0D3C1BED7B3BCA6959DA8AA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0595238 0.0238095 0.0595238 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
80808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0595238 0.0238095 0.0595238 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ACB3A6ABA7A0979B868A8F8C908F928E
BEC6AFB5A095959695919A908F92929A
A8AEACA49D9E8F8A8C90928C9195A8A7
A0ABB3B3A89B968F8F928D8E9190908D
AD9792A2A29C939494938E9690958F8F
9D9AA293B59091938D939396928E918E
A496A09596B7948C8D8A939295939094
A7A1979595AFAE909590969B9891918F
A6A2A9A0A5A899A69193A6B7B69D979B
9FA29BADBCAD98A0B2AFB1BE9FAB978F
AFA1C3A9A39E9591BAA0A8A9B1A59393
9FB4A5A1BDA5989891A4AFA6A1AFA991
A6B3A6A4A5B3B2A6948E9DAE9E918E8E
ADB2B5979BB5A5A5908F948E9D8E8F8F
B0979F9C9AADAEB3ABA8959F9490A88E
C0B4ACB5A5A6B3AAA7A5B59B9496929E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.34127 0.00396825 0.5 0.162698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B7ADB095969595A5
B4A9B7949A96999D
ACB9AC9796959495
A4AEAE9F97979BA2
A3ACBBA3A7B3AD9E
B1ADC0A7B2ACA797
B2AFB1BF9EA49A96
AFABB7B0AFAD9B9E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D4BEA7A49E989B9C
BDBEB19FA09A9FA5
ACBDB99CA09F9EA3
ACC0C5ACA29F9EA0
B0C6BAE3A2C0A6A3
CCBDD9B0D6BABEA5
CABCC4DCBFADA99C
BBC3C4B8BCAC9DA4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080808080808080
8080808080808080
8080808080808080
8080808080808080
8080808080808080
8080808080808080
8080808080808080
8080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B8B4A09790929093
A7AEA1908F8E929D
9F9BA3939293928F
A199A79B90969691
A2A4AE9EA4B3A896
A9ADAA96A6A9A999
ADA6AAA8909D978E
B0A8A5B0A7A3949B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00396825 0.65873 0.162698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0238095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B0A7979D
AEA5979A
ACB2AEA4
AFB6A89A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0238095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C4A79C9F
B6B4A0A0
C0CCBFAC
C1C8B5A2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0238095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
80808080
80808080
80808080
80808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0238095 0.238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B19B9095
9D9E9392
A7A4AAA1
ABAA9F96
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.65873 0.00396825 0.81746 0.162698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
2 string
2 2 8 [2 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AB99
B1A6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
2 string
2 2 8 [2 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B69F
C5B2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
2 string
2 2 8 [2 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080
8080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
2 string
2 2 8 [2 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A393
A8A1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.81746 0.00396825 0.97619 0.162698 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B5
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
80
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{908, 151.313},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000><0000Ub000`400?l00000o`00003oo`38h=So
0<SPf?l0b>3HS`38h=P00?l0b>3Ho`38h=So0<SPf8l0b>3H003o0<SPf?l0b>3Ho`38h=R?0<SPf000
o`38h=So0<SPf?l0b>3HS`38h=P00?l0b>3Ho`38h=So0<SPf8l0b>3H003o0<SPf?l0b>3Ho`38h=R?
0<SPf000o`38h=So0<SPf?l0b>3HS`38h=P00?l0b>3Ho`38h=So0<SPf8l0b>3H003o0<SPf?l0b>3H
o`38h=R?0<SPf000o`38h=So0<SPf?l0b>3HS`38h=P001d0b>3H0P3De=@20;Fe]@80^k^k0P2o_kl2
08n?S`80^KVi0P2j^[X20<K6aP80YJFU0P2o_kl208B4Q080^[Zj0P2QXJ420:NWY`80U9BD0P2HV9P3
09BDU080RHV90P2JVYX208F5Q@80UYJF0P2CTi<20:6QX@80S8b<0P2LW9`209jNWP80V9RH0P2>SXh4
096AT@80aLG50P2VYZH30<SPf080o_kn0P3Bd]820>3Ph080bl_;0P3<c<`209FEU@80]KFe0P2BTY82
0;>c/`80Xj>S0P2LW9`20;6a/@80Xj>S0P2d];@20:NWY`80][Jf0`2EUID2096AT@80X:2P0P2UYJD2
09BDU080WinO0P2EUID208V9R@80U9BD0P2PX:0209jNWP80Y:BT102XZ:P20:>SX`80UYJF2P38h=P4
0<[:bP@0[jn_102ZZZX40<30`0@0/k>c102WYjL509jNWP@0U9BD102EUID809JFUP@0TY:B102JVYX4
09BDU0@0UYJF1@2e]KD20<SPf0@0f=SH103Rh^840:n_[`d0Xj>S202WYjL409^KV`@0W9bL102FUYH4
09VIV@@0VYZJ1@2HV9P40::RXP@0UYJF2@38h=P80;Ng]`P0[Jf]2@2`/;0809FEU@P0UYJF4@2EUID8
0:FUY@80b>3H203De=@80;jn_PT0YjNW202TY:@809jNWPP0V9RH2@2KVi/809bLW0T0b>3H402`/;0A
0:NWYa00UiNG4@2MWId20<SPf140a<C4402WYjLA09bLW100WinO2@38h=PQ0:^[Zb40VIVI0P38h=PQ
0;Jf]R40WinO2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20=CDe080]KFe0P2k^k/20;no
_`80Shn?0P2i^KT20;Zj^P80a/K60P2UYJD20;no_`80Q8B40P2j^[X20:6QX@80YjNW0P2DU9@209RH
V0<0U9BD0P29RHT209ZJVP80QHF50P2FUYH209>CT`80XJ6Q0P2<S8`209bLW080WYjN0P2HV9P208j>
SP@0TI6A0P35aLD20:JVYP<0b>3H0P3no_h20=;BdP80h>3P0P3;bl/20<c<c080UIFE0P2e]KD209:B
TP80/k>c0P2SXj<209bLW080/K6a0P2SXj<20;Bd]080YjNW0P2f][H309FEU@80TI6A0P2PX:020:FU
Y@80U9BD0P2OWil209FEU@80RHV90P2DU9@20:2PX080WYjN0P2TY:@40:RXZ080Xj>S0P2FUYH:0<SP
f0@0b/[:102_[jl40:ZZZP@0`<30102c/k<40:NWY`D0WYjN102DU9@409FEU@P0UYJF102BTY8409ZJ
VP@0U9BD102FUYH50;Fe]@80b>3H103Hf=P40>;RhP@0[jn_3@2SXj<80:NWY`@0Vi^K102LW9`409JF
UP@0VIVI102JVYX509RHV0@0XZ:R102FUYH90<SPf0P0]kNg202][Jd90;2`/0P0UIFE202FUYHA09FE
U@P0YJFU0P38h=P80=CDe0P0_[jn2@2WYjL80:BTY0P0WYjN202HV9P909^KV`P0W9bL2@38h=P@0;2`
/140YjNW402GUiLA09fMW@80b>3H4@34a<@@0:NWYa40W9bL402OWil90<SPf240Zj^[8@2IVIT20<SP
f240][Jf8@2OWil90<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080a<C40P3Ti>@20:2PX080
[Zj^0P2JVYX209JFUP80Z:RX0P2DU9@209VIV@80/;2`0P2^[Zh209VIV@80RHV90P2SXj<2092@T080
SHf=0`2CTi<209fMW@80VYZJ0P2<S8`209ZJVP80U9BD0P27QhL209>CT`80VIVI0P2DU9@209VIV@80
SHf=0P2DU9@20:2PX080[Jf]0P31`L430<SPf080h>3P0P2h^;P20?ooo`80Zj^[0P2^[Zh209jNWP80
Y:BT0P2QXJ4208Z:RP80Xj>S0P2QXJ4209nOW`80S8b<0P2g]kL209:BTP80/k>c0`2IVIT20:^[Z`80
Vi^K0P2JVYX208f=S@80Shn?0P2PX:020:FUY@80VYZJ0P2<S8`2092@T080U9BD0P2OWil209FEU@80
V9RH0P27QhL:0<SPf0@0b/[:102_[jl40:ZZZP@0`<30102c/k<40:NWY`D0WYjN102DU9@409FEU@P0
UYJF102BTY8409ZJVP@0U9BD102FUYH50;Fe]@80b>3H103Hf=P40>;RhP@0[jn_3@2SXj<80:NWY`@0
Vi^K102LW9`409JFUP@0VIVI102JVYX509RHV0@0XZ:R102FUYH90<SPf0P0]kNg202][Jd90;2`/0P0
UIFE202FUYHA09FEU@P0YJFU0P38h=P80=CDe0P0_[jn2@2WYjL80:BTY0P0WYjN202HV9P909^KV`P0
W9bL2@38h=P@0;2`/140YjNW402GUiLA09fMW@80b>3H4@34a<@@0:NWYa40W9bL402OWil90<SPf240
Zj^[8@2IVIT20<SPf240][Jf8@2OWil90<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080a<C4
0P3Ti>@20:2PX080[Zj^0P2JVYX209JFUP80Z:RX0P2DU9@209VIV@80/;2`0P2^[Zh209VIV@80RHV9
0P2SXj<2092@T080SHf=0`2CTi<209fMW@80VYZJ0P2<S8`209ZJVP80U9BD0P27QhL209>CT`80VIVI
0P2DU9@209VIV@80SHf=0P2DU9@20:2PX080[Jf]0P31`L430<SPf080h>3P0P2h^;P20?ooo`80Zj^[
0P2^[Zh209jNWP80Y:BT0P2QXJ4208Z:RP80Xj>S0P2QXJ4209nOW`80S8b<0P2g]kL209:BTP80/k>c
0`2IVIT20:^[Z`80Vi^K0P2JVYX208f=S@80Shn?0P2PX:020:FUY@80VYZJ0P2<S8`2092@T080U9BD
0P2OWil209FEU@80V9RH0P27QhL:0<SPf0@0b/[:102_[jl40:ZZZP@0`<30102c/k<40:NWY`D0WYjN
102DU9@409FEU@P0UYJF102BTY8409ZJVP@0U9BD102FUYH50;Fe]@80b>3H103Hf=P40>;RhP@0[jn_
3@2SXj<80:NWY`@0Vi^K102LW9`409JFUP@0VIVI102JVYX509RHV0@0XZ:R102FUYH90<SPf0P0]kNg
202][Jd90;2`/0P0UIFE202FUYHA09FEU@P0YJFU0P38h=P80=CDe0P0_[jn2@2WYjL80:BTY0P0WYjN
202HV9P909^KV`P0W9bL2@38h=P@0;2`/140YjNW402GUiLA09fMW@80b>3H4@34a<@@0:NWYa40W9bL
402OWil90<SPf240Zj^[8@2IVIT20<SPf240][Jf8@2OWil90<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H
000M0<SPf080^KVi0P2:RXX20;Zj^P80[:b/0P2BTY820::RXP80YjNW0P2ATI4209RHV080ZJVY0P2^
[Zh209fMW@80R8R80P2IVIT208f=S@80Rh^;0`2@T9020:2PX080Shn?0P27QhL209^KV`80SXj>0P2<
S8`208j>SP80VYZJ0P2:RXX208f=S@80S8b<0P2EUID208J6QP80Vi^K0P3;bl/30<SPf080Zj^[0P2e
]KD20=OGe`80hn?S0P2NWYh20:RXZ080k^k^0P2BTY820;Ng]`80Xj>S0P2`/;020;Jf]P80XZ:R0P2=
SHd20:>SX`80WIfM0`2XZ:P2092@T080/k>c0P2JVYX208b<S080W9bL0P2VYZH208b<S080V9RH0P25
QHD209NGU`80SXj>0P2UYJD20:JVYP80W9bL0P26QXH:0<SPf0@0[:b/102f][H409RHV0@0WinO102_
[jl40;2`/0D0T92@102?Shl409NGU`@0TY:B102JVYX4096AT@`0U9BD1@2YZJT20<SPf0@0b/[:103B
d]840<?3``@0emOG102^[Zh50:^[Z`@0XJ6Q102MWId409bLW0@0YjNW102JVYX409NGU`@0X:2P1@2G
UiL40:BTY0@0T92@2@38h=P80;Ng]`P0[Jf]2@2`/;0809FEU@P0UYJF4@2EUID80:FUY@80b>3H203D
e=@80;jn_PT0YjNW202TY:@809jNWPP0V9RH2@2KVi/809bLW0T0b>3H402`/;0A0:NWYa00UiNG4@2M
WId20<SPf140a<C4402WYjLA09bLW100WinO2@38h=PQ0:^[Zb40VIVI0P38h=PQ0;Jf]R40WinO2@38
h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20;Vi^@80RXZ:0P2j^[X20:b/[080TY:B0P2RXZ82
0:NWY`80TI6A0P2HV9P20:VYZ@80[Zj^0P2MWId208R8R080VIVI0P2=SHd208^;R`<0T92@0P2PX:02
08n?S`80QhN70P2KVi/208j>SP80S8b<0P2>SXh209ZJVP80RXZ:0P2=SHd208b<S080UIFE0P26QXH2
09^KV`80bl_;0`38h=P20:^[Z`80]KFe0P3GemL20>?Sh`80WYjN0P2XZ:P20>k^kP80TY:B0P2g]kL2
0:>SX`80/;2`0P2f][H20::RXP80SHf=0P2SXj<209fMW@<0Z:RX0P2@T9020;>c/`80VYZJ0P2<S8`2
09bLW080YZJV0P2<S8`209RHV080QHF50P2GUiL208j>SP80YJFU0P2VYZH209bLW080QXJ62P38h=P4
0:b/[0@0][Jf102HV9P409nOW`@0[jn_102`/;05092@T0@0Shn?102GUiL409:BTP@0VYZJ102ATI4<
09BDU0D0ZJVY0P38h=P40<[:bP@0d];B1033`l<40=OGe`@0[Zj^1@2[Zj/40:6QX@@0WIfM102LW9`4
0:NWY`@0VYZJ102GUiL40:2PX0D0UiNG102TY:@4092@T0T0b>3H202g]kL80:f][@T0/;2`202EUID8
09JFUQ40UIFE202UYJD20<SPf0P0e=CD202n_[h90:NWY`P0Y:BT202NWYh809RHV0T0Vi^K202LW9`9
0<SPf100/;2`4@2WYjL@09NGUa40WIfM0P38h=PA0<C4a100YjNW4@2LW9`@09nOW`T0b>3H8@2[Zj/Q
09VIV@80b>3H8@2f][HQ09nOW`T0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2f][H20:RX
Z080a<C40P2/[:`20:6QX@80SHf=0P2HV9P20:VYZ@80cLg=0P2YZJT20;Bd]080Ti>C0P25QHD208b<
S080R8R80P2GUiL309^KV`80UYJF0P2GUiL208N7Q`80UIFE0P2[Zj/208b<S080R8R80P2HV9P208n?
S`80VYZJ0P2FUYH208j>SP80WYjN0P2ATI4208Z:RP<0b>3H0P3kno/20<_;b`80]KFe0P2LW9`20?Sh
n080VYZJ0P3oool20<[:bP@0ZZZZ0P2TY:@20:RXZ080ZZZZ0P2][Jd209JFUP80TI6A0`2;Rh/20:NW
Y`80ZJVY0P2GUiL209fMW@80T92@0P2:RXX209JFUP80[:b/0P2c/k<209:BTP80RXZ:0P2/[:`20:>S
X`80TI6A0P28R8P:0<SPf0@0[:b/102f][H409RHV0@0WinO102_[jl40;2`/0D0T92@102?Shl409NG
U`@0TY:B102JVYX4096AT@`0U9BD1@2YZJT20<SPf0@0b/[:103Bd]840<?3``@0emOG102^[Zh50:^[
Z`@0XJ6Q102MWId409bLW0@0YjNW102JVYX409NGU`@0X:2P1@2GUiL40:BTY0@0T92@2@38h=P80;Ng
]`P0[Jf]2@2`/;0809FEU@P0UYJF4@2EUID80:FUY@80b>3H203De=@80;jn_PT0YjNW202TY:@809jN
WPP0V9RH2@2KVi/809bLW0T0b>3H402`/;0A0:NWYa00UiNG4@2MWId20<SPf140a<C4402WYjLA09bL
W100WinO2@38h=PQ0:^[Zb40VIVI0P38h=PQ0;Jf]R40WinO2@38h=Q20:RXZ080b>3H@P2e]KDN0<SP
f0007@38h=P20;Jf]P80Z:RX0P34a<@20:b/[080XJ6Q0P2=SHd209RHV080ZJVY0P3=cLd20:VYZ@80
];Bd0P2CTi<208F5Q@80S8b<0P28R8P209NGU`<0Vi^K0P2FUYH209NGU`80QhN70P2EUID20:^[Z`80
S8b<0P28R8P209RHV080Shn?0P2JVYX209JFUP80SXj>0P2NWYh2096AT@80RXZ:0`38h=P20?_kn`80
bl_;0P2e]KD209bLW080n?Sh0P2JVYX20?ooo`80b/[:102ZZZX20:BTY080Z:RX0P2ZZZX20:f][@80
UYJF0P2ATI4308^;R`80YjNW0P2YZJT209NGU`80WIfM0P2@T90208Z:RP80UYJF0P2/[:`20;>c/`80
TY:B0P2:RXX20:b/[080Xj>S0P2ATI4208R8R0X0b>3H102/[:`40;Jf]P@0V9RH102OWil40:n_[`@0
/;2`1@2@T90408n?S`@0UiNG102BTY8409ZJVP@0TI6A302DU9@50:VYZ@80b>3H103:b/X40=;BdP@0
`l?3103GemL40:j^[PD0Zj^[102QXJ4409fMW@@0W9bL102WYjL409ZJVP@0UiNG102PX:0509NGU`@0
Y:BT102@T9090<SPf0P0]kNg202][Jd90;2`/0P0UIFE202FUYHA09FEU@P0YJFU0P38h=P80=CDe0P0
_[jn2@2WYjL80:BTY0P0WYjN202HV9P909^KV`P0W9bL2@38h=P@0;2`/140YjNW402GUiLA09fMW@80
b>3H4@34a<@@0:NWYa40W9bL402OWil90<SPf240Zj^[8@2IVIT20<SPf240][Jf8@2OWil90<SPf480
Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080W9bL0P3IfMT20;>c/`80Vi^K0P2_[jl208R8R080Vi^K
0P2DU9@20:VYZ@80Shn?0P2/[:`20:JVYP80Xj>S0P2IVIT208^;R`80SHf=0`2BTY82092@T080W9bL
0P2ATI4209fMW@80W9bL0P24Q8@209NGU`80QXJ60P2IVIT408f=S@80ZZZZ0P2@T90209FEU@80YZJV
0`38h=P20;Bd]080_Kfm0P2e]KD20:n_[`80o_kn0P2UYJD20:RXZ080]kNg0P2ZZZX209JFUP80YjNW
0P2h^;P20:ZZZP80WinO0P2<S8`208f=S@<0TI6A0P2JVYX20;6a/@80TY:B0P2XZ:P209BDU080TI6A
0P2>SXh209VIV@80]KFe0P26QXH209jNWP80X:2P0P2n_[h20:2PX080_[jn2P38h=P40;Zj^P@0Z:RX
102SXj<409jNWP@0]kNg102UYJD509ZJVP@0T92@102EUID409nOW`@0UYJF202@T9040:FUY@@0X:2P
1@2QXJ420<SPf0@0`l?3102ZZZX40=OGe`@0^;Rh102SXj<50;bl_0@0YJFU102LW9`409fMW@@0Y:BT
102PX:0409VIV@@0YZJV1@2OWil40:n_[`@0Zj^[2@38h=P80;Bd]0P0ZJVY2@2g]kL809BDU0P0VYZJ
202FUYH909VIV@P0WIfM0P38h=P80;fm_@P0_[jn2@2a/K4809nOW`P0X:2P202JVYX909nOW`P0YJFU
2@38h=P@0;2`/140YjNW402GUiLA09fMW@80b>3H4@34a<@@0:NWYa40W9bL402OWil90<SPf240Zj^[
8@2IVIT20<SPf240][Jf8@2OWil90<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080W9bL0P3I
fMT20;>c/`80Vi^K0P2_[jl208R8R080Vi^K0P2DU9@20:VYZ@80Shn?0P2/[:`20:JVYP80Xj>S0P2I
VIT208^;R`80SHf=0`2BTY82092@T080W9bL0P2ATI4209fMW@80W9bL0P24Q8@209NGU`80QXJ60P2I
VIT408f=S@80ZZZZ0P2@T90209FEU@80YZJV0`38h=P20;Bd]080_Kfm0P2e]KD20:n_[`80o_kn0P2U
YJD20:RXZ080]kNg0P2ZZZX209JFUP80YjNW0P2h^;P20:ZZZP80WinO0P2<S8`208f=S@<0TI6A0P2J
VYX20;6a/@80TY:B0P2XZ:P209BDU080TI6A0P2>SXh209VIV@80]KFe0P26QXH209jNWP80X:2P0P2n
_[h20:2PX080_[jn2P38h=P40;Zj^P@0Z:RX102SXj<409jNWP@0]kNg102UYJD509ZJVP@0T92@102E
UID409nOW`@0UYJF202@T9040:FUY@@0X:2P1@2QXJ420<SPf0@0`l?3102ZZZX40=OGe`@0^;Rh102S
Xj<50;bl_0@0YJFU102LW9`409fMW@@0Y:BT102PX:0409VIV@@0YZJV1@2OWil40:n_[`@0Zj^[2@38
h=P80;Bd]0P0ZJVY2@2g]kL809BDU0P0VYZJ202FUYH909VIV@P0WIfM0P38h=P80;fm_@P0_[jn2@2a
/K4809nOW`P0X:2P202JVYX909nOW`P0YJFU2@38h=P@0;2`/140YjNW402GUiLA09fMW@80b>3H4@34
a<@@0:NWYa40W9bL402OWil90<SPf240Zj^[8@2IVIT20<SPf240][Jf8@2OWil90<SPf480Z:RX0P38
h=Q20;Fe]Ah0b>3H000M0<SPf080^KVi0P2e]KD20;>c/`80T92@0P2^[Zh209NGU`80S8b<0P2][Jd2
0;6a/@80iNGU0P2VYZH209jNWP80Vi^K0P2CTi<208b<S080UYJF0`2GUiL209:BTP80[jn_0P2WYjL2
09JFUP80T92@0P2?Shl208N7Q`80SXj>0P2CTi<20:^[Z`80`/;20P2TY:@20:2PX080WinO0P2a/K43
0<SPf080X:2P0P3emOD20;6a/@80WIfM0P36a/H20?Ogm`80TI6A0P36a/H209JFUP80];Bd1037alL2
09JFUP80/K6a0P2[Zj/20:BTY0<0ZZZZ0P2OWil209fMW@80ZJVY0P2RXZ820:b/[080VYZJ0P2OWil2
09NGU`80/k>c0P2LW9`208j>SP80/;2`0P2h^;P40:j^[PX0b>3H102j^[X40:RXZ0@0Xj>S102NWYh4
0;Ng]`@0YJFU1@2JVYX4092@T0@0UIFE102OWil409JFUPP0T92@102UYJD40:2PX0D0XJ6Q0P38h=P4
0<?3``@0ZZZZ103GemL40;Rh^0@0Xj>S1@2l_;`40:FUY@@0W9bL102MWId40:BTY0@0X:2P102IVIT4
0:JVYPD0WinO102_[jl40:^[Z`T0b>3H202d];@80:VYZ@T0]kNg202DU9@809ZJVPP0UYJF2@2IVIT8
09fMW@80b>3H202m_Kd80;jn_PT0/K6a202OWil80:2PX0P0VYZJ2@2OWil80:FUY@T0b>3H402`/;0A
0:NWYa00UiNG4@2MWId20<SPf140a<C4402WYjLA09bLW100WinO2@38h=PQ0:^[Zb40VIVI0P38h=PQ
0;Jf]R40WinO2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20;Vi^@80]KFe0P2c/k<2092@
T080[Zj^0P2GUiL208b<S080[Jf]0P2a/K420>GUi@80YZJV0P2NWYh209^KV`80Ti>C0P2<S8`209JF
UP<0UiNG0P2BTY820:n_[`80YjNW0P2FUYH2092@T080Shn?0P27QhL208j>SP80Ti>C0P2[Zj/20<;2
`P80Y:BT0P2PX:0209nOW`80/K6a0`38h=P20:2PX080mOGe0P2a/K4209fMW@80a/K60P3gmoL2096A
T@80a/K60P2FUYH20;Bd]0@0alO70P2FUYH20;6a/@80Zj^[0P2TY:@30:ZZZP80WinO0P2MWId20:VY
Z@80XZ:R0P2/[:`209ZJVP80WinO0P2GUiL20;>c/`80W9bL0P2>SXh20;2`/080^;Rh102^[Zh:0<SP
f0@0^[Zj102XZ:P40:>SX`@0WYjN102g]kL40:FUY@D0VYZJ102@T90409FEU@@0WinO102FUYH8092@
T0@0YJFU102PX:050:6QX@80b>3H1033`l<40:ZZZP@0emOG102h^;P40:>SX`D0_;bl102UYJD409bL
W0@0WIfM102TY:@40:2PX0@0VIVI102VYZH509nOW`@0[jn_102[Zj/90<SPf0P0];Bd202YZJT90;Ng
]`P0U9BD202JVYX809JFUPT0VIVI202MWId20<SPf0P0_Kfm202n_[h90;6a/@P0WinO202PX:0809ZJ
VPT0WinO202UYJD90<SPf100/;2`4@2WYjL@09NGUa40WIfM0P38h=PA0<C4a100YjNW4@2LW9`@09nO
W`T0b>3H8@2[Zj/Q09VIV@80b>3H8@2f][HQ09nOW`T0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0
b>3H0P2m_Kd208B4Q080YJFU0P36a/H20:f][@80^[Zj0P2BTY820::RXP80g=cL102i^KT20:b/[080
TY:B0P2OWil209>CT`80TY:B0`2:RXX209:BTP80YZJV0P27QhL20:FUY@80UYJF0P2MWId209ZJVP80
SHf=0P2DU9@208V9R@80ZJVY0P2CTi<208j>SP80XZ:R0P2DU9@30<SPf080/k>c0P3lo?`20:n_[`80
Y:BT0P2b/[820>SXj080XZ:R0P2_[jl20:VYZ@80_;bl0P2d];@20:VYZ@80Vi^K0P2ZZZX209NGU`80
W9bL0`2CTi<209FEU@80ZJVY0P2HV9P208V9R@80YZJV0P2FUYH4092@T080RXZ:0P2<S8`208B4Q080
S8b<0P28R8P20;Jf]P80Vi^K2P38h=P40:n_[`@0_kno102h^;P409nOW`P0_;bl1@2EUID409>CT`@0
WYjN102DU9@409VIV@@0V9RH102BTY8409VIV@@0UYJF1@2NWYh20<SPf0@0f=SH102YZJT40;jn_P@0
YJFU102g]kL50:f][@@0XZ:R102IVIT40:6QX@@0W9bL102IVIT409>CT`@0VIVI1@2LW9`409BDU0@0
XJ6Q2@38h=P80;Bd]0P0ZJVY2@2g]kL809BDU0P0VYZJ202FUYH909VIV@P0WIfM0P38h=P80;fm_@P0
_[jn2@2a/K4809nOW`P0X:2P202JVYX909nOW`P0YJFU2@38h=P@0;2`/140YjNW402GUiLA09fMW@80
b>3H4@34a<@@0:NWYa40W9bL402OWil90<SPf240Zj^[8@2IVIT20<SPf240][Jf8@2OWil90<SPf480
Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080_Kfm0P24Q8@20:FUY@80a/K60P2][Jd20;Zj^P80TY:B
0P2RXZ820=cLg0@0^KVi0P2/[:`209:BTP80WinO0P2CTi<209:BTP<0RXZ:0P2BTY820:JVYP80QhN7
0P2UYJD209JFUP80WIfM0P2JVYX208f=S@80U9BD0P29RHT20:VYZ@80Ti>C0P2>SXh20::RXP80U9BD
0`38h=P20;>c/`80o?cl0P2_[jl20:BTY080/[:b0P3Xj>P20::RXP80[jn_0P2YZJT20;bl_080];Bd
0P2YZJT209^KV`80ZZZZ0P2GUiL209bLW0<0Ti>C0P2EUID20:VYZ@80V9RH0P29RHT20:JVYP80UYJF
102@T90208Z:RP80S8b<0P24Q8@208b<S080R8R80P2f][H209^KV`X0b>3H102_[jl40;no_`@0^;Rh
102OWil80;bl_0D0UIFE102CTi<409jNWP@0U9BD102IVIT409RHV0@0TY:B102IVIT409JFUPD0WYjN
0P38h=P40=SHf0@0ZJVY102n_[h40:FUY@@0]kNg1@2][Jd40::RXP@0VIVI102QXJ4409bLW0@0VIVI
102CTi<409VIV@D0W9bL102DU9@40:6QX@T0b>3H202d];@80:VYZ@T0]kNg202DU9@809ZJVPP0UYJF
2@2IVIT809fMW@80b>3H202m_Kd80;jn_PT0/K6a202OWil80:2PX0P0VYZJ2@2OWil80:FUY@T0b>3H
402`/;0A0:NWYa00UiNG4@2MWId20<SPf140a<C4402WYjLA09bLW100WinO2@38h=PQ0:^[Zb40VIVI
0P38h=PQ0;Jf]R40WinO2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20;Vi^@80[jn_0P38
b<P20=;BdP80]kNg0P3AdM420:ZZZP80WIfM0P2HV9P20;jn_P80k>c/0P2JVYX209RHV080TI6A0P2;
Rh/209FEU@<0];Bd0P2OWil208Z:RP80QHF50P2CTi<209RHV080RHV90P2PX:0208b<S080Shn?102F
UYH208j>SP80YjNW0P2HV9P20:b/[0<0b>3H0P35aLD20?ooo`80^;Rh0P2IVIT209:BTP80[:b/0P2X
Z:P20:^[Z`80`L710P2j^[X20;Ng]`80V9RH0P2EUID209:BTP80V9RH0P2IVIT3092@T080ZJVY0P2I
VIT209bLW080X:2P0P2HV9P2092@T080UIFE0P2SXj<209fMW@80];Bd0P2;Rh/208f=S@80YJFU102E
UID:0<SPf0@0[jn_102o_kl40;Rh^0@0WinO202l_;`509FEU@@0Ti>C102NWYh409BDU0@0VIVI102H
V9P409:BTP@0VIVI102FUYH509jNWP80b>3H103Hf=P40:VYZ@@0_[jn102UYJD40;Ng]`D0[Jf]102R
XZ8409VIV@@0XJ6Q102LW9`409VIV@@0Ti>C102IVIT509bLW0@0U9BD102QXJ490<SPf0P0];Bd202Y
ZJT90;Ng]`P0U9BD202JVYX809JFUPT0VIVI202MWId20<SPf0P0_Kfm202n_[h90;6a/@P0WinO202P
X:0809ZJVPT0WinO202UYJD90<SPf100/;2`4@2WYjL@09NGUa40WIfM0P38h=PA0<C4a100YjNW4@2L
W9`@09nOW`T0b>3H8@2[Zj/Q09VIV@80b>3H8@2f][HQ09nOW`T0b>3H@P2XZ:P20<SPf480]KFe7P38
h=P001d0b>3H0P2i^KT20:n_[`80b<S80P3Bd]820;Ng]`80dM7A0P2ZZZX209fMW@80V9RH0P2n_[h2
0>c/k080VYZJ0P2HV9P2096AT@80Rh^;0P2EUID30;Bd]080WinO0P2:RXX208F5Q@80Ti>C0P2HV9P2
08V9R@80X:2P0P2<S8`208n?S`@0UYJF0P2>SXh20:NWY`80V9RH0P2/[:`30<SPf080aLG50P3oool2
0;Rh^080VIVI0P2BTY820:b/[080Z:RX0P2[Zj/20<71`@80^[Zj0P2g]kL209RHV080UIFE0P2BTY82
09RHV080VIVI0`2@T9020:VYZ@80VIVI0P2LW9`20:2PX080V9RH0P2@T90209FEU@80Xj>S0P2MWId2
0;Bd]080Rh^;0P2=SHd20:FUY@@0UIFE2P38h=P40:n_[`@0_kno102h^;P409nOW`P0_;bl1@2EUID4
09>CT`@0WYjN102DU9@409VIV@@0V9RH102BTY8409VIV@@0UYJF1@2NWYh20<SPf0@0f=SH102YZJT4
0;jn_P@0YJFU102g]kL50:f][@@0XZ:R102IVIT40:6QX@@0W9bL102IVIT409>CT`@0VIVI1@2LW9`4
09BDU0@0XJ6Q2@38h=P80;Bd]0P0ZJVY2@2g]kL809BDU0P0VYZJ202FUYH909VIV@P0WIfM0P38h=P8
0;fm_@P0_[jn2@2a/K4809nOW`P0X:2P202JVYX909nOW`P0YJFU2@38h=P@0;2`/140YjNW402GUiLA
09fMW@80b>3H4@34a<@@0:NWYa40W9bL402OWil90<SPf240Zj^[8@2IVIT20<SPf240][Jf8@2OWil9
0<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080Xj>S0P2IVIT20<g=c@80g]kN0P3:b/X20::R
XP80dm?C0P2VYZH208n?S`80[Jf]0P38b<P20;2`/080RXZ:0P2SXj<209^KV`80QhN70`2FUYH20:RX
Z080UiNG0P2MWId408n?S`80W9bL0P2<S8`409^KV`80SXj>0P2:RXX2092@T080UiNG0P24Q8@2092@
T0<0b>3H0P2XZ:P209JFUP80W9bL0P2YZJT20:RXZ080bl_;0P2c/k<20<_;b`80_;bl0P31`L420:>S
X`80YZJV0P2TY:@208b<S080Rh^;0P2ZZZX30:VYZ@80T92@0P2a/K420:6QX@80][Jf0P2;Rh/209fM
W@80SHf=0P2OWil209>CT`80][Jf0P29RHT209>CT`80W9bL0P28R8P20::RXPX0b>3H102[Zj/40;Vi
^@@0][Jf102i^KT80:n_[`D0W9bL102EUID409RHV0@0VIVI102DU9@409:BTP@0V9RH102<S8`409FE
U@D0TI6A0P38h=P40:^[Z`@0/;2`102j^[X40=3@d0@0]KFe1@2MWId40:2PX0@0WYjN102RXZ880:BT
Y0@0V9RH102IVIT90:2PX0@0WIfM2@38h=P80:b/[0P0^KVi2@2/[:`809NGU`P0UYJF202EUID909BD
U0P0UIFE0P38h=P80:b/[0P0_Kfm2@2i^KT809bLW0P0X:2P202OWil909jNWPP0Xj>S2@38h=P@0:j^
[Q40YJFU402GUiLA09ZJVP80b>3H4@2f][H@0;Bd]240X:2P2@38h=PQ0:^[Zb40VIVI0P38h=PQ0;Jf
]R40WinO2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20:>SX`80VIVI0P3=cLd20=kNgP80
b/[:0P2RXZ820=?Cd`80YZJV0P2?Shl20:f][@80b<S80P2`/;0208Z:RP80Xj>S0P2KVi/208N7Q`<0
UYJF0P2XZ:P209NGU`80WIfM102?Shl209bLW080S8b<102KVi/208j>SP80RXZ:0P2@T90209NGU`80
Q8B40P2@T9030<SPf080Z:RX0P2FUYH209bLW080ZJVY0P2XZ:P20<_;b`80/k>c0P3;bl/20;bl_080
`L710P2SXj<20:JVYP80Y:BT0P2<S8`208^;R`80ZZZZ0`2YZJT2092@T080/K6a0P2QXJ420;Jf]P80
Rh^;0P2MWId208f=S@80WinO0P2CTi<20;Jf]P80RHV90P2CTi<209bLW080R8R80P2RXZ8:0<SPf0@0
Zj^[102i^KT40;Jf]P@0^KVi202_[jl509bLW0@0UIFE102HV9P409VIV@@0U9BD102BTY8409RHV0@0
S8b<102EUID5096AT@80b>3H102[Zj/40;2`/0@0^[Zj103@d=040;Fe]@D0WIfM102PX:0409jNWP@0
XZ:R202TY:@409RHV0@0VIVI2@2PX:0409fMW@T0b>3H202/[:`80;Vi^@T0[:b/202GUiL809JFUPP0
UIFE2@2DU9@809FEU@80b>3H202/[:`80;fm_@T0^KVi202LW9`80:2PX0P0WinO2@2NWYh80:>SX`T0
b>3H402^[ZhA0:FUYA00UiNG4@2JVYX20<SPf140][Jf402d];@Q0:2PX0T0b>3H8@2[Zj/Q09VIV@80
b>3H8@2f][HQ09nOW`T0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2f][H20;Fe]@80W9bL
0P23Ph<20:b/[080_[jn0P2`/;020;>c/`80YZJV0P3>c/h209RHV080VYZJ0P2KVi/209>CT`80UYJF
0P27QhL3096AT@80R8R80P2ATI420:6QX@80WYjN0P2FUYH209NGU`80RHV90P2JVYX209>CT`80QhN7
0P2ATI4208f=S@80WinO0P2ATI4209ZJVP<0b>3H0P2_[jl20;no_`80];Bd0P2MWId20=SHf080YZJV
0P2QXJ420?ooo`80YjNW0P2VYZH208J6QP80S8b<0P2LW9`209nOW`80Zj^[0P2CTi<30:j^[P80W9bL
0P2:RXX20:ZZZP80[Jf]0P2=SHd209BDU080Xj>S0P2OWil2096AT@80VIVI0P28R8P20:>SX`80/K6a
0P2LW9`209JFUPX0b>3H102[Zj/40;Vi^@@0][Jf102i^KT80:n_[`D0W9bL102EUID409RHV0@0VIVI
102DU9@409:BTP@0V9RH102<S8`409FEU@D0TI6A0P38h=P40:^[Z`@0/;2`102j^[X40=3@d0@0]KFe
1@2MWId40:2PX0@0WYjN102RXZ880:BTY0@0V9RH102IVIT90:2PX0@0WIfM2@38h=P80:b/[0P0^KVi
2@2/[:`809NGU`P0UYJF202EUID909BDU0P0UIFE0P38h=P80:b/[0P0_Kfm2@2i^KT809bLW0P0X:2P
202OWil909jNWPP0Xj>S2@38h=P@0:j^[Q40YJFU402GUiLA09ZJVP80b>3H4@2f][H@0;Bd]240X:2P
2@38h=PQ0:^[Zb40VIVI0P38h=PQ0;Jf]R40WinO2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38
h=P20;Jf]P80]KFe0P2LW9`208>3P`80[:b/0P2n_[h20;2`/080/k>c0P2VYZH20<k>cP80V9RH0P2J
VYX209^KV`80Ti>C0P2FUYH208N7Q`<0TI6A0P28R8P2096AT@80XJ6Q0P2NWYh209JFUP80UiNG0P29
RHT209ZJVP80Ti>C0P27QhL2096AT@80SHf=0P2OWil2096AT@80VYZJ0`38h=P20:n_[`80_kno0P2d
];@209fMW@80f=SH0P2VYZH20:6QX@80oooo0P2WYjL20:JVYP80QXJ60P2<S8`209bLW080WinO0P2[
Zj/209>CT`<0[Zj^0P2LW9`208Z:RP80ZZZZ0P2][Jd208f=S@80U9BD0P2SXj<209nOW`80TI6A0P2I
VIT208R8R080Xj>S0P2a/K4209bLW080UYJF2P38h=P40:^[Z`@0^KVi102f][H40;Vi^@P0[jn_1@2L
W9`409FEU@@0V9RH102IVIT409BDU0@0TY:B102HV9P408b<S0@0UIFE1@2ATI420<SPf0@0Zj^[102`
/;040;Zj^P@0d=3@102e]KD509fMW@@0X:2P102NWYh40::RXPP0Y:BT102HV9P409VIV@T0X:2P102M
WId90<SPf0P0[:b/202i^KT90:b/[0P0UiNG202FUYH809FEU@T0U9BD202EUID20<SPf0P0[:b/202m
_Kd90;Vi^@P0W9bL202PX:0809nOW`T0WYjN202SXj<90<SPf100[Zj^4@2UYJD@09NGUa40VYZJ0P38
h=PA0;Jf]Q00];Bd8@2PX:090<SPf240Zj^[8@2IVIT20<SPf240][Jf8@2OWil90<SPf480Z:RX0P38
h=Q20;Fe]Ah0b>3H000M0<SPf080W9bL0P2:RXX209:BTP80Zj^[0P2l_;`20:NWY`80ZZZZ0P3=cLd2
0:FUY@80cLg=0P2SXj<209VIV@80RHV90P2<S8`208V9R@80SXj>0`2GUiL2092@T080XJ6Q0P2=SHd2
09JFUP80V9RH0P2=SHd209JFUP80Rh^;0P26QXH208n?S`80SHf=0P2JVYX208f=S@80WYjN0P2MWId3
0<SPf080YjNW0P2DU9@20:j^[P80VYZJ0P3>c/h20<;2`P80^[Zj0P2RXZ820=oOg`80][Jf0P2JVYX2
0:NWY`80SXj>0P2IVIT20:VYZ@80Rh^;0`2VYZH209:BTP80ZZZZ0P2YZJT20:JVYP80X:2P0P2NWYh2
09RHV080U9BD0P2HV9P20:ZZZP80SHf=0P2LW9`20:2PX080b<S80P2][Jd:0<SPf0@0YZJV102TY:@4
0<30`0@0/;2`102c/k<409jNWPD0Ti>C102FUYH8096AT@@0U9BD102FUYH409>CT`@0UIFE102FUYH5
09NGU`80b>3H102RXZ840:ZZZP@0^KVi102XZ:P40=SHf0D0ZJVY102IVIT409NGU`@0V9RH102RXZ84
0:BTY0@0Vi^K2@2PX:0409nOW`@0[jn_2@38h=P80:b/[0P0^KVi2@2/[:`809NGU`P0UYJF202EUID9
09BDU0P0UIFE0P38h=P80:b/[0P0_Kfm2@2i^KT809bLW0P0X:2P202OWil909jNWPP0Xj>S2@38h=P@
0:j^[Q40YJFU402GUiLA09ZJVP80b>3H4@2f][H@0;Bd]240X:2P2@38h=PQ0:^[Zb40VIVI0P38h=PQ
0;Jf]R40WinO2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P209bLW080RXZ:0P2BTY820:^[
Z`80_;bl0P2WYjL20:ZZZP80cLg=0P2UYJD20<g=c@80Xj>S0P2IVIT208V9R@80S8b<0P29RHT208j>
SP<0UiNG0P2@T9020:6QX@80SHf=0P2FUYH209RHV080SHf=0P2FUYH208^;R`80QXJ60P2?Shl208f=
S@80VYZJ0P2=SHd209jNWP80WIfM0`38h=P20:NWY`80U9BD0P2^[Zh209ZJVP80c/k>0P32`/820;Zj
^P80XZ:R0P3Ogml20;Jf]P80VYZJ0P2WYjL208j>SP80VIVI0P2YZJT208^;R`<0YZJV0P2BTY820:ZZ
ZP80ZJVY0P2VYZH20:2PX080WYjN0P2HV9P209BDU080V9RH0P2ZZZX208f=S@80W9bL0P2PX:020<S8
b080[Jf]2P38h=P40:JVYP@0Y:BT1030`<040;2`/0@0/k>c102NWYh509>CT`@0UYJF202ATI4409BD
U0@0UYJF102CTi<409FEU@@0UYJF1@2GUiL20<SPf0@0XZ:R102ZZZX40;Vi^@@0Z:RX103Hf=P50:VY
Z@@0VIVI102GUiL409RHV0@0XZ:R102TY:@409^KV`T0X:2P102OWil40:n_[`T0b>3H202/[:`80;Vi
^@T0[:b/202GUiL809JFUPP0UIFE2@2DU9@809FEU@80b>3H202/[:`80;fm_@T0^KVi202LW9`80:2P
X0P0WinO2@2NWYh80:>SX`T0b>3H402^[ZhA0:FUYA00UiNG4@2JVYX20<SPf140][Jf402d];@Q0:2P
X0T0b>3H8@2[Zj/Q09VIV@80b>3H8@2f][HQ09nOW`T0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0
b>3H0P36a/H209JFUP80_;bl0P2FUYH20>KViP80`L710P2OWil20;2`/080^;Rh0P2WYjL20:JVYP80
V9RH0P2EUID208n?S`80UIFE0P2<S8`309BDU080RHV90P2=SHd20861P@80QhN70P2BTY8209NGU`80
W9bL0P2@T90209FEU@80RXZ:0P2QXJ4209jNWP80TY:B0P2?Shl209BDU0<0b>3H0P2UYJD20:ZZZP80
XJ6Q0P2l_;`209ZJVP80`/;20P2ZZZX209fMW@80oooo0P3Fe]H20<71`@80S8b<0P2YZJT209>CT`80
U9BD0P2GUiL308j>SP80TI6A0P2IVIT209>CT`80Shn?0P2b/[8209NGU`80XJ6Q0P2DU9@20;:b/P80
W9bL0P2QXJ4209bLW080S8b<0P2`/;0209BDU0X0b>3H102VYZH40:BTY0@0`<30102`/;040;>c/`@0
WYjN1@2CTi<409JFUPP0TI6A102DU9@409JFUP@0Ti>C102EUID409JFUPD0UiNG0P38h=P40::RXP@0
ZZZZ102i^KT40:RXZ0@0f=SH1@2YZJT409VIV@@0UiNG102HV9P40::RXP@0Y:BT102KVi/90:2PX0@0
WinO102_[jl90<SPf0P0[:b/202i^KT90:b/[0P0UiNG202FUYH809FEU@T0U9BD202EUID20<SPf0P0
[:b/202m_Kd90;Vi^@P0W9bL202PX:0809nOW`T0WYjN202SXj<90<SPf100[Zj^4@2UYJD@09NGUa40
VYZJ0P38h=PA0;Jf]Q00];Bd8@2PX:090<SPf240Zj^[8@2IVIT20<SPf240][Jf8@2OWil90<SPf480
Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080a/K60P2FUYH20;bl_080UYJF0P3Vi^H20<71`@80WinO
0P2`/;020;Rh^080YjNW0P2VYZH209RHV080UIFE0P2?Shl209FEU@80S8b<0`2DU9@208V9R@80SHf=
0P21PH4208N7Q`80TY:B0P2GUiL209bLW080T92@0P2EUID208Z:RP80XJ6Q0P2NWYh209:BTP80Shn?
0P2DU9@30<SPf080YJFU0P2ZZZX20:6QX@80_;bl0P2JVYX20<;2`P80ZZZZ0P2MWId20?ooo`80e]KF
0P31`L4208b<S080ZJVY0P2CTi<209BDU080UiNG0`2>SXh2096AT@80VIVI0P2CTi<208n?S`80/[:b
0P2GUiL20:6QX@80U9BD0P2b/[8209bLW080XJ6Q0P2LW9`208b<S080/;2`0P2DU9@:0<SPf0@0YZJV
102TY:@40<30`0@0/;2`102c/k<409jNWPD0Ti>C102FUYH8096AT@@0U9BD102FUYH409>CT`@0UIFE
102FUYH509NGU`80b>3H102RXZ840:ZZZP@0^KVi102XZ:P40=SHf0D0ZJVY102IVIT409NGU`@0V9RH
102RXZ840:BTY0@0Vi^K2@2PX:0409nOW`@0[jn_2@38h=P80:b/[0P0^KVi2@2/[:`809NGU`P0UYJF
202EUID909BDU0P0UIFE0P38h=P80:b/[0P0_Kfm2@2i^KT809bLW0P0X:2P202OWil909jNWPP0Xj>S
2@38h=P@0:j^[Q40YJFU402GUiLA09ZJVP80b>3H4@2f][H@0;Bd]240X:2P2@38h=PQ0:^[Zb40VIVI
0P38h=PQ0;Jf]R40WinO2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20<?3``80Vi^K0P2=
SHd209^KV`80`l?30P2EUID20<;2`P@0UiNG0P2MWId20<O7a`80UIFE0P2HV9P208j>SP@0W9bL0`2=
SHd209VIV@80SXj>0P2DU9@209>CT`80UIFE0P2GUiL208J6QP80QHF50P2=SHd208F5Q@80VIVI0P2M
WId20:VYZ@80XZ:R0P2:RXX30<SPf080WYjN0P33`l<208f=S@80UiNG0P2XZ:P20=;BdP80Zj^[0P2g
]kL209BDU080fMWI0P2PX:020:^[Z`80X:2P0P2<S8`20;fm_@80TI6A0`2LW9`209^KV`80XJ6Q0P2Z
ZZX209>CT`80T92@0P2?Shl209^KV`80RXZ:0P28R8P209FEU@80Y:BT0P2>SXh209JFUP80XJ6Q0P2I
VIT:0<SPf0@0[Zj^102JVYX40:^[Z`@0^KVi102OWil40:b/[0D0UiNG102LW9`409FEU@P0UiNG102C
Ti<408j>SP@0U9BD102MWId50:VYZ@80b>3H102ZZZX409NGU`@0^KVi103<c<`40;:b/PD0b/[:102K
Vi/40:JVYPP0X:2P102KVi/409ZJVP@0Vi^K1@2JVYX40:6QX@@0YjNW2@38h=P80:BTY140[Zj^202O
Wil@09NGU`T0Vi^K202RXZ820<SPf0P0[:b/2030`<090<G5a@P0[:b/202RXZ8809nOW`T0WYjN202P
X:090<SPf100[Zj^4@2UYJD@09NGUa40VYZJ0P38h=PA0;Jf]Q00];Bd8@2PX:090<SPf240Zj^[8@2I
VIT20<SPf240][Jf8@2OWil90<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080`l?30P2KVi/2
08f=S@80Vi^K0P33`l<209FEU@80`/;2102GUiL209fMW@80alO70P2EUID209RHV080SXj>102LW9`3
08f=S@80VIVI0P2>SXh209BDU080Ti>C0P2EUID209NGU`80QXJ60P25QHD208f=S@80QHF50P2IVIT2
09fMW@80ZJVY0P2RXZ8208Z:RP<0b>3H0P2NWYh20<?3``80SHf=0P2GUiL20:RXZ080d];B0P2[Zj/2
0;Ng]`80U9BD0P3IfMT20:2PX080Zj^[0P2PX:0208b<S080_Kfm0P2ATI4309bLW080Vi^K0P2QXJ42
0:ZZZP80Ti>C0P2@T90208n?S`80Vi^K0P2:RXX208R8R080UIFE0P2TY:@208j>SP80UYJF0P2QXJ42
09VIV@X0b>3H102^[Zh409ZJVP@0Zj^[102i^KT409nOW`@0[:b/1@2GUiL409bLW0@0UIFE202GUiL4
09>CT`@0SXj>102DU9@409fMW@D0ZJVY0P38h=P40:ZZZP@0UiNG102i^KT40<c<c0@0/[:b1@3:b/X4
09^KV`@0YZJV202PX:0409^KV`@0VYZJ102KVi/509ZJVP@0XJ6Q102WYjL90<SPf0P0Y:BT4@2^[Zh8
09nOWa00UiNG2@2KVi/80::RXP80b>3H202/[:`80<30`0T0aLG5202/[:`80::RXPP0WinO2@2NWYh8
0:2PX0T0b>3H402^[ZhA0:FUYA00UiNG4@2JVYX20<SPf140][Jf402d];@Q0:2PX0T0b>3H8@2[Zj/Q
09VIV@80b>3H8@2f][HQ09nOW`T0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2c/k<209bL
W080UYJF0P2PX:020:j^[P80VIVI0P2i^KT20<g=c@80WinO0P2JVYX208b<S080^[Zj0P2CTi<20:FU
Y@80Xj>S0P2DU9@309^KV`80SHf=0P2JVYX20:6QX@80W9bL0P2EUID2096AT@80X:2P0P2ATI4209:B
TP80SHf=0P2IVIT208R8R080UIFE0P2YZJT20;fm_@<0b>3H0P2FUYH20:2PX080U9BD0P2SXj<20:b/
[080_Kfm0P3/k>`20>GUi@80/k>c0P2BTY820=_Kf`80m_Kf0P2UYJD209JFUP80/;2`0P2<S8`308B4
Q080^[Zj0P2IVIT20::RXP80Ti>C0P2a/K4209RHV080VIVI0P2CTi<20:n_[`80UYJF0P2CTi<20:VY
Z@80VYZJ0P2XZ:P20;Bd]0X0b>3H102^[Zh409ZJVP@0Zj^[102i^KT409nOW`@0[:b/1@2GUiL409bL
W0@0UIFE202GUiL409>CT`@0SXj>102DU9@409fMW@D0ZJVY0P38h=P40:ZZZP@0UiNG102i^KT40<c<
c0@0/[:b1@3:b/X409^KV`@0YZJV202PX:0409^KV`@0VYZJ102KVi/509ZJVP@0XJ6Q102WYjL90<SP
f0P0Y:BT4@2^[Zh809nOWa00UiNG2@2KVi/80::RXP80b>3H202/[:`80<30`0T0aLG5202/[:`80::R
XPP0WinO2@2NWYh80:2PX0T0b>3H402^[ZhA0:FUYA00UiNG4@2JVYX20<SPf140][Jf402d];@Q0:2P
X0T0b>3H8@2[Zj/Q09VIV@80b>3H8@2f][HQ09nOW`T0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0
b>3H0P2c/k<209bLW080UYJF0P2PX:020:j^[P80VIVI0P2i^KT20<g=c@80WinO0P2JVYX208b<S080
^[Zj0P2CTi<20:FUY@80Xj>S0P2DU9@309^KV`80SHf=0P2JVYX20:6QX@80W9bL0P2EUID2096AT@80
X:2P0P2ATI4209:BTP80SHf=0P2IVIT208R8R080UIFE0P2YZJT20;fm_@<0b>3H0P2FUYH20:2PX080
U9BD0P2SXj<20:b/[080_Kfm0P3/k>`20>GUi@80/k>c0P2BTY820=_Kf`80m_Kf0P2UYJD209JFUP80
/;2`0P2<S8`308B4Q080^[Zj0P2IVIT20::RXP80Ti>C0P2a/K4209RHV080VIVI0P2CTi<20:n_[`80
UYJF0P2CTi<20:VYZ@80VYZJ0P2XZ:P20;Bd]0X0b>3H102^[Zh409ZJVP@0Zj^[102i^KT409nOW`@0
[:b/1@2GUiL409bLW0@0UIFE202GUiL409>CT`@0SXj>102DU9@409fMW@D0ZJVY0P38h=P40:ZZZP@0
UiNG102i^KT40<c<c0@0/[:b1@3:b/X409^KV`@0YZJV202PX:0409^KV`@0VYZJ102KVi/509ZJVP@0
XJ6Q102WYjL90<SPf0P0Y:BT4@2^[Zh809nOWa00UiNG2@2KVi/80::RXP80b>3H202/[:`80<30`0T0
aLG5202/[:`80::RXPP0WinO2@2NWYh80:2PX0T0b>3H402^[ZhA0:FUYA00UiNG4@2JVYX20<SPf140
][Jf402d];@Q0:2PX0T0b>3H8@2[Zj/Q09VIV@80b>3H8@2f][HQ09nOW`T0b>3H@P2XZ:P20<SPf480
]KFe7P38h=P001d0b>3H0P2LW9`20:2PX080V9RH0P2g]kL208b<S080WYjN0P29RHT20>3Ph080_[jn
0P2?Shl20:^[Z`80YjNW0P2TY:@209:BTP@0Rh^;0`27QhL209bLW080Rh^;0P2FUYH208f=S@80TY:B
0P2GUiL209fMW@80Ti>C0P2UYJD209:BTP80SXj>0P25QHD2096AT@80Ph>30P2e]KD30<SPf080TY:B
0P2WYjL209^KV`80SXj>0P2UYJD209FEU@80`/;20P3<c<`20=kNgP80UiNG0P3Kfm/20?ooo`80cLg=
0P2QXJ4209bLW080YZJV0`2CTi<20;^k^`80XJ6Q0P2LW9`209>CT`@0TY:B0P2[Zj/208^;R`80Z:RX
0P2<S8`208f=S@80TI6A0P2DU9@20:^[Z`80V9RH2P38h=P40:6QX@@0Xj>S102GUiL40;Vi^@@0^[Zj
102a/K450:j^[P@0Ti>C102IVIT409JFUP@0VIVI102HV9P40:>SX`@0X:2P102EUID50:FUY@80b>3H
1030`<040:2PX0@0[jn_103;bl/40;Jf]PD0h>3P102m_Kd40:2PX0@0ZZZZ102PX:0409jNWP@0Z:RX
102RXZ8909NGU`@0WYjN2@38h=P80:BTY140[Zj^202OWil@09NGU`T0Vi^K202RXZ820<SPf0P0[:b/
2030`<090<G5a@P0[:b/202RXZ8809nOW`T0WYjN202PX:090<SPf100[Zj^4@2UYJD@09NGUa40VYZJ
0P38h=PA0;Jf]Q00];Bd8@2PX:090<SPf240Zj^[8@2IVIT20<SPf240][Jf8@2OWil90<SPf480Z:RX
0P38h=Q20;Fe]Ah0b>3H000M0<SPf080W9bL0P2PX:0209RHV080]kNg0P2<S8`209jNWP80RHV90P3P
h>020;jn_P80Shn?0P2[Zj/20:NWY`80Y:BT0P2BTY8408^;R`<0QhN70P2LW9`208^;R`80UYJF0P2=
SHd209:BTP80UiNG0P2MWId209>CT`80YJFU0P2BTY8208j>SP80QHF50P2ATI4208>3P`80]KFe0`38
h=P209:BTP80YjNW0P2KVi/208j>SP80YJFU0P2EUID20<;2`P80c<c<0P3Ng]h209NGU`80fm_K0P3o
ool20<g=c@80XJ6Q0P2LW9`20:JVYP<0Ti>C0P2k^k/20:6QX@80W9bL0P2CTi<409:BTP80Zj^[0P2;
Rh/20:RXZ080S8b<0P2=SHd2096AT@80U9BD0P2[Zj/209RHV0X0b>3H102QXJ440:>SX`@0UiNG102i
^KT40;Zj^P@0/K6a1@2^[Zh409>CT`@0VIVI102FUYH409VIV@@0V9RH102SXj<40:2PX0@0UIFE1@2U
YJD20<SPf0@0`<30102PX:040:n_[`@0bl_;102f][H50>3Ph0@0_Kfm102PX:040:ZZZP@0X:2P102N
WYh40:RXZ0@0XZ:R2@2GUiL409jNWPT0b>3H202TY:@A0:j^[PP0WinO402GUiL909^KV`P0XZ:R0P38
h=P80:b/[0P0`<302@35aLD80:b/[0P0XZ:R202OWil909jNWPP0X:2P2@38h=P@0:j^[Q40YJFU402G
UiLA09ZJVP80b>3H4@2f][H@0;Bd]240X:2P2@38h=PQ0:^[Zb40VIVI0P38h=PQ0;Jf]R40WinO2@38
h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20;Ng]`80UYJF0P2QXJ4409BDU080VIVI0P2QXJ42
0:n_[`80h^;R0P2^[Zh20:6QX@80cLg=0P3Fe]H209nOW`80UIFE0P29RHT309jNWP80SHf=0P2MWId2
09:BTP80Zj^[0P2@T90209VIV@80TY:B0P2g]kL20:>SX`80Rh^;0P2EUID208j>SP80WYjN0P2IVIT2
0:JVYP<0b>3H0P3hn?P20:j^[P80XJ6Q0P2c/k<40;jn_P80g]kN0P3Ph>020;^k^`80YjNW0P2;Rh/2
0:NWY`80_;bl0P3Fe]H20:b/[080Vi^K0`2d];@2092@T080/K6a0P2ATI420:n_[`80UiNG0P2OWil2
0;:b/P80YjNW0P2YZJT209jNWP80TI6A0P2IVIT209nOW`80Y:BT0P2=SHd:0<SPf0@0XJ6Q102SXj<4
09NGU`@0^KVi102j^[X40;6a/@D0[Zj^102CTi<409VIV@@0UYJF102IVIT409RHV0@0Xj>S102PX:04
09FEU@D0YJFU0P38h=P40<30`0@0X:2P102_[jl40<_;b`@0][Jf1@3Ph>040;fm_@@0X:2P102ZZZX4
0:2PX0@0WYjN102XZ:P40::RXPT0UiNG102NWYh90<SPf0P0Y:BT4@2^[Zh809nOWa00UiNG2@2KVi/8
0::RXP80b>3H202/[:`80<30`0T0aLG5202/[:`80::RXPP0WinO2@2NWYh80:2PX0T0b>3H402^[ZhA
0:FUYA00UiNG4@2JVYX20<SPf140][Jf402d];@Q0:2PX0T0b>3H8@2[Zj/Q09VIV@80b>3H8@2f][HQ
09nOW`T0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2g]kL209JFUP80XJ6Q102DU9@209VI
V@80XJ6Q0P2_[jl20>;RhP80[Zj^0P2QXJ420<g=c@80e]KF0P2OWil209FEU@80RHV90`2NWYh208f=
S@80WIfM0P2BTY820:^[Z`80T92@0P2IVIT209:BTP80]kNg0P2SXj<208^;R`80UIFE0P2>SXh209jN
WP80VIVI0P2VYZH30<SPf080n?Sh0P2^[Zh20:6QX@80/k>c102n_[h20=kNgP80h>3P0P2k^k/20:NW
Y`80Rh^;0P2WYjL20;bl_080e]KF0P2/[:`209^KV`<0];Bd0P2@T9020;6a/@80TI6A0P2_[jl209NG
U`80WinO0P2b/[820:NWY`80ZJVY0P2NWYh2096AT@80VIVI0P2OWil20:BTY080SHf=2P38h=P40:6Q
X@@0Xj>S102GUiL40;Vi^@@0^[Zj102a/K450:j^[P@0Ti>C102IVIT409JFUP@0VIVI102HV9P40:>S
X`@0X:2P102EUID50:FUY@80b>3H1030`<040:2PX0@0[jn_103;bl/40;Jf]PD0h>3P102m_Kd40:2P
X0@0ZZZZ102PX:0409jNWP@0Z:RX102RXZ8909NGU`@0WYjN2@38h=P80:BTY140[Zj^202OWil@09NG
U`T0Vi^K202RXZ820<SPf0P0[:b/2030`<090<G5a@P0[:b/202RXZ8809nOW`T0WYjN202PX:090<SP
f100[Zj^4@2UYJD@09NGUa40VYZJ0P38h=PA0;Jf]Q00];Bd8@2PX:090<SPf240Zj^[8@2IVIT20<SP
f240][Jf8@2OWil90<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080]kNg0P2FUYH20:6QX@@0
U9BD0P2IVIT20:6QX@80[jn_0P3Rh^820:j^[P80XJ6Q0P3=cLd20=KFeP80WinO0P2EUID208V9R@<0
WYjN0P2=SHd209fMW@80TY:B0P2[Zj/2092@T080VIVI0P2BTY820;Ng]`80Xj>S0P2;Rh/209FEU@80
SXj>0P2NWYh209VIV@80YZJV0`38h=P20?Shn080[Zj^0P2QXJ420;>c/`@0_[jn0P3Ng]h20>3Ph080
^k^k0P2WYjL208^;R`80YjNW0P2l_;`20=KFeP80[:b/0P2KVi/30;Bd]080T92@0P2a/K42096AT@80
[jn_0P2GUiL209nOW`80/[:b0P2WYjL20:VYZ@80WYjN0P2ATI4209VIV@80WinO0P2TY:@208f=S@X0
b>3H102NWYh40:FUY@@0/;2`102][Jd40<K6aP@0ZJVY1@2KVi/40:RXZ0@0Y:BT102ZZZX40:^[Z`@0
/K6a102/[:`409jNWP@0Vi^K1@2GUiL20<SPf0@0[jn_102VYZH40<O7a`@0`<301032`/8509nOW`@0
n?Sh103Ph>04092@T0@0Xj>S1030`<040:VYZ@@0YZJV1@2KVi/40:NWY`@0Xj>S2@38h=P80:>SX`P0
[:b/2@2k^k/80:>SX`P0YjNW202c/k<90:f][@P0WYjN0P38h=P80;2`/0P0a/K62@2j^[X80>?Sh`P0
XZ:R2030`<090:JVYPP0Xj>S2@38h=P@0:b/[140/[:b402^[ZhA0:BTY080b>3H4@30`<0@0<c<c140
_kno402/[:`90<SPf240/K6a8@2VYZH20<SPf240aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0
b>3H000M0<SPf080UiNG0P2YZJT209NGU`80TY:B0P2i^KT209:BTP80`/;20P2KVi/20;2`/080i>CT
0P2CTi<209nOW`80T92@0P2TY:@209bLW080^KVi0`2][Jd209BDU080VYZJ0P2QXJ420:b/[080/;2`
0P2g]kL20=7Ad@80bl_;0P2IVIT20:RXZ080RXZ:0P2JVYX209BDU080SXj>0P24Q8@30<SPf080Z:RX
0P2LW9`20:>SX`80_;bl0P3Shn<20<S8b080[Zj^0P3Vi^H20>_[j`80`L710P2GUiL209BDU080gmoO
0P3oool20;6a/@80RXZ:0`2>SXh208b<S080Shn?0P2YZJT20:j^[P80a<C40P2@T9020:n_[`80W9bL
0P2n_[h208n?S`80Ti>C0P2XZ:P20:n_[`80Ti>C0P2SXj<:0<SPf0@0WYjN102UYJD40;2`/0@0[Jf]
1036a/H40:VYZ@D0Vi^K102XZ:P40:BTY0@0ZZZZ102[Zj/40;6a/@@0[:b/102NWYh409^KV`D0UiNG
0P38h=P40:n_[`@0YZJV1037alL40<30`0@0`/;21@2OWil40?Shn0@0h>3P102@T9040:>SX`@0`<30
102YZJT40:JVYPD0Vi^K102WYjL40:>SX`T0b>3H202SXj<80:b/[0T0^k^k202SXj<80:NWY`P0/k>c
2@2][Jd809jNWP80b>3H202`/;080<K6aPT0^[Zj203Shn<80::RXPP0`<302@2VYZH80:>SX`T0b>3H
402/[:`A0;:b/Q00[Zj^4@2TY:@20<SPf140`<30403<c<`A0;no_a00[:b/2@38h=PQ0;6a/B40YZJV
0P38h=PQ0<G5aB40/[:b2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P209NGU`80ZJVY0P2G
UiL209:BTP80^KVi0P2BTY820<;2`P80Vi^K0P2`/;020>CTi080Ti>C0P2OWil2092@T080Y:BT0P2L
W9`20;Vi^@<0[Jf]0P2DU9@209ZJVP80XJ6Q0P2/[:`20;2`/080]kNg0P3AdM420<_;b`80VIVI0P2X
Z:P208Z:RP80VYZJ0P2DU9@208j>SP80Q8B40`38h=P20:RXZ080W9bL0P2SXj<20;bl_080hn?S0P38
b<P20:j^[P80i^KV0P3[jn/20<71`@80UiNG0P2DU9@20=oOg`80oooo0P2a/K4208Z:RP<0SXj>0P2<
S8`208n?S`80ZJVY0P2^[Zh20<C4a080T92@0P2_[jl209bLW080_[jn0P2?Shl209>CT`80Z:RX0P2_
[jl209>CT`80Xj>S2P38h=P409jNWP@0YJFU102`/;040:f][@@0a/K6102YZJT509^KV`@0Z:RX102T
Y:@40:ZZZP@0Zj^[102a/K440:b/[0@0WYjN102KVi/509NGU`80b>3H102_[jl40:JVYP@0alO71030
`<040<;2`PD0WinO103hn?P40>3Ph0@0T92@102SXj<40<30`0@0ZJVY102VYZH509^KV`@0YjNW102S
Xj<90<SPf0P0Xj>S202/[:`90;^k^`P0Xj>S202WYjL80;>c/`T0[Jf]202NWYh20<SPf0P0/;2`2036
a/H90;Zj^PP0hn?S202RXZ880<30`0T0YZJV202SXj<90<SPf100[:b/4@2b/[8@0:j^[Q40Y:BT0P38
h=PA0<30`100c<c<4@2o_kl@0:b/[0T0b>3H8@2a/K4Q0:JVYP80b>3H8@35aLDQ0;:b/PT0b>3H@P2X
Z:P20<SPf480]KFe7P38h=P001d0b>3H0P2FUYH20:ZZZP80ZJVY0P2l_;`20:FUY@80alO70P2LW9`2
0;jn_P80iNGU0P2>SXh20=7Ad@80Shn?0P2ATI4208j>SP80ZZZZ0P2KVi/309JFUP80[Zj^0P2ATI42
0<[:bP80_kno0P2@T902096AT@80Shn?0P2<S8`20:BTY080RXZ:0P2b/[820::RXP80T92@0P2JVYX2
0:6QX@<0b>3H0P2WYjL209VIV@80T92@0P2IVIT209JFUP80/K6a0P2OWil20<;2`P80X:2P0P2j^[X2
0:f][@80YZJV0P25QHD20?;blP80oooo0P2e]KD308b<S080VYZJ0P2PX:020;:b/P80fMWI0P2j^[X2
09jNWP80SHf=0P2;Rh/20:BTY080TY:B0P2HV9P20:j^[P80Y:BT0P2MWId209jNWPX0b>3H102NWYh4
0:FUY@@0/;2`102][Jd40<K6aP@0ZJVY1@2KVi/40:RXZ0@0Y:BT102ZZZX40:^[Z`@0/K6a102/[:`4
09jNWP@0Vi^K1@2GUiL20<SPf0@0[jn_102VYZH40<O7a`@0`<301032`/8509nOW`@0n?Sh103Ph>04
092@T0@0Xj>S1030`<040:VYZ@@0YZJV1@2KVi/40:NWY`@0Xj>S2@38h=P80:>SX`P0[:b/2@2k^k/8
0:>SX`P0YjNW202c/k<90:f][@P0WYjN0P38h=P80;2`/0P0a/K62@2j^[X80>?Sh`P0XZ:R2030`<09
0:JVYPP0Xj>S2@38h=P@0:b/[140/[:b402^[ZhA0:BTY080b>3H4@30`<0@0<c<c140_kno402/[:`9
0<SPf240/K6a8@2VYZH20<SPf240aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SP
f080UYJF0P2ZZZX20:VYZ@80_;bl0P2UYJD20<O7a`80W9bL0P2n_[h20>GUi@80SXj>0P3AdM4208n?
S`80TI6A0P2>SXh20:ZZZP80Vi^K0`2FUYH20:j^[P80TI6A0P3:b/X20;no_`80T92@0P2ATI4208n?
S`80S8b<0P2TY:@208Z:RP80/[:b0P2RXZ82092@T080VYZJ0P2QXJ430<SPf080YjNW0P2IVIT2092@
T080VIVI0P2FUYH20;6a/@80WinO0P32`/820:2PX080^[Zj0P2][Jd20:JVYP80QHF50P3bl_820?oo
o`80]KFe0`2<S8`209ZJVP80X:2P0P2b/[820=WIf@80^[Zj0P2NWYh208f=S@80Rh^;0P2TY:@209:B
TP80V9RH0P2^[Zh20:BTY080WIfM0P2NWYh:0<SPf0@0[Jf]102JVYX40:BTY0@0/;2`102c/k<40<S8
b0D0W9bL102ZZZX40:>SX`@0Zj^[1031`L440:b/[0@0YZJV1030`<040:6QX@D0YZJV0P38h=P40;Zj
^P@0YJFU103=cLd40<[:bP@0aLG51@30`<0409^KV`Cooooo202XZ:P40<71`@@0clo?102QXJ450;:b
/P@0VYZJ102PX:090<SPf0P0Xj>S202/[:`90;^k^`P0Xj>S202WYjL80;>c/`T0[Jf]202NWYh20<SP
f0P0/;2`2036a/H90;Zj^PP0hn?S202RXZ880<30`0T0YZJV202SXj<90<SPf100[:b/4@2b/[8@0:j^
[Q40Y:BT0P38h=PA0<30`100c<c<4@2o_kl@0:b/[0T0b>3H8@2a/K4Q0:JVYP80b>3H8@35aLDQ0;:b
/PT0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2[Zj/209bLW080WIfM0P29RHT208Z:RP80
YjNW0P2?Shl209:BTP80TI6A0P2XZ:P20;Jf]P80[:b/0P2BTY8209>CT`80WIfM0P2JVYX309jNWP80
TY:B0P2_[jl20<W9b@80fm_K0P2e]KD20:NWY`80UYJF0P2a/K4209JFUP80][Jf0P38b<P20:j^[P80
UYJF0P2>SXh20:ZZZP<0b>3H0P38b<P20<30`080[Jf]0P2WYjL20>_[j`80YZJV0P2g]kL20:VYZ@80
W9bL0P3oool20:b/[080Y:BT0P2HV9P209fMW@80oOgm0P3oool309RHV080b<S80P2OWil20;Fe]@80
k^k^0P2h^;P20;jn_P80/k>c0P2<S8`209RHV080[:b/0P2;Rh/209>CT`80X:2P0P2?Shl209:BTPX0
b>3H102][Jd409ZJVP@0Y:BT102`/;040;>c/`@0b<S81@2LW9`40:ZZZP@0Xj>S102[Zj/40<71`@@0
[:b/102VYZH40<30`0@0XJ6Q1@2VYZH20<SPf0@0^[Zj102UYJD40<g=c@@0b/[:1035aLD50<30`0@0
Vi^K1?ooool80:RXZ0@0`L71103?cll40:6QX@D0/[:b102JVYX40:2PX0T0b>3H202SXj<80:b/[0T0
^k^k202SXj<80:NWY`P0/k>c2@2][Jd809jNWP80b>3H202`/;080<K6aPT0^[Zj203Shn<80::RXPP0
`<302@2VYZH80:>SX`T0b>3H402/[:`A0;:b/Q00[Zj^4@2TY:@20<SPf140`<30403<c<`A0;no_a00
[:b/2@38h=PQ0;6a/B40YZJV0P38h=PQ0<G5aB40/[:b2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf000
7@38h=P20:^[Z`80W9bL0P2MWId208V9R@80RXZ:0P2WYjL208n?S`80TY:B0P2ATI420:RXZ080][Jf
0P2/[:`209:BTP80Ti>C0P2MWId209ZJVP<0WYjN0P2BTY820:n_[`80bLW90P3Kfm/20;Fe]@80YjNW
0P2FUYH20;6a/@80UYJF0P2f][H20<S8b080[Zj^0P2FUYH208j>SP80ZZZZ0`38h=P20<S8b080`<30
0P2][Jd20:NWY`80jn_[0P2VYZH20;Ng]`80ZJVY0P2LW9`20?ooo`80[:b/0P2TY:@209RHV080WIfM
0P3moOd20?ooo`<0V9RH0P38b<P209nOW`80]KFe0P3^k^h20;Rh^080_[jn0P2c/k<208b<S080V9RH
0P2/[:`208^;R`80Ti>C0P2PX:0208n?S`80TY:B2P38h=P40:f][@@0VYZJ102TY:@40;2`/0@0/k>c
1038b<P509bLW0@0ZZZZ102SXj<40:^[Z`@0`L71102/[:`40:JVYP@0`<30102QXJ450:JVYP80b>3H
102j^[X40:FUY@@0cLg=103:b/X40<G5a@D0`<30102KVi/4ooooo`P0Z:RX1031`L440<o?c`@0XJ6Q
1@2b/[8409ZJVP@0X:2P2@38h=P80:>SX`P0[:b/2@2k^k/80:>SX`P0YjNW202c/k<90:f][@P0WYjN
0P38h=P80;2`/0P0a/K62@2j^[X80>?Sh`P0XZ:R2030`<090:JVYPP0Xj>S2@38h=P@0:b/[140/[:b
402^[ZhA0:BTY080b>3H4@30`<0@0<c<c140_kno402/[:`90<SPf240/K6a8@2VYZH20<SPf240aLG5
8@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080UiNG0P2XZ:P209RHV080Vi^K0P2E
UID20<30`080`L710P2`/;020<30`080b/[:0P3_knl20<o?c`80[Jf]0P2NWYh208R8R080a<C40`2o
_kl208j>SP80TY:B0P2OWil20<W9b@80/k>c0P39bLT20;6a/@80WIfM0P2RXZ820<30`080bLW90P2:
RXX20;:b/P80W9bL0P2m_Kd30<SPf080[:b/0P2XZ:P20:b/[080UYJF0P2d];@20?KfmP80oooo0P2n
_[h2096AT@80ZZZZ0P3Kfm/20=KFeP80UYJF0P2IVIT20;Jf]P80g=cL0`2SXj<209jNWP80[:b/0P2Y
ZJT209nOW`80aLG50P3^k^h20>;RhP80^KVi0P2OWil20=WIf@80SHf=0P2GUiL209RHV080Vi^K0P2O
Wil:0<SPf0@0[Jf]102JVYX40:BTY0@0/;2`102c/k<40<S8b0D0W9bL102ZZZX40:>SX`@0Zj^[1031
`L440:b/[0@0YZJV1030`<040:6QX@D0YZJV0P38h=P40;Zj^P@0YJFU103=cLd40<[:bP@0aLG51@30
`<0409^KV`Cooooo202XZ:P40<71`@@0clo?102QXJ450;:b/P@0VYZJ102PX:090<SPf0P0Xj>S202/
[:`90;^k^`P0Xj>S202WYjL80;>c/`T0[Jf]202NWYh20<SPf0P0/;2`2036a/H90;Zj^PP0hn?S202R
XZ880<30`0T0YZJV202SXj<90<SPf100[:b/4@2b/[8@0:j^[Q40Y:BT0P38h=PA0<30`100c<c<4@2o
_kl@0:b/[0T0b>3H8@2a/K4Q0:JVYP80b>3H8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe7P38
h=P001d0b>3H0P2GUiL20:RXZ080V9RH0P2KVi/209FEU@80`<300P31`L420;2`/080`<300P3:b/X2
0>o_k`80clo?0P2][Jd209jNWP80R8R80P34a<@30;no_`80SXj>0P2BTY8209nOW`80bLW90P2c/k<2
0<W9b@80/K6a0P2MWId20::RXP80`<300P39bLT208Z:RP80/[:b0P2LW9`20;fm_@<0b>3H0P2/[:`2
0:RXZ080[:b/0P2FUYH20;Bd]080m_Kf0P3oool20;jn_P80TI6A0P2ZZZX20=_Kf`80e]KF0P2FUYH2
09VIV@80][Jf0P3Lg=`30:>SX`80WYjN0P2/[:`20:VYZ@80WinO0P35aLD20>k^kP80h^;R0P2i^KT2
09nOW`80fMWI0P2=SHd209NGU`80V9RH0P2KVi/209nOW`X0b>3H102[Zj/40::RXP@0]KFe102SXj<4
0;Zj^P@0^k^k1@2PX:0409FEU@@0aLG5102][Jd40:VYZ@@0/;2`102[Zj/40:NWY`@0V9RH1@2DU9@2
0<SPf0@0b<S8102d];@40<o?c`@0_;bl103Ph>050>_[j`@0];Bd102EUID40?Ogm`@0`L71102^[Zh4
0<k>cP@0fMWI1@2k^k/40;Jf]P@0W9bL2@38h=P80;6a/@P0[Jf]2@30`<080:NWY`P0/[:b202/[:`9
0:NWY`P0UiNG0P38h=P80<c<c0P0_Kfm2@3IfMT80;2`/0P0e]KF202j^[X90;jn_PP0YJFU2@38h=P@
0:b/[140/[:b402^[ZhA0:BTY080b>3H4@30`<0@0<c<c140_kno402/[:`90<SPf240/K6a8@2VYZH2
0<SPf240aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080Y:BT0P2h^;P20:^[
Z`80U9BD0P2m_Kd20:JVYP80/;2`0P2MWId20;Jf]P80[Zj^0P2`/;020<o?c`80WIfM0P2HV9P209bL
W080VIVI0`3QhN420;Vi^@80[Zj^0P2=SHd20:RXZ080W9bL0P2>SXh20;Ng]`@0T92@0P2TY:@208j>
SP80VYZJ0P2CTi<209:BTP80W9bL0`38h=P20>WYj@80`l?30P2VYZH20<C4a080iNGU0P3Lg=`20>SX
j080X:2P0P33`l<20<C4a080nOWi0P32`/820:2PX080YZJV0P2:RXX208n?S`D0gMgM0P3AdM420:NW
Y`80Vi^K0P2TY:@20:ZZZP80e]KF0P3Lg=`20;>c/`80f=SH0P2DU9@20;Jf]P80]KFe0P2ZZZX208b<
S0X0b>3H102[Zj/40::RXP@0]KFe102SXj<40;Zj^P@0^k^k1@2PX:0409FEU@@0aLG5102][Jd40:VY
Z@@0/;2`102[Zj/40:NWY`@0V9RH1@2DU9@20<SPf0@0b<S8102d];@40<o?c`@0_;bl103Ph>050>_[
j`@0];Bd102EUID40?Ogm`@0`L71102^[Zh40<k>cP@0fMWI1@2k^k/40;Jf]P@0W9bL2@38h=P80;6a
/@P0[Jf]2@30`<080:NWY`P0/[:b202/[:`90:NWY`P0UiNG0P38h=P80<c<c0P0_Kfm2@3IfMT80;2`
/0P0e]KF202j^[X90;jn_PP0YJFU2@38h=P@0:b/[140/[:b402^[ZhA0:BTY080b>3H4@30`<0@0<c<
c140_kno402/[:`90<SPf240/K6a8@2VYZH20<SPf240aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe
]Ah0b>3H000M0<SPf080Y:BT0P2h^;P20:^[Z`80U9BD0P2m_Kd20:JVYP80/;2`0P2MWId20;Jf]P80
[Zj^0P2`/;020<o?c`80WIfM0P2HV9P209bLW080VIVI0`3QhN420;Vi^@80[Zj^0P2=SHd20:RXZ080
W9bL0P2>SXh20;Ng]`@0T92@0P2TY:@208j>SP80VYZJ0P2CTi<209:BTP80W9bL0`38h=P20>WYj@80
`l?30P2VYZH20<C4a080iNGU0P3Lg=`20>SXj080X:2P0P33`l<20<C4a080nOWi0P32`/820:2PX080
YZJV0P2:RXX208n?S`D0gMgM0P3AdM420:NWY`80Vi^K0P2TY:@20:ZZZP80e]KF0P3Lg=`20;>c/`80
f=SH0P2DU9@20;Jf]P80]KFe0P2ZZZX208b<S0X0b>3H102[Zj/40::RXP@0]KFe102SXj<40;Zj^P@0
^k^k1@2PX:0409FEU@@0aLG5102][Jd40:VYZ@@0/;2`102[Zj/40:NWY`@0V9RH1@2DU9@20<SPf0@0
b<S8102d];@40<o?c`@0_;bl103Ph>050>_[j`@0];Bd102EUID40?Ogm`@0`L71102^[Zh40<k>cP@0
fMWI1@2k^k/40;Jf]P@0W9bL2@38h=P80;6a/@P0[Jf]2@30`<080:NWY`P0/[:b202/[:`90:NWY`P0
UiNG0P38h=P80<c<c0P0_Kfm2@3IfMT80;2`/0P0e]KF202j^[X90;jn_PP0YJFU2@38h=P@0:b/[140
/[:b402^[ZhA0:BTY080b>3H4@30`<0@0<c<c140_kno402/[:`90<SPf240/K6a8@2VYZH20<SPf240
aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080WinO0P2][Jd20:6QX@80ZJVY
0P3Cdm<20:FUY@80WYjN0P2<S8`20:f][@80h^;R0P33`l<20:^[Z`80/[:b0P2CTi<208Z:RP80V9RH
0`2<S8`20=kNgP80_;bl0P2>SXh20;^k^`80ZZZZ0P2_[jl20<S8b080a<C40P2][Jd20;Zj^P80Ti>C
0P2JVYX209jNWP80Shn?0P2FUYH30<SPf080X:2P0P3;bl/209:BTP80]KFe0P2][Jd20;>c/`80YZJV
0P2WYjL20=gMg@80oooo0P3kno/20?ooo`80alO70P2j^[X2096AT@80XJ6Q0`2XZ:P20?ooo`80k>c/
0P2KVi/20;Jf]P80Y:BT0P2VYZH20;fm_@80a<C40P3oool20;fm_@80YJFU0P2l_;`409fMW@80Ti>C
2P38h=P40:^[Z`@0XZ:R102e]KD40:>SX`@0^[Zj102k^k/50:2PX0@0UIFE1035aLD40:f][@@0ZJVY
102`/;040:^[Z`@0YjNW102HV9P509BDU080b>3H1038b<P40;Bd]0@0clo?102l_;`40>3Ph0D0jn_[
102d];@409FEU@@0moOg1031`L440:j^[P@0c/k>103IfMT50;^k^`@0][Jf102LW9`90<SPf0P0/K6a
202][Jd90<30`0P0YjNW202b/[880:b/[0T0YjNW202GUiL20<SPf0P0c<c<202m_Kd90=WIf@P0/;2`
203Fe]H80;Zj^PT0_[jn202UYJD90<SPf100[:b/4@2b/[8@0:j^[Q40Y:BT0P38h=PA0<30`100c<c<
4@2o_kl@0:b/[0T0b>3H8@2a/K4Q0:JVYP80b>3H8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe
7P38h=P001d0b>3H0P2OWil20:f][@80XJ6Q0P2YZJT20=?Cd`80YJFU0P2NWYh208b<S080[Jf]0P3R
h^820<?3``80Zj^[0P2b/[8209>CT`80RXZ:0P2HV9P308b<S080g]kN0P2l_;`208j>SP80^k^k0P2Z
ZZX20:n_[`80b<S80P34a<@20:f][@80^[Zj0P2CTi<209ZJVP80WYjN0P2?Shl209JFUP<0b>3H0P2P
X:020<_;b`80TY:B0P2e]KD20:f][@80/k>c0P2VYZH20:NWY`80gMgM0P3oool20?_kn`80oooo0P37
alL20;Zj^P80TI6A0P2QXJ430:RXZ080oooo0P3/k>`209^KV`80][Jf0P2TY:@20:JVYP80_Kfm0P34
a<@20?ooo`80_Kfm0P2UYJD20;bl_0@0WIfM0P2CTi<:0<SPf0@0[jn_1031`L440;Bd]0@0Zj^[102`
/;040=7Ad@D0`<30102JVYX40:>SX`@0[Zj^102TY:@40;6a/@@0/;2`202KVi/509BDU080b>3H1031
`L440>c/k0@0Y:BT102o_kl40=KFePD0a/K6102l_;`40;:b/P@0YjNW103YjNT40;Bd]0@0^KVi102b
/[850:f][@@0XZ:R102NWYh90<SPf0P0/K6a202][Jd90<30`0P0YjNW202b/[880:b/[0T0YjNW202G
UiL20<SPf0P0c<c<202m_Kd90=WIf@P0/;2`203Fe]H80;Zj^PT0_[jn202UYJD90<SPf100[:b/4@2b
/[8@0:j^[Q40Y:BT0P38h=PA0<30`100c<c<4@2o_kl@0:b/[0T0b>3H8@2a/K4Q0:JVYP80b>3H8@35
aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2][Jd20;6a/@80/;2`0P3;bl/2
0;Vi^@80Shn?0P2EUID20;^k^`80_;bl0P3<c<`20=_Kf`80^;Rh0P3;bl/209RHV080Rh^;0P2<S8`3
09JFUP80]KFe0P33`l<20;Bd]080WIfM0P2`/;020<g=c@80WYjN0P3?cll20<30`080WIfM0P2RXZ82
09nOW`80Vi^K0P2=SHd208^;R`<0b>3H0P2][Jd20:ZZZP80dM7A0P3Bd]8209fMW@80Ti>C0P2/[:`2
0;Jf]P80oooo0P2o_kl20;Ng]`80]KFe0P2SXj<20;2`/080X:2P0P2DU9@30;Zj^P80QXJ60P3inOT2
0?ooo`80ZJVY0P2`/;020>OWi`80][Jf0P2[Zj/20:n_[`80X:2P0P2YZJT20:RXZ080Y:BT0P2HV9P2
09NGU`X0b>3H102_[jl40<71`@@0];Bd102[Zj/40;2`/0@0dM7A1@30`<0409ZJVP@0Xj>S102^[Zh4
0:BTY0@0/K6a102`/;0809^KV`D0U9BD0P38h=P40<71`@@0k>c/102TY:@40;no_`@0e]KF1@36a/H4
0;bl_0@0/[:b102WYjL40>WYj@@0];Bd102i^KT40;:b/PD0[Jf]102RXZ8409jNWPT0b>3H202a/K48
0:f][@T0`<30202WYjL80;:b/PP0[:b/2@2WYjL809NGU`80b>3H203<c<`80;fm_@T0fMWI202`/;08
0=KFePP0^[Zj2@2n_[h80:FUY@T0b>3H402/[:`A0;:b/Q00[Zj^4@2TY:@20<SPf140`<30403<c<`A
0;no_a00[:b/2@38h=PQ0;6a/B40YZJV0P38h=PQ0<G5aB40/[:b2@38h=Q20:RXZ080b>3H@P2e]KDN
0<SPf0007@38h=P20:f][@80/K6a0P2`/;020<_;b`80^KVi0P2?Shl209FEU@80^k^k0P2l_;`20<c<
c080fm_K0P2h^;P20<_;b`80V9RH0P2;Rh/208b<S0<0UYJF0P2e]KD20<?3``80];Bd0P2MWId20;2`
/080cLg=0P2NWYh20<o?c`80`<300P2MWId20::RXP80WinO0P2KVi/208f=S@80Rh^;0`38h=P20:f]
[@80ZZZZ0P3AdM420=;BdP80WIfM0P2CTi<20:b/[080][Jf0P3oool20;no_`80]kNg0P2e]KD20:>S
X`80/;2`0P2PX:0209BDU0<0^[Zj0P26QXH20?Win@80oooo0P2YZJT20;2`/080inOW0P2f][H20:^[
Z`80[jn_0P2PX:020:VYZ@80Z:RX0P2TY:@209RHV080UiNG2P38h=P40:n_[`@0`L71102d];@40:^[
Z`@0/;2`103AdM450<30`0@0VYZJ102SXj<40:j^[P@0Y:BT102a/K440;2`/0P0Vi^K1@2DU9@20<SP
f0@0`L71103/k>`40:BTY0@0_kno103Fe]H50<K6aP@0_;bl102b/[840:NWY`@0jNWY102d];@40;Vi
^@@0/[:b1@2][Jd40::RXP@0WYjN2@38h=P80;6a/@P0[Jf]2@30`<080:NWY`P0/[:b202/[:`90:NW
Y`P0UiNG0P38h=P80<c<c0P0_Kfm2@3IfMT80;2`/0P0e]KF202j^[X90;jn_PP0YJFU2@38h=P@0:b/
[140/[:b402^[ZhA0:BTY080b>3H4@30`<0@0<c<c140_kno402/[:`90<SPf240/K6a8@2VYZH20<SP
f240aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080Xj>S0P34a<@20;:b/P80
bl_;0P3<c<`20;2`/080_[jn0P2ATI420:>SX`80P8200P3IfMT20>?Sh`80Vi^K0P3YjNT20;6a/@80
Shn?0`2TY:@209FEU@80[Zj^0P2MWId20;Zj^P80QHF50P2][Jd209ZJVP80SXj>0P26QXH209FEU@80
TY:B0P2TY:@208Z:RP80VIVI0P2CTi<30<SPf080`<300P3Jf]X20?ooo`80`L710P2c/k<208Z:RP80
d=3@0P2n_[h20;^k^`80ZZZZ0P34a<@20<?3``80iNGU0P2f][H20>;RhP80UiNG0`2DU9@20;:b/P80
]KFe0P2MWId20=OGe`80Shn?0P2VYZH409FEU@80emOG102i^KT209NGU`80W9bL0P2>SXh20:^[Z`X0
b>3H102_[jl40<71`@@0];Bd102[Zj/40;2`/0@0dM7A1@30`<0409ZJVP@0Xj>S102^[Zh40:BTY0@0
/K6a102`/;0809^KV`D0U9BD0P38h=P40<71`@@0k>c/102TY:@40;no_`@0e]KF1@36a/H40;bl_0@0
/[:b102WYjL40>WYj@@0];Bd102i^KT40;:b/PD0[Jf]102RXZ8409jNWPT0b>3H202a/K480:f][@T0
`<30202WYjL80;:b/PP0[:b/2@2WYjL809NGU`80b>3H203<c<`80;fm_@T0fMWI202`/;080=KFePP0
^[Zj2@2n_[h80:FUY@T0b>3H402/[:`A0;:b/Q00[Zj^4@2TY:@20<SPf140`<30403<c<`A0;no_a00
[:b/2@38h=PQ0;6a/B40YZJV0P38h=PQ0<G5aB40/[:b2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf000
7@38h=P20:>SX`80a<C40P2b/[820<_;b`80c<c<0P2`/;020;jn_P80TI6A0P2SXj<20820P080fMWI
0P3Shn<209^KV`80jNWY0P2a/K4208n?S`<0Y:BT0P2EUID20:j^[P80WIfM0P2j^[X208F5Q@80[Jf]
0P2JVYX208j>SP80QXJ60P2EUID209:BTP80Y:BT0P2:RXX209VIV@80Ti>C0`38h=P20<30`080f][J
0P3oool20<71`@80/k>c0P2:RXX20=3@d080_[jn0P2k^k/20:ZZZP80a<C40P33`l<20>GUi@80][Jf
0P3Rh^8209NGU`<0U9BD0P2b/[820;Fe]@80WIfM0P3GemL208n?S`80YZJV102EUID20=OGe`@0^KVi
0P2GUiL209bLW080SXj>0P2[Zj/:0<SPf0@0];Bd102e]KD40:JVYP@0YjNW102g]kL409RHV0D0b<S8
102j^[X409RHV0@0UiNG102VYZH40:>SX`@0VIVI102EUID408n?S`D0VIVI0P38h=P40;bl_0@0h^;R
102^[Zh40<C4a0@0bl_;1@3AdM440>g]k@@0alO7102RXZ8409VIV@@0`/;2102[Zj/409^KV`D0YjNW
102OWil409JFUPT0b>3H202b/[880:n_[`T0/K6a202o_kl809jNWPP0Y:BT2@2JVYX809JFUP80b>3H
203:b/X80;bl_0T0a<C4203Lg=`80;no_`P0[Jf]2@2YZJT809bLW0T0b>3H402_[jlA0;Jf]Q00Z:RX
4@2JVYX20<SPf140`L714038b<PA0;Fe]A00XZ:R2@38h=PQ0;6a/B40YZJV0P38h=PQ0<G5aB40/[:b
2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20:n_[`80VYZJ0P2j^[X20;Ng]`80TI6A0P29
RHT20:VYZ@80SHf=0P23Ph<20:b/[080YJFU0P2>SXh20=_Kf`80VYZJ0P3>c/h209ZJVP<0Ti>C0P2O
Wil209JFUP80V9RH0P2PX:020:>SX`80T92@0P2g]kL209VIV@80WIfM0P2:RXX209NGU`80RXZ:0P2>
SXh208f=S@80UYJF0`38h=P20<K6aP80`L710P38b<P20<K6aP80XZ:R0P2g]kL20:RXZ080^KVi0P3`
l?020:j^[P80bLW90P3:b/X20?ooo`80`L710P3`l?020;no_`<0SXj>0P2i^KT209fMW@80T92@0P2i
^KT20?Cdm080Vi^K0P2m_Kd208^;R`80[jn_0P2[Zj/20;Jf]P80V9RH0P2XZ:P209nOW`80UIFE2P38
h=P40;Bd]0@0]KFe102VYZH40:NWY`@0]kNg102HV9P50<S8b0@0^[Zj102HV9P409NGU`@0YZJV102S
Xj<409VIV@@0UIFE102?Shl509VIV@80b>3H102l_;`40>;RhP@0[Zj^1034a<@40<_;b`D0dM7A103]
kNd40<O7a`@0XZ:R102IVIT40<;2`P@0Zj^[102KVi/50:NWY`@0WinO102FUYH90<SPf0P0/[:b202_
[jl90;6a/@P0_kno202NWYh80:BTY0T0VYZJ202FUYH20<SPf0P0b/[:202l_;`90<C4a0P0g=cL202o
_kl80:f][@T0ZJVY202LW9`90<SPf100[jn_4@2f][H@0:RXZ140VYZJ0P38h=PA0<71`A00b<S84@2e
]KD@0::RXPT0b>3H8@2a/K4Q0:JVYP80b>3H8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe7P38
h=P001d0b>3H0P2_[jl209ZJVP80^[Zj0P2g]kL2096AT@80RHV90P2YZJT208f=S@80Ph>30P2/[:`2
0:FUY@80SXj>0P3Kfm/209ZJVP80c/k>0P2JVYX309>CT`80WinO0P2FUYH209RHV080X:2P0P2SXj<2
092@T080]kNg0P2IVIT209fMW@80RXZ:0P2GUiL208Z:RP80SXj>0P2=SHd209JFUP<0b>3H0P36a/H2
0<71`@80b<S80P36a/H20::RXP80]kNg0P2XZ:P20;Vi^@80l?3`0P2^[Zh20<W9b@80b/[:0P3oool2
0<71`@80l?3`0P2o_kl308j>SP80^KVi0P2MWId2092@T080^KVi0P3dm?@209^KV`80_Kfm0P2;Rh/2
0:n_[`80Zj^[0P2f][H209RHV080Z:RX0P2OWil209FEU@X0b>3H102d];@40;Fe]@@0YZJV102WYjL4
0;Ng]`@0V9RH1@38b<P40;Zj^P@0V9RH102GUiL40:JVYP@0Xj>S102IVIT409FEU@@0Shn?1@2IVIT2
0<SPf0@0_;bl103Rh^840:j^[P@0a<C4103;bl/50=7Ad@@0kNg]1037alL40::RXP@0VIVI1032`/84
0:^[Z`@0Vi^K1@2WYjL409nOW`@0UYJF2@38h=P80;:b/PP0[jn_2@2a/K480;no_`P0WYjN202TY:@9
09ZJVPP0UYJF0P38h=P80<[:bPP0_;bl2@34a<@80=cLg0P0_kno202][Jd90:VYZ@P0W9bL2@38h=P@
0:n_[a40][Jf402XZ:PA09ZJVP80b>3H4@31`L4@0<S8b140]KFe402RXZ890<SPf240/K6a8@2VYZH2
0<SPf240aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080dm?C0P2IVIT20<k>
cP80YJFU0P2VYZH209fMW@80[:b/0P2?Shl20<g=c@80`<300P20P80209BDU080Z:RX0P3@d=020<C4
a080^[Zj0`2>SXh209ZJVP80Vi^K0P2?Shl209bLW080^;Rh0P2:RXX209VIV@80W9bL0P2=SHd20:NW
Y`80Rh^;0P2JVYX208Z:RP80VYZJ0P2IVIT30<SPf080TY:B0P3Jf]X20<S8b080oooo0P2TY:@20<O7
a`80X:2P0P3/k>`20;Rh^080c/k>0P3UiND20=[JfP80[Jf]0P3@d=020<;2`P80ZZZZ0`2JVYX2096A
T@80RHV90P2NWYh2092@T080ZJVY0P2BTY8209nOW`80S8b<0P2LW9`20::RXP80X:2P0P2/[:`209:B
TP80UIFE0P2@T90:0<SPf0@0];Bd102e]KD40:JVYP@0YjNW102g]kL409RHV0D0b<S8102j^[X409RH
V0@0UiNG102VYZH40:>SX`@0VIVI102EUID408n?S`D0VIVI0P38h=P40;bl_0@0h^;R102^[Zh40<C4
a0@0bl_;1@3AdM440>g]k@@0alO7102RXZ8409VIV@@0`/;2102[Zj/409^KV`D0YjNW102OWil409JF
UPT0b>3H202b/[880:n_[`T0/K6a202o_kl809jNWPP0Y:BT2@2JVYX809JFUP80b>3H203:b/X80;bl
_0T0a<C4203Lg=`80;no_`P0[Jf]2@2YZJT809bLW0T0b>3H402_[jlA0;Jf]Q00Z:RX4@2JVYX20<SP
f140`L714038b<PA0;Fe]A00XZ:R2@38h=PQ0;6a/B40YZJV0P38h=PQ0<G5aB40/[:b2@38h=Q20:RX
Z080b>3H@P2e]KDN0<SPf0007@38h=P20=?Cd`80VIVI0P3>c/h20:FUY@80YZJV0P2MWId20:b/[080
Shn?0P3=cLd20<30`080P8200P2DU9@20:RXZ080d=3@0P34a<@20;Zj^P<0SXj>0P2JVYX209^KV`80
Shn?0P2LW9`20;Rh^080RXZ:0P2IVIT209bLW080SHf=0P2WYjL208^;R`80VYZJ0P2:RXX209ZJVP80
VIVI0`38h=P209:BTP80f][J0P38b<P20?ooo`80Y:BT0P37alL20:2PX080k>c/0P2h^;P20<k>cP80
iNGU0P3Jf]X20:f][@80d=3@0P32`/820:ZZZP<0VYZJ0P2ATI4208V9R@80WYjN0P2@T9020:VYZ@80
TY:B0P2OWil208b<S080W9bL0P2RXZ820:2PX080[:b/0P2BTY8209FEU@80T92@2P38h=P80;2`/0@0
/k>c102j^[X40:n_[`T0_;bl1033`l<40:RXZ0@0WinO102][Jd409VIV@@0WinO102KVi/409>CT`D0
Vi^K0P38h=P40;no_`P0`l?3102k^k/40;Vi^@D0^[Zj103De=@40>?Sh`@0n?Sh102KVi/80:6QX@@0
YZJV1@2g]kL409>CT`@0YZJV2@38h=P80;:b/PP0[jn_2@2a/K480;no_`P0WYjN202TY:@909ZJVPP0
UYJF0P38h=P80<[:bPP0_;bl2@34a<@80=cLg0P0_kno202][Jd90:VYZ@P0W9bL2@38h=P@0:n_[a40
][Jf402XZ:PA09ZJVP80b>3H4@31`L4@0<S8b140]KFe402RXZ890<SPf240/K6a8@2VYZH20<SPf240
aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SPf080ZZZZ0P2][Jd20;Jf]P80/K6a
0P3EeMD209bLW080]KFe102g]kL20:>SX`80^KVi0P2HV9P20;fm_@80dM7A0P2FUYH20=gMg@<0c<c<
102ATI4209RHV080Vi^K0P3@d=020:RXZ080Rh^;0P2BTY8208j>SP80UYJF102HV9P208b<S080Ti>C
0P2OWil30<SPf080fMWI0P2VYZH20=[JfP80fm_K0P3;bl/20;jn_P80YZJV0P2e]KD20:>SX`80alO7
0P3Ti>@209NGU`80TY:B0P3oool20?7al@80YZJV0`3oool2092@T080V9RH0P2ATI4209bLW080[:b/
0P2XZ:P20:NWY`80YZJV0P2PX:020:RXZ080XZ:R0P2ATI4209fMW@80XZ:R0P2QXJ4:0<SPf0P0/;2`
102c/k<40;Zj^P@0[jn_2@2l_;`40<?3``@0Z:RX102OWil40:f][@@0VIVI102OWil409^KV`@0Ti>C
1@2KVi/20<SPf0@0_kno2033`l<40;^k^`@0^KVi1@2j^[X40=CDe0@0hn?S103hn?P409^KV`P0XJ6Q
102VYZH50;Ng]`@0Ti>C102VYZH90<SPf0P0/[:b202_[jl90;6a/@P0_kno202NWYh80:BTY0T0VYZJ
202FUYH20<SPf0P0b/[:202l_;`90<C4a0P0g=cL202o_kl80:f][@T0ZJVY202LW9`90<SPf100[jn_
4@2f][H@0:RXZ140VYZJ0P38h=PA0<71`A00b<S84@2e]KD@0::RXPT0b>3H8@2a/K4Q0:JVYP80b>3H
8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2ZZZX20:f][@80][Jf0P2a
/K420=GEe@80W9bL0P2e]KD40;Ng]`80Xj>S0P2i^KT209RHV080_Kfm0P3AdM4209JFUP80gMgM0`3<
c<`4096AT@80V9RH0P2KVi/20=3@d080Z:RX0P2;Rh/209:BTP80SXj>0P2FUYH409RHV080S8b<0P2C
Ti<209nOW`<0b>3H0P3IfMT20:JVYP80f][J0P3Kfm/20<_;b`80_[jn0P2VYZH20;Fe]@80Xj>S0P37
alL20>CTi080UiNG0P2BTY820?ooo`80lO7a0P2VYZH30?ooo`80T92@0P2HV9P2096AT@80W9bL0P2/
[:`20:RXZ080YjNW0P2VYZH20:2PX080Z:RX0P2RXZ82096AT@80WIfM0P2RXZ820:6QX@X0b>3H202`
/;040;>c/`@0^[Zj102_[jl90;bl_0@0`l?3102XZ:P409nOW`@0[Jf]102IVIT409nOW`@0Vi^K102C
Ti<509^KV`80b>3H102o_kl80<?3``@0^k^k102i^KT50;Zj^P@0e=CD103Shn<40?Shn0@0Vi^K202Q
XJ440:JVYPD0]kNg102CTi<40:JVYPT0b>3H202b/[880:n_[`T0/K6a202o_kl809jNWPP0Y:BT2@2J
VYX809JFUP80b>3H203:b/X80;bl_0T0a<C4203Lg=`80;no_`P0[Jf]2@2YZJT809bLW0T0b>3H402_
[jlA0;Jf]Q00Z:RX4@2JVYX20<SPf140`L714038b<PA0;Fe]A00XZ:R2@38h=PQ0;6a/B40YZJV0P38
h=PQ0<G5aB40/[:b2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P20:BTY080^;Rh0P2VYZH2
0;bl_080`<300P2@T9020:FUY@80_Kfm0P2QXJ420:ZZZP80h^;R0P2e]KD20:VYZ@80aLG50P3Cdm<2
0<W9b@<0U9BD0P2CTi<209fMW@80YJFU0P2SXj<209:BTP80Rh^;0P2?Shl2092@T080_;bl0P2KVi/2
0:BTY080UYJF0P27QhL209bLW080XZ:R0`38h=P20<?3``80^[Zj0P2VYZH20::RXP80f=SH0P2n_[h2
0>7Qh@80UYJF0P2a/K4209nOW`80[Zj^0P2`/;020=SHf080Z:RX0P3]kNd20>KViP<0oooo0P3WinL2
09fMW@80Z:RX0P2HV9P209fMW@80UIFE0P2YZJT208f=S@80a<C40P3Ph>0209fMW@80Rh^;0P2ATI42
0;:b/P80W9bL2P38h=P80;2`/0@0/k>c102j^[X40:n_[`T0_;bl1033`l<40:RXZ0@0WinO102][Jd4
09VIV@@0WinO102KVi/409>CT`D0Vi^K0P38h=P40;no_`P0`l?3102k^k/40;Vi^@D0^[Zj103De=@4
0>?Sh`@0n?Sh102KVi/80:6QX@@0YZJV1@2g]kL409>CT`@0YZJV2@38h=P80;:b/PP0[jn_2@2a/K48
0;no_`P0WYjN202TY:@909ZJVPP0UYJF0P38h=P80<[:bPP0_;bl2@34a<@80=cLg0P0_kno202][Jd9
0:VYZ@P0W9bL2@38h=P@0:n_[a40][Jf402XZ:PA09ZJVP80b>3H4@31`L4@0<S8b140]KFe402RXZ89
0<SPf240/K6a8@2VYZH20<SPf240aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0b>3H000M0<SP
f080Y:BT0P2h^;P20:JVYP80_;bl0P30`<02092@T080YJFU0P2m_Kd20:6QX@80ZZZZ0P3Rh^820;Fe
]@80ZJVY0P35aLD20=?Cd`80bLW90`2DU9@209>CT`80WIfM0P2UYJD20:>SX`80TY:B0P2;Rh/208n?
S`80T92@0P2l_;`209^KV`80Y:BT0P2FUYH208N7Q`80W9bL0P2RXZ830<SPf080`l?30P2j^[X20:JV
YP80XZ:R0P3Hf=P20;jn_P80hN7Q0P2FUYH20;6a/@80WinO0P2^[Zh20;2`/080f=SH0P2XZ:P20>g]
k@80i^KV0`3oool20>OWi`80WIfM0P2XZ:P209RHV080WIfM0P2EUID20:VYZ@80SHf=0P34a<@20>3P
h080WIfM0P2;Rh/2096AT@80/[:b0P2LW9`:0<SPf0@0/K6a102c/k<40;Fe]@@0ZJVY102h^;P40:n_
[`D0XZ:R102e]KD40;:b/P@0ZJVY102c/k<40:VYZ@@0WinO102QXJ440::RXPD0Vi^K0P38h=P40<71
`@@0[Jf]102[Zj/40<c<c0@0_Kfm1@35aLD40;6a/@@0/[:b102[Zj/40;2`/0@0X:2P102WYjL40:2P
X0D0XZ:R102OWil409^KV`T0b>3H202_[jl80:^[Z`T0]kNg202`/;080:n_[`P0[Jf]2@2KVi/809jN
WP80b>3H202k^k/80<?3``T0a<C4202h^;P80;bl_0P0[:b/2@2MWId80:BTY0T0b>3H402_[jlA0;Jf
]Q00Z:RX4@2JVYX20<SPf140`L714038b<PA0;Fe]A00XZ:R2@38h=PQ0;6a/B40YZJV0P38h=PQ0<G5
aB40/[:b2@38h=Q20:RXZ080b>3H@P2e]KDN0<SPf0007@38h=P209nOW`80Ti>C0P31`L420:j^[P80
[:b/0P32`/8209fMW@80[jn_0P2h^;P20<W9b@80^;Rh0P2HV9P20820P080[Zj^0P2n_[h20;Ng]`<0
ZZZZ0P3:b/X20;Vi^@80Shn?0P2RXZ820<;2`P80Rh^;0P2JVYX209^KV`80VYZJ0P2QXJ4209bLW080
SXj>0P2@T90208R8R080UYJF0`38h=P20;Fe]@80c<c<0P2XZ:P20;Vi^@@0[Jf]0P3AdM420=;BdP80
f][J0P2XZ:P20>WYj@80YZJV0P3=cLd20:6QX@80_Kfm0P2b/[830:VYZ@80ZZZZ0P2SXj<20::RXP80
YJFU0P2FUYH20:n_[`80/[:b0P2;Rh/2096AT@80WinO0P2o_kl20:JVYP80SHf=0P2>SXh20:2PX0X0
b>3H102a/K440;>c/`@0]KFe102YZJT40;Rh^0@0[jn_1@2RXZ840;Fe]@@0/[:b102YZJT40;>c/`@0
ZJVY102OWil40:6QX@@0XZ:R1@2KVi/20<SPf0@0`L71102][Jd40:^[Z`@0c<c<102m_Kd50<G5a@@0
/K6a102b/[840:^[Z`@0/;2`102PX:040:NWY`@0X:2P1@2RXZ8409nOW`@0Vi^K2@38h=P80:n_[`P0
Zj^[2@2g]kL80;2`/0P0[jn_202][Jd909^KV`P0WYjN0P38h=P80;^k^`P0`l?32@34a<@80;Rh^0P0
_;bl202/[:`909fMW@P0Y:BT2@38h=P@0:n_[a40][Jf402XZ:PA09ZJVP80b>3H4@31`L4@0<S8b140
]KFe402RXZ890<SPf240/K6a8@2VYZH20<SPf240aLG58@2b/[890<SPf480Z:RX0P38h=Q20;Fe]Ah0
b>3H000M0<SPf080WinO0P2CTi<20<71`@80[Zj^0P2/[:`20<;2`P80WIfM0P2_[jl20;Rh^080bLW9
0P2h^;P209RHV080P8200P2^[Zh20;jn_P80]kNg0`2ZZZX20<[:bP80^KVi0P2?Shl20::RXP80`/;2
0P2;Rh/209ZJVP80Vi^K0P2JVYX20:6QX@80W9bL0P2>SXh2092@T080R8R80P2FUYH30<SPf080]KFe
0P3<c<`20:RXZ080^KVi102][Jd20=7Ad@80d];B0P3Jf]X20:RXZ080jNWY0P2VYZH20<g=c@80XJ6Q
0P2m_Kd20;:b/P<0ZJVY0P2ZZZX20:>SX`80XZ:R0P2UYJD209JFUP80[jn_0P2b/[8208^;R`80TI6A
0P2OWil20;no_`80YZJV0P2=SHd208j>SP80X:2P2P38h=P40;6a/@@0/k>c102e]KD40:VYZ@@0^;Rh
102_[jl50::RXP@0]KFe102b/[840:VYZ@@0/k>c102YZJT409nOW`@0XJ6Q102RXZ8509^KV`80b>3H
1031`L440:f][@@0Zj^[103<c<`40;fm_@D0aLG5102a/K440;:b/P@0Zj^[102`/;040:2PX0@0YjNW
102PX:050::RXP@0WinO102KVi/90<SPf0P0[jn_202[Zj/90;Ng]`P0/;2`202_[jl80:f][@T0Vi^K
202NWYh20<SPf0P0^k^k2033`l<90<C4a0P0^;Rh202l_;`80:b/[0T0WIfM202TY:@90<SPf100[jn_
4@2f][H@0:RXZ140VYZJ0P38h=PA0<71`A00b<S84@2e]KD@0::RXPT0b>3H8@2a/K4Q0:JVYP80b>3H
8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2XZ:P20<?3``80c<c<0P2B
TY820;Vi^@80/k>c0P2WYjL20:BTY080aLG50P2ZZZX20;Ng]`80Zj^[0P2:RXX20;Bd]080S8b<0P31
`L430:RXZ080X:2P0P2a/K4209:BTP80WYjN0P3?cll20;^k^`80Xj>S0P2/[:`209ZJVP80WIfM0P2S
Xj<20<?3``80T92@0P2VYZH20:>SX`<0b>3H0P2k^k/20=GEe@80_;bl0P2PX:0208n?S`80a/K60P2/
[:`20<c<c080_Kfm0P2b/[820;bl_080ZJVY0P2QXJ420;bl_080VYZJ0P2a/K430;bl_080ZZZZ0P2m
_Kd20:>SX`80WIfM0P2HV9P20:VYZ@80Vi^K0P30`<0208J6QP80SHf=0P2FUYH20:FUY@80X:2P0P2F
UYH20:f][@X0b>3H102a/K440;>c/`@0]KFe102YZJT40;Rh^0@0[jn_1@2RXZ840;Fe]@@0/[:b102Y
ZJT40;>c/`@0ZJVY102OWil40:6QX@@0XZ:R1@2KVi/20<SPf0@0`L71102][Jd40:^[Z`@0c<c<102m
_Kd50<G5a@@0/K6a102b/[840:^[Z`@0/;2`102PX:040:NWY`@0X:2P1@2RXZ8409nOW`@0Vi^K2@38
h=P80:n_[`P0Zj^[2@2g]kL80;2`/0P0[jn_202][Jd909^KV`P0WYjN0P38h=P80;^k^`P0`l?32@34
a<@80;Rh^0P0_;bl202/[:`909fMW@P0Y:BT2@38h=P@0:n_[a40][Jf402XZ:PA09ZJVP80b>3H4@31
`L4@0<S8b140]KFe402RXZ890<SPf240/K6a8@2VYZH20<SPf240aLG58@2b/[890<SPf480Z:RX0P38
h=Q20;Fe]Ah0b>3H000M0<SPf080Z:RX0P33`l<20<c<c080TY:B0P2i^KT20;>c/`80YjNW0P2TY:@2
0<G5a@80ZZZZ0P2g]kL20:^[Z`80RXZ:0P2d];@208b<S080`L710`2XZ:P20:2PX080/K6a0P2BTY82
09jNWP80clo?0P2k^k/20:>SX`80[:b/0P2JVYX209fMW@80Xj>S0P33`l<2092@T080YZJV0P2SXj<3
0<SPf080^k^k0P3EeMD20;bl_080X:2P0P2?Shl20<K6aP80[:b/0P3<c<`20;fm_@80/[:b0P2l_;`2
0:VYZ@80XJ6Q0P2l_;`209ZJVP80/K6a0`2l_;`20:ZZZP80_Kfm0P2SXj<209fMW@80V9RH0P2YZJT2
09^KV`80`<300P26QXH208f=S@80UYJF0P2UYJD20:2PX080UYJF0P2][Jd:0<SPf0@0[jn_102ZZZX4
09ZJVP@0];Bd102h^;P40<30`0D0b<S8102FUYH40:>SX`@0_Kfm102d];@40:2PX0@0UIFE202DU9@5
0:FUY@80b>3H102b/[840<;2`P@0YZJV103IfMT40<30`0D0dm?C1031`L440;jn_P@0emOG102c/k<4
0;bl_0@0YZJV102EUID509fMW@@0Z:RX102ZZZX90<SPf0P0[jn_202[Zj/90;Ng]`P0/;2`202_[jl8
0:f][@T0Vi^K202NWYh20<SPf0P0^k^k2033`l<90<C4a0P0^;Rh202l_;`80:b/[0T0WIfM202TY:@9
0<SPf100[jn_4@2f][H@0:RXZ140VYZJ0P38h=PA0<71`A00b<S84@2e]KD@0::RXPT0b>3H8@2a/K4Q
0:JVYP80b>3H8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2n_[h20;Fe
]@80/k>c0P2RXZ8209BDU080TY:B0P34a<@20;Jf]P80XZ:R0P3;bl/209:BTP80f][J0P3Hf=P20:n_
[`80YZJV0P2KVi/309BDU080Y:BT0P2XZ:P20>3Ph080_;bl0P3<c<`20:f][@80VYZJ0P2=SHd20:JV
YP80T92@0P2HV9P209JFUP80SXj>0P2FUYH20;:b/P<0b>3H0P2k^k/2092@T080]KFe0P3:b/X409jN
WP80Z:RX0P2d];@20;Vi^@80[jn_0P2k^k/20<71`@80YjNW0P3Bd]820<g=c@80aLG50`37alL20?gm
o@80b/[:0P2][Jd20:j^[P80`L710P2h^;P20:FUY@80UYJF0P2CTi<20:VYZ@80W9bL0P2QXJ420;>c
/`80[Zj^0P2a/K4:0<SPf0@0[jn_102ZZZX409ZJVP@0];Bd102h^;P40<30`0D0b<S8102FUYH40:>S
X`@0_Kfm102d];@40:2PX0@0UIFE202DU9@50:FUY@80b>3H102b/[840<;2`P@0YZJV103IfMT40<30
`0D0dm?C1031`L440;jn_P@0emOG102c/k<40;bl_0@0YZJV102EUID509fMW@@0Z:RX102ZZZX90<SP
f0P0[jn_202[Zj/90;Ng]`P0/;2`202_[jl80:f][@T0Vi^K202NWYh20<SPf0P0^k^k2033`l<90<C4
a0P0^;Rh202l_;`80:b/[0T0WIfM202TY:@90<SPf100[jn_4@2f][H@0:RXZ140VYZJ0P38h=PA0<71
`A00b<S84@2e]KD@0::RXPT0b>3H8@2a/K4Q0:JVYP80b>3H8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SP
f480]KFe7P38h=P001d0b>3H0P2n_[h20;Fe]@80/k>c0P2RXZ8209BDU080TY:B0P34a<@20;Jf]P80
XZ:R0P3;bl/209:BTP80f][J0P3Hf=P20:n_[`80YZJV0P2KVi/309BDU080Y:BT0P2XZ:P20>3Ph080
_;bl0P3<c<`20:f][@80VYZJ0P2=SHd20:JVYP80T92@0P2HV9P209JFUP80SXj>0P2FUYH20;:b/P<0
b>3H0P2k^k/2092@T080]KFe0P3:b/X409jNWP80Z:RX0P2d];@20;Vi^@80[jn_0P2k^k/20<71`@80
YjNW0P3Bd]820<g=c@80aLG50`37alL20?gmo@80b/[:0P2][Jd20:j^[P80`L710P2h^;P20:FUY@80
UYJF0P2CTi<20:VYZ@80W9bL0P2QXJ420;>c/`80[Zj^0P2a/K4:0<SPf0@0[jn_102ZZZX409ZJVP@0
];Bd102h^;P40<30`0D0b<S8102FUYH40:>SX`@0_Kfm102d];@40:2PX0@0UIFE202DU9@50:FUY@80
b>3H102b/[840<;2`P@0YZJV103IfMT40<30`0D0dm?C1031`L440;jn_P@0emOG102c/k<40;bl_0@0
YZJV102EUID509fMW@@0Z:RX102ZZZX90<SPf0P0[jn_202[Zj/90;Ng]`P0/;2`202_[jl80:f][@T0
Vi^K202NWYh20<SPf0P0^k^k2033`l<90<C4a0P0^;Rh202l_;`80:b/[0T0WIfM202TY:@90<SPf100
[jn_4@2f][H@0:RXZ140VYZJ0P38h=PA0<71`A00b<S84@2e]KD@0::RXPT0b>3H8@2a/K4Q0:JVYP80
b>3H8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe7P38h=P001d0b>3H0P2UYJD20:f][@80/k>c
0P2FUYH20:^[Z`80UiNG0P2LW9`20<?3``80^k^k0P3:b/X20<o?c`80a/K60P3fm_H209BDU080Q8B4
0P2?Shl30:FUY@80Z:RX0P2/[:`20;Rh^080P8200P2o_kl208^;R`80U9BD0P2;Rh/409>CT`80UYJF
0P2CTi<209bLW080];Bd0P2GUiL30<SPf080WYjN0P2o_kl20>_[j`80UIFE0P2CTi<20;Fe]@80`<30
0P3oool20>WYj@80Y:BT0P3Hf=P20?Gem@80ZZZZ0P3MgMd20;jn_P80`/;20`2h^;P20=7Ad@80Zj^[
0P2e]KD20:NWY`80b<S80P2>SXh20;2`/080Ti>C0P2IVIT209:BTP80YZJV0P2CTi<20;Fe]@80/;2`
0P2RXZ8:0<SPf0@0[jn_102ZZZX409ZJVP@0];Bd102h^;P40<30`0D0b<S8102FUYH40:>SX`@0_Kfm
102d];@40:2PX0@0UIFE202DU9@50:FUY@80b>3H102b/[840<;2`P@0YZJV103IfMT40<30`0D0dm?C
1031`L440;jn_P@0emOG102c/k<40;bl_0@0YZJV102EUID509fMW@@0Z:RX102ZZZX90<SPf0P0[jn_
202[Zj/90;Ng]`P0/;2`202_[jl80:f][@T0Vi^K202NWYh20<SPf0P0^k^k2033`l<90<C4a0P0^;Rh
202l_;`80:b/[0T0WIfM202TY:@90<SPf100[jn_4@2f][H@0:RXZ140VYZJ0P38h=PA0<71`A00b<S8
4@2e]KD@0::RXPT0b>3H8@2a/K4Q0:JVYP80b>3H8@35aLDQ0;:b/PT0b>3H@P2XZ:P20<SPf480]KFe
7P38h=P001d0b>3H0P2UYJD20:f][@80/k>c0P2FUYH20:^[Z`80UiNG0P2LW9`20<?3``80^k^k0P3:
b/X20<o?c`80a/K60P3fm_H209BDU080Q8B40P2?Shl30:FUY@80Z:RX0P2/[:`20;Rh^080P8200P2o
_kl208^;R`80U9BD0P2;Rh/409>CT`80UYJF0P2CTi<209bLW080];Bd0P2GUiL30<SPf080WYjN0P2o
_kl20>_[j`80UIFE0P2CTi<20;Fe]@80`<300P3oool20>WYj@80Y:BT0P3Hf=P20?Gem@80ZZZZ0P3M
gMd20;jn_P80`/;20`2h^;P20=7Ad@80Zj^[0P2e]KD20:NWY`80b<S80P2>SXh20;2`/080Ti>C0P2I
VIT209:BTP80YZJV0P2CTi<20;Fe]@80/;2`0P2RXZ;o0<SPf?l0b>3Hk038h=P00?l0b>3Ho`38h=So
0<SPf8l0b>3H003o0<SPf?l0b>3Ho`38h=R?0<SPf000o`38h=So0<SPf?l0b>3HS`38h=P001d0b>3H
@@20P8030<SPf080]KFe0P31`L420<G5a@80UIFE0P2PX:0208n?S`80Vi^K0P2;Rh/208f=S@80V9RH
0P2TY:@209BDU080X:2P0P2@T90209fMW@80R8R80`27QhL408>3P`80RHV90P2?Shl209:BTP80QXJ6
0P2DU9@209VIV@80Rh^;0P2ATI4208j>SP80Shn?0P2FUYH408n?S`X0b>3H@P20P8020<SPf0@0[:b/
102c/k<40:JVYP@0Zj^[102WYjL50:2PX0@0UiNG102KVi/408J6QP@0RXZ:102?Shl408b<S0@0T92@
1@2?Shl409:BTP@0SXj>2@38h=Q20820P080b>3H202h^;P80;Bd]0T0X:2P202GUiL8092@T0P0TY:B
2@2@T90809>CT`T0b>3H@P20P8020<SPf140/K6a402KVi/A092@T100UIFE2@38h=Q20820P080b>3H
8@2SXj<Q09>CT`T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080]KFe0P31
`L420<G5a@80UIFE0P2PX:0208n?S`80Vi^K0P2;Rh/208f=S@80V9RH0P2TY:@209BDU080X:2P0P2@
T90209fMW@80R8R80`27QhL408>3P`80RHV90P2?Shl209:BTP80QXJ60P2DU9@209VIV@80Rh^;0P2A
TI4208j>SP80Shn?0P2FUYH408n?S`X0b>3H@P20P8020<SPf0@0[:b/102c/k<40:JVYP@0Zj^[102W
YjL50:2PX0@0UiNG102KVi/408J6QP@0RXZ:102?Shl408b<S0@0T92@1@2?Shl409:BTP@0SXj>2@38
h=Q20820P080b>3H202h^;P80;Bd]0T0X:2P202GUiL8092@T0P0TY:B2@2@T90809>CT`T0b>3H@P20
P8020<SPf140/K6a402KVi/A092@T100UIFE2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20
P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080Vi^K0P2^[Zh20;Ng]`80][Jf0P2RXZ82
09VIV@80V9RH0P2][Jd20;:b/P80Zj^[0P2OWil20:j^[P80UiNG0P2ATI4209:BTP80U9BD0`2:RXX2
08J6QP80U9BD0P24Q8@208Z:RP80S8b<0P28R8P208V9R@80SXj>0P2ATI4208>3P`80U9BD0P29RHT2
09NGU`80Ti>C0P28R8P:0<SPf480P8200P38h=P40:b/[0@0/k>c102VYZH40:^[Z`@0YjNW1@2PX:04
09NGU`@0Vi^K1026QXH408Z:RP@0Shn?102<S8`4092@T0D0Shn?102BTY8408j>SPT0b>3H@P20P802
0<SPf0P0^;Rh202d];@90:2PX0P0UiNG202@T90809:BTPT0T92@202CTi<90<SPf480P8200P38h=PA
0;6a/A00Vi^K4@2@T90@09FEU@T0b>3H@P20P8020<SPf240Xj>S8@2CTi<90<SPf480P8200P38h=Q2
0:6QXAh0b>3H000M0<SPf440P8200`38h=P209^KV`80[Zj^0P2g]kL20;Jf]P80XZ:R0P2IVIT209RH
V080[Jf]0P2b/[820:^[Z`80WinO0P2^[Zh209NGU`80TI6A0P2BTY8209BDU0<0RXZ:0P26QXH209BD
U080Q8B40P2:RXX208b<S080R8R80P29RHT208j>SP80TI6A0P23Ph<209BDU080RHV90P2GUiL209>C
T`80R8R82P38h=Q20820P080b>3H102/[:`40;>c/`@0YZJV102[Zj/40:NWY`D0X:2P102GUiL409^K
V`@0QXJ6102:RXX408n?S`@0S8b<102@T90508n?S`@0TY:B102>SXh90<SPf480P8200P38h=P80;Rh
^0P0];Bd2@2PX:0809NGU`P0T92@202BTY89092@T0P0Ti>C2@38h=Q20820P080b>3H4@2a/K4@09^K
Va40T92@402EUID90<SPf480P8200P38h=PQ0:>SXb40Ti>C2@38h=Q20820P080b>3H@P2QXJ4N0<SP
f0007@38h=Q10820P0<0b>3H0P3YjNT209jNWP80Xj>S0P2l_;`20:n_[`80WinO0P2`/;0209NGU`80
S8b<0P26QXH2096AT@80UIFE0P2:RXX208j>SP80RXZ:0P2ATI430:6QX@80Ti>C102>SXh209bLW080
R8R80P25QHD209>CT`80Vi^K102;Rh/209FEU@80SHf=0P2;Rh/209>CT`80Rh^;2P38h=Q20820P080
b>3H102n_[h40<K6aP@0[jn_102e]KD40:2PX0T0UIFE102FUYH409FEU@@0TI6A102JVYX4092@T0@0
Shn?2@2BTY8409ZJVPT0b>3H@P20P8020<SPf0P0^;Rh202d];@90:2PX0P0UiNG202@T90809:BTPT0
T92@202CTi<90<SPf480P8200P38h=PA0;6a/A00Vi^K4@2@T90@09FEU@T0b>3H@P20P8020<SPf240
Xj>S8@2CTi<90<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P20>WYj@80WYjN
0P2SXj<20;bl_080[jn_0P2OWil20;2`/080UiNG0P2<S8`208J6QP80TI6A0P2EUID208Z:RP80SXj>
0P2:RXX2096AT@<0XJ6Q0P2CTi<408j>SP80W9bL0P28R8P208F5Q@80Ti>C0P2KVi/408^;R`80UIFE
0P2=SHd208^;R`80Ti>C0P2;Rh/:0<SPf480P8200P38h=P40;jn_P@0a/K6102_[jl40;Fe]@@0X:2P
2@2EUID409JFUP@0UIFE102ATI4409ZJVP@0T92@102?Shl909:BTP@0VYZJ2@38h=Q20820P080b>3H
202h^;P80;Bd]0T0X:2P202GUiL8092@T0P0TY:B2@2@T90809>CT`T0b>3H@P20P8020<SPf140/K6a
402KVi/A092@T100UIFE2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SPf480XJ6Q
7P38h=P001d0b>3H@@20P8030<SPf080_[jn0P2ZZZX20;Jf]P80n?Sh0P34a<@20:RXZ080g=cL0P2P
X:02096AT@80^[Zj0P2CTi<409bLW080SHf=0P2TY:@209BDU0<0SHf=0P2>SXh209^KV`80T92@0P2X
Z:P209ZJVP80U9BD0P2EUID208V9R@80Shn?0P2GUiL208j>SP80Vi^K0P2DU9@209RHV080YjNW2P38
h=Q20820P080b>3H102n_[h40<K6aP@0[jn_102e]KD40:2PX0T0UIFE102FUYH409FEU@@0TI6A102J
VYX4092@T0@0Shn?2@2BTY8409ZJVPT0b>3H@P20P8020<SPf0P0^;Rh202d];@90:2PX0P0UiNG202@
T90809:BTPT0T92@202CTi<90<SPf480P8200P38h=PA0;6a/A00Vi^K4@2@T90@09FEU@T0b>3H@P20
P8020<SPf240Xj>S8@2CTi<90<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P2
0;jn_P80ZZZZ0P2f][H20?Shn080a<C40P2XZ:P20=cLg080X:2P0P2ATI420;Zj^P80Ti>C102LW9`2
08f=S@80Y:BT0P2DU9@308f=S@80SXj>0P2KVi/2092@T080Z:RX0P2JVYX209BDU080UIFE0P29RHT2
08n?S`80UiNG0P2>SXh209^KV`80U9BD0P2HV9P20:NWY`X0b>3H@P20P8020<SPf0@0_[jn1036a/H4
0:n_[`@0]KFe102PX:0909FEU@@0UYJF102EUID4096AT@@0VYZJ102@T90408n?S`T0TY:B102JVYX9
0<SPf480P8200P38h=P80;Rh^0P0];Bd2@2PX:0809NGU`P0T92@202BTY89092@T0P0Ti>C2@38h=Q2
0820P080b>3H4@2a/K4@09^KVa40T92@402EUID90<SPf480P8200P38h=PQ0:>SXb40Ti>C2@38h=Q2
0820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P36a/H20:2PX080/;2`0P2KVi/20:>S
X`80Y:BT0P2JVYX208B4Q080Vi^K0P2ZZZX209>CT`80QHF50P29RHT209>CT`80RHV90P27QhL308Z:
RP80T92@0P2IVIT208F5Q@80UiNG0P29RHT2092@T080QXJ60P29RHT208n?S`80Ti>C0P2:RXX209FE
U@80^;Rh0P37alL20:JVYPX0b>3H@P20P8020<SPf0@0Z:RX102^[Zh40:b/[0@0Y:BT102MWId509jN
WP@0Shn?102:RXX408b<S0@0T92@102BTY8408b<S0@0TI6A1@2EUID40:RXZ0@0YjNW2@38h=Q20820
P080b>3H202WYjL80:j^[PT0XJ6Q202@T90808n?S`P0SXj>2@2BTY8809fMW@T0b>3H@P20P8020<SP
f140/K6a402KVi/A092@T100UIFE2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SP
f480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080a/K60P2PX:020;2`/080Vi^K0P2SXj<20:BTY080
VYZJ0P24Q8@209^KV`80ZZZZ0P2CTi<208F5Q@80RHV90P2CTi<208V9R@80QhN70`2:RXX2092@T080
VIVI0P25QHD209NGU`80RHV90P2@T90208J6QP80RHV90P2?Shl209>CT`80RXZ:0P2EUID20;Rh^080
alO70P2VYZH:0<SPf480P8200P38h=P40:RXZ0@0[Zj^102/[:`40:BTY0@0WIfM1@2NWYh408n?S`@0
RXZ:102<S8`4092@T0@0TY:B102<S8`4096AT@D0UIFE102XZ:P40:NWY`T0b>3H@P20P8020<SPf0P0
YjNW202^[Zh90:6QX@P0T92@202?Shl808j>SPT0TY:B202MWId90<SPf480P8200P38h=PA0;6a/A00
Vi^K4@2@T90@09FEU@T0b>3H@P20P8020<SPf240Xj>S8@2CTi<90<SPf480P8200P38h=Q20:6QXAh0
b>3H000M0<SPf440P8200`38h=P209fMW@80W9bL0P2PX:020<?3``80YZJV0P3:b/X20;6a/@80/;2`
0P2;Rh/2096AT@80UYJF0P2OWil4092@T080QhN70P2=SHd308V9R@80S8b<0P2?Shl209FEU@80VIVI
102;Rh/208J6QP80RHV9102EUID209nOW`80UYJF0P2][Jd208J6QP80UYJF2P38h=Q20820P080b>3H
102XZ:P40:j^[P@0[:b/102TY:@409fMW@D0WYjN102?Shl408Z:RP@0S8b<102@T90409:BTP@0S8b<
102ATI4509FEU@@0Z:RX102WYjL90<SPf480P8200P38h=P80:NWY`P0[Zj^2@2QXJ48092@T0P0Shn?
202>SXh909:BTPP0WIfM2@38h=Q20820P080b>3H4@2a/K4@09^KVa40T92@402EUID90<SPf480P820
0P38h=PQ0:>SXb40Ti>C2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P2M
WId209bLW080X:2P0P33`l<20:JVYP80b/[:0P2a/K420;2`/080Rh^;0P2ATI4209JFUP80WinO102@
T90208N7Q`80SHf=0`29RHT208b<S080Shn?0P2EUID209VIV@@0Rh^;0P26QXH208V9R@@0UIFE0P2O
Wil209JFUP80[Jf]0P26QXH209JFUPX0b>3H@P20P8020<SPf0@0Z:RX102^[Zh40:b/[0@0Y:BT102M
WId509jNWP@0Shn?102:RXX408b<S0@0T92@102BTY8408b<S0@0TI6A1@2EUID40:RXZ0@0YjNW2@38
h=Q20820P080b>3H202WYjL80:j^[PT0XJ6Q202@T90808n?S`P0SXj>2@2BTY8809fMW@T0b>3H@P20
P8020<SPf140/K6a402KVi/A092@T100UIFE2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20
P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080WinO0P27QhL20;Vi^@80[jn_0P34a<@2
0;Rh^080/k>c0P2NWYh20<30`080[Jf]0P2KVi/209fMW@80Xj>S102>SXh208Z:RP<0Q8B40P2IVIT2
09RHV080T92@102>SXh209>CT`80T92@0P2DU9@209RHV080VIVI0P2CTi<208j>SP80TI6A0P2FUYH2
08j>SPX0b>3H@P20P8020<SPf0@0X:2P102[Zj/80;>c/`@0Z:RX1@2KVi/409JFUPP0Shn?102BTY84
08f=S@@0SXj>102ATI49092@T0@0SHf=2@38h=Q20820P080b>3H202WYjL80:j^[PT0XJ6Q202@T908
08n?S`P0SXj>2@2BTY8809fMW@T0b>3H@P20P8020<SPf140/K6a402KVi/A092@T100UIFE2@38h=Q2
0820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SP
f080WinO0P27QhL20;Vi^@80[jn_0P34a<@20;Rh^080/k>c0P2NWYh20<30`080[Jf]0P2KVi/209fM
W@80Xj>S102>SXh208Z:RP<0Q8B40P2IVIT209RHV080T92@102>SXh209>CT`80T92@0P2DU9@209RH
V080VIVI0P2CTi<208j>SP80TI6A0P2FUYH208j>SPX0b>3H@P20P8020<SPf0@0X:2P102[Zj/80;>c
/`@0Z:RX1@2KVi/409JFUPP0Shn?102BTY8408f=S@@0SXj>102ATI49092@T0@0SHf=2@38h=Q20820
P080b>3H202WYjL80:j^[PT0XJ6Q202@T90808n?S`P0SXj>2@2BTY8809fMW@T0b>3H@P20P8020<SP
f140/K6a402KVi/A092@T100UIFE2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SP
f480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080UIFE0P2h^;P20:b/[080TY:B0P2JVYX20;Fe]@80
^;Rh0P2`/;0209ZJVP80WinO0P2PX:0208^;R`80VIVI0P2=SHd209NGU`80Rh^;0`27QhL208n?S`80
UYJF0P24Q8@208V9R@@0S8b<0P2@T902096AT@@0R8R80P2?Shl2096AT@80TY:B0P2:RXX208R8R0X0
b>3H@P20P8020<SPf0@0X:2P102[Zj/80;>c/`@0Z:RX1@2KVi/409JFUPP0Shn?102BTY8408f=S@@0
SXj>102ATI49092@T0@0SHf=2@38h=Q20820P080b>3H202WYjL80:j^[PT0XJ6Q202@T90808n?S`P0
SXj>2@2BTY8809fMW@T0b>3H@P20P8020<SPf140/K6a402KVi/A092@T100UIFE2@38h=Q20820P080
b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080UIFE
0P2h^;P20:b/[080TY:B0P2JVYX20;Fe]@80^;Rh0P2`/;0209ZJVP80WinO0P2PX:0208^;R`80VIVI
0P2=SHd209NGU`80Rh^;0`27QhL208n?S`80UYJF0P24Q8@208V9R@@0S8b<0P2@T902096AT@@0R8R8
0P2?Shl2096AT@80TY:B0P2:RXX208R8R0X0b>3H@P20P8020<SPf0@0X:2P102[Zj/80;>c/`@0Z:RX
1@2KVi/409JFUPP0Shn?102BTY8408f=S@@0SXj>102ATI49092@T0@0SHf=2@38h=Q20820P080b>3H
202WYjL80:j^[PT0XJ6Q202@T90808n?S`P0SXj>2@2BTY8809fMW@T0b>3H@P20P8020<SPf140/K6a
402KVi/A092@T100UIFE2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SPf480XJ6Q
7P38h=P001d0b>3H@@20P8030<SPf080Vi^K0P2n_[h208j>SP80UiNG0P2NWYh209:BTP80UYJF0P34
a<@20:ZZZP80TY:B0P2=SHd209RHV0@0UYJF0P2BTY8208j>SP<0SHf=0P2DU9@2092@T080WYjN0P2=
SHd209JFUP80X:2P0P2DU9@209ZJVP80SHf=0P2CTi<209FEU@80SXj>0P2;Rh/2092@T080R8R82P38
h=Q20820P080b>3H102][Jd409NGU`@0TY:B202RXZ8509bLW0@0Ti>C202DU9@409>CT`@0SXj>102F
UYH4092@T0D0UIFE202?Shl90<SPf480P8200P38h=P809nOW`P0Vi^K2@2SXj<809>CT`P0TY:B202C
Ti<909:BTPP0Shn?2@38h=Q20820P080b>3H4@2MWId@09jNWQ40Ti>C402BTY890<SPf480P8200P38
h=PQ0:>SXb40Ti>C2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P2KVi/2
0;jn_P80SXj>0P2GUiL209jNWP80TY:B0P2FUYH20<C4a080ZZZZ0P2BTY8208f=S@80V9RH102FUYH2
09:BTP80SXj>0`2=SHd209BDU080T92@0P2NWYh208f=S@80UYJF0P2PX:0209BDU080VYZJ0P2=SHd2
09>CT`80UIFE0P2>SXh208^;R`80T92@0P28R8P:0<SPf480P8200P38h=P40:f][@@0UiNG102BTY88
0::RXPD0W9bL102CTi<809BDU0@0Ti>C102>SXh409JFUP@0T92@1@2EUID808n?S`T0b>3H@P20P802
0<SPf0P0WinO202KVi/90:>SX`P0Ti>C202BTY8809>CT`T0TY:B202?Shl90<SPf480P8200P38h=PA
09fMWA00WYjN4@2CTi<@09:BTPT0b>3H@P20P8020<SPf240Xj>S8@2CTi<90<SPf480P8200P38h=Q2
0:6QXAh0b>3H000M0<SPf440P8200`38h=P20;no_`80UIFE0P2?Shl209nOW`80SHf=0P2;Rh/208>3
P`80UYJF0P2UYJD20:VYZ@80W9bL0P2ZZZX209>CT`80TI6A0P2DU9@209fMW@<0WinO0P2FUYH208V9
R@80U9BD0P22PX8208V9R@80TI6A0P2BTY8208f=S@80R8R80P2LW9`208b<S080TI6A0P2:RXX209FE
U@80TY:B2P38h=Q20820P080b>3H102][Jd409NGU`@0TY:B202RXZ8509bLW0@0Ti>C202DU9@409>C
T`@0SXj>102FUYH4092@T0D0UIFE202?Shl90<SPf480P8200P38h=P809nOW`P0Vi^K2@2SXj<809>C
T`P0TY:B202CTi<909:BTPP0Shn?2@38h=Q20820P080b>3H4@2MWId@09jNWQ40Ti>C402BTY890<SP
f480P8200P38h=PQ0:>SXb40Ti>C2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0
b>3H0P2o_kl209FEU@80Shn?0P2OWil208f=S@80Rh^;0P23Ph<209JFUP80YJFU0P2YZJT209bLW080
ZZZZ0P2CTi<2096AT@80U9BD0P2MWId309nOW`80UYJF0P29RHT209BDU080PX:20P29RHT2096AT@80
TY:B0P2=SHd208R8R080W9bL0P2<S8`2096AT@80RXZ:0P2EUID209:BTPX0b>3H@P20P8020<SPf0@0
[Jf]102GUiL409:BTPP0XZ:R1@2LW9`409>CT`P0U9BD102CTi<408j>SP@0UYJF102@T90509FEU@P0
Shn?2@38h=Q20820P080b>3H202OWil809^KV`T0Xj>S202CTi<809:BTPP0Ti>C2@2BTY8808n?S`T0
b>3H@P20P8020<SPf140WIfM402NWYhA09>CTa00TY:B2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0
b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080T92@0P2YZJT209FEU@80UYJF
0P2BTY820:NWY`80TY:B0P2<S8`20;Vi^@80]KFe0P2<S8`209RHV080Vi^K0P2DU9@20:2PX080SHf=
0`2ATI4208j>SP80Ti>C0P2KVi/2092@T080VYZJ0P2LW9`208V9R@80VYZJ0P2=SHd208b<S080RXZ:
0P25QHD209:BTP80Shn?0P2=SHd:0<SPf480P8200P38h=P409fMW@@0VYZJ102RXZ8409>CT`@0]KFe
1@2@T904096AT@@0Ti>C102=SHd809>CT`@0UYJF102BTY8508j>SP@0TI6A102>SXh90<SPf480P820
0P38h=P809nOW`P0Vi^K2@2SXj<809>CT`P0TY:B202CTi<909:BTPP0Shn?2@38h=Q20820P080b>3H
4@2MWId@09jNWQ40Ti>C402BTY890<SPf480P8200P38h=PQ0:>SXb40Ti>C2@38h=Q20820P080b>3H
@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P2@T9020:VYZ@80UIFE0P2FUYH209:BTP80YjNW0P2B
TY8208b<S080^KVi0P2e]KD208b<S080V9RH0P2KVi/209BDU080X:2P0P2=SHd3096AT@80SXj>0P2C
Ti<209^KV`80T92@0P2JVYX209bLW080RHV90P2JVYX208f=S@80S8b<0P2:RXX208F5Q@80TY:B0P2?
Shl208f=S@X0b>3H@P20P8020<SPf0@0WIfM102JVYX40::RXP@0Ti>C102e]KD5092@T0@0TI6A102C
Ti<408f=S@P0Ti>C102FUYH409:BTPD0SXj>102ATI4408j>SPT0b>3H@P20P8020<SPf0P0WinO202K
Vi/90:>SX`P0Ti>C202BTY8809>CT`T0TY:B202?Shl90<SPf480P8200P38h=PA09fMWA00WYjN4@2C
Ti<@09:BTPT0b>3H@P20P8020<SPf240Xj>S8@2CTi<90<SPf480P8200P38h=Q20:6QXAh0b>3H000M
0<SPf440P8200`38h=P208n?S`80SHf=0P2>SXh20:6QX@80W9bL0P2b/[8209bLW080Ti>C0P2GUiL2
0=CDe080TI6A0P2<S8`208J6QP80SXj>0P2<S8`209JFUP<0SHf=0P2:RXX209FEU@H0TI6A0P2MWId2
09JFUP80QhN7102>SXh209JFUP80VIVI102BTY8208N7Q`X0b>3H@P20P8020<SPf0@0WIfM102JVYX4
0::RXP@0Ti>C102e]KD5092@T0@0TI6A102CTi<408f=S@P0Ti>C102FUYH409:BTPD0SXj>102ATI44
08j>SPT0b>3H@P20P8020<SPf0P0WinO202KVi/90:>SX`P0Ti>C202BTY8809>CT`T0TY:B202?Shl9
0<SPf480P8200P38h=PA09fMWA00WYjN4@2CTi<@09:BTPT0b>3H@P20P8020<SPf240Xj>S8@2CTi<9
0<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P208n?S`80SHf=0P2>SXh20:6Q
X@80W9bL0P2b/[8209bLW080Ti>C0P2GUiL20=CDe080TI6A0P2<S8`208J6QP80SXj>0P2<S8`209JF
UP<0SHf=0P2:RXX209FEU@H0TI6A0P2MWId209JFUP80QhN7102>SXh209JFUP80VIVI102BTY8208N7
Q`X0b>3H@P20P8020<SPf0@0WIfM102JVYX40::RXP@0Ti>C102e]KD5092@T0@0TI6A102CTi<408f=
S@P0Ti>C102FUYH409:BTPD0SXj>102ATI4408j>SPT0b>3H@P20P8020<SPf0P0WinO202KVi/90:>S
X`P0Ti>C202BTY8809>CT`T0TY:B202?Shl90<SPf480P8200P38h=PA09fMWA00WYjN4@2CTi<@09:B
TPT0b>3H@P20P8020<SPf240Xj>S8@2CTi<90<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440
P8200`38h=P20:f][@80V9RH0P2EUID20::RXP80WIfM0P2OWil209VIV@80TI6A0P24Q8@20:^[Z`80
Z:RX0P2SXj<208f=S@80VYZJ0P23Ph<208n?S`<0TI6A0P23Ph<208J6QP80SHf=0P2:RXX20::RXP80
T92@0P2FUYH208Z:RP@0Ti>C0P2BTY8209NGU`80QHF50P2IVIT208b<S0X0b>3H@P20P8020<SPf0@0
Y:BT102FUYH40:2PX0@0UIFE102FUYH50;Ng]`@0U9BD102<S8`408f=S@@0RXZ:102CTi<409:BTP@0
UIFE1@2CTi<4092@T0@0U9BD2@38h=Q20820P080b>3H202QXJ4809VIV@T0YjNW202KVi/8092@T140
UYJF202ATI490<SPf480P8200P38h=PA09fMWA00WYjN4@2CTi<@09:BTPT0b>3H@P20P8020<SPf240
Xj>S8@2CTi<90<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P20:f][@80V9RH
0P2EUID20::RXP80WIfM0P2OWil209VIV@80TI6A0P24Q8@20:^[Z`80Z:RX0P2SXj<208f=S@80VYZJ
0P23Ph<208n?S`<0TI6A0P23Ph<208J6QP80SHf=0P2:RXX20::RXP80T92@0P2FUYH208Z:RP@0Ti>C
0P2BTY8209NGU`80QHF50P2IVIT208b<S0X0b>3H@P20P8020<SPf0@0Y:BT102FUYH40:2PX0@0UIFE
102FUYH50;Ng]`@0U9BD102<S8`408f=S@@0RXZ:102CTi<409:BTP@0UIFE1@2CTi<4092@T0@0U9BD
2@38h=Q20820P080b>3H202QXJ4809VIV@T0YjNW202KVi/8092@T140UYJF202ATI490<SPf480P820
0P38h=PA09fMWA00WYjN4@2CTi<@09:BTPT0b>3H@P20P8020<SPf240Xj>S8@2CTi<90<SPf480P820
0P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P20:VYZ@80VIVI102CTi<209ZJVP80YjNW0P2R
XZ8208R8R080TY:B0P29RHT20=_Kf`80`L710P2ATI4209^KV`80QXJ60P2;Rh/309:BTP80Shn?1P2=
SHd208B4Q080QhN70P2@T902096AT@80X:2P0P2@T90209BDU080S8b<0P2FUYH209fMW@80Shn?2P38
h=Q20820P080b>3H102TY:@409JFUP@0X:2P102EUID409JFUPD0]kNg102DU9@408b<S0@0SHf=102:
RXX409>CT`@0TY:B102EUID509>CT`@0T92@102DU9@90<SPf480P8200P38h=P80:6QX@P0VIVI2@2W
YjL809^KV`P0T92@4@2FUYH8096AT@T0b>3H@P20P8020<SPf140WIfM402NWYhA09>CTa00TY:B2@38
h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P803
0<SPf080ZJVY0P2IVIT409>CT`80VYZJ0P2WYjL20::RXP80R8R80P2BTY8208V9R@80fm_K0P31`L42
096AT@80Vi^K0P26QXH208^;R`<0TY:B0P2?Shl608f=S@80Q8B40P27QhL2092@T080TI6A0P2PX:02
092@T080U9BD0P2<S8`209JFUP80WIfM0P2?Shl:0<SPf480P8200P38h=P40:BTY0@0UYJF102PX:04
09FEU@@0UYJF1@2g]kL409BDU0@0S8b<102=SHd408Z:RP@0Ti>C102BTY8409FEU@D0Ti>C102@T904
09BDU0T0b>3H@P20P8020<SPf0P0XJ6Q202IVIT90:NWY`P0Vi^K202@T90A09JFUPP0TI6A2@38h=Q2
0820P080b>3H4@2MWId@09jNWQ40Ti>C402BTY890<SPf480P8200P38h=PQ0:>SXb40Ti>C2@38h=Q2
0820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P2GUiL20::RXP80YZJV102GUiL2096A
T@80WIfM0P2BTY8209jNWP80Vi^K0P2GUiL20>;RhP80alO70P2BTY8209NGU`80RXZ:0`2FUYH209RH
V080SHf=0P2>SXh208V9R@@0V9RH0P2KVi/208^;R`80UIFE0P28R8P208n?S`80VYZJ1P2<S8`:0<SP
f480P8200P38h=P40:NWY`@0XJ6Q102GUiL809FEU@D0[jn_102^[Zh4092@T0@0UIFE102@T90409JF
UP@0Vi^K102HV9P9096AT@@0Shn?2@38h=Q20820P080b>3H202QXJ4809VIV@T0YjNW202KVi/8092@
T140UYJF202ATI490<SPf480P8200P38h=PA09fMWA00WYjN4@2CTi<@09:BTPT0b>3H@P20P8020<SP
f240Xj>S8@2CTi<90<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P209NGU`80
XZ:R0P2VYZH409NGU`80TI6A0P2MWId209:BTP80WYjN0P2KVi/209NGU`80h^;R0P37alL209:BTP80
UiNG0P2:RXX309JFUP80V9RH0P2=SHd208j>SP80RHV9102HV9P209^KV`80Rh^;0P2EUID208R8R080
Shn?0P2JVYX608b<S0X0b>3H@P20P8020<SPf0@0YjNW102QXJ4409NGU`P0UIFE1@2_[jl40:j^[P@0
T92@102EUID4092@T0@0UYJF102KVi/409RHV0T0TI6A102?Shl90<SPf480P8200P38h=P80:6QX@P0
VIVI2@2WYjL809^KV`P0T92@4@2FUYH8096AT@T0b>3H@P20P8020<SPf140WIfM402NWYhA09>CTa00
TY:B2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H
@@20P8030<SPf080_;bl0P2OWil20:j^[P80Xj>S0P2KVi/209nOW`80Ti>C0P2JVYX208b<S080T92@
0P2EUID208n?S`80`/;20P2FUYH4096AT@<0W9bL0P2?Shl208f=S@80VYZJ0P2:RXX20:6QX@80Rh^;
0P26QXH209bLW080UiNG0P2CTi<209bLW080V9RH1026QXH209RHV0X0b>3H@P20P8020<SPf0@0YjNW
102QXJ4409NGU`P0UIFE1@2_[jl40:j^[P@0T92@102EUID4092@T0@0UYJF102KVi/409RHV0T0TI6A
102?Shl90<SPf480P8200P38h=P80:6QX@P0VIVI2@2WYjL809^KV`P0T92@4@2FUYH8096AT@T0b>3H
@P20P8020<SPf140WIfM402NWYhA09>CTa00TY:B2@38h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H
@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080_;bl0P2OWil20:j^[P80Xj>S0P2K
Vi/209nOW`80Ti>C0P2JVYX208b<S080T92@0P2EUID208n?S`80`/;20P2FUYH4096AT@<0W9bL0P2?
Shl208f=S@80VYZJ0P2:RXX20:6QX@80Rh^;0P26QXH209bLW080UiNG0P2CTi<209bLW080V9RH1026
QXH209RHV0X0b>3H@P20P8020<SPf0@0YjNW102QXJ4409NGU`P0UIFE1@2_[jl40:j^[P@0T92@102E
UID4092@T0@0UYJF102KVi/409RHV0T0TI6A102?Shl90<SPf480P8200P38h=P80:6QX@P0VIVI2@2W
YjL809^KV`P0T92@4@2FUYH8096AT@T0b>3H@P20P8020<SPf140WIfM402NWYhA09>CTa00TY:B2@38
h=Q20820P080b>3H8@2SXj<Q09>CT`T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P803
0<SPf080_;bl0P2OWil20:j^[P80Xj>S0P2KVi/209nOW`80Ti>C0P2JVYX208b<S080T92@0P2EUID2
08n?S`80`/;20P2FUYH4096AT@<0W9bL0P2?Shl208f=S@80VYZJ0P2:RXX20:6QX@80Rh^;0P26QXH2
09bLW080UiNG0P2CTi<209bLW080V9RH1026QXH209RHV0X0b>3H@P20P8020<SPf0@0YZJV102RXZ84
0:VYZ@@0X:2P102UYJD50:RXZ0@0VIVI102VYZH4096AT@@0Ti>C102VYZH40;Ng]`@0][Jf1@2MWId4
09NGU`@0Vi^K2@38h=Q20820P080b>3H202RXZ880:BTY0T0[Zj^202NWYh80:BTY0P0/k>c2@2XZ:P8
09JFUPT0b>3H@P20P8020<SPf140YjNW402TY:@A0:ZZZQ00XJ6Q2@38h=Q20820P080b>3H8@2XZ:PQ
0:6QX@T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080YZJV0P2FUYH209^K
V`80VYZJ0P2e]KD20:6QX@80Xj>S0P2NWYh20:^[Z`80V9RH0P27QhL4092@T080YJFU0P2TY:@2092@
T0<0SHf=0P2?Shl2092@T080Rh^;0P2KVi/20:JVYP80_;bl0P2^[Zh208V9R@80a<C40P2SXj<208^;
R`80UIFE0P2NWYh20:RXZ080TI6A2P38h=Q20820P080b>3H102VYZH40::RXP@0ZJVY102PX:040:FU
Y@D0Z:RX102IVIT40:JVYP@0TI6A102CTi<40:JVYP@0]kNg102f][H509fMW@@0UiNG102KVi/90<SP
f480P8200P38h=P80::RXPP0Y:BT2@2^[Zh809jNWPP0Y:BT202c/k<90:RXZ0P0UYJF2@38h=Q20820
P080b>3H4@2WYjL@0:BTY140ZZZZ402QXJ490<SPf480P8200P38h=PQ0:RXZ240XJ6Q2@38h=Q20820
P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P2VYZH209JFUP80Vi^K0P2JVYX20;Fe]@80
XJ6Q0P2SXj<209jNWP80Zj^[0P2HV9P208N7Q`@0T92@0P2UYJD20:BTY080T92@0`2=SHd208n?S`80
T92@0P2;Rh/209^KV`80YZJV0P2l_;`20:j^[P80RHV90P34a<@20:>SX`80Rh^;0P2EUID209jNWP80
Z:RX0P2ATI4:0<SPf480P8200P38h=P40:JVYP@0XZ:R102YZJT40:2PX0@0YJFU1@2XZ:P409VIV@@0
YZJV102ATI4409>CT`@0YZJV102g]kL40;Jf]PD0WIfM102GUiL409^KV`T0b>3H@P20P8020<SPf0P0
XZ:R202TY:@90:j^[PP0WYjN202TY:@80;>c/`T0Z:RX202FUYH90<SPf480P8200P38h=PA0:NWYa00
Y:BT4@2ZZZX@0:6QX@T0b>3H@P20P8020<SPf240Z:RX8@2QXJ490<SPf480P8200P38h=Q20:6QXAh0
b>3H000M0<SPf440P8200`38h=P20;^k^`80W9bL0P2a/K420:VYZ@80^[Zj0P2MWId209BDU080YjNW
0P2JVYX209^KV`80clo?0P2SXj<208R8R080S8b<0P2f][H20;>c/`<0SXj>0P2DU9@208^;R`80Xj>S
0P2f][H208N7Q`80cLg=0P2VYZH20:^[Z`80clo?0P2`/;0208b<S080TI6A0P2GUiL209JFUP80U9BD
2P38h=Q20820P080b>3H102VYZH40::RXP@0ZJVY102PX:040:FUY@D0Z:RX102IVIT40:JVYP@0TI6A
102CTi<40:JVYP@0]kNg102f][H509fMW@@0UiNG102KVi/90<SPf480P8200P38h=P80::RXPP0Y:BT
2@2^[Zh809jNWPP0Y:BT202c/k<90:RXZ0P0UYJF2@38h=Q20820P080b>3H4@2WYjL@0:BTY140ZZZZ
402QXJ490<SPf480P8200P38h=PQ0:RXZ240XJ6Q2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38
h=Q10820P0<0b>3H0P2k^k/209bLW080/K6a0P2YZJT20;Zj^P80WIfM0P2DU9@20:NWY`80VYZJ0P2K
Vi/20<o?c`80Xj>S0P28R8P208b<S080][Jf0P2c/k<308j>SP80U9BD0P2;Rh/20:>SX`80][Jf0P27
QhL20<g=c@80YZJV0P2[Zj/20<o?c`80/;2`0P2<S8`2096AT@80UiNG0P2FUYH209BDU0X0b>3H@P20
P8020<SPf0@0WinO102RXZ8409^KV`@0[Jf]102l_;`50:f][@@0V9RH102PX:040;:b/P@0[jn_102a
/K440;jn_P@0WinO1@2[Zj/409NGU`@0Shn?2@38h=Q20820P080b>3H202RXZ880:BTY0T0[Zj^202N
WYh80:BTY0P0/k>c2@2XZ:P809JFUPT0b>3H@P20P8020<SPf140YjNW402TY:@A0:ZZZQ00XJ6Q2@38
h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P803
0<SPf080VYZJ0P2GUiL20;Jf]P80YJFU0P2ATI4208b<S080ZJVY0P2ATI440=3@d080/;2`0P3De=@2
0:ZZZP80SHf=0P2ATI4209JFUP<0W9bL0P2QXJ420;Fe]@80/K6a0P2WYjL20<[:bP80];Bd0P3De=@2
08b<S080SHf=0P26QXH208j>SP80Ti>C0P2QXJ4208N7Q`80TI6A2P38h=Q20820P080b>3H102OWil4
0::RXP@0Vi^K102][Jd40;bl_0D0[Jf]102HV9P40:2PX0@0/[:b102_[jl40;6a/@@0_[jn102OWil5
0:^[Z`@0UiNG102?Shl90<SPf480P8200P38h=P80::RXPP0Y:BT2@2^[Zh809jNWPP0Y:BT202c/k<9
0:RXZ0P0UYJF2@38h=Q20820P080b>3H4@2WYjL@0:BTY140ZZZZ402QXJ490<SPf480P8200P38h=PQ
0:RXZ240XJ6Q2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P2JVYX209NG
U`80][Jf0P2UYJD2096AT@80S8b<0P2YZJT2096AT@@0d=3@0P2`/;020=CDe080ZZZZ0P2=SHd2096A
T@80UYJF0`2LW9`20:6QX@80]KFe0P2a/K420:NWY`80b/[:0P2d];@20=CDe080S8b<0P2=SHd208J6
QP80SXj>0P2CTi<20:6QX@80QhN70P2ATI4:0<SPf480P8200P38h=P409nOW`@0XZ:R102KVi/40:f]
[@@0_;bl1@2][Jd409RHV0@0X:2P102b/[840:n_[`@0/K6a102n_[h409nOW`D0Zj^[102GUiL408n?
S`T0b>3H@P20P8020<SPf0P0XZ:R202TY:@90:j^[PP0WYjN202TY:@80;>c/`T0Z:RX202FUYH90<SP
f480P8200P38h=PA0:NWYa00Y:BT4@2ZZZX@0:6QX@T0b>3H@P20P8020<SPf240Z:RX8@2QXJ490<SP
f480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P20;2`/080UiNG0P2PX:0208n?S`80
Xj>S0P2][Jd20:2PX080bl_;0P2j^[X209fMW@80QHF5102FUYH2092@T080R8R80P30`<030>CTi080
RHV90P2k^k/20:6QX@80];Bd0P2^[Zh209BDU080gmoO0P2TY:@20;Fe]@80^k^k0P34a<@208R8R080
VYZJ0P25QHD208j>SPX0b>3H@P20P8020<SPf0@0WinO102RXZ8409^KV`@0[Jf]102l_;`50:f][@@0
V9RH102PX:040;:b/P@0[jn_102a/K440;jn_P@0WinO1@2[Zj/409NGU`@0Shn?2@38h=Q20820P080
b>3H202RXZ880:BTY0T0[Zj^202NWYh80:BTY0P0/k>c2@2XZ:P809JFUPT0b>3H@P20P8020<SPf140
YjNW402TY:@A0:ZZZQ00XJ6Q2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SPf480
XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080/;2`0P2GUiL20:2PX080Shn?0P2SXj<20:f][@80X:2P
0P3;bl/20;Zj^P80WIfM0P25QHD409JFUP80T92@0P28R8P20<30`0<0i>CT0P29RHT20;^k^`80XJ6Q
0P2d];@20:j^[P80U9BD0P3Ogml20:BTY080]KFe0P2k^k/20<C4a080R8R80P2JVYX208F5Q@80SXj>
2P38h=Q20820P080b>3H102_[jl40:6QX@@0`l?3102YZJT40:>SX`D0WYjN102EUID4096AT@@0^[Zj
102PX:040:RXZ0@0ZJVY102a/K450:FUY@P0Ti>C2@38h=Q20820P080b>3H202YZJT80:f][@T0ZZZZ
202FUYH80:JVYQ40ZJVY202IVIT90<SPf480P8200P38h=PA0:NWYa00Y:BT4@2ZZZX@0:6QX@T0b>3H
@P20P8020<SPf240Z:RX8@2QXJ490<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38
h=P20<K6aP80[jn_0P2OWil208Z:RP80YZJV0P3Xj>P20<K6aP80UYJF0P2VYZH209ZJVP80YZJV102F
UYH208N7Q`80PX:20P2BTY830=;BdP80bl_;0P2RXZ8208^;R`80Xj>S0P2BTY8209JFUP80Rh^;0P32
`/8208R8R080VYZJ0P2m_Kd209VIV@80Q8B40P2IVIT208Z:RPX0b>3H@P20P8020<SPf0@0[jn_102Q
XJ440<?3``@0ZJVY102SXj<509jNWP@0UIFE102ATI440;Zj^P@0X:2P102XZ:P40:VYZ@@0/K6a1@2U
YJD809>CT`T0b>3H@P20P8020<SPf0P0ZJVY202][Jd90:ZZZPP0UYJF202VYZHA0:VYZ@P0VIVI2@38
h=Q20820P080b>3H4@2WYjL@0:BTY140ZZZZ402QXJ490<SPf480P8200P38h=PQ0:RXZ240XJ6Q2@38
h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P36a/H20:n_[`80WinO0P2:RXX2
0:JVYP80j>SX0P36a/H209JFUP80YZJV0P2JVYX20:JVYP@0UYJF0P27QhL208:2PP80TY:B0`3Bd]82
0<_;b`80XZ:R0P2;Rh/20:>SX`80TY:B0P2FUYH208^;R`80`/;20P28R8P209ZJVP80_Kfm0P2IVIT2
08B4Q080VIVI0P2:RXX:0<SPf480P8200P38h=P40:n_[`@0XJ6Q1033`l<40:VYZ@@0Xj>S1@2NWYh4
09FEU@@0TI6A102j^[X40:2PX0@0Z:RX102YZJT40;6a/@D0YJFU202CTi<90<SPf480P8200P38h=P8
0:VYZ@P0[Jf]2@2ZZZX809JFUPP0YZJV4@2YZJT809VIV@T0b>3H@P20P8020<SPf140YjNW402TY:@A
0:ZZZQ00XJ6Q2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SPf480XJ6Q7P38h=P0
01d0b>3H@@20P8030<SPf0@0ZJVY0P2PX:020;2`/080a<C40P2l_;`20:f][@80TY:B0P2JVYX20;Vi
^@80YJFU0P2KVi/20:JVYP80S8b<0P2LW9`208b<S0<0TI6A0P2c/k<20:ZZZP80Y:BT0P31`L4209>C
T`80/k>c0P2o_kl20;jn_P80^KVi0P2OWil208f=S@80TI6A102CTi<209BDU0X0b>3H@P20P8020<SP
f0@0[jn_102QXJ440<?3``@0ZJVY102SXj<509jNWP@0UIFE102ATI440;Zj^P@0X:2P102XZ:P40:VY
Z@@0/K6a1@2UYJD809>CT`T0b>3H@P20P8020<SPf0P0ZJVY202][Jd90:ZZZPP0UYJF202VYZHA0:VY
Z@P0VIVI2@38h=Q20820P080b>3H4@2WYjL@0:BTY140ZZZZ402QXJ490<SPf480P8200P38h=PQ0:RX
Z240XJ6Q2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H102YZJT20:2PX080
/;2`0P34a<@20;bl_080[Jf]0P2BTY8209ZJVP80^KVi0P2UYJD209^KV`80YZJV0P2<S8`209bLW080
S8b<0`2ATI420;>c/`80ZZZZ0P2TY:@20<71`@80Ti>C0P2c/k<20;no_`80_[jn0P2i^KT209nOW`80
SHf=0P2ATI4409>CT`80U9BD2P38h=Q20820P080b>3H102OWil40;Bd]0@0YJFU102QXJ440;fm_@D0
YJFU202HV9P4096AT@@0Y:BT102_[jl40:JVYP@0XJ6Q1@2_[jl40:VYZ@@0TI6A2@38h=Q20820P080
b>3H202YZJT80:f][@T0ZZZZ202FUYH80:JVYQ40ZJVY202IVIT90<SPf480P8200P38h=PA0:NWYa00
Y:BT4@2ZZZX@0:6QX@T0b>3H@P20P8020<SPf240Z:RX8@2QXJ490<SPf480P8200P38h=Q20:6QXAh0
b>3H000M0<SPf440P8200`38h=P209bLW080TI6A0P2LW9`20:JVYP80Z:RX0P2UYJD208Z:RP80Xj>S
0P2RXZ820=_Kf`80U9BD0P2OWil20:NWY`80V9RH0P2LW9`2092@T0<0TI6A0P2>SXh20:b/[080^KVi
0P2CTi<208b<S080^[Zj0P2JVYX409FEU@80][Jf0P2JVYX20<K6aP80R8R80P29RHT209RHV0X0b>3H
@P20P8020<SPf0@0WinO102d];@40:FUY@@0XJ6Q102m_Kd50:FUY@P0V9RH102ATI440:BTY0@0[jn_
102VYZH40:6QX@D0[jn_102YZJT4096AT@T0b>3H@P20P8020<SPf0P0ZJVY202][Jd90:ZZZPP0UYJF
202VYZHA0:VYZ@P0VIVI2@38h=Q20820P080b>3H4@2WYjL@0:BTY140ZZZZ402QXJ490<SPf480P820
0P38h=PQ0:RXZ240XJ6Q2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H0P2L
W9`2096AT@80W9bL0P2VYZH20:RXZ080YJFU0P2:RXX20:>SX`80XZ:R0P3Kfm/209BDU080WinO0P2W
YjL209RHV080W9bL0P2@T903096AT@80SXj>0P2/[:`20;Vi^@80Ti>C0P2<S8`20;Zj^P80VYZJ102E
UID20;Jf]P80VYZJ0P36a/H208R8R080RHV90P2HV9P:0<SPf480P8200P38h=P409nOW`@0];Bd102U
YJD40:6QX@@0_Kfm1@2UYJD809RHV0@0TI6A102TY:@40:n_[`@0YZJV102QXJ450:n_[`@0ZJVY102A
TI490<SPf480P8200P38h=P80:VYZ@P0[Jf]2@2ZZZX809JFUPP0YZJV4@2YZJT809VIV@T0b>3H@P20
P8020<SPf140YjNW402TY:@A0:ZZZQ00XJ6Q2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20
P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080SXj>0P2j^[X20<c<c080b/[:0P2SXj<2
08f=S@80Rh^;0P2d];@20=GEe@80Ti>C0P2WYjL20:FUY@80SHf=0P2EUID20:RXZ080S8b<0`2EUID2
08j>SP80T92@0P2BTY820=kNgP80WYjN0P2EUID20:b/[080XZ:R0P2_[jl20<o?c`80UiNG0P2][Jd2
08V9R@80Ti>C0P2BTY8:0<SPf480P8200P38h=P409nOW`@0];Bd102UYJD40:6QX@@0_Kfm1@2UYJD8
09RHV0@0TI6A102TY:@40:n_[`@0YZJV102QXJ450:n_[`@0ZJVY102ATI490<SPf480P8200P38h=P8
0:VYZ@P0[Jf]2@2ZZZX809JFUPP0YZJV4@2YZJT809VIV@T0b>3H@P20P8020<SPf140YjNW402TY:@A
0:ZZZQ00XJ6Q2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SPf480XJ6Q7P38h=P0
01d0b>3H@@20P8030<SPf080SXj>0P2j^[X20<c<c080b/[:0P2SXj<208f=S@80Rh^;0P2d];@20=GE
e@80Ti>C0P2WYjL20:FUY@80SHf=0P2EUID20:RXZ080S8b<0`2EUID208j>SP80T92@0P2BTY820=kN
gP80WYjN0P2EUID20:b/[080XZ:R0P2_[jl20<o?c`80UiNG0P2][Jd208V9R@80Ti>C0P2BTY8:0<SP
f480P8200P38h=P40:JVYP@0/k>c102VYZH40:BTY0@0YJFU1@2c/k<40;:b/P@0YZJV102DU9@408j>
SP@0WIfM102^[Zh409jNWPD0TI6A202>SXh90<SPf480P8200P38h=P80:f][@P0YZJV2@2ZZZX80:RX
Z0P0T92@202MWId909NGU`P0SXj>2@38h=Q20820P080b>3H4@2[Zj/@0:ZZZQ40WinO402FUYH90<SP
f480P8200P38h=PQ0:RXZ240XJ6Q2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0
b>3H0P2IVIT20;2`/080b/[:0P2[Zj/208j>SP80TY:B0P2?Shl20;Zj^P80XZ:R0P2UYJD2092@T080
_;bl0P2ZZZX20:f][@80WYjN0P2MWId309:BTP80RHV90P2?Shl209>CT`80UiNG0P2][Jd20;6a/@80
Y:BT0P2DU9@20:^[Z`80S8b<0P2HV9P208V9R@80UYJF0P2BTY8209>CT`X0b>3H@P20P8020<SPf0@0
YZJV102c/k<40:JVYP@0Y:BT102UYJD50;>c/`@0/[:b102VYZH409BDU0@0SXj>102MWId40:j^[P@0
WYjN1@2ATI4808j>SPT0b>3H@P20P8020<SPf0P0[Jf]202VYZH90:ZZZPP0Z:RX202@T90809fMW@T0
UiNG202>SXh90<SPf480P8200P38h=PA0:^[Za00ZZZZ4@2OWil@09JFUPT0b>3H@P20P8020<SPf240
Z:RX8@2QXJ490<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P209VIV@80/;2`
0P3:b/X20:^[Z`80SXj>0P2BTY8208n?S`80^[Zj0P2RXZ820:FUY@80T92@0P2l_;`20:ZZZP80[Jf]
0P2NWYh209fMW@<0TY:B0P29RHT208n?S`80Ti>C0P2GUiL20:f][@80/K6a0P2TY:@209BDU080Zj^[
0P2<S8`209RHV080RHV90P2FUYH209:BTP80Ti>C2P38h=Q20820P080b>3H102VYZH40;>c/`@0YZJV
102TY:@40:FUY@D0/k>c102b/[840:JVYP@0U9BD102>SXh409fMW@@0[Zj^102NWYh5096AT@P0SXj>
2@38h=Q20820P080b>3H202][Jd80:JVYPT0ZZZZ202XZ:P8092@T0P0WIfM2@2GUiL808j>SPT0b>3H
@P20P8020<SPf140Zj^[402ZZZXA09nOWa00UYJF2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H
@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080[Zj^0P2PX:020:BTY080_;bl0P36
a/H209FEU@80UYJF0P2[Zj/209BDU080YZJV0P2g]kL20<?3``80][Jf0P3;bl/209FEU@80^KVi0`2O
Wil209BDU080T92@0P29RHT2096AT@80WIfM0P2o_kl20;6a/@80YZJV0P2GUiL2096AT@80T92@0P2;
Rh/408b<S080QhN72P38h=Q20820P080b>3H102VYZH40;>c/`@0YZJV102TY:@40:FUY@D0/k>c102b
/[840:JVYP@0U9BD102>SXh409fMW@@0[Zj^102NWYh5096AT@P0SXj>2@38h=Q20820P080b>3H202]
[Jd80:JVYPT0ZZZZ202XZ:P8092@T0P0WIfM2@2GUiL808j>SPT0b>3H@P20P8020<SPf140Zj^[402Z
ZZXA09nOWa00UYJF2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SPf480XJ6Q7P38
h=P001d0b>3H@@20P8030<SPf080[Zj^0P2PX:020:BTY080_;bl0P36a/H209FEU@80UYJF0P2[Zj/2
09BDU080YZJV0P2g]kL20<?3``80][Jf0P3;bl/209FEU@80^KVi0`2OWil209BDU080T92@0P29RHT2
096AT@80WIfM0P2o_kl20;6a/@80YZJV0P2GUiL2096AT@80T92@0P2;Rh/408b<S080QhN72P38h=Q2
0820P080b>3H102][Jd40;:b/P@0]KFe102GUiL409^KV`D0]KFe202UYJD4092@T0@0Shn?102DU9@4
08j>SP@0WIfM1@2>SXh808n?S`T0b>3H@P20P8020<SPf0P0[Jf]202VYZH90:ZZZPP0Z:RX202@T908
09fMW@T0UiNG202>SXh90<SPf480P8200P38h=PA0:^[Za00ZZZZ4@2OWil@09JFUPT0b>3H@P20P802
0<SPf240Z:RX8@2QXJ490<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P20=_K
f`80WIfM0P2a/K420=OGe`80]KFe0P2o_kl209RHV080UIFE0P2:RXX20::RXP80[Zj^0P2DU9@2096A
T@80XJ6Q0P2a/K4209jNWP<0RXZ:0P29RHT208f=S@80SXj>0P2FUYH209BDU080UiNG0P23Ph<209bL
W080[:b/0P27QhL208j>SP@0Rh^;1029RHT:0<SPf480P8200P38h=P40:f][@@0/[:b102e]KD409NG
U`@0Vi^K1@2e]KD80:FUY@@0T92@102?Shl409BDU0@0SXj>102MWId508j>SPP0Shn?2@38h=Q20820
P080b>3H202][Jd80:JVYPT0ZZZZ202XZ:P8092@T0P0WIfM2@2GUiL808j>SPT0b>3H@P20P8020<SP
f140Zj^[402ZZZXA09nOWa00UYJF2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SP
f480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080fm_K0P2MWId20;6a/@80emOG0P2e]KD20;no_`80
V9RH0P2EUID208Z:RP80XZ:R0P2^[Zh209BDU080TI6A0P2QXJ420;6a/@80WYjN0`2:RXX208V9R@80
SHf=0P2>SXh209JFUP80U9BD0P2GUiL208>3P`80W9bL0P2/[:`208N7Q`80SXj>102;Rh/408V9R@X0
b>3H@P20P8020<SPf0@0[Jf]102b/[840;Fe]@@0UiNG102KVi/50;Fe]@P0YJFU102@T90408n?S`@0
U9BD102>SXh409fMW@D0SXj>202?Shl90<SPf480P8200P38h=P80:f][@P0YZJV2@2ZZZX80:RXZ0P0
T92@202MWId909NGU`P0SXj>2@38h=Q20820P080b>3H4@2[Zj/@0:ZZZQ40WinO402FUYH90<SPf480
P8200P38h=PQ0:RXZ240XJ6Q2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820P0<0b>3H
0P2ATI4209JFUP80Rh^;0P2][Jd20<W9b@80YJFU0P2ATI4209ZJVP80SHf=0P2[Zj/20:>SX`80gMgM
0P2b/[8209fMW@80UIFE0P2ZZZX3092@T080Vi^K0P27QhL209FEU@80SHf=0P25QHD208n?S`80QXJ6
0P28R8P20:FUY@80T92@0P2;Rh/208b<S0@0Ti>C0P2DU9@:0<SPf480P8200P38h=P40:f][@@0/[:b
102e]KD409NGU`@0Vi^K1@2e]KD80:FUY@@0T92@102?Shl409BDU0@0SXj>102MWId508j>SPP0Shn?
2@38h=Q20820P080b>3H202][Jd80:JVYPT0ZZZZ202XZ:P8092@T0P0WIfM2@2GUiL808j>SPT0b>3H
@P20P8020<SPf140Zj^[402ZZZXA09nOWa00UYJF2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H
@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080TI6A0P2FUYH208^;R`80[Jf]0P39
bLT20:FUY@80TI6A0P2JVYX208f=S@80Zj^[0P2SXj<20=gMg@80/[:b0P2MWId209FEU@80ZZZZ0`2@
T90209^KV`80QhN70P2EUID208f=S@80QHF50P2?Shl208J6QP80R8R80P2UYJD2092@T080Rh^;0P2<
S8`409>CT`80U9BD2P38h=Q20820P080b>3H102`/;0409NGU`@0WinO102LW9`409ZJVPD0[Jf]102^
[Zh40;>c/`@0Zj^[102XZ:P409FEU@@0WinO102DU9@5092@T0@0Z:RX102>SXh90<SPf480P8200P38
h=P80;2`/0P0Z:RX2@2UYJD80;2`/0P0YjNW202SXj<909BDU0P0Vi^K2@38h=Q20820P080b>3H4@2[
Zj/@0:ZZZQ40WinO402FUYH90<SPf480P8200P38h=PQ0:RXZ240XJ6Q2@38h=Q20820P080b>3H@P2Q
XJ4N0<SPf0007@38h=Q10820P0<0b>3H0P38b<P209:BTP80Xj>S0P2EUID20;>c/`80Z:RX0P2[Zj/2
09fMW@80TI6A0P2OWil20<?3``80ZJVY0P2i^KT20:f][@80UiNG0P3>c/h309VIV@80ZJVY0P2o_kl2
08R8R080WinO0P27QhL20:FUY@80W9bL0P27QhL209>CT`80T92@0P2DU9@209jNWP80SHf=0P2ATI42
08R8R0X0b>3H@P20P8020<SPf0@0/;2`102GUiL409nOW`@0W9bL102JVYX50:f][@@0[Zj^102c/k<4
0:^[Z`@0Z:RX102EUID409nOW`@0U9BD1@2@T9040:RXZ0@0SXj>2@38h=Q20820P080b>3H202`/;08
0:RXZ0T0YJFU202`/;080:NWY`P0Xj>S2@2DU9@809^KV`T0b>3H@P20P8020<SPf140Zj^[402ZZZXA
09nOWa00UYJF2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SPf480XJ6Q7P38h=P0
01d0b>3H@@20P8030<SPf080b<S80P2BTY820:>SX`80UIFE0P2c/k<20:RXZ080Zj^[0P2MWId2096A
T@80WinO0P33`l<20:VYZ@80^KVi0P2][Jd209NGU`80c/k>0`2IVIT20:VYZ@80_kno0P28R8P209nO
W`80QhN70P2UYJD209bLW080QhN70P2CTi<2092@T080U9BD0P2NWYh208f=S@80TI6A0P28R8P:0<SP
f480P8200P38h=P40;2`/0@0UiNG102OWil409bLW0@0VYZJ1@2][Jd40:j^[P@0/k>c102[Zj/40:RX
Z0@0UIFE102OWil409BDU0D0T92@102XZ:P408j>SPT0b>3H@P20P8020<SPf0P0/;2`202XZ:P90:FU
Y@P0/;2`202WYjL80:>SX`T0U9BD202KVi/90<SPf480P8200P38h=PA0:^[Za00ZZZZ4@2OWil@09JF
UPT0b>3H@P20P8020<SPf240Z:RX8@2QXJ490<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440
P8200`38h=P209nOW`80Z:RX0P2DU9@209FEU@80UYJF0P2?Shl409JFUP80WYjN0P2CTi<209NGU`80
/k>c0P2TY:@20:VYZ@80^[Zj0P2MWId30<O7a`80ZJVY0P2[Zj/20:b/[080V9RH0P2IVIT20;2`/0@0
TY:B0P2SXj<208N7Q`80U9BD0P3?cll209RHV080Ti>C0P2>SXh:0<SPf480P8200P38h=P40;2`/0@0
UiNG102OWil409bLW0@0VYZJ1@2][Jd40:j^[P@0/k>c102[Zj/40:RXZ0@0UIFE102OWil409BDU0D0
T92@102XZ:P408j>SPT0b>3H@P20P8020<SPf0P0/;2`202XZ:P90:FUY@P0/;2`202WYjL80:>SX`T0
U9BD202KVi/90<SPf480P8200P38h=PA0:^[Za00ZZZZ4@2OWil@09JFUPT0b>3H@P20P8020<SPf240
Z:RX8@2QXJ490<SPf480P8200P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P209nOW`80Z:RX
0P2DU9@209FEU@80UYJF0P2?Shl409JFUP80WYjN0P2CTi<209NGU`80/k>c0P2TY:@20:VYZ@80^[Zj
0P2MWId30<O7a`80ZJVY0P2[Zj/20:b/[080V9RH0P2IVIT20;2`/0@0TY:B0P2SXj<208N7Q`80U9BD
0P3?cll209RHV080Ti>C0P2>SXh:0<SPf480P8200P38h=P40<30`0@0];Bd102/[:`40;Fe]@@0YJFU
1@2VYZH40;>c/`@0ZZZZ102WYjL40:FUY@@0]KFe102KVi/409BDU0D0UYJF102BTY8409jNWPT0b>3H
@P20P8020<SPf0P0/;2`202XZ:P90:FUY@P0/;2`202WYjL80:>SX`T0U9BD202KVi/90<SPf480P820
0P38h=PA0:^[Za00ZZZZ4@2OWil@09JFUPT0b>3H@P20P8020<SPf240Z:RX8@2QXJ490<SPf480P820
0P38h=Q20:6QXAh0b>3H000M0<SPf440P8200`38h=P20;Fe]@80YjNW102OWil20;Jf]P80YJFU0P2X
Z:P20:n_[`80YjNW0P2UYJD209nOW`80X:2P0P2h^;P20<;2`P80/k>c0P2CTi<309NGU`80aLG50P2L
W9`20;Rh^080d=3@0P2l_;`2096AT@80UYJF0P27QhL20:2PX080Shn?0P28R8P2096AT@80SXj>0P2A
TI4209fMW@X0b>3H@P20P8020<SPf0@0`<30102d];@40:b/[0@0]KFe102UYJD50:JVYP@0/k>c102Z
ZZX40:NWY`@0YJFU102e]KD409^KV`@0U9BD1@2FUYH409:BTP@0WYjN2@38h=Q20820P080b>3H202`
/;080:RXZ0T0YJFU202`/;080:NWY`P0Xj>S2@2DU9@809^KV`T0b>3H@P20P8020<SPf140Zj^[402Z
ZZXA09nOWa00UYJF2@38h=Q20820P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SPf480XJ6Q7P38
h=P001d0b>3H@@20P8030<SPf080]KFe0P2WYjL409nOW`80][Jf0P2UYJD20:RXZ080[jn_0P2WYjL2
0:FUY@80WinO0P2PX:020;Rh^080`/;20P2c/k<209>CT`<0UiNG0P35aLD209bLW080^;Rh0P3@d=02
0;bl_080TI6A0P2FUYH208N7Q`80X:2P0P2?Shl208R8R080TI6A0P2>SXh2096AT@80WIfM2P38h=Q2
0820P080b>3H1030`<040;Bd]0@0[:b/102e]KD40:FUY@D0YZJV102c/k<40:ZZZP@0YjNW102UYJD4
0;Fe]@@0Vi^K102DU9@509JFUP@0TY:B102NWYh90<SPf480P8200P38h=P80;2`/0P0Z:RX2@2UYJD8
0;2`/0P0YjNW202SXj<909BDU0P0Vi^K2@38h=Q20820P080b>3H4@2[Zj/@0:ZZZQ40WinO402FUYH9
0<SPf480P8200P38h=PQ0:RXZ240XJ6Q2@38h=Q20820P080b>3H@P2QXJ4N0<SPf0007@38h=Q10820
P0<0b>3H0P35aLD20=GEe@80^k^k0P3Fe]H20;>c/`80WIfM0P34a<@20;fm_@80];Bd0P2@T90209FE
U@80`<300P2n_[h209>CT`80[Zj^0P2c/k<309:BTP80[Jf]0P2UYJD2096AT@80]KFe0P2DU9@20:b/
[080Shn?0P2IVIT208Z:RP80YZJV0P27QhL209VIV@80U9BD0P2QXJ420:JVYPX0b>3H@P20P8020<SP
f0@0`<30102d];@40:b/[0@0]KFe102UYJD50:JVYP@0/k>c102ZZZX40:NWY`@0YJFU102e]KD409^K
V`@0U9BD1@2FUYH409:BTP@0WYjN2@38h=Q20820P080b>3H202`/;080:RXZ0T0YJFU202`/;080:NW
Y`P0Xj>S2@2DU9@809^KV`T0b>3H@P20P8020<SPf140Zj^[402ZZZXA09nOWa00UYJF2@38h=Q20820
P080b>3H8@2XZ:PQ0:6QX@T0b>3H@P20P8020<SPf480XJ6Q7P38h=P001d0b>3H@@20P8030<SPf080
aLG50P3EeMD20;^k^`80e]KF0P2c/k<209fMW@80a<C40P2m_Kd20;Bd]080T92@0P2EUID20<30`080
_[jn0P2CTi<20:j^[P80/k>c0`2BTY820:f][@80YJFU0P2ATI420;Fe]@80U9BD0P2/[:`208n?S`80
VIVI0P2:RXX20:JVYP80QhN70P2IVIT209BDU080XJ6Q0P2VYZKo0<SPf?l0b>3Hk038h=P00?l0b>3H
o`38h=So0<SPf8l0b>3H003o0<SPf?l0b>3Ho`38h=R?0<SPf000o`38h=So0<SPf?l0b>3HS`38h=P0
0?l0b>3Ho`38h=So0<SPf8l0b>3H003o0<SPf?l0b>3Ho`38h=R?0<SPf000o`38h=So0<SPf?l0b>3H
S`38h=P00?l0b>3Ho`38h=So0<SPf8l0b>3H003o0<SPf?l0b>3Ho`38h=R?0<SPf000\
\>"],
  ImageRangeCache->{{{0, 907}, {150.313, 0}} -> {-0.167995, -0.0250052, \
0.00698566, 0.00698566}, {{24, 167.188}, {146.688, 3.5625}} -> {-0.402613, \
-0.103199, 0.0146727, 0.0146727}, {{27.4375, 95.5625}, {143.25, 75.125}} -> \
{-14.3328, -4.28351, 0.493216, 0.493216}, {{95.5625, 163.688}, {143.25, \
75.125}} -> {-47.9331, -4.28351, 0.493216, 0.493216}, {{27.4375, 95.5625}, \
{75.125, 6.9375}} -> {-14.3328, -37.8993, 0.493216, 0.493216}, {{95.5625, \
163.688}, {75.125, 6.9375}} -> {-47.9331, -37.8993, 0.493216, 0.493216}, \
{{167.188, 310.313}, {146.688, 3.5625}} -> {-2.50309, -0.103199, 0.0146727, \
0.0146727}, {{170.563, 238.75}, {143.25, 75.125}} -> {-42.4699, -2.14175, \
0.246608, 0.246608}, {{238.75, 306.875}, {143.25, 75.125}} -> {-59.2777, \
-2.14175, 0.246608, 0.246608}, {{170.563, 238.75}, {75.125, 6.9375}} -> \
{-42.4236, -18.9249, 0.246382, 0.246382}, {{238.75, 306.875}, {75.125, \
6.9375}} -> {-59.2777, -18.9496, 0.246608, 0.246608}, {{310.313, 453.5}, \
{146.688, 3.5625}} -> {-4.60358, -0.103199, 0.0146727, 0.0146727}, {{313.75, \
381.875}, {143.25, 75.125}} -> {-38.8865, -1.07087, 0.123304, 0.123304}, \
{{381.875, 450}, {143.25, 75.125}} -> {-47.2866, -1.07087, 0.123304, \
0.123304}, {{313.75, 381.875}, {75.125, 6.9375}} -> {-38.8865, -9.47478, \
0.123304, 0.123304}, {{381.875, 450}, {75.125, 6.9375}} -> {-47.2866, \
-9.47478, 0.123304, 0.123304}, {{453.5, 596.625}, {146.688, 3.5625}} -> \
{-6.70406, -0.103199, 0.0146727, 0.0146727}, {{456.875, 525.063}, {143.25, \
75.125}} -> {-28.2692, -0.535439, 0.0616521, 0.0616521}, {{525.063, 593.188}, \
{143.25, 75.125}} -> {-32.4712, -0.535439, 0.0616521, 0.0616521}, {{456.875, \
525.063}, {75.125, 6.9375}} -> {-28.2415, -4.73124, 0.0615955, 0.0615955}, \
{{525.063, 593.188}, {75.125, 6.9375}} -> {-32.4712, -4.73741, 0.0616521, \
0.0616521}, {{596.625, 739.75}, {146.688, 3.5625}} -> {-8.80408, -0.103199, \
0.0146727, 0.0146727}, {{600, 668.188}, {143.25, 75.125}} -> {-18.5466, \
-0.267719, 0.030826, 0.030826}, {{668.188, 736.313}, {143.25, 75.125}} -> \
{-20.6476, -0.267719, 0.030826, 0.030826}, {{600, 668.188}, {75.125, 6.9375}} -> \
{-18.5287, -2.36562, 0.0307978, 0.0307978}, {{668.188, 736.313}, {75.125, \
6.9375}} -> {-20.6476, -2.36871, 0.030826, 0.030826}, {{739.75, 882.938}, \
{146.688, 3.5625}} -> {-10.9046, -0.103199, 0.0146727, 0.0146727}, {{743.188, \
811.313}, {143.25, 75.125}} -> {-11.4798, -0.13386, 0.015413, 0.015413}, \
{{811.313, 879.438}, {143.25, 75.125}} -> {-12.5298, -0.13386, 0.015413, \
0.015413}, {{743.188, 811.313}, {75.125, 6.9375}} -> {-11.4798, -1.18435, \
0.015413, 0.015413}, {{811.313, 879.438}, {75.125, 6.9375}} -> {-12.5298, \
-1.18435, 0.015413, 0.015413}}]
}, Open  ]],

Cell["\<\
It seems that the variance map at 16 pixel resolution works best: not too \
much detail, yet not too little of it. Let's now apply variance map at \
resolution 16 for noise reconstruction. We divide the standard deviations by \
2, or else the amount of noise is overestimated. It is important to realize \
that only noise must be reintroduced, but not just noise is lost in \
quantization.\
\>", "Text"],

Cell[BoxData[{
    \(\(res\  = \ 16;\)\), "\[IndentingNewLine]", 
    \(\(vmap\  = \ 
        Map[VarianceMap[#, res] &, 
          Table[{mcomp[\([i, j]\)], qdecomp[\([i, j]\)]}, {i, 1, 2}, {j, 1, 
              2}], {2}];\)\), "\[IndentingNewLine]", 
    \(\(NoiseRectangle[stddev_, dim_] := 
        Partition[RandomArray[NormalDistribution[0.0, stddev/1.5], dim*dim], 
          dim];\)\)}], "Input"],

Cell[BoxData[
    \(\(noiserects\  = \ 
        Map[NoiseRectangle[#, res] &, vmap, {4}];\)\)], "Input"],

Cell[BoxData[{
    \(\(<< LinearAlgebra`MatrixManipulation`;\)\), "\[IndentingNewLine]", 
    \(MyFold[fun_, array_] := 
      Fold[fun, First[array], Rest[array]]\), "\[IndentingNewLine]", 
    \(Merging[array_] := 
      Flatten[Map[MyFold[AppendRows, #] &, array], 1]\)}], "Input"],

Cell[BoxData[
    \(\(noisemap = Map[Merging, noiserects, {2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{Graphics[
              Raster[\((ImgIDWT[Interleave2[qdecomp]] + 128)\)/255], 
              AspectRatio \[Rule] 1], 
            Graphics[Raster[\((sub + 128)\)/255], AspectRatio \[Rule] 1], 
            Graphics[
              Raster[\((ImgIDWT[Interleave2[noisemap + qdecomp]] + 128)\)/
                  255], AspectRatio \[Rule] 1]}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
576883A7BC3329242E262231403F3A35323435323034373533343845504B423D38312C28
28303B6D63635A7C67466060646C7375767A7E7F7F80817F7E7E7F818386888A8A898889
8B8E908D8B8E908D8988898A8C8C8C8C8D8E8F909192929191909091929394918F919492
909498969496999A9B9DA0A3A8B5C3CACFD0D3B3
585F70A1BFA64621292526313B3833373A3733323132343434363B424C48403933302F29
272F3A6C62645C7B614F5D626B6E7174767A7E7E7F8082817F808081838587898A89888A
8C8E8F8D8A8B8C8D8D8A898B8E8D8C8D8E90929393939292939291929496979592939493
9193969695989A9A9B9DA0A3A9B6C4CCD1D0CFBE
5B575A7996B4983F28212A2F332F2C38423A313133312F3135393D4146423D342D2F322B
262F3A6B60666079575A5A6672716F72777A7C7E7F81828281818282828486888989898B
8D8E8E8C8A89888D918D898C908F8D8E909294969695949495949495979A9C9995959594
9293949596999B9A9A9C9FA3A8B6C4CFD4D0C9CA
5C57576A83A6B67C3A1D27282D2D2F363B342D2F33302D303436364D403F39332E30322A
2534407061666079545B5E687171717477797B7D7F80818283838281818488898889898B
8D8D8C8C8B8B8B8E908E8B8D8F8F8F91939495969696969595969797989B9D9A96949392
92959797969798999A9B9DA1A7B4C1CDD4CFC7C9
5E5A5A5F7082C4B6592A2522282D3333322E2A2F332F2B30343330573D3C373431313129
2537487563676077525B63696E71737678797A7D80808082848381807F858A8A8889898B
8C8C8B8B8C8D8E8E8D8E8E8E8E8F9194969696969697989695979999999B9C9A96939191
93979A9895949597999A9B9FA5B1BECAD2CDC6C5
635E59596375A8C4A63A3224262A2F2E2D2C2C3033312E323536354C3F3F3A373331302A
292B4A79676D646B565E676C6F7072777C7B7B7D7F7F808081808081838587888A8A8B8B
8C8C8C8C8C8C8C8C8C8D8F8E8E919497989897979897979797989A9A9A9B9B9997949394
95979795939495949597999CA1ADBAC8D1CBC2C4
65605B575A708AB8CE9633272A2A2B2B2B2D303233333234373A3D3E42413E3934312F29
2B1D4D7C6C70695F59606A6E717171787E7E7C7D7E7F807F7E7E8083868483878B8C8C8C
8C8E8E8D8B8A898B8C8E8F8F909397999A9998999A989697999A9A9B9C9B9A9998969596
9896949393939492909397999DA9B6C5CFC8BFBF
575E60585B7390A7D4B87E47272931302F33373736343435383B3E3D3F3D3A36332D2C39
4B32577171646D5E595F686D707274797D7E7E7D7D8082817F808183858687898C8D8D8D
8D8D8D8C8B8C8D8E8E8F91929497999A9999999A9A99999A9C9D9D9D9C9C9B9997969798
9997949494949391909194979DA6B1BFCAC6C1AF
505B655D5E779992C4CEC86D332D363434383D3B37363536393C3E3D3B383533322F2D27
2C29636B76566F60575C666B6F7377797B7D7F7E7D8082828182828283878B8B8C8C8D8D
8D8C8C8C8C8F92919091929597999A9A999A9A9A9A9B9B9D9F9F9F9E9D9D9D9A97979899
9997959596949291919090959DA3ABB9C4C2C1A0
7358616E5C708989A8C1C8C5542B302F3236393835353536383C3E3C3937363433302F2C
332D646F7C566A5C555B656A6E7376797A7C7E7D7D7E807E7D808383828588898A8B8C8C
8C8D8F8F8E8F90919191929294979A9A9A9A9B9B9B9C9E9FA19F9D9D9E9E9E9B999A9B9A
97969595959492908E8D8E91969CA4B2BEBAB5A3
995D5F795C69757D87B1D0CF9B3F2C262F31343331323436383B3E3B3736363534312F2E
362F647481596558535A656A6E7275787A7B7C7C7C7D7D7B797E83838182848688898A8B
8C8F9191908F8F8F919191909094999A9B9B9B9B9C9D9FA0A19E9C9D9E9E9E9C9B9C9D9A
969595949393928E8B8A8B8C8E939BA9B4AEA5A5
A98B67656A68676E779ABAD8C5823A222B2B2E2D2B2E3133343C413A31323333312D2A28
302E6875805564565159656C7072747678797A7B7C7D7E7D7D7F8181818385878988888A
8C8F9191908F8F9091929394949597999B9B9B9B9C9C9B9D9F9F9E9E9E9D9C9C9C9C9B98
969595939291908C88878787888D929DA59E9495
A9B06D50776A61647086A0CCE0C1532927252A27262A2E31343E443A2E2E30302F292522
2A2D6B757C5364565059666D7273737477787A7B7C7D7F8182807F80828486888A88868A
8E8F90909090909192939597989795999C9B9A9B9D9A989A9E9FA09F9E9C9B9C9C9A9797
96959391908E8C888483838385878B91958D8583
87A497706D6B7071757D8CB0CBCA961A3321262324272D3842484940352F2B2B2C2B2A29
312D65727B615F545059666B6F72737475787B7D7E7D7D7F81828181818486888988878C
919190919192929292929395969696989B99979A9C9B9A9D9F9F9D9E9E9D9B9A99979696
95928E8C8B8885817E808283848587898A837C7A
646C787066738283807F8299B0BCB9583121272324252B3D4D4E49433B3128282B2D3130
372D5F6F796D5A52505A65696C70747475797D7F7F7D7C7D80828483818487888988888E
939290919394959392909092959697999A9896999C9D9EA0A19E9B9D9E9E9C9895959594
928D888685827E7B7A7D818384848484837C7674
4850637277818A8E919397A3AFB7B4A7604C2322262527333E3D3937352F2A2A2C2D302D
332D626E7468544F515B676A6C70747474787D7D7D7D7D7F8082848484868889898B8D90
929190919294969594929194979899999999999A9C9D9FA0A09E9C9D9F9D9A9693949593
9088817E7D7D7D7D7E81848585868685827B7472
33374568888F9099A2AAB1B2B2BBC1B1AB852520272625282C2A292A2C2C2C2D2E2E2E29
2D2C656E70604F4D525C676A6C70747473787C7B7A7C7F808182838486888989898D9191
909091909194969796959396999B9B9A999B9C9C9B9D9F9F9E9D9D9E9F9C989593939492
8D837A77787B7E80818180808082848380797170
27242F4D8E959FA4A9B3BCBBB8BDC1C3B99F3E2720212527282725272A2C2F30302F2E28
2B28606D72604D4D545D6567686C707274777A7B7C7C7D8082828283858788898A8C8F91
91919191939597979696959697999A9B9B9D9E9E9D9E9E9E9E9E9E9F9F9B96959494928F
897F76787C80827C746A6260626A72706C666160
22191F30879AABADADB8C2C0BCBFC1C5B9AC5C371F20282828262526282C303232302E27
2A255C6B73604C4E555C626465696E727577797B7D7D7C8083828182848687898A8B8C90
9392919395979897969797969597999B9D9E9F9F9F9E9D9E9E9E9E9F9F9A94959594918B
857B757B838786796753423F43515E5E5A585656
221A1C275BA9ADB4ABB7C1BDB7BBBFBEB5C0A27B3329292624232324252A2F302F2C2A26
2B2661686A5C4D4E53596062646A707376787A7A7B7D7F808181818386888A8A8A8B8D90
9191909498979596979999989697999B9C9D9E9E9E9E9D9E9E9E9D9F9F9A959493908C87
817A777D8588877D6E5036313745555D62646566
231F1D232EAEABB5A8B3BCB6B0B6BBB8B2AEA29B523F31282221222223282D2D2C292724
2B2A656661574D4C50565D60646C737576797C7A797E82817E808284878A8C8B8A8C8E8F
8F8F90959A979395989A9A9997989A9B9B9C9D9D9D9D9E9E9F9D9C9E9F9A9593918D8983
7D79787F86888784795636313642516271767879
25211C1B218DB0A3AAADB1B0AFB2B5B7B8B5B3C0A2784B342625232222272D2D2C2B2A25
26365E64625547464B535C61656D7475767A7D7D7D8082807E80828486898B8C8D8D8D8F
91919093969696969798999796989A9C9D9B9A9C9F9F9E9F9F9D9C9D9D999492908F8D81
7674767C838789857F7C7978798188847E7D7D7C
27221D151F63AE93ABA7A6A9ADACACB2B7B7B4B2AD906E4C3028242223272C2D2D2E2D25
213F57646554424146505B61666D7375767A7E80808182807F8183848587898D8F8D8B8F
92929191929699989696979696989B9D9F9B989CA0A09F9F9F9D9C9C9A9794918F919080
706F73787F868B8B88858284858584898B847D7B
2B2723181E4397A5A8A7A5A4A39F9B9696A6B7B8B6AA966C4922232024272B2B2B2C2D23
28365D6468574441444E5960676D7274767B7E7F7E808281808183848687898C8F8E8E8F
90909191929698979697999A9A9B9C9E9E9D9B9EA0A09F9E9D9E9E9D9A96939190908E7F
716E6F767E858B8C8D8C8B8D8F8F8F8F8D857D7B
2C2B291E202A77B1A0A5A19C968F877D7577819CB6BCB38C6421251F24272A29282A2F1D
312A626768584743454D585F666C7174777B7E7D7C7F8181818283858788898B8E90908F
8E8F91939496979796989B9D9E9E9E9D9E9E9FA0A0A0A09E9D9FA19E9A9692918F8E8A7F
746E6D757E84898D8E8B888A8D8F8F8E8A837C7B
26292C2320204A839295928C847B736E6D757F848E9CA2A075363728232327292926203E
22235E725C504344494F565D646B727475797D7D7D7F81808082848687898B8C8D909290
8F9193959798989797989A9B9C9C9D9D9D9E9FA0A0A0A0A0A0A1A19D999795918D8D8B80
746F6D747C83888B8C8A898B8E8E8D8985817D7C
1F272E28221E234E7C807D7C776C64626B94BAB4A59A8DAB874F4A3021202526282B2F1C
2F27577651483E444D51555B616A727474787C7D7E7F80807F838686878A8C8C8C8F9291
91939597999A999897989A99999A9C9D9E9E9F9FA0A1A1A2A3A2A09C999898928C8D8C81
76706F747A8085888888888A8C8A8783807E7E7D
23292F2D29211A32506C62737E726A6A7391ADCAB79E7E8D79281C192324262626292C23
2B285C6D56483B424D51555B6269707274787B7D7E80818182848687878888898B8E9293
93949597999998979698999A9A9C9F9FA0A0A0A1A2A2A2A3A4A29F9D9A9896928E8F8E86
7C767274787E8386878888878683817E7C7C7D7D
282B2F3131261C212955466B877F74757B8A9AD6CBC5B3AEA4482C1F2224282625272926
292860605D4A39404C51565C63696E7275787B7D7E80828384858687888685878A8D9194
969695979898979697989A9B9C9EA1A1A1A2A2A3A4A3A2A3A4A19F9D9C98959291918F8A
837C7775767C8185868787837F7D7C7B7A7B7C7C
24292F2E30291E1F21342E5D84927475787F8BC4D1CCC1C2BB7A34192324292826262724
27265E5A5A493B414B52595E63696F7376787A7D7F8183838485868687898B8B8B8E9194
96969597989796989A9A9B9C9C9D9E9FA1A3A5A5A4A3A1A1A2A1A19F9D9A979492908D89
857F7B7A7B7C7E82858686817C7C7D7B79797A7A
21283131312A212123181B4D7B9E757573747FA7CED1CDD8D1B4502525242A2928262522
27245A5854483E424B535B60646B717578797A7D8082838383848686878C91908E8F9193
959696979897979A9D9D9C9C9D9D9D9EA0A4A7A6A4A2A1A0A0A2A3A19F9C9996938F8B88
8682807F807E7D80848584807B7D7F7C79797979
202E3D4E3E2023202115183E678D867A70717E8ABBD5C9D1CFD0A12F3026262627252423
2A20525E4A433C414A515960666C7074787C7E7E7D80848382848788898A8C8E91929293
94969898989A9C9EA09E9C9D9E9F9FA1A4A5A6A6A5A5A4A3A2A3A3A3A2A09D9994908D8A
88858382818181828382807E7C7B7B7A797A7B7B
23374C6D4C1A251E1F191A304F7696846F717F72A4D3C2C9CAD6D1822E24262526232324
2C204B64403D3B4149505760686D7074787E827F7B7F84828184888A8B88868C93949493
93979B99989CA1A2A2A09D9EA0A2A3A6A7A6A5A6A7A8A8A7A5A4A3A5A5A39F9B9692908C
8A87858382838584827F7D7D7D7A77787A7C7C7D
2D3E54907C43241B1D191B23376D98966D6E777393BDC4CBCAD0CBC66829212025242422
252A43613D3B393F48505961696D7074787D80807E818382818387898A89898D92949495
96999B9A9A9EA2A3A3A09EA0A3A6A7A7A6A8A9A8A7A8A9A8A7A5A3A4A5A29E9B9895918D
898786848284858583807E7F807C78797B7C7C7D
394D638D6D4E271E1D1B1C1B256090A46F6E707885A5C6CBC9CED2C0C142291D24252621
1E333F5C3B3A373E47515A63696D6F74797B7D8082838282828384878A8C8D8F91939598
9A9A9B9B9C9FA2A3A3A09FA2A6A9ABA8A5A9ADABA8A9A9A9A8A6A3A4A4A09C9B9A97928D
888787848384858585828081817D797A7B7C7D7D
4360819D8960281E1F1E1F1B223D77A27E756E727B9DC4C8CACED0CBC1A7471C24222723
2426415D3735343D48525B62686C6F74787A7C8083838383848484878A8D8F8F90949798
989B9D9D9E9FA0A1A1A1A2A6AAABACA9A7A9ACACABABAAAAAAA7A4A5A5A29E9C9A97948E
888786858485868584828181807D79797A7D7F7F
50739FA59A63291F2221231F251E5A958D7F6D6A7396BBC5CBCCCBD4D0C48B33251E2726
2B1A455B3432313C4A545C61666B707477797B7F83838385868585878B8E8F9091959998
979A9E9F9F9F9F9FA0A2A5AAADADABAAA9A9AAADAEACAAAAABA8A5A5A5A3A19D9997958F
8986858585878886848381807F7C79797A7D8182
6187B1A58D492A2024252724271F417D909166696F87A0CAC8CCC9D0CDD9B46B22202625
2826434A3835353F4C555C63686D7175787B7E81838282848787878A8D8E909193969898
989B9E9E9EA0A2A3A5A6A8ADB0AEACACADADADAEAEABA9AAABA9A7A5A4A3A19D99979690
8A88868686868688898581807F7E7C7B7B7F8283
7695B399732B2A222627292929282E618C9E656A6E7885C9C5CBC6C9CAD9D3A430262623
24333F3B3B3839424E565D656B6F7376797D81828181818487888A8C8E8F909396979798
999B9D9C9CA0A5A8A9AAABAFB2B0ADAFB1B1B0AFADAAA8A9ABAAA8A6A3A2A09C99979691
8C8A88878786858A8E878080807F7E7C7C808384
999B94714D272B242424272728262B4685957C65727380A9CAC6C1C4C9D6D7BE7631251F
2430354231353A424B555F656B7177797A7C7E7F8082848485888B8C8D8E909396989899
99999A9B9CA1A5A7A8A9AAAEB2B0ADAFB2B2B1B0AEABA8AAACAAA8A7A5A3A09E9B989593
908D8A898888898B8D888381817F7D7C7C808384
B0956A4629292C262121232425232D307687956675718085CAC3BBC0C8CED1CCBE432D1F
252A2D4A28313A41495560666B737A7B7A7B7B7D8083868483878B8C8C8E909396989999
9998989A9DA2A5A6A6A7A9ADB1B0AEB0B2B3B2B0AFABA9AAACABA8A8A7A4A09F9D999494
93908C8A8A8B8D8C8B888583817E7C7C7D808384
9A77472F21262926212223232421252A587C9E7971707A75B7C9B7BEC4C8C9CCC19F381E
292C303F2D3237404A5763696D757A7977797C7F828587858486898C8F90909193949698
999A9A9C9FA2A5A7A8AAADB0B3B1AFB0B1B3B4B2AFACABADAFADA9A8A6A4A1A09E9A9592
8F8F8E8C8B8E908E8A898784817E7C7D7F828384
76552B22222426252323232424201F28396F9C8D706F756C9ECBB7BEC0C0C0CFD1B46B35
2B2B34323333353F4B58646B7076797775797E81848687868585868C9191909090929497
9A9C9D9FA2A4A6A8AAAEB1B3B4B2B1B1B1B4B6B3AFADADB0B2AEA9A8A7A4A2A09E9B9791
8C8E908E8C9093908B898785827E7C7E81838484
54432824242528262426272726232020275B8D91846B776D88BAC3C1BCBEC0C5C5CDAE3B
352B2D2B303136414E58626B72757777787C8081828384858585868A8E91939392939597
9B9EA1A3A6A7A9ABADAFB1B2B3B3B2B5B7B7B5B2AEACABADAFACA9AAAAA6A19F9E9C9995
919192908F9293908C8A888784807C7F82848585
3C382E2723262A2827292B2B2927241B1D47768D996B7A7276A2CBC5B9BDC2BEB9CBCC8E
2E2628292B3036424F58606A737575787A7E81817F808183868686888B91969694959799
9CA0A4A7AAABACAEAFB0B1B2B2B2B4B9BDB9B4B1AEABAAABACABAAACADA7A19F9D9C9B99
97959392929393908D8B898886827E7F82848586
51303038413629292B2A292D2F2A241E20395A83A37C75737687BDCCB4BDC0BBB7C8CEB9
6C2A23242F32373F4A55616A717577787A7D7F7D7C7E808386888B8B8C9297979798999B
9DA0A4A9ACADADAEB0B2B3B3B2B3B4B7B8B4B0B0B1ADAAADAFADABACADA9A4A29F9E9D9A
97969594929394918E8C8B89868381807F828585
6831352621252B2D2E2A272E332C2423272E4074A18F74737B72A6CCB1BBBDBCB9C1C3DD
AE3B2A243132363C445361696E757979797B7C7B7A7D8183868B8F8F8F939798999A9B9D
9EA1A5AAAEAEADAEB0B3B5B4B3B3B3B3B3AFADB0B3B0ACAFB2B0ADACABAAA8A5A19F9D9A
96969794929394928F8D8C89858584807D808384
5332312A292A2D2D2D2C2B2D2F2D2A292929335E869D836E7B6F8BB4B8ABBEBEBFC3C4D8
BBA13F1F292A343B445260676C73787A7A7B7D7C7C7F8284868A8E91929395979A9B9C9F
A2A4A5A9ACADADAEB0B2B4B4B4B2B1B2B2B1AFB0B1B0AFB1B2B2B1AEACAAA8A5A29F9C9B
9A979493939393908E8C8A878584848280808080
3A352C2D2E2E2E2D2C2D2F2C2A2D2F2D2A272B4764A0956C7B727497BD9FBDBFC4C2C2D1
D7C07A351F20313A45525E656A7177797A7C7D7E80828485878A8D9194949396999B9CA0
A4A6A6A8AAACADAEAFB1B2B3B4B1AFB1B3B3B2B0AEB0B2B1B1B2B3B1ADAAA7A5A39F9B9C
9C9691929493918F8D8A87858483848483817E7E
3E382B2E32312F2F2F2E2E2E2E2E2E2D2B282935488CA27D736F717FB5B5B1BBC1C2C2C9
D0D8B54F30282935444F5961676F7678787A7D7E80818386898B8D9093959596989B9EA1
A2A5A7AAACACABADB0B3B4B1AEADAEB1B3B3B2B1B1B1B1B0AFB0B1B0AFACA9A7A5A19D9A
979593939593918F8D8A87858484848382818181
45392B2E34333031312E2C2F322F2C2C2C2A29283370A5906F6B726DA5C9A8B5BCC0C2C4
C5D2C9B132342432424C545D656E757676797C7E7F8081868A8C8D8F92969897979BA0A0
A0A4A8ABAEACAAADB0B4B5AFA9AAAEB1B3B2B0B2B4B1AEAEAEAFAFB0B0AEABA9A7A39F98
93939494949391908D8A86858585858280828485
4134252B3433312F2D2C2C2E302E2C2D2D2A2826315092A383636B688FB7B8A9BBBDC1C0
C0CCCFCA8D3231344047505A656D737474777B7E81818185898B8E9092969A99999CA0A1
A2A5A8AAACABAAACAFB1B2AEAAAEB2B3B2B0AFAFB0ACA9ABADAFB1B1B1AFACA8A4A09C98
95939291909192908D898684838484817D7F8282
3B2E21293333302C292A2C2D2D2D2D2E2E2B2928333476AA98616769799EC6A1B7B9BFBE
BDC4CBCFC57831313F464E59646C717374777A7E82828184888B8E9093979B9B9B9D9FA1
A3A6A8A9A9AAABACADAEAEADADB1B5B3AFAEADACABA8A6A8ACAFB1B1B0AFADA7A19D9998
97938F8C8B8F93908C888583818283807C7D7F7F
352F292F36322E2D2C2A2A2C2E3030302F2E2E2A2D2C5391A0786C6A6D92BAB5A9B3BEBF
BEC3C7C8BFC961313842505860686F7274787B7E808182868B8C8D909497999B9C9D9EA1
A5A7A8A6A5A7AAACAEAFAFADABACADACABABABACADABAAA9A9AAACADADACABA7A29E9B99
97918C8A8B8F918D88868583828282817F808080
3131313537322C2D2F2B282C313333323032322D292B366D9E91776B6687A6C69EAEBCBF
BFC0C1C5C5D0B3443B3E51565C656D7175787C7D7F8082888E8D8C909596989B9D9D9DA2
A6A8A9A4A1A4A9ACAFAFAFACA8A6A5A6A7A8A9ACAFAFAEAAA6A6A7A9AAAAA9A6A4A19E9A
958E898A8C8E8F8B868584838382818283828282
2F30313333302C2C2D2B2A2E333433323132332E2A2A314A87A0886164768FB1A9AFB6BA
BDBFC0C5C7D4BAA7503246515C656C717476797C7F8285888A8C8D919597989B9E9E9FA2
A6A7A8A4A1A4A9ACAFAEACA9A6A6A6A6A7A7A8ACB0AFADACABA9A8A7A7A9ABA8A5A4A39C
948E8A8A8B8E918D888786848382818182828282
2E2E2E2F2F2E2C2B2A2B2D31353433323232322E2C2A322C69A2965F66687996B5B3AFB4
BABDC0C3C7D2D2C58C3F40485C646A6F7374757A7F848887868A90939697989B9E9F9FA2
A5A6A6A4A2A4A7AAADAAA7A4A3A5A8A6A5A5A7ABAFACA9ACAFADA9A6A5A9ADA9A5A7A79E
938E8B89898D918F8B8988858382828180818282
2F2D2B2D2E2E2D2B2A2A2C32363431303031312C27252A26498796856B656B8AACBFAAB2
B7B9BBBFC5CCCFD5B17F513B545A676C707274787D838887868B90949798999A9B9C9DA0
A2A3A3A3A2A2A3A3A3A09D9C9C9FA1A09FA0A2A5A8A6A5A8ACACABA8A6A8A9A6A3A6A8A0
97908A8685888C8D8C8A87838081828180828585
2F2C2A2C2E2E2E2C2B2B2C3236332F2E2D2F3029232224262E628EA9746963819EC7A9B0
B2B4B6BBC0C5C8D2CEC16F394E5362676C7074777B818687878C91959899999897989A9D
9FA0A0A1A19F9D9B999693949698989897999C9E9FA0A0A3A5A8AAA9A7A6A5A2A0A4A7A3
9C9188838183868A8C8A87817D80838180838788
2C2C2D2D2E2F2F2C2B2D303234322F2E2D2D2D2924232422273E7B9E8D75637690B9B4B0
A7ADB5B8BBBFC4CDCFD1A4674F51575F696F74787B808687898D929496999B9A98989899
9A9B9C9C9B999796959290929494949392949596979A9CA09EA1A4A5A4A6A7A29EA1A4A4
A1958883818285888A898783808081807F838687
292C30302E2F2F2D2B2F33323130302F2D2C2B292726262025206385A185676D81A3BFB0
9DA6B3B5B5BBC0C4C8D2D29B5C5C4D57656D74787B8084878A8E929394989B9A99979696
969797969593929394918E9093918F8E8D8E8F8F90949899979A9D9FA1A5A7A29C9DA0A3
A3978A84818284868888878683817F7E7F828687
2B2D30313131302D2C2F32312F2F2F303031302B2725241F211C437099996E6A7285BDAE
A0A6AFB1B3B6BBC1C7CDD1BEA1585A56586370767A7F8385888B8F929394949596969696
95949290909192959690898D908D88888886898B8E8D93839696989B9EA0A09C9897979A
9C968E837B7D82858787858483817F7E7F848889
2E2E2F313332302E2C2E312F2D2E2F313435342E272422201F1F275985A5796B666BB1AD
A7A8AAADB1B3B6BEC6C8C7CEC59D54594E5C6B73797E818385888C9093908D8F92949596
95918E8C8C8F9397988F85888B878280808084888C888C70949192979C9B989796939092
94948F82767980838685838282817F7F80858B8C
2B2D2F2F2F2E2D2C2C2F312F2C2D30333535332C26252523211E1F4064938F735E6693B7
B3ACA1A7B0B3B5BCC3C6C8CDCAB99C555A5A676F787C808386888B8E908E8C8E90929392
91908F8E8E909395948A807F80817F746A847F86858E776F88807B8C9D9A93989D9B9895
938E887E76787C81848483828281817F80878F90
282C2F2D2B2B2B2B2C2F322F2C2D30333634312B26262725231E1E2C43769E805E6674BC
BDB29DA4AFB2B5BAC0C5C9C8C5C9C29B5658666D757A7E838788898B8C8C8C8D8F90918F
8E90929190908F908E857B76747A7D6B58887C8581966C7B83776D869F9B939CA5A6A29C
948A827C78787A7E828383828182828080899294
2A2A2A2A2B2C2D2D2E2F302E2C2C2D303333312F2C2825252521202230519097735766A4
C0BAA9A8A9AEB4B9BDC3C7C9C8CBC9B28D705C626F767C80838586878887878B8F90908F
8E90928F8C87838789847C7169727A695A7C808A87835D6C76685E80A3A5A1A6ACADABA5
9C91877F7B7A7C7C7D7F818080818381828A9394
2C2825272B2E3030302F2E2F2F2D2B2D30313133322B23242624231E263077A48B515F87
BABFB9AEA4A9B2B7BBC0C4C9CBC8C2C6C18F5F5D69717A7D7F818384848282888F90908F
8E8F8F8B857C767B81807B6E646E796F6673878D8F8F949FA89F969CA6A9ABACAEAFAFA9
A0968C847E7D7D7A777A7E7F7F818383848B9294
2B272325292D3031302F2F3439342F2F3131323537302927262423212726568B95765771
9CBCCAB5A0A3ADB2B8BCC0C7CBC9C6C8C8AD8E715D66777B7E7F808283807F8891919090
8F8D8B867F776F69676D7474747D8687888D989B9FA0A7AFB4B1ADAAABBBC6B49F9D9D92
8B888784827F7C7976787C7F82828282838C9496
2B272424272C313231303039413B33313131323639342E29262323262D223B6B949A5763
7BADD2BB9E9FA7AEB5B8BCC3CACAC8C6C3C5BE8D5E6374797C7D7E80817E7D8791918F8F
8D89837C756F685B535E6E7B858B8F99A1A3A4A8AEB4BBBFC1C4C4BEB6AA9F98928E8A7C
7478808384807A7776777A7F84838181838C9698
2C2B2A29282D333434302D363E3A332F2D2C2E3336312B29282623201B4127537C977967
6385C0C6A19FA1ACB7B8B8C0C7C8C8C7C5C8C5AD907A6B6F787B7C7C7B7C7E868E8F8D8B
877F75675B5A5C5D6168717F8A87828388909CADBDC2C3C6C8CBCDC9C2B5A7978A8C8D8D
6D737C81837D767677797C7F81828282848B9394
2F30302C2A2E34393C322A303836312D29282A2F332D27282A262223291E37475C809872
555CA5C9A6A19BA9B7B7B5BCC3C6C7C7C7C4C2C7C3986C6B74777977767A7F84888A8986
7F746651414550637476767F857A6D64637289A6BFC6C7CACCCFD1D1CDBFAE99888D8F9D
6B727A7E7E797374787A7C7D7E818384868B9091
36322C2A2A2D34465642282C3535332E29292B30342F29292B27242529273035445B9184
584986ACAB9E939EADB0B1B8BFC4C7C8C8C6C4C9C9B4997D686B7475777D82818081817D
75685841323A4A5D6F787B776E5E4E484850607A98B8CDCECED0D1D0CCC4B9A5928A8284
68717F7A727172767A79777B7F828587898E9394
3C322726292D36556F50292A3233332F2B2B2D3337322B2A2A2827282A2B2B2830397C90
63456B8AAC9F9097A1A7ADB3BAC0C5C7C8C7C6C4C3C9C69768666F73787F827D76767570
685A4A362935485968767B6B5544383333353D4F6A9ECAD0CED0D0CECAC8C2B29D846F65
67738275666B73787B767278808486888B919798
3830272528313A69774C342C2D2E2F2D2B2B2C3338312928292A2B292728282225316183
77575C799EB5A2A09C9C9FA6AFB6BDC3C7C9C9C6C4CACAB39679646973797B736A66635D
55483B302D394B5F6F75715C41424B58625547404D6BA9CFCFD3D0CFCCCDC9B79E795A57
627D746B61687174757474797E83868789919899
332E29262634417B754140302A282A2B2C2A2B3338312726282C2F2B252526222434486C
8771596E8AC5B6AE9C96959DA7AEB5BDC5C9CCC9C5C5C5CBC69565636B6F71695E57504A
43382F2E333E4E657670624B394D645C50565C463D3C82C9CED5D0D0CECFCAB5976B4752
62846363616971706F73777A7D82868788909799
302F2D282930528D5F344233292627292C2C2C3337312A27272D312E2A27272E383C4353
849070696EADC5BBA6A2A2A8AFB3B7BABEC6CDCBC8C7C7CDCBB1916C575F6962564B413C
37312D2E323D4B6374624E3C52575A4A3C49515B472B5CB5CBD2CACDCECAC3A5815B435C
777B59606A7073716F757C7F808487898B8F9394
2E2F312A2C2F659546284133292625282C2D2E3236332E2A282E3535332C293B4D443F3A
75A48A6C588CC7C3B3B0B0B4B8B9BAB7B7C2CCCDCACAC9C8C6C9C1795254615B51453934
322F2E2E3139455D6D523B31695B483223374A70542C48A4C8CEC4C8C9C0B28C654B4264
856C5260747877737179818384878A8C8E909191
2F2E2E273037787D392836312D2A282A2D2D2E2F3031322C2937464844382B221D212E2E
538F98895676A2B7C2B4A9ADB4B6B7B5B5BBC3C9CDCBC7C7C6C8BDBB71584D54554C423B
36302B2B2E343D505D463232564A392B251C38544F364497CFD3C4C2B9B58965453C3F55
6A584C617B7D7A76747A818486888B8E90929393
2F2E2E283344885E312B2C2E2F2E2C2C2D2D2E2F32373B342F3F50534E3C2A2829201B22
326D9BA3626778A5CBB8A2A5AEB1B3B3B4B5B9C5CFCBC4C3C3C8CCB7B66C474C59544D46
3D322A292C2F35424B3C2D363D362D252927634E415D83ACCFCEC0B5A0A05D412B2F3B42
47474A657F817C7A787B8184878A8C8F91949696
2C323E4330548C4D2D2B2F2E2D2C2A2A2B2927394E575B534C5C6752382F2B26221F1F20
29498CA0846C6290BDCAAAA9A9ACAFB2B4B6B9C4CDCBC6C4C3C4C4BFB7B46C424C4C4C47
3F362E2D2E2F31363A352F3434312C292B29493E3E58769CBEBBA99376693E30272A2F2F
3240536D8385827E7C7E8285898A8C8F92959697
293A4C5A2C608A412B29332F2A282828292628496B767671654F382B24272B2824242721
262A7390A37A587CA7D3B5AFA5A8ADB0B4B7BAC3CACBC9C6C3BEBBC5CCB6B64C49434A46
413A35323130302F2E31333331302E2D2D2F2F333B4B6186A39E8A6C4C3529282B282524
29426076858886827F8082868A8B8C8F93969798
2A4C45492F5B803A2A262F2B272525242A254D65797A705E49392C26242A2F2B25272822
221F4979A39462728CBEC1B4A5A9ACAFB2B5B8C0C7CACAC6C1BDBBC2C4BDB2AE66404642
433E3835333131303032333332312F2E2D2F2C2F353E4A6479715F4B382B27272926232D
3D587380878784817F8082878B8C8D909396999A
305838323254743529232926252323232E2E727A7B6F5D41272122252A2F322E28282924
211D235E92A87570749EC5BAA9ABADAFB1B3B6BDC4C8CAC6C1BEBDBAB8C0C1CAA6574C42
46413D3936353435363534343433312F2E2E2F2F3032374550483A332D2C2C2A2927293F
5A7184888785817F7E7F82878C8E8F9193989B9C
4B40332B2F5E682F282226262626272C375A797362503E312725262A2D30312C26272725
1E1C1E466DA68E7B6E7AACC5B8A1AEADB0B2B5BCC3C8CBC8C4BFBBB9B8BCBBD1BC874E42
42474946413E3A3532353937343332302F2F2F31323130343735312C2827272A2E2C3A5B
788289868282837F7D8085898C8E9094989A9C9D
5F262F292D685F2B29222526282A2E3944827361433023262E2E2E2F30302E2925262726
221F223045959F8A725D8DC7C39CB0ACAEB0B4BBC3C7CACAC8C1BAB9B9B5B3BFC4D2936C
494C54524E49433A3339403C36353534333232333433322F2D2F312E2A26252E3C355171
8C8D88817B7F837F7B80878A8C8F92979C9D9D9D
49272D2C345B612C2E252525272D36495877644C2F2726292E2E2F2F2F2F2E2B28262820
382C23212C70929F805676A8BAB8ADABAAACB0B8C0C5C8CBCBC4BDB9B5B1AFB5BDE2D097
59474D525956514D4B4C4D453D3C3D3F3F3B35312F363E4140362B30332F323F4A776060
7A8F7F7D797B7C7A787D83878B91969A9D9E9E9E
2D2D2C313B4D622E32282724263140586B61503723262F2E2D2E2E2E2D2D2D2C2C2B3121
4C3824181C4879AA905D6884A8CFACABA7A8ACB4BCC1C6CACCC7C1B8B1ADABAFB4BCC3BE
AE6C4E5262615F6265615B5149484A4E50493F322B3D525B5B453038423E415974728754
6087747876757473747980868D949A9D9E9FA0A0
2C2D2A2F375556342A262825263649616F5A3D2D23252A2B2C2F302D292A27292A23262C
4B341C181C3558919D7768728BBABCB4A6A7ABB0B6BDC2C6C8C7C3B9AEA8A6A9AFB6C3D1
D0C571645E60666A6D6B67646161626567645B3F2D476B88987653465F634B6072798362
627871706C6C6E6D6F77828C94999B9EA0A1A2A2
2F2C292D315D473923242926273B51656E522F28282626282B2F302C262828262A405653
402C1B1C2228386EA090736C739BC4BAA9A8AAADB1B8BFC2C4C6C5BBAEA6A1A3A9B1B9C2
C7B6B98B61616C6F7272727578797A7C7D7D7651365B879190857B5C798557616A747871
66676C66606267686B7887949E9E9D9FA2A3A4A5
292A2B2D2D563C3A2C2928252C4056636B413628272526282A2C2D2A2C243F3E436D744B
34333E21211B2551829290807487A5B3BAB0A4A8B0B4B9BDC1C6C7BFB4A69C9DA2ABB5BF
C6C5C5AE927C6C6F777A7D7E7F84898A8987826856759AA19E948975838A735E6C6C6A66
5E5A5C56525357606D7D8E9BA5A5A2A3A5A7A7A8
23282D2C28493238382F26252D42585E62323F2D252528282928282932275B5B5974521F
2D425E2523161B375C89A9977C787FA5C7B8A2A6AEB1B3B9BEC4C8C4BBA999979CA5B0B8
BFC5C7CAC39A747681838382838B9292908D887D788DA5A6A1988E89838387596A605B56
534F4B4948494F60758696A3ABAAA6A7A9A9AAAA
242428384670554736404B5A464C4E5C462F353C2425272728262529322745606C865624
2D4E57272E201D273F73A19C89716A8FB8B9B1AAA4AAB3B7BBC1C5C5C0AF9E97979FAAB2
B9C0C3C9C9B79E7F686E7D848B91959898948F8D8F9AA5A49F968C857B7574565A524D48
444242454A5564778A98A2A8ABABA9A9A9AAACAD
2626272828513C3E3A3A34492339475C2C2F2A4825272627282524283251686237665A30
345745283D2D221E28598A9895755D789DB4BFAF9DA6B2B6B8BDC1C5C4B6A69A949BA5AD
B4B9BDC1C4C7C4AD9480747F8F9293989C9793979D9E9D9B978E84796E6359534B474440
3D3F444C576B8092A1A9ADADAAABACAAA9ABADAE
2527292929403B44464138422F3E484C2B2E2C3E2E2C28292B272738466E6724254B5C2B
495B34254B341E1C264264899A8F5E66799CBBB3A5A8ADB1B5B9BCC3C5BCAFA196989FA6
AFB7BDC0C1C6C7BDAD95817D7F868E949B98939697928B88847C72675C4F454745444348
4F555D6B7C8A97A3ACAFAFAFAFB0B1AEACACADAE
24292E2A282C36454F4437343842493B2F2D2F3236302B2C2F2A29465A73434A35465C26
5D59262356391C1E292F3D7197A6695D5A82ABB3B0ADA9ADB2B4B7BFC5C0B6A79A979AA1
AAB4BDBEBEBFC1C7C7AD9181787B838A92918E8C89817874706A63584E433C4149494C5A
69727C8FA0A7ABB0B3B1AFB0B3B4B5B2B0AEADAD
222C362F282B353B3F3832333B3B3F332E2C2E323A332B2C324150485557383735376037
654F29285F3E201D23212B4A879E866C576B8AA6BAB4A9AAAEB0B3BBC1C0BAAA9B989A9D
A3AFBBBEBFC1C3C5C5CDC99E7065666E71767978746F6A6764636158504F525860646976
848D95A1ABB0B2B5B6B4B1B1B3B3B3B2B1AFACAC
212E3B332A2F35322E2D2E353A36332F2C2B2D343A332C31383536264F3D302C362C624B
67442F2B62452921211B23266F8A9D81615E6A93BAB8ADAAAAACAFB6BDBFBCAC9C9A9B9B
9DABB9BEC1C3C4C4C2BFBBBAB080505C555D636361616160606467605C6570757A818993
9CA3A8ACAFB2B4B6B7B5B3B2B2B1B0B1B2AFADAC
212B37332E363D3B3734313434402A2A2A29292D312F2D313635382955372B2530255F5A
654329235D593536362A231F476E95907F685B799EB4BFB4A6A7ACB2B7BAB9ADA09B9A99
9BA7B5BCC1C2C2C3C3C2BFBDB7A5904748444E565F6468696B717877777E85888C939AA0
A6AAADAFB1B2B4B6B7B5B3B1B0B0B0B1B1B0B0AF
20283231323B4443403E3B38324C272A2B282627292C2F323532352D5A3F2A232A225864
6442241B526C464B4839292225507E959B7958627DA7C9BBA5A4A8ADB2B5B5ADA49D9998
9BA5B1BAC0C0BEC1C4C0BBBCBCBDB49F68524753656E74787C838A8F93949597999FA5A8
AAACADAFB1B1B1B4B6B5B2B1AFB0B1B1B1B2B3B3
1F262F2E2D31354D635F554E454E3C39342D28282A2C2F3439333328545D262526264762
6F3D26203D5F392B3737322B24375380A188675E638BB3B8B3A8A3A8AFB1B1AEA8A29D9B
9EA7B1BAC0BFBCBEBFBEBCBAB8B9B8B9AB8D716C6F7780868B9094999C9E9FA0A2A5A8A9
AAACAFB0B0B1B1B3B4B4B4B2B1B1B1B2B3B5B6B6
21262C2B292A2A3443596B665B5250473E342B2A2C2D2F373C342F234B792827242C375C
79382C2327686534212C3A342B242B6398917A61526E93ADBEAFA0A4ACADADADABA6A09F
A0A8B2BAC0BEBBBABBBCBCB7B2B1B2AFADA9A28F7E838C93989A9B9EA0A3A5A6A7A7A8A8
A9ACAEAFAFB0B2B2B1B3B5B4B3B1B1B3B5B7B8B8
2E27272D3622373C454A5160686846433F362E2A292B2F363B30272842733C24272F3B5A
73393A2A274A72363922362E292022497383856B535E7494AEBDA3A4A4A6A9A9A7A39F9E
A1A8B1BAC0BFBCB9B7BABBB6B0B0B3B4B7B1AA9F969495989B9EA1A3A4A5A6A6A6A6A6A7
A9AAABADAEB0B2B1B0B1B3B3B2B2B1B1B1B4B8B8
3B2E252F40214341403531546F77393D423A312925282E35392D212E396552212A314356
663A45322F265C7E3E193129252021324A6E8A785F595F7B96C3A8A59EA1A4A4A3A09D9E
A1A8B0B9C0C0BDB9B5B8BAB4AEAEB0B3B5AFA9A9AAA39C9A9B9FA4A5A5A5A5A4A3A3A3A6
A8A8A7AAADB0B2B0AFAFB0B1B1B2B2B0AEB2B8B9
3F492D2F31343534322D2B2E3B696F644F40332A26282D353A2F242C34596124272F434E
51373B33332644736B3F2D23211E1F2331547B837F6F666F7FA9ACADA6A29FA0A1A09FA0
A2A9B0B8BFBFBCB9B7BABBB4ACA7A1ABBAB6AFACA9A6A29E9B9DA0A2A3A5A6A4A1A1A2A4
A7A6A6AAADAFB0AFAEAEAFB1B2B3B4B2B1B5B9BA
3C5E38302245252624262C3747525D615E4B362C28292C353B332A282F4D6A2A25304545
3D342E31362F2E618E62281E1E1D1E1D25436A879A8A776D6D89AAB0AEA59D9EA1A1A1A2
A4AAB1B8BDBDBBBABABBBBB3A99B91A3BBBBB5ADA5A5A6A19C9A9B9DA0A4A6A39F9FA1A3
A5A5A6AAADAEAEAEADAEAFB1B2B4B5B5B5B8BBBB
2F4B423625392925212A374F3E3E44535D503E32292A2F3438332D282A476536273C5637
323B242B313432587B56241E201D1C27315D677F899F8B796A768FA1AFA9A0A0A1A1A2A4
A7AEB5BABCBBB9BBBBBAB6AFA28286A8B3BDBEB7ADA9A6A19D9A999A9D9FA09E9C9EA1A2
A3A4A6A9ACADADACACAEB0B1B2B3B5B5B5B8BCBD
2232463A2B2A2E28253646663C2F253D565348382A2C313435332F2827435B432B45612B
2B40202931363A505E41211F231D1D354B7A646C6BA69B89706D738FA9ABA6A3A1A1A3A6
ABB2B8BBBCBAB8BBBCB8B0A79B6D7FAFABBCC4C0B7AEA6A29F9B99999A9A9B9A9A9DA1A1
A1A3A6A9ABACACABABAEB1B1B1B3B4B4B4B9BCBD
232B39332B282B2C3058594B362B2735475153412E2D303437353029273D4F512B3D4E2E
2B382B36452F3649593F221F221C2039757C5B404E869C948173708095A4AEA79FA1A6AA
AFB1B4BBC0BCB8BBBDB7AF979D6C83B2AAB9C0C2BFB7ADA8A49F9B9B9D9E9E9B989BA0A2
A3A3A3A7ABACACACADAEB0B1B1B1B2B4B7BABCBD
26282A2B2B2828334075642E342D3031374A5948332E2E343A37312B2939435A2E343733
2C2E39485929364556422922221D284398764E17335C8F97918175768099AFAAA0A3A9AD
B1B0B0BAC3BEB8BABCB5B088A0748AB3AAB4B9C1C6C0B7B0A9A39F9FA0A2A39D989A9EA1
A4A2A0A5AAABACADAEAEADAFB1B0B0B5B9BBBCBC
262728292A27294054685037423A342F2E3E4C42352F2E343A3834302E363E503D3A342E
262C3A5D5E34494A4942392D252B396A9467361325406986969C797474869AA7AFACA8AA
AEB0B3BAC0BDB9B7B6B4B4879E838BB3A2ACB3BEC6C5BFB6ABA6A2A1A2A3A4A19E99979C
A1A09FA3A7A9A9ABADADADAEAFB1B3B6B9BCBDBE
272728292A272B4C675238434D4438302B333C3B37312D323939383432353A424A413529
222C3A6B5D445D4F41474C392937498F875A231A1D293F6C90AF8178707583A0B9B4A9A7
A9B0B7BBBCBBB9B4B0B3B78B9A928DB09BA6AFBBC5C8C6BBAFA8A4A4A4A4A4A5A49A9296
9D9D9EA1A4A5A6A9ABACACADAEB2B7B8B9BCBFC0
2B2826282B282D4F714030353C3B39363332333A3F352B2F35393A363231333C473F332A
2735455E554D6047515558575B5C78AA8B60291F1C1D294D729B96897672778EA6B3B9AF
A5ADB8BAB9B8B6B2B0B4B696929597A99EA7AFBAC3C8C8C1B8AEA5A6A8A8A6A5A39E9997
96989C9FA3A3A3A7ABABABABABB1B6B8BABDC0C0
2F2A25282D2A2F5273342D25292F373C3E362F3B45392A2C32373B37322E2D37403B332E
2E3C4C4C4E566044676560524B39669C8D6733231D181D314F7BA1988377727C8EACC3B6
A4ACB7B8B7B4B1B0B0B3B29F8B94A2A2A5AAB0B9C1C5C7C5C0B2A6A8ACABA9A5A2A3A39B
9395999DA1A1A1A6AAAAA9A9AAAFB5B8BBBEC0C1
2E2A25282D2E33636B3D2824292D3340493D30373F372E2F32363939372F2A323B3B3835
33363D4655616C66775752434135699177432C201F1C1E24345983969D8978767E98B2B5
B1AFAEB3B7B2ADABABAEAD9C8895A7A7AAADB1B6BCC1C5C4BFB4A9A9ACAAA9A8A7A7A6A1
9C989697999DA0A5A9A9A9A9ABAFB4B8BBBEC0C1
302C282A2E323671634A26262D2C2E404F433434363432323234363A3C31282F383C3E3B
372F2D445F6972808244402E303169835C20231E2222231F213A5B89AB9B8377738399AD
BCB2A6AEB6B0A9A6A5A8A8968796A9AEAFAFAFB3B7BDC2C1BCB4ACAAAAA9A8ABADAAA8A8
A79E969394999FA4A7A8A9AAACAFB3B7BBBEC0C0
413D362F2C303967694F2A282D2B2B3843433F3A363635312E2F32383B3229303B3E3F3A
3432354E5F6C5B617E39362A303A7E854624272324242320202738638BA7958171737E99
B2B3AFAFAEAAA6A5A5A7A6938595A9AFAFAAA6AFBABEC0BFBBB5AEABA9A8A9ABADABAAAB
ACA8A29B9595989FA6A7A8AAACAEB1B4B8BBBEBF
4E493F332B2F3B586F53312B2B2A2A2E343F4740373738312B2B2F3439332E3640413F37
323842565E6A3F3A7233302A374B9185342E2C2826242324241D1D3C5FA59F8F776A6882
A0AFB7B1A8A6A5A6A6A7A5918393A8ADADA59EADBDC0BFBDB9B5B0ABA8A8A9AAABABAAAC
ADAFAEA69C96939AA3A5A7A9ACADAEB1B5B9BCBD
61625E452F2D37536E56373029282A2B2E39423A32373C352C2D313133383E4346433E38
363E4B485C612D345C39342648728F712C27262525232122231C1A273C778BA7907A6471
869DB1B7B5ACA2A4A7A7A390818E9FA7AAA5A2ABB6BDC0B9B1B3B5AEA8A8AAAAAAA8A7A8
A9ADAFAFACA096969BA0A6A9ACADAFB2B5B8BABA
3D3D3D383430335068583F3328282A2A2B333A332D363E372F30333030404F4F4A443E3B
3B434F3A5A582134464039265795885C2A2224252724212122201F1B21446DB1A58D6C68
7088A3B6C0B3A2A3A6A6A18F808A99A2A9A9A8ABB0BAC1B6ABB1B9B2A9A9AAA9A8A5A3A3
A4A8ACB5BAAD9D96959CA5A8ABADAFB2B6B7B8B8
5B5243372E2B3049615C4F2B2A272A2A2B3136312C3138342F3032363B49544C41414344
443F3E425B5A21323F3B33305296855A2A2A333535302A262422211C1D2C49879C9A8978
6B73849FB6B5AEA8A1A19D8C79889DAAB3B0ABACB1BBC2BBB3B6BAB2AAA8A8A7A5A3A2A0
A1A5AAB2B8B5AEA69F9D9DA2A8AAACAFB2B4B6B7
7861413127272E42565D5D262F282B2A2B3033302C2E31302F30333E4951534639404A4D
4A392D4B5C5F252F3C342E3E4E8E845E31384746413A312B26242321201F2954839BA38B
6F656682A1B0B6AC9F9D9886768AA5B4BDB6ADAFB4BCC3C1BDBCBBB3ACA9A7A5A3A1A09F
9FA2A8ADB2B9BDB6ACA0989DA4A7A8ABAEB2B5B6
766C583B2425303A45535C36332D2D2C2C2E2F2E2E30312E2D343D4B545048423F49534E
45342C3B5F612129332F2E486089886D4D4F5965694C2C2525242422211F2337577E9D97
846C5B668198ACB1AF9F93778093ACB6BEB7AFB2B7BCC0C1C0C0BEB8B1ACA7A5A4A2A09F
A0A3A7ABB0B6BAB8B2AAA2A1A2A4A7ABAEB2B4B5
75562F26272C33333447564A3933302E2D2C2C2D2F32332E2C3A4A565B4C3C4048535A4C
3B2F2F2C615F1E232D2E3655758389766164685E4E3A292525252423232325242D5A8898
96785955627C98AFBAA38E6C8F9CAFB6BCB6B0B4BABBBDBFC2C2C1BDB7B0AAA7A6A29FA0
A2A4A6A9ADB0B3B6B6B3AEA7A1A2A6AAAEB1B3B4
7358352E2A2F352E2A3E4F5D3E37302E2D2C2D2E3031312E2F44585852463D434E595E47
302C333A5B4F2421283E536B7F807B62473A312925292F2C2828282522232420233E5D7C
8F7C606757647795ABAA8C759F9FA0BCB6B6B3B5B8B9BABDBFC0C0BCB7B3AEA9A5A29FA0
A1A3A5A7A9ACAFB4B8B5B0A8A2A0A0A3A7ADB1B3
725B3E3733373A2F26384869443C312E2D2D2F2F2F2F2F2F334C615746424149525C5E42
272A3649543E29242B4F717F82796644252832343433322E2A2B2C28242324232428345A
7B7A6A7E5653567692AB8780AD9E8FBEB1B6B5B5B6B6B8BABCBDBDBAB7B5B3ACA5A2A0A0
A1A3A5A5A6A8ACB3B8B5AFAAA49E9B9DA2A9AFB1
70615041524F4C3D313B475F50473A34312F2F2E2D2E3033394C5B524543444C55595640
2B2D36495239262F44537B807A664D3625272D2F303132302D2C2C2C2C29262525242940
59676E8266574A5E7392777BB19D89AFB6B8B3B3B4B5B6B7B8BBBCBBB9B8B5B0AAA6A4A2
A2A4A7A8A8ABADB2B6B4B1AEABA29C9FA5A9ACAD
6F6660496E675D4A3B3E47515B50423B35312F2C2B2D31363D49534D4645474F56554E3F
323035465238223A5D537E7B7154372D2B2D3132323131302F2D2B30332F29282727282D
39577187755C434B587B6B76B19C879EBCB9B1B1B2B4B6B5B5B9BCBDBCBAB7B3AEAAA7A4
A3A6AAABACAEB0B2B3B3B2B2B1A79EA3AAABA9A9
6F67644B75695F5E5E50454C5D53443C36322F2C2B2D31373F49514C4645475057544C3F
333134465237213C6354807B6F50312A2B2D313131313030302D2B3035302A2828262629
324661518875605852614864B39E869BBDB9B0B0B2B4B6B5B5B8BCBDBCBAB7B3AFABA8A4
A3A6AAABACAEB0B2B3B3B2B3B2A89FA4ABABA9A9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5D6685BBB54029292428262D425238333932392F2F3835392F3A37434B513F3B382F2D26
2B283E6A66665A7165535C62676A736F76827D7C83837B837D81827E8385888989888887
8C8E928B8E8C908C88898A8B8E8A8A8D8E8A928E8F9292929293908D9195938F8E929295
9090999493969B979B9B9EA0ACB1C4CFCBD1CFBE
5A597093C19C3E282C29242A373630343837372B323B30322F4135444C4D4236372F2E30
2B2742696164607A644A5C62696D7575757C7C7E7A82847F7F7E807F8586868A8B88898B
8B9090888C8A8F8B8F87888B8D8B8F8E8D9191939595928F919292909698999195949492
9293979798969A9B9BA0A1A7AAAEC4CFD1CDCCC0
595A5F729AC2953A2A262A2D38342F364438322E3335332C343D384A413D422D2E34302C
292A416364675F7B59515E69766E6D7777787D7E818281818087837F8284838B8786898B
8F8C908C8B88898B928A8A8E908D8B8E8E9694939595949595979292979C9C9394979690
94919694959B9B999B9A9DA4ABB0C4D4D3CECDC5
60595D667CACC06E2F2A24282B2A2B3D4030333031312A2E363E2F4E443E3C312D362F27
262A466C65685C77585B63656F70717276797D7B7E818082847F82828088878B8889898E
8D888D8E8C888C90928D8C908E938D949196949499979593939998999899A09A99939392
96909797949699969A999DA5A5B0C2D2CFCECCC1
5F5A5B59708DBFB35B2C27242B2D32342E30292C32332B2D3133324B4339363031343228
27304C74606A676F565E636A6E7073787A7777817F7E7E858382827C7F85888B8787878E
8B8889908B8B918B8F8C8F8E8D8F8E95949796949598969794999898999F9B979593928F
94979A9A97909897979C96A3A5AABECED1CEC8BC
625A585F6176A0C8AA3F2824242934312D2C2C3135343032383C3D4C403D433A33322C30
302D4B77696E6169515E6169737273747D7A7C827D8080837F8182848288858B898D898D
8D8F8D8D8A8C8C8A8D8B8C918C9294989A97979997979A94979C9696979D999899949494
939598959294939797989A9EA4ABB8CACECDC7BB
5C6A595A62658AC3C791372C31262C322834312E31332E2D313731413D3C3B2E322F2C2B
28264A706F6E666654616C6C717170767F7A79827A7D7E7D7E797E83848582858C898991
898D8E8F8B888A8C8E8C8F918F949697999897979B9A9694989D999C9B9C9B979794929A
9895939294949491909497969CA9B6C6CDCAC1B7
4E6955515A6994B3C7C57E3927252C2B2A313238383B39403E43424C4142423C3A3A2F39
3A3A5C72746770625D636B6B6F72787B807F7F7D7F828584838386818588888A8F8A8F91
8A8B8A8C8C8B8E8D8C9090959099999A9A9A9C99999B98989B9F9E9C9F9D9B9B9897979A
98959795929493918E8E95989FA3B1BFC9C8C0B0
516063596276939CC1CBC374383537363641403E373733383A343D3F3836342C2E32272D
2C325A6F705D6E565660646A707476787B787D827A80807E7F8280848384888D8B898D8F
8A8E8D8A8C8F938F91919397969B979D979999999A9A9C9B9F9CA09D9D9C9D9A96949A98
999796949697929291918F959EA1ACBAC2C5BBA8
65586F6A63748789A4C2D0BA4B2F2E303030343431312D353433413638363632322F2C2C
30345C73735F695554646169717076777B7D7F807A7F807F7C817F8482848B8B898B898D
8F8D908F8F918E93948D8F919398999B979E999C9D9E9EA1A49F9D9D9D9C9E9B9A989A99
999693919691918F8F8D8D949499A5B3BABFB1A1
9E5B63705F6A777D8AABCFD4A13A322E2D34383635323A393E403E3A3833393435312F31
31386077815E6751545C656D6D7275787979797B7D7C7D7B787D828682828685868E8A8C
8A8D938E908E8F8E918F91958E94989A9B9A9A9C9A9F9E9D9EA29B9D9E9D9E9C9B9BA096
969896969690958F8A8D8A8B8D919DA4B2B6A59A
B48A60646A5E65757D8EC0D4CB7730292A292E2B2F2A3232332D4641343436313332292A
2D3164777957664E575B606E6D73737A79797F7C7D7C7E7A8181847E7D8381818A898588
908B919591908F92909095949495969F9A999C9C999B9B9EA09F9B9DA19C9E9A9C9E9A98
969396908F918F8A868785888D8F9798A6A49693
ADAC72647566636C7283A2D3D7C05225262A272426292D31383D41343031302F31272529
262E6776795E644B555B676A7374737576747B797D7E7D8081827C7F8386898689898789
8E8D938E8F918D91929394979893949B99999A9A9E9A96999E9E9FA29C989C999D9A979C
9592948F938D8C86838B828385878D8F968F8486
879794616A746B6C6F7384BBCFCF9D2D29252C23292A323A434E5A3435312A2730232A2B
2F35637D7563634F52596970716F717578787A7D7A7F81817F82847F828685878B8C868C
92918D918E949393909493959A94969E9D989A979DA09D9C9F9E9F9F9E9F9C9D98979195
94958F8D898E887F7D807F808280858788817679
606F7E6D6D7A7F84847A879BB5B4B7633127232324262A3B524B4B46452C2C2D2D27333B
342C577179685D53515C61696B70777674767E7E7F7E7B7E7F88818580868687868C878D
94928F9191989294909491959493989C9A9397989D9C9D9E9FA3989B9E9E9A9794969893
938D868686827D7A7A80828287848686827C7477
4C5E6470707B8B949694999FA8A4AE9E5F3727262023282E383C2C312F2B2A2B31262F2F
2A3163747368524A505E666C68746F717577807E817B7B7C807F82828188888A898A8B90
8E95939294939595939187969693969A97969C989B9E9CA19F9E9AA09E9A9C9594949592
9089827E7B7A7E7C8082848784868685847E7777
2C3B46698D899399A1ADADB1B6BEC0B9AE8129252627242A2F2B2C342E2C2E2F3228312C
3130606E6D644D4E506365666C75777175767D7D787E818083828385858A88868A8E9190
938C8F8F909597959795969D979A9C9D999A9C9A9B9F9EA09D9D9C9EA29B979891949490
90817B74787D7F7F837F807C7E837F817D776F6E
221F235192979EA2A2AFC2B9BEC0C7C6BCA23C2325232728292727272B2B2F2D2E2F2F29
24295F6B70664D4E535F66636A6C706F7875787A7A7D7D7E838283848389888A88909090
92909492919796989696939599979A9F9C9B9F9D9F9D9EA09D9F9F9E9C9B96949494938C
8B7C777A7E808278736C6560666D78746F696064
201C222F81A4A6AAB1B4C5B7BEBFC1BEBCAE6534232128282A2525262B2A3432342F2C27
272E5A6D7069474F555C626466696E7473797C79807D7D7F83828180858787888B8C8B93
93938E9493999796969598979494989D9C9FA09E9F9B9E9C9E9D9C9FA296969895948F8B
857B757A848384816957463B4751615D5C575559
25221F2158ADB1ADB3BAC4B4B7BDBCBEB7AEA27430292A232126262525262C382E2A2E2B
2B2D576A625F4B4951605E60626B70717579787A7A7B808182808282868A8988888B8A90
8F8D8E9A9696939999969B9C98959A9C9A9A9D9CA09F9E9F9F9EA09FA1989394918D8F8A
82777981848688836541323132404D59605A6371
201D1D1F37A2B4ACAFADBFB3B3B8BDB9B3AFA7A15B3C35272521222226292D2F2F252729
252E5E6E585B47504C565D62656A777379777D7C7A7D82807F7E8284878A8D8C8B8A9090
919090959B94929A94979A9C9598999D999F9C9E9C9E9C9E9D9D999F9D9C9692948A8A87
807478878485848A78563A38394959667273777E
2920211D258CAEA5A7A7B4B4A9B0B0B4B9B4B6B4997B4C2D292620222222302D2B262829
2534606F645C464D4C555C5D666D746F797A7D807C7D857F7D83838288868C8A918D8D8F
908D9295959697959A9895979597999C9C9F989D9E9E9EA09FA09D9B9E97968F948A8A84
716C71817F89878585837770757E7F8082847E7A
2A201B1B1D62A89DAAA8A6AFA9ACA7B1B5B5B8BDAD8C774F3729242626272C2931312F26
273258695B563E3A47555A60656E7473767D7C7F837D84807F83808586838B908E898D8D
978D8F988F96999397959797949B9C9CA09A979CA19F9F9E9E9C9B9A9B969192908B9480
746C747C7D878A8786878684868D89848B847E77
28261D1D1C3BA0A3A3A59F9FA6ACA19E9B9FA9BDBAAA8F5D412621201F2635282F282A29
28345B6A675A47443D53585F697072747676837B7F84817F7F8383868686878D8D8D908D
928D939091949C9796989B9C9C979C9D9E9B9E9D9EA59E9E9F9CA29D9A9794998F918F83
756B72787D858F8D8B89888A928D8F908C837E78
26312720212A78A9A1A6A49996928180757782A1ABBDB191653124242428263227232728
252C5D71635943454A4C5C5A696D6F74787B80787D7F8280818581838887898C8B928F90
908F8F9395979796999598A19B9D9F9C9F9F9F9F9FA29F9E9F9DA19E9A959292908B8C7E
786870767D86868D8D8E898C8D8C908E8A827C79
25302C212225478C989A968881766B6D6476838792A2AD9C6E372925262323272E242F46
252E57715B4E4643444E5957636B7672777A7B827E7C827F80828686868C888F8E91918D
8E8F939C9399969695979A9D9C9F9C9F9C9D9E9EA0A29E9F9D9F9F9D9A92938E8B8D8A7D
746B6D747D83878A8D8B888B908D8F888680807D
24243226221E224C7883787A7A67656C6C90B5ADA38D909A875A452D23222B252B282822
232E5A6D5A43404B4E51535F5F6A747176767D7F7D7C827D81838685878B8D8A8B8F9493
948F939B97979A98969A9A96999C9A9F99A29F9CA19FA2A4A3A1A19B999899928C8B8F7F
77726E737C8087868B888A898B8F8484817C7D7F
2323302F2B1E23285165677E856A6E727290B9C9C3A682977D3424231F1E232925222A25
292A5C6C5C413847484F565D67686C737575797D7F808482838287858886878C8B8D9091
9393959A9B99989897999A969A9D9E9DA2A39FA2A69EA2A4A4A3A19D9C98989691908E85
7C797572767C84858387868483827F84797B7B81
25312C372F1F1B212E4F4B6D877672807B7E9EC9CACAABA0A33C28221F25272B27262C25
252C596A5D3D42474D525958656A6D7574767B7E7D8080818585858C8782858A898D9492
979693999697979896949B9A9E9FA2A0A0A0A2A5A59EA3A5A29D9F9D9B9892958E8E908A
837C7772797D8286868B8783817E7B7C7A7C7B7E
2A24293A32212330212C285C898A7578787992BFCCCECABFC57F2F2222272B2922282727
283056645A4137484553575C6066717577777D8080808784848486868A878C8F86909092
96999397959894969A9D9B9C9C989EA3A2A0A5A4A4A0A4A4A3A4A19E9B9D9494928F8E88
857D7C7A7B7C7B82838C857D7F7B7D7E79757A7E
232532382F2C1F1F221E2244829A7B7176737FA8D0CFD0CCD0B94926232A26282C242425
22285360543C414A4B545D61676A71757779777F8080858181878386878B8C988A929090
969892999899989A9B9E9B9B9F9A9EA09FA3A7A7A4A3A09EA0A1A39F9E9D999591928988
87827E817F7E7C838387837E7C7B7F7F79757681
232E3D4E3523201B1E1C1F2F6B8F867370747690BFCDCBCECCCEA3382524262925262722
24254D664E3A4247454B5761676C7171797E807A7E80808382878889898A8E8E8F949390
91989B9796999A9EA29E9D9CA09F9F9FA2A6A8A2A6A4A5A2A0A4A5A2A69F9E9A93938C8E
85858484808181847D84827C7F7C7B797B797C7D
26324C734D2620211E1D1D25508395796F797678A5C7C8CECFCECE893125262527212329
2729495C48353C45494D5A62666C72747582837D7B8083867E8487898A8A8689909A9290
96969B9997A1A1A1A3A09E9FA0A2A3A2A5A8A5A3A8A9A8A4A5A8A2A6A69FA09B96919089
8A8883838382848481817B7C7D7978787A7B7C7D
333D5C857646241E1B1B1C233770A08B6D7E767591BEC3CACACCCFC3642821232526211F
272E4B5544353A444A515668696B706F7B7E7D7D81838185817F898B8B87888D92989196
97999A969BA19DA3A29A9E9EA2A4ABAAABAAA8A7A9A8AAA6A8A6A0A0A5A19E9B9598918C
8B8A86858083868785827D7E807C787A7B7C7B7D
345166887758241C1D1B1A1E2659929E716F6F7185A8C5C9CCCBCCCEB546272121232A25
232947563F3A383C45555569666C7076777D7D858182848082828487898D8B909093959D
979C9D98A09DA1A4A2A1A2A0AAA7AAA6A3ABACA8AAABA9A7A9A5A5A1A5A1999B9897928E
89868884838383878381817D827E7B787A7E7B7E
43627E937F60261D1F241D1E243B819C7F756E707EA0C6C7CACCCDCECCA53F2623232321
212B41573C37343C45505B64656C7074767C7981818083858687838689918F928E939397
959B9C9F9A9FA4A2A0A4A0A4AAACADA6A3ABADACA8A8ABAAA9AAA7A5A5A69E9D9D979488
878584868587868883828383817C77787D7B7E83
53749BAD9869261E2024231F20265B8C947C6E6B7490B6CEC6CDCFCDCDC98B3122272724
2B264455382F35394C565A65666F7173767E788385808385858586878B8B90938F959898
9898A09DA0A49C9DA0A3A8A4ADB1A9AAA7ACA8AEB0ABAAACACA5A7A0A5A69F9E98999491
8A85868686848886828580807F7B7A787B7C8282
5F80B6AD8A5129232328252028243B7A99836D6F6F81A0D1C7C9CBCCCDD1C15C27202623
2425404E3931383F4F545B62656C706F787C7D7E857F87848685848D8F8B8C9093989B99
999C9E9B9E9CA4A1A6A3AAACB2ADACACAFAEABACAEADA8A8ABA6A7A7A1A29F9995979591
8A88868984848787878A7E7B807F80797B7D8185
7993B2986E32212E22262B2B2827306090956D64707985C3CAC5C8CBCED1D4A72F222525
282F394837363C4751535E656E6D77747A807E83837E848286878A8D8D8D909794989697
989C9C9B9D9CA5A9A7ADABABB4AFADAFB1AFB2AFACA8A7ACACA7A9A7A4A1A29E9A999391
8A898588868587889186837F81817A7D7C7C8489
A49A9470492D2621222528242A2B2A4D80977964707B7DADCCBCC4C8CCD0D5C875352922
26273F43312F363D475164686C707779798080807F828084898C8D8B8D93929098919997
98999A9E9FA2A6A9A5ADA8ABB3AEAEAEB1B0B1B0B2AAA8ABADA8A8A8A4A39F9D9B979895
92908B8C8B89898B8B86847E817E7D817C838184
AC976C442C282B262126222320282833718F8E697074778FC7BCBDC4C7CBCFD1B3442A23
24282F3E2F343C434F5163686C707A7A7B7B7B7E8183888282868C8A8D8F909298959A99
9B96999D9DA0A5A5A5ADA7AEB1B0ACB1B5B1B2AFADABA9ABAAACAAA7A7A5A1A19D9A9293
938F8C888A8A90888F88858380827B7D79828283
907A452A222B2F29222122292622242A53859F787374777BB6C5B8BDC4C5C9D0CC973229
292935432C303C3D4B555F656E747F797678797F83828C84848589898F8F918E95969899
9C929B9B9AA2A7A3A7A9AAB2AFB3AFB1AFB1B8B1AEAEA9ABB0AEA5A6A5A49E9D9B9F9292
8C8E8F898B8C918B8A898984817C76847F808388
77582D252320232225242322221F212539729A8B737270749BC6B9BBBFC4C3C5CCC26A32
302A2D3A2D37343C4D59656C71757A7876787E83868487828585878C9094928E92919495
9C9D9BA2A2A2A8A6ACAFB0B1B0B8AEB2B4B5B7B0AFAFAFABB2ADA9A8A6A7A2A2A09A9695
8B8F918C8D94938E8A8B8586817F7E7D83808682
593E272524272C27232226322522221F295B8994766F6F7384C0C7BBBDC6BDBDC3CEAC3A
2F2B2D352E3236404F59656C727175757B7B82837E8289858886848B8F91909390909597
989DA2A7A9A5A8ABACB0B2B4B6B3B0AFB4B7B3ADAFAEA9AFB0AFABADA9A2A39E9B9B9796
918F93908D92948C91888886867E7F7C82848585
4331332C2827292A29252831252A201D223A769493707478759FCCBEB9C2C0BCBBCACA90
3523252C2B2E37454D596167757379757C7D7E83827A848186848589889296969593979A
9E9EA5A7A8AAADACB2ADB1B0B1B4B4B7BEB9B5AFADAEA8ABABA9ABA8AFA8A19FA09A9B9C
989393969095928C8D8C8A8486857B8081858489
542F2F383335242A2C2A29322B27282224335F90A48373777286BFCCB1BEC1BFBAC1D1C1
622827282C30344448555F6874747979787C80807F798083868A8C8E8D92989898979B98
9CA0A1A6ADADB0AEAEB3B5B3AEB6B3BABAB6B4ADB3ABABACB0ADACA8B0A6A4A59D9F9F98
96939495919495958C8E8C8A8587817E81838483
5F37302B23292B2F2C272632333026212A2C3C789794766D7D76A4CDB3B6BFBBBCBDCAD1
AF4229272D393637475761696D75787A787C7A7B7A7A8383868A8F918F91989899989D9C
9EA2A6A8AFAEAEADB1B1B4B3B4B4B2B4B2B0AFACB6ADAFB0B3AEB0AAACAEA7A6A29F9D9A
98929999929195948F8C8C8A848983817C818482
503A2E2E26322A30322A2D2E2F292726282A325C889B7F69797983B2B8ACBBBDC0BEC8D1
CD983524262F323B415461656E727A777B7C7C7F7D7C868187898B8F938E95969B9B9C9C
A5A4A7A8ACAAACACB1B3B4B4B3B3B0ADB0AEAEAEB3B0ADADB2B3B1ABAAA9A5A2A19E9B9B
9B9A909291908E928B8B8884848081847F7F8082
3738292E2F322E2D2B2C2D2F2A2F3329292A303A6C94977373787590BCA8B6C1C1C3C3CD
D2C97C2D21282D38475560626C6F777C7B7A7E80807F87818A888E9494919397979D9D9D
A5A5A7A7AAAEADACB0B1B3B0B5AFB0B4B2B7B4AEAEAFB4B3B0B3B2B2ADAAA8A6A1A19A9D
999A9092929490948A8D8A818587858382827B7F
3E352F2D2E2E2E2F2D2E302E2D2E2F31302B2C365389AA807372747DB5B5B3BCC0C3C3C6
CFCFBD5829242E34444D575F696F777577797C7D7E8682838D898D9493979897989A9EA1
A2A3A7A9ABAEADABAEB3B2B4B0ACAAB4B3B0B1B1B2B1B0ADAEB2AFB2AFADAAA9A7A49B9C
9493949498958E928A8D86828886847F84838285
4A302D3335342F3A2D2D2C30302D2B3029292926316F9E9470666F76A6C0ABB4BDBCC4C2
C9D0CCA83D2A2836414B545A66717574757A7D7E807E81868A8C8D9290949898959E9EA2
9FA4A7AEACADA9ADAFB6B5AEA8AAABB2B2B1AFB6B3B1B0B0ADAEAFB1B0B0A9AAA4A39F9A
93919595949193908C8C85858586877D81838285
532F272E32362D2C31302B3035302B2A2C2927282D5493A27D66677088BBB4AEB9BCC2BF
C2CBCEC8903430333F4C535F5F6F727579787A7B837F8384888A8B90929799959A9DA0A0
A2A7A8A8AEA7A7B1ACB4B0ADA8B1B6B6B1B1B0AFACABA5A9AEB2AEB2ABAEAAA8A3A09A98
9696908E8E90918F8C8B86817E87877C7F808084
4227252834333429262F2B2A292F2D2D2E2B29282D42779C986E616A76A4BEA7B1BCBFBB
BDC6CCCDC17A36343D474B56676D727075787C7B83818084878C908F94989C969B9D9FA0
A5A4A8A8ACA7ADADACB0ADAEADB0B2B2ADAFACAAACADA8A4ADB1B1B2AEB2ACA7A29B9B98
9593908A8E8D948F8B8884878182877C807A7F83
2F2C2D2D36332E2E2C2D2830312C3431372C2B322C29528BA57E6967708CC0B2ABB5BCBE
BDC2C6C9C9BB593637455152616B70716F797E7A8482828A8B8B8D8D92979D9AA19B9F9F
A2A9A9A4A5A5AAADA9B1ADADACABADABACADABAAACADA8A9A8A9A9B0B0ADA8ACA09C9A9A
95948D888E8E96898B8980838281817A867A7E87
3134313337362E2B302C282F322F35332D2E313127273A6F969B746C6982ACBEA0B3B8BF
C0BEC4C3C7CCB04C39434B575F647070767C7A797F7F7F8C8B8B8A93939698979E9D9F9F
A7AAA9A1A3A2AAACAEB4ACABA9A3A6A5A8A6A9ACAEAEADACA8A8AAA6A8ACA8AAA3A2A099
948E8A888D8D8D8A858387828183847F85807F89
333030333431262B2B2C282C31353136353234352A2E2C5082A37F67656E8EB9A3B1B6BC
BBBDC0C2C8CCCCA4403F47515C5F6C7074787B7C837D868D898C8E95969898989D9FA09E
A8A9A7A3A5A2AAACACB2ABA9A8A3A6AAA4A7A8AEB1B0AEACA5A9A6A6A6A7A7A6A1A69B9F
958D88898B8E92908A86878584867F8281818488
322B2F32302C302E27302E31323F30303030332B2A2A2C386B92956F626475A2B5AAB2B5
BABDBDC6C9CFCEC78A40404D59616A71717576777D858689858A8D979497969CA198A1A2
A4A7A4A6A0A4A7AAADACA6A6A0A5A7A5A8A3A7A9ABADA9A9B1AEA9A4A6ACB0A4A6AEA59E
938C8E8888908F8E8B8689868181838182807F8B
2C2C2D2F2D272C31282B293036372D33323130302627282D47829E8469656B87B4ADB1B4
B6BBBBC3C3CACFCDC1813F4554606671706F72787F878687838E8C9694979C9C9C9B9FA4
A1A1A2A49EA6A1A1A39F9A9F9BA2A29D9E9FA6A4ABAAA3A6B1ACAEA5A2ACACA0A2AAA4A4
958C8D8585888A8F8E888882827E847F7F807D8C
302D292C2E2E2D2C2B2F2934352F2F322A2F32292521252330668F9F7C64687BA4BBACB6
B1B3B7BAC0C6CBCCCEBB703C4E555E656E70767879828787868D8E989699979A97979A9B
A0A39EA39FA09C9A9A97949696989B96999E9B9C9CA5A0A2A4A5A7AAA5A7A5A29FA6A3A7
9C8E8B827F84868B8C8789807E8084828283878D
2B2F2C2F3231332C272E31383633302F2D2D2C2723242523243F799C8F736B6F96C1B2AB
A6AAB1B5BCBFC8CCCFCCB66047515C5F676E727B7A7C838B88909294999A9A989793969E
949B9B9F9A9D9A9597918E9291938F909093929298969C9DA0A1A8A8A7A3A4A49CA1A3A7
A0928683858484868A8B87847F817C837C81848E
272B342E2D2B2E2F302D2E362C2E2F2B2F2A3027282B262122286085A1826B677EA9C0A8
A1ABB2B6B7B5C1C7C9CACAA95F4A565D636D75757D7F838A888D939494959B999A9A9698
969497999594939095908B94928F908D8E908E8F8E969796979A9B9DA1A3A5A49A9DA1A3
A1988B81818188848A88868781837E827F82838C
342A2C343432312E282E3733332E3437342C3030271E212020233C76999B6E63708CB9AA
9FA7B0B3B3B0BBC2CAC9CBC8A25D4F535C63717679848386878B8C8F9392979A92969297
999193918B8F919495958C8A94908D8988898B8D8D94918C95959B999F9FA49E9A949699
9C9C8D837A7B81848689868285817F7F7D838590
2D2A2C312F3433292E33302E2F2C2F343532362D2627261C1E23265987A180636673A8B8
A3A3A8B3ADB2B5BDC5C8CBC6C49E595151606B6E7B807E8385878E92958D8D9090969497
92948B8F8C8F9396979084838C89827C7E847F88888585778C958E90A099999696969191
96958F83777A80818884857E8383807D80868991
2E31334429292B2F2F2E2D2E2A2C2C303236342D28252623222223326B8D956E626990BB
B7A2A1B0ADB6B8BCC4C4CBC9C5C59A59515F666E767C818289858C8D93858D8B91949392
8E928D9190909695948E837781817B716E867F888A8F7B6C868A8186A692929799979992
8E8E847F75797F838384847F81837E7F82888A91
282B2D262D292D2C2C3034342B2A2F39382F302C2327262323222126467C9980625C7FB3
C3AD9FA9AAB3B3B8C1C2C8CAC5C7C1965953696C747E7E8388858A8D8D8A8E8E908F8F91
8E8C91958F8C908D8E85816D77807A6E5C808089868B716E807B667DA698939CA5A2A399
978A837E7A777A7C8284847D838081807E8A9495
2C262A2D2E2B302F2B2D2E312F3030333239332E2B312426222320202A5E899C6F59679C
C0C2A2A4A8AFB0BBBDC2C8CEC6C5C6C2966060696E76787F8583868B848789898F8D9291
908F9292898684888A837A6D68777D6459768182847F696A8073657F9FA3A8A7B3AFAFA8
9E90887D777D787E7C81818283848782818A8F96
302A23292A2F2C362D2E2F30302B2A2B322C3A2D39282425242523222239779C875F6181
B7CAB9A6A7AAB1B6BABEC3CACBC9C2C2BF8A5E5F68757781827C828A81878285928E8F8F
8D8F8F8D8678767D7E7F7E6C6D6B7C6F607A858892969193A7A08D9FA2A4AFACACABAEAD
9F948C837E807C7F747B827B7E808383868D9295
2824252B252C2F343231303138322E3930312F2A382F27262D22211F232C52849F6D566C
9BC2CBAFA3A7ACB6B9BCBEC8C9CAC6C4C5BE94625C6C787B7C7B81867E817D8493939190
8F8D878881706D72696C78726F7485858F979B979EA9A7ACB2B2AAB1B4BBBDB1A09B9794
88888984837E79777973788083818079828D9497
2C2724272931342C312D303C403A362E2C3032443B2F342B232725222C293B6E91935F60
7CACCEBF9EA3A6AEB4BABBC5C8CAC8C6C4BFBC8F606277797B7B7F8181807E889093908D
8D8C827C746B6369534B717D878A92959D9D9FA8ADB0BBBBC1C4C1B9AFA7AA9B928E877C
75768280867E7D7877797B8082828580848E949A
322C27272429303938322E36433F2E2E36302C2E313727242825242120392A4D859B7C63
6688C2C59C959FADB1B9B5C0C7C7C6C7C5C1C1BC926669727F7C7B7A7C7E7B878E8B8D86
8685726A5F5B5D5F5E6E77828B8D83858A939EB6BBC1C5C7CBCED1CEC7B69E908991988B
73707C83827D797275797C8481828185848D8D99
2C2B362C2F2B363D3A362D283740312726292C2F303526252E2D2123212A363C58889663
5866A3C2AB969CACB5B2B4BDC3C3C7C9C5C7C1C4C19C6C6A73777A72767E7C838C838F88
7C766353434352637377777C84786C65667489A3BAC5C6CACDCFD1CFCAC6B09788908E94
716E79857E747179747C7B7C7F82828386869094
3C35282E2A2E34454F3D2A29313A322D2C282D2D36382827272421252A3032353F6E957C
53567EAFB99F98A9B0B3B4BCBEC3C7C9CAC4C5C5C5C4A06D68717576767F8284827C827C
756C56412F2F496371707578715F523F424B587F9EBCCACBCACACECCC6C3BCA3948A8478
6A747E7A7070737C7D78767B7A86848B8A8F949B
402E2C282C283A52744D2A2C3430352C2D2B2B3534302A302C27282B272E28252C407D8A
67516689A6A19097A3A8ABBBB9C1C6C5C8C7C5C4C2C7C3986C6370727A7E817D7475796D
64604A322B33445C69727D71593E39363D3A414D6BA0C6D0CED0CFD1CAC8C0B09E837261
667D7D74666F72777C75717B818286898A8E939B
38282627262D40657F4F352E3129352B29312D313D2D282D262C2B28232D2724262F5A78
73515C7D97B19E93979399A2AAB4BBC3C6C9CAC8C5C5C3C298676D6573787A756E64615F
564E372F3345535A6C7F73583B3C4F575A504D374171ADCFD3D2D3D3CDCECAB69E7B5D54
637E7666626B6F6F7572767A80808688899097A2
382E2B292B31457977463E2C292A2C2A2D2C2A303A2E2A2628292B2B25272325252E4A69
8472566C93BCBFA8A1999599A8ADB3BEC3CACACBC6C1C6C7C793696267746E695C54524E
423B2E2B2D454A5D757963433A546256565B534839427EC5D1CED0D2CDCEC8B6956C4C46
6C7E6A5C6070706D7076797A7D81858A888D959C
352A3026272E528854364430302324262F262E37382F2B29273439322B25282D35484A62
899D756074A9CDBFAAA4ADAAB2BBB6BDBCC8C9CBC6C6CDC9C8C28D5D616B656156534035
3330312D2F42475F736B47345C625A4842425A6C4A3557B1CFCCCCCECBC8BFAB80584658
7C785E5A6C7772707173787B818687888B8D9199
28352B2C2C34668D49313D35292729282E2E2F2C3A32322A2B2A343A342A292F494B393B
74988E675C8CC2C9B4A4AFB6B3B9B9B8B7C0CCCFCBC7C9C9C4C9BD7A505B5E5651443838
35332A2E3438465C675A32395E5D4C30292B45704D38429DCCCCC6C6C6C1AC906246445D
836E545B747A75747173888284898B89908C8F99
27382E272C3E7A7D3F2B352B2C282A2B2933302F312E2F2B2B2D404841383A2526272125
528DA17E606C9CC6BDA4ADAFB1B7B2B1B7B9C3CECBCAC7C1C8C5CBB76B515258554E4438
31352C2A2C3341525A51323C504F30262427385A413248A3CCCCC7C0C0B98B6B483C3E68
6C544B647B7C787A7779808782878B8B968D919A
2C302D2E304780652A2F2D31312E2B322F2B2D30323B3B2D333F505A55322A2722211F21
3272989C6B5F79B1C8B0A4A8ACB3B5AFB5B8B6CACEC9C7C1C5C5C5C4AF694C5057554C44
3C322A292A33353D4D432B2F3E3C2D2724285857415679AECACCBFB0A39A61452B2B3B4C
4A3F4F6D7B827C797679808A868C8B9290919499
31303840334F8D53282E2C2C2F2B282928252B344867604A5A536D5E2F292A2823252220
26538C9F85656592C3C6ABACA6AFB2AEB5B5B4C4C9CAC4C7C5C0BEC0C8AE614448504B4B
463A292F3130313035352F2B363132282E304C3E455E80A2C1C0AF9577623B2A2726272A
2C33516E8187817E7D807E8788858E8C93959899
2F3A5256355C8747252D34322C252B292B2A303E6E7A706D66523B2B27272D2922222621
21336A93A6715F7EACC9BDA7A9AAABAFB3B9B9C4C9CDCAC2C4BEBEC3C1C5A659434B493E
3B42333030342F30302F372F33302E2C2E2F2C3238465A8AA2968E684E382A29292B262A
2E436475848884817E8082888A8B8A8F92969499
2A3F553D2D5E82382C2C2A2826242429252A4169797972674828242926272D2F25292722
21234580A195646490B9C6AFA7A4ACB1B0B8B8C2C5CDCAC3C2C0BDBFBFBDC5A75E4A4141
43433935322F30353533353733352D2C2A2F2E2F304F4262776F5C46392E2A272E29262E
3C5673818B8787837D8282858D8D90979394999D
37563A2F3259732E26292724272525203035707971726040262624272B2F33342A20262A
1B1F265A90AD76677B9AC1C3A6A6ACB0ADB6B4B9C4C8CBC3C1C2BABCBEB9C2C6A2584640
3F4B3B36373935323534343A332F32342E302E2F2C33373F544737332E282E2727302837
586F8388898180837B7E83828C8F8B9294949C9D
4A472D303163672E2B262B242826272B305C7B7C6E4F322D2A2E282B292F2E2C25242C33
1D1F1F3978A098806D7DAACBB4A7ADB3AFB1B7BBC4C8CBC5C2BEB9B7BAB4BBC6C89D5041
47464744433F3A3533363433343431322F31302E323B30383936412C2E28262C292A385E
838A8D82827F847D7E83828F8C8E909197999C9E
582F2C2A2F5D652F282622232631303A497D7865412F28252B2B2C392F2F302826242427
1F2523284F91A0886E668DBCC0A6ACAAADB0B3BBC3C6CBC7C9C2BBB9BBB6B6BFC5C99F5A
484E564D5048473C343B4038363935323831323533353532312D2B2D2B29282C35444B6A
8A8C8880807A85837D7A8989899292979B9E9C9F
4027292D36595D2B27262624292E30435C76603A2A292C2F322D282F2D2E332930262423
283D2122276E8F9F77656FA2BFB9A8AAAAB0AEB6BFC4CBCCCBC7BCB9B5ACB1B7BFC6CDA6
5E4F514F5E574D454657544040433E393B3936322C32353C37382F2B2F303038537B6461
7888817C797A7B7C777A84898C8F969A9FA19A9D
31302D2D3C545E312F2D262429333E5F606C573425302B2B2C2E2D342A2E2B2B2A2E2727
443F1E1D223E81A28D6A697CB0C6B5A4AAA8ADB1BBC1C5C8C8CAC0B5B3A9AEADB7BDC6CA
AD6454555F6260646764604A4B49435249513B362F3851695E4B302E434540546F798057
6580777A75737474777A80868D93999C9DA2A09D
2C2C312A305B57342E29252324304D676C6234282B2528262B34322E2D262C2A25282D3B
55261C1E212C6194A173686B8CB9C1B0A4ACA7B2BBBDC2C4CBC8C3B9B1A8A8A6B2BABCC4
CCB275556460686C6B655E5F626666696D6B573E2F456F91847C5344657049676E7B7C6B
5F75746F6D7170666D79818A939B9F9A9EA3A3A2
302F292A3C5351322626282A30315565685B2D272828242A2A302F28282A28312D385262
3D2922262121357B9699716D779EBCC2A7A3ACAEAFB8C0C0C3C7C5BBACA3A1A2A6B7BAC2
C8C8B68264626C7171727875767D78757C816E58335A8195928B7460777D5B5971737C71
69646E635D6461686D7A85989C9D9C9DA1A6A4A5
28252C29344C40372B27263028385766664C352A23222C2D2C2A3128272A3335436C6E41
2B312F221E20214A7B9E8E7B7281A3BFB9A8A8A9ABB2B8BDC1C6C5BFB5A99AA19CB1B5BE
C4C7C7BD956C6F71787E7D7B7C8A8786848A83734F7B9B9D9B9D89718489765B6C656A64
5E575D5A515A5C626F778F9EA5A4A3A3A7AAA2A5
2429312634473B3E372E2A2C33395B5D613C3830242424292829272A3031595360855225
2B495C27201D1F32628EA796827182A8C3B7A1A8ACB1B3B8BBC7C6C4BBA7969A99A8ABBA
BFC1C5C7C09E6F6E7B828283858992938E928A757A90A5A3A09B8F7F818A7E5B685A5E55
544F4B4E484E4E60768796A6AAA9A6A8A7ABAAAD
26242F3345614C463C373D63463F5B5C4327353B2929282B272529232D334F5F66765426
2D5B592E2A1F1D2439759AA7886E688FB7C3ACA7AAADB4B4BEC2C6C7BFACA39696A1A9B3
BCBEC4C5C7C1AB7C74787A86898E97999A958E7B969D9FA3A09A8B857E7E736161565348
48443F3F414F5B798895A1A7ABA7ABA4A7ABABAD
25282727334D3F423A2B3D532A334A543429363E2A28232C29202829345066593D696125
335D3A2D3E2228272A5085A2907264739ABFBDA69EAAB0B2B8BBC1C6C4B3A69B949CA5A8
B2BBBDC0C5C3BDB1887679838B919198999998929DA29B96958F817A6D605D52464D4341
3F39464F59678196A0A9AFABAAADABA8ABAAABB0
212827262A3C4C424E4C3B35293B4F4835302B3C2D2727282A272A2E4A6D6033284E6328
4B5C2B364E28221D2F3A6E8D9E816562799BBFB1A1ABAFB0B7B9BAC3C7BDAF9B979A9CAB
ACBCBDBAC6C3C3C0B9927B7D84898F969C9696979794918C847D74685C4B433B463D3D44
4C585E71848D9BA7A9AFB0ADAFB5B1AEACAEAEB1
242B34232A34353C5642323B344746392F2A2C3A372F322B30302C4260684E46323C602E
5B53252D55311F2725233E75979F6E5B607BAAB9AEA6ADACB4B2B8C0C2C4B5A59A9C989F
A8B6BCBBBDC2C3C2C1BA9979767A8289908C8E8D897F79756E6B645B503F3F4447494B59
6A6F7A8D9EA5A8B0B3B0AFB1B3B4B3B4B0ACACAC
2828362E2730302F383738343F4A393329302F36392D2B272F48464F5A52323D3D345733
694E262F5C341D2727202A4C84A6836C5C6488B0BFAEA9AAACAFB5B8BEC2BBA9979A989E
9EB6BABEBEC2C4C2C1C2C19E7666686E76787977756C666067655B534D57555D656B727D
8592989FA7AEB0B9B5B5B0ADB1B3B2B1AFAFADAA
262B412C2C2E383433392A34353A302B2F2A2C353A372E323839352E4A462F2B2C386049
6C3E30325F422A25201D232B6D8B9982635D6C8FB5C1ACA5ACAEB3B2BFC0BBAD9A9D999C
9DADB8BDC0C3C4C6C5C0C0BFAA785555575861616066635B6068646456666E737A7C8690
9CA3A6ADAFB3B3B6B6B5B1B2B3B0B0AFB5ADAAAF
23263D3233393F39342F2F2F3340322831292A2B342C2E353335312C47372A2929306555
6C3929325B5B37322E291E233B798CA0785F647297C6BAA9ABA6A7B0B9B9B7ABA39A9B96
9BA4B3BDC3C1C0C2C5C0BEBBB9B0894F454755595D656A6E6874797D7E7D84878994989E
A6A6ACB1AFB5B4B4B7B5B5B4AEB3B3AFAFB2AFB4
262230373235484D463E3C323E432D282C28252A282D3132333A332F57472424262C5465
6C3C23234A6D4145503B27212A457D9D97745B657DAAC6B9A4A8A7ABB3B3B7ABA69A9C96
9DA6B2B8C0C0C0BEC6BFBEBFBBB6B8A36D4E4A5266756E797986898E93919498989EA4AB
AAAEAEAAB1B4B0B4B6B4B0B4AEAEB1B0B1B2AFB5
22292F33292A32405A615F5043463A3A312B272C292A2C3435382B315A582D2326263C69
633D25243A6A412C3440362E2F2B5883A689605D6187B4C2AFA3A6B0ACB3B2AEA5A69B9C
9EA7B3B7BFBEBEBABFBDB9B4B9B4B6B5A5896C64687C7B8A8A8E939499A0A3A3A5A5A8A9
A6AEB1AFB2AFB0B3B3B4B2B0B2B0B1AFB4B7B5B8
2621253725282F384853666E565056433E312C2C2D2D313E38332D2B476F2F2728263864
753D29252C5C662A2B30383226242E648E9A735F596994B4B9ACA0A9A6B0ABAEA9A59FA1
9EA7B0BDBFBEBABAB9BFBCB7B2B6B2B0B4ACA28C7C858B9397969E9FA2A1A3A4A7A4A6AF
A9A8AEB0AEB1B1B2B1B3B6B7AFB5B2AFB6B6B7B7
27292A34372334474B444E687857494F48353127282F28383D31252B4472332A282B3F5E
723E36292B417D3A29242D342E21223E768C906956597290B9B89FA0A7A7A5A8AAA59D9F
A1A9AFBEBEBEBDBAB5C0BAB7ADAFB2B8AFAEB2A89E959598A0A0A1A3A3A7A5A5A7A3A7A9
A7A9ABABAEAFB4B1B1AFB1B2B2B1B0B0B4B2B8B8
363424283D2C3A3F3B3B33476D71423946363425272E2C3C37292827376B4D272A2C3F5D
5D3A3B3B282A5D753E282C282520292B49788775635C66799ABBB0A1A0A4A3A5A29C9E9E
A3A6AFBCBEC2BCB7B4BCB7B8B2AAAEB9B5ACA9A6A6A79B989AA1A4A8A2A4A6A4A4A1A6A3
A9A7A7ACABB4B2ADB0B0B0B2B0B2B4AEAEB1B6BC
404F2B2433373D2F322D2E37426B686547363B2A25222B3B372E26293759642A252A4751
583940432F273C78714130231D1E2020325372767E6C636A839EB4AEA29DA1A1A09FA1A1
A0A6ADBCBBBEBEB5B7B9B7B4AC9CA2B6B9B6ACA3A7A6A49B9A9A9CA1A6A9A4A1A3A29EA4
A9A7A6A8ADB0ADAEADAEAFB1B2B4B4B1B2B4B8BE
3A6234292839282524272C363E4D6369623F3637282930393C2E2B2C2D52642D262D4A3C
3E392931322D2E638C61291F1F1D1F21283E6C8E97847C716E86A7BCAD9D9EA3A09FA2A1
A6ACAFBBBCBABBBCBBBBBBB2AE908FABB5BCB8A7A9A7A6A19E9A9B9CA0A5A6A39E9DA3A1
A6A1A8A8B0ABB0ADADB0B0AEB4B5B6B2B6B8B9BE
274A5432313C2A2525283452483E395A62533D322628293239372C292940663B273B5A31
343225263245344F7A532120231E1E203162678E8EA1887D6A7488A3B2A5A0A4A19CA2A2
A5AFB3C0BCBAB9BBB8BBB9AFA48A84ABB0B9C3B8AEA8A69F9C9E9C9B989EA09E9E9EA3A0
A2A6A5ACAAAEAFABACACB0AFAFB4B4B3B7B6BCBD
2931453327302C26293449613B2E293B55584A392E2B2F3831392A2C2A3C5F412B455D33
2D37272B2E3D364F653F241F2120202C4F7D675F729BA187746F7A84ABAFA3A4A29DA6A6
AAB4B5BDBBBAB6BFBBB8B1A098747DA9B0BCC3C0B6AFA6A2A199979B969B9A9B999BA0A4
A1A3A5A9AAADAAA9ACAFB1B1B4B0B7B5B7B5BDC1
2926363728292B2C3348684B3625322E3E574E35342D3C362F3B2A302A36594B323D4E2F
3137312E422D344E533F23231F20243373865A3156819F947D6F777A90B7A99DA2A5A5AB
AEB3B3BABEBAB9BBBBBAAE929A7681ACABB8C0C2BEB8AAABA19D999CA2A59A989B98A1A1
A0A3A2A8AAAEADACAEADB3AEB3B0B0B2B5B7BBBD
2328292E292A2A34476B5F3B312B2F30334D5C46362D2C35383A2D2C2E334A542F343B28
2F2E3451562A324D51412B2823202B45947B4B202C6687A0907A777F8095B1AA9DA7A7AE
B1AEB0BCC3BBB8BBB9B9AC8C9B7D88B0ADB1BAC0C5C1B6AFA9A4A09C9BA9A2939C9D9F9D
A99DA1A8A9A9ABAEAEADAEAEB3B0B0B9B8B8BAC3
2B282B2B292A2B335A6C4D3F3E3D342F3F41484B312F2A32394732312C303D523F38382F
282C3868612E4A514C482F2722242E6E91692E1D2336698AA28A787A727B96BAABA6A6AC
ADACB3BFC2BCBABAB4B9AF8998878BAAA6ADB4BCC5C9C0B2ACA7A2A19FA1AAA29C96999B
A1A09CA3A6A9AAABAEAAAEACB0ABB2BDBBB8BFC1
252729232D282F45685733474B4E352B2C2F3A423131313039383536333239484B3A3926
272C386A5B3C67434251473733344F9A88512A1F212041788BAA8579707781A2B6B3AAAA
AAADBBB8BBBEB4B4ADB6B2939A8F95A7A1A4B2B9C6C6C5BCAEAAA2A5A6A1A4A6A797939A
9A9E9BA5A2A9A5A8ABADAFABADB4B5B8B7BCBEC3
2B27252C2929314D6E492C3336383E332E2D353D47302D3337333A423131373B483D3526
242E4769594E643C4B59615D565677A68A5E271D1E202A46769A9B83787B7881AABEB6A5
AAACB9B3B8BBB6B5ACB5B399919298A7A0A3AEB6C3C9C7C3B6ADA5A7A8A9A49FA0A69493
989B9CA09FA3A2A6ADAAA9A8AEB3B7B4BABBBDBF
2D2926272E282B576E3E272B2E2A38403F2F353744342C2F34383D373132312E443C312E
313C4B5548595B4568655F52533E68A48C6F36231D1D20295285979B8079727B8EAFC0B7
A6ACB8B5BAB0B2B0B3B3B1A18D90A4A6A6AAB1B7C0C7C5CABEB0A8A6ADADABA4A2A3A49D
95929B9CA1A0A2A6AAABABAAA8ACB4B8BBBDC0C1
3A2729252E39345B693F2527272F3047513E303840422B292D383438362A2B2E3A483B2D
3938334649666C6F79594C3B3B2D5E986A41251F1C201D252E5983A196857C737B93B4BD
A9AAB0B8B9AEAEA9A8ABAE998A90A7A8A7A6B6BABDBFBFC4BFB3ABA5A9ACA7A7A9A7A2A5
9991969B9D9C9FA6A6A8A7A9ADAFB7B8BAC1C2BE
322B32262F3538696D41272A292F2E414C47382C363D302D333732423537292E36413C38
3734323F607269787E50402A35366889582920262024221E24365D91A994847B777D95B6
B9A9A8B6B3AEAAA6A3B0A3948B8FA9B5ADACAFAEB9BEC3BFBAB6ACA7ACABA7ABADA8A7AB
A5A0959394979DA5A6A9ABA8ADADB3B7B9BEBFBE
3F372E2A2C2C3C686D4D2E312C2B2B303E473F32333B353235313736442E2B2E3B3E4039
3232374E636E675C7A3F372D333B8089472524281F24232823292B6291A5958174727BA0
B5B9A5AEADA8A9A1A8A8AA96878EA9B6B1A9A8AFB9BCC0C6B9B8AFA7AAABA9AAACA9ABAE
AAAFA19693959CA3A6A5A9A7AEACB2B0BABDBFB9
4F5247332B2C35666D49342D2A2A2C2E3646463A3B3C392A2B2E2F2F3B353134433E4239
3634445A60633B436A372C2F3450908137292D2A27242123202124346B9BA08F786B6A7D
9BB5B5ACABA5A5A6A6A7A394848DA7B1ADA39FB1BAC1BEBDB8B7B1A7A7A7A8AAABABAAAB
ADAEACA79C9395A2A0A2A9AAADAFB0AEB6BABCBB
5C5C5A43392E3754685A322D292A2D262D4043372E413A322C2E342B303A3C414C3A3B41
353448545C4F3137613A2C2E406F8F712C2E292327262322211F2025367097A88E746772
83A0B3BFB1A9A4A5A4A5A08E8489A4A9A59E9FA9B6C1BBB5ADB6B4ABACACA9A9ACA6A8A4
AAA8B2B3AF9D8A939D9FA6A7A9ACAFAFB4B9BBB7
43424435342E2E5561623E2D2A272D292D343B2E2E383E33312F36313340514C4A413D44
39414D465950292B4B3B352D59888A5E272926242E282323211D1E1F264173A4AC887167
74879FB6BFADA6A4A6A5A38D86809BA7A4ACACA2B0C0BFB6ADACBDAEA7ADAAA9AAA1A7A0
A8A3AEB0B7B59E8F999FA6A5AAB2ADAFB4BBB4B9
50563F2F2E3233515E604D322B2A29272D3237332F313B3332352E333853544848454245
41433A4061562B2E3E40373C57928E5B28272C2D2B2A25242A211E1E21254A85A49C8970
6A7284A0BABDA7A4A5A4A386808399AFB5B6AEA4B2C1C0B8B9B3BBB3A9A7A6A0A8A0A4A1
A5A4AEAFB4BBB5A59B9C9BA4A7AEACADB5B6B3BD
7569472D272B2D3E575F562C2D292F262B2F36342D2B32302D3134384A564F453A3F494B
4540314562582B2D3C3C2C32518E8558313E404B433E2E29262423231F212956829AA088
716C68789FB8B5A0A7A298807B8EA0BBBAB1B4A6B7BCC3BCBCBEB8B5ADAAACA2A4A39FA1
9E9FA7B1B4B6BCB1B09F989CA4A8A8A7AFB0B4BA
786857302C262B363F5B5D362D2F2C2B352A2A2A2B2E30312B37434C54504E3B3F485655
45382838675324232D392B3B629187635651646F63593325212A22241F22282E50869FA2
81665D637C9EB5ABA1A48E7A7B86B0BEBAAEAFB4B5C0C1BFBFC1BFB5AEAAA6A2A5A29F9C
A19FA6AAADB5B9B6B2B0A29EA0A4A7ADADADB0BB
725D342D26292F3C33435847413330302B2D312D3132382F3134465C50533B3F4B4E594B
3D2C2E3A625325232A3731537288876B685E5F5D48352523262A242125242521325B839A
94755A53667696B4B6A589788D95ACBBBCB6B0B5BBBABCC0C2C1C1BDB6B3A7A9A5A5A1A1
A1A6A5AAAFACB4B7B6B2ADA7A4A1A6ABADACB1B8
76522E272B313B342B3C54503D39312C2B2D2F2F352F2E2B2F3E585F58423A415557604D
2B272F405750252A2C3A5C687D8D865C463F362F2E2A31292A26292322222428262F5F7E
937A6669605C7795B5AE8677A69EA7BCB6B4B4B5B6B5BABCC1BEBFBEB9B4B1A9A2A49B9C
A2A4A5A8ABACB0B5B6B3B1A6A29BA0A5ACAEB6B6
765D4335353D392E2B384E5F4A36342B2D333129312F3233394A62594A3E45475254613B
2B2F3648564127282E4776757E8162392A2A2D2F2E3031342B2F2C2E232222242629375F
767C6C755C4E5B7793A38B7AB19893B9B5B3B6B4B8B6B8BABCBBBDBBB6B5B3AAA5A5A1A0
A1A0A6A4A6ABACB3B9B4AFACA7999CA39EA5AEB5
6D5E56434A534433313249665949412E33342A2A302B2F343346614B3B454458555B5945
292D37485036222F3B5A76857C6F4B2A2B2C302E333A312B2929292C2D282A2324242736
5C696E7A6B4F4F5F6F89827DB19785B3B7B4B7B1B6B2B6BBB6BBBDBBB8B4B4AFA9A7A1A2
A3A5A7A6A6A5ABB1B6B6B0ACABA39A9DA5A7A9A7
6A66584F67625D4E463B44575A4F4233342E2F2D2E2B31353D4A55514655444855604C3D
3825384B4F3F282C5E597B806C5E35292D2F322D31323234302C2A31332B2F21272C2635
3C536F8A765649545D6C657CB19A86A7BDB7B7AFB3B7B6B6B7B9BDBFBCB9B6B6ADACA4A2
A0A9A8A9AEAEB0B3B1B8B0AEB1AB9D9DAAADA8A6
766F5C5B7C716A595553494A514D4C3D3E3B3230292A383A484D484E434145455551473E
3B27364C51382636715B79785F5832282C2B2F3A2F2C2D30303631303A2F292A2C292729
2C415F6C846B585559614F72A7A1839DB6B0AEA9B1B7B1B0B3B5B7BBBCBCB7B2ABADADA5
A3A6ABACAFACB3B3AFB2B4B3B0A9A7A0AFB3ACAD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
546982AABA3C232B3223222B3C403438352E31342E2E393A31333A41554B4340372F252D
25313A6D64635C7B6946635D666E756B7A7B81837C8380827D827E8383888A868C8C8689
8B8C918D89908F8E8889878C8D8E8C888B8E908F919393909391909093969492908F9791
8F91989694979C9B9A9D9FA5A8B6C6C8D0D2D4B2
595F6EA3BBA34520261F2C31403C3536373A37343334333133383A434B443F3D312F332C
262C3B6D6065597A5E505C6069717173787C7A7C7E837F8080797F867F8487888A87898C
8C8F908D8B8C8C8C8C8B898A8D8B8E8F8F9291929393938F929291929297959593919394
94919798939A97969D9D9FA5A8B4C3CBD0D1CEBC
5B595B7998B69A3F2A24282B352E2B3743392D3430322F31323D3A4147413F362B2F312A
282B3D696068617859585C6B71706C747577817E7D80848183818286818386898A88898C
8D8D8E8D888C888C908E888C92908D8E8F9294969696939395949199979B9D9895969594
92909696969C9C979B9FA0A2A8B7C5CDD3D0C8C9
5A54566A83A3B47C3A2028262B2731353B3A283030302C303835365142393636302E3029
2733426F62696078555B586671737375797A7B798582827F848380818286878A86878A89
8E8F8C8B8A8A8A8E918F8B8D8F8E8B9192929795979698959A95999A96999E9995959392
9393979394989A979A999CA0A7B6C2CCD7D3C9CB
5D5D56637082C6B6582D24202D2D322F362C2A2E352A2C3036323058393935333030312B
25354972616B6074515F636670707472767D7C787E807D838386818180828B8D8988898A
8B8C8A8A8C8F8E8E8D8D8E8F8E8E919797939795949997929794999B999B9C9E96939193
929A9A98959296979B9A9C9FA4B0BDCAD2CAC6C1
645E5C596172AAC4A6363229222A363229283330373330343130334F4245413A372D3529
272C4B756A6D656954606A6D6E6F71777C7D797B8480837F7F7E7F8280848489898C8B8D
8D8E8E8C8D8A8D8E8B8D8E8E909195989A999799969C959598989A979B9A989996929195
93959796969594949496999CA3ACBBC9D0CAC3C8
63605854577583B7CF9B3227292B292A2F2831323131313434403E3D3C42373734302E29
29204B776C706A605860686E726F6F797A7F7D7A7B80807F807C8184858782888A8E8B8C
8D8D8F8B8A8B89898E8F8F8D909396979A9798999A9A97959A989B9A9B9B9A9B9897939B
99959593919293939192979A9EA2B8C7CEC7BEBF
5A5F64585C7C96A4D2B87B48292A2A34302E353A363533323A44383B413D3A38312C3037
4D365973706769605A5F696B7271777F7E827E7E7E807D82817C848386848A878C8F8A8C
8B8C8D8B8D8D8E8B8C91919194989B9B999A9998999B98999E9F9DA19D9F9D9995969699
9793969395959491909294989FA7AFC2CBC4C2B3
4D5C655761799590C4D0C96D2F32353A31383B3737313535353E3D3D363F3136312F2F25
2A2B606D73596D5F565B696B6F757477787B7D807A7F80897E82838086868E888C8D8D8E
8E8C8C8C8C8F92919193919597999899989B9A9A9A9C9C9EA19C9F9E9C9C9B9C95999898
9A99939694959190928F91959CA3A9B9C5C0C2A1
6F5C5E6E58678991ABBDCAC2562D2C2932393E3E373C3839383E403E3938333034332D29
343060717B556C60555864686F7377767D7D7E817D7E7F827C7B857F838187878D8B8D8B
8D8F908D8D8E90919291929393979A9C9B999C9C9D9A9D9D9F9C9DA09D9C9D9E989A9A98
989695979394958F908A8E8F959EA6B4BCBBB49F
965F5E7B6164758289AAD3CE9844302530303133302C3538373A3E393B393832362E302E
352E64757F5A64565459656C6E72767479797D787C7E7B80797B87818382868587868C88
8D8F929091908F8F9190929092939A989B9A9B9C9C9C9FA4A39D9D9E9D9D9D9E9A999D9B
97939695938E928D8B8B8C8A8E949AAAB3B1A5A8
A78E63656A696A697598BCDAC67F35262C2A2C2C2C2E2A31333B40392A2D3635312C2C2B
322D6B75825861555059676D6F7273777A7C7A787E7E7A7D7E7E8181838387868B898A89
8E8D919092908E91908F9394939598989D9C9A9B9C9A9D9D9EA09D9CA0A09B9C9E9D9C9A
969396949492928C87888688888C909DA4A09194
ABAD7152786764636D899CCCDFC8542827232D29242D30363439463D312F302B3028281D
2B2E6A747A5863535159696B7378737276787A787E7A818282827E7E818585858A888689
8F8E91928F8E90919391949B9796959A9A9C999D9C9A97999D9FA29D9E9F9A9A9B9B9597
959691918E8D8A8A8283838685878A93928D8586
87A3976B6E6A6D757B808DAFC7C696173818262422252A3646424B41352F2B2E2F29292A
3030656F7A60615555576666706F7174747A7D7D7E7E7E7F7F828281818386898986878C
91908E919191939392939296969694999B99969A9E9B9CA1A2A09D9C9C9D9B9A9A949896
9690908D8C8884847E80808183848A888D857B7C
666E796E6477837B837D819BB2BABB553224252624242E3F4B524C3D3B3728272A2A2E35
332B616D7B6C5A514F586A686F6F747674777A817D7F7B7D81828484818487898988878F
93938F93949195959193918F96989599999896989D9E9CA09F9D9CA09CA09C9896949694
958B8988847F7E7D797F818484868483837A7774
474E686D7B858C8B8E8F97A5B1B8B5AC5E4A2821262726303E3E3632353024282E2F3031
342C63697768544E535866696B70787275787C82797F7C817F868182838888878A8B8F90
909190938F9497959195918E99979C9A989B989A9B9B9F9F9F9E999C9FA1989391979392
8E877E827C7D7C807C81858387848785827B7370
323D44638D92909AA1AAAFB0B6BCC0B6A984241C262526292C282A282C2F2D292F2C2D27
2B2C656C735D514D525C676C6A707471737B7A7E7B7A837C818681848688898C898B9192
928C919192949696959793969A9A9D989A9A9B9C9C9EA09E9D9F9E9E9E9E989293949492
8E84787B77777E838181817E818483858079726C
1F2630458C8D9FA2ADBBBFBAB2B9B9C9B89B422926222327272E28292C29372D322F3027
2D2C616C715D4D4F565A6868696F706E7577787A7B7C7C7E8380818583888888898D8F91
938E93939392979897979596999A999A9D9E9E9E9D9E9E9F9EA19C9C9F9B979897948F92
887F747C7B7E837B726A625F60686F7268676263
21201C2E899EADABACB6C0BFBFC4C2CAB7AA5A3A1E1F282F232A23232E2A2F32322F2E26
2B245D6C70604B525656655F64696B7375777A7F797F7A83847B8285838687898A8C8B90
9390909295979797949797959595989E9A9E9E9D9E9E9CA09C9CA0A0A09993949393908E
837C757A838B88756A54423D44535D5F59575456
2018202560ABACB2AEB1C4BCB5B8BBBEB3C5A07A2D2628232027211D2228322E2F2F2A22
2A255E686E5F494C515A6162656B71777576787A7C807F81857B848786868B8A8A8E8C92
92909395989A9596999A9A979698999D9B9D9FA0A19C9E9FA19C9CA19D9A9595948F8E86
8279787D848988766F5336313845575E63666665
22221E1F2DAFA8BAA6B0BBB6B1B8BBB6B2AE9C9D5240342926252225232E2E2A2C2B291E
2E2B676561544E4B50545C646068737677777F7B797E847E7F7D828787888D8D8A8F8C90
8D8F8F939898939498999B9A9897999A9A9B9C9D9E9BA09D9F9C9C9E9C9D929092898C83
7D78787D898789837B56352F344350617077787A
2621191D1F93AFA2ABB1B4B0AEB5B8BAB8B3BBC6A6714C2E21232122202A252B2B2D2A22
29385D5E63534A484E515B62676E737478777F7C7A7E827F827F8282858B89888B8C8C8D
93919394989897949797979696989B9FA0999A9F9D9F9DA0A09E9C9F9E9C979292908E7D
7875767C828889847D7C7C787C8388827E7A7B7B
26211F172063B095A9A8A7A6AEADA8B4B9B1B3AEAD8A6C5234252A23222B2B2F2D2F2C27
223D5A666850423F44505C5F666C727776767F84818382817F7F8383838B888D8E8F8C8B
9392928F929798999697989697969B9D9E99989E9FA19F9E9F9C9D9B9A95948F8E93907F
717171777E8B898D8A838484848484888B847E7D
2C281F14194192A4A9A4A1A7A19D9B9297A3B9B7B8B29C694A211C1E24232F302A2B2D24
26325D60675A4442474E5C5E676D727A76747E7F7C7F81827E8287858687898B90918E8F
928E9090909497989695999B999C9C9C9E9E9A9FA1A09EA19C9E9E9B9C939391918F8F81
6F6E73747D86878F8C89898E8F8F8F908D887B7B
272C2B1D1D3177AF9EA5A2A1958D88827676829AB5BDB18B651F24222626262F212C2B22
31276566685A4642464B5B5C6A6A71767879807F7E7E8281807E828888858A8C8D8E908F
8E8E9291959897989599999E9E9E9E9B9CA19EA19FA09F9D9C9EA09D99969292918A8C7F
746E6E767F83898F908A8A8A8F90908C88877A7C
2C292B262427498797928E8E837A7566717181838E979EA4723C3D2A2120262E2C252044
242360745C5143424A4B575C636C707575767D7D7A807E8186868088858A8A8B8D909193
8E92949698999897969B9B9B9A9F9D9D9EA09D9EA1A0A1A4A1A3A29E9A9B94928C8C8984
766C6A737E808A8B89898A8A8B8E8B8884807B7E
1F262C291F19245175847B7F756C695C6E99BBAFA99D8AB18350462B21261F2A2527311C
2F2558774E4C3D434C50555E61687077747A79807C80827E7C858386868C8E8B8C909190
909592989A989B9597989999999A9C9D9DA09EA0A1A09FA4A2A0A09D989996928B8F8D7F
757170767B7C87878B8888888E8B88837F7E7D7E
19302F2F2920192B517260757E74686B748BAFC8B69E7E946F321C142823282625292C21
2C265A6D574839444E54535D6069707471777B807E7F827D838589878888868A8C8E9394
92959498979A96979697999C9A9C9E9F9EA0A09FA1A2A2A3A3A2A09B999797948F8C8E85
7C767275797B868587868889868282807F7B817A
2A2A2E2C2F251F1F2A564669838474717F8A9DD8CBCAB4AEA24A2B1A21292521242C2727
292960625C4C38464950556262676C7378777A7D7C8184818781898488868687898E9095
97969595989997989697999C9C9CA0A4A1A2A1A2A4A3A1A5A4A29F9C9D96959292908E89
807F7773787B8084868686847D7D7B7C7C787E7D
2728312F352D1D1D1F312D5F87927575777B89C2D0C7B8C1C178371922252E2A25282522
272A5F5859473B3F4E4F585E606D6E7673787C7C8381848385858685898A8A8A8B8E938E
9696969699989498999B9B9B9D9E9FA0A1A2A8A4A6A5A29FA0A2A2A1A098999490918F8C
84817A797A7B8084888886837C7E7E7979747B79
21273230302820212217194C7A9D7577727A7EA3CED6CADECDB34E272423292428272421
26235956564741404D525864636B6C7B77797B7C8181848281878486878E91928F8E9393
97969794989A99999D9E9B9B9E9C9D9EA0A3A6A5A4A1A09FA2A2A2A09F9A9A98938F8B87
86807F81817C7E7F85828482797D807A797A7879
20303C4A3A28212623191A426786867A6C73828ABED7CAD7C9D09F372C25252628272724
2B2052604B423C3F4A505E5F666B6F77747C7E7A7D8084837E88868987888C8F8F919190
949699979798999DA0A19E9C9E9D9EA3A4A5A8A5A4A8A5A3A0A7A2A4A19F9B99948F8D8A
8B848585817F817F8380807F7C7C7A7B7B7D7C7A
22364D6C501C23201D1619304D7D938670727F70A4D2BFC9D1CFD2862F24272A2321241F
2F1B4D64403F3A43484B5A606C6A7376777E847E7C7F8380808987898D88878B93959391
939A9A9B989CA3A1A2A09D9EA0A5A2A8A7A4A5A8A7A8A8A5A4A9A1A3A6A6A0999692908D
8A85858480838784837F7D7C7C7D7677797B7C7B
2D4154907840231C1B1A1925336F9798696B737292BDC7CFC9C9CEC76621201E27242622
282A44603C3737434B51585F69696C78777E7F807F83877F808787868B88898D92959797
9796989B9B9FA3A1A69F9CA0A2A6A5A7A6A7A8A9A7A7A8A9A6A6A3A4A5A19F9A9995918B
8A8687838484828684807F827E7C777B7B7C7D80
3A4A6290714C282119211A1A22638FA36F6E737687A0C6CEC7CFD2BCC245291F25202820
1A383C5A3E39393E42525865686E6D75787B7E8182808183818284888A8E8B9292929499
999A9E999C9FA2A0A2A09FA3A7A9ABA7A4AAAEAAA9A9AAAAA7A7A3A4A5A09C999B98938C
8888888382838786857F8083807E787A7C7B7D7C
4461829C885C291A201E201A244175A37F767071809DC2CAC9D2CDD0C2A94918271F2627
2327455B3937313F475659686370717675797B7F877E858784858487888E8D8F8E929796
9A999EA09DA1A0A1A0A2A4A5ABAAADABA7ABACAAADAAA8A9AAA7A3A4A89CA09E9896938D
888885878484868785808081807A7A79797D7E7D
5171A0A59A6426201F23231E231A599989846C657496BCC5CCC9CCD3CEC58C31271B2A24
2D1A47593530303C49515C6666666E74757A797F857F8685878685898D8C909291959998
97999E9E9F9FA09F9FA3A3A9ADADA9ABA7ADABA8AFAFABABAAA9A5A4A5A0A39D9B969591
8887848783878784848382817F7A7A7A7A7E8280
6189AFA68D4C2D21282328232B22427D8E92686570899ECDC7CCCACFCCD7B26E22212525
262540443A3837424C555765696E72797A7A818282827E848285858B8A8F908F93959897
999AA09D9E9FA1A6A3A8ABABB2ADADADABAAAFADAFABA6AAABA9A8A7A5A4A09A989A9491
888886878886888888877F80807D7D7979828282
7498B29C6F2D281D252929252C26305E8D9F67656E7A85CBC7C7C6CACCD7CFA72B242821
2833413D393B363E4C585E65697072737880818080848087888C898D8E91919196979799
9A999C9C9BA1A4A9A9A9AAAEB1B2ACAFB3B1B1AEADABA8ABACABA9A3A1A59F9A9A999591
898C8785878786888D8B807D7F837D7C7C7E8587
979A90734D282A282325282626232B4687927D6772777EA2CDC5C3C5C7D7DCC576322320
202D37412F363A43505361656B7277777A7E7B7D8184848682848E8F8D8F909198999897
98999C9C9BA1A3A9A8A6ABAFB1B0ACAEB2B0B2AFAFAAA8A8AAA8A9A6A6A3A19E9A959892
9490898A8886888B8C89828080807C7D7E7E8182
AF976A472B232F292020232524272C337787976276708381CEBEBBC5C7C9CFCBBF402D21
252B2E49292F3643455760686976797A78807C7F817F898686848B8E8B8E92959594999B
999A98999DA4A5A6A7A7A9ADB1AFADB1B4B2B3B0AEADA9A9AEA9AAA7A8A3A29DA1979791
94908C8C8B898E8D898A868282807E7B7F7F8485
9877453621232823221F2127241E222C5479A077736E7B7AB7C4B7C0C6C9CDC8BFA4361E
292F2D3F2E343B42495561676D757B76777C78808285858386848A8D8F8F8E9295959699
9A989A9CA0A1A6A4A7A9AEAFB4B1B2AFB1B1B3B2AFADAAAFB0ADABA5A6A2A29C9F999492
8D8C8E8B898F8F8E8C8986847F7D7B7B7F828387
76572A221F28262721242524231E1E2E396A9F8F726E75709CCCB8BEC1BCC0CFD3B76A34
292C3433342F363F4A57646C6F767C77757B7F80828988858686858D91909391908F959A
999B9EA1A3A3A7A7ACADB1B1B3B2B0B1B1B4B5B3AEAFACB3B1ACA9A8A7A8A0A19D9C9691
8C8F8F928B92948E898A878483817D7C82838386
55412825222923262724272729251E24275C8C908466727186B8C5BDBBC0C1C3C4CAAF3F
342F2C2B322D34435157646E73747276787A7F8381868483858188888F91919391909298
9A9D9DA3A4A7AAACACAFB1B4B5B3B1B4B9B8B9B2AEABAAABAEADA9AAA9A7A39E9F9D9B93
9395928E8E92938F8D8D878683827E7E84858383
4134322826242D2D26262F262B23241D1B48768B9A707E6D78A1C9CAB5BFBEC0B8CACD8E
2D2627272E2E39434F5B5E69727878777B7B82827E827F82888786878B9095999295979A
9AA0A4A8AAACACACAEB2B1B3B1B3B4B8BCB9B3B0AEACAAABADACA8ABADA8A09E9E9B9D97
979692939491948F8E8A8B8787847C7F80858684
522F2F36412D272A29282B2D302A231D1D3D5A82A27E7470788CBCC7B5C2C2BDBBC8CDB4
6D2B27262E30373D455561677170767B7C7B817B7B7D808685878A8E8B939799969A989C
9DA0A6ABABAEADAEB4AFB3B2B1B4B4B7B8B4AFB1AEB0ABAAB0AFAFACACA9A4A3A09C9E9A
93979592939397918F89898C8581817F81848683
6832332C1D262A332B2D262B312E222423313F70A29073767771A7C9B3BABCBCB7C0C5DD
AD3A262233323540445360696F73797D78787E787B788087858A8E908F92969998999D9C
9FA0A4AAADB1ADAEAFB3B5B3B4B2B2B4B2B1ADB0B3B1AAAFB4AFADACACAAA8A6A19F9C9E
979398939294958F908E8B8A8584857E7D808380
5132302E2C2C2B302A2F2A30312D2D2B2B2D306186A0826E7D708EB2B9A9BCC1BCC8C3D6
BDA541222825353D4453606B6C767878787B7F7A83848185838C8D949193929C9B979E9E
A4A1A6AAABADABACB0B3B7B2B5B4B2B2B1B1AFAFB0B3AFB0B2AFB0ADACA9A8A5A1A19A9B
9B9597949395928F8D8F8B85868485818080837F
3D342B2F2933292D2B2B302D2D29322E28272E44649F9964806C759ABCA3B9C0C0C5C2CE
D6BE783A1D1E313A43505D666A73737F7A7A7D7B81808488888B8C929592929998999DA1
A5A2A7AAABACAEAEAFB1B2B2B3B2ADB2B3B4B3AFAFAEB3B1B2B3B4B0ADACA8A3A3A19A9E
9D9392929392918E8E89888484838385837E807D
3E382D2E322C3431302D2D282D262E282B2D25314A8DA37B756F737DB3B3B2BBC3BFC2CA
D4D9B1513027293846535565616C747D747B80817C7D8288858A8B8F95949897979B9FA1
A5A4A8ABAAA9ABB0B1B0B3B4AFABAEB2B2B3B3B1B3AEB2ABB0B1B1B2AEADABA6A5A39E99
97939194939590918D888884858583858280817E
443B292F352D3033302C2E31342C31292D2A2B223470A38F6F6A7569A5CCA5B8BBBBC5C5
C2D4CBB034342430404A5363636E74787878787E827E808A868C919094949A95969BA09F
A0A5A7ADB0A9AAADAFB2B7B0AAA7ADB6B3B0AFB5B4AEB1ADAFB2AFADB0AEAAA8A6A4A098
949095939592928F8F898588828585827F828586
3F32242D3A31312E2C2D2E2D333229302B2F2A26335393A782626C6893BBB8A7BEBCC1C0
BFCBCFC78B34323241494B5C656D74727573817D837E81898D8D8B89949799999AA1A09F
A0A7A8A8ABAEABACAFB3B0AFA9ADB2B4B1B0AFB0AFAAABA8ACB0AFB0B1B2ABA8A49F9B97
95969491909092908C878587838383847C7D8285
3D2F202B3035302A2A282C302B2C2C302B2B2924323472AE97616768799DC5A2B7B8C0BF
BFBFD0CDC979322C3F494F57636D72707A757D7E837E847E868F918A959A9B9A999D9EA0
A3A8A9A6AAACABAAAEAEB1ADAEB0B5B2AFB1ACADACA7A6A9AEAEB2AFB0B0ABA89FA09A97
96938D8D8D8A96918D878681818381837D7A817F
342D2732322E332D2F2B273029322E33332E2D29302D52919E756F686992B9B5A7B5BFBC
C0C3C8C6BCCC60313A424F585F6D6E707571787C83838483898F8C919597979C9C9D9DA3
A7A5A9A7A6A4AAAAAFADADACACACAFADAAA9AAACADABACA8A9ADADB0ADABABA8A19F9898
96958B888D8D918D8787848181818282817E807F
31313039392D302C3030252A313631323031332E282B366BA38D786E648CA4C69FB2BBBE
BDC6C0C1C7D4B1453A3A53545C676C7377787F7F807D86858E8C8B8D9597989B9D9D9D9F
A7A8A8A7A0A4AAACAEB1B0AAA8A7A4A6A8A7AAADAFB1AFA9A5A9A5A7A9ABA9A7A59E9F9B
929289868D908E8C858383868282828084828382
312D3234382A2A29272A2C323136352E31333133292336498B9F8A5A65798EB0A8AEB5B6
BDBEC3C2C7D3B8A8503447505C666D6B7576797B7E7F83878F8C8F959595989C9C9EA3A1
A7A7A9A1A1A5ABABB1AFADAAA7A3A6A6A6A9A8ACAEAFABACABAAA8A7A9A7ABA5A5A7A19D
958D8A878D8E918E898886878281827E81848182
2D302D302C2A2C352A2C2B303731362E35302F312D2537276D9F9959686B7796B5B3AEB5
B8BFBFC3C7D4D1C68B3C40475E646B6F7274737B7D88858B838B8D969597979C9DA09EA3
A5A6A5A2A2A3A7A9ACACA6A5A4A2A8A7A5A6A6ADAFACA9AEAFADAAA3A6A8AFA9A5AAA59C
948B8D888B89948F8B8787898381838180848280
2B2E2A2F2F322A2D26292C323833332D3034313026232A2549819D826D64688DACBFADB4
BBBAB8C2C3C9D0D7B382513B515A6969747276797C84868B82898F9696979A999E9A9C9E
A1A4A4A4A3A4A3A2A2A29C9B9E9EA3A29D9FA1A5A7A4A6A8AAADABA5A6A6AAA7A0A4A9A2
988F8B8884858C8D8E8886827E8282807E858485
2D312B232C332E28292D2B3035312F2E2B2F2C2E242127232F5E8FA5746765809DC5A7AD
B2B4B6BCC0C2CAD2CDBE7039515362646D7172787B818487878C9295969B999796979B9C
9FA1A1A0A19D9D9C989994949699989798989D9D9EA1A0A0A5ABA9A7A7A7A6A2A0A5A7A1
9C9287828182898A8A8C87837D8183807F868686
2B2C2D2E2F332D2A342D333238322E322E2D2C2D1F2024262A427C9C927364798FBAB9AF
A5AEB4B6BCC2C4CCD1D0A2664D52596165707376798587848D8F91919A9B9C97989A9998
9D9A9B9A9C9C979694958C9193949292929696939A9D9DA09EA5A3A6A4A6A4A59DA0A4A4
A194878484818387898D868181837F8080828887
282E302D2F2C30302731322F3130302E2F292D2B2824261F20226087A38068717EA2BDAE
9DAAB0B8B5BBBDC9C5CFD19C5B5E4F57676B7475798581818C8C969193979B9B99979794
98969A989494929392928C929194908C8D90908E8F959699979B9E9EA0A7A7A39C9DA1A3
A4958D8281808488888B878482827F7F7E828488
2B2F313232302D30272B33332D2F302C2D322D2C27282421241A446F9A936D6D6E88BDA9
A1A8ADB5ACB4BCC2C8CFD6BDA15A5451586B6F7778858387878B8F8D9494929694969596
939390908E91939798908A918F8D88858B8589868E9093829498959A9CA29E9A97989699
9E958E817C7F83868484878386807F7F81828A8B
322D2D3332322F332A312E322D2C2F333335352B2923251E1E1E255988A478746566B4AB
A5ACA9B0B1B7B5BFC7C4C8CCC59F59554E606972787F8082838A8A94938C8D9191919696
95908D8F8D909397978E86878C888380817F88888D888B7294929199999D999598909292
95928F8475787E87848583808283817C81858C89
262A2F332D262F2E2D2F30332E2830393734382925232026211D2442648F8B785A6894B7
B5AD9E9FB2B1B2C0BFC4CACBCDB69C545B56666F797A7F818A8A8A8F8E8E8B8E92929394
9194908F8C8F92969689817A80817D746C827E85868D776E877F7B8E9E9995949F9F9794
928F8880757B7884848882817E877E7C80878E8F
262F2F2B2C2E2B2F2C2E32312A28323138353029262A26292218202C44779C855F6374BD
BBB0A3A0B6ACB5C2BFC2C8C9C5C4C59A5856666C757A7F8688848C8C8A93888C8D928F8F
8A918F94908C8F8F8E857E77757A7B6F57867E8C7F936F76887472879E9C939AA6A9A19A
938C817C77787B81827F82858087857D80899397
2D2F272A2A2E2B292C2E302D312F2D312C33312D2D26262328211F1F32529192715866A1
C2BFA9A9A8AEB4BABBC7C8CCC9CDCBB38E7162636F797F7883878583838C868B9091938A
92948F8E8B8F838A8B7C7D6E69737C6C5A787E8787835F6C79635B78A3ABA0A4A8ADABA5
9D9284837A7B79787B81837E7E817D80868A8E95
292C26222B342C31312E2D302C2D2B2A31373031322D232623272121223374A68C4D6185
BCBABAB4A3A7B1B9BCC0C3C8CDC7C3C4C28D5E5D6A717B7E8081838486847F8D8D8F8F8D
8F8F8F88827C737B837F7A74646C786E66718D8B918F969EA7A297A2A4A7AEABB0B2AFA7
A2958E847D7D7E7A767B7D81808183878585949E
252625202A2D3430312F32333C323132352F313637312425272225202727578A98795A6F
9DBEC6B1A39FACB6B3BCC1C2CDC3C5CCC6AE8E6D6062767C7F808481847C7D898E95928D
8F8E90848375716465767372747B87878A9294999FA0A5ACB5B2AAABAEB7C6B0A19C9D93
8A878483827D8077797B7B7C82808286808A9593
2D28232625282D3831302F38433B36313431333436382D2D262323292B223C6594985860
7DAED5B8A1A0A7B3B5B9BCC3C8CFC3CABDC7BA8F5E61737D7B797F7F83807F8791918D8F
8F89807971706657555E6C7C88899097A1A4A6A5AEB6BCBFC0C2C5BDB6A8A29990908A7F
74798282877E7B7776737E7C87848080828C9997
2A2F28262D3133342E2F2D373D362F2B26292F3637322A27272124191C45265780937C66
6083C4C4A19DA0A7B7B9BBBEC8CCC6C6C5CEC8A992796A72777C7D7A7A7E7B848A97898B
847F78645E646158636A727F888684848788A0ADBFC2C1C8CACDCEC9C3B3A6998C8C8B8C
6B757C7F827A76757B757F82807F8188858E8F92
2C312E2B272B333C3D302B323936332D2C2C282E3130272A2B2925202D1F37455A7E9777
565BA6C9A6A59BAAB6B8B3BEBFC8C3C7C3C2C1C6C2966C6A73747A7674837C83848D8889
7D76634E40474F5F7575777D87786B67646E8AA2C1C9C5CACAD1CFD1CDBFAE99878E90A2
6B70797D7D796F7575787C7D80808582828E8F92
33352B302C29354B5741272B333B342E292A2A31332F24292925261D26273031485D8F84
584883B1AA9990A4ADB1B1B6C0C8CAC8CBCEC1C7CDB897816B6B7478757C808282867C7C
77675C423136485C707D7A77706051464D51647A94B9CFCCCED0D0D0CAC6B7A791867F86
666E827F737776797D7A767C7E83828987929296
3C3329202B2B35556F51292A31352E322A2C2C3635322D312B27242B292E2B2930397E90
644A6988AC9D958F9FAFABB3BAC1C6C3C6CAC6C6C4C6C59869626B747882817C717C7471
6A5D47332D31465D68717A6C5246392C35373B4E6C9DCBD3CDCFCFD0C9CCC1AFA0827465
66728072646D7176777A71748384878A89939495
392C28202C313B6C714B37262D342D2D2B29293539302823252C2D2D28282821232A6383
71555D7C9EBBA29F9DA09BA4ADB7B9C5C5C7C4C7BCCDCBAF957A6B696F7B7B73676A6455
52453F2F2E394F646C77735E3F434C526354483F4E68A6CBD0D3D1CEC7CFC8B8A0775758
6780776861676D72767973777D84848985949A9C
352F2D1C2C31418074413D32282B2C262C2A293235342627272E2D282622242723354C68
8A75566D89C2B6AB9B99959BA6AFB3BDC9C3CECDC5C6C5C7C29D605E6D6C746562525349
483530293140476676725F493A48675B52595C453D3D83C2D0D7D0CFD0D0C9B7976D4A52
61806163616D716F6D7272797B86858589919695
2D2F2F2D292C508E61324634272822282E312D3A36322A2A2A2B33302928292E3A3C4152
85906F686CB5C3BCA59FA5ABB1B4BBB7BECACFCCC8C8C7CCCFB4916B5E606A5F5D44483A
3B2C313135404D6270624E4155575B483A455359472E61B6CECDCCCDCFCAC2A27E594258
797D5D6065727572707983847E8687888B8D9295
2D2E2F2C2A2E6896482440352A26242D292A2A3435302C31293033342F33253D50434139
76A38A6F578CC8BFB7ABB1B6B8B4BAB2B9C5CCCACBCEC8C9C4C7C37A4C595F5951403A39
342B322F3233475E6E523B2F695747382535486F542D45A2C7CDC4C9C8BDB38D654D4560
866D4E5F7876777271757E838584898E8F8B8F97
352F2B253338777C382C34302C272C2C2D2C3130352936292132464E43392A1C1C1B3231
548A988A576FA5B9C3B4A8ACB4B4BDB9B4BBC1C8C9CCC3CAC6C5BBBB6F594D525B4B403A
322B27282F2F3C505D47313557453C2D1D23375D4C304597D1D3C4C2BCB68A66473B3F55
685D4B637C797B7677787F8683878A928E919598
34263429343F8A5F2E2B283231293027302D2D3331323B36343A50534D3C2B2929211B20
33699DA3616978AAC8BBA0A5ACB2B1B4B5B3B8C7CCCFC5C1C5C7CDBCB56B4A4758534E47
42302D292D2D3541474028363C333126262B5D4F445A86ADCED0C1B1A3A15F3E2D2C3D44
4845486680807C7C77798286858A898F8F949592
2C32403F30558E4C302F31312D282A2B2A24233751575C5A4F5B6C5239302A2925211E1A
2C4B8D9E866D5D90B9C9A6B1AAA9ACB2B0BCBAC2CFD0C1C4C2C6C0C2B3B76C434E4E4F41
423132312E2D363B39383136373126292C2F483D3C55749BBABEA693726A3E2F29282C32
2F3D556F8186817D7D7D808A8B8D8E909496969A
2D384F572D62893F2C2A312E2B2627292827294B6E707674644E342E2425282C1B28271C
282A7392A17B5880A7D8B3AAA5ABABB3B2B5BAC3CCC4C9CCC0BABCCCCBB6B15144404A48
44363633302E2E2E2E30333232322E302A2E2F383B4C62899FA0866D4B3928272A282325
26455D77828C847F7F83838287908A8D91969696
244F4449305C7F3A26262F29262729242A2C4E647877745A48352C272326322C27292D1C
241D4976A694607784C3C5AEA4ABADACB7B4B7C1C6CBCCCAC4BEBAC0C2BBB2B667404544
403C363833352E30302F31342A322E342D2D2830353D4A657A795F4D362D25282927272F
3F596F82878788817E8181868A8F899295989B99
34553733315575372D232B281F281D272B2E707F7A6E603F2B2224202B31312B27272C22
231A245F8FAE726F749DC8B6AAACAEAEB4ADB9C2C2C9C7C4BDC0BFBBB9BDC2C6A7574948
45473C3A36312F3E3432373735373232312B33342F2F34494B4738342E2C2D2C2926273E
587185878785827D7D7B8388898F8E90929A9B9A
4B40362D2E5B652A261F2227282A2527365B7474654B3A322626282631313428301D232C
1C1C21446CA68D7F707BACBDBFA1B1A3B4AFB5B8C1CACAC8C5C1B5BABABCBDCEBC864F40
3F4548453F403F3332373539333127322A292D33313033393633312B2924232C2B2E395D
76868A8582847F80818482899090919397959F9A
5F242D292A6A602A2D212825242D2A3B4481755F422F222C292E2F2B333032252823282A
221D21314796A08A6E5C8FC6C49AB0ADAEB2B7B5C5CCC9C5C8C1BDBBBAB4B5BCC7D29169
485051514A4C403833423F393635373735303335352F322E2D2D332B2B26262E3B364E76
8D8A8A837E7D877C7983858A8B8E94969F9C9E9D
4C282A33345F632B2E2A2522282F374F577864532D2E262630342E2F2A2C2A2D29202F1D
372D23222A6E939C835B74AABAB3AFB4A7ACB4B3BECCC7CCCCC4BFB3B4AFB3B0BEE5D39D
5A4A51535D5D4F4A4948503F4144413B413E35302E353E443F352E31362E35404B77605C
788D7D7A75797C7B777D87848B91949B9F9C9D9F
2B2D2A3339485E2D31262726282F405A69604D381D2B2D2A2D2F2C322F2B2D2C2C2A361B
513926181B4A76B089626387A5D2A8ACA4B1A6B3BAC1C3CBC7C5C4B8B7A7ABB0B3BBC2B9
AF634C4C5F665B6267605954474A494C514D412F2F3552605B423039423C415772748754
6483747B77747474777880888C979D9EA19F9FA4
2831253435575F3429282722253343626D5F3E2B222A282D2A2D2E2B292A2C2A2E22222D
4A2F19151D3B55909E756A738CB9BBB6A3A4ABB4B9BEC2C7CCCCC1B5AFA9ABAAAFBAC5CA
D6CA7C625E606A6A6C6E69645E5C62626661584030496E85977852465E664D5D757B845E
657A74746C6E6F6B6F7582899595969A9CA1A29F
2A2E282B3358463827202C242C3755676A562D242A2227292D2B332F28222B2426435154
3F2A1D1F2326396BA38F746C7298C5BBACA6ACACB0BBBEC0C2C9C6BBB4A3A2A5A9AFBBC0
CAB5B88964656C6D746F75717C727F7D80797A4F345B84938E887C587B87575F6C737A70
65696C5F626467676C7988939F9B9FA0A2A5A5A1
2F2A2F262F59393A2B252B272D4055636D4336272925252C2C272B2F2B223C3F42747659
352D44221F18285481909081798BA5B1BAB0A4A8A9B7B8BAC0C9C6BCB39C9D9AA2ABB7BA
C4C0C3AA8C7B6A6B7B757D808682888C8A86836958779BA09E968874818B715B696D6A61
5D5C5C535150575F6F7A909AA7A8A5A9A6A7A8A8
1F262E282A4B2F3B353123282F415763632D43272723262A2B252C2731265B5F55724D23
2D3E5F2825131D355E88A89778797EA5C7BBA0A7AEB2B5B7BDCDC1C7BCA99A949CA3B2B5
C1C8C6CAC69D767381848284828695928C90847F758FA1AAA3968F8A818389596D605A55
52544A4849464F63748897A3AAA5A3ABA6A8ABAE
26272B384474554939424B55414C4D5D3F31343E242B292728222928342A41616F845421
2A504F2B2B231B273E77A49B89706B8DB7B9AFACA8A5B3B6B8C0C9C6BFB2A3999EA0AAB5
BAC0C4CCCBB3A17E6A717D848C88999A99958E8E8C99A5A49A94898A7E74735558555148
454441444E5865778B92A2A7AEABA8A9A6AAA8AC
2029212C294D3B40393A354D2236465E2A2E2848262126252A2624282E53675E39645E2C
375C44263E2D1F2229538C9398715E7A9AB3BDAD9EA4B3B9B8C0BCC7C0BBA496909DA3AC
B2BCBBC0C8C8C1AD9380747D91909498999B92979C9D9D9C949085776D6757564A46433D
3C3F444B56697D95A2A8B0AEAAAAADA7A8AFABAF
2725282E25413C45443D3348343E4A4E3130303C302E2B262928243543756A2327476328
4A5637274934231B254566869E8D60657FA0C2B2A5ACACB0B5B7BFC0C3C3A8A098979EA9
AFB5BFBDBCC4D0B8AD96827C82868D949B9691999B96898789826F63575144474446404D
4E555D6D7A8C97A4ABACB0ACACB3B0B1AAB0ADB1
23292F2E2B2A37494F44393638384D392E282E33382C2B25302C29445A75444835485B26
6058271F593C1B182A34387397A26E595D7FABB1AEAFA9AEB2B6B5C3C3BEB8A796979AA2
AAB5BFBDC3B9C3C5CBAC8F837481838891968F8888837A716E6C66564D473A40484C4B58
67747D91A0A5ACAFB5AFB1B2B3B3B5B1B0ADABAD
2529322C23292F3F3D382D373A3A43312D2E332C3A372F30364253475755323535385C3A
644C2C275B3F2217231F3044899B8966556A87A8B9B5A6A9B0ADB3BDC3BDBCAF9E97989F
A0ABB9BEC3C3C5BDC5CFC99F6E6564716F747973736E696663635E58535054575F666A79
868B90A0ABB0B1B5B8B3B0B0B5B4B3B3B1ADACAF
292A3D36293131372D302F363B34352B2D2D2C2F3A302A3238353426513C362E362B5F4F
67423326694627251E192722718AA27D62626E87BFB9A9B3A7ADB3B1BEC4BAAA989C9C9B
A1A9BBBFBDC6C2C3C3C1B8BAAF83505956606461626160635E6666635B62717679838991
9AA5A9ABAEB2B6B4B7B5B3B3B2ACB0B3B1AFABAD
172D39363133443B3332303334392D2A2E242E2E37342D2C2F35372D532E2B252F285F5F
653E2F1B5D57323A382B221D4D6A968C826C5C789FB7C0B0A5A5ACAEB7B8B7AE9F9E9994
9CA6B7BBC2C2C2C6C0C3BFC1B5A5914649424E565F66656E69717777767E84898A93979E
A7AFAEB3B2B4B4B6B7B5B2B3B0B2B2B0B0B0B1AF
24252F31313A3F46423E3B3A334D2A262F282725262B2F373A35372B5A442C212D205565
5F4A2319576A464E413D252125507F91977C585E7DACC7B5ABA7ACA5B8B4B8ABA1A19A98
99ACAFB7BFC4BAC3C5BDBCBDBBBCB79E6B514854636C717B7B838B939493969898A1A6A9
AAABAAB1B0AFB1B6B6B5B1B1AFAEB0B1B0B4B6B1
202B322D2C30374C5F5F554C434D3B38312A25272B2B2C30332E2E25545F222526244C60
713B24203D613631353933301E3852879F8F6755658BB7BAB0A0A3AAB1B0B2ACACA09B99
9DA9AEBDBDC2BBBDBFBBBBB9BAB9B8B7AC8B706D6F7A828A8A8C939899A09F9EA4A3A9A7
A9ABAFB1AEAFB2B2B2B3B5B2B1B1B2B3B5B2B3B3
1F242E2B2B2B2635415C6C675B524D4A3E342B2B2C2E2F393E3530234A78262824293B55
7E312E27246965301F2B39382A29256595937D5E547093ABC0B09EA8A7B0B1A5ABA8A19B
A3A6B5BAC0C2B7BEBCB7BFB9B1AFB3AEACA9A28F7E858692999A9E9EA0A2A3A7A6A6A9A7
AAACADAEAEB1B3B1B2B5B5B2B6AEB2B5B3B9B8B8
332425283623393F484B4C606A6B47464232332B2928313A3D2E2C2940793C27282F3C57
7939392D234C73383D273329291B244A707E836D555B7098ACC29FA8A1AAA6A8AAA8A09D
A3A6B2B5BCC2B7BFB6B5BDB8AFAFB6B2BCB7AB9C9198989B9B9DA1A1A6ABA5A7A7A9A7A8
AAABAAB2AFB0B0B2B2AEB4B3B1B1AFB2AFB8B9B8
3A2B26313F20443B3B39305570773B3E423F322827243332392E1D2F38634D1D2B2E415D
643947302F255A7F3F17342A2724233149728B745E585E8292C7A4A89AA3A5A39FA09D9D
A3A9B0BCC0C1BABBB5B8B9B4AEB1B1B2B3ADA9A7AFA59D9B9B9FA6A5A5A3A4A4A0A3A3A6
A6A8A7A8ACB3B1B4AFADB1AFB1B4B2B0AEB2B8BA
464731333332343635302B2F38626A65473C2C2929272D2D3E2E2829335F682328314053
4A373A32342A476C673E2E221F1D1A2135547E81856F646F7CA6ACACA7A49CA2A1A29D9F
A1A9ADBAC0BBC1BAB5BEBFAEAEA69CADB8BAADACA8A09E9D9B9BA0A2A4A3A8A7A49EA0A5
A6AAA4A9ADAEB0AEADADB0B3B3B4B6B1B2B4B7B5
3D5A35362047242620282A3E484F63626149363029242B3739362D2533486829242F4744
41372F2D3A2D2F618C67271D1E1E1F1E23436B859B88796D6F88ABB1ABA79D999EA19FA4
A5A9B3BBBCB8B9B9BCBCB9ADAB9F92A3B9BCB2AEA5A3AAA59C9B9C9CA1A2A6A09FA0A2A2
A5A6A5AAAEAFAFACB0ACAFB2AFB5B4B5B5B8BCBB
2E4D3F381D352A28242037513E3C45515F554330262B333C342E28282A466638293A5635
2F3825302A352E597F57211F22201E2833596781859F8A7C6B768FA0AFACA39EA7A6A2A6
A6AAB5BBC0BCBEBDB8BBB8B2A08086A6B5BFBEBCAFA9A7A09C99969C9F9EA39D9BA0A09F
A3A1A8AAACACB0ABADACAEB5B2B4B3B5B5BBBEBD
2731483B2E28302823374A663735223A545348372C292D3434393128283E5C482A43602D
2F401B2D30333F505D41221E261A1B384D7464716BA59A896C6E748EAAADA49D9EA4A2A8
AAB2BABBBDBAB6BCB9B8ACA79A6A83A9ADBBC5C0B8ADA5A1A09B999B999A9B979C9DA19F
A2A3A6A9ACAAACABADACB2B2B0B1B5B6B5BABCBA
212437382C26272E315B57453A2F243D46504F40352A353333392C2B283F4B512940512C
273A2B3C472C3646583E271B1F1C233571815A404D889D948777737698A6B0A89F9FA2A8
B1AEB2BDBBB8B5BEBFBAAE98A26F86B0ACBBBCC1BCB5B3A7A69E9B9B9BA19D99989EA2A3
A4A2A4A7ABADACAAADACB2B1B2B1B3B4B4B8BBBD
252B2B2C2A232B353E77663236233033354D594A2F282E36373D2C29283D425A30323B2E
33303A455B273C42593F2A1B221F2840967F4911356090928F86766E839BADA99EA5A8AE
B2B1AFBCC2C6B9B9BAB8AE8AA17189B4A9B5B7C3C7C1B7AAAAA59EA0A0A3A19D98999EA1
A4A0A1A3AAADACACB0ACAFB1B2ADB2B7BBBABCBC
2C25272A2B2C2A3C4F6E483A403737322A3A494539342D313742382C2B38404C3D3A3325
2727385D5C3449464D43402A2D33395F966F3A12253E6B7E98987A7975869CA6B2AEAAAB
ABACB7BAC1BAB5B9B2B6B18698828EB09FADB6BFC8C2BFB9AAA5A2A4A0A3A5A39E99959B
9FA29DA2A7A8AAABAFACAAADB2ACB4B6BABCBFBF
26262C232A262D4B6655374A4D4237322E333B3D322E2E34383A352E343237424A46382A
26333B695D435E533F414C3727394B928755221C1E2D416793B27B7B706E85A3B9B0AAA8
ADB0B8B6BEBDBAB6AFB2B88E9B938AAF9CA6ACBCC2C7C5BCAFA7A3A5A6A1A4A4A49A9397
9D9D9EA1A4A7A6A7ADACAEACAFB3B9B6BABBBEBF
2B2824292B28265471422B3239413637332B373E42352A30333B3D3837363540453A3125
2231465F5453594A52535B54545E70A88E5F2721181C2950729A9A8A75737590A7AEB7B1
A1ADB8BCB9B8B4B3B1B4B399929699ABA1A5B0BBC7C9C5C8B7ABA7A7A8A7A7A5A39B9A97
97979CA0A4A3A5A5ABA9ACABAAB0B6B7BABCC2C1
2E28212A2C27325475332F23293539384031313A46362B2E2F3D3836352A2D3244353535
303F4E484F53614B666162534D3C6D968E6B312621181A314E7C9F97827974798EACC3B7
A5AAB5BDB3B5AEB4AFB3B39F8895A0A3A3ACAFBDC0C1C6CCBDB1A6A9ABA8A9A7A3A2A29C
9493989EA29EA3A7ADA8A9ACABADB7B7BCBEC2BE
2F2E292C2D2E3361643F2E1F2C2B2F404F3E323240352B342D3B3930332E2D3442373C33
2E3A3C4157666B617B4E54473D37668C7448291E18231F28345B82989E857975809AB3BA
B2ADAEB4B2BAABAEA9ACAC9C8B95A7A7A9AAB0B3B9C2C2C3BFB2A8ADADA8ABA8A6A8A7A3
9B989A979A99A0A5A7A7ABA7ACADB5B8BABFBFBD
2E2E262B2C323870674827252E2E2D414B42333535352E35313337363D342A253A3D4135
3C332C485F637285804340332F306F825C24241F22272116223E5A8AAC9883776E8898A9
BCAFABB0B8AEA6A6A7AAA8978792A9B1AEADAFB5B7BCC5BEBEB4AAAEA8A9A9AAACAAA6A8
A79D969393999EA8A6A8A9A8AEACB3B9BBBEC1C0
3F3A322E2C3636656A53282529312E344446403C383639332E2D343E3E36282B39453E34
332E334E5F6D5F5F8139313131317C874722242224212820202835628CA4988473737B99
B4B6AAA7AEA9A9A8A1A5A5968295A8B0B2AAA7B1BBC1BFBEBDB5AEAEA8A6A9ABAEADA9AD
ADA7A09A989597A2A5A6A9ABACB2B0B5B7BABFC0
4E4B452F2A2D3A576F5330312729272B383F483C393538352A272E33333330363F3C3E39
392E495A5C6B3C326E3E2D283C4C9881362D2D2C25232423291C243A60A39F8F786E6782
9BB6B9B2ABA4A3A5A5ABA4907F94A9ACACA89DACBBBFBEC0B8B3B0ADA7AAAAA8A9AAA8AF
ADACAFA79D92959BA2A5A6A7ACADAEB0B6B9BCC1
64615E42333438526D5235312B2E31242F35433A33303B3631293434353B3B424D45423B
363A4B485B6731395A3B3522436E8D742F2329262720211C221816273C798BA28C776674
829EACB9B2ABA4A8A8A6A39387939FA2A9A6A2A8BABBC1BBB1B2B4B0A5A8AAAAADAAA7AB
A6ADB3ADAC9B98979C9EA7ADAAAFB0AFB9B5B7BB
38433C35342E30546A5943322629292B2F313A342E323E382C2D342B31444E5149413F39
3D454D3B59571C36453939295798865D2A1C252A2525251C25271F1822456DB4A78B6D6C
7184A3BCBFB4A0A3A7A6A1937E849AA4AAA8A9AAB2BAC1B6AAB3B6B4A8A8AAA9A6A5A3A4
A3A9ABB3BCAB9C95949AA5A7ACACB0B3B6B5B9BA
595344372B322C4F595A4E29292A27242E3138352A3539382E3835313848524C3D3E4242
414440415B572031443E37315596855E2C2A362C333A2924222421201927488D9E968679
6B72869DB7B4B0A79DA3998B78849EAEB1B1ABA9AEBBC2B6B2B7BBB1ADAAA7A8A6A0A0A0
A3A5ABB1B9B5AFA9A19E9EA1A6ACAAAAB4B4B8B5
7A604130262A2748585B62242F272E2A2C313034282F2B322C303141485155463D404B4B
493B2B4C5A5C272D39372C3C4E8C855B3033484A3E3E33272B1E24211F212953819AA28E
6E64697EA4B2B4AC9E9E9B857887A5B3BEB9AAB1B3BEC1BFBEBDBBB1ADA7A8A5A3A0A1A2
9DA0A8ABB4B9BBB4AAA2979CA2AAA8AAAEB1B5B3
7A695B392524343644525C3536312D282C302C2C2D32332B2B343B4B595147413D4C544E
48312B3E646224263132274A6187896F544D58686D432B1D2922271E2621223A55859C98
866C5C647F96ADB3B1A291768298ADB5BBB8ADB7B7BAC2C6BFC0BDB8B1A8A9A5A59FA1A0
9FA3AAA9B0B5BDB5B2ACA0A2A2A8A8AAB0B1B8B3
73582E28262E3132344A554539332E2F2C312E29333033312F3C4C5359493D444651564E
3A2C312E5E611D1C2B32345575838C7163626C5F4D352F2625292220232126222B5B8795
957A5757627F97ABBBA1926B8D9CADBBBDB5ADB4B9BABDC4C0C3C0BDB8B0ACA6A7A2A19C
A3A3A7A7AFB0B2B7B6B2AEA79FA0A6A8AEB0B1B4
725A312E27343728303D51603F34352D292F2F253235312A2C3D5B5955453B454F5A5F4E
2D2F3233585522282C435763817E7C6144372C2C262C3027262A2A2422242420223E5C7D
8D7C5E6C54657897AAA888789F9A9CC1B2B6B8B8B9B9B5B9BDC3C2BBB6B4ABA9A4A6A09D
A4A4A4A5ABAAB0B5B8B6B0A7A6A0A0A6A8ACB3B1
6F5F3C3634363B2B2931476C443B332F2C312F2B2F2E2F3236496057463E434954585E3E
252C364A553C2625244F6D8286776745262B353132362F342B262D28222524202626335C
797A68825555557494AA8782AE9E91C1B3B4B3B4B4B8BABCBCBCBBBBB6B7B3AEA5A2A09F
9FA3A5A3A8A7ADB5B7B3B0AAA29D98A0A1A6AFB3
6D635343564C4F4132384961503F3833332F2F2F322D2F333A4F5E564245444E53545A40
302C36475340253143587A7E77634F33242C2B2B2E342F3030272D342A272821262A2841
5A696D8263534C5F73917880AE9A89AEB4B9B3B1B4B7B5B7BABABEBDBAB8B4AEA8A3A3A2
A1A9A8A8A9A9ABB1B9B6B0ACADA69C9FA5A7ADAD
6D675C4A70605C4E393D4551594E453C372E2F2C2B2A2E3C3D45554C4641464E585B4E3E
312C3744523721365C517B7E725338272E2F333131372E312D292A32312E282B28252730
355971857959424A567A6C74B49D899DBEBAB1B0B4B5B7B6B5B9BBBEBAB9B5B6ADAAA6A6
A3A5A9ACACAFB0B3B3B0B3B1B1A69DA4ABACA9AA
6F69624E74635F665A53484B64554539342F31312929353A3F41504D494748515352483E
353234485137253A68597F836B56352B2C2A322B2F362B34322E2D3333312B252722272A
2E4A60508C74635D565F4961B29E8897BBBDB0AEB1AFB4B8B2B7B8BFBBBBB7B5AFB1A9A3
A0A6A7ACAAAEB0B5B4AEB6B4B0A6A1A2AAAAA7A9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{922, 288.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>J000182000`400?l00000o`00003oo`38h=So
0<SPf?l0b>3HW@38h=P00?l0b>3Ho`38h=So0<SPf9d0b>3H003o0<SPf?l0b>3Ho`38h=RM0<SPf000
o`38h=So0<SPf?l0b>3HW@38h=P00?l0b>3Ho`38h=So0<SPf9d0b>3H003o0<SPf?l0b>3Ho`38h=RM
0<SPf000o`38h=So0<SPf?l0b>3HW@38h=P00?l0b>3Ho`38h=So0<SPf9d0b>3H003o0<SPf?l0b>3H
o`38h=RM0<SPf000o`38h=So0<SPf?l0b>3HW@38h=P00?l0b>3Ho`38h=So0<SPf9d0b>3H003o0<SP
f?l0b>3Ho`38h=RM0<SPf000o`38h=So0<SPf?l0b>3HW@38h=P00?l0b>3Ho`38h=So0<SPf9d0b>3H
003o0<SPf?l0b>3Ho`38h=RM0<SPf0007@38h=P205MGE`80J6QX0P23Ph<20:NWY`80_;bl0P0c<c<2
02TY:@8092@T0P0^;Rh202HV9P808R8R0P0a<C420410@080?clo0P0j>SX203De=@<0<S8b0P0d=3@2
03De=@80<S8b0P0`<30203@d=080=cLg0P0e=CD203<c<`80=3@d0P0h>3P204E5A@80D51@0P1;Bd/2
0492@P80?Cdm0P0h>3P2034a<@80;2`/100X:2P2030`<080>c/k0P1]KFd406=SH`80FUYJ0P1lO7`2
06MWI`80ATI6101PH60306ATI080K6a/0P1cLg<207EeM@80MWIf0P1jNWX207inOP@0Ogmo0P20P802
0861P@80Ogmo101nOWh207moO`80PH610P23Ph<208J6QP80R8R8102:RXX208V9R@80R8R80P29RHT2
08^;R`80SXj>0P2@T90208f=S@80Rh^;0P2>SXh2092@T080SHf=0`29RHT208R8R080RHV90P2:RXX8
08b<S080SHf=0P2>SXh208n?S`80T92@0P2ATI4409:BTP@0TI6A102@T902096AT@80TY:B0P2CTi<2
09BDU080TI6A0P2?Shl2096AT@80U9BD0P2BTY82092@T080U9BD0P2HV9P209JFUP<0U9BD0P2FUYH2
09VIV@80VYZJ0P2KVi/209fMW@80X:2P0P2SXj<20:RXZ080]KFe0P33`l<20<[:bP80clo?0P3@d=02
0=?Cd`80/k>c:@38h=P205eMG@80IVIV0P25QHD20;^k^`80]KFe0P10@40402TY:@8092@T0P0X:2P2
02HV9P80;Bd]0P12@T82059BDP80>3Ph0P0c<c<303Ti>@80<S8b0P0i>CT402l_;`80>3Ph0P0e=CD2
03Ti>@80;bl_0P0j>SX203Lg=`80@d=30P1;Bd/2055AD@80?clo0P0k>c/203Ph>080;bl_0P0];Bd2
02HV9P80:b/[0P0X:2P203hn?P80JVYZ101VIVH205YJFP80LG5a0P1UIFD205=CD`80G5aL0P1RHV83
06MWI`80JVYZ0P1cLg<206m_K`80MWIf0P22PX8207emO@80O7al1023Ph<207]kN`80Ph>30P1mOGd2
0861P@80PX:20P1nOWh208>3P`80QHF50P28R8P408V9R@@0R8R80P27QhL208b<S080SXj>0P2BTY82
08^;R`80SXj>0P2<S8`2092@T080S8b<0`28R8P208V9R@80RXZ:0P2;Rh/208j>SP@0RXZ:0P2=SHd2
08j>SP80RXZ:0P2BTY8208j>SP80Shn?202BTY8209>CT`80T92@0P2=SHd2096AT@80UIFE0P2CTi<2
08n?S`80SXj>102BTY8209FEU@@0T92@0P2IVIT209BDU0<0Ti>C0P2FUYH209^KV`80UiNG102KVi/2
09jNWP80X:2P0P2/[:`20;6a/@80a<C40P3?cll20<_;b`80dM7A0P3?cll20;jn_RT0b>3H0P1DE5@2
06UYJ@80PX:20P2ZZZX20;Zj^P80?3`l0P0S8b<202/[:`80<S8b0P0S8b<2028R8P80:b/[0P0l?3`2
0410@080=3@d0P0h>3P303De=@80;Rh^0P0a<C4203@d=0@0;Rh^0P0i>CT203Xj>P80<C4a0P0c<c<2
03Xj>P80@D510P1EEED204];B`80@d=30P10@40203Lg=`80;bl_0P0U9BD202d];@809BDU0P0a<C42
03Xj>P80KFe]0P1TI6@206=SH`80G5aL0P1kNg/206UYJ@80ATI60P1SHf<205eMG@<0IVIV0P1^KVh2
07EeM@80Jf][0P1jNWX207]kN`80PH610P23Ph<207alO080Ph>30P20P80208:2PP80OGem0P22PX82
07inOP@0Ph>30P28R8P208Z:RP80QXJ6102<S8`208J6QP80RHV90P2;Rh/208b<S080TI6A0P2=SHd2
08V9R@80T92@0P2?Shl208j>SP<0R8R80P29RHT208N7Q`80S8b<0P2=SHd208j>SP80S8b<0P28R8P2
08^;R`80SXj>0P2@T90208n?S`80TI6A102CTi<2092@T080Ti>C0P2ATI44092@T080Ti>C0P2FUYH2
09BDU080TY:B0P2@T90208n?S`80UiNG0P2ATI4208n?S`80TI6A0P2HV9P209JFUP<0U9BD0P2GUiL2
09bLW080Vi^K0P2JVYX209fMW@80WinO0P2UYJD20:RXZ080][Jf0P36a/H20<S8b080d=3@0P3Bd]82
0=CDe080/[:b7`38h=P001d0b>3H0P1GEeL206QXJ080Ph>30P2WYjL20;bl_080<c<c0P0Y:BT202@T
9080;Rh^0P0V9RH2028R8P80<C4a0P10@40203lo?`80>SXj0P0e=CD3038b<P80=3@d0P0e=CD2038b
<P80<30`0P0d=3@203Lg=`80=CDe0P0c<c<203@d=080>3Ph0P15ADD2051@D080Bd];0P12@T8203dm
?@80>3Ph0P0a<C4202`/;0@0:2PX0P0`<30203/k>`80KFe]101SHf<205YJFP80O7al0P1WIfL204I6
AP@0H61P0`1TI6@206a/K080Lg=c0P1eMGD207IfMP80NWYj0P1nOWh407moO`80P8200P21PH4207mo
O`@0OWin0P1oOgl20861P@80Ph>30P26QXH208R8R0@0RXZ:0P29RHT208R8R080RHV90P2;Rh/208j>
SP80T92@0P2=SHd208^;R`80SXj>0P2@T90208f=S@<0RHV90P28R8P208V9R@80RXZ:202<S8`208f=
S@80SXj>0P2?Shl2092@T080TI6A102BTY84096AT@@0T92@0P2ATI4209:BTP80Ti>C0P2DU9@2096A
T@80Shn?0P2ATI4209BDU080TY:B0P2@T90209BDU080V9RH0P2FUYH309BDU080UYJF0P2IVIT209ZJ
VP80Vi^K0P2MWId20:2PX080Xj>S0P2XZ:P20;Fe]@80`l?30P3:b/X20<o?c`80d=3@0P3Cdm<20;>c
/bT0b>3H0P1MGEd206IVIP80QHF50P2k^k/20;Fe]@80@410100Y:BT202@T9080:2PX0P0V9RH202d]
;@80@T920P1BDU8203Ph>080<c<c0`0i>CT2038b<P80>CTi100_;bl203Ph>080=CDe0P0i>CT202l_
;`80>SXj0P0g=cL204=3@`80Bd];0P1ADE4203lo?`80>c/k0P0h>3P202l_;`80;Bd]0P0V9RH202/[
:`80:2PX0P0n?Sh206YZJP@0IVIV0P1JFUX2075aL@80IFEU0P1CDe<205aLG080HV9R0`1WIfL206YZ
JP80Lg=c0P1_Kfl207IfMP80PX:20P1mOGd207alO0@0Ph>30P1kNg/208>3P`80OGem0P21PH4208:2
PP80OWin0P23Ph<208F5Q@80R8R81029RHT408R8R080QhN70P2<S8`208j>SP80TY:B0P2;Rh/208j>
SP80S8b<0P2@T90208b<S0<0R8R80P29RHT208Z:RP80Rh^;0P2>SXh408Z:RP80SHf=0P2>SXh208Z:
RP80TY:B0P2>SXh208n?S`P0TY:B0P2CTi<2092@T080SHf=0P2ATI4209FEU@80Ti>C0P2?Shl208j>
SP@0TY:B0P2EUID4092@T080VIVI0P2DU9@309>CT`80UYJF0P2KVi/209NGU`@0Vi^K0P2NWYh20:2P
X080[:b/0P2a/K420<C4a080clo?0P3;bl/20=7Ad@80clo?0P2n_[hY0<SPf080E5AD0P1YJFT208:2
PP80ZZZZ0P2j^[X203`l?0808b<S0P0[:b/2038b<P808b<S0P0R8R8202/[:`80?3`l0P10@40203@d
=080>3Ph0`0e=CD202h^;P80<C4a0P0d=3@402h^;P80>CTi0P0j>SX2034a<@80<c<c0P0j>SX20451
@@80EEEE0P1;Bd/204=3@`80@4100P0g=cL202l_;`809BDU0P0];Bd202DU9@80<C4a0P0j>SX206e]
K@80I6AT0P1SHf<205aLG080Ng]k0P1YJFT204I6AP80Hf=S0P1MGEd306IVIP80KVi^0P1eMGD206][
J`80NWYj0P1kNg/20861P@80Ph>30P1lO7`208>3P`80P8200P22PX8207emO@80PX:20P1nOWh408>3
P`80R8R80P2:RXX208J6QP@0S8b<0P26QXH208V9R@80Rh^;0P2<S8`2096AT@80SHf=0P29RHT2092@
T080Shn?0P2>SXh308R8R080RHV90P27QhL208b<S080SHf=0P2>SXh208b<S080R8R80P2;Rh/208j>
SP80T92@0P2?Shl2096AT@@0Ti>C0P2@T90209>CT`80TI6A102@T90209>CT`80UYJF0P2DU9@209:B
TP80T92@0P2?Shl209NGU`80TI6A0P2?Shl2096AT@80V9RH0P2FUYH309BDU080UiNG0P2LW9`209^K
V`80VYZJ0P2MWId209nOW`80YJFU0P2XZ:P20;Jf]P80a/K60P38b<P20=3@d080d];B0P3De=@20;:b
/Ql0b>3H000M0<SPf080F5QH0P1OGel2071`L080XJ6Q0P2o_kl20:JVYP80ATI60P0Q8B4202TY:@80
9BDU0P0V9RH2034a<@80>c/k0P0h>3P203<c<`80=cLg0`0j>SX203Lg=`80<c<c0P0b<S82034a<@80
<S8b1P0d=3@203Hf=P80>c/k0P12@T8204a<C080B4Q80P10@40203Ti>@80<c<c0P0`<30202l_;`80
:BTY0P0W9bL202l_;`80>SXj0P1/K6`2069RHP80I6AT0P1LG5`207]kN`80HF5Q0P1?Cdl205eMG@80
HV9R0`1[Jf/206i^KP80LG5a0P1dM7@207IfMP80NWYj101nOWh207moO`80P8200P22PX820861P@80
Ogmo1020P8020861P@80Ph>30P25QHD208N7Q`80RHV90P2:RXX208V9R@80R8R80P2:RXX208b<S080
SXj>0P2?Shl208f=S@80RXZ:0P2;Rh/208b<S0D0SHf=0P2:RXX208V9R@80Rh^;0P2>SXh208f=S@80
S8b<0P2=SHd208j>SP80T92@0P2BTY8609>CT`@0TY:B0P2CTi<209:BTP80TI6A0P2BTY8209BDU080
UYJF0P2GUiL209FEU@80TY:B0P2CTi<209BDU080Ti>C0P2ATI4209>CT`@0UYJF0`2EUID209RHV0@0
VYZJ0P2KVi/209fMW@80X:2P0P2SXj<20:VYZ@80][Jf0P34a<@20<c<c080dM7A0P3@d=020<o?c`80
_[jn:@38h=P205YJFP80FEUI0P1`L70209>CT`80`L710P2LW9`203hn?P80:2PX0P0/;2`202TY:@80
92@T0P0Z:RX203Lg=`80=SHf0P0`<30203@d=0<0>3Ph100g=cL202/[:`80<S8b0P0k>c/2030`<080
<S8b0P0_;bl20451@@80=CDe0P14A4@204a<C080CDe=0P12@T8203Hf=P80=cLg0P0_;bl202h^;P80
<30`0P0[:b/202LW9`80@T920P1YJFT2065QH@80I6AT0P1PH60207YjNP80I6AT0P1:BTX205aLG080
HV9R0`1YJFT206e]K@H0MGEe101lO7`207inOP80NWYj0P22PX8208B4Q0@0Ogmo0P1nOWh20820P080
Ogmo0P25QHD408J6QP80RXZ:0P2;Rh/208R8R080RHV9102;Rh/4092@T080R8R80P2<S8`208Z:RP80
Shn?0P2;Rh/308n?S`80QhN70P28R8P208^;R`80SHf=0P2;Rh/208n?S`80SXj>0P2=SHd4096AT@80
Ti>C102EUID209:BTP80Shn?0P2ATI4409:BTP80T92@0P2FUYH209RHV080VIVI0P2ATI4209FEU@@0
U9BD102BTY8209>CT`@0UiNG0`2HV9P209JFUP80VYZJ102KVi/20:2PX080XJ6Q0P2WYjL20:ZZZP80
[Zj^0P34a<@20<o?c`80dM7A0P3=cLd20<c<c080`<30:@38h=P205UIF@80GemO0P1^KVh20:>SX`80
^k^k0P2SXj<204E5A@80820P0P0V9RH201lO7`80;2`/0P0a<C420410@080?3`l0P0e=CD203Hf=P<0
=cLg0P0j>SX203Lg=`80=3@d0P0c<c<203@d=080<c<c0P0a<C4203<c<`80>3Ph0P0j>SX204=3@`80
Bd];0P14A4@203lo?`80?Cdm0P0a<C4202l_;`80<c<c0P0/;2`202HV9P80;2`/0P0k>c/206e]K@80
H61P0P1UIFD205UIF@80NWYj0P1NGUh2051@D080G5aL0P1PH60306UYJ@@0LG5a0P1cLg<207QhN080
O7al0P1jNWX207alO080OWin0P23Ph<207moO`@0P8200P1iNGT207moO`80QXJ60P1oOgl208B4Q080
QhN70P28R8P208Z:RP80QhN70P29RHT408b<S080Shn?0P2@T90208f=S@80Rh^;2@2<S8`208^;R`80
RHV90P2:RXX208f=S@80Rh^;0P2>SXh408n?S`80TY:B0P2ATI4209:BTPH0Ti>C0P2?Shl409:BTP80
TI6A102BTY8209NGU`@0UIFE0P2CTi<2096AT@80Ti>C102DU9@2096AT@80UiNG0P2HV9P309>CT`80
VYZJ0P2GUiL209JFUP@0WIfM0P2OWil20:FUY@80Z:RX0P2d];@20<?3``80bl_;0P3@d=020=7Ad@80
c/k>0P2l_;`O0<SPf0007@38h=P205QHF080GemO0P1`L7020:6QX@80_kno0P2VYZH204I6AP808B4Q
0P0Y:BT202DU9@809RHV0P0a<C4203/k>`80>3Ph0P0c<c<203Lg=`<0>SXj0P0g=cL203<c<`80<S8b
0P0a<C42038b<PH0=3@d0P0f=SH203/k>`80@T920P1<C4`204Q8B080@4100P0i>CT203<c<`80<30`
0P0_;bl202TY:@809bLW0P0_;bl203Xj>P80K6a/0P1RHV8206ATI080G5aL0P1kNg/2065QH@80Cdm?
0P1MGEd2069RHP<0Jf][0P1^KVh2075aL@80M7Ad0P1fMWH207YjNP@0OWin0P1oOgl20820P080PX:2
0P21PH4207moO`@0P8200P21PH4208>3P`80QHF50P27QhL208V9R@80RXZ:0P29RHT208R8R080RXZ:
0P2<S8`208j>SP80Shn?0P2=SHd208Z:RP80Rh^;0P2<S8`508f=S@80RXZ:0P29RHT208^;R`80SXj>
0P2=SHd208b<S080SHf=0P2>SXh2092@T080TY:B1P2CTi<409:BTP80Ti>C0P2BTY82096AT@80TY:B
0P2DU9@209JFUP80UiNG0P2EUID209:BTP80Ti>C0P2DU9@209>CT`80TI6A0P2CTi<409JFUP<0UIFE
0P2HV9P409ZJVP80Vi^K0P2MWId20:2PX080Xj>S0P2YZJT20;Jf]P80a<C40P3<c<`20=7Ad@80d=3@
0P3?cll20;jn_RT0b>3H0P1JFUX205UIF@80L71`0P2CTi<20<71`@80W9bL0P0n?Sh202PX:080;2`/
0P0Y:BT202@T9080:RXZ0P0g=cL203Hf=P80<30`0P0d=3@303Ph>0@0=cLg0P0[:b/2038b<P80>c/k
0P0`<302038b<P80;bl_0P11@D4203De=@80A4A40P1<C4`204e=C@80@T920P0f=SH203Lg=`80;bl_
0P0^;Rh2030`<080:b/[0P0W9bL20492@P80JFUY0P1QHF4206ATI080H61P0P1jNWX206ATI080BTY:
0P1LG5`2069RHP<0JFUY0P1]KFd607EeM@@0O7al0P1nOWh207YjNP80PX:20P24Q8@407moO`80OWin
0P20P80207moO`80QHF51026QXH208Z:RP80Rh^;0P28R8P208V9R@@0Rh^;102@T90208R8R080S8b<
0P2:RXX208n?S`80Rh^;0`2?Shl208N7Q`80R8R80P2;Rh/208f=S@80Rh^;0P2?Shl208j>SP80SHf=
102ATI4209>CT`@0UIFE0P2BTY8208n?S`80TI6A102BTY82092@T080UYJF0P2HV9P209VIV@80TI6A
0P2EUID409BDU0@0TY:B0P2CTi<409NGU`<0V9RH0P2FUYH209ZJVP@0Vi^K0P2PX:020:6QX@80YjNW
0P2ZZZX20:j^[P80a<C40P3?cll20=7Ad@80cLg=0P3<c<`20<30`2T0b>3H0P1IFET205mOG`80KVi^
0P2SXj<20;^k^`80Xj>S0P15ADD2020P80809RHV0P0O7al202`/;080<C4a0P10@40203`l?080=CDe
0P0f=SH303Lg=`80>SXj0P0g=cL203@d=080<c<c0P0d=3@203<c<`80<C4a0P0c<c<203Ph>080>SXj
0P13@d<204];B`80A4A40P0o?cl203dm?@80<C4a0P0_;bl203<c<`80;2`/0P0V9RH202`/;080>c/k
0P1]KFd2061PH080IFEU0P1IFET207YjNP80GUiN0P1@D50205aLG080H61P0`1YJFT4075aL@80Lg=c
0P1hN7P207alO080NWYj0P1lO7`207inOP80Ph>30P1oOgl40820P080NGUi0P1oOgl208J6QP80Ogmo
0P24Q8@208N7Q`80R8R80P2:RXX208N7Q`80RHV9102<S8`208n?S`80T92@0P2=SHd208^;R`T0S8b<
0P2;Rh/208V9R@80RXZ:0P2=SHd208^;R`80SXj>102?Shl209:BTP80TI6A0P2BTY8609>CT`80Shn?
102BTY82096AT@@0TY:B0P2GUiL409FEU@80Ti>C0P2ATI4209>CT`@0U9BD0P2ATI4209NGU`80V9RH
0`2CTi<209ZJVP80UiNG0P2FUYH409fMW@80WinO0P2UYJD20:RXZ080];Bd0P33`l<20<_;b`80d=3@
0P3AdM420<k>cP80_;bl7`38h=P001d0b>3H0P1KFe/205MGE`80FUYJ0P1iNGT209JFUP80];Bd0P2H
V9P203lo?`80:2PX0P0Q8B4202XZ:P80;bl_0P0c<c<202l_;`80;2`/0P0h>3P30492@P80>SXj100a
<C4203<c<`80<C4a0P0_;bl2034a<@80=CDe0P0i>CT203dm?@80@D510P16ATH20492@P80?Cdm0P0d
=3@202d];@80;bl_0P0b<S8202/[:`809RHV0P0_;bl203Xj>P80Jf][0P1PH60206IVIP80H61P0P1i
NGT205MGE`@0FUYJ0P1VIVH3079bLP80LG5a0P1_Kfl2079bLP80MgMg0P1jNWX207alO080OWin0P1o
Ogl20861P@@0PX:21021PH4608:2PP80Q8B40P26QXH208R8R0H0RHV90P2;Rh/208f=S@@0SXj>0P2<
S8`208Z:RP80RHV90P28R8P208f=S@<0TI6A0P2=SHd208V9R@80S8b<0P2@T90208n?S`80SHf=0P2>
SXh2092@T080TY:B0P2DU9@409JFUP80UIFE102DU9@209FEU@@0U9BD0P2EUID209NGU`80VYZJ0P2L
W9`209VIV@H0UIFE0P2DU9@209:BTP80Ti>C0P2DU9@209FEU@<0UYJF0P2IVIT209^KV`@0VYZJ0P2L
W9`209nOW`80Xj>S0P2XZ:P20;Jf]P80a<C40P3?cll20=CDe080d=3@0P39bLT20<[:bRT0b>3H0P1I
FET205YJFP80GemO0P1bLW8209ZJVP80`/;20P2EUID203Xj>P80:RXZ0P0V9RH202XZ:P80;Bd]0P0h
>3P203@d=080;bl_0P0f=SH304A4A080>3Ph0P0b<S8202h^;P80<c<c0P0e=CD203<c<`80;2`/0P0d
=3@203dm?@80>3Ph0P1:BTX20451@@80?Cdm0P12@T8202d];@80;Rh^0P0d=3@2030`<080;2`/0P0Y
:BT202XZ:P80@D510P1SHf<206ATI080IfMW0P1OGel207]kN`80FEUI0P1ADE4205iNGP80JFUY0`1f
MWH206i^KP80KFe]101gMgL207QhN080OGem0P1nOWh20861P@80PX:21021PH420820P080QhN70P23
Ph<207moO`80PX:20P24Q8@208>3P`80Rh^;0P27QhL208J6QP80RHV90P2;Rh/208n?S`80S8b<0P2@
T90208b<S080Rh^;0P28R8P208V9R@80Rh^;0`2BTY8408Z:RP80SXj>0P2@T90208f=S@80Rh^;102>
SXh209JFUP80U9BD0P2CTi<409FEU@80U9BD102EUID209NGU`@0TY:B0P2GUiL409bLW080Ti>C0P2D
U9@209NGU`80UYJF0P2@T90209BDU080TI6A0P2FUYH209BDU0<0UIFE102KVi/209VIV@80Vi^K0P2J
VYX209fMW@80Y:BT0P2[Zj/20;2`/080a<C40P3De=@20=?Cd`80c/k>0P3=cLd20<G5aBT0b>3H0P1K
Fe/205UIF@80Fe]K0P1iNGT209RHV080][Jf0P2JVYX203lo?`80:RXZ0P0T92@202PX:080:b/[0P0e
=CD202h^;P80:b/[0P0g=cL304=3@`80>CTi0P0];Bd203@d=080<30`0P0b<S8202l_;`80<C4a0P0b
<S8203dm?@80>SXj0P11@D4204M7A`80@D510P0o?cl203Hf=P80:b/[0P0_;bl2034a<@80:RXZ0P0X
:2P202/[:`80?Cdm0P1YJFT2061PH080J6QX0P1QHF4207QhN080FEUI0P1HF5P205aLG080Jf][0`1a
LG42071`L080K6a/0P1dM7@207EeM@80MgMg0P21PH4207inOP80OGem0P20P80208B4Q080PH610P23
Ph<20861P@80PX:20P26QXH20861P@80Ph>30P26QXH208V9R@80RXZ:0P28R8P208V9R@80S8b<102=
SHd208j>SP80SHf=0P28R8P208b<S080R8R80P2<S8`3092@T080SXj>0P28R8P208b<S080TY:B0P2@
T90208f=S@80SXj>0P2?Shl209:BTP80U9BD1P2FUYH409>CT`80UIFE0P2DU9@2096AT@80VIVI0P2G
UiL209^KV`80WIfM0P2HV9P209FEU@80UYJF0P2EUID209BDU080TY:B0P2@T90709JFUP@0W9bL0P2G
UiL209^KV`80WinO0P2PX:020::RXP80Z:RX0P2g]kL20<G5a@80cLg=0P3Cdm<20=3@d080b<S80P39
bLTO0<SPf0007@38h=P205]KF`80EeMG0P1JFUX207UiN@80UYJF0P2d];@209RHV080?clo0P0X:2P2
024Q8@80:RXZ0P0_;bl203<c<`80;bl_0P0/;2`203Ph>0<0@T920P0j>SX4034a<@80<c<c0P0a<C42
02l_;`80<C4a0P0e=CD203Ti>@80?Cdm0P11@D4204I6AP80@T920P0m?Cd203@d=080;Bd]0P0_;bl2
038b<P80:b/[0P0V9RH202l_;`80>SXj0P1[Jf/2061PH080IVIV0P1PH60207UiN@80EeMG101JFUX2
06IVIP<0LW9b0P1aLG4206m_K`80LW9b0P1gMgL207YjNP80O7al0P1nOWh207moO`80PH611022PX84
0861P@H0PX:20P24Q8@208J6QP80R8R81P29RHT208^;R`80SHf=102>SXh208b<S080RXZ:0P29RHT2
08R8R080SHf=0`2ATI4208f=S@80RHV90P2<S8`2092@T080Shn?0P2=SHd208j>SP80T92@0P2BTY82
09BDU0@0UYJF0P2EUID409BDU080UIFE102DU9@209FEU@80UiNG0P2JVYX209bLW080VIVI1P2EUID2
09BDU080TY:B0P2CTi<209BDU080UIFE0`2FUYH209VIV@80Vi^K102JVYX209bLW080WinO0P2SXj<2
0:RXZ080][Jf0P34a<@20<o?c`80e=CD0P3@d=020<W9b@80b/[::@38h=P205UIF@80FUYJ0P1OGel2
079bLP80VYZJ0P32`/8209FEU@80>SXj0P0Z:RX202HV9P80:RXZ0P0];Bd203Ph>080=3@d0P0_;bl2
03Hf=P<0A4A40P0h>3P2038b<P80;Rh^0P0c<c<203De=@80<c<c0P0/;2`203@d=080?Cdm0P0h>3P2
04Y:BP80@D510P0m?Cd20492@P80;Bd]0P0^;Rh203@d=080<30`0P0/;2`202TY:@80:RXZ0P11@D42
06=SH`80I6AT0P1WIfL205mOG`80Ng]k0P1IFET2055AD@80GUiN0P1YJFT307IfMP80KVi^0P1]KFd4
07MgM`80N7Qh0P1mOGd207inOP80PH610P22PX840861P@80P8200P27QhL208>3P`80Ogmo0P22PX82
08B4Q080Ph>30P2;Rh/208N7Q`80QXJ60P29RHT208^;R`80Shn?0P2<S8`2092@T080S8b<0P2;Rh/2
08R8R080RHV90P2;Rh/309:BTP@0RXZ:0P2>SXh2092@T080SHf=0P2;Rh/408j>SP80UYJF0P2DU9@2
09>CT`@0UIFE0P2DU9@409FEU@80UiNG102BTY8209NGU`@0W9bL0P2CTi<209BDU080UiNG0P2FUYH2
092@T080U9BD0P2ATI4209JFUP80U9BD0`2EUID409^KV`80VIVI0P2KVi/209ZJVP80WIfM0P2TY:@2
0:^[Z`80/;2`0P34a<@20=CDe080dm?C0P3>c/h20<g=c@80aLG5:@38h=P205]KF`80FEUI0P1KFe/2
07UiN@80V9RH0P2f][H209ZJVP80?clo0P0Z:RX202@T9080:2PX0P0[:b/203De=@80;Rh^0P0[:b/2
03Lg=`<0@d=30P0i>CT202d];@80=3@d0P0`<302038b<P80;bl_0P0a<C42038b<P80?Cdm0P0j>SX2
0451@@80AdM70P11@D4203lo?`80=SHf0P0[:b/202l_;`80<C4a0P0Z:RX202PX:080:b/[0P0m?Cd2
06UYJ@80H61P0P1XJ6P2065QH@80N7Qh0P1IFET205QHF080G5aL0P1[Jf/3075aL@80L71`0P1/K6`2
07AdM080MGEe0P1gMgL20861P@80OWin0P1mOGd20820P080Q8B40P21PH4208>3P`80PH610P22PX82
08J6QP80PH610P23Ph<208J6QP80RHV90P2:RXX208R8R080RHV90P2<S8`408f=S@80SXj>0P2=SHd2
08R8R080S8b<0P28R8P208b<S0<0T92@0P2>SXh208R8R080S8b<0P2BTY82092@T080SHf=0P2>SXh2
08n?S`80TY:B0P2DU9@609JFUP@0Ti>C0P2EUID209BDU080TI6A0P2IVIT209NGU`80Vi^K0P2MWId2
09RHV080UIFE0P2FUYH209FEU@80U9BD0P2BTY82092@T0L0UYJF102LW9`209NGU`80Vi^K0P2OWil2
0:2PX080XZ:R0P2XZ:P20;Ng]`80aLG50P3=cLd20=?Cd`80d=3@0P38b<P20<W9bAl0b>3H000M0<SP
f080G5aL101GEeL206YZJP80Ph>30P2VYZH20;Jf]P80O7al0P0j>SX201dM7@809bLW0P0X:2P402d]
;@80;bl_0P0f=SH303/k>`80=3@d0P0];Bd202l_;`80<c<c0P0`<30202d];@80<30`0P0d=3@403Hf
=P80CDe=0P10@40203lo?`80>CTi0P0c<c<202h^;P80<30`0P0b<S8202XZ:P809BDU0P0d=3@20410
@080L71`0P1QHF4206IVIP80H61P0P1iNGT205ADE080Fe]K0P1NGUh206QXJ0L0LG5a0P1dM7@207Mg
M`80NGUi0P1kNg/207emO@80Ogmo0P20P8020861P@80PX:21023Ph<208:2PP@0PH610P24Q8@208R8
R080RHV90P28R8P408V9R@80Rh^;102=SHd408b<S0H0Rh^;0P2>SXh3092@T080SXj>0P2;Rh/208f=
S@H0Shn?0P2ATI4209>CT`80U9BD0P2EUID809JFUP@0UIFE0P2FUYH409NGU`80V9RH0P2KVi/209fM
W@80VYZJ0P2FUYH209BDU080Ti>C102BTY8209FEU@@0UiNG0`2FUYH209NGU`80V9RH0P2IVIT209ZJ
VP80Vi^K0P2MWId20:6QX@80YjNW0P2d];@20<71`@80cLg=0P3De=@20<o?c`80alO70P39bLTY0<SP
f080H61P0P1IFET205eMG@80IVIV0P1lO7`20:b/[080`<300P1^KVh202l_;`80:RXZ0P0T92@202PX
:080:b/[0P0Z:RX202/[:`80?Cdm0`10@402030`<080<c<c0P0`<304034a<@80:RXZ0P0^;Rh203Hf
=P80?Shn0P0_;bl204i>CP80A4A40P0n?Sh203`l?080<C4a0P0];Bd203Hf=P80;bl_0P0W9bL202HV
9P80:RXZ0P16ATH206a/K080IFEU0P1XJ6P205aLG080MgMg0P1HF5P205]KF`80Hf=S0P1UIFD306m_
K`80L71`0P1aLG42079bLP80MWIf0P1iNGT207emO@80Ng]k0P1nOWh20861P@80P8200P22PX8208B4
Q080Ogmo1022PX820820P080R8R80P27QhL208^;R`80R8R81029RHT208j>SP80SHf=0P28R8P208f=
S@80SXj>0P2<S8`208R8R080S8b<0P2@T90309:BTP80SHf=0P2<S8`2092@T080SXj>0P2CTi<208f=
S@80U9BD0P2ATI4209JFUP@0U9BD0P2IVIT209NGU`80UIFE102CTi<209VIV@80V9RH0P2IVIT209RH
V080VIVI0P2PX:0209ZJVP80VIVI102CTi<209:BTP80UYJF0P2@T90409NGU`<0U9BD0P2FUYH209VI
V@80UYJF0P2JVYX209VIV@80WIfM102UYJD20;2`/080`/;20P3Bd]820<o?c`80c/k>0P3<c<`20<71
`BT0b>3H0P1JFUX205ADE080EUIF0P1ZJVX208>3P`80Xj>S0P2d];@207alO080>SXj0P0P820202PX
:0809RHV0P0[:b/202LW9`80<C4a0P0e=CD303/k>`80>SXj0P0X:2P6030`<080;2`/0P0`<30203Ph
>080=CDe0P0f=SH2055AD@80@T920P0i>CT403Hf=P80<30`0P0^;Rh2030`<080:BTY0P0W9bL203<c
<`80@T920P1_Kfl2069RHP80JFUY0P1PH60207QhN080EEEE0P1KFe/205QHF080IVIV0`1aLG4407=c
L`80MGEe0P1iNGT207YjNP80Ng]k0P1iNGT208F5Q@@0PX:20P1oOgl208B4Q080Ph>30P20P8020861
P@80PX:20P26QXH208N7Q`80RXZ:0P26QXH208N7Q`80RXZ:0P29RHT208j>SP80Shn?0P2<S8`208^;
R`H0RXZ:0P2>SXh3096AT@80Shn?0P2;Rh/208f=S@80Shn?0P2>SXh208^;R`80TI6A102BTY8209NG
U`80UIFE0P2GUiL209JFUP80V9RH0P2EUID209ZJVP80UIFE0P2IVIT209ZJVP80UYJF0P2IVIT209jN
WP80VIVI102EUID209>CT`80TY:B102CTi<209NGU`80Ti>C0`2DU9@209RHV080VYZJ0P2GUiL209ZJ
VP80VIVI0P2LW9`20:2PX080YjNW0P2f][H20<;2`P80c<c<0P3GemL20=?Cd`80bLW90P3;bl/O0<SP
f0007@38h=P205aLG0@0EeMG0P1ZJVX208>3P`80YZJV0P2f][H207alO080>SXj0P0M7Ad202LW9`80
:2PX100];Bd202l_;`80=SHf0`0k>c/203@d=080;Bd]0P0_;bl203<c<`80<30`0P0];Bd2030`<080
=3@d100f=SH204e=C@80@4100P0o?cl203Ti>@80<c<c0P0^;Rh2030`<080<S8b0P0Z:RX202DU9@80
=3@d0P10@402071`L080HF5Q0P1VIVH2061PH080NGUi0P1DE5@205]KF`80GUiN0P1XJ6P7075aL@80
M7Ad0P1gMgL207UiN@80Ng]k0P1mOGd207moO`80P8200P21PH4208:2PP@0Ph>30P22PX840861P@80
Q8B40P28R8P208V9R@80R8R81029RHT208^;R`@0SHf=102<S8`608^;R`80SXj>0`2@T90208j>SP80
Rh^;0P2=SHd608n?S`80TI6A0P2CTi<209BDU080UIFE202FUYH409FEU@80UYJF102GUiL209RHV080
Vi^K0P2MWId209ZJVP80UYJF0P2DU9@209>CT`@0TY:B0P2EUID409NGU`<0UYJF0P2GUiL209RHV080
VIVI0P2JVYX209^KV`80WIfM0P2QXJ420:NWY`80];Bd0P31`L420<g=c@80e=CD0P3?cll20<O7a`80
bLW9:@38h=P2061PH080FEUI0P1MGEd206IVIP80O7al0P2/[:`20<30`080KVi^0P0_;bl202XZ:P80
92@T0P0X:2P202/[:`80:RXZ0P0[:b/203dm?@<0@4100P0`<30203<c<`80<30`100a<C4202XZ:P80
;Rh^0P0f=SH203hn?P80;bl_0P1>CTh204A4A080?Shn0P0l?3`2034a<@80;Bd]0P0f=SH202l_;`80
9bLW0P0V9RH202XZ:P80ATI60P1/K6`206EUI@80J6QX0P1LG5`207MgM`80F5QH0P1KFe/206=SH`80
IFEU0`1_Kfl2071`L080LG5a0P1bLW8207IfMP80NGUi0P1mOGd207]kN`80OWin0P21PH420820P080
PX:20P24Q8@207moO`@0PX:20P20P80208R8R080QhN70P2;Rh/208R8R0@0RHV90P2>SXh208f=S@80
R8R80P2=SHd208j>SP80S8b<0P28R8P208b<S080T92@0`2BTY8208f=S@80S8b<0P2@T90208j>SP80
Ti>C0P2=SHd209BDU080TI6A0P2FUYH409BDU080VIVI0P2GUiL209FEU@@0Ti>C0P2IVIT209RHV080
VIVI0P2HV9P209VIV@80X:2P0P2JVYX209VIV@@0Ti>C0P2BTY8209JFUP80T92@102GUiL309BDU080
UYJF0P2IVIT209JFUP80VYZJ0P2IVIT209fMW@@0YJFU0P2`/;020<;2`P80d];B0P3?cll20<k>cP80
c<c<0P31`L4Y0<SPf080FUYJ0P1DE5@205IFEP80JVYZ0P23Ph<20:>SX`80];Bd0P1lO7`203Xj>P80
820P0P0X:2P202HV9P80:b/[0P0W9bL2034a<@80=CDe0`0k>c/203Xj>P80:2PX1P0`<30202`/;080
<30`0P0h>3P203De=@80=SHf0P1ADE420492@P80>CTi100f=SH2030`<080;Rh^0P0`<30202TY:@80
9bLW0P0c<c<20492@P80Kfm_0P1RHV8206UYJ@80H61P0P1hN7P205EEE@80Fe]K0P1HF5P206IVIP<0
LG5a101cLg<207EeM@80NGUi0P1jNWX207]kN`80NGUi0P25QHD408:2PP80Ogmo0P24Q8@208>3P`80
P8200P21PH4208:2PP80QXJ60P27QhL208Z:RP80QXJ60P27QhL208Z:RP80RHV90P2>SXh208n?S`80
S8b<0P2;Rh/608Z:RP80SXj>0`2ATI4208n?S`80Rh^;0P2=SHd208n?S`80SXj>0P2;Rh/2096AT@@0
TY:B0P2GUiL209FEU@80UiNG0P2FUYH209RHV080UIFE0P2JVYX209FEU@80VIVI0P2JVYX209JFUP80
VIVI0P2NWYh209VIV@@0UIFE0P2CTi<209:BTP@0Ti>C0P2GUiL209>CT`<0U9BD0P2HV9P209ZJVP80
UiNG0P2JVYX209VIV@80W9bL0P2PX:020:NWY`80][Jf0P32`/820<c<c080emOG0P3Cdm<20<W9b@80
bl_;7`38h=P001d0b>3H0P1NGUh405YJFP80GemO0P1`L70208:2PP80a<C40P2f][H205UIF@80:RXZ
0P0U9BD2028R8P80:2PX0P0];Bd403<c<`<0<S8b0P0^;Rh202XZ:P80;bl_0P0c<c<202l_;`80:b/[
0P0`<30203@d=080<c<c0P0`<30205MGE`80?Cdm0P0l?3`203Lg=`80=3@d1P0a<C4202TY:@809BDU
0P0g=cL204Q8B080MGEe0P1SHf<206MWI`80H61P0P1gMgL2059BDP80Fe]K0P1SHf<206UYJ@<0KVi^
0P1aLG4207=cL`80MWIf0P1hN7P207UiN@80NWYj0P1mOGd60820P080PX:20P24Q8@208>3P`80PH61
0P20P80207moO`80QHF5102:RXX208R8R0@0RHV90P2;Rh/408b<S0@0Rh^;0P2<S8`208f=S@@0SXj>
0`2=SHd808j>SP80Shn?0P2ATI4209BDU0X0UYJF0P2GUiL209RHV080UYJF0P2EUID209NGU`H0VIVI
0P2KVi/209bLW080VYZJ0P2FUYH209>CT`@0TI6A0P2CTi<209NGU`80VYZJ0P2HV9P309FEU@80U9BD
0P2EUID209NGU`80VIVI0P2JVYX209^KV`80WinO0P2UYJD20;6a/@80_[jn0P3:b/X20=;BdP80cLg=
0P36a/H20<G5aBT0b>3H0P1OGel205YJFP80Fe]K0P1IFET2071`L080SHf=0P2o_kl20;>c/`80Fe]K
0P0/;2`202LW9`8092@T0P0[:b/202d];@80<S8b0P0d=3@302h^;P80<30`0P0Y:BT202`/;080<S8b
0P0c<c<202/[:`80;Bd]0P0a<C4203<c<`80<S8b0P1;Bd/204=3@`80>CTi0P0f=SH2030`<080<C4a
0P0d=3@2038b<P80:2PX0P0W9bL2030`<080C4a<0P1dM7@2061PH080JVYZ0P1WIfL206m_K`80EUIF
0P1NGUh206=SH`80JVYZ0`1^KVh2071`L080Lg=c0P1hN7P207YjNP@0MgMg0P21PH4207moO`@0OWin
0P25QHD208>3P`@0PX:20P1lO7`207moO`80QHF50P28R8P208^;R`H0QhN70P2>SXh208^;R`80R8R8
0P29RHT2092@T0@0Rh^;0P2ATI4208^;R`<0Shn?0P2<S8`208n?S`80SXj>0P2=SHd208n?S`80SXj>
0P2EUID209BDU080UiNG0P2FUYH209BDU080UIFE0P2HV9P209JFUP80UiNG0P2DU9@209VIV@@0V9RH
0P2IVIT209nOW`80Vi^K0P2GUiL209FEU@80Ti>C0P2BTY8208n?S`80U9BD0P2GUiL409ZJVP<0UiNG
0P2@T90209RHV0@0UiNG0P2LW9`209JFUP80Xj>S0P2UYJD20:ZZZP80_[jn0P3>c/h20=7Ad@80c/k>
0P38b<P20;bl_2T0b>3H101MGEd205IFEP80Hf=S0P1`L70208:2PP80a/K60P2f][H205QHF080;Bd]
0P0T92@2020P80@0;Bd]0P0b<S8202l_;`<0=SHf0P0/;2`202XZ:P80;Rh^0P0e=CD202XZ:P80;2`/
0P0`<30203Hf=P80<S8b0P0`<30205QHF0@0>CTi0P0e=CD203<c<`@0<30`0P0a<C4202/[:`809BDU
0P0e=CD204U9B@80LW9b0P1QHF4206][J`80H61P0P1dM7@2055AD@80GemO0P1SHf<206IVIPD0L71`
0P1dM7@2079bLP80MWIf0P1mOGd207alO080N7Qh0P1nOWh20820P080OGem1023Ph<208J6QP@0PH61
0P20P80208:2PP80Rh^;0P2=SHd208V9R@80R8R80P29RHT208Z:RP80Rh^;0P2<S8`408Z:RP80S8b<
0P2?Shl408j>SPD0SHf=0P2>SXh208n?S`@0SXj>0P2ATI4409NGU`80Ti>C0P2GUiL209FEU@80U9BD
0P2IVIT209NGU`80TY:B0P2GUiL209BDU080VIVI0P2KVi/209VIV@80Vi^K0P2LW9`209jNWP80UYJF
0P2CTi<2096AT@80Ti>C0P2BTY8409ZJVP80V9RH0`2EUID209:BTP80UYJF0P2GUiL209^KV`80VYZJ
0P2LW9`209nOW`80Y:BT0P2`/;020;fm_@80b/[:0P3Bd]820<[:bP80a/K60P31`L4O0<SPf0007@38
h=P205iNGP@0FUYJ0P1OGel2071`L080PX:20P34a<@20;Jf]P80FEUI0P0Z:RX202DU9@808R8R0P0X
:2P202d];@@0<c<c0`0b<S8202h^;P80:RXZ0P0_;bl203<c<`80;bl_0P0[:b/2030`<080=3@d0P0c
<c<2030`<080EeMG0P0m?Cd203`l?080=cLg0P0d=3@6034a<@80:BTY0P0U9BD203Lg=`80B4Q80P1e
MGD206=SH`80IfMW0P1PH60207MgM`80DU9B0P1KFe/206=SH`80JFUY0`1^KVh2075aL@80Lg=c0P1f
MWH207QhN080NGUi0P1jNWX207emO@H0P8200P22PX8208B4Q080Ph>30P21PH420820P080Ogmo0P25
QHD408Z:RP80R8R81029RHT208^;R`@0S8b<102;Rh/208b<S080SHf=102>SXh308f=S@P0SXj>0P2?
Shl2096AT@80U9BD2P2FUYH209NGU`80V9RH0P2FUYH209FEU@80UiNG1P2IVIT209^KV`80W9bL0P2J
VYX209JFUP80Ti>C102ATI4209>CT`80UiNG0P2JVYX209RHV0<0UIFE0P2DU9@209FEU@80UiNG0P2I
VIT209ZJVP80Vi^K0P2OWil20:FUY@80/K6a0P2n_[h20<[:bP80d];B0P3=cLd20<K6aP80aLG5:@38
h=P205mOG`80FUYJ0P1KFe/205UIF@80L71`0P2=SHd20;no_`80/k>c0P1KFe/202`/;0809bLW0P0T
92@202/[:`80;Bd]0P0b<S8203@d=0<0;Rh^0P0`<30202TY:@80;2`/0P0b<S8203<c<`80:b/[0P0]
;Bd2034a<@80<c<c0P0b<S8204];B`80@d=30P0i>CT203Hf=P80<30`0P0a<C4203@d=080<S8b0P0X
:2P202LW9`80<30`0P1<C4`207AdM080H61P0P1ZJVX206MWI`80Kfm_0P1FEUH205iNGP80Hf=S0P1Z
JVX306i^KP80L71`0P1cLg<207QhN080NWYj101gMgL20861P@80Ogmo101nOWh208F5Q@80Ph>31022
PX8207alO080Ogmo0P25QHD208R8R080Rh^;1P27QhL208j>SP80Rh^;0P28R8P208V9R@80T92@102;
Rh/2096AT@80Rh^;0`2?Shl208b<S080Shn?0P2>SXh208f=S@80Shn?0P2>SXh209FEU@80U9BD0P2G
UiL209JFUP80U9BD0P2EUID209RHV080UYJF0P2GUiL209BDU080VIVI102HV9P209VIV@80WinO0P2K
Vi/209NGU`80UIFE0P2CTi<209:BTP80Shn?0P2DU9@209NGU`@0VYZJ0`2GUiL2092@T080V9RH102G
UiL209bLW080UYJF0P2SXj<20:FUY@80ZZZZ0P2n_[h20<k>cP80dM7A0P3>c/h20<S8b080_;bl:@38
h=P405eMG@80EUIF0P1SHf<2071`L080PX:20P36a/H20;Jf]P80F5QH0P0];Bd202@T9080820P100]
;Bd2038b<P80;bl_0`0f=SH202`/;080:RXZ0P0^;Rh203De=@80:RXZ0P0/;2`2030`<080=SHf0P0b
<S82030`<080F5QH100i>CT203De=@80<c<c100`<302034a<@80:b/[0P0U9BD203De=@80BDU90P1b
LW82065QH@80Jf][0P1PH60207AdM080DE5A0P1OGel206=SH`80IVIV1@1`L70207AdM080LW9b0P1f
MWH207emO@80O7al0P1hN7P207inOP80P8200P1mOGd408>3P`80QXJ61021PH420820P080PX:20P2;
Rh/208f=S@80RHV90P28R8P208V9R@80RXZ:0P2;Rh/208b<S0@0RXZ:0P2<S8`208n?S`@0SXj>1@2=
SHd208j>SP80Shn?102>SXh2096AT@@0UiNG0P2CTi<209NGU`80UIFE0P2DU9@209VIV@80UiNG0P2B
TY8209NGU`80U9BD0P2IVIT209^KV`80VIVI0P2KVi/209bLW080WYjN0P2FUYH209>CT`80TI6A0P2C
Ti<209:BTP@0VYZJ0P2HV9P309FEU@80TY:B0P2FUYH209NGU`80Vi^K0P2JVYX209bLW080WinO0P2T
Y:@20;2`/080_Kfm0P3:b/X20=;BdP80b/[:0P36a/H20<71`Al0b>3H000M0<SPf080Hf=S0P1NGUh4
05UIF@80Hf=S0P1eMGD20:RXZ080a<C40P2VYZH203Xj>P80<S8b0P0T92@202HV9P80:RXZ0P0_;bl2
02h^;P<0;Bd]100/;2`2030`<080<c<c0P0a<C4202h^;P80<S8b0P0e=CD203Hf=P80=CDe0P1<C4`4
03lo?`80>SXj0P0g=cL203<c<`80<C4a0P0`<30202XZ:P80:BTY0P0[:b/204Y:BP80NGUi0P1WIfL2
06e]K@80I6AT0P1[Jf/205IFEP80GUiN0P1WIfL206a/K0<0Kfm_0P1`L702079bLP80MgMg0P1lO7`4
07]kN`80OGem101oOgl40820P080PH611020P8020861P@80Ph>30P25QHD208N7Q`80R8R8102:RXX4
08^;Ra<0S8b<0P2=SHd208n?S`@0SXj>0P2ATI4209BDU080UiNG102HV9P409NGU`80V9RH202GUiL2
09RHV0H0VYZJ102KVi/209VIV@80UiNG0P2DU9@209>CT`80U9BD0P2EUID409NGU`80UIFE0`2CTi<2
09BDU080UIFE0P2DU9@209FEU@80UiNG0P2IVIT209bLW080XJ6Q0P2][Jd20;Zj^P80b<S80P3AdM42
0<_;b`80`/;20P34a<@Y0<SPf080HV9R0P1JFUX205QHF080GemO0P1QHF4207IfMP80X:2P0P38b<P2
0:ZZZP80?clo0P0X:2P402@T9080:BTY0P0d=3@2034a<@<0;Bd]100/;2`2034a<@80=CDe0P0d=3@2
030`<080<S8b0P0h>3P203`l?080?Cdm0P1<C4`20410@080?Cdm0P13@d<203Xj>P80<c<c0P0b<S82
02`/;0@0<30`0P0];Bd204];B`80MgMg0P1YJFT206i^KP80HF5Q0P1YJFT2055AD@80GUiN0P1QHF42
06UYJ@<0Lg=c0P1bLW8207=cL`80M7Ad0P1mOGd207YjNP80O7al0P22PX8207emO@@0P8200P23Ph<2
07moO`80PH610P22PX8208B4Q080PX:20P28R8P208F5Q@80Rh^;0P29RHT208f=S@80RHV9102=SHd2
08n?S`@0SHf=0P2:RXX408b<S080RXZ:0`2=SHd208^;R`80S8b<0P2ATI4208b<S080TY:B0P2DU9@2
09RHV080VYZJ102GUiL209VIV@@0UiNG0P2JVYX209BDU080UiNG0P2LW9`409JFUP80UiNG0P2MWId2
09VIV@80V9RH0P2IVIT609BDU080Ti>C0P2EUID209RHV080UIFE0`2BTY8209BDU080Ti>C102GUiL2
09RHV080VYZJ0P2NWYh20:BTY080Zj^[0P2h^;P20<[:bP80c/k>0P3=cLd20<O7a`80^k^k:@38h=P2
06ATI080GUiN0P1LG5`205UIF@80HF5Q0P1bLW820:ZZZP80a<C40P2VYZH203Hf=P80<S8b0P0Y:BT2
028R8P80:RXZ0P0f=SH2038b<P<0:BTY0P0X:2P203<c<`80<30`0P0g=cL203<c<`80<30`0P0d=3@2
034a<@80<30`0P0c<c<204m?C`80@T920P15ADD20451@@80>SXj0P0g=cL202d];@80=CDe0P0Y:BT2
02LW9`80;2`/0P1;Bd/207EeM@80JVYZ0P1]KFd206EUI@80JFUY0P1DE5@2061PH080JVYZ0P1]KFd3
06i^KP80Kfm_0P1aLG4207MgM`80O7al0P1mOGd207UiN@80Ng]k0P24Q8@20820P080Ph>3101oOgl2
07inOP80Ogmo0P22PX820820P0@0Q8B41029RHT208b<S080Rh^;102=SHd408j>SP80S8b<0P2=SHd2
08Z:RP80SHf=0P2>SXh308^;R`80SHf=102>SXh2092@T080TI6A0P2EUID209RHV080VYZJ0P2IVIT2
09NGU`80VIVI0P2FUYH209bLW0@0UIFE102HV9P209ZJVP80UiNG0P2KVi/209ZJVP80V9RH0P2IVIT2
09JFUP80TY:B0P2ATI4209FEU@80Ti>C0P2EUID209NGU`D0UYJF0P2EUID609BDU080UYJF0P2IVIT2
09bLW080Xj>S0P2/[:`20;^k^`80bLW90P3@d=020<[:bP80`l?30P38b<PO0<SPf0007@38h=P206=S
H`80GUiN101IFET206=SH`80MGEe0P2XZ:P20<C4a080YZJV0P0j>SX2038b<P8092@T0P0V9RH202XZ
:P80;bl_0P0^;Rh302d];@@0;2`/0P0`<30203<c<`80<C4a0P0^;Rh2038b<P80=CDe0P0f=SH203De
=@80C4a<100o?cl203Xj>P80=cLg0P0c<c<2034a<@80<30`0P0Z:RX202TY:@80:b/[0P1:BTX207Ui
N@80IfMW0P1]KFd206ATI080Jf][0P1FEUH205iNGP80IfMW0P1/K6`306m_K`80L71`0P1bLW8207Mg
M`80O7al101kNg/207emO@@0Ogmo1020P8020861P@@0P8200P21PH4208>3P`80QHF50P27QhL208R8
R0@0RXZ:102;Rh/C08b<S080SHf=0P2?Shl408j>SP80TI6A0P2DU9@209NGU`@0V9RH102GUiL209RH
V0P0UiNG0P2HV9P609ZJVP@0Vi^K0P2IVIT209NGU`80U9BD0P2CTi<209BDU080UIFE102GUiL209FE
U@<0Ti>C0P2DU9@209FEU@80U9BD0P2EUID209NGU`80VIVI0P2LW9`20:6QX@80[Jf]0P2j^[X20<S8
b080dM7A0P3;bl/20<;2`P80a<C4:@38h=P2069RHP80FUYJ0P1HF5P205mOG`80HF5Q0P1fMWH20:2P
X080b<S80P2ZZZX203lo?`80:2PX100T92@202TY:@80=3@d0P0a<C4302d];@@0;2`/0P0a<C4203De
=@80=3@d0P0`<302038b<P80>3Ph0P0l?3`203dm?@80C4a<0P10@40203dm?@80@d=30P0j>SX203<c
<`80<S8b0P0/;2`4030`<080;Bd]0P1;Bd/207MgM`80JFUY0P1^KVh2065QH@80JFUY0P1ADE4205iN
GP80HF5Q0P1YJFT307=cL`80LW9b0P1cLg<207AdM080OGem0P1jNWX207alO080PX:20P1mOGd40820
P080Ph>30P1oOgl20861P@80PX:20P24Q8@208:2PP80R8R80P25QHD208^;R`80RHV90P2=SHd208V9
R@@0SHf=0P2?Shl408f=S@80RXZ:102<S8`208Z:RP<0SHf=0P2;Rh/208b<S080TI6A0P2<S8`209:B
TP80U9BD0P2HV9P209ZJVP@0UiNG0P2IVIT409NGU`80VYZJ0P2DU9@209NGU`80W9bL102FUYH209NG
U`80WIfM0P2IVIT209RHV080VIVI1P2DU9@209>CT`80UIFE0P2HV9P209FEU@<0TY:B0P2DU9@209>C
T`@0UiNG0P2HV9P209ZJVP80WYjN0P2TY:@20:^[Z`80^;Rh0P3:b/X20<k>cP80cLg=0P37alL20;^k
^bT0b>3H0P1TI6@205iNGP80G5aL0P1IFET2065QH@80LW9b0P2ZZZX20<C4a080YZJV0P0f=SH2038b
<P80:BTY0P0R8R8202XZ:P80=SHf0P0b<S8302TY:@80:2PX0P0c<c<2030`<080=cLg0P0c<c<2030`
<080=3@d0P0a<C42030`<080<c<c0P1?Cdl20492@P80ADE50P11@D4203Xj>P80=cLg0P0];Bd203De
=@80:BTY0P0W9bL202`/;080Bd];0P1eMGD206YZJP80KFe]0P1UIFD206UYJ@80E5AD0P1PH60206YZ
JP80KFe]0`1^KVh206m_K`80LG5a0P1gMgL207alO080OGem0P1iNGT207]kN`80Q8B40P20P80208>3
P`@0Ogmo0P1nOWh207moO`80PX:20P20P80408B4Q0@0RHV90P2<S8`208^;R`@0SHf=102>SXh208b<
S080SHf=0P2:RXX208f=S@80SXj>0`2;Rh/208f=S@@0SXj>0P2@T902096AT@80UIFE0P2HV9P209ZJ
VP80VIVI0P2GUiL209VIV@80UYJF0P2LW9`409FEU@@0V9RH0P2JVYX209NGU`80Vi^K0P2JVYX209RH
V080VIVI0P2FUYH209:BTP80TI6A0P2EUID209>CT`80UIFE0P2GUiL509JFUP80UIFE1P2DU9@209JF
UP80VIVI0P2LW9`20:>SX`80[:b/0P2k^k/20<W9b@80d=3@0P3:b/X20<?3``80b<S87`38h=P001d0
b>3H0P1UIFD2061PH080Fe]K0P1GEeL205YJFP80L71`0P2:RXX20;Rh^080c/k>0P2FUYH203<c<`80
9bLW100Z:RX702/[:`80;Bd]0P0`<302038b<P@0<c<c0P0b<S8203@d=080=cLg0P0j>SX203dm?@80
?Shn0P12@T820451@@80?Shn0P0i>CT203@d=080<C4a0P0_;bl202TY:@80:b/[0P0M7Ad204e=C@80
O7al0P1/K6`2071`L080JFUY0P1OGel205UIF@80H61P0P1ZJVX206i^KPL0LG5a0P1hN7P407inOP80
O7al0P1mOGd207inOP80Ogmo0P20P80207moO`@0OWin0P20P80208>3P`80QXJ60P24Q8@208>3P`80
QhN70P2;Rh/808b<S0@0SXj>0P2=SHd208^;R`80RXZ:0P29RHT208^;R`<0S8b<0P2>SXh408n?S`80
T92@0P2CTi<209NGU`80VIVI0P2JVYX209VIV@80V9RH0P2IVIT209ZJVP80V9RH0P2FUYH209NGU`80
VIVI102JVYX209^KV`80W9bL0P2KVi/209ZJVP80VIVI0P2HV9P209JFUP80UIFE0P2FUYH209RHV080
UYJF0P2DU9@709>CT`80U9BD0P2BTY82092@T080Ti>C0P2GUiL209VIV@80WIfM0P2YZJT20;Jf]P80
aLG50P3?cll20<S8b0@0_kno:@38h=P205aLG080JVYZ0P1IFET205YJFP80HV9R0P1UIFD208Z:RP80
`l?30P37alL2096AT@80=cLg0P0/;2`2034a<@809RHV0P0/;2`2038b<P<0:2PX0P0d=3@2034a<@80
;Rh^0P0a<C4203<c<`80;Rh^0P0];Bd2034a<@80=cLg0P0a<C420451@@80?Cdm0P0l?3`203/k>`80
;Rh^0P0b<S8202l_;`80;2`/0P0[:b/202PX:0809RHV0P1:BTX2071`L080Kfm_0P1^KVh406IVIP80
E5AD0P1QHF4406a/K0D0LG5a0P1`L70207IfMP80Ogmo0P1jNWX207UiN@80PX:20P1jNWX207emO@80
OWin0P1mOGd207inOP80NGUi0P1nOWh208>3P`80Q8B40P25QHD208:2PP80QHF50P2<S8`408V9R@80
TI6A0P29RHT208f=S@80SXj>0P2?Shl208^;R`80R8R80P2:RXX208b<S0<0SXj>0P2<S8`208n?S`80
TI6A0P2?Shl209BDU080UYJF0P2GUiL209VIV@80V9RH102GUiL209^KV`80VYZJ0P2FUYH209BDU080
V9RH0P2MWId209VIV@80W9bL0P2KVi/209bLW080Vi^K102GUiL209BDU080TY:B0P2JVYX209RHV080
UIFE0P2CTi<209:BTPL0U9BD0P2ATI42092@T080U9BD0P2GUiL209JFUP80W9bL0P2YZJT20;Jf]P80
a/K60P3=cLd20<[:bP80`L710P2g]kLY0<SPf080Hf=S0P1PH60205QHF080E5AD0P1GEeL207EeM@80
Ph>30P2g]kL20<o?c`80Vi^K0P0b<S8202LW9`80:BTY0P0[:b/202TY:@80:RXZ0`0_;bl202PX:080
<C4a0P0b<S86034a<@@0=3@d0P10@40203hn?P80?Cdm0P0l?3`20492@P@0=cLg0P0d=3@2030`<080
;Rh^100Y:BT2020P8080Bd];0P1gMgL206a/K080L71`0P1ZJVX2061PH080F5QH0P1PH60206QXJ080
KVi^0`1bLW8406m_K`80NGUi0P1jNWX207moO`80OGem0P1jNWX207]kN`@0P8200P1oOgl20820P080
O7al0P21PH4208B4Q080QHF50P27QhL208:2PP80R8R80P2:RXX208j>SP80Rh^;0P2<S8`408f=S@80
Shn?0P2;Rh/208Z:RP80Rh^;1029RHT308j>SP@0Shn?0P2=SHd2092@T080Ti>C0P2FUYH209NGU`80
VYZJ0P2GUiL209RHV080VIVI102JVYX209NGU`80UIFE0P2JVYX209RHV080Vi^K0P2JVYX409^KV`80
VYZJ0P2KVi/209RHV080UiNG0P2CTi<209^KV`80VIVI102EUID209>CT`<0TI6A0P2BTY8409>CT`80
TI6A0P2BTY8209NGU`80VYZJ0P2NWYh20::RXP80^;Rh0P37alL20<k>cP80alO70P2n_[h20;no_al0
b>3H000M0<SPf080IFEU0P1PH60205]KF`80EeMG0P1JFUX2071`L080RXZ:0P2h^;P20<k>cP80UYJF
0P0c<c<202LW9`@0:RXZ1`0[:b/202d];@80<30`0P0b<S8403<c<`80<S8b0P0d=3@203Lg=`80>SXj
0P0m?Cd203hn?P80@T920P11@D4203hn?P80>CTi0P0d=3@2034a<@80;bl_0P0Y:BT202/[:`807AdM
0P1=CDd207alO080K6a/0P1`L70206UYJ@80GemO0P1IFET2061PH080JVYZ0P1^KVh7075aL@80N7Qh
101nOWh207alO080OGem0P1nOWh207moO`80P8200P1oOgl407inOP80P8200P23Ph<208J6QP80Q8B4
0P23Ph<208N7Q`80Rh^;202<S8`408j>SP80SHf=0P2;Rh/208Z:RP80RHV90P2;Rh/308b<S080SXj>
102?Shl2092@T080Ti>C0P2GUiL209VIV@80VYZJ0P2IVIT209RHV080VIVI0P2JVYX209RHV080UYJF
0P2GUiL209VIV@@0VYZJ0P2KVi/209bLW080Vi^K0P2JVYX209VIV@80V9RH0P2FUYH209FEU@80UYJF
0P2HV9P209JFUP80U9BD1`2CTi<209BDU080TY:B0P2@T90209>CT`80UiNG0P2IVIT209fMW@80ZJVY
0P2f][H20<G5a@80clo?0P38b<P40;no_bT0b>3H0P1LG5`206YZJP80FEUI0P1JFUX2069RHP80IFEU
0P2:RXX20<?3``80alO70P2ATI4203Lg=`80;2`/0P0a<C4202HV9P80;2`/0P0b<S8302PX:080=3@d
0P0a<C4202h^;P80<C4a0P0c<c<202h^;P80;Bd]0P0a<C4203Lg=`80<C4a0P11@D4203dm?@80?3`l
0P0k>c/202h^;P80<S8b0P0_;bl202`/;080:b/[0P0X:2P202HV9P80BTY:0P1`L70206m_K`80KVi^
101VIVH205ADE080HF5Q101/K6`5075aL@80L71`0P1fMWH207moO`80NWYj0P1iNGT208:2PP80NWYj
0P1mOGd207inOP80OGem0P1nOWh207UiN@80OWin0P23Ph<208B4Q080QHF50P22PX8208F5Q@80S8b<
1029RHT2096AT@80RHV90P2=SHd208j>SP80Shn?0P2;Rh/208R8R080RXZ:0P2<S8`308j>SP80S8b<
0P2?Shl2096AT@80Shn?0P2DU9@209JFUP80UiNG0P2IVIT209RHV0@0UiNG0P2KVi/209ZJVP80UYJF
0P2DU9@209RHV080WIfM0P2IVIT209bLW080Vi^K0P2LW9`209^KV`@0UiNG0P2DU9@209:BTP80VYZJ
0P2HV9P209FEU@80Ti>C0P2BTY8709BDU080TI6A0P2@T90209BDU080UiNG0P2FUYH209bLW080ZJVY
0P2f][H20<K6aP80cLg=0P3:b/X20<71`@80]kNg:@38h=P206=SH`80H61P0P1HF5P205ADE080EeMG
0P1eMGD208>3P`80]kNg0P3?cll209^KV`80<S8b0P0W9bL202TY:@80:b/[0P0Y:BT202XZ:P<0;bl_
0P0X:2P2034a<@80<S8b1P0a<C4403@d=080@4100P0n?Sh203dm?@80?3`l0P12@T8403Lg=`80=3@d
0P0`<30202h^;P@0:BTY0P0P820204];B`80MgMg0P1/K6`2071`L080JVYZ0P1PH60205QHF080H61P
0P1XJ6P206i^KP<0LW9b101_Kfl207UiN@80NWYj0P1oOgl207emO@80NWYj0P1kNg/40820P080Ogmo
0P20P80207alO080PH610P24Q8@208F5Q@80QhN70P22PX8208R8R080RXZ:0P2>SXh208^;R`80S8b<
102=SHd208n?S`80Rh^;0P2:RXX208^;R`@0RHV90`2>SXh408n?S`80SHf=0P2@T90209>CT`80UYJF
0P2GUiL209ZJVP80UiNG0P2HV9P209VIV@@0VYZJ0P2GUiL209FEU@80VYZJ0P2HV9P209^KV`80VYZJ
102KVi/209ZJVP80Vi^K0P2HV9P209NGU`80Ti>C0P2KVi/209VIV@@0UIFE0P2CTi<3096AT@80TY:B
102CTi<2096AT@80TY:B0P2GUiL209ZJVP80WYjN0P2RXZ820;Rh^080alO70P3>c/h20<O7a`80_[jn
0P2o_klO0<SPf0007@38h=P205MGE`80GUiN0P1PH60205QHF080Fe]K0P1cLg<2092@T080YjNW0P3D
e=@20;Rh^080OWin0P17AdL202LW9`80:BTY0P0a<C42030`<0<0;bl_0P0c<c<403Lg=`80=SHf100d
=3@203De=@80>3Ph0P0k>c/203hn?P80?Cdm0P0o?cl203dm?@80>SXj0P0f=SH203<c<`80;Bd]0P0/
;2`203Ti>@80Bd];0P0b<S8205MGE`@0LG5a0P1TI6@206e]K@80GUiN0P1IFET205mOG`80J6QX0P1]
KFd3071`L080LW9b0P1dM7@207UiN@80OGem101nOWh407emO@80P8200P22PX820861P@80Ogmo0P20
P8020861P@80Ph>30P25QHD208J6QP80QhN70P29RHT208b<S0`0SHf=0P2<S8`208^;R`80S8b<0P2=
SHd508j>SP80Shn?0P2ATI4209:BTP80U9BD0P2GUiL209VIV@80VYZJ1P2IVIT409ZJVP@0VIVI0P2J
VYX209bLW0H0WIfM102LW9`209^KV`80VIVI0P2GUiL209JFUP80UiNG0P2HV9P209VIV@80UiNG2@2D
U9@209>CT`80TI6A0P2@T902096AT@80U9BD0P2GUiL209fMW@80YZJV0P2a/K420;no_`80b/[:0P36
a/H20<71`@80[jn_:@38h=P204i>CP80JFUY0P1EEED2055AD@80FUYJ0P1YJFT209BDU080/k>c0P37
alL20<G5a@80OWin0P0i>CT202LW9`809BDU0P0/;2`202/[:`<0:RXZ0P0a<C42038b<P@0>3Ph0P0k
>c/203Ti>@80@4100P0n?Sh204=3@`80@T920P1<C4`20451@@@0@T920P0l?3`403Xj>P80;bl_0P0i
>CT403Xj>P80G5aL0P1bLW8207AdM080IfMW0P1`L702069RHP80GEeM0P1SHf<406][J`<0Kfm_0P1b
LW8207QhN080Ng]k0P20P80407moO`80OGem0P1oOgl208:2PP80QHF50P24Q8@408>3P`80QXJ60P21
PH4208F5Q@@0R8R80P2:RXX208n?S`80RXZ:0P2?Shl2096AT@80RXZ:0P2;Rh/208Z:RP@0S8b<0P2;
Rh/208j>SP80SHf=0`2<S8`4092@T080UIFE0P2@T90409VIV@H0VYZJ0P2LW9`409VIV@80Vi^K102H
V9P209^KV`80WinO0P2NWYh209bLW080WinO0P2MWId409^KV`80V9RH102GUiL209ZJVP80V9RH0P2E
UID209NGU`80UIFE0`2BTY8209BDU080Ti>C0P2ATI4408j>SP80UIFE0P2HV9P209nOW`80Xj>S0P2a
/K420;no_`80bLW90P38b<P20<30`080/;2`:@38h=P205YJFP80GemO0P1TI6@205QHF080G5aL0P1l
O7`209JFUP80Y:BT0P3Bd]820;Rh^080Ng]k0P18B4P202TY:@@0:RXZ0P0d=3@3030`<080;Rh^0P0e
=CD203Xj>P80=SHf0P0e=CD203<c<`80<S8b0P0j>SX204A4A080>3Ph0P0k>c/20451@@80?Cdm0P0j
>SX203Ph>080<C4a0P0/;2`2030`<080=cLg0P1=CDd203Hf=P80FEUI0P1cLg<2071`L080IfMW0P1Y
JFT2061PH080FUYJ0P1OGel206UYJ@80Jf][0`1bLW82075aL@80MgMg0P1oOgl207inOP80PX:21P1n
OWh20820P080OGem0P22PX820861P@80O7al0P24Q8@208>3P`80QXJ60P24Q8@208Z:RP80QhN70P2<
S8`208n?S`80RXZ:0P2<S8`208^;R`80S8b<0P2=SHd208^;R`@0SHf=0P2>SXh208^;R`<0S8b<1P2A
TI4209BDU080V9RH102KVi/209VIV@80VYZJ0P2IVIT209RHV080VIVI0P2KVi/209RHV080VIVI0P2N
WYh209nOW`80WIfM0P2QXJ4209fMW@80WinO0P2MWId209VIV@80UIFE102FUYH209VIV@80UiNG0P2C
Ti<209JFUP80Ti>C1@2EUID209BDU080TI6A0P2@T90209:BTP80U9BD0P2HV9P209nOW`80YjNW0P2_
[jl20<;2`P80bl_;0P34a<@20<;2`P80/k>c7`38h=P001d0b>3H0P1GEeL205iNGP80H61P0P1HF5P2
05]KF`80Lg=c0P2@T9020:NWY`80e=CD0P2h^;P207inOP80AdM70P0W9bL202TY:@80<C4a0P0`<303
02l_;`80<c<c100g=cL203Hf=P@0=3@d0P0e=CD203Ph>080>c/k0P0n?Sh203dm?@80?clo0P0m?Cd2
03Xj>P80=SHf0P0c<c<202d];@80;2`/0P0i>CT204];B`80<S8b0P1GEeL4075aL@80I6AT0P1]KFd2
05iNGP80FEUI0P1OGel206QXJ080KFe]0`1`L702079bLP80M7Ad0P1iNGT207emO@@0OWin101mOGd2
0820P080PX:20P21PH4207moO`80P8200P21PH4208>3P`80QHF50P26QXH208N7Q`80RHV90P2<S8`<
08f=S@80S8b<0P2;Rh/208b<S080SHf=1@2>SXh208n?S`80TI6A0P2BTY8209BDU080UiNG0P2IVIT2
09ZJVPH0VIVI102JVYX409VIV@80VYZJ0P2LW9`609fMW@@0W9bL0P2KVi/209VIV@80UiNG0P2FUYH2
09NGU`80V9RH0P2IVIT209NGU`T0U9BD0P2CTi<2096AT@80T92@0P2ATI4209BDU080UiNG0P2MWId2
0:JVYP80/K6a0P2o_kl20<[:bP80a/K60P31`L420:n_[bT0b>3H0P1>CTh206UYJ@80EEEE0P1ADE42
05YJFP80JFUY0P2DU9@20;>c/`80alO70P35aLD207inOP80>CTi0P0W9bL202DU9@80;2`/0P0[:b/3
02XZ:P80<C4a0P0b<S8403Ph>080>c/k0P0i>CT20410@080?Shn0P13@d<20492@P80C4a<0P11@D44
0492@P80?3`l100j>SX202l_;`80>CTi100j>SX205aLG080LW9b0P1dM7@206MWI`80L71`0P1RHV82
05eMG@80Hf=S101[Jf/306m_K`80LW9b0P1hN7P207]kN`80P820101oOgl207emO@80Ogmo0P22PX82
08F5Q@80Q8B41023Ph<208J6QP80PH610P25QHD408R8R080RXZ:0P2?Shl208Z:RP80Shn?0P2ATI42
08Z:RP80Rh^;0P2:RXX408b<S080Rh^;0P2>SXh208f=S@<0S8b<102@T90209FEU@80T92@102IVIT6
09ZJVP80W9bL102IVIT209^KV`@0V9RH0P2KVi/209nOW`80WYjN0P2LW9`209nOW`80WIfM102KVi/2
09RHV0@0UiNG0P2JVYX209RHV080UIFE0P2GUiL209FEU@<0TY:B0P2DU9@209>CT`80TI6A102>SXh2
09FEU@80V9RH0P2OWil20:>SX`80/K6a0P2o_kl20<W9b@80b<S80P30`<020;2`/2T0b>3H0P1JFUX2
05mOG`80I6AT0P1HF5P205aLG080O7al0P2FUYH20:BTY080d];B0P2h^;P207]kN`80B4Q80P0Y:BT4
02XZ:P80=3@d0`0`<30202h^;P80=CDe0P0j>SX203Hf=P80=CDe0P0c<c<2038b<P80>SXj0P14A4@2
03Ph>080>c/k0P11@D4203dm?@80>SXj0P0h>3P2034a<@80;2`/0P0`<30203Lg=`80CDe=0P0f=SH2
05UIF@80Lg=c0P1`L70206MWI`80JFUY0P1PH60205YJFP80GemO0P1YJFT206][J`<0LW9b0P1aLG42
07MgM`80Ogmo0P1nOWh208:2PPH0OWin0P20P80207emO@80PX:20P21PH4207alO080Q8B40P23Ph<2
08J6QP80Q8B40P2:RXX208N7Q`80S8b<0P2?Shl208Z:RP80S8b<0P2;Rh/208b<S080SHf=0P2;Rh/4
08f=S@80SXj>0P2;Rh/308b<S0H0TI6A0P2DU9@209RHV0@0Vi^K0P2IVIT209ZJVP80VIVI0P2HV9P2
09VIV@80Vi^K0P2HV9P209VIV@80WYjN0P2OWil209fMW@80XJ6Q0P2MWId209nOW`80WIfM0P2IVIT2
09FEU@@0UYJF0P2IVIT209NGU`80Ti>C0P2FUYH209>CT`D0UIFE0P2DU9@2096AT@80T92@0P2BTY82
09BDU080V9RH0P2OWil20:NWY`80[jn_0P32`/820<_;b`80a<C40P32`/820;>c/al0b>3H000M0<SP
f080D51@0P1KFe/206EUI@80GEeM0P1NGUh207MgM`80VIVI0P2BTY820<C4a080c/k>0P38b<P206e]
K@80<c<c0P0];Bd203Hf=PD0=3@d0P0h>3P203dm?@80>c/k0P0g=cL203Hf=P80=CDe0P0f=SH203Ti
>@80?3`l0P0n?Sh203dm?@80>c/k0P0h>3P203De=@80<c<c0P0b<S8202l_;`80;Bd]0P0W9bL202`/
;080:BTY0P1SHf<206][J`80MWIf0P1FEUH206m_K`80H61P0P1GEeL205aLG080IVIV0P1[Jf/306m_
K`80Lg=c0P1gMgL207UiN@80Ng]k0P1mOGd207moO`80OWin0P1mOGd20820P0@0PX:20P21PH4608:2
PP80Ph>30P27QhL408^;R`@0S8b<1P2=SHd808b<S080Shn?0P2BTY82096AT@<0T92@0P2ATI4209:B
TP80UIFE0P2GUiL209VIV@@0VYZJ0P2IVIT809ZJVP@0Vi^K0P2MWId609nOW`80WYjN1P2MWId209ZJ
VP@0UiNG0P2HV9P409VIV@80UiNG102EUID309JFUP80U9BD0P2BTY84096AT@@0T92@0P2EUID209fM
W@80Xj>S0P2[Zj/20;Vi^@80a<C40P32`/820<71`@80X:2P:@38h=P2055AD@80H61P0P1SHf<205UI
F@80HV9R0P1fMWH209>CT`80W9bL0P31`L420<_;b`80`l?30P1dM7@203Ph>080=CDe0P0g=cL503Hf
=P80@D510P10@40203hn?P@0=cLg0P0c<c<203Ph>080>SXj0P0d=3@203dm?@80?clo0P0h>3P203Hf
=P80=3@d0P0/;2`202h^;P80<S8b0P0W9bL202d];@80;2`/0P0b<S8205YJFP80Kfm_0P1`L70205eM
G@80KVi^101FEUH2061PH080I6AT0P1ZJVX3071`L080M7Ad0P1fMWH207QhN080Ng]k0P1hN7P207em
O@80PX:20P1jNWX40820P080OWin0P1oOgl208:2PP80P8200P24Q8@208>3P`80Q8B40P28R8P208f=
S@80Rh^;0P29RHT208f=S@80Shn?0P2:RXX208j>SP80SHf=0P2:RXX208b<S080Shn?0P2CTi<208n?
S`D0TI6A0P2CTi<209NGU`80UYJF0P2KVi/209NGU`80WIfM0P2GUiL609VIV@@0VYZJ0P2LW9`209^K
V`80WinO0P2LW9`20:2PX0@0WIfM0P2LW9`209fMW@80VYZJ0P2FUYH209BDU080VYZJ0P2HV9P209VI
V@80UiNG0P2FUYH209BDU0<0UYJF0P2GUiL409:BTP@0TI6A0P2?Shl209FEU@80WYjN0P2QXJ420:b/
[080^[Zj0P32`/820<G5a@80^k^k0P2XZ:PY0<SPf080CDe=0P1LG5`206EUI@80EeMG0P1QHF4207Ui
N@80UIFE0P2@T9020<C4a080d=3@0P39bLT206e]K@80;bl_0P0b<S8203De=@80>SXj0`0a<C4203Ph
>080>c/k100g=cL2034a<@H0=CDe0P0n?Sh403dm?@80=SHf0P0o?cl2034a<@80=SHf0P0a<C4402l_
;`809BDU0P0Z:RX202/[:`80H61P0P1]KFd207=cL`80FEUI0P1]KFd205mOG`80EUIF0P1KFe/206UY
J@80Jf][0`1_Kfl207EeM@80M7Ad0P1gMgL207QhN080Ng]k0P1mOGd20820P080NWYj0P1oOgl20820
P080RHV90P1nOWh208:2PP80Ph>30P20P80408J6QP80SXj>0P28R8P208b<S0@0SHf=102>SXh808b<
S080Shn?0P2BTY85096AT@80Ti>C0P2ATI4209FEU@80UiNG0P2IVIT209RHV080VIVI0P2HV9P209^K
V`H0VYZJ102LW9`209jNWP80XJ6Q0P2LW9`209nOW`80WYjN102LW9`209^KV`80W9bL0P2EUID209VI
V@@0V9RH0P2JVYX209VIV@80Ti>C0P2FUYH309BDU080UIFE0P2ATI42092@T080TY:B0P2?Shl2096A
T@80UIFE0P2LW9`20:>SX`80ZJVY0P2i^KT20<G5a@80`<300P32`/820:6QXAl0b>3H000M0<SPf080
D51@0P1KFe/206EUI@80GEeM0P1NGUh207MgM`80VIVI0P2BTY820<C4a080c/k>0P38b<P206e]K@80
<c<c0P0];Bd203Hf=PD0=3@d0P0h>3P203dm?@80>c/k0P0g=cL203Hf=P80=CDe0P0f=SH203Ti>@80
?3`l0P0n?Sh203dm?@80>c/k0P0h>3P203De=@80<c<c0P0b<S8202l_;`80;Bd]0P0W9bL202`/;080
:BTY0P1SHf<206][J`80MWIf0P1FEUH206m_K`80H61P0P1GEeL205aLG080IVIV0P1[Jf/306m_K`80
Lg=c0P1gMgL207UiN@80Ng]k0P1mOGd207moO`80OWin0P1mOGd20820P0@0PX:20P21PH4608:2PP80
Ph>30P27QhL408^;R`@0S8b<1P2=SHd808b<S080Shn?0P2BTY82096AT@<0T92@0P2ATI4209:BTP80
UIFE0P2GUiL209VIV@@0VYZJ0P2IVIT809ZJVP@0Vi^K0P2MWId609nOW`80WYjN1P2MWId209ZJVP@0
UiNG0P2HV9P409VIV@80UiNG102EUID309JFUP80U9BD0P2BTY84096AT@@0T92@0P2EUID209fMW@80
Xj>S0P2[Zj/20;Vi^@80a<C40P32`/820<71`@80X:2P:@38h=P2055AD@80H61P0P1SHf<205UIF@80
HV9R0P1fMWH209>CT`80W9bL0P31`L420<_;b`80`l?30P1dM7@203Ph>080=CDe0P0g=cL503Hf=P80
@D510P10@40203hn?P@0=cLg0P0c<c<203Ph>080>SXj0P0d=3@203dm?@80?clo0P0h>3P203Hf=P80
=3@d0P0/;2`202h^;P80<S8b0P0W9bL202d];@80;2`/0P0b<S8205YJFP80Kfm_0P1`L70205eMG@80
KVi^101FEUH2061PH080I6AT0P1ZJVX3071`L080M7Ad0P1fMWH207QhN080Ng]k0P1hN7P207emO@80
PX:20P1jNWX40820P080OWin0P1oOgl208:2PP80P8200P24Q8@208>3P`80Q8B40P28R8P208f=S@80
Rh^;0P29RHT208f=S@80Shn?0P2:RXX208j>SP80SHf=0P2:RXX208b<S080Shn?0P2CTi<208n?S`D0
TI6A0P2CTi<209NGU`80UYJF0P2KVi/209NGU`80WIfM0P2GUiL609VIV@@0VYZJ0P2LW9`209^KV`80
WinO0P2LW9`20:2PX0@0WIfM0P2LW9`209fMW@80VYZJ0P2FUYH209BDU080VYZJ0P2HV9P209VIV@80
UiNG0P2FUYH209BDU0<0UYJF0P2GUiL409:BTP@0TI6A0P2?Shl209FEU@80WYjN0P2QXJ420:b/[080
^[Zj0P32`/820<G5a@80^k^k0P2XZ:PY0<SPf080CDe=0P1LG5`206EUI@80EeMG0P1QHF4207UiN@80
UIFE0P2@T9020<C4a080d=3@0P39bLT206e]K@80;bl_0P0b<S8203De=@80>SXj0`0a<C4203Ph>080
>c/k100g=cL2034a<@H0=CDe0P0n?Sh403dm?@80=SHf0P0o?cl2034a<@80=SHf0P0a<C4402l_;`80
9BDU0P0Z:RX202/[:`80H61P0P1]KFd207=cL`80FEUI0P1]KFd205mOG`80EUIF0P1KFe/206UYJ@80
Jf][0`1_Kfl207EeM@80M7Ad0P1gMgL207QhN080Ng]k0P1mOGd20820P080NWYj0P1oOgl20820P080
RHV90P1nOWh208:2PP80Ph>30P20P80408J6QP80SXj>0P28R8P208b<S0@0SHf=102>SXh808b<S080
Shn?0P2BTY85096AT@80Ti>C0P2ATI4209FEU@80UiNG0P2IVIT209RHV080VIVI0P2HV9P209^KV`H0
VYZJ102LW9`209jNWP80XJ6Q0P2LW9`209nOW`80WYjN102LW9`209^KV`80W9bL0P2EUID209VIV@@0
V9RH0P2JVYX209VIV@80Ti>C0P2FUYH309BDU080UIFE0P2ATI42092@T080TY:B0P2?Shl2096AT@80
UIFE0P2LW9`20:>SX`80ZJVY0P2i^KT20<G5a@80`<300P32`/820:6QXAl0b>3H000M0<SPf080Lg=c
0P1HF5P2065QH@80KVi^0P1LG5`2071`L0@0RHV90P2XZ:P20<71`@80b<S80P35aLD205ADE080:b/[
0P0`<30202l_;`<0<S8b0P0f=SH203Ti>@80>3Ph1P0e=CD203Hf=P80>3Ph0P0l?3`203hn?P80?3`l
0P0i>CT203Lg=`80=SHf0P0d=3@203<c<`80<30`0P0_;bl202`/;080<c<c0P0];Bd206ATI080Kfm_
0P1lO7`205IFEP80JVYZ0P1LG5`205EEE@80Fe]K0P1UIFD206YZJP<0KVi^0P1cLg<207IfMP80NGUi
0P1jNWX207alO080OWin101mOGd207inOP80P8200P1nOWh207emO@80P8201023Ph<208:2PP80QHF5
0P28R8P208V9R@80RXZ:0P2;Rh/608b<S080SHf=102?Shl208j>SP80Shn?0P2@T907096AT@@0TY:B
0P2DU9@209NGU`P0VYZJ1P2KVi/209bLW080WYjN0P2OWil20:6QX@80WinO102MWId609jNWP80Vi^K
0P2IVIT209ZJVP80Vi^K0P2JVYX209NGU`80UYJF1`2EUID209BDU080TY:B0P2@T90208j>SP80SHf=
0P2>SXh2096AT@80UYJF0P2LW9`20:BTY080/[:b0P2n_[h20;Zj^P80]KFe0P2SXj<Y0<SPf080IFEU
0P1HF5P206m_K`80JVYZ0P1SHf<207AdM080QhN70P29RHT20:BTY080`/;20P3@d=020;Zj^P80Bd];
0P0_;bl202h^;PL0<30`100d=3@4034a<@80;Bd]0P0e=CD203@d=080<c<c0P11@D4203Hf=P80>3Ph
100f=SH4038b<P80;bl_100/;2`2030`<080=3@d0P1LG5`407=cL`80GemO0P1YJFT205EEE@80E5AD
0P1TI6@2065QH@80JFUY0`1aLG42071`L080MWIf0P1gMgL207]kN`80OGem0P1oOgl20820P080NWYj
0P1oOgl20820P080Ogmo0P1lO7`20861P@80Ogmo0P24Q8@208:2PP80Q8B4102;Rh/208V9R@80Rh^;
0P29RHT208f=S@80Shn?0P2=SHd2092@T0@0Shn?0P2ATI4208j>SP80Ti>C0`2DU9@208f=S@80Shn?
0P2ATI4209>CT`80V9RH0P2IVIT209^KV`80UiNG0P2NWYh209VIV@80W9bL0P2MWId409jNWP80XJ6Q
0P2TY:@209nOW`H0WIfM0P2LW9`209jNWP80Vi^K0P2JVYX209RHV080VYZJ102IVIT209JFUP80Ti>C
0P2ATI4309JFUP@0TI6A102?Shl408f=S@@0U9BD0P2IVIT20:FUY@80/k>c0P2j^[X20;no_`80/K6a
0P2QXJ4Y0<SPf080Kfm_0P1LG5`205iNGP80KVi^0P1HF5P206MWI`80RHV90P2ATI420:^[Z`80_Kfm
0P3:b/X20<;2`P80EUIF0P0];Bd202`/;080:BTY0`0b<S8203Ti>@@0?Shn0P0g=cL203`l?080>3Ph
0P0i>CT203Ph>080?Shn0P10@40203hn?P80>CTi0P0h>3P203<c<`80<30`0P0d=3@203<c<`80;Bd]
0P0Y:BT203@d=080<30`0P1PH602075aL@80Ng]k0P1EEED206a/K080H61P0P1EEED205QHF080I6AT
0P1XJ6P306m_K`80Lg=c0P1gMgL207IfMP@0OGem0P1nOWh20861P@80OGem0P1nOWh207moO`80PX:2
0P1lO7`207]kN`80QHF50P1oOgl208>3P`80PH611027QhL208f=S@80Rh^;0P2=SHd208^;R`80SHf=
0P2?Shl2092@T0@0SHf=0P2>SXh2092@T080TI6A0`2BTY82096AT@80TY:B102CTi<209NGU`80VYZJ
0P2LW9`209^KV`80VIVI102LW9`209fMW@80VYZJ102MWId209nOW`80W9bL0P2MWId20:2PX080WIfM
0P2LW9`209fMW@80WYjN0P2HV9P409ZJVP@0V9RH0P2FUYH209FEU@80UiNG0`2CTi<209BDU080UIFE
0P2?Shl2092@T080RXZ:0P2>SXh208n?S`80UIFE0P2NWYh20:JVYP80];Bd0P2l_;`20;^k^`80];Bd
0P2OWilO0<SPf0007@38h=P207=cL`80F5QH0P1QHF4206i^KP80G5aL0P1`L70408V9R@80Z:RX0P31
`L420<S8b080aLG50P1DE5@202/[:`80<30`0P0_;bl3038b<P80=SHf0P0i>CT203Ph>0H0=CDe0P0f
=SH203Ph>080?3`l0P0n?Sh203`l?080>CTi0P0g=cL203Hf=P80=3@d0P0c<c<2030`<080;bl_0P0/
;2`203<c<`80;Bd]0P1TI6@206m_K`80O7al0P1FEUH206YZJP80G5aL0P1EEED205]KF`80IFEU0P1Z
JVX306i^KP80Lg=c0P1fMWH207UiN@80NWYj0P1lO7`207inOP@0OGem0P1nOWh20820P080OWin0P1m
OGd20820P0@0Ph>30P22PX8208F5Q@80R8R80P29RHT208Z:RP80Rh^;1P2<S8`208f=S@@0Shn?0P2>
SXh208n?S`80T92@1`2ATI4409:BTP80U9BD0P2GUiL809ZJVPH0Vi^K0P2LW9`209jNWP80WinO0P2Q
XJ4209nOW`@0WIfM1P2NWYh209^KV`80VIVI0P2JVYX209^KV`80VYZJ0P2GUiL209JFUPL0UIFE0P2D
U9@209:BTP80T92@0P2>SXh208f=S@80SXj>0P2ATI4209JFUP80W9bL0P2TY:@20;:b/P80_[jn0P2j
^[X20;Fe]@80Xj>S:@38h=P206EUI@80F5QH0P1_Kfl206YZJP80Hf=S0P1dM7@208N7Q`80RHV90P2T
Y:@20<;2`P80d=3@0P2j^[X204];B`80;bl_0P0^;Rh7030`<0@0=3@d100a<C4202d];@80=CDe0P0d
=3@203<c<`80@D510P0f=SH203Ph>0@0=SHf100b<S8202l_;`@0;2`/0P0`<30203@d=080G5aL101c
Lg<205mOG`80JFUY0P1EEED205ADE080I6AT0P1QHF4206UYJ@<0LG5a0P1`L70207IfMP80MgMg0P1k
Ng/207emO@80Ogmo0P20P80207YjNP80Ogmo0P20P80207moO`80O7al0P21PH4207moO`80Q8B40P22
PX8208B4Q0@0Rh^;0P29RHT208^;R`80RHV90P2=SHd208n?S`80SHf=0P2@T90408n?S`80TI6A0P2>
SXh209>CT`<0U9BD0P2=SHd208n?S`80TI6A0P2CTi<209RHV080VIVI0P2KVi/209NGU`80WYjN0P2I
VIT209bLW080WIfM102NWYh20:6QX@80Y:BT0P2OWil609fMW@80W9bL0P2NWYh209^KV`80VYZJ0P2H
V9P209ZJVP@0VIVI0P2FUYH209>CT`80TI6A0`2FUYH4096AT@@0Shn?102=SHd409BDU080VIVI0P2U
YJD20;>c/`80^[Zj0P2o_kl20;6a/@80XJ6Q:@38h=P206m_K`80G5aL0P1NGUh206i^KP80F5QH0P1W
IfL208V9R@80TI6A0P2[Zj/20;fm_@80b/[:0P32`/8205IFEP80;Bd]0P0/;2`202TY:@<0<S8b0P0i
>CT403hn?P80=cLg0P0l?3`203Ph>080>CTi0P0h>3P203hn?P80@4100P0n?Sh203Ti>@80>3Ph0P0c
<c<2030`<080=3@d0P0c<c<202d];@80:BTY0P0d=3@2030`<080H61P0P1aLG4207]kN`80EEEE0P1/
K6`2061PH080EEEE0P1HF5P206ATI080J6QX0`1_Kfl207=cL`80MgMg0P1fMWH407emO@80OWin0P21
PH4207emO@80OWin0P1oOgl208:2PP80O7al0P1kNg/208F5Q@80Ogmo0P23Ph<20861P@@0QhN70P2=
SHd208^;R`80SHf=0P2;Rh/208f=S@80Shn?0P2@T90408f=S@80SXj>0P2@T902096AT@<0TY:B0P2A
TI4209:BTP@0Ti>C0P2GUiL209ZJVP80W9bL0P2KVi/209VIV@@0W9bL0P2MWId209ZJVP@0WIfM0P2O
Wil209bLW080WIfM0P2PX:0209fMW@80W9bL0P2MWId209jNWP80V9RH102JVYX409RHV080UYJF0P2E
UID209NGU`<0Ti>C0P2DU9@209FEU@80Shn?0P2@T90208Z:RP80SXj>0P2?Shl209FEU@80WYjN0P2V
YZH20;Bd]080_;bl0P2k^k/20;Bd]080WinO7`38h=P001d0b>3H0P2IVIT205eMG@80GemO0P1iNGT2
05aLG080JFUY0P1eMGD207emO@80QhN70P2a/K420=3@d080clo?0P2KVi/203lo?`80;2`/0P0V9RH3
02l_;`80<C4a0P0d=3@203<c<`80<C4a0P0b<S8203@d=080=SHf0P0h>3P203/k>`80?Shn0P0k>c/2
03Lg=`@0=SHf0P0e=CD203@d=080<C4a0P0_;bl202h^;P80=SHf0P0_;bl206ATI080M7Ad0P21PH42
05UIF@80IFEU0P1HF5P205=CD`80FUYJ0P1UIFD206YZJP<0KVi^0P1bLW8207EeM@80N7Qh0P1jNWX2
07]kN`H0O7al101mOGd207]kN`80NGUi0P1nOWh408>3P`80PH610P22PX8208B4Q080QXJ60P28R8P2
08V9R@80RXZ:0P2;Rh/208b<S080Shn?102ATI42092@T0H0Shn?1`2ATI44092@T080U9BD0P2IVIT2
09ZJVPP0Vi^K0P2LW9`209fMW@80WinO0P2PX:020:6QX@80WYjN0P2LW9`209fMW@H0WYjN0P2LW9`2
09^KV`80W9bL0P2MWId209ZJVP80UYJF102EUID209BDU0D0Ti>C0P2BTY8208j>SP80Rh^;0P2:RXX2
08^;R`80S8b<0P2>SXh209>CT`80Vi^K0P2YZJT20;Bd]080[Zj^102UYJDY0<SPf080WYjN0P1KFe/2
06=SH`80L71`0P1OGel206YZJP80MgMg0P1mOGd208Z:RP80Zj^[0P3?cll20=CDe080XJ6Q0P0j>SX2
038b<P80;Rh^0`0];Bd203@d=080>3Ph0P0f=SH203De=@80<S8b0P0j>SX203Ti>@80?Shn0P10@402
03hn?P80>SXj0P0h>3P203<c<`80>CTi0P0d=3@203De=@80<C4a0P0_;bl4034a<@80>3Ph0P1PH602
07MgM`80PH610P1NGUh206MWI`80DE5A0P1DE5@205aLG080IFEU1@1]KFd2079bLP80MGEe0P1hN7P6
07UiN@80Ng]k0P1mOGd207alO080OGem0P1kNg/207QhN080OGem0P22PX8208J6QP@0PX:20P26QXH2
08F5Q@80QXJ60P2>SXh208Z:RP80S8b<0P2:RXX208f=S@80Ti>C0P2>SXh2092@T080SXj>0P2?Shl2
08j>SP<0TI6A0P2?Shl2096AT@80UIFE0P2>SXh209BDU080V9RH0P2JVYX209^KV`@0VYZJ0P2LW9`2
09ZJVP80WinO0P2NWYh209fMW@80WYjN0P2RXZ8209^KV`80WIfM0P2NWYh209fMW@80WYjN0P2LW9`4
09^KV`80X:2P102FUYH209RHV0L0UYJF0P2@T90209FEU@80Shn?0P2:RXX208f=S@80RXZ:0P2;Rh/2
08f=S@80TI6A0P2MWId20:BTY080/[:b0P2f][H20:FUY@80VYZJ:@38h=P209JFUP80GemO0P1NGUh2
07]kN`80HF5Q0P1TI6@207EeM@80PX:20P29RHT20:ZZZP80dm?C0P3>c/h209RHV080A4A40P0`<302
02DU9@D0<30`0P0a<C4203<c<`80<30`0P0/;2`203De=@80>3Ph0P0g=cL203Xj>P80?Shn0P0i>CT2
03/k>`80>CTi0P0h>3P2038b<P80=SHf0P0^;Rh2030`<080;Rh^0P0e=CD202h^;P80I6AT0P1eMGD2
07moO`80FUYJ0P1TI6@205IFEP80E5AD0P1IFET206EUI@80K6a/0`1^KVh2079bLP80MWIf0P1dM7@4
07UiN@80OGem0P1hN7P207alO080OWin0P1kNg/20820P080NGUi0P1kNg/208N7Q`80PH610P23Ph<2
08:2PP80QXJ60P25QHD208N7Q`80QXJ60P2<S8`208R8R080SHf=0P2?Shl209:BTP80T92@0P2ATI42
092@T0@0Shn?0`2ATI42092@T080TY:B0P2@T90209:BTP80Ti>C0P2JVYX209RHV080Vi^K0P2JVYX2
09^KV`H0W9bL0P2OWil20:BTY080Xj>S102MWId209jNWPH0WIfM0P2NWYh209ZJVP80VIVI0P2MWId2
09^KV`80UiNG0P2CTi<209JFUP80UIFE0`2CTi<208j>SP80TY:B0P2=SHd408^;R`80S8b<0P2:RXX2
08j>SP80U9BD0P2JVYX20:ZZZP80/k>c0P2a/K420:FUY@80Z:RX7`38h=P001d0b>3H0P2IVIT205eM
G@80GemO0P1iNGT205aLG080JFUY0P1eMGD207emO@80QhN70P2a/K420=3@d080clo?0P2KVi/203lo
?`80;2`/0P0V9RH302l_;`80<C4a0P0d=3@203<c<`80<C4a0P0b<S8203@d=080=SHf0P0h>3P203/k
>`80?Shn0P0k>c/203Lg=`@0=SHf0P0e=CD203@d=080<C4a0P0_;bl202h^;P80=SHf0P0_;bl206AT
I080M7Ad0P21PH4205UIF@80IFEU0P1HF5P205=CD`80FUYJ0P1UIFD206YZJP<0KVi^0P1bLW8207Ee
M@80N7Qh0P1jNWX207]kN`H0O7al101mOGd207]kN`80NGUi0P1nOWh408>3P`80PH610P22PX8208B4
Q080QXJ60P28R8P208V9R@80RXZ:0P2;Rh/208b<S080Shn?102ATI42092@T0H0Shn?1`2ATI44092@
T080U9BD0P2IVIT209ZJVPP0Vi^K0P2LW9`209fMW@80WinO0P2PX:020:6QX@80WYjN0P2LW9`209fM
W@H0WYjN0P2LW9`209^KV`80W9bL0P2MWId209ZJVP80UYJF102EUID209BDU0D0Ti>C0P2BTY8208j>
SP80Rh^;0P2:RXX208^;R`80S8b<0P2>SXh209>CT`80Vi^K0P2YZJT20;Bd]080[Zj^102UYJDY0<SP
f080WYjN0P1KFe/206=SH`80L71`0P1OGel206YZJP80MgMg0P1mOGd208Z:RP80Zj^[0P3?cll20=CD
e080XJ6Q0P0j>SX2038b<P80;Rh^0`0];Bd203@d=080>3Ph0P0f=SH203De=@80<S8b0P0j>SX203Ti
>@80?Shn0P10@40203hn?P80>SXj0P0h>3P203<c<`80>CTi0P0d=3@203De=@80<C4a0P0_;bl4034a
<@80>3Ph0P1PH60207MgM`80PH610P1NGUh206MWI`80DE5A0P1DE5@205aLG080IFEU1@1]KFd2079b
LP80MGEe0P1hN7P607UiN@80Ng]k0P1mOGd207alO080OGem0P1kNg/207QhN080OGem0P22PX8208J6
QP@0PX:20P26QXH208F5Q@80QXJ60P2>SXh208Z:RP80S8b<0P2:RXX208f=S@80Ti>C0P2>SXh2092@
T080SXj>0P2?Shl208j>SP<0TI6A0P2?Shl2096AT@80UIFE0P2>SXh209BDU080V9RH0P2JVYX209^K
V`@0VYZJ0P2LW9`209ZJVP80WinO0P2NWYh209fMW@80WYjN0P2RXZ8209^KV`80WIfM0P2NWYh209fM
W@80WYjN0P2LW9`409^KV`80X:2P102FUYH209RHV0L0UYJF0P2@T90209FEU@80Shn?0P2:RXX208f=
S@80RXZ:0P2;Rh/208f=S@80TI6A0P2MWId20:BTY080/[:b0P2f][H20:FUY@80VYZJ:@38h=P209JF
UP80GemO0P1NGUh207]kN`80HF5Q0P1TI6@207EeM@80PX:20P29RHT20:ZZZP80dm?C0P3>c/h209RH
V080A4A40P0`<30202DU9@D0<30`0P0a<C4203<c<`80<30`0P0/;2`203De=@80>3Ph0P0g=cL203Xj
>P80?Shn0P0i>CT203/k>`80>CTi0P0h>3P2038b<P80=SHf0P0^;Rh2030`<080;Rh^0P0e=CD202h^
;P80I6AT0P1eMGD207moO`80FUYJ0P1TI6@205IFEP80E5AD0P1IFET206EUI@80K6a/0`1^KVh2079b
LP80MWIf0P1dM7@407UiN@80OGem0P1hN7P207alO080OWin0P1kNg/20820P080NGUi0P1kNg/208N7
Q`80PH610P23Ph<208:2PP80QXJ60P25QHD208N7Q`80QXJ60P2<S8`208R8R080SHf=0P2?Shl209:B
TP80T92@0P2ATI42092@T0@0Shn?0`2ATI42092@T080TY:B0P2@T90209:BTP80Ti>C0P2JVYX209RH
V080Vi^K0P2JVYX209^KV`H0W9bL0P2OWil20:BTY080Xj>S102MWId209jNWPH0WIfM0P2NWYh209ZJ
VP80VIVI0P2MWId209^KV`80UiNG0P2CTi<209JFUP80UIFE0`2CTi<208j>SP80TY:B0P2=SHd408^;
R`80S8b<0P2:RXX208j>SP80U9BD0P2JVYX20:ZZZP80/k>c0P2a/K420:FUY@80Z:RX7`38h=P001d0
b>3H0P2YZJT208^;R`80IfMW0P1UIFD206YZJP80J6QX0P1WIfL206i^KP80MgMg0P2JVYX20;Zj^P80
f=SH0P35aLD208:2PP80>SXj0P0R8R8502/[:`80;Rh^0P0];Bd202/[:`80;Rh^0P0a<C4203<c<`80
=3@d0P0l?3`20451@@80>SXj0P0a<C42038b<P@0<c<c0P0a<C4202d];@80:RXZ0P0X:2P2030`<080
;Rh^0P1XJ6P207EeM@80P8200P1EEED206ATI080EUIF0P1ADE4205UIF@80IFEU0P1/K6`3071`L080
LW9b0P1dM7@207IfMP80N7Qh0P1iNGT207YjNP80Ng]k0P1lO7`207emO@80OWin101mOGd207moO`H0
PH610P23Ph<208F5Q@80QhN70P29RHT408R8R080RXZ:0P2<S8`208n?S`@0TI6A0P2@T90408n?S`80
T92@0`2ATI4209:BTP80Ti>C102DU9@209FEU@80UiNG0P2IVIT809^KV`@0W9bL0P2KVi/209fMW@@0
WinO1P2NWYh209fMW@P0W9bL0P2KVi/209RHV080UYJF102EUID209>CT`<0TY:B0P2ATI42092@T080
S8b<0P28R8P608N7Q`80R8R80P2=SHd209:BTP80WIfM0P2UYJD209jNWP80U9BD0P2EUIDY0<SPf080
];Bd0P2:RXX2061PH080I6AT0P1ZJVX205iNGP80IFEU0P1eMGD207emO@80SXj>0P30`<020=CDe080
bl_;0P1gMgL2030`<080:BTY0`0Z:RX202TY:@80;Rh^0P0[:b/202l_;`80:RXZ100b<S8203<c<`80
;Bd]0P16ATH20451@@@0=3@d0P0f=SH2034a<@80<c<c0P0b<S8202TY:@80:RXZ0P0];Bd2034a<@80
I6AT0P1gMgL207UiN@80EeMG0P1VIVH204i>CP80EeMG0P1KFe/2061PH080KVi^0`1]KFd407=cL`80
NWYj101iNGT207moO`80O7al0P1mOGd207alO080OWin0P1jNWX40861P@80Q8B40P1nOWh207emO@80
Ph>31021PH4208Z:RP80RHV90P25QHD208R8R080T92@0P2;Rh/2096AT@80UIFE0P2ATI42092@T080
Shn?0P2BTY85092@T080UIFE102DU9@209FEU@80UYJF0P2OWil209ZJVP80VIVI102LW9`209VIV@@0
Vi^K0P2NWYh20:2PX080WinO0P2KVi/209fMW@80XJ6Q0P2LW9`209jNWP80VYZJ0P2LW9`209jNWP80
VYZJ0P2HV9P209JFUP80Ti>C0P2FUYH2092@T0<0Shn?0P2ATI4208n?S`80RXZ:0P26QXH208N7Q`80
QHF50P28R8P208f=S@80Shn?0P2GUiL209RHV080YZJV0P2TY:@209JFUP80Ti>C:@38h=P20:NWY`80
SXj>0P1SHf<206EUI@80JVYZ0P1YJFT206YZJP80JFUY0P1eMGD209RHV080_;bl0P3Jf]X20<K6aP80
Ogmo0P0e=CD202HV9P<0;2`/0P0Z:RX602`/;080;Rh^0P0Z:RX2034a<@80<c<c0P0k>c/20410@080
>CTi0P0Z:RX202d];@80=SHf0P0e=CD2034a<@@0;2`/0P0[:b/2038b<P80;Bd]0P1[Jf/207EeM@80
PX:20P1HF5P2065QH@80EEEE0P1@D50205UIF@80IfMW0P1]KFd306m_K`80LW9b0P1cLg<207MgM`80
NWYj0P1lO7`207YjNP80N7Qh101nOWh207YjNP80OGem101nOWh40861P@@0Ph>30P27QhL208J6QP80
Rh^;0P29RHT208Z:RP80RHV90P2>SXh208f=S@80TI6A0P2@T90209:BTP80T92@0P2>SXh2096AT@<0
T92@0P2?Shl209>CT`80U9BD0P2CTi<209FEU@@0V9RH0P2MWId209bLW080VYZJ0P2KVi/209bLW080
VYZJ102MWId209jNWP80X:2P0P2MWId209bLW0@0X:2P0P2KVi/209bLW080WYjN0P2MWId209bLW080
VYZJ0P2FUYH209>CT`80UYJF1@2DU9@409:BTP80S8b<0P27QhL208R8R080QXJ61028R8P208b<S080
T92@0P2MWId20:BTY080X:2P0P2ATI4209BDU1l0b>3H000M0<SPf080ZJVY0P2;Rh/206MWI`80IFEU
0P1ZJVX206QXJ080IfMW0P1^KVh207MgM`80VYZJ0P2j^[X20=SHf080aLG50P22PX8203Xj>P808R8R
1@0[:b/202h^;P80;Bd]0P0[:b/202h^;P80<C4a0P0c<c<203@d=080?3`l0P11@D4203Xj>P80<C4a
0P0b<S8403<c<`80<C4a0P0];Bd202XZ:P80:2PX0P0`<30202h^;P80J6QX0P1eMGD20820P080EEEE
0P1TI6@205IFEP80DE5A0P1IFET206EUI@80K6a/0`1`L702079bLP80M7Ad0P1fMWH207QhN080NGUi
0P1jNWX207]kN`80O7al0P1mOGd207inOP@0OGem0P1oOgl60861P@80Ph>30P25QHD208N7Q`80RHV9
1028R8P208Z:RP80S8b<0P2?Shl4096AT@80T92@102?Shl2092@T0<0TI6A0P2BTY8209>CT`@0U9BD
0P2EUID209NGU`80VIVI202KVi/409bLW080Vi^K0P2MWId409nOW`H0WYjN0P2MWId809bLW080Vi^K
0P2HV9P209JFUP@0UIFE0P2CTi<309:BTP80TI6A0P2@T90208b<S080R8R81P27QhL208R8R080SHf=
0P2BTY8209fMW@80YJFU0P2NWYh209BDU080UIFE:@38h=P20;Bd]080RXZ:0P1PH60206ATI080JVYZ
0P1NGUh206EUI@80MGEe0P1mOGd208j>SP80`<300P3De=@20<_;b`80MgMg0P0`<30202TY:@<0:RXZ
0P0Y:BT202h^;P80:b/[0P0_;bl202XZ:P@0<S8b0P0c<c<202d];@80ATI60P11@D4403@d=080=SHf
0P0a<C4203<c<`80<S8b0P0Y:BT202XZ:P80;Bd]0P0a<C4206ATI080MgMg0P1iNGT205MGE`80IVIV
0P1>CTh205MGE`80Fe]K0P1PH60206i^KP<0KFe]101cLg<207YjNP@0NGUi0P1oOgl207alO080OGem
0P1lO7`207inOP80NWYj1021PH4208B4Q080OWin0P1mOGd208>3P`@0PH610P2:RXX208V9R@80QHF5
0P28R8P2092@T080Rh^;0P2ATI4209FEU@80TI6A0P2@T90208n?S`80TY:B1@2@T90209FEU@@0U9BD
0P2EUID209JFUP80WinO0P2JVYX209VIV@@0W9bL0P2IVIT409^KV`80WYjN0P2PX:0209nOW`80Vi^K
0P2MWId20:6QX@80W9bL0P2NWYh209ZJVP80W9bL0P2NWYh209ZJVP80V9RH0P2FUYH209>CT`80UYJF
0P2@T90308n?S`80TI6A0P2?Shl208Z:RP80QXJ60P27QhL208F5Q@80R8R80P2=SHd208n?S`80UiNG
0P2HV9P20:JVYP80Y:BT0P2FUYH209>CTbT0b>3H0P2WYjL208j>SP80Hf=S0P1UIFD206YZJP80JFUY
0P1ZJVX206UYJ@80MGEe0P2HV9P20;bl_080f][J0P36a/H207moO`80=CDe0P0V9RH302`/;080:RXZ
1P0/;2`202h^;P80:RXZ0P0a<C4203<c<`80>c/k0P10@40203Ti>@80:RXZ0P0];Bd203Hf=P80=CDe
0P0a<C4402`/;080:b/[0P0b<S8202d];@80Jf][0P1eMGD208:2PP80F5QH0P1QHF4205EEE@80D51@
0P1IFET206MWI`80KFe]0`1_Kfl2079bLP80Lg=c0P1gMgL207YjNP80O7al0P1jNWX207QhN0@0OWin
0P1jNWX207emO@@0OWin1021PH4408>3P`80QhN70P26QXH208^;R`80RHV90P2:RXX208V9R@80SXj>
0P2=SHd2096AT@80T92@0P2BTY82092@T080SXj>0P2ATI43092@T080Shn?0P2CTi<209BDU080Ti>C
0P2EUID409RHV080WIfM0P2LW9`209ZJVP80Vi^K0P2LW9`209ZJVP@0WIfM0P2NWYh20:2PX080WIfM
0P2LW9`40:2PX080Vi^K0P2LW9`209jNWP80WIfM0P2LW9`209ZJVP80UYJF0P2CTi<209JFUPD0U9BD
102BTY8208b<S080QhN70P28R8P208J6QP@0R8R80P2<S8`2092@T080WIfM0P2TY:@20:2PX080TI6A
0P2DU9@O0<SPf0007@38h=P20:VYZ@80/;2`0P1]KFd2051@D080MgMg0P1ZJVX2065QH@80I6AT0P1`
L70208J6QP80X:2P0P3<c<`20>3Ph080`L710P1CDe<202TY:@<09bLW0P0U9BD202XZ:P809bLW0P0V
9RH202XZ:P80;Rh^0P0a<C4203@d=080?Shn0P14A4@203Xj>P@0;Rh^100`<30202l_;`80:BTY0P0U
9BD2028R8P80:RXZ0P0];Bd206][J`80MGEe0P1lO7`205=CD`80I6AT0P1FEUH2051@D080FEUI0P1V
IVH206e]K@<0LW9b101cLg<207AdM080MgMg0P1hN7P207YjNP80Ng]k0P1lO7`207emO@80Ogmo0P21
PH4208:2PP80P8200P1oOgl20820P080PX:20P24Q8@208J6QP80R8R80P2:RXX208R8R080QXJ60P2:
RXX208j>SP80Shn?2P2@T902096AT@<0TY:B0P2CTi<209FEU@80UiNG0P2HV9P209NGU`80UIFE0P2I
VIT209bLW080Vi^K0P2JVYX209^KV`80WIfM0P2JVYX209RHV080VYZJ0P2NWYh209nOW`80X:2P0P2O
Wil209jNWP80W9bL0P2KVi/409bLW080VYZJ102GUiL209JFUP80UIFE0P2CTi<2096AT@<0T92@0P2>
SXh208b<S080R8R80P24Q8@608>3P`80QHF50P27QhL208^;R`80TI6A0P2EUID208f=S@80QHF50P23
Ph<Y0<SPf080[Jf]0P2/[:`2079bLP80I6AT0P1eMGD206IVIP80Hf=S0P1/K6`2079bLP80Ph>30P2R
XZ820=?Cd`80emOG0P30`<02059BDP809BDU0`0V9RH202XZ:P809bLW0P0T92@202HV9P80:BTY0P0]
;Bd2034a<@80>3Ph0P0m?Cd20451@@80=3@d0P0`<302034a<@80<30`0P0_;bl2034a<@809bLW0P0U
9BD202TY:@809RHV0P0^;Rh206MWI`80MWIf0P1iNGT205iNGP80I6AT0P1;Bd/205EEE@80Fe]K0P1W
IfL206YZJP<0Lg=c0P1dM7@207=cL`80MGEe0P1fMWH207AdM080Ng]k0P1iNGT207emO@80OWin0P1m
OGd20820P080PH610P22PX8207alO080Ogmo0P23Ph<208J6QP80RHV90P26QXH408V9R@80QhN70P29
RHT208j>SP80SHf=0P2CTi<208j>SP80Shn?0P2ATI4208f=S@80TI6A0`2BTY8209>CT`80U9BD0P2G
UiL209RHV080Ti>C0P2DU9@209^KV`@0VIVI102JVYX209jNWP80VYZJ0P2FUYH209VIV@@0WYjN0P2O
Wil20::RXP80W9bL0P2HV9P209bLW080VIVI0P2MWId209ZJVP80UiNG0P2LW9`209FEU@80TY:B0P2D
U9@208n?S`<0Ti>C0P2=SHd208b<S080QXJ60P23Ph<208^;R`80PX:20P23Ph<208F5Q@80QhN70P2=
SHd208n?S`80UYJF0P2?Shl208B4Q080QXJ6:@38h=P20:^[Z`80[Jf]0P1aLG42059BDP80N7Qh0P1W
IfL206ATI080Hf=S0P1]KFd208V9R@80W9bL0P3<c<`20=oOg`80b<S80P1DE5@202PX:0<09bLW0P0S
8b<202d];@80:BTY0P0T92@202d];@80<30`0P0f=SH203@d=080>CTi0P16ATH203dm?@80<C4a0P0_
;bl2030`<080:b/[0P0`<30402PX:0807AdM0P0[:b/202h^;P80JVYZ0P1dM7@207YjNP80F5QH0P1S
Hf<205=CD`80DE5A0P1IFET206UYJ@80Jf][0`1cLg<207QhN080Lg=c0P1bLW8207IfMP80N7Qh0P1j
NWX207QhN080OWin0P1jNWX20861P@H0PX:2101nOWh20861P@H0QHF50P2:RXX208R8R080QXJ60P29
RHT208n?S`80SXj>0P2ATI4209:BTP80Shn?0P2>SXh2092@T080TI6A0`2CTi<2096AT@80U9BD0P2K
Vi/209NGU`80UYJF0P2EUID409ZJVP80W9bL0P2IVIT209fMW@80W9bL0P2JVYX209NGU`80VIVI0P2M
WId209nOW`80XZ:R0P2MWId209jNWP80WinO102JVYX409^KV`80UIFE0P2GUiL209FEU@80UYJF102A
TI4308j>SP80SHf=102:RXX208:2PP@0Ph>30P26QXH208F5Q@80QhN70P2:RXX209>CT`80TY:B0P2=
SHd208F5Q@80QXJ67`38h=P001d0b>3H0P2YZJT20;2`/080KFe]0P1@D50207MgM`80JVYZ0P1QHF42
06ATI080L71`0P26QXH20:2PX080c<c<0P3Ph>020<71`@80De=C0P0Y:BT302LW9`809BDU0P0Z:RX2
02LW9`809RHV0P0Z:RX202h^;P80<C4a0P0d=3@203hn?P80A4A40P0j>SX402h^;P@0<30`0P0_;bl2
02TY:@809BDU0P0R8R8202XZ:P80;Bd]0P1[Jf/207EeM@80O7al0P1CDe<206ATI080EUIF0P1@D502
05UIF@80IVIV0P1]KFd3079bLP@0Lg=c0P1dM7@207MgM`80N7Qh0P1jNWX207]kN`80O7al0P1mOGd2
07moO`80PH610P22PX820820P080Ogmo0P20P80208:2PP80Q8B40P26QXH208R8R080RXZ:0P28R8P2
08J6QP80RXZ:0P2>SXh208n?S`X0T92@0P2ATI4309:BTP80Ti>C0P2EUID209NGU`80V9RH0P2GUiL2
09FEU@80VIVI0P2LW9`209^KV`80VYZJ0P2KVi/209fMW@80VYZJ0P2HV9P209ZJVP80WYjN0P2OWil2
0:2PX080WinO0P2NWYh209bLW080Vi^K102LW9`209ZJVP@0UiNG0P2FUYH209FEU@80Ti>C0P2ATI43
092@T080SXj>0P2<S8`208R8R080Q8B41P23Ph<208F5Q@80QhN70P2;Rh/2096AT@80UIFE0P2=SHd2
08F5Q@80Ph>3:@38h=P20:f][@80[:b/0P1bLW8206ATI080MGEe0P1VIVH206=SH`80K6a/0P1bLW82
08>3P`80XZ:R0P3Cdm<20=OGe`80`<300P1BDU8202DU9@<09RHV0P0Z:RX202LW9`8092@T0P0V9RH2
02TY:@80;Bd]0P0a<C4203Ph>080?Cdm0P11@D4203@d=080<30`0P0a<C42030`<080;bl_0P0a<C42
02LW9`809BDU0P0Y:BT202HV9P80;Rh^0P1WIfL207IfMP80NGUi0P1NGUh206ATI080Bd];0P1EEED2
05]KF`80IfMW0P1ZJVX307=cL`80M7Ad0P1cLg<207EeM@80MWIf0P1dM7@207]kN`80NGUi0P1mOGd2
07inOP80OGem0P20P8020861P@80PX:20P1lO7`207moO`80Ph>30P26QXH208V9R@80QXJ61029RHT2
08N7Q`80RHV90P2>SXh208f=S@80Ti>C0P2>SXh208n?S`80TI6A0P2=SHd2096AT@<0TY:B0P2CTi<2
09BDU080UiNG0P2HV9P209>CT`80U9BD0P2KVi/409VIV@@0VYZJ0P2NWYh209ZJVP80UYJF0P2IVIT4
09jNWP80WinO0P2RXZ8209bLW080V9RH0P2LW9`209VIV@80WIfM0P2JVYX209NGU`80W9bL0P2EUID2
09:BTP80U9BD0P2?Shl309>CT`80SHf=0P2<S8`208J6QP80Ph>30P2;Rh/208:2PP80Ph>30P25QHD2
08N7Q`80SHf=0P2?Shl209JFUP80Shn?0P24Q8@208J6QRT0b>3H0P2[Zj/20:f][@80LG5a0P1BDU82
07QhN080IfMW0P1TI6@206=SH`80KFe]0P29RHT209bLW080c<c<0P3Ogml20<S8b080E5AD0P0X:2P3
02LW9`808b<S0P0];Bd202TY:@8092@T0P0];Bd2030`<080=SHf0P0d=3@203Ti>@80ATI60P0m?Cd2
034a<@80;bl_0P0`<30202/[:`80<30`100X:2P201dM7@80:b/[0P0^;Rh206YZJP80M7Ad0P1jNWX2
05QHF080Hf=S0P1CDe<2055AD@80FEUI0P1YJFT206][J`<0Lg=c0P1hN7P207=cL`80LW9b0P1fMWH2
07QhN080NWYj0P1hN7P207inOP80NWYj0P21PH4608:2PP@0OWin0P21PH4608F5Q@80RXZ:0P28R8P2
08J6QP80RHV90P2?Shl208j>SP80TI6A0P2BTY8208n?S`80SXj>0P2@T902096AT@<0Ti>C0P2ATI42
09BDU080Vi^K0P2GUiL209JFUP80UIFE102JVYX209bLW080VIVI0P2MWId209bLW080VYZJ0P2GUiL2
09VIV@80WIfM0P2OWil20::RXP80WIfM0P2NWYh209nOW`@0VYZJ102KVi/209FEU@80UiNG0P2EUID2
09JFUP@0TI6A0`2>SXh208f=S@@0RXZ:0P22PX8408>3P`80QXJ60P25QHD208N7Q`80RXZ:0P2CTi<2
09:BTP80SHf=0P25QHD208J6QQl0b>3H000M0<SPf080QhN70P2TY:@209NGU`80L71`0P1]KFd206][
J`80L71`0P1aLG4207EeM@80OGem0P2<S8`20;2`/080bl_;0P3:b/X209JFUP806QXJ0`0c<c<2024Q
8@809RHV0P0S8b<202@T90809bLW0P0];Bd203Ph>080@T920P18B4P204U9B@80@4100P0e=CD202l_
;`@0:b/[0P0/;2`202/[:`80:RXZ0P0Y:BT2034a<@80;Bd]0P1UIFD2079bLP80Ng]k0P1QHF4205mO
G`80E5AD0P1@D50205UIF@80IVIV0P1[Jf/306m_K`80LW9b0P1cLg<207AdM080MGEe0P1hN7P207]k
N`80OGem0P1nOWh407emO@80Ogmo0P21PH4208:2PPH0PH610P24Q8@208J6QP80R8R80P29RHT208R8
R080QhN70P2<S8`4096AT@80T92@102ATI4;09:BTP80Ti>C0P2EUID609JFUP80V9RH0P2KVi/209VI
V@80UiNG0P2JVYX209bLW080Vi^K0P2JVYX209fMW@@0WinO0P2MWId409jNWP80WIfM0P2KVi/209ZJ
VP80VIVI0P2GUiL409JFUP80UIFE0P2BTY8208j>SP80S8b<0`2;Rh/208R8R080QHF50P21PH4207in
OP80P8200P22PX8208>3P`80Q8B40P25QHD208N7Q`80RHV90P2:RXX208>3P`80O7al0P1jNWXY0<SP
f080QhN70P2GUiL209BDU080HF5Q0P1ZJVX207AdM080Jf][0P1/K6`206m_K`80Lg=c0P24Q8@20;^k
^`@0clo?0P2MWId202d];@<0:BTY0P0U9BD202`/;0808b<S0P0Y:BT202XZ:P80<S8b0P0j>SX204=3
@`80CTi>0P1JFUX203@d=080=CDe0P0a<C4202XZ:P809bLW0P0`<30202<S8`80:RXZ0P0[:b/202l_
;`80=CDe0P1SHf<207emO@80MGEe101SHf<204m?C`80DU9B0P1IFET206UYJ@80L71`0`1aLG4206m_
K`80LG5a0P1eMGD407QhN080NWYj0P1mOGd207YjNP80Ogmo1021PH4207moO`80PX:20P24Q8@207mo
O`80PX:20P26QXH208F5Q@80QhN70P2;Rh/208b<S080QXJ60P2<S8`209:BTP80TI6A0P2=SHd2096A
T@80SXj>0P2DU9@409>CT`<0T92@0P2DU9@209>CT`80UIFE0P2JVYX209BDU080UYJF0P2NWYh209fM
W@80V9RH0P2JVYX209NGU`80WIfM0P2PX:0209fMW@80W9bL0P2OWil209jNWP@0WinO0P2NWYh209nO
W`80W9bL0P2MWId209RHV080UiNG0P2ATI4209FEU@80U9BD0P2EUID208n?S`80SHf=0`29RHT208j>
SP80R8R80P1oOgl207emO@80P8200P1oOgl20820P080PX:20P20P80208F5Q@80QhN70P28R8P20861
P@80MWIf0P1iNGTY0<SPf080QhN70P2SXj<209NGU`80Jf][0P1^KVh206YZJP80KFe]0P1eMGD207]k
N`80P8200P2=SHd20:n_[`80alO70P36a/H209JFUP805aLG0`0h>3P201PH60809RHV0P0T92@2028R
8P809BDU0P0Z:RX203Hf=P80ATI60P12@T8204];B`80@D510P0e=CD202l_;`80:b/[0P0^;Rh202l_
;`@0:BTY0P0Z:RX4030`<080IFEU0P1_Kfl207YjNP80H61P0P1QHF4405EEE@80EeMG101VIVH3071`
L080Kfm_0P1aLG4407AdM080NWYj101mOGd607inOP@0Ogmo1022PX840861P@80Ph>30P26QXH408V9
R@80QXJ60P27QhL208b<S080TI6A0P2@T90208j>SPH0TI6A102CTi<309:BTP80Ti>C0P2BTY8609JF
UP80U9BD0P2IVIT209^KV`80VIVI0P2FUYH209ZJVP80WYjN0P2KVi/209bLW080XJ6Q0P2RXZ820:2P
X080WIfM102LW9`209fMW@80Vi^K102JVYX209BDU080V9RH102FUYH4092@T080SHf=0`2<S8`208R8
R0@0Q8B40P1nOWh40820P080PH610P23Ph<208B4Q080RXZ:0P28R8P208f=S@80QHF50P1kNg/207al
O1l0b>3H000M0<SPf080QhN70P2TY:@209NGU`80L71`0P1]KFd206][J`80L71`0P1aLG4207EeM@80
OGem0P2<S8`20;2`/080bl_;0P3:b/X209JFUP806QXJ0`0c<c<2024Q8@809RHV0P0S8b<202@T9080
9bLW0P0];Bd203Ph>080@T920P18B4P204U9B@80@4100P0e=CD202l_;`@0:b/[0P0/;2`202/[:`80
:RXZ0P0Y:BT2034a<@80;Bd]0P1UIFD2079bLP80Ng]k0P1QHF4205mOG`80E5AD0P1@D50205UIF@80
IVIV0P1[Jf/306m_K`80LW9b0P1cLg<207AdM080MGEe0P1hN7P207]kN`80OGem0P1nOWh407emO@80
Ogmo0P21PH4208:2PPH0PH610P24Q8@208J6QP80R8R80P29RHT208R8R080QhN70P2<S8`4096AT@80
T92@102ATI4;09:BTP80Ti>C0P2EUID609JFUP80V9RH0P2KVi/209VIV@80UiNG0P2JVYX209bLW080
Vi^K0P2JVYX209fMW@@0WinO0P2MWId409jNWP80WIfM0P2KVi/209ZJVP80VIVI0P2GUiL409JFUP80
UIFE0P2BTY8208j>SP80S8b<0`2;Rh/208R8R080QHF50P21PH4207inOP80P8200P22PX8208>3P`80
Q8B40P25QHD208N7Q`80RHV90P2:RXX208>3P`80O7al0P1jNWXY0<SPf080QhN70P2GUiL209BDU080
HF5Q0P1ZJVX207AdM080Jf][0P1/K6`206m_K`80Lg=c0P24Q8@20;^k^`@0clo?0P2MWId202d];@<0
:BTY0P0U9BD202`/;0808b<S0P0Y:BT202XZ:P80<S8b0P0j>SX204=3@`80CTi>0P1JFUX203@d=080
=CDe0P0a<C4202XZ:P809bLW0P0`<30202<S8`80:RXZ0P0[:b/202l_;`80=CDe0P1SHf<207emO@80
MGEe101SHf<204m?C`80DU9B0P1IFET206UYJ@80L71`0`1aLG4206m_K`80LG5a0P1eMGD407QhN080
NWYj0P1mOGd207YjNP80Ogmo1021PH4207moO`80PX:20P24Q8@207moO`80PX:20P26QXH208F5Q@80
QhN70P2;Rh/208b<S080QXJ60P2<S8`209:BTP80TI6A0P2=SHd2096AT@80SXj>0P2DU9@409>CT`<0
T92@0P2DU9@209>CT`80UIFE0P2JVYX209BDU080UYJF0P2NWYh209fMW@80V9RH0P2JVYX209NGU`80
WIfM0P2PX:0209fMW@80W9bL0P2OWil209jNWP@0WinO0P2NWYh209nOW`80W9bL0P2MWId209RHV080
UiNG0P2ATI4209FEU@80U9BD0P2EUID208n?S`80SHf=0`29RHT208j>SP80R8R80P1oOgl207emO@80
P8200P1oOgl20820P080PX:20P20P80208F5Q@80QhN70P28R8P20861P@80MWIf0P1iNGTY0<SPf080
QhN70P2SXj<209NGU`80Jf][0P1^KVh206YZJP80KFe]0P1eMGD207]kN`80P8200P2=SHd20:n_[`80
alO70P36a/H209JFUP805aLG0`0h>3P201PH60809RHV0P0T92@2028R8P809BDU0P0Z:RX203Hf=P80
ATI60P12@T8204];B`80@D510P0e=CD202l_;`80:b/[0P0^;Rh202l_;`@0:BTY0P0Z:RX4030`<080
IFEU0P1_Kfl207YjNP80H61P0P1QHF4405EEE@80EeMG101VIVH3071`L080Kfm_0P1aLG4407AdM080
NWYj101mOGd607inOP@0Ogmo1022PX840861P@80Ph>30P26QXH408V9R@80QXJ60P27QhL208b<S080
TI6A0P2@T90208j>SPH0TI6A102CTi<309:BTP80Ti>C0P2BTY8609JFUP80U9BD0P2IVIT209^KV`80
VIVI0P2FUYH209ZJVP80WYjN0P2KVi/209bLW080XJ6Q0P2RXZ820:2PX080WIfM102LW9`209fMW@80
Vi^K102JVYX209BDU080V9RH102FUYH4092@T080SHf=0`2<S8`208R8R0@0Q8B40P1nOWh40820P080
PH610P23Ph<208B4Q080RXZ:0P28R8P208f=S@80QHF50P1kNg/207alO1l0b>3H000M0<SPf080I6AT
0P1/K6`207QhN080L71`0P1VIVH207=cL`80PX:20P23Ph<20820P080Ogmo0P22PX8209VIV@80/;2`
0P2l_;`20;Vi^@80F5QH0`0a<C42024Q8@809bLW0P0S8b<202@T90809BDU0P0[:b/203dm?@80CDe=
0P1>CTh204U9B@80@d=30P0k>c/2034a<@@0:2PX0P0[:b/202d];@80<C4a0P0`<30203Lg=`80;Bd]
0P1OGel206m_K`80NGUi0P1]KFd205YJFP80DU9B0P1@D50205YJFP80IFEU0P1YJFT306a/K080L71`
101dM7@207EeM@80NGUi0P1mOGd407moO`80OGem0P1lO7`207emO@80P8200P22PX8208B4Q080Ph>3
0P21PH4208B4Q080QhN70P28R8P208V9R@@0R8R80P2>SXh209>CT`80TY:B0P2@T902096AT@80Ti>C
0P2DU9@209FEU@80Ti>C0`2BTY84092@T080TY:B0P2EUID209JFUP80UiNG0P2IVIT209ZJVP80V9RH
0P2FUYH209VIV@80W9bL0P2MWId209jNWP80X:2P0P2QXJ4209jNWP80Vi^K0P2MWId409jNWP80W9bL
0P2HV9P609FEU@80U9BD0P2BTY8208f=S@80R8R80P26QXH308F5Q@80PX:20P1nOWh207]kN`80NWYj
0P1mOGd20861P@80Ph>32024Q8@208>3P`80O7al0P1fMWH207AdM2T0b>3H0P1PH60206m_K`80OWin
101]KFd207YjNP80Ogmo1024Q8@207YjNP80QhN70P2KVi/20;Fe]@80];Bd0P2g]kL206=SH`<0<C4a
0P0W9bL402<S8`8092@T0P0V9RH202XZ:P80>c/k0P1BDU8404];B`80ATI60P15ADD402`/;0@0;Bd]
0P0W9bL203<c<`80>c/k0P0d=3@202`/;080EeMG0P1aLG4207UiN@80J6QX0P1MGEd205=CD`80DE5A
0P1LG5`2065QH@80JFUY0`1[Jf/2071`L080MgMg0P1fMWH207AdM080MWIf101nOWh207moO`80OWin
0P1kNg/207inOP80Ogmo0P28R8P20861P@80QHF50P20P80408J6QP80QhN70P26QXH208b<S080QhN7
0P2=SHd209BDU080TY:B0P2?Shl4096AT@80V9RH0P2BTY8209BDU0<0T92@0P2DU9@2096AT@80UIFE
0P2DU9@209>CT`80V9RH0P2LW9`209ZJVP80Ti>C0P2GUiL209RHV080WIfM0P2LW9`209fMW@80WYjN
0P2OWil20:>SX`80V9RH0P2KVi/409jNWP80VYZJ0P2GUiL209BDU080UYJF0P2HV9P409>CT`80SHf=
1`26QXH208:2PP80OGem101jNWX20820P0@0PX:20P27QhL208B4Q0@0QXJ60P22PX8207alO080M7Ad
0P1gMgLY0<SPf080IVIV0P1^KVh207UiN@80KVi^0P1TI6@207MgM`80Ph>30P1kNg/208>3P`80OGem
0P21PH4209^KV`80/[:b0P2j^[X20;^k^`80EEEE0`0b<S8202@T90809BDU0P0V9RH402@T9080;Rh^
0P0o?cl204];B`80DU9B0P1<C4`203dm?@80>c/k0P0g=cL202PX:0809bLW100Z:RX202h^;P80=CDe
0P0c<c<202/[:`80HF5Q0P1]KFd207]kN`80K6a/0P1JFUX2055AD@80Cdm?0P1HF5P206YZJP80J6QX
1@1_Kfl207AdM080MWIf0P1dM7@207MgM`80NWYj0P21PH4207emO@80Ogmo0P1kNg/207emO@80PH61
0P22PX8408B4Q080PH610P24Q8@208N7Q`@0RHV90P28R8P208N7Q`80Shn?102CTi<208n?S`80Ti>C
0P2DU9@2096AT@@0UIFE0`2ATI4209>CT`80TI6A0P2?Shl209JFUP80V9RH0P2EUID409VIV@80V9RH
0P2FUYH209RHV080WIfM0P2NWYh209bLW080X:2P0P2OWil209fMW@80W9bL0P2PX:0209bLW080X:2P
0P2LW9`209RHV080UYJF0P2DU9@209JFUP80U9BD0P2EUID208^;R`80RHV90P28R8P308B4Q080Ogmo
0P1nOWh207emO@80NGUi0P1oOgl20861P@@0Q8B40P26QXH208B4Q0@0Ph>30P1jNWX207MgM`80M7Ad
7`38h=P001d0b>3H0P1TI6@206a/K080N7Qh0P1`L70206IVIP80Lg=c0P22PX8208>3P`80P8200P1o
Ogl208:2PP80VIVI0P2`/;020;bl_080^KVi0P1HF5P3034a<@808B4Q0P0W9bL202<S8`8092@T0P0U
9BD202/[:`80?Cdm0P1=CDd204i>CP80BDU90P13@d<203/k>`80<C4a100X:2P202/[:`80;Bd]0P0a
<C42030`<080=cLg0P0];Bd205mOG`80Kfm_0P1iNGT206e]K@80FUYJ0P1BDU82051@D080FUYJ0P1U
IFD206UYJ@<0K6a/0P1`L70407AdM080MGEe0P1iNGT207emO@@0Ogmo0P1mOGd207alO080OGem0P20
P80208:2PP80Q8B40P23Ph<20861P@80Q8B40P27QhL208R8R080RHV91028R8P208j>SP80Ti>C0P2B
TY82092@T080TI6A0P2CTi<209BDU080UIFE0P2CTi<309:BTP@0T92@0P2BTY8209FEU@80UYJF0P2G
UiL209VIV@80VYZJ0P2HV9P209JFUP80VIVI0P2LW9`209fMW@80WYjN0P2PX:020:6QX@80WYjN0P2K
Vi/209fMW@@0WYjN0P2LW9`209RHV0H0UIFE0P2DU9@209:BTP80SHf=0P28R8P208J6QP<0QHF50P22
PX8207inOP80Ng]k0P1jNWX207emO@80PH610P23Ph<808B4Q080Ph>30P1lO7`207IfMP80M7Ad:@38
h=P2061PH080Kfm_0P1nOWh406e]K@80NWYj0P1oOgl408B4Q080NWYj0P27QhL209^KV`80]KFe0P2d
];@20;Ng]`80Hf=S0`0a<C4202LW9`@08b<S0P0T92@202HV9P80:RXZ0P0k>c/2059BDP@0Bd];0P16
ATH204E5A@@0;2`/100];Bd202LW9`80<c<c0P0k>c/203@d=080;2`/0P1GEeL2075aL@80NGUi0P1X
J6P205eMG@80De=C0P1ADE4205aLG080HF5Q0P1YJFT306][J`80L71`0P1gMgL207IfMP80M7Ad0P1f
MWH407inOP80Ogmo0P1nOWh207]kN`80OWin0P1oOgl208R8R080PH610P25QHD20820P0@0QXJ60P27
QhL208J6QP80S8b<0P27QhL208f=S@80U9BD0P2BTY8208n?S`@0TI6A0P2HV9P209:BTP80U9BD0`2@
T90209BDU080TI6A0P2EUID209BDU080Ti>C0P2HV9P209bLW080VYZJ0P2CTi<209NGU`80V9RH0P2M
WId209bLW080WIfM0P2NWYh209nOW`80Xj>S0P2HV9P209^KV`@0WYjN0P2JVYX209NGU`80U9BD0P2F
UYH209RHV0@0Ti>C0P2=SHd708J6QP80PX:20P1mOGd407YjNP80P8201022PX8208N7Q`80Q8B41026
QXH208:2PP80O7al0P1dM7@207MgMbT0b>3H0P1VIVH206i^KP80NGUi0P1^KVh206ATI080MgMg0P23
Ph<207]kN`80Ph>30P1mOGd20861P@80Vi^K0P2b/[820;Zj^P80^k^k0P1EEED3038b<P8092@T0P0U
9BD202HV9P@092@T0P0^;Rh203lo?`80Bd];0P1BDU8204a<C080?Cdm0P0k>c/203Lg=`80:2PX0P0W
9bL402XZ:P80;Rh^0P0e=CD203<c<`80:b/[0P1QHF4206e]K@80Ng]k0P1/K6`205YJFP80DE5A0P1?
Cdl205QHF080JVYZ0P1XJ6P506m_K`80M7Ad0P1fMWH207AdM080MgMg0P1jNWX20861P@80OGem0P1o
Ogl207]kN`80OGem0P21PH4208:2PP@0Q8B40P21PH4208B4Q080QhN71029RHT208R8R080QhN70P2?
Shl409>CT`80Shn?0P2CTi<209BDU080TI6A102EUID3096AT@80Ti>C0P2ATI4208n?S`80UYJF0P2H
V9P209FEU@@0VIVI0P2HV9P209JFUP80V9RH0P2MWId209jNWP80W9bL0P2PX:0209nOW`80WIfM0P2L
W9`20:2PX080W9bL0P2PX:0209bLW080V9RH0P2FUYH209BDU080UYJF0P2DU9@209FEU@80Rh^;0P29
RHT208R8R0<0Q8B40P1oOgl207inOP80OGem0P1iNGT207moO`80PH611024Q8@208J6QP80Q8B41023
Ph<207YjNP80MgMg0P1dM7@O0<SPf0007@38h=P204Q8B080D51@0P1SHf<2079bLP80MgMg0P21PH42
08Z:RP80SXj>0P2ATI4209>CT`80UiNG0P2SXj<20:n_[`80]kNg0P2d];@20:NWY`<0H61P0P1<C4`2
02<S8`808R8R0P0V9RH202DU9@809bLW0P0c<c<203hn?P80?Cdm0P0i>CT203Lg=`80=CDe0P0_;bl4
02XZ:P80;2`/0P0];Bd2030`<080;Bd]0P0c<c<202d];@80HV9R0P1^KVh207AdM080J6QX0P1DE5@2
04m?C`80DE5A0P1KFe/206MWI`80JVYZ0`1/K6`2071`L0H0M7Ad0P1hN7P:07emO@80Ogmo0P20P802
08:2PPH0Q8B40P26QXH208R8R0@0RHV90P2;Rh/208f=S@80T92@0P2BTY82096AT@80T92@0P2ATI42
09:BTP80U9BD0P2FUYH209FEU@<0U9BD0P2BTY82096AT@80U9BD0P2GUiL209RHV0X0VIVI0P2JVYX2
09bLW080WIfM0P2OWil40:2PX080WYjN0P2LW9`209fMW@80WinO0P2MWId209ZJVP80UYJF0P2CTi<2
09BDU080UIFE0P2CTi<2092@T080R8R80P21PH4207inOPT0OGem0P1nOWh20861P@80Q8B41025QHD4
08J6QP80QHF50P22PX8207]kN`80M7Ad0P1bLW8Y0<SPf080C4a<0P1NGUh206ATI0@0L71`0P1kNg/2
08^;R`80U9BD0P2FUYH209BDU080VIVI0P2OWil20:RXZ080Y:BT0P2^[Zh209jNWP<0GemO0P0g=cL2
02LW9`809RHV0P0P820202<S8`80:2PX0P0^;Rh203Ph>080?3`l0P0/;2`2034a<@80;bl_0P0[:b/2
02XZ:P80:b/[0P0a<C4202HV9P@0;bl_0P0Z:RX2034a<@80Hf=S0P1dM7@207=cL`80J6QX0P1BDU82
04Y:BP80D51@0P1NGUh206IVIP80K6a/0`1XJ6P207AdM080Kfm_0P1aLG4207EeM@80MgMg0P20P802
07inOP80PH61101kNg/207alO080P8200P1oOgl408:2PP80PH611028R8P208Z:RP80RHV90P2:RXX2
08^;R`80T92@0P2>SXh209FEU@80Ti>C0P2BTY8209BDU080Ti>C102EUID309>CT`80TI6A0P27QhL4
09JFUP80Ti>C0P2FUYH209ZJVP80UiNG0P2FUYH209bLW080V9RH0P2KVi/209jNWP80W9bL0P2QXJ42
09nOW`80WYjN0P2JVYX20:2PX080WYjN0P2JVYX209bLW080UIFE102DU9@209FEU@80TY:B0P2@T902
08V9R@80PX:20P1nOWh307]kN`80NWYj0P1nOWh207alO080P8200P22PX8208B4Q080QhN70P24Q8@4
08J6QP80QHF50P24Q8@207inOP@0MgMg:@38h=P204M7A`80CTi>0P1XJ6P206e]K@80Ng]k0P25QHD2
08b<S080Rh^;0P2>SXh208n?S`80UiNG0P2UYJD20;6a/@80^;Rh0P2e]KD20:b/[0<0GUiN0P1:BTX2
02PX:0808B4Q0P0V9RH202LW9`809RHV0P0`<30403hn?P80=SHf0P0b<S8203De=@80<30`0P0T92@2
02PX:080;Rh^0P0_;bl2030`<080<C4a0P0d=3@202`/;080Hf=S0P1YJFT207MgM`80J6QX0P1DE5@2
04i>CP80De=C0P1HF5P206IVIP80JFUY0`1[Jf/2071`L080N7Qh0P1bLW8207EeM@80N7Qh0P1lO7`2
08:2PP80NGUi0P1oOgl207alO080PH610P1oOgl208J6QP80PH610P22PX8208>3P`@0R8R80P27QhL2
08Z:RP80Rh^;0P2?Shl4092@T080TI6A0P2@T90209>CT`80Shn?0P2DU9@209NGU`80UIFE0`2ATI42
09FEU@80TI6A0P2>SXh209VIV@80UiNG0P2LW9`209ZJVP80V9RH0P2KVi/209RHV080VYZJ102KVi/6
09nOW`80WYjN0P2IVIT209bLW080WinO0P2QXJ4209RHV080Ti>C0P2ATI4209NGU`80Ti>C0P2BTY82
08j>SP80QhN70P1nOWh208:2PP<0O7al0P1mOGd207alO080P8200P1lO7`20861P@80QHF50P23Ph<2
08N7Q`80Q8B40P27QhL208F5Q@80PX:20P1kNg/207=cL`80L71`7`38h=P001d0b>3H0P18B4P2051@
D080Hf=S0P1bLW8207MgM`80PH610P2:RXX208j>SP80TI6A0P2CTi<209NGU`80Xj>S0P2_[jl20;Ng
]`80];Bd0P2WYjL3061PH080C4a<0P0S8b<2028R8P809RHV0P0U9BD202LW9`80<c<c0P0n?Sh203dm
?@80>CTi0P0g=cL203De=@80;bl_100Z:RX202`/;080;Bd]0P0`<30202d];@80<c<c0P0];Bd2069R
HP80KVi^0P1dM7@206QXJ080E5AD0P1?Cdl2055AD@80Fe]K0P1WIfL206YZJP<0K6a/0P1`L70607Ad
M080N7Qh2P1mOGd207moO`80P8200P22PX8608B4Q080QXJ60P28R8P408V9R@80Rh^;0P2=SHd2092@
T080TY:B0P2ATI42092@T080TI6A0P2BTY8209BDU080UYJF0P2EUID309BDU080TY:B0P2ATI4209BD
U080UiNG0P2HV9P:09VIV@80VYZJ0P2LW9`209fMW@80WinO102PX:0209jNWP80W9bL0P2MWId209nO
W`80WIfM0P2JVYX209JFUP80Ti>C0P2DU9@209FEU@80Ti>C0P2@T90208R8R080PH610P1nOWh907em
O@80OWin0P21PH4208B4Q0@0QHF51026QXH208F5Q@80PX:20P1kNg/207AdM080LW9b:@38h=P204a<
C080GUiN0P1TI6@4071`L080Ng]k0P2;Rh/209BDU080UYJF0P2DU9@209VIV@80WinO0P2XZ:P20:BT
Y080[Zj^0P2NWYh305mOG`80=cLg0P0W9bL202HV9P80820P0P0S8b<202PX:080;Rh^0P0h>3P203`l
?080;2`/0P0a<C4202l_;`80:b/[0P0Z:RX202/[:`80<C4a0P0V9RH402l_;`80:RXZ0P0a<C4206=S
H`80M7Ad0P1cLg<206QXJ080DU9B0P1:BTX2051@D080GUiN0P1VIVH206a/K0<0J6QX0P1dM7@206m_
K`80LG5a0P1eMGD207MgM`80P8200P1nOWh20861P@@0Ng]k0P1lO7`20820P080Ogmo1022PX820861
P@@0R8R80P2:RXX208V9R@80RXZ:0P2;Rh/2092@T080SXj>0P2EUID209>CT`80TY:B0P2DU9@209>C
T`@0UIFE0`2CTi<2096AT@80QhN7102FUYH209>CT`80UYJF0P2JVYX209NGU`80UYJF0P2LW9`209RH
V080Vi^K0P2NWYh209bLW080XJ6Q0P2OWil209jNWP80VYZJ0P2PX:0209jNWP80VYZJ0P2LW9`209FE
U@@0U9BD0P2EUID209:BTP80T92@0P29RHT208:2PP80OWin0`1kNg/207YjNP80OWin0P1lO7`20820
P080PX:20P24Q8@208N7Q`80Q8B41026QXH208F5Q@80Q8B40P1nOWh407MgMbT0b>3H0P17AdL204i>
CP80J6QX0P1]KFd207]kN`80QHF50P2<S8`208^;R`80SXj>0P2?Shl209NGU`80YJFU0P2a/K420;Rh
^080]KFe0P2/[:`305iNGP80BTY:0P0X:2P2024Q8@809RHV0P0W9bL202HV9P80<30`100n?Sh203Hf
=P80<S8b0P0e=CD2030`<08092@T0P0X:2P202h^;P80;bl_0P0`<302034a<@80=3@d0P0/;2`206=S
H`80JFUY0P1gMgL206QXJ080E5AD0P1>CTh205=CD`80F5QH0P1VIVH206UYJ@<0Jf][0P1`L70207Qh
N080LW9b0P1eMGD207QhN080O7al0P22PX8207UiN@80Ogmo0P1lO7`20861P@80Ogmo0P26QXH20861
P@80PX:20P23Ph<408R8R080QhN70P2:RXX208^;R`80Shn?102@T902096AT@80T92@0P2CTi<208n?
S`80U9BD0P2GUiL209FEU@<0TI6A0P2EUID2096AT@80SXj>0P2IVIT209NGU`80W9bL0P2JVYX209RH
V080Vi^K0P2HV9P209ZJVP@0Vi^K1P2OWil209jNWP80VIVI0P2LW9`209nOW`80XJ6Q0P2HV9P209>C
T`80TI6A0P2GUiL209>CT`80TY:B0P2>SXh208N7Q`80OWin0P22PX8307alO080OGem0P1lO7`20820
P080O7al0P21PH4208F5Q@80Ph>30P27QhL208B4Q080QhN70P25QHD208:2PP80Ng]k0P1cLg<2071`
L1l0b>3H000M0<SPf080B4Q80P1@D50206=SH`80LW9b0P1gMgL20861P@80RXZ:0P2>SXh2096AT@80
Ti>C0P2GUiL20:>SX`80[jn_0P2g]kL20;Bd]080YjNW0`1PH60204a<C0808b<S0P0R8R8202HV9P80
9BDU0P0W9bL203<c<`80?Shn0P0m?Cd203Ti>@80=cLg0P0e=CD202l_;`@0:RXZ0P0/;2`202d];@80
<30`0P0];Bd203<c<`80;Bd]0P1RHV8206i^KP80M7Ad0P1XJ6P205ADE080Cdm?0P1ADE4205]KF`80
IfMW0P1ZJVX306a/K080L71`1P1dM7@207QhN0X0OGem0P1oOgl20820P080PX:21P24Q8@208J6QP80
R8R81029RHT208^;R`80SHf=0P2@T90209:BTP80TI6A0P2@T902096AT@80TY:B0P2DU9@209JFUP80
UIFE0`2DU9@209:BTP80TI6A0P2DU9@209NGU`80V9RH2P2IVIT209ZJVP80W9bL0P2MWId209nOW`@0
X:2P0P2NWYh209bLW080WIfM0P2OWil209fMW@80VYZJ0P2FUYH209>CT`80U9BD0P2EUID209>CT`80
T92@0P28R8P20861P@80OWin2@1mOGd207inOP80PH610P24Q8@408F5Q@@0QXJ60P25QHD208:2PP80
Ng]k0P1dM7@2079bLRT0b>3H0P1<C4`205iNGP80I6AT101`L70207]kN`80Rh^;0P2DU9@209JFUP80
U9BD0P2IVIT209nOW`80Z:RX0P2TY:@20:j^[P80WYjN0`1OGel203Lg=`809bLW0P0V9RH2020P8080
8b<S0P0X:2P202h^;P80>3Ph0P0l?3`202`/;080<C4a0P0_;bl202/[:`80:RXZ0P0[:b/2034a<@80
9RHV100_;bl202XZ:P80<C4a0P1SHf<207AdM080Lg=c0P1XJ6P2059BDP80BTY:0P1@D50205iNGP80
IVIV0P1/K6`306QXJ080M7Ad0P1_Kfl2075aL@80MGEe0P1gMgL20820P080OWin0P21PH4407]kN`80
O7al0P20P80207moO`@0PX:20P21PH4408R8R080RXZ:0P29RHT208Z:RP80Rh^;0P2@T90208j>SP80
UIFE0P2CTi<209:BTP80U9BD0P2CTi<409FEU@<0Ti>C0P2ATI4208N7Q`@0UYJF0P2CTi<209JFUP80
VYZJ0P2GUiL209JFUP80W9bL0P2HV9P209^KV`80WYjN0P2LW9`20:6QX@80WinO0P2NWYh209ZJVP80
X:2P0P2NWYh209ZJVP80W9bL0P2EUID409BDU080UIFE0P2BTY82092@T080RHV90P22PX8207inOP<0
Ng]k0P1jNWX207inOP80O7al0P20P80208:2PP80Q8B40P27QhL208B4Q0@0QXJ60P25QHD208B4Q080
OWin101gMgLY0<SPf080AdM70P1>CTh206QXJ080KFe]0P1kNg/208F5Q@80S8b<0P2;Rh/208j>SP80
Shn?0P2GUiL20:FUY@80/K6a0P2h^;P20;Fe]@80[:b/0`1NGUh204Y:BP80:2PX0P0Q8B4202HV9P80
9bLW0P0V9RH2030`<0@0?Shn0P0f=SH2038b<P80=CDe0P0`<30202@T9080:2PX0P0^;Rh202l_;`80
<30`0P0a<C4203@d=080;2`/0P1SHf<206UYJ@80MgMg0P1XJ6P205ADE080CTi>0P1CDe<205QHF080
IVIV0P1YJFT306][J`80L71`0P1hN7P2079bLP80MGEe0P1hN7P207alO080PX:20P1iNGT207moO`80
O7al0P21PH4207moO`80QXJ60P21PH4208:2PP80Ph>31028R8P208N7Q`80RXZ:0P2;Rh/208n?S`@0
T92@0P2ATI42092@T080Ti>C0P2?Shl209BDU080UiNG0P2EUID3096AT@80UIFE0P2ATI4208j>SP80
VIVI0P2GUiL209bLW080VYZJ0P2HV9P209^KV`80V9RH0P2JVYX409^KV`H0WinO0P2NWYh209VIV@80
W9bL0P2OWil20:6QX@80V9RH0P2CTi<2096AT@80UiNG0P2CTi<209:BTP80SXj>0P27QhL207inOP80
PX:20`1lO7`207emO@80O7al0P20P80207alO080PH610P25QHD208>3P`80QhN70P24Q8@208N7Q`80
QHF50P22PX8207]kN`80Lg=c0P1`L70O0<SPf0007@38h=P203<c<`80=cLg0P15ADD206QXJ080R8R8
0P2?Shl2092@T080VIVI0P2RXZ820:ZZZP80/K6a102b/[820;^k^`80`L710P2a/K430:^[Z`80QHF5
0P0U9BD2020P80809bLW0P0V9RH202DU9@80:2PX0P0/;2`202XZ:P80:BTY0P0Z:RX602`/;080;Bd]
1P0^;Rh202TY:@80;Bd]0P0/;2`206EUI@80KVi^0P1`L702061PH080Cdm?0P1=CDd2059BDP80G5aL
0P1WIfL206YZJP<0K6a/0P1`L70407AdM080Lg=c0P1hN7P207alO080Ng]k0P1jNWX207alO080Ogmo
0P20P8020861P@80PX:20P23Ph<208B4Q080QXJ60P28R8P608V9R@80SHf=102ATI44092@T080TI6A
0P2@T902096AT@80U9BD0P2FUYH209NGU`<0UYJF0P2EUID209>CT`80UYJF0P2IVIT409^KV`80VYZJ
0P2IVIT209^KV`@0W9bL0P2KVi/209fMW@@0WinO0P2NWYh409fMW@80WYjN0P2OWil209bLW080V9RH
0P2EUID409>CT`80U9BD0P2BTY8208f=S@80Ph>30P1jNWX207MgM`<0N7Qh0P1kNg/207inOP80P820
1021PH460820P080PX:20P24Q8@208>3P`80P8200P1iNGT2075aL@80L71`:@38h=P202`/;080>c/k
0P16ATH206UYJ@80SHf=0P29RHT209>CT`80VIVI0P2QXJ440:f][@80/K6a0P2f][H20;jn_P80`<30
0P2i^KT30:j^[P80PH610P0Y:BT202DU9@809RHV0P0W9bL202@T9080:RXZ0P0_;bl202/[:`80;2`/
0P0d=3@202h^;P80;2`/0P0^;Rh202l_;`80<S8b0P0X:2P2034a<@80;2`/0P0a<C42030`<080H61P
0P1^KVh206e]K@80I6AT0P1=CDd204i>CP80D51@0P1SHf<206EUI@80IVIV0`1/K6`207EeM@80MgMg
0P1aLG4207EeM@80MWIf101mOGd207QhN080OWin0P21PH420820P080Ph>30P22PX8208>3P`@0QHF5
0P2:RXX208R8R080QXJ60P2:RXX208j>SP80TI6A0P2@T90209>CT`80S8b<102?Shl2092@T080UIFE
0P2GUiL209FEU@<0UiNG0P2EUID209JFUP80WIfM0P2GUiL209ZJVP80W9bL0P2MWId209VIV@80VYZJ
0P2LW9`209ZJVP80Vi^K0P2OWil209jNWP80X:2P102MWId209bLW080WYjN0P2RXZ8209^KV`80UiNG
0P2HV9P2096AT@@0U9BD102@T9020861P@80Ng]k0P1dM7@307QhN080OGem101oOgl208>3P`80Ogmo
0P20P80207alO080OWin0P23Ph<207moO`80PH610P1mOGd207MgM`80Kfm_0P1^KVhY0<SPf080<S8b
0P0m?Cd204A4A080Hf=S0P2=SHd209:BTP80T92@0P2JVYX20:6QX@80ZZZZ0P2_[jl20;2`/080][Jf
0P2l_;`20<30`080][Jf0`2YZJT208B4Q08092@T0P0L71`202HV9P809BDU0P0V9RH202TY:@80;2`/
0P0X:2P202XZ:P80:2PX0P0/;2`202l_;`80;Bd]0P0Y:BT202l_;`80;2`/0P0];Bd202LW9`80:b/[
0P0/;2`206EUI@80K6a/0P1cLg<205eMG@80DE5A0P1=CDd2059BDP80G5aL0P1WIfL206a/K0<0JVYZ
0P1`L70207AdM080LG5a0P1cLg<207]kN`80NWYj0P1nOWh207]kN`80NWYj0P23Ph<207alO080PH61
0P26QXH20861P@80Q8B40P26QXH208R8R080RHV90P2<S8`208V9R@80Rh^;0P2ATI4409:BTP80S8b<
102ATI4209:BTP80U9BD102FUYH309FEU@80UiNG0P2CTi<209JFUP@0VYZJ0P2MWId209RHV0@0VYZJ
0P2KVi/409bLW080WYjN0P2PX:0209jNWP80WIfM0P2OWil809jNWP80V9RH0P2BTY8209>CT`@0U9BD
0P2BTY8208j>SP80Q8B40P1hN7P207]kN`D0MgMg0P1nOWh208>3P`H0PH610P1nOWh20861P@80Q8B4
0P23Ph<208F5Q@80P8200P1iNGT2079bLP80K6a/7`38h=P001d0b>3H0P0c<c<203Lg=`80ADE50P1X
J6P208R8R080Shn?0P2@T90209VIV@80XZ:R0P2ZZZX20;6a/@@0/[:b0P2k^k/20<71`@80/K6a0`2[
Zj/208F5Q@809BDU0P0P820202LW9`809RHV0P0U9BD202PX:080;2`/0P0Z:RX202TY:@80:RXZ1P0/
;2`202d];@H0;Rh^0P0Y:BT202d];@80;2`/0P1UIFD206i^KP80L71`0P1PH60204m?C`80CDe=0P1B
DU8205aLG080IfMW0P1ZJVX306a/K080L71`101dM7@207=cL`80N7Qh0P1lO7`207]kN`80NWYj0P1l
O7`207moO`80P8200P21PH4208:2PP80Ph>30P24Q8@208J6QP80R8R81P29RHT208f=S@@0TI6A102@
T902096AT@80T92@0P2ATI4209BDU080UYJF0P2GUiL309JFUP80UIFE0P2CTi<209JFUP80VIVI102K
Vi/209ZJVP80VIVI0P2KVi/409bLW080Vi^K0P2MWId409nOW`80WYjN102MWId209jNWP80WinO0P2L
W9`209RHV080UIFE102CTi<209BDU080TY:B0P2=SHd208>3P`80NWYj0P1gMgL307QhN080Ng]k0P1n
OWh20820P0@0PH611P20P80208:2PP80Q8B40P23Ph<20820P080NGUi0P1aLG42071`L2T0b>3H0P0/
;2`203/k>`80ATI60P1YJFT208f=S@80RHV90P2CTi<209VIV@80XJ6Q102][Jd20;6a/@80][Jf0P2n
_[h20<30`080^KVi0`2^[Zh20861P@80:BTY0P0U9BD202HV9P809bLW0P0T92@202XZ:P80;bl_0P0[
:b/202`/;080=3@d0P0^;Rh202`/;080;Rh^0P0_;bl2038b<P80:2PX0P0a<C4202`/;080<C4a0P0`
<302061PH080KVi^0P1]KFd206ATI080CDe=0P1>CTh2051@D080Hf=S0P1UIFD206IVIP<0K6a/0P1e
MGD207MgM`80LG5a0P1eMGD207IfMP@0OGem0P1hN7P207inOP80PH610P20P80208>3P`80PX:20P23
Ph<408F5Q@80RXZ:0P28R8P208J6QP80RXZ:0P2>SXh2096AT@80T92@0P2CTi<208b<S0@0Shn?0P2@
T90209FEU@80UiNG0P2EUID309NGU`80UIFE0P2FUYH209fMW@80UiNG0P2JVYX209bLW080WIfM0P2I
VIT209ZJVP80W9bL0P2JVYX209^KV`80WinO0P2NWYh20:2PX0@0WIfM0P2LW9`209jNWP80XZ:R0P2K
Vi/209NGU`80V9RH0P2ATI4409BDU0@0T92@0P21PH4207]kN`80M7Ad0`1hN7P207emO@@0Ogmo0P23
Ph<207moO`80P8200P1lO7`207inOP80Ph>30P1oOgl20861P@80OGem0P1gMgL206m_K`80KVi^:@38
h=P2038b<P80?Cdm0P14A4@206=SH`80SHf=0P2BTY82092@T080VYZJ0P2QXJ420:ZZZP80[jn_0P2`
/;020;Jf]P80_;bl0P30`<020;Jf]P<0ZJVY0P24Q8@202@T908071`L0P0V9RH202DU9@809RHV0P0Y
:BT202`/;080:2PX0P0Z:RX202PX:080;2`/0P0_;bl202d];@80:BTY0P0_;bl202`/;080;Bd]0P0W
9bL202/[:`80;2`/0P1UIFD206a/K080Lg=c0P1MGEd2055AD@80CDe=0P1BDU8205aLG080IfMW0P1/
K6`306YZJP80L71`0P1dM7@2075aL@80Lg=c0P1kNg/207YjNP80OWin0P1kNg/207YjNP80Ph>30P1l
O7`20861P@80QXJ60P21PH4208B4Q080QXJ60P28R8P208V9R@80S8b<0P29RHT208^;R`80TI6A102B
TY8208b<S0@0TI6A0P2BTY8209BDU0@0UYJF0`2EUID209NGU`80Ti>C0P2FUYH409ZJVP80WIfM0P2H
V9P409ZJVP80Vi^K102LW9`209jNWP80X:2P0P2NWYh209fMW@80WinO202NWYh209RHV080TY:B0P2C
Ti<409BDU080TY:B0P2>SXh208B4Q080N7Qh0P1kNg/507MgM`80OWin0P23Ph<60861P@80OWin0P21
PH4208B4Q080Ph>30P25QHD20820P080NGUi0P1bLW8206a/K1l0b>3H000M0<SPf0809bLW0P0T92@2
02l_;`80CDe=0P2>SXh209FEU@80WinO0P2TY:@20:VYZ@80/k>c0P2l_;`20;^k^`80^;Rh0P2m_Kd2
0<71`@80`l?30`2i^KT209nOW`80?Shn0P0W9bL2020P80808B4Q0P0U9BD202LW9`80:2PX0P0W9bL2
02DU9@809bLW0P0Z:RX202`/;080;bl_100`<30202l_;`80;Rh^0P0X:2P202/[:`80:2PX0P1PH602
06e]K@80LW9b0P1PH60404e=C@80E5AD0P1MGEd206EUI@80IfMW0`1XJ6P206a/K080L71`0P1bLW82
07AdM080MgMg0P1jNWX207]kN`@0O7al0P1mOGd20820P0H0PX:20P23Ph<208F5Q@80QhN70P28R8P2
08V9R@80RXZ:0P2<S8`208n?S`X0TI6A0P2CTi<209FEU@@0UiNG1@2FUYH209FEU@80UYJF0P2GUiL2
09VIV@80VYZJ102KVi/209fMW@@0WYjN0P2MWId<09jNWP@0WinO0P2KVi/209JFUP80UIFE102DU9@2
09:BTP80Shn?0P29RHT207moO`80MWIf0P1hN7P307alO080P8200P22PX8207alO080M7Ad0P1ZJVX2
069RHP80H61P0P1RHV8206YZJP80LW9b0P1`L70206a/K080IVIV0P1QHF42061PH2T0b>3H0P0R8R82
01lO7`808b<S0P1ADE4209:BTP80UiNG0P2NWYh40::RXP80[jn_0P32`/820;Vi^@80_[jn0P30`<02
0<O7a`80a/K60`2l_;`20::RXP80?3`l0P0S8b<202DU9@808b<S0P0W9bL202PX:080:BTY1P0W9bL4
02/[:`80;bl_0P0];Bd202h^;P@0;bl_0P0Y:BT202@T9080:BTY0P1OGel206][J`80L71`0P1VIVH2
04e=C@80CTi>0P1CDe<205mOG`80IVIV0P1SHf<306YZJP80K6a/0P1`L70206m_K`80N7Qh0P1eMGD2
07QhN0@0NWYj101mOGd207inOP80Ph>30P22PX8208>3P`80Q8B40P23Ph<208V9R@80R8R80P2:RXX2
08R8R0H0T92@0P2BTY82092@T080U9BD0P2BTY82096AT@80UiNG0P2FUYH209RHV0D0UYJF0P2CTi<2
09FEU@80VIVI0P2GUiL209ZJVP80WinO0P2LW9`209^KV`80WinO0P2MWId209nOW`80WIfM0P2NWYh2
0:2PX080WIfM102OWil209jNWP80W9bL0P2KVi/209JFUPH0U9BD0P2CTi<208b<S080Rh^;0P1lO7`2
07MgM`80NWYj0`1nOWh20820P080PX:20P1hN7P207=cL`80K6a/0P1UIFD2061PH080IVIV0P1]KFd2
07QhN080M7Ad0P1_Kfl206UYJ@80H61P0P1TI6@Y0<SPf0807alO0P0V9RH2030`<080ADE50P2<S8`2
08f=S@80WinO0P2RXZ820:f][@80^k^k0P2o_kl20;Zj^P80/[:b102i^KT20<W9b@<0^;Rh0P2KVi/2
0492@P80:BTY0P0V9RH2028R8P808b<S100W9bL202h^;P80:2PX0P0Y:BT202`/;080:BTY0P0g=cL2
02d];@80<S8b0P0_;bl2030`<0809bLW0P0];Bd202`/;080HF5Q0P1/K6`2075aL@80GEeM0P1=CDd2
04m?C`80EUIF0P1JFUX406QXJ0<0JFUY0P1_Kfl2071`L080KVi^0P1eMGD207MgM`80N7Qh0P1jNWX2
07]kN`@0O7al0P1nOWh208>3P`80P8200P21PH4208F5Q@80Ph>31P28R8P208V9R@80SHf=0P2?Shl2
096AT@80Ti>C0P2>SXh609>CT`80TY:B0P2GUiL209RHV0D0UiNG0P2EUID209JFUP80VIVI0P2JVYX2
09VIV@80VYZJ0P2MWId609jNWP80WIfM102NWYh209nOW`80WYjN0P2QXJ4409bLW080WinO0P2KVi/2
09NGU`80V9RH0P2GUiL209BDU080Shn?0P2BTY8208R8R080Ogmo0P1dM7@207alO0<0Ng]k0P1nOWh2
08>3P`80Ng]k0P1bLW8206YZJP80HV9R0P1OGel2061PH080J6QX0P1_Kfl2079bLP80J6QX0P1WIfL2
069RHP80Hf=S7`38h=P001d0b>3H0P0W9bL202@T9080;bl_0P1=CDd208j>SP80UIFE0P2OWil20:BT
Y080ZJVY0P2c/k<20;bl_080^k^k0P2h^;P20;fm_@80`L710P33`l<30;Vi^@80WinO0P0n?Sh202LW
9`80820P0P0Q8B4202DU9@809bLW0P0X:2P202LW9`809BDU0P0W9bL202XZ:P80;2`/0P0_;bl4030`
<080;bl_0P0^;Rh202PX:080:b/[0P0X:2P2061PH080KFe]0P1bLW82061PH0@0CDe=0P1DE5@205eM
G@80IFEU0P1WIfL306QXJ080K6a/0P1`L702079bLP80M7Ad0P1gMgL207YjNP80Ng]k101lO7`207em
O@80P8201P22PX8208>3P`80QHF50P27QhL208R8R080RHV90P2:RXX208b<S080Shn?2P2ATI4209>C
T`80UIFE102GUiL509JFUP80UIFE0P2FUYH209NGU`80VIVI0P2JVYX409^KV`80WIfM102NWYh209fM
W@`0WYjN102OWil209^KV`80UYJF0P2EUID409BDU080TY:B0P2?Shl208V9R@80Ogmo0P1fMWH207Qh
N0<0O7al0P20P80208:2PP80O7al0P1dM7@206YZJP80HV9R0P1PH602069RHP80JVYZ0P1bLW82071`
L080K6a/0P1VIVH2065QH@80H61P:@38h=P2028R8P807alO0P0S8b<2055AD@80TY:B0P2GUiL209jN
WP@0XZ:R0P2_[jl20<;2`P80^KVi0P2n_[h20<30`080alO70P36a/H30;bl_080XZ:R0P0l?3`202<S
8`809BDU0P0S8b<202LW9`80:2PX0P0Y:BT602LW9`@0:b/[0P0_;bl202d];@80;Rh^100_;bl202TY
:@8092@T0P0Y:BT205mOG`80Jf][0P1`L70206IVIP80CDe=0P1>CTh205=CD`80GemO0P1VIVH206=S
H`<0JVYZ0P1/K6`2071`L080Kfm_0P1hN7P207EeM@80N7Qh101jNWX407emO@80OWin0P23Ph<208:2
PP80Ph>30P24Q8@208>3P`80RHV90P28R8P208Z:RP80R8R81P2@T90209:BTP80T92@0P2DU9@209:B
TP80TI6A0P2GUiL209JFUP80V9RH1@2FUYH209>CT`80UIFE0P2IVIT209NGU`80VYZJ0P2OWil209bL
W080Vi^K0P2OWil209fMW@80WinO0P2MWId209jNWP80X:2P0P2MWId409nOW`80WYjN0P2LW9`209^K
V`80UYJF1P2DU9@209>CT`80S8b<0P2;Rh/207alO080MgMg0P1jNWX307inOP80P8200P22PX8207Qh
N080Lg=c0P1/K6`206EUI@80H61P0P1VIVH206e]K@80N7Qh0P1dM7@206m_K`80JFUY0P1PH60206AT
I2T0b>3H0P0O7al202HV9P80<30`0P15ADD208b<S080SHf=0P2OWil20::RXP80[Jf]0P2k^k/20;no
_`80^[Zj0P2b/[840;Vi^@80bLW90`2h^;P209^KV`80@T920P0Y:BT202HV9P808R8R0P0S8b<402LW
9`80;Rh^0P0X:2P202TY:@80;2`/0P0Y:BT203Lg=`80;Bd]0P0b<S8202l_;`80<30`0P0W9bL202d]
;@80;2`/0P1QHF4206a/K080LG5a0P1MGEd204e=C@80Cdm?0P1FEUH205YJFP@0J6QX0`1YJFT206m_
K`80L71`0P1^KVh207EeM@80MgMg0P1hN7P207YjNP80Ng]k101lO7`207inOP80Ph>30P20P8020861
P@80QHF50P23Ph<608R8R080RHV90P2=SHd208n?S`80TI6A0P2CTi<208j>SPH0Ti>C0P2BTY8209NG
U`80V9RH1@2GUiL209FEU@80UYJF0P2IVIT209ZJVP80VIVI0P2JVYX209fMW@H0WYjN0P2MWId409jN
WP80WinO0P2NWYh20:6QX@@0W9bL0P2OWil209^KV`80UiNG0P2HV9P209NGU`80U9BD0P2?Shl209:B
TP80R8R80P1oOgl207AdM080O7al0`1kNg/207inOP80Ph>30P1kNg/2079bLP80JVYZ0P1RHV8205mO
G`80H61P0P1XJ6P206m_K`80LW9b0P1XJ6P206MWI`80HV9R0P1SHf<O0<SPf0007@38h=P2028R8P80
6ATI0P0O7al2030`<080QhN70P2JVYX20:^[Z`@0[Jf]0P2h^;P20<;2`P80`<300P2l_;`20;no_`80
`L710P35aLD30;Vi^@80[:b/0P1LG5`203Lg=`807alO0P0P820602PX:0809RHV0P0U9BD202HV9P80
:2PX0P0/;2`2030`<0@0<S8b0P0`<30202h^;P809bLW0P0Z:RX202DU9@80G5aL0P1[Jf/207=cL`80
H61P0P1<C4`204i>CP80EEEE0P1LG5`2069RHP80I6AT0`1UIFD206UYJ@80KVi^0P1bLW8207EeM@80
MgMg0P1iNGT207]kN`@0OGem0P1lO7`20820P080Ph>30P22PX820861P@80PX:20P24Q8@208J6QP80
QhN70P29RHT208Z:RP80Rh^;0P2<S8`2092@T080Ti>C0P2BTY82096AT@80Ti>C0P2EUID209NGU`80
V9RH0P2GUiL309JFUP@0UiNG0P2FUYH209FEU@80UiNG0P2IVIT209^KV`80WIfM0P2NWYh609nOW`80
WYjN0P2MWId809jNWP@0WinO0P2JVYX209BDU0@0UIFE0P2DU9@2096AT@80Rh^;0P25QHD207]kN`80
MGEe0P1kNg/308>3P`80QhN70P26QXH207UiN@80IfMW0P1CDe<20492@P80?clo0P13@d<2055AD@@0
GUiN0P1JFUX205QHF0@0EUIF:@38h=P2020P808071`L0P0R8R8202l_;`80PH610P2TY:@20:JVYP80
ZZZZ0P2a/K420;Bd]080aLG50P2g]kL20;jn_P80_kno0P31`L420;jn_P<0_;bl0P2^[Zh206EUI@80
=3@d0P0S8b<2024Q8@@0:2PX0P0Z:RX402DU9@809RHV0P0[:b/202XZ:P80=3@d0P0b<S8203@d=080
;bl_0P0/;2`402LW9`80;Rh^0P1JFUX206e]K@80L71`0P1YJFT204M7A`80Cdm?0P1EEED205aLG080
HV9R0P1TI6@306IVIP80JFUY0P1^KVh207AdM080Lg=c0P1iNGT207alO080NGUi0P20P80407emO@80
Ogmo0P23Ph<208:2PP80PH610P20P80208F5Q@@0QhN70P28R8P208^;R`80S8b<0P2;Rh/609>CT`80
SXj>0P2DU9@209>CT`80VIVI0P2GUiL509JFUP80UIFE0P2HV9P209NGU`@0U9BD0P2HV9P209fMW@80
W9bL0P2OWil20:2PX080WYjN0P2OWil209^KV`80WYjN0P2LW9`209jNWP80WIfM0P2LW9`209nOW`80
XZ:R102FUYH209RHV080UIFE0P2DU9@208n?S`80Rh^;0P25QHD207]kN`80MGEe0P1jNWX308B4Q080
Ph>30P24Q8@20861P@80JFUY0P1GEeL204I6AP80>c/k0P17AdL2055AD@80HF5Q0P1MGEd205aLG080
EeMG0P1EEED205UIFBT0b>3H0P0Q8B42020P808071`L0P0^;Rh208V9R@80WYjN0P2][Jd20:^[Z`80
[:b/0P2f][H20<30`0@0_kno0P34a<@20<;2`P80b/[:0`2g]kL20:ZZZP80FUYJ0P0j>SX201hN7P80
7alO0P0X:2P202l_;`808b<S0P0Z:RX402<S8`80;Rh^0P0Z:RX202l_;`@0<S8b0P0_;bl202h^;P80
9RHV0P0[:b/202@T9080GEeM0P1/K6`2071`L080H61P0P1;Bd/2059BDP@0EUIF0P1UIFD205mOG`<0
I6AT0P1YJFT206][J`80Lg=c0P1eMGD207MgM`80NWYj0P1oOgl207UiN@80Ogmo0P1jNWX208>3P`80
Q8B40P1kNg/208:2PP80QHF50P23Ph<208J6QP80QhN70P29RHT208Z:RP80S8b<0P2;Rh/2092@T080
Ti>C102@T90209:BTP80UIFE1P2GUiL309BDU0@0UiNG1P2EUID209RHV080WYjN0P2JVYX409jNWP80
WIfM102NWYh209bLW080X:2P102LW9`60:2PX080VIVI0P2CTi<209BDU0@0Ti>C0P2@T90208j>SP80
Ph>30P1lO7`207EeM@80NWYj0`23Ph<208^;R`80R8R80P1eMGD206YZJP80E5AD0P12@T8203dm?@80
A4A40P1CDe<205eMG@80GemO0P1IFET205MGE`80E5AD0P1FEUHO0<SPf0007@38h=P2028R8P806ATI
0P0O7al2030`<080QhN70P2JVYX20:^[Z`@0[Jf]0P2h^;P20<;2`P80`<300P2l_;`20;no_`80`L71
0P35aLD30;Vi^@80[:b/0P1LG5`203Lg=`807alO0P0P820602PX:0809RHV0P0U9BD202HV9P80:2PX
0P0/;2`2030`<0@0<S8b0P0`<30202h^;P809bLW0P0Z:RX202DU9@80G5aL0P1[Jf/207=cL`80H61P
0P1<C4`204i>CP80EEEE0P1LG5`2069RHP80I6AT0`1UIFD206UYJ@80KVi^0P1bLW8207EeM@80MgMg
0P1iNGT207]kN`@0OGem0P1lO7`20820P080Ph>30P22PX820861P@80PX:20P24Q8@208J6QP80QhN7
0P29RHT208Z:RP80Rh^;0P2<S8`2092@T080Ti>C0P2BTY82096AT@80Ti>C0P2EUID209NGU`80V9RH
0P2GUiL309JFUP@0UiNG0P2FUYH209FEU@80UiNG0P2IVIT209^KV`80WIfM0P2NWYh609nOW`80WYjN
0P2MWId809jNWP@0WinO0P2JVYX209BDU0@0UIFE0P2DU9@2096AT@80Rh^;0P25QHD207]kN`80MGEe
0P1kNg/308>3P`80QhN70P26QXH207UiN@80IfMW0P1CDe<20492@P80?clo0P13@d<2055AD@@0GUiN
0P1JFUX205QHF0@0EUIF:@38h=P2020P808071`L0P0R8R8202l_;`80PH610P2TY:@20:JVYP80ZZZZ
0P2a/K420;Bd]080aLG50P2g]kL20;jn_P80_kno0P31`L420;jn_P<0_;bl0P2^[Zh206EUI@80=3@d
0P0S8b<2024Q8@@0:2PX0P0Z:RX402DU9@809RHV0P0[:b/202XZ:P80=3@d0P0b<S8203@d=080;bl_
0P0/;2`402LW9`80;Rh^0P1JFUX206e]K@80L71`0P1YJFT204M7A`80Cdm?0P1EEED205aLG080HV9R
0P1TI6@306IVIP80JFUY0P1^KVh207AdM080Lg=c0P1iNGT207alO080NGUi0P20P80407emO@80Ogmo
0P23Ph<208:2PP80PH610P20P80208F5Q@@0QhN70P28R8P208^;R`80S8b<0P2;Rh/609>CT`80SXj>
0P2DU9@209>CT`80VIVI0P2GUiL509JFUP80UIFE0P2HV9P209NGU`@0U9BD0P2HV9P209fMW@80W9bL
0P2OWil20:2PX080WYjN0P2OWil209^KV`80WYjN0P2LW9`209jNWP80WIfM0P2LW9`209nOW`80XZ:R
102FUYH209RHV080UIFE0P2DU9@208n?S`80Rh^;0P25QHD207]kN`80MGEe0P1jNWX308B4Q080Ph>3
0P24Q8@20861P@80JFUY0P1GEeL204I6AP80>c/k0P17AdL2055AD@80HF5Q0P1MGEd205aLG080EeMG
0P1EEED205UIFBT0b>3H0P0Q8B42020P808071`L0P0^;Rh208V9R@80WYjN0P2][Jd20:^[Z`80[:b/
0P2f][H20<30`0@0_kno0P34a<@20<;2`P80b/[:0`2g]kL20:ZZZP80FUYJ0P0j>SX201hN7P807alO
0P0X:2P202l_;`808b<S0P0Z:RX402<S8`80;Rh^0P0Z:RX202l_;`@0<S8b0P0_;bl202h^;P809RHV
0P0[:b/202@T9080GEeM0P1/K6`2071`L080H61P0P1;Bd/2059BDP@0EUIF0P1UIFD205mOG`<0I6AT
0P1YJFT206][J`80Lg=c0P1eMGD207MgM`80NWYj0P1oOgl207UiN@80Ogmo0P1jNWX208>3P`80Q8B4
0P1kNg/208:2PP80QHF50P23Ph<208J6QP80QhN70P29RHT208Z:RP80S8b<0P2;Rh/2092@T080Ti>C
102@T90209:BTP80UIFE1P2GUiL309BDU0@0UiNG1P2EUID209RHV080WYjN0P2JVYX409jNWP80WIfM
102NWYh209bLW080X:2P102LW9`60:2PX080VIVI0P2CTi<209BDU0@0Ti>C0P2@T90208j>SP80Ph>3
0P1lO7`207EeM@80NWYj0`23Ph<208^;R`80R8R80P1eMGD206YZJP80E5AD0P12@T8203dm?@80A4A4
0P1CDe<205eMG@80GemO0P1IFET205MGE`80E5AD0P1FEUHO0<SPf0007@38h=P2028R8P806QXJ0P0L
71`202LW9`80Fe]K0P2YZJT20:f][@80];Bd0P2[Zj/20;Ng]`80`L710P2m_Kd20;Ng]`80^k^k0P2o
_kl20;jn_P<0]KFe0P30`<020::RXP80Ng]k0P0c<c<402TY:@809RHV0P0T92@402<S8`8092@T0P0U
9BD202XZ:P80;bl_0P0`<30202l_;`80;2`/0P0Z:RX202HV9P80:b/[0P0V9RH2065QH@80J6QX0P1Z
JVX205aLG080CDe=0P1>CTh205=CD`80FEUI0P1PH602069RHP<0I6AT0P1ZJVX2071`L080Lg=c0P1f
MWH207QhN0@0NWYj0P1kNg/207emO@80Ogmo0P20P8060861P@80Ph>30P26QXH208R8R0H0RXZ:0P2;
Rh/208f=S@80T92@102ATI42092@T080U9BD0P2HV9P209NGU`80UIFE0P2FUYH309NGU`@0VIVI0P2H
V9P209JFUP80UiNG0P2IVIT209^KV`80W9bL0P2MWId809jNWP80WIfM1P2NWYh209fMW@@0WinO0P2J
VYX209FEU@80U9BD0P2CTi<2092@T080S8b<0P27QhL20861P@80NWYj0P1gMgL207emO@<0QHF50P28
R8P208N7Q`80OGem0P1^KVh2051@D080=SHf0P0a<C4203Lg=`80ADE50P1EEED205eMG@80HV9R0P1T
I6@206EUI@80IVIV:@38h=P202DU9@808R8R0P0O7al2024Q8@80F5QH0P2][Jd20;6a/@80[Jf]0P2c
/k<20;Zj^P80a<C40P2d];@20;Ng]`80_Kfm0P2l_;`20;jn_P<0]kNg0P2^[Zh20::RXP80M7Ad0P0`
<30202TY:@80:RXZ0P0S8b<2024Q8@@09RHV100U9BD202HV9P80;2`/0P0h>3P202h^;P80:RXZ0P0^
;Rh402/[:`80;Bd]0P1GEeL206YZJP80HV9R0P1OGel204];B`80BDU90P1ADE42061PH080GUiN0P1P
H603069RHP80Jf][0P1`L702075aL@80MGEe0P1iNGT207QhN0@0NWYj0P1kNg/20820P080PH610P22
PX820820P0@0PX:20P26QXH208Z:RP80RHV91028R8P208^;R`80RXZ:0P2@T90208n?S`80SHf=0P2>
SXh209ZJVP@0UYJF0P2CTi<509VIV@80UYJF0P2KVi/209bLW080V9RH0P2EUID209ZJVP80W9bL102J
VYX209fMW@80W9bL0P2PX:0209nOW`80WYjN102OWil209jNWP80X:2P0P2OWil20:6QX@80V9RH0P2C
Ti<209BDU080TI6A0P2=SHd208n?S`80RXZ:0P22PX8207MgM`80NGUi0P21PH4308B4Q080QXJ60P28
R8P208>3P`80IFEU0P11@D42038b<P80<C4a0P0b<S820410@080CDe=0P1IFET2061PH080FUYJ0P1S
Hf<2075aLBT0b>3H0P0P820201PH6080820P0P0U9BD2061PH080Zj^[0P2/[:`20;:b/P80[Zj^0P2a
/K420<C4a080_;bl0P2e]KD20;Rh^080^k^k0P2n_[h30;>c/`80aLG50P2PX:0207YjNP80;Bd]0P0V
9RH202PX:0808b<S0P0P820202LW9`808B4Q0P0M7Ad2028R8P80:2PX0P0b<S8202h^;P@0;bl_0P0Z
:RX2028R8P80:RXZ0P0U9BD205iNGP80J6QX0P1^KVh205mOG`80BDU90P1<C4`2055AD@80FUYJ0P1Q
HF42069RHP<0IFEU0P1[Jf/2075aL@80MgMg0P1eMGD207IfMP80N7Qh0P1jNWX207alO080P8200P1o
Ogl20861P@80QHF50P1kNg/208B4Q080QhN71026QXH208^;R`@0RXZ:0P2>SXh208b<S0@0TY:B0P2@
T90209>CT`80UIFE0P2HV9P209ZJVP80UIFE0P2FUYH309VIV@@0VYZJ0P2GUiL209JFUP80V9RH0P2I
VIT209fMW@80Vi^K0P2MWId209nOW`80X:2P0P2QXJ4209bLW080WYjN0P2OWil20:6QX@@0W9bL0P2Q
XJ4209fMW@80VYZJ102EUID209BDU080Shn?0P2>SXh208J6QP80PX:20P1iNGT207QhN080OGem0`24
Q8@208V9R@80R8R80P1fMWH206m_K`80De=C0P0f=SH2034a<@80>3Ph0P15ADD205MGE`80GUiN0P1S
Hf<406IVIP80IFEU7`38h=P001d0b>3H0P0R8R8201XJ6P8071`L0P0W9bL205]KF`80ZJVY0P2][Jd2
0;Bd]080Zj^[0P2g]kL20<71`@80_Kfm0P2g]kL20;^k^`80_kno0P2n_[h30;Fe]@80`<300P2RXZ82
07]kN`80<c<c100Y:BT202HV9P8092@T100S8b<202@T90809BDU0P0Z:RX202l_;`80<30`0P0_;bl2
02`/;080:RXZ0P0V9RH202/[:`809RHV0P1QHF4206QXJ080JVYZ0P1LG5`204e=C@80CTi>0P1CDe<2
05UIF@80H61P0P1RHV8306ATI080JVYZ0P1`L70207=cL`80MWIf0P1hN7P407YjNP80Ng]k0P1mOGd2
07moO`80P8201P21PH4208>3P`80QXJ60P28R8P608Z:RP80Rh^;0P2=SHd2092@T0@0TI6A0P2@T902
09BDU080V9RH0P2GUiL209FEU@80UYJF0`2GUiL409VIV@80V9RH0P2FUYH209NGU`80VIVI0P2KVi/2
09bLW080WIfM202NWYh209fMW@H0WYjN0P2MWId409nOW`80VYZJ0P2EUID209BDU080Ti>C0P2@T902
08b<S080QhN70P21PH4207YjNP80MgMg0P1mOGd308F5Q@80R8R80P27QhL207emO@80KVi^0P1@D502
03Hf=P80<C4a0P0g=cL204E5A@80EEEE0P1MGEd2069RHP80I6AT0P1UIFD206IVIRT0b>3H0P0U9BD2
028R8P807alO0P0Q8B4205QHF080[Jf]0P2a/K420:f][@80/k>c0P2j^[X20<C4a080];Bd0P2g]kL2
0;fm_@80_;bl0P2n_[h30;Ng]`80[Zj^0P2RXZ8207AdM080<30`0P0Y:BT202XZ:P808b<S0P0Q8B44
02HV9P@09BDU0P0V9RH202`/;080>3Ph0P0^;Rh202XZ:P80;Rh^100[:b/202d];@80EeMG0P1ZJVX2
069RHP80GemO0P1;Bd/204U9B@80DE5A0P1PH60205iNGP80H61P0`1RHV8206][J`80L71`0P1aLG42
07EeM@80NGUi0P1hN7P407YjNP80Ng]k0P20P8020861P@80PX:20P20P80408:2PP80QXJ60P2:RXX2
08V9R@@0R8R80P2;Rh/208Z:RP80T92@0P2?Shl208f=S@80SXj>0P2JVYX409JFUP80Ti>C1@2IVIT2
09JFUP80Vi^K0P2LW9`209RHV080UIFE0P2JVYX209bLW0@0VYZJ0P2MWId209bLW080X:2P0P2OWil2
09jNWP@0WinO0P2NWYh20:2PX080WinO0P2QXJ4209RHV080Ti>C0P2DU9@2096AT@80SHf=0P2?Shl2
08Z:RP80PX:20P1gMgL207UiN@80PH610`24Q8@208J6QP80R8R80P23Ph<206EUI@80@D510P0b<S82
034a<@80<S8b0P10@40204e=C@80FEUI0P1PH60205YJFP80Hf=S0P1aLG4Y0<SPf080820P0P0H61P2
020P80809BDU0P1PH6020:^[Z`80[:b/0P2b/[820:j^[P80/K6a0P34a<@20;bl_080]KFe0P2h^;P2
0;^k^`80_[jn0`2c/k<20<G5a@80X:2P0P1jNWX202d];@809RHV0P0X:2P202<S8`80820P0P0W9bL2
024Q8@807AdM0P0R8R8202PX:080<S8b0P0^;Rh402l_;`80:RXZ0P0R8R8202XZ:P809BDU0P1NGUh2
06QXJ080KVi^0P1OGel204U9B@80C4a<0P1ADE4205YJFP80HF5Q0P1RHV8306EUI@80Jf][0P1aLG42
07MgM`80MGEe0P1fMWH207QhN080NWYj0P1lO7`20820P080Ogmo0P21PH4208F5Q@80Ng]k0P24Q8@2
08N7Q`@0QXJ60P2;Rh/408Z:RP80SXj>0P2<S8`409:BTP80T92@0P2CTi<209FEU@80V9RH0P2JVYX2
09FEU@80UYJF0`2IVIT409ZJVP80UiNG0P2FUYH209RHV080VIVI0P2MWId209^KV`80WIfM0P2OWil2
0:2PX080XJ6Q0P2LW9`209jNWP80WinO0P2QXJ4409bLW080XJ6Q0P2MWId209ZJVP@0UIFE0P2DU9@2
08n?S`80SXj>0P26QXH208:2PP80NGUi0P1hN7P207emO@<0Q8B40P29RHT208R8R080MWIf0P1_Kfl2
05=CD`80=SHf0P0a<C4203Ph>080ADE50P1GEeL205iNGP80Hf=S101VIVH206EUIAl0b>3H000M0<SP
f0808b<S0P0O7al201dM7@808b<S0P0^;Rh20:j^[P80Zj^[0P2e]KD20:RXZ080/k>c0P2l_;`20;Jf
]P80/;2`0P2f][H20;^k^`80^;Rh0`2b/[820:j^[P80XZ:R0P2KVi/2059BDP80?clo0P0a<C4202PX
:0808R8R0P0Q8B44028R8P808b<S0P0X:2P402d];@80;2`/0P0Y:BT202LW9`8092@T0P0[:b/202XZ
:P80IFEU0P1VIVH2065QH@80EeMG0P1=CDd204a<C080D51@0P1FEUH205eMG@80H61P0`1TI6@206a/
K080Lg=c0P1eMGD207IfMP80NGUi0P1lO7`207YjNP80NGUi0P1nOWh208:2PP80PH610P1nOWh20820
P080PX:20P24Q8@208N7Q`80RXZ:0P2<S8`208^;R`80RXZ:0P2<S8`208j>SPH0Shn?0P2@T90209FE
U@80VYZJ0P2GUiL209>CT`80UIFE0`2HV9P409ZJVP80VIVI0P2GUiL209RHV080VYZJ102KVi/209bL
W0P0WIfM102NWYh209nOW`80WIfM0P2LW9`209jNWP80WinO0P2JVYX209FEU@80Ti>C0P2ATI4208f=
S@80RHV90P23Ph<207emO@80NGUi0P1hN7P207moO`<0QXJ60P28R8P208N7Q`80Q8B40P1iNGT205IF
EP80=SHf0P0a<C4203Hf=P80@T920P1ADE42069RHP80LG5a0P1fMWH207QhN080NGUi:@38h=P2020P
80@07AdM0P0O7al203Lg=`80XZ:R0P2d];@20:b/[080[jn_0P2][Jd20;no_`@0/k>c0P2h^;P20;fm
_@80^KVi0`2c/k<20:n_[`80YjNW0P2QXJ4205]KF`80?3`l0P0e=CD202LW9`809BDU0P0Q8B44028R
8P809RHV0P0Y:BT202d];@@0;bl_0P0U9BD202LW9`80:BTY0P0U9BD202h^;P80GUiN0P1^KVh205QH
F080Fe]K0P17AdL2051@D080C4a<0P1FEUH205eMG@80HV9R0`1UIFD206YZJP80MgMg0P1cLg<207Ui
N@80MgMg0P1mOGd207alO080NWYj0P1mOGd208:2PP80P8200P1oOgl207inOP80PX:20P24Q8@208N7
Q`80RXZ:0P2=SHd208b<S080Rh^;0P2:RXX4092@T080TI6A102@T90209FEU@80Vi^K0P2DU9@209:B
TP80VYZJ0`2DU9@209NGU`80VYZJ0P2LW9`209FEU@80V9RH0P2IVIT209fMW@80VIVI0P2OWil209bL
W080WYjN0P2LW9`209jNWP80W9bL0P2NWYh409fMW@80VIVI0P2OWil209fMW@80W9bL0P2FUYH209:B
TP80U9BD102:RXX208N7Q`80P8200P1dM7@207QhN080QhN70`24Q8@208F5Q@80Q8B40P2:RXX207Qh
N080EUIF0P0j>SX203Ph>080>CTi0P19BDT205UIF@80IVIV0P1bLW8207=cL`80MgMg0P1nOWhY0<SP
f0@08R8R0P0N7Qh201lO7`80;Bd]0P2_[jl20:RXZ080^[Zj0P2VYZH20;2`/080^k^k0P2f][H20;6a
/@80^;Rh0P2k^k/20;Jf]P<0/[:b0P2^[Zh209bLW080WIfM0P1BDU820410@080=3@d0P0Y:BT202HV
9P809BDU0P0R8R8202DU9@808b<S100^;Rh202XZ:P80;2`/0P0[:b/202TY:@807QhN0P0^;Rh202/[
:`80IfMW0P1UIFD2065QH@80E5AD0P1>CTh204];B`80D51@0P1DE5@205aLG080I6AT0`1PH60206QX
J080Lg=c0P1fMWH407MgM`80Ogmo0P1kNg/207UiN@80OWin0P24Q8@207inOP80Ogmo0P1mOGd208:2
PP@0QhN70P28R8P408f=S@80RXZ:0P2?Shl208b<S080T92@0P2=SHd408n?S`80Ti>C102HV9P209>C
T`80U9BD0`2HV9P209VIV@80Vi^K0P2JVYX209RHV080UiNG0P2IVIT409ZJVP80Vi^K0P2LW9`209fM
W@80WYjN0P2KVi/20:2PX080WIfM0P2OWil409bLW080WYjN0P2LW9`209fMW@80TY:B0P2@T90209:B
TP80RHV90P2<S8`208>3P`80OGem101hN7P207emO@<0RHV90P27QhL208V9R@80Ph>30P1kNg/205IF
EP80=CDe0P0_;bl203@d=080@d=30P1@D502065QH@80L71`0P1gMgL207QhN080NWYj7`38h=P001d0
b>3H0P0S8b<201lO7`807AdM0P0S8b<202h^;P80[Zj^0P2[Zj/20;Fe]@80Z:RX0P2c/k<20;bl_080
][Jf0P2`/;020;Jf]P80^k^k0P2h^;P30;:b/P80[Zj^0P2RXZ8209^KV`80DU9B0P0o?cl2034a<@80
:2PX0P0R8R82024Q8@@08R8R0P0S8b<202PX:0@0;Bd]0P0/;2`202TY:@809bLW0P0T92@202/[:`80
:RXZ0P1UIFD206IVIP80HF5Q0P1GEeL204e=C@80C4a<0P1@D50205IFEP80GEeM0P1PH60306ATI080
K6a/0P1cLg<207EeM@80MWIf0P1iNGT207alO080NWYj0P1iNGT207inOP80PX:20P21PH4207inOP80
P8200P22PX8208B4Q080QhN70P2:RXX208b<S080Rh^;0P2:RXX208b<S080SXj>1P2?Shl2092@T080
UIFE0P2JVYX209NGU`80Ti>C0P2EUID309RHV0@0VYZJ0P2IVIT209NGU`80V9RH0P2JVYX409^KV`80
W9bL202MWId409jNWP80WinO0P2MWId209bLW080WYjN0P2OWil209ZJVP80UIFE0P2CTi<2096AT@80
SHf=0P29RHT208>3P`80OGem0P1iNGT207QhN080Ogmo0`26QXH208R8R080QhN70P24Q8@207UiN@80
EUIF0P0f=SH2034a<@80=SHf0P12@T82055AD@80HV9R0P1aLG4207IfMP80N7Qh0P1iNGTY0<SPf080
820P100M7Ad201lO7`80=cLg0P2RXZ820;Bd]080[:b/0P2_[jl20:f][@80_kno102c/k<20;Rh^080
_Kfm0P2i^KT30;>c/`80[jn_0P2WYjL20:6QX@80Fe]K0P0l?3`203De=@809bLW0P0U9BD2024Q8@@0
8R8R0P0V9RH202TY:@80;Bd]100_;bl202DU9@809bLW0P0Y:BT202DU9@80;Rh^0P1NGUh206i^KP80
F5QH0P1KFe/204M7A`80D51@0P1<C4`205IFEP80GEeM0P1RHV8306EUI@80JVYZ0P1gMgL207=cL`80
NGUi0P1gMgL207emO@80O7al0P1jNWX207emO@80PX:20P20P80207moO`80OWin0P22PX8208B4Q080
QhN70P2:RXX208f=S@80S8b<0P2;Rh/208Z:RP@0T92@0P2ATI44092@T080UIFE0P2KVi/209BDU080
TY:B0P2JVYX309BDU080UiNG0P2JVYX209bLW080UIFE0P2HV9P209VIV@80WIfM0P2IVIT209nOW`80
W9bL0P2NWYh209bLW080WYjN0P2LW9`209jNWP@0WIfM0P2IVIT209nOW`80WIfM0P2LW9`209JFUP80
TY:B0P2DU9@408Z:RP80QhN70P20P80207AdM080N7Qh0P27QhL308B4Q080QHF50P24Q8@208Z:RP80
N7Qh0P1FEUH203Xj>P80>3Ph0P0i>CT204U9B@80FEUI0P1VIVH2079bLP80Lg=c0P1gMgL207inORT0
b>3H100R8R8201hN7P807alO0P0];Bd20:n_[`80Z:RX0P2j^[X20:JVYP80/;2`0P2k^k/20;Jf]P80
/K6a0P2h^;P20;^k^`80][Jf0`2b/[820:j^[P80W9bL0P2MWId2059BDP80@4100P0d=3@202TY:@80
9RHV0P0U9BD2028R8P809BDU0P0S8b<402h^;P80:RXZ0P0/;2`202/[:`80:BTY0P0N7Qh202h^;P80
:b/[0P1WIfL206EUI@80HF5Q0P1DE5@204i>CP80Bd];0P1@D50205ADE080G5aL0P1TI6@3061PH080
J6QX0P1cLg<207IfMP@0MgMg0P1oOgl207]kN`80NGUi0P1nOWh208B4Q080OWin0P1oOgl207emO@80
PX:21027QhL208R8R0@0SHf=0P2:RXX208n?S`80S8b<0P2@T90208f=S@@0Shn?0P2CTi<409RHV080
Ti>C0P2DU9@309RHV080VIVI0P2KVi/209ZJVP80V9RH0P2GUiL209VIV@@0VYZJ0P2KVi/209bLW080
WIfM0P2NWYh209^KV`80X:2P0P2MWId209nOW`@0W9bL0P2NWYh209bLW080WIfM0P2BTY82092@T080
TY:B0P29RHT208b<S080Ph>30P1mOGd407QhN080OGem0`29RHT208N7Q`80RHV90P23Ph<207]kN`80
EUIF0P0e=CD202l_;`80=3@d0P13@d<2051@D080HF5Q0P1`L70207MgM`80N7Qh0P1jNWXO0<SPf000
7@38h=P202DU9@808B4Q0P0L71`201/K6`808B4Q0P2=SHd20;2`/080Xj>S0P2ZZZX20:f][@80/K6a
0P2`/;020:n_[`80/[:b0P2e]KD20;Ng]`<0^;Rh0P2e]KD20;>c/`80`<300P2RXZ8207QhN080Bd];
0P0d=3@202HV9P809BDU0P0S8b<4028R8P809bLW100];Bd202`/;080:b/[0P0Z:RX202DU9@809RHV
0P0f=SH205iNGP80I6AT0P1RHV8205EEE@80AdM70P16ATH204];B`80De=C0P1LG5`2065QH@<0IFEU
0P1]KFd207AdM080MGEe0P1fMWH207YjNPH0OGem0P20P80208:2PP80P8200P1nOWh20820P080PX:2
0P24Q8@208J6QP80RHV90P2;Rh/208b<S0H0SHf=0P2?Shl4096AT@80T92@0P2CTi<809JFUP<0UiNG
0P2HV9P209VIV@80UiNG0P2FUYH209RHV080VYZJ0P2LW9`209fMW@80Vi^K0P2JVYX209bLW0@0WinO
0P2NWYh409nOW`80WIfM0P2LW9`409fMW@80VIVI0P2DU9@209:BTP80T92@0P2?Shl208f=S@80PH61
0P1fMWH207AdM080MWIf0P1lO7`308>3P`80QhN70P29RHT208F5Q@80Ogmo0P1lO7`207UiN@80N7Qh
0P1iNGT20861P@80R8R80P24Q8@207inOP@0OGem0P1lO7`Y0<SPf080:BTY0P0P8202024Q8@807AdM
0P0U9BD208b<S080[Zj^0P2UYJD40:NWY`@0];Bd0P2YZJT40;2`/080];Bd0`2i^KT20;Bd]080][Jf
0P2d];@209VIV@80Ng]k0P1<C4`202d];@80:BTY0P0V9RH2020P80H08R8R0P0`<30202d];@80:b/[
0P0V9RH202PX:080:BTY0P0U9BD203@d=080H61P0P1_Kfl206ATI080G5aL0P16ATH204e=C@80C4a<
0P1EEED205aLG080GEeM0`1VIVH206e]K@80M7Ad0P1_Kfl207UiN@80NWYj0P1mOGd20820P080O7al
0P1mOGd208F5Q@80Ogmo0P1mOGd408>3P`80PX:20P28R8P208J6QP80S8b<0P2:RXX2096AT@@0SHf=
0P2?Shl2092@T080SHf=0P2BTY8409FEU@80UYJF0P2GUiL209FEU@<0VYZJ0P2HV9P209FEU@80UiNG
0P2EUID209NGU`80VIVI102LW9`209nOW`80V9RH0P2MWId609jNWP80X:2P0P2OWil20:2PX080WIfM
0P2KVi/209jNWP80UiNG0P2FUYH208n?S`80U9BD102:RXX208B4Q080LG5a0P1/K6`2075aL@80PH61
0`1oOgl208V9R@80QhN71025QHD208>3P`80MgMg0P1`L70207EeM@80OWin0P1oOgl20820P080PX:2
0P24Q8@207inOP80NWYj:@38h=P202HV9P808B4Q0P0I6AT201dM7@807alO0P2CTi<20:n_[`80XZ:R
0P2[Zj/20;6a/@80];Bd0P2`/;020:j^[P80]KFe0P2h^;P20;Zj^P<0^;Rh0P2c/k<20;^k^`80a/K6
0P2VYZH2075aL@80C4a<0P0^;Rh2024Q8@808b<S0P0Q8B42028R8P80820P0P0Z:RX202DU9@@0:b/[
0P0];Bd202XZ:P808R8R0P0Y:BT203Ph>080GEeM0P1NGUh206=SH`80De=C0P1:BTX204Q8B080CTi>
0P1ADE4205]KF`80HV9R0`1WIfL206i^KP80Lg=c0P1dM7@207QhN080MgMg0P1oOgl207alO080NWYj
0P1nOWh208:2PP80Ogmo0P22PX8207moO`@0PX:20P25QHD208^;R`80RHV90P28R8P208^;R`@0S8b<
0P2=SHd209>CT`80TI6A0P2CTi<209BDU0@0V9RH0P2GUiL209BDU0L0UiNG102FUYH209RHV080Vi^K
0P2OWil20:2PX080VIVI0P2JVYX209nOW`80WIfM0P2OWil209fMW@@0X:2P0P2NWYh209bLW080WinO
0P2NWYh209bLW080UiNG102BTY82092@T080SXj>0P1mOGd207QhN080MGEe0P1fMWH207alO0<0PX:2
0P28R8P208V9R@80Q8B40P1mOGd407alO080N7Qh0P1lO7`208>3P`80R8R80P22PX8207inOP80NWYj
101kNg/O0<SPf0007@38h=P202DU9@808B4Q0P0L71`201/K6`808B4Q0P2=SHd20;2`/080Xj>S0P2Z
ZZX20:f][@80/K6a0P2`/;020:n_[`80/[:b0P2e]KD20;Ng]`<0^;Rh0P2e]KD20;>c/`80`<300P2R
XZ8207QhN080Bd];0P0d=3@202HV9P809BDU0P0S8b<4028R8P809bLW100];Bd202`/;080:b/[0P0Z
:RX202DU9@809RHV0P0f=SH205iNGP80I6AT0P1RHV8205EEE@80AdM70P16ATH204];B`80De=C0P1L
G5`2065QH@<0IFEU0P1]KFd207AdM080MGEe0P1fMWH207YjNPH0OGem0P20P80208:2PP80P8200P1n
OWh20820P080PX:20P24Q8@208J6QP80RHV90P2;Rh/208b<S0H0SHf=0P2?Shl4096AT@80T92@0P2C
Ti<809JFUP<0UiNG0P2HV9P209VIV@80UiNG0P2FUYH209RHV080VYZJ0P2LW9`209fMW@80Vi^K0P2J
VYX209bLW0@0WinO0P2NWYh409nOW`80WIfM0P2LW9`409fMW@80VIVI0P2DU9@209:BTP80T92@0P2?
Shl208f=S@80PH610P1fMWH207AdM080MWIf0P1lO7`308>3P`80QhN70P29RHT208F5Q@80Ogmo0P1l
O7`207UiN@80N7Qh0P1iNGT20861P@80R8R80P24Q8@207inOP@0OGem0P1lO7`Y0<SPf080:BTY0P0P
8202024Q8@807AdM0P0U9BD208b<S080[Zj^0P2UYJD40:NWY`@0];Bd0P2YZJT40;2`/080];Bd0`2i
^KT20;Bd]080][Jf0P2d];@209VIV@80Ng]k0P1<C4`202d];@80:BTY0P0V9RH2020P80H08R8R0P0`
<30202d];@80:b/[0P0V9RH202PX:080:BTY0P0U9BD203@d=080H61P0P1_Kfl206ATI080G5aL0P16
ATH204e=C@80C4a<0P1EEED205aLG080GEeM0`1VIVH206e]K@80M7Ad0P1_Kfl207UiN@80NWYj0P1m
OGd20820P080O7al0P1mOGd208F5Q@80Ogmo0P1mOGd408>3P`80PX:20P28R8P208J6QP80S8b<0P2:
RXX2096AT@@0SHf=0P2?Shl2092@T080SHf=0P2BTY8409FEU@80UYJF0P2GUiL209FEU@<0VYZJ0P2H
V9P209FEU@80UiNG0P2EUID209NGU`80VIVI102LW9`209nOW`80V9RH0P2MWId609jNWP80X:2P0P2O
Wil20:2PX080WIfM0P2KVi/209jNWP80UiNG0P2FUYH208n?S`80U9BD102:RXX208B4Q080LG5a0P1/
K6`2075aL@80PH610`1oOgl208V9R@80QhN71025QHD208>3P`80MgMg0P1`L70207EeM@80OWin0P1o
Ogl20820P080PX:20P24Q8@207inOP80NWYj:@38h=P202HV9P808B4Q0P0I6AT201dM7@807alO0P2C
Ti<20:n_[`80XZ:R0P2[Zj/20;6a/@80];Bd0P2`/;020:j^[P80]KFe0P2h^;P20;Zj^P<0^;Rh0P2c
/k<20;^k^`80a/K60P2VYZH2075aL@80C4a<0P0^;Rh2024Q8@808b<S0P0Q8B42028R8P80820P0P0Z
:RX202DU9@@0:b/[0P0];Bd202XZ:P808R8R0P0Y:BT203Ph>080GEeM0P1NGUh206=SH`80De=C0P1:
BTX204Q8B080CTi>0P1ADE4205]KF`80HV9R0`1WIfL206i^KP80Lg=c0P1dM7@207QhN080MgMg0P1o
Ogl207alO080NWYj0P1nOWh208:2PP80Ogmo0P22PX8207moO`@0PX:20P25QHD208^;R`80RHV90P28
R8P208^;R`@0S8b<0P2=SHd209>CT`80TI6A0P2CTi<209BDU0@0V9RH0P2GUiL209BDU0L0UiNG102F
UYH209RHV080Vi^K0P2OWil20:2PX080VIVI0P2JVYX209nOW`80WIfM0P2OWil209fMW@@0X:2P0P2N
WYh209bLW080WinO0P2NWYh209bLW080UiNG102BTY82092@T080SXj>0P1mOGd207QhN080MGEe0P1f
MWH207alO0<0PX:20P28R8P208V9R@80Q8B40P1mOGd407alO080N7Qh0P1lO7`208>3P`80R8R80P22
PX8207inOP80NWYj101kNg/O0<SPf0007@38h=P202LW9`808R8R0P0M7Ad201DE5@807alO0P1SHf<2
0:j^[P80Ti>C0P2[Zj/20:NWY`80YZJV0P2YZJT20:f][@@0[:b/0P2b/[850;Ng]`80];Bd0P2b/[82
0:f][@80T92@0P1^KVh204a<C080<30`0P0X:2P202@T90808R8R0P0S8b<202LW9`80;2`/100];Bd2
02h^;P80;Bd]0P0U9BD2024Q8@80?clo0P1GEeL206ATI080IFEU0P1DE5@20492@P80@D510P16ATH2
051@D080Fe]K0P1QHF4306IVIP80KFe]0P1cLg<207EeM@80MWIf0P1jNWX207inOP@0P8200P21PH42
08:2PP80P8200P1oOgl20861P@80Ph>30P24Q8@208F5Q@80QhN70P29RHT208f=S@80Shn?0P2=SHd2
08^;R`80Shn?102BTY84096AT@80TY:B0P2FUYH209VIV@80V9RH1@2FUYH209NGU`@0UYJF0P2HV9P2
09^KV`80WIfM0P2OWil209^KV`80V9RH0P2LW9`40:2PX0H0WinO0P2MWId409bLW080VYZJ0P2GUiL2
09BDU080TI6A0P2?Shl2096AT@80T92@0P20P802071`L080Kfm_0P1cLg<207QhN0<0Ogmo0P26QXH4
08^;R`80R8R80P25QHD208:2PP80Q8B41025QHD208B4Q080RHV90P2;Rh/208B4Q080OGem0P1kNg/Y
0<SPf080:RXZ0P0P820401/K6`807AdM0P1RHV820:RXZ080WIfM0P2ZZZX20:RXZ080YZJV0P2_[jl2
0:VYZ@80[:b/0P2WYjL20;6a/@D0]KFe0P2h^;P20;fm_@80[Jf]0P2<S8`207MgM`80Cdm?0P0g=cL2
02TY:@8092@T100V9RH202LW9`80;2`/0P0Y:BT4034a<@80;bl_0P0V9RH202LW9`80<S8b0P1HF5P2
06UYJ@80Fe]K0P1FEUH203hn?P80>SXj0P17AdL205EEE@80FUYJ0P1PH60306EUI@80KVi^0P1dM7@2
07=cL`80MWIf0P1mOGd207alO080Ogmo0P23Ph<207emO@80Q8B40P20P80207moO`80Ph>30P20P802
08F5Q@80QXJ60P23Ph<208^;R`80T92@0P2>SXh208V9R@@0SHf=0P2GUiL208f=S@80Shn?0P2HV9P2
08n?S`80UYJF0P2IVIT209>CT`<0UiNG0P2EUID409NGU`80U9BD0P2KVi/409bLW080X:2P0P2JVYX2
09NGU`80W9bL0P2QXJ4409nOW`@0WYjN0P2LW9`209^KV`80VYZJ0P2KVi/209JFUP80TI6A0P2BTY82
092@T080Rh^;0P2DU9@20820P080M7Ad0P1/K6`207AdM080O7al0`1mOGd208N7Q`80RXZ:0P27QhL2
08J6QP80QhN70P26QXH208B4Q080QXJ60P2=SHd208V9R@80Q8B40P2;Rh/208B4Q080OWin0P1gMgLY
0<SPf0809RHV0P0Q8B4201lO7`805aLG0P0P820206=SH`80/;2`0P2EUID20:VYZ@80Z:RX0P2WYjL2
0:JVYP80[Zj^0P2][Jd20:RXZ080];Bd0`2i^KT20;6a/@80/k>c0P2^[Zh20:f][@80RXZ:0P1/K6`2
059BDP80=3@d0P0U9BD202XZ:P808b<S0P0R8R8402/[:`80;bl_0P0];Bd202l_;`80;2`/0P0W9bL2
028R8P80?Cdm0P1JFUX206IVIP80J6QX0P1@D5020492@P80?clo0P14A4@2051@D080G5aL0P1OGel3
06IVIP80K6a/0P1bLW8207MgM`@0MWIf0P1oOgl208B4Q080PH610P23Ph<208:2PP80PH61101oOgl6
08>3P`80Rh^;0P28R8P208f=S@80SXj>0P2?Shl208b<S080Rh^;0P2CTi<409:BTP80Shn?0P2BTY82
09NGU`80V9RH0P2IVIT309JFUP80UiNG0P2HV9P209JFUP80UiNG0P2FUYH209^KV`80WIfM0P2NWYh2
09VIV@80V9RH0P2NWYh209nOW`80XJ6Q0P2OWil209jNWP80WinO0P2LW9`209fMW@80Vi^K0P2JVYX2
09FEU@80U9BD0P2?Shl208j>SP80Ti>C0P2@T90207moO`H0LG5a0P1gMgL307inOP80Rh^;0P29RHT2
08f=S@80RXZ:0P23Ph<:08B4Q080R8R80P2;Rh/208B4Q080OWin0P1mOGdO0<SPf0007@38h=P202LW
9`808R8R0P0M7Ad201DE5@807alO0P1SHf<20:j^[P80Ti>C0P2[Zj/20:NWY`80YZJV0P2YZJT20:f]
[@@0[:b/0P2b/[850;Ng]`80];Bd0P2b/[820:f][@80T92@0P1^KVh204a<C080<30`0P0X:2P202@T
90808R8R0P0S8b<202LW9`80;2`/100];Bd202h^;P80;Bd]0P0U9BD2024Q8@80?clo0P1GEeL206AT
I080IFEU0P1DE5@20492@P80@D510P16ATH2051@D080Fe]K0P1QHF4306IVIP80KFe]0P1cLg<207Ee
M@80MWIf0P1jNWX207inOP@0P8200P21PH4208:2PP80P8200P1oOgl20861P@80Ph>30P24Q8@208F5
Q@80QhN70P29RHT208f=S@80Shn?0P2=SHd208^;R`80Shn?102BTY84096AT@80TY:B0P2FUYH209VI
V@80V9RH1@2FUYH209NGU`@0UYJF0P2HV9P209^KV`80WIfM0P2OWil209^KV`80V9RH0P2LW9`40:2P
X0H0WinO0P2MWId409bLW080VYZJ0P2GUiL209BDU080TI6A0P2?Shl2096AT@80T92@0P20P802071`
L080Kfm_0P1cLg<207QhN0<0Ogmo0P26QXH408^;R`80R8R80P25QHD208:2PP80Q8B41025QHD208B4
Q080RHV90P2;Rh/208B4Q080OGem0P1kNg/Y0<SPf080:RXZ0P0P820401/K6`807AdM0P1RHV820:RX
Z080WIfM0P2ZZZX20:RXZ080YZJV0P2_[jl20:VYZ@80[:b/0P2WYjL20;6a/@D0]KFe0P2h^;P20;fm
_@80[Jf]0P2<S8`207MgM`80Cdm?0P0g=cL202TY:@8092@T100V9RH202LW9`80;2`/0P0Y:BT4034a
<@80;bl_0P0V9RH202LW9`80<S8b0P1HF5P206UYJ@80Fe]K0P1FEUH203hn?P80>SXj0P17AdL205EE
E@80FUYJ0P1PH60306EUI@80KVi^0P1dM7@207=cL`80MWIf0P1mOGd207alO080Ogmo0P23Ph<207em
O@80Q8B40P20P80207moO`80Ph>30P20P80208F5Q@80QXJ60P23Ph<208^;R`80T92@0P2>SXh208V9
R@@0SHf=0P2GUiL208f=S@80Shn?0P2HV9P208n?S`80UYJF0P2IVIT209>CT`<0UiNG0P2EUID409NG
U`80U9BD0P2KVi/409bLW080X:2P0P2JVYX209NGU`80W9bL0P2QXJ4409nOW`@0WYjN0P2LW9`209^K
V`80VYZJ0P2KVi/209JFUP80TI6A0P2BTY82092@T080Rh^;0P2DU9@20820P080M7Ad0P1/K6`207Ad
M080O7al0`1mOGd208N7Q`80RXZ:0P27QhL208J6QP80QhN70P26QXH208B4Q080QXJ60P2=SHd208V9
R@80Q8B40P2;Rh/208B4Q080OWin0P1gMgLY0<SPf0809RHV0P0Q8B4201lO7`805aLG0P0P820206=S
H`80/;2`0P2EUID20:VYZ@80Z:RX0P2WYjL20:JVYP80[Zj^0P2][Jd20:RXZ080];Bd0`2i^KT20;6a
/@80/k>c0P2^[Zh20:f][@80RXZ:0P1/K6`2059BDP80=3@d0P0U9BD202XZ:P808b<S0P0R8R8402/[
:`80;bl_0P0];Bd202l_;`80;2`/0P0W9bL2028R8P80?Cdm0P1JFUX206IVIP80J6QX0P1@D5020492
@P80?clo0P14A4@2051@D080G5aL0P1OGel306IVIP80K6a/0P1bLW8207MgM`@0MWIf0P1oOgl208B4
Q080PH610P23Ph<208:2PP80PH61101oOgl608>3P`80Rh^;0P28R8P208f=S@80SXj>0P2?Shl208b<
S080Rh^;0P2CTi<409:BTP80Shn?0P2BTY8209NGU`80V9RH0P2IVIT309JFUP80UiNG0P2HV9P209JF
UP80UiNG0P2FUYH209^KV`80WIfM0P2NWYh209VIV@80V9RH0P2NWYh209nOW`80XJ6Q0P2OWil209jN
WP80WinO0P2LW9`209fMW@80Vi^K0P2JVYX209FEU@80U9BD0P2?Shl208j>SP80Ti>C0P2@T90207mo
O`H0LG5a0P1gMgL307inOP80Rh^;0P29RHT208f=S@80RXZ:0P23Ph<:08B4Q080R8R80P2;Rh/208B4
Q080OWin0P1mOGdO0<SPf0007@38h=P202/[:`809bLW0P0S8b<201PH60807QhN0P13@d<209NGU`80
YJFU0P2XZ:P20:NWY`80YJFU0P2TY:@20:>SX`80WinO0P2KVi/509JFUP80YZJV0P2g]kL20;Rh^080
][Jf0P2ZZZX209JFUP80K6a/0P19BDT2028R8P808b<S0P0P820202@T90809bLW1P0[:b/202`/;080
;Bd]0P0S8b<202PX:080=SHf0P1MGEd206ATI080J6QX0P1GEeL204A4A080@D510P14A4@204i>CP80
FEUI0P1PH60306MWI`80KFe]0P1bLW8207AdM080MWIf0P1kNg/207inOP80Ogmo0P1nOWh20820P080
PX:20P21PH420820P080PH610P23Ph<208B4Q080QXJ60P27QhL208V9R@80S8b<0P2?Shl408j>SP80
Shn?102@T904096AT@80TY:B0P2FUYH209RHV080UiNG0`2FUYH209NGU`80VIVI102JVYX209^KV`80
W9bL102NWYh209fMW@80Vi^K0P2NWYh40:2PX080WinO0P2NWYh209fMW@@0WYjN0P2MWId209ZJVP80
UYJF0P2CTi<2096AT@@0T92@0P2>SXh207moO`80LG5a0P1^KVh206m_K`80MWIf0`1nOWh208F5Q@80
Rh^;0P2<S8`208f=S@80S8b<0P2;Rh/208f=S@P0Shn?0P2=SHd208F5Q@80OGem0P1kNg/Y0<SPf080
:2PX0P0V9RH401dM7@8071`L0P0k>c/20:2PX0@0Xj>S0P2UYJD409nOW`80YZJV0P2/[:`20:6QX@80
WYjN0`2KVi/209nOW`80ZJVY0P2m_Kd20;Zj^P80ZZZZ0P2?Shl205eMG@80@D510P0V9RH2024Q8@80
820P0P0O7al202HV9P80=CDe0P0X:2P202l_;`80:2PX0P0Z:RX202TY:@80:2PX0P0d=3@205]KF`80
JVYZ0P1WIfL205YJFP80AdM70P14A4@203dm?@80De=C0P1HF5P205mOG`<0JFUY0P1`L702079bLP80
M7Ad101fMWH208>3P`80Ng]k0P1oOgl208B4Q080PH61101oOgl408>3P`H0QXJ60P27QhL608f=S@80
T92@0P2=SHd209:BTP80SHf=0P2CTi<2092@T080TI6A0P2DU9@209bLW080UiNG0`2FUYH209RHV080
Vi^K102LW9`209NGU`80W9bL0P2MWId209jNWP80Vi^K0P2NWYh209fMW@80WYjN0P2UYJD409jNWP80
WinO0P2LW9`20::RXP80WIfM0P2JVYX209NGU`80U9BD0P2IVIT208n?S`80TI6A0P2?Shl208>3P`80
MGEe0P1[Jf/2079bLP80N7Qh0`1mOGd208F5Q@80Shn?0P2=SHd208^;R`80RHV90P28R8P208Z:RP80
TY:B0P2=SHd208n?S`80T92@0P2<S8`208>3P`80OWin0P1hN7PY0<SPf080;2`/0P0X:2P201lO7`80
51@D0P0I6AT20451@@80TY:B0P2TY:@20:VYZ@80Y:BT0P2QXJ420:NWY`80XJ6Q0P2MWId209^KV`80
TY:B0`2GUiL20:>SX`80^KVi0P2g]kL20;Rh^080/[:b0P2LW9`206UYJ@80BTY:0P0Q8B4201`L7080
7QhN0P0T92@202<S8`80;bl_0P0`<30202XZ:P80:b/[0P0];Bd202@T90809RHV0P0b<S8205eMG@80
H61P0P1WIfL205YJFP80A4A40P12@T8204M7A`80CTi>0P1LG5`205iNGP<0IfMW0P1]KFd2079bLP80
NWYj0P1fMWH207AdM080OWin0P1oOgl207alO080Ogmo0P21PH4208:2PP80OWin0P22PX8208N7Q`80
QHF50P26QXH208N7Q`80RHV90P2;Rh/2092@T080TI6A0P2>SXh208n?S`80TY:B0P2>SXh6092@T080
U9BD0P2GUiL209RHV0<0UYJF0P2EUID209VIV@80Vi^K0P2IVIT609bLW0@0WYjN0P2JVYX209nOW`80
XJ6Q0P2PX:0209jNWP80XJ6Q0P2LW9`409jNWP80Vi^K0P2LW9`409>CT`@0TI6A102?Shl20861P@80
Kfm_0P1^KVh207=cL`80M7Ad0`1mOGd208J6QP80QhN70P2?Shl208b<S0@0RHV90P2>SXh608n?S`80
T92@0P2=SHd208R8R0@0Ng]k7`38h=P001d0b>3H0P0[:b/202LW9`808b<S0P0H61P201hN7P80@d=3
0P2GUiL20:FUY@80Z:RX0P2WYjL20:FUY@80Y:BT0P2SXj<209nOW`80Vi^K1@2FUYH20:JVYP80]kNg
0P2h^;P20;Jf]P80ZZZZ0P2FUYH206a/K080BDU90P0R8R8202<S8`80820P0P0T92@202LW9`H0:b/[
0P0/;2`202d];@808b<S0P0X:2P203Hf=P80GEeM0P1TI6@206QXJ080EeMG0P14A4@20451@@80A4A4
0P1>CTh205UIF@80H61P0`1WIfL206e]K@80LW9b0P1dM7@207IfMP80Ng]k0P1nOWh207moO`80OWin
0P20P80208:2PP80PH610P20P8020861P@80Ph>30P24Q8@208J6QP80QhN70P29RHT208b<S080Shn?
102>SXh208n?S`@0T92@102ATI4209:BTP80UYJF0P2HV9P209NGU`<0UYJF0P2GUiL209VIV@@0VYZJ
0P2KVi/209bLW0@0WYjN0P2MWId209^KV`80WYjN102PX:0209nOW`80WYjN0P2MWId409jNWP80WIfM
0P2JVYX209JFUP80Ti>C0P2ATI44092@T080SXj>0P1oOgl2075aL@80KVi^0P1_Kfl207IfMP<0OWin
0P25QHD208^;R`80S8b<0P2=SHd208b<S080Rh^;0P2=SHd808n?S`80SHf=0P25QHD207emO@80Ng]k
:@38h=P202PX:0809RHV100M7Ad201`L7080>c/k0P2PX:040:>SX`80YJFU102OWil20:JVYP80[:b/
0P2QXJ4209jNWP<0Vi^K0P2OWil20:VYZ@80_Kfm0P2j^[X20:ZZZP80Shn?0P1MGEd20451@@809RHV
0P0Q8B42020P80807alO0P0V9RH203De=@80:2PX0P0_;bl202PX:080:RXZ0P0Y:BT202PX:080=3@d
0P1KFe/206YZJP80IfMW0P1JFUX204M7A`80A4A40P0m?Cd205=CD`80F5QH0P1OGel306UYJ@80L71`
0P1bLW8207AdM0@0MWIf0P23Ph<207]kN`80Ogmo0P24Q8@20861P@@0Ogmo1023Ph<608J6QP80QhN7
1P2=SHd2092@T080SHf=0P2BTY8208f=S@80Ti>C0P2@T902096AT@80U9BD0P2LW9`209NGU`<0UYJF
0P2HV9P209^KV`@0W9bL0P2GUiL209bLW080WIfM0P2NWYh209^KV`80WYjN0P2MWId209jNWP80YJFU
102NWYh209nOW`80W9bL0P2RXZ8209fMW@80VYZJ0P2GUiL209BDU080VIVI0P2?Shl2096AT@80Shn?
0P23Ph<207EeM@80Jf][0P1bLW8207QhN0<0OGem0P25QHD208n?S`80SHf=0P2;Rh/208V9R@80R8R8
0P2:RXX209:BTP80SHf=0P2?Shl2092@T080S8b<0P23Ph<207inOP80N7Qh:@38h=P202`/;080:2PX
0P0O7al201@D50806ATI0P11@D4209:BTP80Y:BT0P2YZJT20:BTY080XJ6Q0P2WYjL20:6QX@80WIfM
0P2KVi/209:BTP<0UiNG0P2SXj<20;Vi^@80]kNg0P2h^;P20;:b/P80W9bL0P1YJFT204Y:BP808B4Q
0P0L71`201hN7P8092@T0P0S8b<202l_;`80<30`0P0Z:RX202/[:`80;Bd]0P0T92@202HV9P80<S8b
0P1MGEd2061PH080IfMW0P1JFUX204A4A080@T920P17AdL204i>CP80G5aL0P1NGUh306MWI`80KFe]
0P1bLW8207YjNP80MWIf0P1dM7@207inOP80Ogmo0P1lO7`207moO`80PH610P22PX8207inOP80PX:2
0P27QhL208F5Q@80QXJ60P27QhL208V9R@80Rh^;0P2@T902096AT@80SXj>0P2?Shl209:BTP80SXj>
1P2@T90209BDU080UiNG0P2HV9P309JFUP80UIFE0P2IVIT209^KV`80VIVI1P2LW9`409jNWP80VYZJ
0P2OWil20:6QX@80X:2P0P2NWYh20:6QX@80W9bL102NWYh209^KV`80W9bL102CTi<4096AT@@0Shn?
0P21PH4206m_K`80KVi^0P1cLg<207AdM0<0OGem0P26QXH208N7Q`80Shn?0P2<S8`408V9R@80SXj>
1P2?Shl2092@T080SHf=0P28R8P407]kNal0b>3H000M0<SPf080;2`/0P0[:b/202TY:@807QhN0P0P
820202XZ:P80MgMg0P2a/K420:2PX080YJFU0P2QXJ4209bLW080UYJF0P2?Shl208N7Q`80OGem0`1e
MGD207MgM`80PH610P2LW9`20;Jf]P80_;bl0P2c/k<208b<S080I6AT0P0Q8B4202DU9@807alO0P0T
92@202LW9`80:RXZ0P0Y:BT202PX:080:RXZ0P0_;bl201dM7@80<C4a0P0Z:RX2069RHP80IfMW0P1X
J6P205QHF080AdM70P13@d<204E5A@80CDe=0P1HF5P205mOG`<0IVIV0P1/K6`2075aL@80M7Ad0P1g
MgL207]kN`80OWin0P1mOGd207alO080Ogmo1P21PH4208:2PP80Ph>30P25QHD208N7Q`80R8R80P29
RHT208^;R`80SXj>102@T90208n?S`80SXj>0P2?Shl2096AT@80Ti>C0P2DU9@209JFUP@0UiNG0`2F
UYH209RHV080Vi^K0P2MWId609jNWP80WIfM102NWYh209nOW`P0X:2P0P2NWYh209fMW@80WinO0P2Q
XJ4209jNWP80VYZJ0P2FUYH209:BTP80TI6A0P2?Shl208j>SP80RXZ:0P1oOgl207AdM080KVi^0P1]
KFd207EeM@<0OWin0P24Q8@208V9R@80SHf=0P2>SXh208^;R`80R8R80P2:RXX208f=S@@0Shn?0P2>
SXh208Z:RP80Ph>30P1lO7`207]kNbT0b>3H0P0V9RH2034a<@809bLW0P0P8202024Q8@80:RXZ0P1h
N7P20:VYZ@80XJ6Q0P2VYZH20:BTY080VIVI0P2FUYH209:BTP80PH610P20P80307EeM@80MgMg0P22
PX820:6QX@80Zj^[0P2m_Kd20;6a/@80TI6A0P1UIFD2034a<@H092@T0P0X:2P202HV9P80<S8b0P0W
9bL202<S8`809bLW0P0X:2P202DU9@80;2`/0P1MGEd2075aL@80Hf=S0P1IFET204=3@`80ADE50P1:
BTX204a<C080G5aL0P1JFUX306UYJ@80KFe]0P1_Kfl207AdM080N7Qh0P1kNg/20820P080N7Qh0P1m
OGd207moO`80PX:20P20P8020861P@80QHF50P21PH4208>3P`80R8R80P27QhL208V9R@80S8b<0P2;
Rh/209:BTP80Shn?102@T90408n?S`80Ti>C0P2EUID409NGU`80UYJF0`2IVIT209FEU@80V9RH0P2Q
XJ4209^KV`80WIfM0P2OWil209bLW0X0WinO0P2RXZ8209nOW`80WYjN0P2OWil209fMW@80XJ6Q0P2N
WYh209ZJVP80UIFE102BTY82092@T080Rh^;0P2<S8`207inOP80N7Qh0P1XJ6P2071`L080MWIf0`1m
OGd408J6QP@0SHf=0P2>SXh208V9R@80S8b<0P2=SHd208b<S080T92@0P2>SXh208Z:RP80PX:20P1l
O7`207UiNBT0b>3H0P0W9bL202`/;080:b/[100M7Ad2034a<@80MgMg0P2_[jl209jNWP80YJFU0P2R
XZ820:6QX@80UIFE0P2=SHd208R8R080PX:21@1fMWH208:2PP80VYZJ0P2e]KD20;fm_@80/K6a0P2;
Rh/206EUI@807alO0P0T92@2028R8PH09RHV0P0_;bl2024Q8@80;2`/0P0[:b/2028R8P80<C4a0P0W
9bL206EUI@80IVIV0P1XJ6P205YJFP80ATI60P12@T8204I6AP80Bd];0P1KFe/205aLG0D0JVYZ0P1a
LG4207IfMP80N7Qh0P1iNGT20820P080Ogmo101nOWh208:2PP80PH610P20P80207inOP80PX:21028
R8P208F5Q@80RXZ:0P2<S8`208f=S@80SXj>0P2@T90208n?S`@0SXj>0P2BTY82096AT@80UIFE0P2H
V9P209NGU`80V9RH0`2EUID409VIV@P0WYjN0P2KVi/209bLW080XJ6Q0P2NWYh20:6QX@80WinO0P2P
X:0209nOW`80WIfM0P2LW9`209jNWP80X:2P0P2MWId209VIV@80UYJF102BTY82096AT@80RXZ:0P2<
S8`207moO`80M7Ad101^KVh207IfMP<0Ogmo0P23Ph<208V9R@80Shn?0P2@T90608Z:RP80Shn?102@
T90208b<S080R8R80P27QhL207YjNP80O7al7`38h=P001d0b>3H0P0/;2`202/[:`80:BTY0P0N7Qh2
020P8080:RXZ0P1gMgL20;6a/@80X:2P0P2UYJD20:6QX@80W9bL0P2FUYH208n?S`80QhN70P1mOGd3
07EeM@80MgMg0P21PH4209bLW080][Jf0P2l_;`20;>c/`80S8b<0P1TI6@2024Q8@809BDU0P0O7al2
02@T90809bLW0P0Z:RX202TY:@80:2PX0P0Z:RX202l_;`807AdM0P0a<C4202XZ:P80HV9R0P1WIfL2
06QXJ080F5QH0P17AdL204=3@`80ADE50P1=CDd205QHF080GemO0`1VIVH206a/K080LG5a0P1dM7@2
07MgM`80Ng]k0P1nOWh207emO@80O7al0P1oOgl60861P@80PX:20P23Ph<208F5Q@80QhN70P28R8P2
08V9R@80Rh^;0P2>SXh4092@T080Shn?0P2>SXh208n?S`80TI6A0P2CTi<209BDU080UYJF102GUiL3
09JFUP80V9RH0P2KVi/209fMW@H0WYjN0P2MWId409jNWP80WinO202PX:0209jNWP80WIfM0P2OWil2
0:6QX@80WYjN0P2JVYX209JFUP80TY:B0P2ATI4208n?S`80SXj>0P2:RXX207moO`80M7Ad0P1^KVh2
06e]K@80MGEe0`1nOWh208B4Q080RHV90P2=SHd208j>SP80Rh^;0P28R8P208Z:RP80SHf=102?Shl2
08j>SP80RXZ:0P23Ph<207alO080Ng]k:@38h=P202HV9P80<C4a0P0W9bL2020P80808B4Q0P0Z:RX2
07QhN080ZJVY0P2QXJ420:JVYP80Y:BT0P2IVIT209JFUP80TY:B0P21PH420820P0<0MGEe0P1gMgL2
08:2PP80XJ6Q0P2[Zj/20;fm_@80/K6a0P2ATI4206EUI@80<C4a1P0T92@202PX:0809RHV0P0b<S82
02LW9`808b<S0P0W9bL202PX:0809BDU0P0/;2`205eMG@80LG5a0P1SHf<205UIF@80@d=30P15ADD2
04Y:BP80C4a<0P1LG5`205YJFP<0JFUY0P1]KFd206m_K`80M7Ad0P1hN7P207]kN`80P8200P1hN7P2
07emO@80Ogmo0P22PX820820P080PH610P25QHD20861P@80Ph>30P28R8P208N7Q`80RHV90P2<S8`2
08^;R`80TY:B0P2?Shl4092@T0@0Shn?0P2CTi<209FEU@@0UiNG0P2FUYH309VIV@80UIFE0P2HV9P2
0:6QX@80Vi^K0P2MWId209nOW`80W9bL2P2OWil20::RXP80WinO0P2NWYh209nOW`80WIfM0P2QXJ42
09jNWP80VYZJ0P2EUID409:BTP80T92@0P2;Rh/208b<S080OWin0P1hN7P206QXJ080L71`0P1fMWH3
07emO@@0QXJ6102=SHd208j>SP80RHV90P2<S8`208f=S@80S8b<0P2@T90208j>SP80RXZ:0P22PX82
07alO080NGUi:@38h=P202LW9`80;2`/0P0[:b/401dM7@80<C4a0P1gMgL20:n_[`80WYjN0P2UYJD2
0::RXP80XJ6Q0P2EUID208f=S@80R8R80P22PX8507IfMP80PX:20P2JVYX20;Fe]@80_Kfm0P2a/K42
08^;R`80IFEU0P0O7al202@T90808R8R1P0V9RH202l_;`808B4Q0P0/;2`202/[:`808R8R0P0a<C42
02LW9`80IFEU0P1VIVH206QXJ080FUYJ0P16ATH20492@P80ATI60P1;Bd/205]KF`80G5aL1@1ZJVX2
075aL@80MWIf0P1hN7P207UiN@80P8200P1oOgl407inOP80PX:20P21PH420820P080OWin0P22PX84
08R8R080QHF50P2:RXX208b<S080SHf=0P2>SXh2092@T080Shn?102>SXh209:BTP80TI6A0P2EUID2
09RHV080UiNG0P2HV9P309FEU@@0VIVI202NWYh209^KV`80W9bL0P2QXJ4209jNWP80XJ6Q0P2OWil2
0:2PX080WinO0P2MWId209bLW080WYjN0P2PX:0209fMW@80VIVI0P2FUYH409:BTP80TI6A0P2:RXX2
08b<S080Ogmo0P1dM7@406i^KP80MWIf0`1oOgl208>3P`80RHV90P2?Shl2092@T0H0RXZ:0P2?Shl4
092@T080S8b<0P28R8P208N7Q`80NWYj0P1lO7`O0<SPf0007@38h=P202HV9P80:BTY0P0/;2`202<S
8`@0820P0P1:BTX208>3P`80TY:B0P2EUID209:BTP80S8b<0P24Q8@207]kN`80Lg=c0P1^KVh306e]
K@80MGEe0P1oOgl208B4Q080SXj>0P2LW9`20::RXP80X:2P0P1eMGD203Hf=P80=cLg0P0X:2P402<S
8`809bLW100Y:BT202HV9P80820P0P0n?Sh2028R8P808b<S0P1NGUh2079bLP80G5aL0P1@D50204=3
@`80A4A40P19BDT204m?C`80EUIF0P1MGEd306ATI080Jf][0P1bLW8207AdM080MGEe0P1iNGT607em
O@80Ogmo0P21PH440820P080PX:20P24Q8@208J6QP80QhN70P29RHT208^;R`80S8b<0P2=SHd2092@
T080TY:B0P2@T90208n?S`80TI6A0P2CTi<209FEU@80UiNG102HV9P509NGU`80V9RH0P2JVYX209^K
V`@0W9bL1P2MWId209jNWP80WinO302PX:040:6QX@80WIfM0P2IVIT209NGU`80UIFE0P2ATI4408f=
S@80Rh^;0P20P80207AdM080Kfm_0P1]KFd207AdM0<0O7al0P23Ph<208R8R080Rh^;0P2<S8`208Z:
RP80RHV90P2;Rh/408j>SP80SHf=0P29RHT208F5Q@80PH610P1mOGd207alO2T0b>3H0P0U9BD2030`
<080;2`/0P0Q8B42028R8P809BDU0P17AdL208b<S080V9RH0P2JVYX209JFUP80R8R80P21PH4207If
MP80Jf][0P1]KFd306ATI080MWIf0P23Ph<208N7Q`80TY:B0P2RXZ820:f][@80W9bL0P1^KVh203Lg
=`80:BTY0P0U9BD202HV9P@08b<S0P0W9bL202h^;P8092@T0P0_;bl204I6AP809BDU0P0^;Rh205MG
E`80LG5a0P1KFe/204i>CP80ATI60P13@d<204A4A080CTi>0P1IFET205MGE`<0Hf=S0P1[Jf/207If
MP80LW9b0P1gMgL207YjNP80Ng]k0P22PX8207inOP80O7al0P22PX8207moO`80P8200P22PX8608J6
QP80S8b<0P28R8P208n?S`80SXj>102ATI4208f=S@80SXj>0P2?Shl209>CT`80W9bL0P2CTi<209VI
V@@0UYJF0`2EUID209NGU`80VYZJ0P2MWId209bLW080WinO0P2LW9`209nOW`80W9bL0P2MWId409jN
WP80X:2P0P2RXZ8209jNWP80WinO0P2MWId409nOW`80WIfM0P2JVYX209:BTP80Ti>C0P2>SXh208^;
R`80SHf=0P2:RXX207emO@80M7Ad0P1[Jf/206e]K@80M7Ad0`1mOGd208>3P`80QhN70P2:RXX208f=
S@80Rh^;0P28R8P208^;R`80T92@0P2=SHd208n?S`80R8R80P26QXH40820P080OGem:@38h=P202`/
;080:BTY0P0[:b/202HV9P8092@T0P0W9bL204U9B@80QhN70P2GUiL209:BTP@0SXj>0P23Ph<207Yj
NP80MGEe0P1VIVH5075aL@80PH610P23Ph<208j>SP80UiNG0P2NWYh20:BTY080LW9b0P0l?3`203dm
?@80:RXZ0P0Q8B42020P80809RHV0P0^;Rh202`/;0809BDU0P0P820204A4A08092@T0P0S8b<2061P
H080M7Ad0P1LG5`2055AD@80@d=30P12@T8204Y:BP80Bd];0P1GEeL205aLG0<0Hf=S0P1/K6`2071`
L0@0MGEe0P1fMWH407emO@80NWYj0P20P80207inOP80PH611026QXH20820P080R8R80P25QHD408Z:
RP80Rh^;0P2=SHd2092@T080TI6A0P2CTi<208j>SP80TY:B0P2DU9@209JFUP80V9RH0P2IVIT209RH
V080UiNG0`2FUYH609^KV`80VYZJ0P2OWil409fMW@80WYjN0P2PX:0209fMW@80WYjN0P2QXJ420:2P
X080XJ6Q0P2TY:@20:6QX@80Xj>S0P2RXZ8209jNWP80VYZJ0P2KVi/209BDU080TY:B102<S8`208V9
R@80Q8B40P1fMWH206a/K080JVYZ0P1cLg<307inOP80P8200P2:RXX208^;R`@0RHV9102:RXX208^;
R`80SXj>0P2;Rh/208R8R080Q8B40P20P80207]kN`80OWin7`38h=P001d0b>3H0P0V9RH202TY:@80
;2`/0P0S8b<4020P8080BTY:0P23Ph<209:BTP80UIFE0P2BTY8208b<S080Q8B40P1kNg/207=cL`80
KVi^0`1]KFd207EeM@80Ogmo0P24Q8@208j>SP80W9bL0P2RXZ820:2PX080MGEe0P0f=SH203Lg=`80
:2PX100S8b<202LW9`@0:BTY0P0V9RH2020P8080?Shn0P0R8R8202<S8`80GUiN0P1bLW8205aLG080
D51@0P13@d<204A4A080BDU90P1?Cdl205IFEP80GEeM0`1TI6@206][J`80LW9b0P1dM7@207EeM@80
NGUi1P1mOGd207moO`80PH611020P80208:2PP80Q8B40P26QXH208N7Q`80RHV90P2;Rh/208b<S080
SHf=0P2@T90209:BTP80T92@0P2?Shl2096AT@80Ti>C0P2EUID209NGU`@0V9RH1@2GUiL209RHV080
VYZJ0P2KVi/409bLW0H0WIfM0P2NWYh209nOW``0X:2P102QXJ4209fMW@80VIVI0P2GUiL209FEU@80
TI6A102=SHd208^;R`80P8200P1dM7@206m_K`80KFe]0P1dM7@307alO080Ph>30P28R8P208^;R`80
S8b<0P2:RXX208V9R@80Rh^;102>SXh208f=S@80RHV90P25QHD20861P@80OGem0P1lO7`Y0<SPf080
9BDU0P0`<30202`/;0808B4Q0P0R8R8202DU9@80AdM70P2<S8`209RHV080VYZJ0P2FUYH208R8R080
PH610P1fMWH206][J`80KFe]0`1TI6@207IfMP80Ph>30P27QhL209:BTP80XZ:R0P2][Jd209bLW080
KVi^0P0g=cL202TY:@809BDU0P0V9RH402<S8`809bLW0P0^;Rh202@T9080;bl_0P16ATH202DU9@80
;Rh^0P1GEeL2075aL@80Fe]K0P1>CTh204I6AP80@d=30P14A4@204i>CP80FEUI0P1GEeL306=SH`80
Jf][0P1fMWH2079bLP80MgMg0P1jNWX207]kN`80PX:20P1nOWh207alO080PX:20P1oOgl20820P080
PX:21P26QXH208b<S080R8R80P2?Shl208j>SP@0TI6A0P2=SHd208j>SP80Shn?0P2CTi<209bLW080
Ti>C0P2IVIT409JFUP<0UIFE0P2GUiL209ZJVP80WIfM0P2LW9`209nOW`80W9bL0P2OWil209bLW080
WIfM102NWYh20:2PX080XZ:R0P2NWYh209nOW`80WIfM102OWil209fMW@80VYZJ0P2BTY8209>CT`80
SXj>0P2;Rh/208f=S@80RXZ:0P1mOGd207AdM080Jf][0P1]KFd207AdM0<0OGem0P23Ph<208N7Q`80
RXZ:0P2=SHd208^;R`80R8R80P2;Rh/2092@T080SHf=0P2?Shl208R8R080QXJ61020P80207emOBT0
b>3H0P0/;2`202TY:@80:b/[0P0V9RH202@T90809bLW0P19BDT208N7Q`80UiNG0P2BTY8408j>SP80
Ph>30P1jNWX207EeM@80IVIV1@1aLG420861P@80Ph>30P2>SXh209NGU`80WYjN0P2TY:@2079bLP80
?3`l0P0m?Cd202XZ:P808B4Q0P0P820202HV9P80;Rh^0P0/;2`202DU9@80820P0P14A4@202@T9080
8b<S0P1PH60207AdM080G5aL0P1ADE4204=3@`80@T920P1:BTX204];B`80EeMG0P1LG5`306=SH`80
K6a/0P1`L70407EeM@80MWIf101mOGd207YjNP80P8200P1nOWh20861P@@0QXJ60P20P80208R8R080
QHF5102:RXX208^;R`80SHf=0P2@T902096AT@80Ti>C0P2>SXh209:BTP80U9BD0P2FUYH209RHV080
VIVI0P2HV9P209NGU`<0UYJF1P2KVi/209ZJVP80WinO102MWId209jNWP80X:2P0P2MWId209jNWP80
XJ6Q0P2PX:020:6QX@80Y:BT0P2QXJ420:>SX`80XZ:R0P2NWYh209ZJVP80Vi^K0P2DU9@209:BTP@0
S8b<0P29RHT208B4Q080MWIf0P1/K6`206YZJP80Lg=c0`1nOWh20820P080RXZ:0P2;Rh/408V9R@@0
RXZ:0P2;Rh/208j>SP80Rh^;0P28R8P208B4Q080P8200P1kNg/207inOQl0b>3H000M0<SPf0807alO
0P0W9bL202h^;P80:2PX0P0R8R8201hN7P808b<S0P1>CTh207alO080P8200P1mOGd207alO080MgMg
0P1/K6`206ATI080HV9R0`1[Jf/209BDU080^[Zj0P2d];@20:FUY@80VYZJ0P2=SHd20:^[Z`80QhN7
0P1?Cdl204Y:BP80<30`0P0Q8B42020P80809BDU0P0V9RH202PX:080:b/[0P0_;bl201`L7080;bl_
0P0W9bL205MGE`80MWIf0P1ADE4204Q8B080?Shn0P14A4@204e=C@80DE5A0P1EEED205]KF`<0HF5Q
0P1ZJVX2079bLP@0M7Ad0P1hN7P207alO080OGem0P1nOWh207moO`@0P8200P1oOgl208>3P`@0QXJ6
0P27QhL208Z:RPH0S8b<0P2?Shl209:BTP@0TI6A0P2CTi<209FEU@80UiNG0P2IVIT209ZJVP80VIVI
0P2HV9P309NGU`80V9RH0P2JVYX409VIV@80VYZJ0P2LW9`209fMW@@0WYjN102OWil20:2PX0@0XJ6Q
0P2RXZ820:>SX`80XZ:R0P2PX:0209bLW080VIVI102HV9P209:BTP80S8b<0P2=SHd208b<S080PH61
0P1fMWH2071`L080Kfm_0P1dM7@307YjNP80P8200P25QHD808R8R080RXZ:0P2<S8`208Z:RP80QhN7
0P23Ph<20820P0@0OWin0P1mOGdY0<SPf0@092@T0P0b<S8202HV9P808R8R0P0N7Qh2028R8P80C4a<
0P1hN7P208>3P`80N7Qh101jNWX206MWI`80IFEU1@1/K6`2092@T080]KFe0P2][Jd20:>SX`80SHf=
0P2@T90209ZJVP80QhN70P1JFUX204E5A@80;Bd]0P0S8b<2028R8P80:b/[0P0U9BD202/[:`@0:2PX
0P0R8R8202<S8`80;Rh^0P1JFUX206e]K@80FUYJ0P13@d<20410@080Bd];0P1>CTh2055AD@80De=C
1@1OGel206YZJP80M7Ad0P1aLG4407IfMP80OGem0P1oOgl207emO@80O7al0P22PX8207emO@80PH61
0P23Ph<208J6QP80QHF50P27QhL208^;R`80SHf=0P2:RXX208^;R`80Shn?0P2DU9@209>CT`80U9BD
0P2?Shl209>CT`80Vi^K102GUiL209ZJVP80V9RH0`2FUYH409ZJVP80UYJF0P2IVIT209bLW080VYZJ
0P2OWil209VIV@80XZ:R0P2OWil209bLW080XJ6Q0P2OWil20::RXP80Y:BT0P2SXj<40:6QX@80Vi^K
0P2IVIT209RHV080VIVI0P2BTY8208b<S080Rh^;0P2?Shl207moO`80MgMg0P1bLW8206i^KP80Lg=c
0`1lO7`20820P080QhN70P26QXH208^;R`80R8R80P2:RXX208V9R@80Rh^;0P2?Shl408B4Q080PH61
0P1lO7`207emO@80Ogmo:@38h=P201lO7`809RHV0P0/;2`202TY:@807alO0P0I6AT202@T9080DE5A
0P1eMGD208B4Q080Ng]k0P1oOgl207EeM@80K6a/0P1YJFT205aLG0<0KVi^0P2IVIT20;^k^`80[jn_
0P2YZJT209fMW@80RXZ:0P2a/K4208>3P`80D51@0P16ATH202/[:`808B4Q0P0V9RH201lO7`80:RXZ
0P0U9BD202LW9`80<C4a0P0L71`202l_;`809BDU0P1HF5P207MgM`80CTi>0P1<C4`203dm?@80@d=3
0P1<C4`2051@D080EEEE0P1NGUh3065QH@80J6QX0P1`L70207MgM`80M7Ad0P1jNWX207UiN@80P820
0P1lO7`20820P080PX:20P1nOWh207alO080QHF50P23Ph<408J6QP80S8b<0P2>SXh208^;R`80S8b<
0P2@T902096AT@@0T92@0P2EUID209:BTP80V9RH0P2JVYX209RHV080Vi^K0P2EUID309NGU`80V9RH
1P2IVIT209ZJVP80W9bL102MWId20:2PX080WYjN0P2PX:020:6QX@80X:2P0P2OWil20:BTY080XZ:R
102PX:0209fMW@80V9RH0P2IVIT209JFUP80TY:B0P2;Rh/208n?S`80SHf=0P1oOgl207EeM@80LG5a
0P1`L70207IfMP<0Ng]k0P1lO7`408N7Q`80Rh^;1P28R8P208j>SP80Rh^;0P28R8P208>3P`80Ogmo
0P1nOWh207emO@80OWin7`38h=P001d0b>3H0P0O7al202LW9`80;Rh^0P0X:2P2028R8P807QhN0P0S
8b<204i>CP80O7al0P20P80207emO@80O7al0P1gMgL206a/K080I6AT0P1RHV8306][J`80U9BD0P2j
^[X20;Bd]080YJFU0P2JVYX208f=S@80Zj^[0P27QhL204m?C`80BTY:0P0`<302024Q8@80820P0P0U
9BD202HV9P80:2PX0P0[:b/202l_;`8071`L0P0_;bl202LW9`80EeMG0P1fMWH2055AD@80B4Q80P0n
?Sh204A4A080CDe=0P1ADE4205EEE@80Fe]K0`1QHF4206YZJP80LW9b101dM7@207QhN080O7al0P1m
OGd207inOP80Ogmo1020P80207moO`80Ph>31026QXH208N7Q`80RXZ:1P2<S8`208n?S`80TY:B102A
TI4209>CT`80UIFE0P2GUiL209VIV@80VYZJ0P2IVIT209RHV0<0UiNG0P2HV9P209ZJVP@0VIVI0P2J
VYX209bLW080WIfM102NWYh409nOW`80X:2P102QXJ420::RXP80Xj>S0P2RXZ820:2PX080W9bL0P2I
VIT409RHV080TY:B0P2<S8`208f=S@80S8b<0P21PH4207IfMP80L71`0P1_Kfl207AdM0<0NWYj0P20
P80208F5Q@P0R8R80P2:RXX208b<S080RXZ:0P27QhL208>3P`80P820101nOWh207emOBT0b>3H100T
92@2038b<P809RHV0P0R8R8201hN7P808R8R0P1<C4`207QhN080Ph>30P1hN7P407YjNP80IfMW0P1U
IFD506a/K080T92@0P2e]KD20:f][@80Xj>S0P2=SHd2092@T080VYZJ0P27QhL205YJFP80ADE50P0]
;Bd202<S8`808R8R0P0[:b/202DU9@80:b/[100X:2P2028R8P808b<S0P0^;Rh205YJFP80KFe]0P1J
FUX204=3@`80@4100P1;Bd/204i>CP80DE5A0P1CDe<505mOG`80JVYZ0P1dM7@2075aL@@0MWIf0P1m
OGd207moO`80OGem0P1lO7`208:2PP80OGem0P21PH4208>3P`80QXJ60P25QHD208N7Q`80Rh^;0P2=
SHd208Z:RP80Rh^;0P2?Shl209BDU080Ti>C0P2DU9@208n?S`80Ti>C0P2KVi/409NGU`80VYZJ0P2H
V9P309JFUP@0VYZJ0P2FUYH209VIV@80W9bL0P2JVYX209nOW`80VIVI0P2RXZ8209nOW`80W9bL0P2Q
XJ4209nOW`80XZ:R0P2TY:@20:>SX`@0XJ6Q0P2KVi/209VIV@80V9RH0P2IVIT209:BTP80S8b<0P2;
Rh/208n?S`80Ogmo0P1gMgL2079bLP80KVi^0P1cLg<307alO080P8200P27QhL208J6QP80Rh^;0P28
R8P208Z:RP80RHV90P2;Rh/208n?S`@0Q8B40P21PH4207alO080OGem0P1oOglY0<SPf0807alO0P0V
9RH202`/;080:BTY0P0O7al201TI6@8092@T0P1ADE4207EeM@80Q8B40P1kNg/207moO`80MGEe0P1/
K6`206UYJ@80G5aL0`1^KVh209VIV@80^k^k0P2_[jl20:VYZ@80WIfM0P2:RXX20;6a/@80Ph>30P1@
D50204I6AP80:b/[0P0Q8B4202HV9P807alO0P0Z:RX202DU9@809bLW0P0a<C4201`L7080;bl_0P0U
9BD205QHF080MgMg0P1>CTh204a<C080?Cdm0P13@d<204a<C080D51@0P1EEED205iNGP<0HF5Q0P1X
J6P2071`L080MgMg0P1dM7@207YjNP80NGUi0P20P80207alO080P8200P22PX8207inOP80O7al0P25
QHD208>3P`@0QXJ60P2<S8`208j>SP80Rh^;0P2<S8`2092@T080TI6A102@T90209FEU@80TY:B0P2H
V9P209ZJVP80V9RH0P2KVi/209FEU@<0UiNG0P2HV9P609VIV@80VYZJ0P2LW9`409fMW@80X:2P0P2N
WYh20:2PX080XJ6Q0P2PX:0209nOW`80Y:BT0P2RXZ840:2PX080WIfM0P2HV9P209VIV@80UYJF0P2B
TY8208^;R`80Shn?0P2=SHd207moO`80MGEe0P1aLG42071`L080MWIf0`1kNg/207alO0@0QhN70P2;
Rh/608R8R080SXj>0P2;Rh/208R8R080Ph>30P1oOgl207inOP80OGem0P1nOWhO0<SPf0007@38h=P2
02<S8`80:BTY0P0_;bl202d];@80:BTY0P0Q8B4201XJ6P80<S8b0P1@D50206a/K080HV9R0P1cLg<2
07inOP80LW9b101ZJVX307=cL`80TI6A0P2][Jd20<[:bP80]kNg0P2NWYh207inOP80SHf=0P1iNGT2
02PX:08071`L0P0I6AT202<S8`8092@T1P0V9RH202TY:@80;2`/0P0S8b<202/[:`80:2PX0P1LG5`2
06e]K@80EUIF0P18B4P203/k>`80@T920P1=CDd2055AD@80EEEE0P1KFe/3069RHP80JFUY0P1`L702
079bLP80M7Ad0P1hN7P207]kN`80OGem0P1nOWh20820P0@0PH610P22PX8208B4Q080QXJ61027QhL4
08R8R080RHV90P2;Rh/208j>SP80TY:B102CTi<209BDU080UIFE0P2GUiL409VIV@80V9RH0P2GUiL3
09JFUP80V9RH0P2IVIT409ZJVP80W9bL102OWil60:2PX080XJ6Q1P2RXZ820:>SX`80Y:BT0P2RXZ82
09nOW`80WIfM0P2JVYX209RHV080UYJF0P2BTY8208j>SP80Shn?0P2>SXh208J6QP80O7al0P1fMWH2
079bLP80M7Ad0`1hN7P207inOP80Ph>30P26QXH208N7Q`@0R8R80P27QhL208J6QP80Ph>30P21PH42
07inOP@0O7al101mOGdY0<SPf0@08b<S0P0`<30202l_;`80:b/[0P0N7Qh202<S8`80:2PX0P1ADE42
06EUI@80IfMW0P1nOWh208F5Q@80JVYZ0P1^KVh5079bLP80T92@0P2i^KT20<W9b@80`l?30P2VYZH2
08:2PP80UiNG0P1mOGd203@d=08092@T0P0S8b<201lO7`807QhN0P0S8b<202TY:@809BDU0P0R8R82
02XZ:P809BDU0P0Y:BT202XZ:P80G5aL0P1/K6`205aLG080@D510P0h>3P204M7A`80B4Q80P1?Cdl2
05IFEP80GEeM0`1WIfL206QXJ080K6a/0P1cLg<407EeM@80NGUi0P1mOGd207moO`80P8200P24Q8@2
08:2PP80Ph>30P22PX8208N7Q`80QHF50P28R8P208J6QP80QhN70P2<S8`208^;R`80SHf=0P2@T902
096AT@@0Ti>C0P2EUID209ZJVP80Vi^K0P2IVIT409RHV0<0UiNG0P2IVIT209ZJVP80UYJF0P2JVYX2
09fMW@80WYjN0P2MWId20::RXP80Xj>S0P2OWil20::RXP80YZJV0P2NWYh20::RXP@0Y:BT0P2SXj<2
0:6QX@80WIfM0P2LW9`409RHV080UYJF0P2ATI42092@T080SXj>0P25QHD207alO080NGUi0P1eMGD2
079bLP<0MWIf0P1lO7`208B4Q080QHF50P23Ph<208N7Q`80QXJ60P24Q8@208>3P`80PX:20P1oOgl2
08B4Q080NGUi101kNg/20861PBT0b>3H0P0I6AT2030`<0@0;bl_0P0Y:BT2020P80806ATI0P0[:b/2
055AD@80LW9b0P1PH60207EeM@80OWin0P1dM7@206QXJ080Jf][0`1dM7@208^;R`80[jn_0P38b<P2
0;Jf]P80WYjN0P1nOWh209BDU080Kfm_0P0b<S8201`L708051@D0P0X:2P202<S8`80:2PX0P0V9RH2
02DU9@80:BTY0P0/;2`2024Q8@80;2`/0P0V9RH205YJFP80KFe]0P1GEeL204Q8B080>CTi0P14A4@2
04i>CP80E5AD0P1CDe<205eMG@<0H61P0P1YJFT2071`L080M7Ad0P1aLG4207MgM`80Ng]k0P20P802
07inOP80Ogmo0P22PX8207emO@80Ph>30P25QHD208V9R@80QhN71028R8P208J6QP80RXZ:0P2<S8`2
08j>SP80Ti>C0P2DU9@209:BTP80UIFE0P2DU9@209RHV080UiNG0P2JVYX209JFUP80UiNG0`2FUYH2
09NGU`80VIVI0P2LW9`209ZJVP80W9bL0P2NWYh209nOW`80WYjN102PX:0209nOW`80XJ6Q102RXZ84
0:>SX`80XZ:R0P2PX:0209^KV`80VIVI102GUiL209BDU080Shn?0P2<S8`208j>SP80QHF50P1lO7`2
07IfMP80LW9b0P1eMGD307UiN@80Ng]k0P26QXH208F5Q@80QhN70P26QXH208R8R080RHV90P26QXH4
08:2PP80P8200P1oOgl207]kN`80PH610P1jNWXO0<SPf0007@38h=P202<S8`80:BTY0P0_;bl202d]
;@80:BTY0P0Q8B4201XJ6P80<S8b0P1@D50206a/K080HV9R0P1cLg<207inOP80LW9b101ZJVX307=c
L`80TI6A0P2][Jd20<[:bP80]kNg0P2NWYh207inOP80SHf=0P1iNGT202PX:08071`L0P0I6AT202<S
8`8092@T1P0V9RH202TY:@80;2`/0P0S8b<202/[:`80:2PX0P1LG5`206e]K@80EUIF0P18B4P203/k
>`80@T920P1=CDd2055AD@80EEEE0P1KFe/3069RHP80JFUY0P1`L702079bLP80M7Ad0P1hN7P207]k
N`80OGem0P1nOWh20820P0@0PH610P22PX8208B4Q080QXJ61027QhL408R8R080RHV90P2;Rh/208j>
SP80TY:B102CTi<209BDU080UIFE0P2GUiL409VIV@80V9RH0P2GUiL309JFUP80V9RH0P2IVIT409ZJ
VP80W9bL102OWil60:2PX080XJ6Q1P2RXZ820:>SX`80Y:BT0P2RXZ8209nOW`80WIfM0P2JVYX209RH
V080UYJF0P2BTY8208j>SP80Shn?0P2>SXh208J6QP80O7al0P1fMWH2079bLP80M7Ad0`1hN7P207in
OP80Ph>30P26QXH208N7Q`@0R8R80P27QhL208J6QP80Ph>30P21PH4207inOP@0O7al101mOGdY0<SP
f0@08b<S0P0`<30202l_;`80:b/[0P0N7Qh202<S8`80:2PX0P1ADE4206EUI@80IfMW0P1nOWh208F5
Q@80JVYZ0P1^KVh5079bLP80T92@0P2i^KT20<W9b@80`l?30P2VYZH208:2PP80UiNG0P1mOGd203@d
=08092@T0P0S8b<201lO7`807QhN0P0S8b<202TY:@809BDU0P0R8R8202XZ:P809BDU0P0Y:BT202XZ
:P80G5aL0P1/K6`205aLG080@D510P0h>3P204M7A`80B4Q80P1?Cdl205IFEP80GEeM0`1WIfL206QX
J080K6a/0P1cLg<407EeM@80NGUi0P1mOGd207moO`80P8200P24Q8@208:2PP80Ph>30P22PX8208N7
Q`80QHF50P28R8P208J6QP80QhN70P2<S8`208^;R`80SHf=0P2@T902096AT@@0Ti>C0P2EUID209ZJ
VP80Vi^K0P2IVIT409RHV0<0UiNG0P2IVIT209ZJVP80UYJF0P2JVYX209fMW@80WYjN0P2MWId20::R
XP80Xj>S0P2OWil20::RXP80YZJV0P2NWYh20::RXP@0Y:BT0P2SXj<20:6QX@80WIfM0P2LW9`409RH
V080UYJF0P2ATI42092@T080SXj>0P25QHD207alO080NGUi0P1eMGD2079bLP<0MWIf0P1lO7`208B4
Q080QHF50P23Ph<208N7Q`80QXJ60P24Q8@208>3P`80PX:20P1oOgl208B4Q080NGUi101kNg/20861
PBT0b>3H0P0I6AT2030`<0@0;bl_0P0Y:BT2020P80806ATI0P0[:b/2055AD@80LW9b0P1PH60207Ee
M@80OWin0P1dM7@206QXJ080Jf][0`1dM7@208^;R`80[jn_0P38b<P20;Jf]P80WYjN0P1nOWh209BD
U080Kfm_0P0b<S8201`L708051@D0P0X:2P202<S8`80:2PX0P0V9RH202DU9@80:BTY0P0/;2`2024Q
8@80;2`/0P0V9RH205YJFP80KFe]0P1GEeL204Q8B080>CTi0P14A4@204i>CP80E5AD0P1CDe<205eM
G@<0H61P0P1YJFT2071`L080M7Ad0P1aLG4207MgM`80Ng]k0P20P80207inOP80Ogmo0P22PX8207em
O@80Ph>30P25QHD208V9R@80QhN71028R8P208J6QP80RXZ:0P2<S8`208j>SP80Ti>C0P2DU9@209:B
TP80UIFE0P2DU9@209RHV080UiNG0P2JVYX209JFUP80UiNG0`2FUYH209NGU`80VIVI0P2LW9`209ZJ
VP80W9bL0P2NWYh209nOW`80WYjN102PX:0209nOW`80XJ6Q102RXZ840:>SX`80XZ:R0P2PX:0209^K
V`80VIVI102GUiL209BDU080Shn?0P2<S8`208j>SP80QHF50P1lO7`207IfMP80LW9b0P1eMGD307Ui
N@80Ng]k0P26QXH208F5Q@80QhN70P26QXH208R8R080RHV90P26QXH408:2PP80P8200P1oOgl207]k
N`80PH610P1jNWXO0<SPf0007@38h=P202PX:080:b/[0P0_;bl4034a<@809RHV0P0L71`2024Q8@80
:BTY0P1EEED204I6AP80Jf][0P27QhL207moO`80M7Ad0P1eMGD307]kN`80RXZ:0P2JVYX20=KFeP80
bl_;0P35aLD20;>c/`80[Zj^0P2TY:@204Q8B080;2`/0P0O7al2028R8P8092@T0P0X:2P202HV9P80
9BDU0P0W9bL202TY:@809RHV0P0Y:BT202PX:0@0H61P0P1MGEd204Y:BP80>CTi0P10@40204a<C080
DE5A0P1FEUH205aLG0<0Hf=S0P1YJFT206i^KP80LW9b0P1eMGD207QhN080Ng]k0P1mOGd207inOP80
P8200P22PX8208>3P`80Q8B40P25QHD208J6QP80QhN70P28R8P208J6QP80QHF50P27QhL208Z:RP80
SHf=0P2ATI4209BDU0@0UYJF0P2EUID209NGU`@0V9RH0P2GUiL209JFUP<0UiNG0P2HV9P209ZJVP80
Vi^K0P2LW9`209jNWPH0XJ6Q102RXZ820:>SX`80Y:BT0P2SXj<20::RXP80Xj>S0P2TY:@20:6QX@80
WinO0P2MWId209bLW080V9RH0P2EUID209:BTP@0TI6A0P2?Shl208Z:RP80Ph>30P1lO7`207MgM`80
MGEe0`1fMWH207alO080PH610P25QHD208J6QP@0QhN70P23Ph<207moO`80OGem0P1lO7`207]kN`80
NWYj0P1kNg/407alO2T0b>3H0P0U9BD2034a<@80;2`/0P0g=cL202l_;`807alO0P0K6a/2024Q8@80
;Rh^0P1?Cdl204];B`80KFe]0P27QhL207IfMP80LW9b0P20P80307]kN`80OWin0P2NWYh20<W9b@@0
b/[:0P2[Zj/20:2PX080Xj>S0P0l?3`202PX:0808R8R0P0O7al202DU9@809bLW0P0[:b/202LW9`80
9RHV0P0/;2`402DU9@80;2`/0P1IFET206YZJP80GEeM0P0m?Cd20492@P80AdM70P1=CDd2059BDP80
FEUI0P1HF5P306EUI@80JVYZ0P1]KFd207EeM@80M7Ad0P1fMWH207]kN`80OWin0P1mOGd40820P080
PH611P25QHD208b<S080QhN70P22PX8208F5Q@80RXZ:0P29RHT208f=S@80U9BD0P2BTY8209NGU`80
UYJF0P2CTi<209VIV@80UYJF102GUiL209RHV0<0UYJF0P2DU9@209^KV`80VYZJ0P2NWYh209nOW`80
XZ:R1P2PX:020::RXP@0YJFU0P2NWYh20:>SX`80YJFU0P2RXZ8209fMW@80WinO0P2MWId209^KV`80
V9RH0P2BTY8209FEU@@0SXj>0P2@T90208Z:RP80Ph>30P1lO7`207MgM`80LW9b0`1iNGT207emO@80
PX:21026QXH208^;R`80QhN70P23Ph<20861P@80OWin0P1kNg/207alO080NWYj0P1lO7`207]kN`80
OWin:@38h=P402XZ:P80;Rh^0P0/;2`202l_;`809BDU100O7al202XZ:P80EUIF0P16ATH206UYJ@80
Ph>30P24Q8@207AdM080LG5a0`1oOgl208Z:RP80WIfM0P3Hf=P20<_;b`80b/[:0P2d];@20:j^[P80
XZ:R0P1:BTX202/[:`806QXJ0P0Q8B4202TY:@809BDU0P0Q8B4202@T9080;2`/100W9bL402TY:@80
H61P0P1RHV8205aLG080C4a<0P0h>3P204I6AP80BDU90P1@D50205EEE@D0HV9R0P1WIfL206a/K080
Lg=c0P1hN7P207MgM`80NWYj0P1mOGd207alO080PH610P24Q8@20861P@80QhN70P21PH4208V9R@80
Q8B40P28R8P408J6QP80QhN70P29RHT208j>SP80T92@0P2EUID209NGU`80UYJF102EUID209RHV080
VIVI0P2GUiL209RHV0<0UYJF0P2GUiL209VIV@H0W9bL0P2PX:020:BTY080XJ6Q0P2RXZ820:6QX@80
XZ:R0P2TY:@20:>SX`80XJ6Q0P2UYJD20:BTY080XZ:R0P2OWil209bLW080WIfM0P2FUYH209FEU@@0
TY:B0P2@T90208j>SP80RHV90P20P80207moO`80MgMg0P1cLg<307QhN080Ng]k0P20P80208B4Q0H0
QXJ60P24Q8@407emO@80Ng]k101lO7`207QhN080OWin0P1mOGdO0<SPf0007@38h=P202PX:080:b/[
0P0_;bl4034a<@809RHV0P0L71`2024Q8@80:BTY0P1EEED204I6AP80Jf][0P27QhL207moO`80M7Ad
0P1eMGD307]kN`80RXZ:0P2JVYX20=KFeP80bl_;0P35aLD20;>c/`80[Zj^0P2TY:@204Q8B080;2`/
0P0O7al2028R8P8092@T0P0X:2P202HV9P809BDU0P0W9bL202TY:@809RHV0P0Y:BT202PX:0@0H61P
0P1MGEd204Y:BP80>CTi0P10@40204a<C080DE5A0P1FEUH205aLG0<0Hf=S0P1YJFT206i^KP80LW9b
0P1eMGD207QhN080Ng]k0P1mOGd207inOP80P8200P22PX8208>3P`80Q8B40P25QHD208J6QP80QhN7
0P28R8P208J6QP80QHF50P27QhL208Z:RP80SHf=0P2ATI4209BDU0@0UYJF0P2EUID209NGU`@0V9RH
0P2GUiL209JFUP<0UiNG0P2HV9P209ZJVP80Vi^K0P2LW9`209jNWPH0XJ6Q102RXZ820:>SX`80Y:BT
0P2SXj<20::RXP80Xj>S0P2TY:@20:6QX@80WinO0P2MWId209bLW080V9RH0P2EUID209:BTP@0TI6A
0P2?Shl208Z:RP80Ph>30P1lO7`207MgM`80MGEe0`1fMWH207alO080PH610P25QHD208J6QP@0QhN7
0P23Ph<207moO`80OGem0P1lO7`207]kN`80NWYj0P1kNg/407alO2T0b>3H0P0U9BD2034a<@80;2`/
0P0g=cL202l_;`807alO0P0K6a/2024Q8@80;Rh^0P1?Cdl204];B`80KFe]0P27QhL207IfMP80LW9b
0P20P80307]kN`80OWin0P2NWYh20<W9b@@0b/[:0P2[Zj/20:2PX080Xj>S0P0l?3`202PX:0808R8R
0P0O7al202DU9@809bLW0P0[:b/202LW9`809RHV0P0/;2`402DU9@80;2`/0P1IFET206YZJP80GEeM
0P0m?Cd20492@P80AdM70P1=CDd2059BDP80FEUI0P1HF5P306EUI@80JVYZ0P1]KFd207EeM@80M7Ad
0P1fMWH207]kN`80OWin0P1mOGd40820P080PH611P25QHD208b<S080QhN70P22PX8208F5Q@80RXZ:
0P29RHT208f=S@80U9BD0P2BTY8209NGU`80UYJF0P2CTi<209VIV@80UYJF102GUiL209RHV0<0UYJF
0P2DU9@209^KV`80VYZJ0P2NWYh209nOW`80XZ:R1P2PX:020::RXP@0YJFU0P2NWYh20:>SX`80YJFU
0P2RXZ8209fMW@80WinO0P2MWId209^KV`80V9RH0P2BTY8209FEU@@0SXj>0P2@T90208Z:RP80Ph>3
0P1lO7`207MgM`80LW9b0`1iNGT207emO@80PX:21026QXH208^;R`80QhN70P23Ph<20861P@80OWin
0P1kNg/207alO080NWYj0P1lO7`207]kN`80OWin:@38h=P402XZ:P80;Rh^0P0/;2`202l_;`809BDU
100O7al202XZ:P80EUIF0P16ATH206UYJ@80Ph>30P24Q8@207AdM080LG5a0`1oOgl208Z:RP80WIfM
0P3Hf=P20<_;b`80b/[:0P2d];@20:j^[P80XZ:R0P1:BTX202/[:`806QXJ0P0Q8B4202TY:@809BDU
0P0Q8B4202@T9080;2`/100W9bL402TY:@80H61P0P1RHV8205aLG080C4a<0P0h>3P204I6AP80BDU9
0P1@D50205EEE@D0HV9R0P1WIfL206a/K080Lg=c0P1hN7P207MgM`80NWYj0P1mOGd207alO080PH61
0P24Q8@20861P@80QhN70P21PH4208V9R@80Q8B40P28R8P408J6QP80QhN70P29RHT208j>SP80T92@
0P2EUID209NGU`80UYJF102EUID209RHV080VIVI0P2GUiL209RHV0<0UYJF0P2GUiL209VIV@H0W9bL
0P2PX:020:BTY080XJ6Q0P2RXZ820:6QX@80XZ:R0P2TY:@20:>SX`80XJ6Q0P2UYJD20:BTY080XZ:R
0P2OWil209bLW080WIfM0P2FUYH209FEU@@0TY:B0P2@T90208j>SP80RHV90P20P80207moO`80MgMg
0P1cLg<307QhN080Ng]k0P20P80208B4Q0H0QXJ60P24Q8@407emO@80Ng]k101lO7`207QhN080OWin
0P1mOGdO0<SPf0007@38h=P202@T9080:BTY0P0_;bl202h^;P80<30`0P0Y:BT201hN7P807alO0P0Q
8B4203@d=080;Rh^0P1MGEd208B4Q080TY:B0P1dM7@207EeM@<0N7Qh0P1oOgl208^;R`80a<C40P3A
dM420<c<c080`L710P32`/820;^k^`80NWYj0P0d=3@201TI6@808b<S0P0T92@202TY:@80:2PX100V
9RH202LW9`8092@T0P0W9bL202HV9P80GUiN101JFUX204U9B@80>c/k0P11@D4204];B`80DU9B0P1I
FET205iNGP<0Hf=S0P1YJFT206m_K`80Lg=c0P1fMWH207QhN080NWYj0P1mOGd207moO`80PH611023
Ph<208B4Q080QHF51026QXH208N7Q`80RHV91P2;Rh/208j>SP80TI6A0P2DU9@409JFUP80UIFE0P2G
UiL209RHV080UiNG0P2FUYH209RHV0D0VYZJ0P2KVi/409bLW080WIfM0P2NWYh209nOW`80XJ6Q0P2S
Xj<40:FUY@80Y:BT0P2SXj<40:6QX@80XZ:R102QXJ4209nOW`80WIfM0P2JVYX209NGU`80U9BD0P2B
TY82092@T080SHf=0P29RHT208F5Q@80Ogmo0P1kNg/207YjNP<0Ng]k0P1lO7`207inOP80PX:20P25
QHD408J6QP80PH61101lO7`207emO@80Ng]k101iNGT407YjNRT0b>3H0P0Z:RX202@T9080:BTY0P0j
>SX2038b<P808B4Q0P0S8b<2030`<0808B4Q0P0/;2`202PX:080G5aL0P29RHT208Z:RP80MGEe1@1h
N7P207UiN@80TY:B0P2o_kl20<c<c080c/k>0P3:b/X20;no_`80aLG50P1oOgl202l_;`@08R8R0P0W
9bL202/[:`80:BTY0P0R8R8202PX:0@09bLW0P0X:2P2030`<080EUIF0P1TI6@205YJFP80@D510P0g
=cL204Q8B080ADE50P1CDe<205MGE`80G5aL0`1PH60206IVIP80LG5a0P1eMGD407MgM`80OGem1P20
P80208N7Q`H0Q8B41026QXH208Z:RP80QhN70P2<S8`208n?S`80QXJ6102@T90209:BTP80UYJF0P2I
VIT209>CT`80UiNG0P2EUID209RHV080U9BD0P2FUYH309ZJVP80WIfM0P2KVi/409bLW080V9RH0P2N
WYh20:>SX`80XZ:R0P2PX:020:FUY@@0Y:BT0P2PX:040:BTY080Xj>S0P2TY:@20:6QX@80WYjN0P2K
Vi/209fMW@@0U9BD0P2BTY8208n?S`80SXj>0P28R8P208F5Q@80OGem0P1lO7`207YjNP<0Ng]k0P1l
O7`207]kN`80PX:20P23Ph<208b<S080QHF50P1mOGd207moO`80Ng]k0P1mOGd207inOP80NGUi0P1e
MGD207YjNP80OWin:@38h=P202LW9`80:2PX0P0a<C4202l_;`80=CDe0P0];Bd401dM7@807alO0P0a
<C4202d];@80GemO0P27QhL209:BTP@0MGEe0`1gMgL207]kN`80RHV90P32`/820=3@d080alO70P2h
^;P40<71`@80N7Qh0P0g=cL201TI6@808R8R0P0U9BD202h^;P80:RXZ0P0U9BD202PX:0809BDU0P0R
8R8202LW9`80:RXZ0P1OGel205QHF080FEUI0P17AdL203/k>`80?clo0P1>CTh204m?C`80F5QH0P1N
GUh3061PH080KFe]0P1^KVh207IfMP80Lg=c0P1hN7P407alO080Ph>30P21PH4208B4Q080Ph>31025
QHD208J6QP80QHF50P29RHT608Z:RP80Rh^;0P2>SXh209>CT`80SXj>202FUYH209VIV@80V9RH0P2D
U9@209RHV0<0VIVI1P2KVi/209fMW@80WYjN0P2OWil20:2PX080XJ6Q0P2RXZ820:RXZ080Y:BT0P2V
YZH20:FUY@80XZ:R0P2OWil20:2PX0@0XZ:R0P2QXJ420:2PX080V9RH0P2IVIT209BDU080T92@0P2A
TI4208n?S`80S8b<0P24Q8@20861P@80NWYj0P1iNGT307YjNP80Ng]k0P20P80208B4Q0@0R8R80P26
QXH208>3P`80O7al101nOWh407UiN@80M7Ad0P1kNg/207UiNAl0b>3H000M0<SPf08092@T0P0Y:BT2
02l_;`80;Rh^0P0`<30202TY:@807QhN0P0O7al2024Q8@80=3@d0P0^;Rh205eMG@80Q8B40P2BTY82
07AdM080MGEe0`1hN7P207moO`80Rh^;0P34a<@20=7Ad@80c<c<0P31`L420<;2`P80^k^k0P1jNWX2
03@d=0806ATI0P0S8b<202@T9080:BTY0P0X:2P402HV9P809bLW0P0T92@202LW9`809RHV0P1NGUh4
05YJFP80BDU90P0k>c/20451@@80Bd];0P1BDU8205UIF@80GUiN0`1SHf<206UYJ@80Kfm_0P1cLg<2
07IfMP80N7Qh0P1jNWX207emO@80Ogmo0P21PH4408>3P`80Q8B40P25QHD408J6QP80QhN70P29RHT6
08^;R`80SXj>0P2ATI4209BDU0@0UYJF0P2EUID209NGU`80V9RH0P2GUiL209JFUP80V9RH1@2JVYX2
09^KV`@0W9bL0P2MWId209jNWP80WinO0P2QXJ420:>SX`@0YJFU0P2TY:@20:>SX`@0XJ6Q0P2RXZ84
0:6QX@80WinO0P2MWId209ZJVP80UiNG0P2DU9@209:BTP80T92@0P2=SHd208V9R@80QHF50P1oOgl2
07]kN`80NWYj0`1kNg/207alO080OWin0P22PX8208F5Q@@0QXJ60P21PH4407alO080OGem0P1kNg/4
07UiN@@0NWYj:@38h=P202XZ:P8092@T0P0Y:BT203Xj>P80<S8b0P0Q8B4202<S8`80<30`0P0Q8B42
02`/;080:2PX0P1LG5`208V9R@80RXZ:0P1eMGD507QhN080NGUi0P2BTY820;no_`80c<c<0P3>c/h2
0<[:bP80_kno0P35aLD207moO`80;bl_100R8R8202LW9`80:b/[0P0Y:BT2028R8P80:2PX100W9bL2
02PX:080<30`0P1FEUH206ATI080FUYJ0P11@D4203Lg=`80B4Q80P15ADD205=CD`80EeMG0P1LG5`3
061PH080IVIV0P1aLG4207EeM@@0MgMg0P1mOGd60820P080QhN71P24Q8@408J6QP80RXZ:0P27QhL2
08b<S080Shn?0P26QXH4092@T080TY:B0P2FUYH209VIV@80Ti>C0P2GUiL209FEU@80V9RH0P2DU9@2
09JFUP<0VYZJ0P2MWId209^KV`@0W9bL0P2HV9P209jNWP80Xj>S0P2RXZ820:2PX080YJFU102TY:@2
0:2PX0@0Y:BT0P2SXj<20:BTY080XJ6Q0P2NWYh209^KV`80WIfM102DU9@209:BTP80Shn?0P2>SXh2
08R8R080QHF50P1mOGd207alO080NWYj0`1kNg/207alO080Ng]k0P22PX8208>3P`80S8b<0P25QHD2
07emO@80Ogmo0P1kNg/207emO@80OWin0P1iNGT207EeM@80NWYj0P1nOWhY0<SPf0809bLW0P0X:2P2
034a<@80;bl_0P0e=CD202d];@@07AdM0P0O7al2034a<@80;Bd]0P1OGel208N7Q`80TY:B101eMGD3
07MgM`80Ng]k0P29RHT20<;2`P80d=3@0P37alL20;Rh^0@0`L710P1hN7P203Lg=`806ATI0P0R8R82
02DU9@80;Rh^0P0Z:RX202DU9@80:2PX0P0U9BD2028R8P809bLW0P0Z:RX205mOG`80F5QH0P1IFET2
04M7A`80>c/k0P0o?cl204i>CP80Cdm?0P1HF5P205iNGP<0H61P0P1]KFd206i^KP80MWIf0P1cLg<2
07QhN0@0O7al0P23Ph<20861P@80Q8B40P23Ph<408F5Q@80QXJ60P25QHD208V9R@H0RXZ:0P2;Rh/2
08j>SP80Ti>C0P2>SXh809JFUP80VIVI0P2HV9P209BDU080V9RH0`2IVIT609^KV`80WIfM0P2NWYh2
09nOW`80X:2P0P2QXJ420::RXP80Z:RX0P2TY:@20:JVYP80YJFU0P2RXZ8209nOW`80X:2P102RXZ82
0:6QX@80X:2P0P2HV9P209VIV@80U9BD0P2@T902096AT@80Shn?0P2<S8`208B4Q080PH610P1jNWX2
07UiN@<0NWYj0P1kNg/20820P080Q8B41028R8P208J6QP80Ph>30P1lO7`407inOP@0NGUi0P1dM7@2
07]kN`80NGUi7`38h=P001d0b>3H0P0Q8B4202PX:0H0<C4a0P0Z:RX4024Q8@808b<S0P0H61P201/K
6`80CDe=0P1kNg/209jNWP@0MGEe0`1cLg<207AdM080Ogmo0P2WYjL20<k>cP80dM7A0P3=cLd20=SH
f080dM7A0P2d];@2051@D0@09BDU0P0T92@202XZ:P80:BTY0P0X:2P202HV9P809BDU0P0R8R8202LW
9`8092@T0P1JFUX205QHF080E5AD0P18B4P203hn?P80@T920P1;Bd/205=CD`80Fe]K0P1PH60306AT
I080Jf][0P1aLG4207EeM@80N7Qh0P1iNGT207YjNP80OGem0P20P80208:2PPH0Ph>30P24Q8@408J6
QP80QhN70P2<S8`2096AT@80T92@0P2>SXh208n?S`80TI6A0P2CTi<209FEU@@0UYJF0P2GUiL209RH
V0@0UiNG0P2JVYX509fMW@@0W9bL1P2MWId209jNWP80X:2P0P2TY:@20:NWY`80YZJV0P2TY:@20::R
XP80XJ6Q102PX:020::RXP80Xj>S0P2QXJ4209nOW`80W9bL0P2IVIT209JFUP80Ti>C0P2?Shl208^;
R`80R8R80P26QXH208:2PP80P8200P1oOgl30820P080OWin0P1mOGd20820P080Q8B40P25QHD208B4
Q080P8200P1kNg/207emO@80Ogmo0P1lO7`807UiNBT0b>3H0P0S8b<202DU9@80<S8b0P0h>3P202l_
;`80;2`/100O7al2028R8P807QhN0P0R8R8204A4A080PX:20P2JVYX207]kN`80LG5a0`1fMWH207=c
L`80Ogmo0P2XZ:P20=3@d080clo?0P3@d=020<c<c080d=3@0P2i^KT204U9B@809RHV0P0S8b<202XZ
:P809RHV0P0X:2P202`/;0@092@T0P0U9BD2028R8P80:2PX0P1CDe<2061PH080E5AD0P0l?3`20451
@@80BTY:0P1;Bd/205ADE080GEeM0P1QHF4306MWI`80JVYZ0P1aLG4207EeM@80MgMg0P1iNGT207Mg
M`80Ogmo1020P80208F5Q@@0PH610P27QhL208>3P`80QXJ60P27QhL208^;R`80S8b<0P2HV9P208Z:
RP80TY:B102@T90209JFUP80V9RH0P2BTY8209VIV@80V9RH0P2IVIT209RHV080VYZJ0`2KVi/209jN
WP@0Vi^K0P2OWil209ZJVP80WYjN0P2PX:0209nOW`80Xj>S102WYjL20:BTY080Xj>S0P2PX:0209jN
WP80X:2P0P2QXJ420:>SX`80WinO0P2NWYh209fMW@80VIVI0P2EUID2096AT@80TY:B0P29RHT208R8
R080QhN70P22PX8207inOP80PH610`1oOgl207inOP80O7al1023Ph<208N7Q`80Ph>30P1nOWh207al
O080Ng]k101oOgl207UiN@80MGEe0P1fMWH20861PBT0b>3H0P0Q8B4202LW9`80<S8b100`<30202PX
:080820P0P0Q8B42028R8P805aLG0P0I6AT204a<C080NWYj0P2MWId207EeM@80MgMg0`1bLW8207Yj
NP80OWin0P2SXj<20<k>cP80e]KF0P3:b/X20=kNgP80cLg=0P2c/k<204i>CP809bLW0P0T92@202<S
8`80:BTY0P0T92@202PX:0809bLW0P0T92@2024Q8@809RHV0P0S8b<205UIF@@0EUIF0P17AdL20451
@@80@4100P1=CDd2059BDP80F5QH0P1TI6@306=SH`80Jf][0P1/K6`207]kN`80MgMg0P1iNGT207]k
N`80O7al1021PH4208B4Q080PX:20P21PH4208N7Q`80Q8B40P26QXH208N7Q`80SXj>0P2ATI4209:B
TP80Shn?0P2>SXh409>CT`80UiNG0P2FUYH209NGU`80U9BD0P2HV9P209ZJVP@0VIVI0`2MWId209jN
WP@0Vi^K0P2NWYh209bLW080WIfM0P2NWYh20:2PX080Xj>S0P2VYZH20:FUY@80Y:BT0P2QXJ420:2P
X080WinO1P2RXZ820:2PX080WinO102JVYX209RHV080Ti>C0P2?Shl208^;R`80QhN70P26QXH20820
P080Ogmo1@21PH4207alO080OWin0P1oOgl208F5Q@80PX:20P24Q8@208:2PP80NGUi0P1mOGd20820
P080NWYj0P1iNGT207YjNP80N7Qh0P1iNGTO0<SPf0007@38h=P2024Q8@80:2PX1P0a<C4202XZ:P@0
8B4Q0P0S8b<201PH60806a/K0P1=CDd207]kN`80WYjN101eMGD307=cL`80M7Ad0P1oOgl20:NWY`80
c/k>0P3AdM420<g=c@80f=SH0P3AdM420;Bd]080D51@100U9BD202@T9080:RXZ0P0Y:BT202PX:080
9RHV0P0U9BD2028R8P809bLW0P0T92@205YJFP80F5QH0P1DE5@204Q8B080?Shn0P12@T8204];B`80
De=C0P1KFe/2061PH0<0I6AT0P1[Jf/2075aL@80MGEe0P1hN7P207UiN@80NWYj0P1mOGd20820P080
PX:21P23Ph<208B4Q0@0QXJ60P27QhL208b<S080TI6A0P2@T90208j>SP80Shn?0P2ATI4209>CT`80
UIFE102FUYH209NGU`80V9RH102GUiL209ZJVPD0WIfM102LW9`609fMW@80WYjN0P2PX:020:BTY080
YjNW0P2VYZH20:BTY080XZ:R0P2QXJ440:2PX080XZ:R0P2SXj<20:6QX@80WinO0P2LW9`209VIV@80
UYJF0P2CTi<208n?S`80Rh^;0P28R8P208J6QP80PX:20P20P80207moO`<0P8200P1nOWh207emO@80
P8200P24Q8@208F5Q@80Q8B40P20P80207]kN`80OGem0P1oOgl207alO0P0NGUi:@38h=P202<S8`80
9BDU0P0b<S8203Ph>080;bl_0P0/;2`401lO7`808R8R0P0N7Qh2028R8P80A4A40P22PX8209ZJVP80
Ng]k0P1aLG4307IfMP80Lg=c0P1oOgl20:RXZ080d=3@0P3?cll20=3@d080c<c<0P3@d=020;Vi^@80
BDU90P0V9RH202<S8`80:RXZ0P0V9RH202PX:080;2`/100T92@202DU9@808R8R0P0X:2P205=CD`80
H61P0P1DE5@203`l?080@D510P1:BTX204];B`80E5AD0P1MGEd2065QH@<0IfMW0P1ZJVX2075aL@80
MGEe0P1gMgL207UiN@80MgMg0P1oOgl40820P080QHF51021PH4208N7Q`80Ph>30P26QXH208N7Q`80
Rh^;0P2<S8`209RHV080RXZ:0P2BTY84092@T080UYJF0P2HV9P209:BTP80VIVI0P2HV9P209VIV@80
V9RH0P2JVYX309^KV`80WYjN102KVi/209nOW`80VYZJ0P2NWYh20:2PX080WinO0P2SXj<40:NWY`80
Y:BT0P2SXj<20:2PX080WYjN0P2PX:020:6QX@80Xj>S0P2OWil209jNWP80WIfM0P2IVIT209FEU@80
TI6A0P2BTY8208V9R@80R8R80P27QhL208:2PP80OWin0P21PH4307moO`80OWin0P1lO7`408>3P`80
QhN70P23Ph<207inOP80O7al0P1kNg/407moO`80NGUi0P1eMGD207IfMP80PH61:@38h=P2024Q8@80
9bLW0P0b<S84030`<080:2PX0P0P8202024Q8@808R8R0P0G5aL201TI6@80C4a<0P1jNWX209fMW@80
MGEe0P1gMgL3079bLP80NWYj0P1nOWh20:>SX`80c/k>0P3Fe]H20<[:bP80g]kN0P3=cLd20;>c/`80
CTi>0P0W9bL202@T90808b<S0P0Y:BT202@T9080:2PX0P0W9bL202@T90808B4Q0P0V9RH202<S8`80
FEUI101FEUH204M7A`80@D510P10@40204e=C@80DU9B0P1HF5P206ATI0<0Hf=S0P1[Jf/206a/K080
Ng]k0P1gMgL207UiN@80Ng]k0P1lO7`40861P@80Q8B40P22PX820861P@80QhN70P24Q8@208J6QP80
QhN70P2>SXh2096AT@80TY:B0P2?Shl208j>SP@0Ti>C0P2GUiL209JFUP80UiNG0P2DU9@209RHV080
VYZJ102IVIT309fMW@80WYjN102KVi/209jNWP80W9bL0P2MWId209jNWP80X:2P0P2SXj<20:JVYP80
YJFU0P2TY:@20:6QX@80X:2P0P2OWil60::RXP80X:2P0P2OWil409ZJVP80V9RH0P2CTi<208n?S`80
Rh^;0P27QhL208J6QP80P8200P1oOgl50861P@80O7al0P1nOWh207moO`80QHF50P22PX8208B4Q080
PX:20P1iNGT207emO@80P8200P1jNWX207UiN@80NWYj0P1hN7P207UiNAl0b>3H000M0<SPf080820P
0P0^;Rh203dm?@80CTi>0P0n?Sh2020P80808b<S0P0P8202024Q8@805ADE0P0H61P203hn?P80IfMW
0P2=SHd208J6QP80NWYj0`1`L702075aL@80OWin0P2:RXX20;^k^`80eMGE0P39bLT20=7Ad@80clo?
0P3@d=020:6QX@80;bl_0P0`<30602HV9P809bLW0P0U9BD202@T90808b<S0P0Z:RX2020P8080DU9B
0P1NGUh204Y:BP80@d=30P0l?3`20451@@80BTY:0P1ADE4205UIF@80H61P0`1VIVH206a/K080L71`
0P1dM7@207QhN080O7al101nOWh207emO@80P8200P24Q8@208>3P`80PX:20P24Q8@208N7Q`80R8R8
0P29RHT208Z:RP80S8b<0P2>SXh2096AT@@0TY:B0P2CTi<209BDU080UYJF1P2HV9P209ZJVP80W9bL
0P2NWYh30:2PX080WYjN0P2LW9`209fMW@80WYjN102OWil20:6QX@80Y:BT0P2UYJD40:JVYP@0YJFU
0P2TY:@20:>SX`80XZ:R1P2SXj<20::RXP80X:2P0P2MWId209VIV@80U9BD0P2@T90208f=S@80RXZ:
0P28R8P208F5Q@80Ph>30P22PX870861P@80PX:20P23Ph<208:2PP80P8200P1nOWh207alO0@0Ng]k
0P1jNWX207UiN@80NWYj101kNg/Y0<SPf0808b<S0P0^;Rh203dm?@80CTi>0P0e=CD202<S8`80820P
0P0K6a/201hN7P8071`L0P0O7al202l_;`80Jf][0P2?Shl208J6QP80Lg=c0`1`L70207AdM080MWIf
0P2@T9020;no_`80cLg=0P3;bl/20<k>cP80c<c<0P3>c/h20:>SX`80>3Ph0P0U9BD202@T90809RHV
0P0Y:BT202DU9@809RHV0P0W9bL2028R8P8092@T0P0U9BD204e=C@80IVIV0P1>CTh203Xj>P80@T92
0P17AdL204E5A@80Bd];0P1GEeL2065QH@<0IfMW0P1/K6`4075aL@80NGUi0P1nOWh20820P080NWYj
0P1nOWh40820P080Ph>30P22PX8208N7Q`80R8R81029RHT208Z:RP@0SXj>0P2?Shl209BDU080Ti>C
0P2@T902096AT@80V9RH0P2KVi/209NGU`80UYJF0P2IVIT209ZJVP80WYjN0`2RXZ8209jNWP80WIfM
0P2LW9`20:2PX0H0WinO0P2RXZ820:JVYP80Z:RX0P2RXZ820:JVYP80Y:BT0P2UYJD20::RXP80X:2P
0P2TY:@20:FUY@80XZ:R0P2VYZH209nOW`80WYjN0P2JVYX409>CT`80S8b<0P2>SXh408F5Q@@0Q8B4
0`20P8040861P@80Q8B40P1mOGd208B4Q080PX:20P1lO7`207moO`80O7al0P1kNg/207UiN@80Ng]k
0P1iNGT207alO080OGem:@38h=P2020P8080<30`0P0l?3`204Y:BP80>SXj0P0X:2P2024Q8@809RHV
0P0S8b<201TI6@806QXJ0P12@T8206MWI`@0QXJ60P1jNWX306a/K080Lg=c0P22PX8208Z:RP80_[jn
0P3GemL20<[:bP80emOG0P39bLT20=3@d080WinO0P0g=cL202`/;0@09BDU0P0V9RH202PX:0@09bLW
0P0T92@202/[:`80820P0P1BDU82061PH080Bd];0P12@T8203`l?080?clo0P1:BTX2051@D080GUiN
0P1OGel306IVIP80Jf][0P1_Kfl207MgM`80M7Ad0P1lO7`207inOP80NWYj0P1mOGd20820P080Q8B4
0P23Ph<207inOP80R8R80P26QXH208V9R@80QhN70P28R8P208b<S0@0Shn?102ATI42092@T080U9BD
0P2FUYH209VIV@@0UiNG0P2HV9P209VIV@80WIfM0`2PX:020:6QX@80WYjN0P2LW9`209jNWP80WIfM
0P2NWYh20:>SX`80Y:BT0P2UYJD20:RXZ080YJFU0P2TY:@20:RXZ080YJFU0P2SXj<20:2PX080YjNW
0P2RXZ820:BTY080XJ6Q0P2OWil209^KV`80VIVI0P2DU9@208n?S`80SHf=0P2:RXX208^;R`80Q8B4
1025QHD30861P@80Ogmo0P21PH4207moO`80Ph>31020P80207moO`@0O7al0P1jNWX407]kN`80OGem
0P1lO7`207YjNQl0b>3H000M0<SPf080820P0P0^;Rh203dm?@80CTi>0P0n?Sh2020P80808b<S0P0P
8202024Q8@805ADE0P0H61P203hn?P80IfMW0P2=SHd208J6QP80NWYj0`1`L702075aL@80OWin0P2:
RXX20;^k^`80eMGE0P39bLT20=7Ad@80clo?0P3@d=020:6QX@80;bl_0P0`<30602HV9P809bLW0P0U
9BD202@T90808b<S0P0Z:RX2020P8080DU9B0P1NGUh204Y:BP80@d=30P0l?3`20451@@80BTY:0P1A
DE4205UIF@80H61P0`1VIVH206a/K080L71`0P1dM7@207QhN080O7al101nOWh207emO@80P8200P24
Q8@208>3P`80PX:20P24Q8@208N7Q`80R8R80P29RHT208Z:RP80S8b<0P2>SXh2096AT@@0TY:B0P2C
Ti<209BDU080UYJF1P2HV9P209ZJVP80W9bL0P2NWYh30:2PX080WYjN0P2LW9`209fMW@80WYjN102O
Wil20:6QX@80Y:BT0P2UYJD40:JVYP@0YJFU0P2TY:@20:>SX`80XZ:R1P2SXj<20::RXP80X:2P0P2M
WId209VIV@80U9BD0P2@T90208f=S@80RXZ:0P28R8P208F5Q@80Ph>30P22PX870861P@80PX:20P23
Ph<208:2PP80P8200P1nOWh207alO0@0Ng]k0P1jNWX207UiN@80NWYj101kNg/Y0<SPf0808b<S0P0^
;Rh203dm?@80CTi>0P0e=CD202<S8`80820P0P0K6a/201hN7P8071`L0P0O7al202l_;`80Jf][0P2?
Shl208J6QP80Lg=c0`1`L70207AdM080MWIf0P2@T9020;no_`80cLg=0P3;bl/20<k>cP80c<c<0P3>
c/h20:>SX`80>3Ph0P0U9BD202@T90809RHV0P0Y:BT202DU9@809RHV0P0W9bL2028R8P8092@T0P0U
9BD204e=C@80IVIV0P1>CTh203Xj>P80@T920P17AdL204E5A@80Bd];0P1GEeL2065QH@<0IfMW0P1/
K6`4075aL@80NGUi0P1nOWh20820P080NWYj0P1nOWh40820P080Ph>30P22PX8208N7Q`80R8R81029
RHT208Z:RP@0SXj>0P2?Shl209BDU080Ti>C0P2@T902096AT@80V9RH0P2KVi/209NGU`80UYJF0P2I
VIT209ZJVP80WYjN0`2RXZ8209jNWP80WIfM0P2LW9`20:2PX0H0WinO0P2RXZ820:JVYP80Z:RX0P2R
XZ820:JVYP80Y:BT0P2UYJD20::RXP80X:2P0P2TY:@20:FUY@80XZ:R0P2VYZH209nOW`80WYjN0P2J
VYX409>CT`80S8b<0P2>SXh408F5Q@@0Q8B40`20P8040861P@80Q8B40P1mOGd208B4Q080PX:20P1l
O7`207moO`80O7al0P1kNg/207UiN@80Ng]k0P1iNGT207alO080OGem:@38h=P2020P8080<30`0P0l
?3`204Y:BP80>SXj0P0X:2P2024Q8@809RHV0P0S8b<201TI6@806QXJ0P12@T8206MWI`@0QXJ60P1j
NWX306a/K080Lg=c0P22PX8208Z:RP80_[jn0P3GemL20<[:bP80emOG0P39bLT20=3@d080WinO0P0g
=cL202`/;0@09BDU0P0V9RH202PX:0@09bLW0P0T92@202/[:`80820P0P1BDU82061PH080Bd];0P12
@T8203`l?080?clo0P1:BTX2051@D080GUiN0P1OGel306IVIP80Jf][0P1_Kfl207MgM`80M7Ad0P1l
O7`207inOP80NWYj0P1mOGd20820P080Q8B40P23Ph<207inOP80R8R80P26QXH208V9R@80QhN70P28
R8P208b<S0@0Shn?102ATI42092@T080U9BD0P2FUYH209VIV@@0UiNG0P2HV9P209VIV@80WIfM0`2P
X:020:6QX@80WYjN0P2LW9`209jNWP80WIfM0P2NWYh20:>SX`80Y:BT0P2UYJD20:RXZ080YJFU0P2T
Y:@20:RXZ080YJFU0P2SXj<20:2PX080YjNW0P2RXZ820:BTY080XJ6Q0P2OWil209^KV`80VIVI0P2D
U9@208n?S`80SHf=0P2:RXX208^;R`80Q8B41025QHD30861P@80Ogmo0P21PH4207moO`80Ph>31020
P80207moO`@0O7al0P1jNWX407]kN`80OGem0P1lO7`207YjNQl0b>3H000M0<SPf0808b<S0P0g=cL2
04a<C080KFe]0P1<C4`201XJ6P809BDU0P0N7Qh201lO7`806ATI0P0J6QX2030`<080Cdm?0P1fMWH2
09JFUP80Q8B40`1_Kfl2075aL@80Ogmo0P1bLW820:BTY080dm?C0P32`/820<W9b@80b/[:0P3Fe]H2
0=7Ad@80PX:20P0^;Rh202@T90809RHV0P0U9BD202HV9P@08b<S0P0T92@202`/;080820P0P1;Bd/2
06ATI080@4100P0m?Cd203/k>`80@D510P19BDT2051@D080EeMG0P1PH60306QXJ080KFe]0P1`L702
07AdM080N7Qh0P1nOWh208:2PP80Ogmo0P1kNg/207moO`80Q8B40P22PX820861P@80Q8B40P28R8P2
08Z:RP80Rh^;0P28R8P208J6QP80S8b<0P2CTi<409BDU0@0Ti>C0P2GUiL209^KV`80VIVI0P2HV9P2
09bLW080XJ6Q1@2RXZ820:2PX080WIfM0P2NWYh20:2PX080XZ:R0P2SXj<20:JVYP80YjNW0P2VYZH2
0:FUY@80YZJV0P2WYjL40:RXZ080YjNW0P2UYJD20:BTY080Xj>S102UYJD20:>SX`80WinO0P2KVi/2
09JFUP80TY:B0P2@T90208b<S080RXZ:0P27QhL208F5Q@80Ph>30`22PX8208>3P`80QHF50P24Q8@2
08:2PP80Ogmo1P1mOGd207YjNP80MgMg0P1hN7P207YjNP@0O7al0P1mOGdY0<SPf0809RHV0P0b<S82
04a<C080Lg=c0P1=CDd202HV9P80820P0P0Q8B4201hN7P@07AdM0P0U9BD2051@D080Ph>30P2EUID2
07UiN@<0Kfm_0P1iNGT207IfMP80N7Qh0P2UYJD20<O7a`80b<S80P3>c/h20<o?c`@0c/k>0P29RHT2
034a<@809BDU0P0V9RH202DU9@809bLW0P0Q8B4202<S8`80:BTY0P0W9bL202TY:@80BDU90P1LG5`2
04Q8B080=CDe0P0l?3`204E5A@80BDU90P1=CDd205YJFP80HV9R0`1VIVH206a/K080LW9b0P1dM7@2
07EeM@80PX:20P23Ph<207emO@80Ng]k0P20P80208>3P`80QXJ60P1nOWh208B4Q080QhN70P29RHT4
08Z:RP80QXJ60P29RHT2092@T080VYZJ0P2BTY82092@T0@0UYJF0P2KVi/209VIV@80UiNG1P2QXJ43
0:>SX`80X:2P0P2NWYh209nOW`80X:2P0P2RXZ820:>SX`80XZ:R0P2UYJD20:RXZ080YJFU0P2SXj<2
0:RXZ080ZJVY0P2XZ:P20:BTY080YJFU0P2XZ:P20::RXP@0YZJV0P2OWil20:2PX080Vi^K0P2FUYH2
096AT@80T92@0P29RHT208Z:RP80R8R81`23Ph<208:2PP@0Q8B41021PH4207]kN`80O7al0P1mOGd2
07UiN@@0N7Qh0P1jNWX207]kN`80O7al0P1mOGdY0<SPf0808R8R0P0f=SH204e=C@80K6a/0P1@D502
01`L70808b<S0P0P820201dM7@805QHF0P0I6AT2030`<080CDe=0P1mOGd209>CT`80QXJ60`1`L702
079bLP80Ogmo0P1`L7020:BTY080d];B0P2o_kl20<W9b@80dM7A0P3?cll20=;BdP80QXJ60P0_;bl2
02@T90809bLW0P0Z:RX202<S8`808B4Q0P0T92@201lO7`80;bl_0P0K6a/204e=C@80I6AT0P10@402
03lo?`80>SXj0P13@d<204Q8B080Bd];0P1JFUX2061PH0<0K6a/0P1ZJVX207=cL`80MWIf0P1gMgL2
07inOP80Q8B40P1nOWh207alO080Ogmo0P23Ph<40820P080RHV90P27QhL208V9R@80SHf=0P28R8P2
08N7Q`80Rh^;0P2CTi<209FEU@80Ti>C0P2ATI4209>CT`@0VYZJ0P2KVi/209RHV080W9bL0P2SXj<2
0:6QX@<0XZ:R0P2PX:0209fMW@80WYjN0P2PX:020:FUY@80XZ:R0P2XZ:P20:NWY`80Y:BT0P2UYJD2
0:RXZ080YjNW102XZ:P20:FUY@80Y:BT0P2YZJT20:6QX@80Xj>S102VYZH20:2PX080VIVI0P2FUYH2
09:BTP80T92@0P2=SHd208Z:RP@0QHF50P24Q8@30820P080Ph>30P27QhL208B4Q080Ph>30P1oOgl2
07emO@@0O7al0P1mOGd207IfMP80MgMg0P1iNGT207]kN`80O7al0P1kNg/O0<SPf0007@38h=P202<S
8`80=cLg0P1<C4`206e]K@80C4a<0P0J6QX202DU9@807QhN0P0O7al201TI6@806QXJ0P0`<30204m?
C`80MWIf0P2FUYH208B4Q0<0Kfm_0P1aLG4207moO`80LW9b0P2TY:@20=?Cd`80`/;20P39bLT20<[:
bP80e]KF0P3AdM4208:2PP80;Rh^0P0T92@202HV9P809BDU0P0V9RH402<S8`8092@T0P0/;2`2020P
8080Bd];0P1TI6@20410@080?Cdm0P0k>c/20451@@80BDU90P1@D50205MGE`80H61P0`1XJ6P206e]
K@80L71`0P1dM7@207QhN080OWin0P22PX8207moO`80Ng]k0P1oOgl208B4Q080PX:20P21PH4208B4
Q080R8R80P2:RXX208^;R`80R8R80P26QXH208b<S080Ti>C102DU9@409>CT`80UiNG0P2KVi/209VI
V@80V9RH0P2LW9`20:6QX@D0XZ:R0P2PX:0209fMW@80WYjN0P2PX:020::RXP80Xj>S0P2VYZH20:NW
Y`80YZJV0P2UYJD20:JVYP80YjNW102XZ:P20:NWY`80YJFU0P2TY:@20:>SX`@0YJFU0P2SXj<209nO
W`80Vi^K0P2FUYH209:BTP80T92@0P2<S8`208Z:RP80QhN70P25QHD208>3P`<0PX:20P23Ph<208F5
Q@80Q8B40P22PX8207moO`H0OGem0P1jNWX207MgM`80N7Qh0P1jNWX407alO080OGem:@38h=P202HV
9P80<S8b0P1<C4`207=cL`80CDe=0P0V9RH2020P80808B4Q0P0N7Qh401dM7@809BDU0P1@D50208>3
P`80UIFE0P1iNGT306m_K`80NGUi0P1fMWH207QhN080YJFU0P37alL20<S8b080c/k>0P3?cll40<k>
cP80RHV90P0a<C4202DU9@809RHV0P0U9BD202LW9`808B4Q0P0S8b<202TY:@809bLW0P0Y:BT204U9
B@80G5aL0P18B4P203De=@80?3`l0P15ADD204U9B@80CDe=0P1JFUX2069RHP<0IVIV0P1/K6`2079b
LP80M7Ad0P1eMGD208:2PP80Ph>30P1mOGd207]kN`80P8200P23Ph<208J6QP80OWin0P24Q8@208N7
Q`80RHV9102:RXX208J6QP80RHV90P2@T90209ZJVP80TY:B0P2@T90409JFUP80Vi^K0P2IVIT209NG
U`H0XJ6Q0`2SXj<20:2PX080WYjN0P2OWil20:2PX080XZ:R0P2SXj<20::RXP80YJFU0P2XZ:P20:FU
Y@80Xj>S0P2XZ:P20:VYZ@80Z:RX0P2TY:@20:FUY@80Z:RX0P2RXZ840:JVYP80WinO0P2PX:0209^K
V`80UYJF0P2ATI42092@T080RHV90P2:RXX208R8R0L0Ph>30P22PX8408B4Q0@0PH610P1kNg/207al
O080OGem0P1iNGT407QhN080NWYj0P1kNg/207alO080OGem:@38h=P2028R8P80=SHf0P1=CDd206a/
K080D51@0P0L71`202<S8`80820P0P0M7Ad201HF5P806ATI0P0`<30204e=C@80OGem0P2CTi<208J6
QP<0L71`0P1bLW8207moO`80L71`0P2TY:@20=;BdP80_kno0P39bLT20=7Ad@80clo?0P3Bd]8208J6
QP80;bl_0P0T92@202LW9`80:RXZ0P0S8b<2024Q8@8092@T0P0O7al202l_;`806a/K0P1=CDd206AT
I080@4100P0o?cl203Xj>P80@d=30P18B4P204];B`80FUYJ0P1PH60306a/K080JVYZ0P1cLg<207If
MP80MgMg0P1nOWh208B4Q080OWin0P1lO7`207moO`80Ph>31020P80208V9R@80QhN70P29RHT208f=
S@80R8R80P27QhL208^;R`80Ti>C0P2EUID209>CT`80TI6A0P2CTi<409ZJVP80Vi^K0P2HV9P209bL
W080Xj>S0P2QXJ430::RXP80X:2P0P2MWId209jNWP80X:2P0P2UYJD20::RXP80Z:RX0P2WYjL20:BT
Y080YJFU0P2XZ:P20:NWY`@0Z:RX0P2UYJD20:BTY080ZJVY0P2QXJ420:>SX`@0YZJV0P2PX:0209VI
V@80UYJF0P2BTY82092@T080SHf=0P2:RXX408F5Q@80Q8B40`20P80208>3P`80QhN70P24Q8@208>3
P`80Ogmo0P1mOGd407alO080OGem0P1fMWH207MgM`80NGUi0P1kNg/207alO080Ng]k7`38h=P001d0
b>3H0P0];Bd203hn?P80E5AD0P2@T90207alO080@d=30P0T92@201/K6`807AdM0P0I6AT201/K6`80
8b<S0P0g=cL206e]K@80V9RH0P2FUYH306e]K@80KVi^0P1gMgL207=cL`80Ti>C0P2m_Kd20<C4a080
bl_;0P3:b/X20=3@d080bl_;0P36a/H206QXJ080:BTY0P0Q8B42020P80809BDU100T92@2028R8P80
9BDU0P0Z:RX204=3@`80HF5Q0P0m?Cd203/k>`80>CTi0P0o?cl204Q8B080D51@0P1IFET2065QH@<0
JFUY0P1]KFd2071`L080M7Ad0P1hN7P207emO@@0P8200P1nOWh20861P@80Ph>30P22PX820861P@80
Ph>30P27QhL208V9R@80RXZ:1029RHT208f=S@80TY:B102DU9@209FEU@80UYJF0P2IVIT209^KV`@0
VYZJ0P2NWYh20::RXPD0Xj>S0P2PX:0209jNWP80X:2P0P2SXj<20:JVYP@0YjNW0P2VYZH20:RXZ080
ZJVY0P2XZ:P20:NWY`80Z:RX0P2YZJT20:RXZ080YjNW0P2UYJD20:>SX`80Y:BT0P2UYJD20::RXP80
WYjN0P2KVi/209RHV080UIFE0P2ATI4208f=S@80RHV90P27QhL208J6QP80Q8B40`22PX8208B4Q0@0
QHF50P23Ph<20820P080OWin0P1oOgl20820P080O7al0P1hN7P207UiN@80Ng]k101lO7`207emOBT0
b>3H0P0c<c<203dm?@80G5aL0P25QHD207IfMP80ATI60P0T92@201hN7P@06a/K0P0L71`202<S8`80
=cLg0P1`L7020:2PX080Rh^;0`1]KFd207inOP80MWIf0P1eMGD2096AT@80_[jn0P33`l<40<[:bP80
c<c<0P3?cll20<?3``80I6AT0P0X:2P2024Q8@808b<S0P0U9BD202HV9P808B4Q0P0O7al202LW9`80
;Rh^0P1;Bd/205EEE@80A4A40P0e=CD203Xj>P80A4A40P1:BTX2055AD@80EUIF0P1XJ6P306UYJ@80
Jf][0P1`L70206m_K`80Ng]k0P1nOWh407emO@80PH610P23Ph<20861P@80QHF50P21PH4207moO`80
RHV9102;Rh/208N7Q`80R8R80P2=SHd209:BTP80V9RH0P2ATI4209JFUP80UiNG0P2IVIT209ZJVP80
UYJF0P2KVi/20:6QX@80WIfM0P2SXj<30::RXP80VYZJ102NWYh20::RXP80Y:BT0P2[Zj/20:ZZZP80
Zj^[0P2ZZZX20:RXZ080YjNW0P2YZJT20:RXZ080ZZZZ0P2VYZH20:RXZ080YZJV102PX:020:FUY@80
XJ6Q0P2NWYh209^KV`80UIFE0P2HV9P2096AT@80S8b<0P2;Rh/208Z:RP80QXJ60P25QHD30820P080
Ph>30P26QXH208N7Q`80QHF50P22PX8207emO@80OWin0P20P80207alO080N7Qh0P1jNWX207]kN`80
O7al0P1kNg/207emOBT0b>3H0P0];Bd20451@@80E5AD0P2@T90207QhN080@4100P0S8b<201`L7080
6a/K0P0J6QX201TI6@809BDU0P0c<c<206m_K`80UiNG0P2HV9P306UYJ@80Jf][0P1cLg<2079bLP80
TY:B0P2m_Kd20<O7a`80clo?1039bLT20<k>cP80alO70P1VIVH2024Q8@80820P0P0N7Qh202LW9`80
92@T0P0V9RH2028R8P80:2PX0P0Z:RX204A4A080H61P0P0l?3`403Lg=`80@d=30P1;Bd/2055AD@80
F5QH0P1OGel506UYJ@80K6a/0P1hN7P207MgM`80OWin0P1oOgl20820P080Ogmo0P23Ph<208N7Q`80
Ogmo0P20P80408N7Q`80QXJ60P2;Rh/208R8R080RHV90P2=SHd209:BTP80UIFE1P2GUiL209JFUP80
V9RH102KVi/209nOW`80Xj>S0P2QXJ430:JVYP80WinO0P2LW9`20:2PX080XZ:R0P2VYZH20:FUY@80
YjNW0P2VYZH20:NWY`80Z:RX0P2YZJT40:NWY`80Z:RX0P2YZJT40:JVYP80Xj>S0P2TY:@20:FUY@80
XJ6Q0P2OWil209ZJVP80VIVI0P2EUID2096AT@80Rh^;0P2:RXX208J6QP80QhN70P23Ph<508B4Q080
PX:20P26QXH208B4Q080P8200P1oOgl208:2PP80OWin0P1lO7`207MgM`@0Ng]k0P1lO7`207emO@80
P8207`38h=P001d0b>3H0P0];Bd203hn?P80E5AD0P2@T90207alO080@d=30P0T92@201/K6`807AdM
0P0I6AT201/K6`808b<S0P0g=cL206e]K@80V9RH0P2FUYH306e]K@80KVi^0P1gMgL207=cL`80Ti>C
0P2m_Kd20<C4a080bl_;0P3:b/X20=3@d080bl_;0P36a/H206QXJ080:BTY0P0Q8B42020P80809BDU
100T92@2028R8P809BDU0P0Z:RX204=3@`80HF5Q0P0m?Cd203/k>`80>CTi0P0o?cl204Q8B080D51@
0P1IFET2065QH@<0JFUY0P1]KFd2071`L080M7Ad0P1hN7P207emO@@0P8200P1nOWh20861P@80Ph>3
0P22PX820861P@80Ph>30P27QhL208V9R@80RXZ:1029RHT208f=S@80TY:B102DU9@209FEU@80UYJF
0P2IVIT209^KV`@0VYZJ0P2NWYh20::RXPD0Xj>S0P2PX:0209jNWP80X:2P0P2SXj<20:JVYP@0YjNW
0P2VYZH20:RXZ080ZJVY0P2XZ:P20:NWY`80Z:RX0P2YZJT20:RXZ080YjNW0P2UYJD20:>SX`80Y:BT
0P2UYJD20::RXP80WYjN0P2KVi/209RHV080UIFE0P2ATI4208f=S@80RHV90P27QhL208J6QP80Q8B4
0`22PX8208B4Q0@0QHF50P23Ph<20820P080OWin0P1oOgl20820P080O7al0P1hN7P207UiN@80Ng]k
101lO7`207emOBT0b>3H0P0c<c<203dm?@80G5aL0P25QHD207IfMP80ATI60P0T92@201hN7P@06a/K
0P0L71`202<S8`80=cLg0P1`L7020:2PX080Rh^;0`1]KFd207inOP80MWIf0P1eMGD2096AT@80_[jn
0P33`l<40<[:bP80c<c<0P3?cll20<?3``80I6AT0P0X:2P2024Q8@808b<S0P0U9BD202HV9P808B4Q
0P0O7al202LW9`80;Rh^0P1;Bd/205EEE@80A4A40P0e=CD203Xj>P80A4A40P1:BTX2055AD@80EUIF
0P1XJ6P306UYJ@80Jf][0P1`L70206m_K`80Ng]k0P1nOWh407emO@80PH610P23Ph<20861P@80QHF5
0P21PH4207moO`80RHV9102;Rh/208N7Q`80R8R80P2=SHd209:BTP80V9RH0P2ATI4209JFUP80UiNG
0P2IVIT209ZJVP80UYJF0P2KVi/20:6QX@80WIfM0P2SXj<30::RXP80VYZJ102NWYh20::RXP80Y:BT
0P2[Zj/20:ZZZP80Zj^[0P2ZZZX20:RXZ080YjNW0P2YZJT20:RXZ080ZZZZ0P2VYZH20:RXZ080YZJV
102PX:020:FUY@80XJ6Q0P2NWYh209^KV`80UIFE0P2HV9P2096AT@80S8b<0P2;Rh/208Z:RP80QXJ6
0P25QHD30820P080Ph>30P26QXH208N7Q`80QHF50P22PX8207emO@80OWin0P20P80207alO080N7Qh
0P1jNWX207]kN`80O7al0P1kNg/207emOBT0b>3H0P0];Bd20451@@80E5AD0P2@T90207QhN080@410
0P0S8b<201`L70806a/K0P0J6QX201TI6@809BDU0P0c<c<206m_K`80UiNG0P2HV9P306UYJ@80Jf][
0P1cLg<2079bLP80TY:B0P2m_Kd20<O7a`80clo?1039bLT20<k>cP80alO70P1VIVH2024Q8@80820P
0P0N7Qh202LW9`8092@T0P0V9RH2028R8P80:2PX0P0Z:RX204A4A080H61P0P0l?3`403Lg=`80@d=3
0P1;Bd/2055AD@80F5QH0P1OGel506UYJ@80K6a/0P1hN7P207MgM`80OWin0P1oOgl20820P080Ogmo
0P23Ph<208N7Q`80Ogmo0P20P80408N7Q`80QXJ60P2;Rh/208R8R080RHV90P2=SHd209:BTP80UIFE
1P2GUiL209JFUP80V9RH102KVi/209nOW`80Xj>S0P2QXJ430:JVYP80WinO0P2LW9`20:2PX080XZ:R
0P2VYZH20:FUY@80YjNW0P2VYZH20:NWY`80Z:RX0P2YZJT40:NWY`80Z:RX0P2YZJT40:JVYP80Xj>S
0P2TY:@20:FUY@80XJ6Q0P2OWil209ZJVP80VIVI0P2EUID2096AT@80Rh^;0P2:RXX208J6QP80QhN7
0P23Ph<508B4Q080PX:20P26QXH208B4Q080P8200P1oOgl208:2PP80OWin0P1lO7`207MgM`@0Ng]k
0P1lO7`207emO@80P8207`38h=P001d0b>3H0P0i>CT204e=C@80Hf=S0P2=SHd206e]K@80CTi>0P0W
9bL201hN7P807AdM0P0K6a/201`L70806a/K0P0U9BD2061PH080T92@0P2TY:@306m_K`80KVi^0P1`
L70207QhN080QHF50P2UYJD20<K6aP80bl_;0P39bLT20<k>cP80d];B0P30`<020<71`@80@T920P0Y
:BT201dM7@8092@T0P0U9BD202HV9P808B4Q0P0N7Qh203<c<`80?clo0P1LG5`203/k>`80>SXj0P0g
=cL203hn?P80AdM70P1ADE4205YJFP80Hf=S0`1YJFT206e]K@80Kfm_0P1dM7@207UiN@80Ng]k0P1m
OGd20820P080PX:20P23Ph<608:2PP80Ph>30P24Q8@208N7Q`80RXZ:0P2<S8`208f=S@80Shn?0P2A
TI4209>CT`80UIFE0P2HV9P409ZJVP@0Vi^K0P2LW9`209nOW`80XZ:R1@2SXj<20:2PX080WinO0P2R
XZ820:JVYP80ZJVY0P2[Zj/20:RXZ080YJFU0P2YZJT20:f][@80Zj^[0P2XZ:P60:VYZ@80Z:RX0P2V
YZH20:>SX`@0Y:BT0P2PX:0209bLW080Vi^K0P2JVYX209NGU`80TY:B0P2=SHd208R8R0@0QhN70P24
Q8@308>3P`80Q8B41P25QHD208:2PP80P8201021PH4207emO@80NGUi0P1jNWX207]kN`80O7al101m
OGdY0<SPf080=3@d0P1ADE4206IVIP80R8R80P1gMgL205QHF08092@T0P0L71`201dM7@806a/K0P0J
6QX201hN7P809RHV0P1IFET209:BTP80WYjN0`1aLG4406m_K`80LG5a0P25QHD20:RXZ080aLG50P39
bLT20<c<c080bl_;0P3<c<`20<k>cP80]KFe0P16ATH202LW9`@08B4Q0P0S8b<202XZ:P809BDU0P0S
8b<202TY:@80AdM70P1FEUH203lo?`80>SXj0P0h>3P203`l?080ADE5101EEED206UYJ@<0IVIV0P1/
K6`2071`L080MWIf0P1gMgL407emO@80QHF50P21PH4208:2PP80Q8B40P20P80408:2PP80Q8B40P27
QhL208V9R@80SHf=0P2;Rh/4092@T080Ti>C0P2EUID209fMW@80UiNG0P2LW9`209fMW@80V9RH0P2P
X:0209fMW@80XJ6Q0P2TY:@30::RXP80XJ6Q0P2RXZ820:2PX080ZZZZ0P2WYjL20:ZZZP80YZJV0P2S
Xj<20:^[Z`80[:b/0P2XZ:P20:ZZZP80Zj^[0P2YZJT20:NWY`80ZJVY102UYJD20:6QX@80YJFU0P2Q
XJ4209VIV@80Vi^K0P2HV9P209NGU`80TY:B0P2>SXh208V9R@80QXJ60P28R8P208B4Q0L0Ph>30P27
QhL208>3P`@0PH610P1mOGd208:2PP80OWin0P1kNg/207QhN080NWYj0P1nOWh207]kN`80OWin:@38
h=P203Xj>P80BTY:0P1RHV82092@T080LG5a0P1<C4`202PX:0808B4Q0P0I6AT2024Q8@@06QXJ0P0R
8R8206=SH`80Shn?0P2SXj<306m_K`80KVi^0P1cLg<207IfMP80QhN70P2PX:020<K6aP80c/k>0P37
alL20<o?c`80d];B0P2l_;`20<;2`P80ADE50P0Y:BT201lO7`809BDU0P0P820202PX:080820P0P0J
6QX203Ph>080?3`l0P1JFUX203hn?P@0>CTi0P0n?Sh20492@P80DU9B0P1HF5P206EUI@<0J6QX0P1^
KVh206e]K@80MGEe0P1hN7P207]kN`80OWin0P21PH4208:2PP80P8200P21PH4208>3P`80PH610P22
PX8208B4Q080R8R80P2:RXX208j>SP80Rh^;1P2BTY8209BDU0@0VIVI0P2JVYX209jNWP80VIVI0P2L
W9`209nOW`80XZ:R0P2PX:030::RXP80X:2P0P2OWil20:>SX`80YjNW0P2YZJT20:^[Z`80YjNW0P2T
Y:@20:ZZZP80[Zj^0P2ZZZX40:VYZ@@0ZZZZ102WYjL20:>SX`80Y:BT0P2UYJD20:2PX080W9bL0P2I
VIT209^KV`80V9RH0P2CTi<208b<S0H0R8R80P23Ph<308:2PP80Ph>30P27QhL208J6QP80QHF50P1o
Ogl20820P080Ph>30P20P80207inOP80N7Qh0P1jNWX207alO080Ng]k0P1mOGd207alO1l0b>3H000M
0<SPf080>CTi0P1=CDd206=SH`80SHf=0P1]KFd204i>CP809bLW0P0N7Qh201dM7@806a/K0P0L71`2
01/K6`809BDU0P1PH602092@T080Y:BT0`1_Kfl206i^KP80L71`0P1hN7P208F5Q@80YJFU0P36a/H2
0<_;b`80bLW90P3>c/h20=;BdP80`<300P31`L420492@P80:BTY0P0M7Ad202@T90809BDU0P0V9RH2
024Q8@807QhN0P0c<c<203lo?`80G5aL0P0k>c/203Xj>P80=cLg0P0n?Sh204M7A`80DE5A0P1JFUX2
06=SH`<0JFUY0P1]KFd206m_K`80M7Ad0P1iNGT207]kN`80OGem0P20P80208:2PP80Ph>31P22PX82
08>3P`80Q8B40P27QhL208Z:RP80S8b<0P2=SHd208n?S`80TI6A0P2CTi<209FEU@80V9RH102JVYX4
09^KV`80W9bL0P2OWil20::RXPD0Xj>S0P2PX:0209nOW`80XZ:R0P2VYZH20:VYZ@80Zj^[0P2XZ:P2
0:FUY@80ZJVY0P2][Jd20:^[Z`80Z:RX1P2YZJT20:RXZ080YZJV0P2SXj<40:BTY080X:2P0P2LW9`2
09^KV`80VYZJ0P2GUiL209:BTP80SHf=0P28R8P408N7Q`80Q8B40`23Ph<208B4Q0H0QHF50P22PX82
0820P0@0PH610P1mOGd207UiN@80NWYj0P1kNg/207alO0@0OGem:@38h=P203@d=080DE5A0P1VIVH2
08R8R080MgMg0P1HF5P202@T908071`L0P0M7Ad201/K6`806QXJ0P0N7Qh202HV9P80FEUI0P2BTY82
09jNWP<0LG5a101_Kfl2075aL@80QHF50P2XZ:P20<G5a@80bLW90P3<c<`20<_;b`80c<c<0P3>c/h2
0;Fe]@80ATI60P0W9bL4024Q8@808b<S0P0Z:RX202DU9@808b<S0P0Y:BT204M7A`80EUIF0P0o?cl2
03Xj>P80>3Ph0P0l?3`204E5A@@0EEEE0P1YJFT306IVIP80K6a/0P1`L70207IfMP80MgMg101mOGd2
08F5Q@80PH610P22PX8208B4Q080P8201022PX8208B4Q080QhN70P29RHT208f=S@80Rh^;102@T902
09>CT`80UIFE0P2MWId209NGU`80W9bL0P2MWId209RHV080X:2P0P2MWId20:6QX@80Y:BT0`2RXZ82
0:6QX@80XZ:R0P2PX:020:ZZZP80YjNW0P2ZZZX20:JVYP80Xj>S0P2[Zj/20:b/[080Z:RX0P2ZZZX2
0:^[Z`80ZJVY0P2WYjL20:VYZ@@0YJFU0P2QXJ420:FUY@80XJ6Q0P2IVIT209^KV`80V9RH0P2GUiL2
09:BTP80SXj>0P29RHT208J6QP80R8R80P24Q8@708>3P`80QhN70P23Ph<40861P@80OGem0P22PX82
07inOP80Ng]k0P1hN7P207YjNP80OWin0P1kNg/207inORT0b>3H0P0j>SX204Y:BP80HV9R0P2@T902
075aL@80C4a<0P0X:2P2024Q8@806ATI0P0Q8B4401XJ6P808R8R0P1SHf<208n?S`80Xj>S0`1_Kfl2
06i^KP80Lg=c0P1fMWH208N7Q`80X:2P0P36a/H20<k>cP80alO70P3?cll20=;BdP80_;bl0P32`/82
04E5A@80:BTY0P0O7al202DU9@80820P0P0X:2P2020P80806QXJ0P0h>3P203`l?080FUYJ0P0n?Sh4
03Ti>@80?Shn0P12@T82059BDP80F5QH0P1UIFD306QXJ080KVi^0P1]KFd207EeM@80N7Qh0P1kNg/2
07inOP80PH610P22PX820820P080PH610P23Ph<20861P@80PX:20P24Q8@208R8R080RXZ:0P2>SXh2
08^;R`H0TY:B0P2DU9@409VIV@80VYZJ0P2NWYh209VIV@80W9bL0P2OWil20::RXP80X:2P0`2RXZ82
0:2PX080WinO0P2SXj<20:NWY`80ZJVY0P2[Zj/20:NWY`80Y:BT0P2ZZZX20:j^[P80ZZZZ102YZJT4
0:ZZZP@0YjNW0P2SXj<20:BTY080YJFU0P2PX:0209bLW080VIVI0P2KVi/209RHV080Ti>C0P2<S8`6
08R8R080Ph>30`22PX8208>3P`80QhN70P26QXH208F5Q@80Ogmo0P20P80208>3P`80P8200P1nOWh2
07QhN080NWYj0P1lO7`207]kN`80OGem0P1lO7`O0<SPf0007@38h=P204=3@`80H61P0P21PH4209fM
W@80RHV90P1PH60202PX:0807QhN0P0O7al201hN7P807alO0P0K6a/2028R8P80?Cdm0P1gMgL20::R
XP<0OWin0P1eMGD206i^KP80LW9b0P1kNg/209fMW@80a<C40P38b<P20<[:bP80c/k>0P3@d=020<_;
b`80`L710P2WYjL204M7A`8071`L0P0T92@2028R8P809bLW0P0S8b<202@T90809RHV0P11@D4205eM
G@80=cLg0P0e=CD203@d=080?Cdm0P18B4P2059BDP80Fe]K0P1RHV8306QXJ080K6a/0P1_Kfl207Ad
M080N7Qh0P1jNWX207alO080P8202023Ph<608B4Q080QhN70P2:RXX208f=S@@0Shn?0P2@T90209BD
U080UiNG102HV9P209^KV`@0WIfM0P2NWYh209nOW`80X:2P1`2QXJ420::RXP80YZJV0P2ZZZX20:^[
Z`80[:b/0P2YZJT20:NWY`80ZJVY102/[:`40:^[Z`H0ZZZZ0P2WYjL20:BTY0@0YJFU0P2RXZ8209jN
WP80W9bL0P2JVYX209NGU`80U9BD0P2>SXh208R8R080QhN70P26QXH208F5Q@<0Q8B40P25QHD208J6
QP80QHF50P24Q8@208:2PP@0PH610P20P80207emO@@0NGUi0P1jNWX207emO@@0Ogmo:@38h=P204=3
@`80HV9R0P1nOWh209>CT`80Ogmo0P1PH60202HV9P807AdM0P0O7al202@T90807AdM0P0N7Qh202@T
9080>c/k0P21PH4209bLW0<0Ogmo0P1eMGD206i^KP80L71`0P1nOWh20:2PX080a/K60P37alL20<[:
bP80c<c<0P3=cLd20<k>cP80c<c<0P2UYJD203lo?`809RHV1P0S8b<4024Q8@80:b/[0P11@D4205MG
E`80?3`l0P0g=cL203@d=080?3`l0P15ADD2051@D080Fe]K0P1TI6@306EUI@80K6a/0P1`L70207Ad
M080MWIf0P1lO7`207UiN@@0PH610P20P80208>3P`80QHF50P26QXH208N7Q`80Ph>30P26QXH208V9
R@80TI6A0P2?Shl209:BTP80SXj>102CTi<209NGU`80UIFE0P2KVi/209bLW080WinO0P2JVYX209nO
W`80Y:BT0P2RXZ830:2PX080Y:BT0P2PX:020:BTY080ZZZZ0P2/[:`20:f][@80YZJV0P2SXj<20:^[
Z`80[Jf]0P2/[:`40:RXZ080Zj^[0P2ZZZX20:VYZ@80ZZZZ0P2WYjL40:FUY@80YZJV0P2NWYh409fM
W@80UiNG0P2DU9@208R8R080QhN70P25QHD208B4Q080QXJ60`25QHD208N7Q`80QXJ60P28R8P208>3
P`80PX:21023Ph<20861P@80O7al0P1gMgL207QhN080OGem0P1kNg/207inOP80Ph>3:@38h=P204A4
A080HF5Q0P22PX8209bLW080R8R80P1LG5`202TY:@806QXJ0P0P820201hN7P80820P0P0J6QX202@T
9080@D510P1eMGD20:>SX`<0Ogmo0P1fMWH2071`L080LG5a0P20P80209fMW@80`/;20P3:b/X20<W9
b@80d];B0P3=cLd20=3@d080`/;20P2YZJT204U9B@8061PH0P0W9bL201lO7`809RHV0P0W9bL202<S
8`809bLW0P15ADD205]KF`80>CTi0P0g=cL2034a<@80?clo0P17AdL205IFEP80FEUI0P1XJ6P306=S
H`80L71`0P1aLG4207IfMP80MGEe0P1iNGT207]kN`80Ogmo0P27QhL207inOP80QHF50P27QhL208B4
Q080QHF50P24Q8@208N7Q`80R8R80P2>SXh208f=S@80Shn?0P2>SXh209:BTP80UiNG0P2FUYH209ZJ
VP80VIVI0P2NWYh20:2PX080WIfM0P2QXJ420:2PX080XJ6Q0`2PX:020::RXP80Y:BT0P2UYJD20:^[
Z`80ZZZZ0P2][Jd20:^[Z`80YjNW0P2[Zj/20:b/[080ZZZZ0P2][Jd20:ZZZP80Z:RX0P2YZJT20:ZZ
ZP80YjNW0P2SXj<20:BTY080Z:RX0P2LW9`20:2PX080WYjN0P2HV9P209JFUP80Ti>C0P2=SHd408R8
R080QHF50P27QhL508B4Q080QXJ60P27QhL208F5Q@@0P8200P21PH420820P0@0NWYj101iNGT207em
O@80OWin0P1mOGdO0<SPf0007@38h=P204=3@`80H61P0P21PH4209fMW@80RHV90P1PH60202PX:080
7QhN0P0O7al201hN7P807alO0P0K6a/2028R8P80?Cdm0P1gMgL20::RXP<0OWin0P1eMGD206i^KP80
LW9b0P1kNg/209fMW@80a<C40P38b<P20<[:bP80c/k>0P3@d=020<_;b`80`L710P2WYjL204M7A`80
71`L0P0T92@2028R8P809bLW0P0S8b<202@T90809RHV0P11@D4205eMG@80=cLg0P0e=CD203@d=080
?Cdm0P18B4P2059BDP80Fe]K0P1RHV8306QXJ080K6a/0P1_Kfl207AdM080N7Qh0P1jNWX207alO080
P8202023Ph<608B4Q080QhN70P2:RXX208f=S@@0Shn?0P2@T90209BDU080UiNG102HV9P209^KV`@0
WIfM0P2NWYh209nOW`80X:2P1`2QXJ420::RXP80YZJV0P2ZZZX20:^[Z`80[:b/0P2YZJT20:NWY`80
ZJVY102/[:`40:^[Z`H0ZZZZ0P2WYjL20:BTY0@0YJFU0P2RXZ8209jNWP80W9bL0P2JVYX209NGU`80
U9BD0P2>SXh208R8R080QhN70P26QXH208F5Q@<0Q8B40P25QHD208J6QP80QHF50P24Q8@208:2PP@0
PH610P20P80207emO@@0NGUi0P1jNWX207emO@@0Ogmo:@38h=P204=3@`80HV9R0P1nOWh209>CT`80
Ogmo0P1PH60202HV9P807AdM0P0O7al202@T90807AdM0P0N7Qh202@T9080>c/k0P21PH4209bLW0<0
Ogmo0P1eMGD206i^KP80L71`0P1nOWh20:2PX080a/K60P37alL20<[:bP80c<c<0P3=cLd20<k>cP80
c<c<0P2UYJD203lo?`809RHV1P0S8b<4024Q8@80:b/[0P11@D4205MGE`80?3`l0P0g=cL203@d=080
?3`l0P15ADD2051@D080Fe]K0P1TI6@306EUI@80K6a/0P1`L70207AdM080MWIf0P1lO7`207UiN@@0
PH610P20P80208>3P`80QHF50P26QXH208N7Q`80Ph>30P26QXH208V9R@80TI6A0P2?Shl209:BTP80
SXj>102CTi<209NGU`80UIFE0P2KVi/209bLW080WinO0P2JVYX209nOW`80Y:BT0P2RXZ830:2PX080
Y:BT0P2PX:020:BTY080ZZZZ0P2/[:`20:f][@80YZJV0P2SXj<20:^[Z`80[Jf]0P2/[:`40:RXZ080
Zj^[0P2ZZZX20:VYZ@80ZZZZ0P2WYjL40:FUY@80YZJV0P2NWYh409fMW@80UiNG0P2DU9@208R8R080
QhN70P25QHD208B4Q080QXJ60`25QHD208N7Q`80QXJ60P28R8P208>3P`80PX:21023Ph<20861P@80
O7al0P1gMgL207QhN080OGem0P1kNg/207inOP80Ph>3:@38h=P204A4A080HF5Q0P22PX8209bLW080
R8R80P1LG5`202TY:@806QXJ0P0P820201hN7P80820P0P0J6QX202@T9080@D510P1eMGD20:>SX`<0
Ogmo0P1fMWH2071`L080LG5a0P20P80209fMW@80`/;20P3:b/X20<W9b@80d];B0P3=cLd20=3@d080
`/;20P2YZJT204U9B@8061PH0P0W9bL201lO7`809RHV0P0W9bL202<S8`809bLW0P15ADD205]KF`80
>CTi0P0g=cL2034a<@80?clo0P17AdL205IFEP80FEUI0P1XJ6P306=SH`80L71`0P1aLG4207IfMP80
MGEe0P1iNGT207]kN`80Ogmo0P27QhL207inOP80QHF50P27QhL208B4Q080QHF50P24Q8@208N7Q`80
R8R80P2>SXh208f=S@80Shn?0P2>SXh209:BTP80UiNG0P2FUYH209ZJVP80VIVI0P2NWYh20:2PX080
WIfM0P2QXJ420:2PX080XJ6Q0`2PX:020::RXP80Y:BT0P2UYJD20:^[Z`80ZZZZ0P2][Jd20:^[Z`80
YjNW0P2[Zj/20:b/[080ZZZZ0P2][Jd20:ZZZP80Z:RX0P2YZJT20:ZZZP80YjNW0P2SXj<20:BTY080
Z:RX0P2LW9`20:2PX080WYjN0P2HV9P209JFUP80Ti>C0P2=SHd408R8R080QHF50P27QhL508B4Q080
QXJ60P27QhL208F5Q@@0P8200P21PH420820P0@0NWYj101iNGT207emO@80OWin0P1mOGdO0<SPf000
7@38h=P2051@D080Lg=c0P2OWil20:FUY@80VYZJ0P1SHf<202TY:@807alO0P0R8R82024Q8@808b<S
0P0O7al202DU9@807QhN0P1JFUX209FEU@<0SHf=0P1oOgl206e]K@80JVYZ0P1cLg<209JFUP80^k^k
0P35aLD20<_;b`80c<c<0P3;bl/20=CDe080d=3@0P34a<@208^;R`80<c<c0P0U9BD201hN7P809bLW
0P0V9RH202/[:`806QXJ0P15ADD205]KF`80=3@d0P0b<S82034a<@80?3`l0P1:BTX205ADE080G5aL
0P1QHF4306IVIP80Jf][0P1`L70207AdM080MgMg0P1iNGT207]kN`80Ogmo1P23Ph<208F5Q@80QXJ6
1025QHD208N7Q`80Rh^;0P2>SXh208n?S`80T92@0P2ATI4209FEU@80VIVI0P2HV9P209NGU`80VYZJ
0P2NWYh:09nOW`<0X:2P0P2RXZ820:FUY@80ZZZZ102][Jd20:^[Z`80ZZZZ102YZJT20:ZZZP80[Jf]
0P2^[Zh20:b/[0@0ZZZZ0P2[Zj/20:RXZ0H0YJFU0P2SXj<20:6QX@80WIfM0P2IVIT209NGU`80UIFE
0P2?Shl208V9R@80QXJ61`25QHD208N7Q`80R8R80P26QXH208B4Q080Ph>30P21PH420820P080Ogmo
0P1lO7`407UiN@80NWYj0P1mOGd20861P@80PX:2:@38h=P205=CD`80M7Ad0P2KVi/20:f][@80V9RH
0P1YJFT202HV9P807QhN0P0P820202@T90808b<S0P0O7al2020P80809RHV0P1KFe/208b<S0<0U9BD
0P1lO7`206i^KP80Jf][0P1dM7@2092@T080][Jf0P3>c/h20<K6aP80cLg=0P3?cll40<g=c@80bLW9
0P2;Rh/2034a<@808R8R100W9bL202@T9080:b/[0P0V9RH204A4A080EEEE0P0h>3P202l_;`80=CDe
0P0i>CT204a<C080EUIF0P1JFUX206EUI@<0IVIV0P1_Kfl2075aL@80Lg=c0P1fMWH207inOP80N7Qh
0P23Ph<208F5Q@80P8200P23Ph<608F5Q@80QXJ60P27QhL408^;R`80T92@0P2CTi<208n?S`80UIFE
202HV9P20:2PX080WIfM0P2PX:020:BTY080W9bL0P2MWId30:2PX080Xj>S0P2XZ:P20:BTY080[Jf]
0P2a/K420:VYZ@80ZZZZ0P2WYjL20:b/[080Z:RX0P2^[Zh20;2`/080Zj^[0P2ZZZX40:b/[080YJFU
0P2WYjL20:2PX080YJFU0P2VYZH209nOW`80WYjN0P2HV9P209VIV@80U9BD0P2ATI4208Z:RP80QHF5
1`26QXH208B4Q080R8R80P26QXH208:2PP80QHF51020P80207moO`80Ng]k0P1jNWX207QhN080Ng]k
0P1lO7`408:2PRT0b>3H0P1ADE42075aL@80X:2P0P2UYJD209ZJVP80I6AT0P0V9RH2020P80807alO
100S8b<201hN7P808b<S0P0J6QX205UIF@80VIVI0`29RHT208B4Q080K6a/0P1UIFD207AdM080UYJF
0P2l_;`20<G5a@80c<c<0P39bLT20<c<c080dm?C0P3>c/h20<G5a@80S8b<0P0a<C4202LW9`806a/K
0P0Z:RX202@T9080;Bd]0P0J6QX204M7A`80FEUI0P0e=CD4030`<080?3`l0P19BDT2055AD@80G5aL
1`1VIVH206i^KP80M7Ad0P1eMGD207YjNP80NGUi0P1oOgl208F5Q@80Ogmo0P26QXH208F5Q@80QhN7
0P26QXH208F5Q@80RHV90P2=SHd208b<S080T92@0P2BTY82096AT@80UIFE0P2IVIT209RHV080UiNG
0P2IVIT409jNWP@0WinO0P2PX:0509nOW`@0Xj>S0P2YZJT40:f][@80ZJVY0P2[Zj/20:NWY`80[Jf]
0P2[Zj/20:RXZ0@0[jn_102[Zj/20:ZZZP80ZJVY0P2UYJD20:BTY080YJFU0P2PX:020:>SX`80WIfM
0P2KVi/209JFUP80UIFE0P2ATI4208R8R080QhN70P24Q8@208N7Q`<0Ph>31027QhL408B4Q080Ph>3
0P22PX820861P@80Ogmo201jNWX207inOP80PX:20P20P80O0<SPf0007@38h=P2051@D080Lg=c0P2O
Wil20:FUY@80VYZJ0P1SHf<202TY:@807alO0P0R8R82024Q8@808b<S0P0O7al202DU9@807QhN0P1J
FUX209FEU@<0SHf=0P1oOgl206e]K@80JVYZ0P1cLg<209JFUP80^k^k0P35aLD20<_;b`80c<c<0P3;
bl/20=CDe080d=3@0P34a<@208^;R`80<c<c0P0U9BD201hN7P809bLW0P0V9RH202/[:`806QXJ0P15
ADD205]KF`80=3@d0P0b<S82034a<@80?3`l0P1:BTX205ADE080G5aL0P1QHF4306IVIP80Jf][0P1`
L70207AdM080MgMg0P1iNGT207]kN`80Ogmo1P23Ph<208F5Q@80QXJ61025QHD208N7Q`80Rh^;0P2>
SXh208n?S`80T92@0P2ATI4209FEU@80VIVI0P2HV9P209NGU`80VYZJ0P2NWYh:09nOW`<0X:2P0P2R
XZ820:FUY@80ZZZZ102][Jd20:^[Z`80ZZZZ102YZJT20:ZZZP80[Jf]0P2^[Zh20:b/[0@0ZZZZ0P2[
Zj/20:RXZ0H0YJFU0P2SXj<20:6QX@80WIfM0P2IVIT209NGU`80UIFE0P2?Shl208V9R@80QXJ61`25
QHD208N7Q`80R8R80P26QXH208B4Q080Ph>30P21PH420820P080Ogmo0P1lO7`407UiN@80NWYj0P1m
OGd20861P@80PX:2:@38h=P205=CD`80M7Ad0P2KVi/20:f][@80V9RH0P1YJFT202HV9P807QhN0P0P
820202@T90808b<S0P0O7al2020P80809RHV0P1KFe/208b<S0<0U9BD0P1lO7`206i^KP80Jf][0P1d
M7@2092@T080][Jf0P3>c/h20<K6aP80cLg=0P3?cll40<g=c@80bLW90P2;Rh/2034a<@808R8R100W
9bL202@T9080:b/[0P0V9RH204A4A080EEEE0P0h>3P202l_;`80=CDe0P0i>CT204a<C080EUIF0P1J
FUX206EUI@<0IVIV0P1_Kfl2075aL@80Lg=c0P1fMWH207inOP80N7Qh0P23Ph<208F5Q@80P8200P23
Ph<608F5Q@80QXJ60P27QhL408^;R`80T92@0P2CTi<208n?S`80UIFE202HV9P20:2PX080WIfM0P2P
X:020:BTY080W9bL0P2MWId30:2PX080Xj>S0P2XZ:P20:BTY080[Jf]0P2a/K420:VYZ@80ZZZZ0P2W
YjL20:b/[080Z:RX0P2^[Zh20;2`/080Zj^[0P2ZZZX40:b/[080YJFU0P2WYjL20:2PX080YJFU0P2V
YZH209nOW`80WYjN0P2HV9P209VIV@80U9BD0P2ATI4208Z:RP80QHF51`26QXH208B4Q080R8R80P26
QXH208:2PP80QHF51020P80207moO`80Ng]k0P1jNWX207QhN080Ng]k0P1lO7`408:2PRT0b>3H0P1A
DE42075aL@80X:2P0P2UYJD209ZJVP80I6AT0P0V9RH2020P80807alO100S8b<201hN7P808b<S0P0J
6QX205UIF@80VIVI0`29RHT208B4Q080K6a/0P1UIFD207AdM080UYJF0P2l_;`20<G5a@80c<c<0P39
bLT20<c<c080dm?C0P3>c/h20<G5a@80S8b<0P0a<C4202LW9`806a/K0P0Z:RX202@T9080;Bd]0P0J
6QX204M7A`80FEUI0P0e=CD4030`<080?3`l0P19BDT2055AD@80G5aL1`1VIVH206i^KP80M7Ad0P1e
MGD207YjNP80NGUi0P1oOgl208F5Q@80Ogmo0P26QXH208F5Q@80QhN70P26QXH208F5Q@80RHV90P2=
SHd208b<S080T92@0P2BTY82096AT@80UIFE0P2IVIT209RHV080UiNG0P2IVIT409jNWP@0WinO0P2P
X:0509nOW`@0Xj>S0P2YZJT40:f][@80ZJVY0P2[Zj/20:NWY`80[Jf]0P2[Zj/20:RXZ0@0[jn_102[
Zj/20:ZZZP80ZJVY0P2UYJD20:BTY080YJFU0P2PX:020:>SX`80WIfM0P2KVi/209JFUP80UIFE0P2A
TI4208R8R080QhN70P24Q8@208N7Q`<0Ph>31027QhL408B4Q080Ph>30P22PX820861P@80Ogmo201j
NWX207inOP80PX:20P20P80O0<SPf0007@38h=P2065QH@80QhN70P2a/K420:FUY@80SHf=0P19BDT2
02XZ:P80820P0P0T92@202DU9@809bLW0P0T92@202LW9`807alO0P11@D4207emO@<0T92@0P2ATI42
06IVIP80JFUY0P1_Kfl208N7Q`80X:2P0P3:b/X20<S8b080c<c<0P39bLT20=3@d080cLg=0P3IfMT2
0;Bd]080Jf][0P0R8R82020P80809RHV0P0U9BD202PX:0809RHV0P13@d<204Y:BP80>3Ph100e=CD2
03lo?`80C4a<0P1EEED205aLG080Hf=S0`1XJ6P206e]K@80LG5a0P1eMGD207QhN080Ng]k0P1nOWh2
0861P@80Ph>31022PX8208B4Q0H0QhN70P2:RXX208f=S@80SXj>0P2@T902096AT@80Ti>C0P2FUYH6
09RHV080Vi^K1P2NWYh20:2PX080XZ:R0P2SXj<30:FUY@80YZJV0P2XZ:P20:f][@80/;2`0P2^[Zh4
0:b/[0H0[Jf]102^[Zh20:^[Z`80ZJVY0P2ZZZX20:^[Z`80ZJVY0P2WYjL20:FUY@80Y:BT0P2SXj<2
0:6QX@80WIfM0P2IVIT209NGU`80UYJF0P2@T90208Z:RP80R8R82`26QXH208R8R080RHV90P25QHD2
0861P@80P8200P1oOgl207inOP80O7al101kNg/207moO`80PX:20P23Ph<Y0<SPf080GemO0P20P802
0;Jf]P80[Jf]0P2:RXX2055AD@80:BTY100S8b<202PX:0809BDU0P0P820202PX:08092@T0P0k>c/2
07YjNP<0VIVI0P23Ph<206e]K@@0Kfm_0P21PH420:2PX080dM7A0P37alL20<W9b@80bl_;0P3<c<`2
0<g=c@80dM7A0P31`L4205aLG0809bLW0P0P820202HV9P808b<S0P0T92@202DU9@80@4100P1>CTh2
03Ti>@80<C4a0P0h>3P203lo?`80Cdm?0P1DE5@205]KF`80HV9R0`1UIFD206a/K080L71`0P1_Kfl2
07QhN080O7al0P1mOGd207inOP80QHF50P1oOgl208N7Q`80Q8B40P26QXH208F5Q@80Q8B40P2=SHd2
08n?S`80Rh^;0P2<S8`2092@T080Ti>C0P2HV9P209^KV`@0VIVI0P2LW9`209jNWP80Vi^K0P2NWYh2
09bLW080Y:BT0P2QXJ430:JVYP80Xj>S0P2ZZZX20:b/[080/[:b0P2][Jd40:b/[080[jn_0P2^[Zh2
0:^[Z`80[:b/0P2^[Zh20:f][@@0Z:RX0P2[Zj/20:JVYP@0YjNW0P2QXJ420::RXP80WinO0P2IVIT2
09FEU@80UiNG0P2EUID2096AT@80RXZ:0P28R8P208J6QP80RHV91@24Q8@608N7Q`80RXZ:0P1nOWh2
07]kN`80P8200P1oOgl20820P080NGUi0P1kNg/207emO@80PH610P25QHDY0<SPf080HF5Q0P29RHT2
0:n_[`80YZJV0P2=SHd204a<C080;Bd]0P0Q8B4202PX:0808b<S0P0X:2P202<S8`80:b/[0P0R8R82
0492@P80OGem0`2>SXh209:BTP80J6QX0P1UIFD2071`L080RHV90P2NWYh20<g=c@80alO70P3<c<`2
0<[:bP80clo?0P3<c<`20=OGe`80/[:b0P1^KVh2028R8P808B4Q100U9BD202HV9P809BDU0P10@402
04A4A080>SXj0P0h>3P203Lg=`80@T920P1<C4`205EEE@80EeMG0P1UIFD306UYJ@80KVi^0P1bLW82
07UiN@@0NWYj0P21PH4608:2PP80OWin0P24Q8@208:2PP@0QHF50P2;Rh/208Z:RP80Shn?0P2@T902
08n?S`80Ti>C0P2EUID209RHV080UiNG0P2IVIT209ZJVP80X:2P0P2MWId209jNWP80WinO0P2QXJ42
0:JVYP<0Xj>S0P2XZ:P40:^[Z`80/[:b1P2][Jd20:^[Z`80ZZZZ0P2_[jl20:f][@80[jn_0P2[Zj/2
0:JVYP80ZZZZ0P2[Zj/20:VYZ@80Z:RX0P2WYjL20:FUY@80Y:BT0P2PX:0209ZJVP80V9RH0P2JVYX2
09BDU080TI6A1028R8P208J6QP80QhN70`28R8P208J6QPH0R8R80P27QhL207moO`@0P820101mOGd4
07UiN@H0PX:27`38h=P001d0b>3H0P1QHF4208N7Q`80/K6a0P2UYJD208f=S@80BDU90P0Z:RX2020P
808092@T0P0U9BD202LW9`8092@T0P0W9bL201lO7`80@D510P1mOGd3092@T080TI6A0P1VIVH206UY
J@80Kfm_0P27QhL20:2PX080b/[:0P38b<P20<c<c080bLW90P3@d=020<g=c@80fMWI0P2d];@206][
J`808R8R0P0P820202HV9P809BDU0P0X:2P202HV9P80@d=30P1:BTX203Ph>0@0=CDe0P0o?cl204a<
C080EEEE0P1LG5`206=SH`<0J6QX0P1]KFd2075aL@80MGEe0P1hN7P207]kN`80OWin0P21PH4208>3
P`@0PX:20P24Q8@608N7Q`80RXZ:0P2=SHd208j>SP80T92@0P2ATI4209>CT`80UYJF1P2HV9P209^K
V`H0WYjN0P2PX:020::RXP80Xj>S0`2UYJD20:JVYP80Z:RX0P2][Jd20;2`/080[Zj^102/[:`60:f]
[@@0[Zj^0P2[Zj/20:VYZ@80ZZZZ0P2[Zj/20:VYZ@80YjNW0P2UYJD20:BTY080Xj>S0P2QXJ4209fM
W@80VIVI0P2GUiL209JFUP80T92@0P2:RXX208R8R0/0QXJ60P28R8P208V9R@80QHF50P21PH420820
P080Ogmo0P1nOWh207alO0@0Ng]k0P1oOgl208:2PP80Ph>3:@38h=P205mOG`80P8200P2f][H20:f]
[@80RXZ:0P1ADE4202TY:@@08b<S0P0X:2P202DU9@80820P0P0X:2P202@T9080>c/k0P1jNWX309VI
V@80Ph>30P1]KFd406m_K`80PH610P2PX:020=7Ad@80alO70P39bLT20<_;b`80c<c<0P3=cLd20=7A
d@80`L710P1LG5`202LW9`80820P0P0V9RH202<S8`8092@T0P0U9BD20410@080CTi>0P0i>CT2034a
<@80>3Ph0P0o?cl204m?C`80E5AD0P1KFe/2069RHP<0IFEU0P1/K6`2071`L080Kfm_0P1hN7P207al
O080OGem0P1nOWh208F5Q@80Ogmo0P27QhL208B4Q080QXJ60P25QHD208B4Q080SHf=0P2?Shl208^;
R`80S8b<0P2@T90209>CT`80V9RH0P2KVi/409VIV@80W9bL0P2NWYh209^KV`80WYjN0P2LW9`20:BT
Y080XJ6Q0`2VYZH20:>SX`80ZZZZ0P2/[:`20;:b/P80[Jf]102/[:`20:n_[`80[Zj^0P2[Zj/20:b/
[080[Zj^0P2][Jd40:RXZ080Zj^[0P2VYZH40:NWY`80XJ6Q0P2RXZ8209nOW`80VIVI0P2EUID209NG
U`80UIFE0P2ATI4208Z:RP80R8R80P26QXH208V9R@D0Q8B41P27QhL208Z:RP80OWin0P1kNg/20820
P080Ogmo0P20P80207UiN@80Ng]k0P1mOGd20861P@80QHF5:@38h=P2065QH@80RHV90P2_[jl20:JV
YP80SHf=0P1<C4`202d];@808B4Q0P0X:2P202<S8`80:2PX0P0S8b<202/[:`808R8R0P12@T8207em
O@<0SXj>0P2BTY8206QXJ080IFEU0P1`L70208V9R@80WYjN0P3=cLd20<O7a`80c<c<0P3:b/X20<o?
c`80c<c<0P3GemL20;:b/P80KVi^0P0R8R82024Q8@@09BDU0P0V9RH202DU9@80@4100P14A4@203Xj
>P80>3Ph0P0g=cL20492@P80C4a<0P1EEED205MGE`80IFEU0`1YJFT206i^KP80LW9b0P1iNGT407Yj
NP80PH611P22PX8207inOP80Q8B40P22PX8408F5Q@80Rh^;0P2:RXX208n?S`80T92@0P2?Shl209>C
T`80UIFE0P2HV9P209NGU`80VIVI0P2JVYX20:2PX080WIfM0P2NWYh209nOW`80XJ6Q0P2VYZH30:>S
X`80Z:RX102[Zj/20;:b/PH0[Jf]0P2[Zj/20:ZZZP80[jn_0P2][Jd20:n_[`80Zj^[0P2VYZH20:ZZ
ZP80Zj^[0P2YZJT20:RXZ080YjNW0P2UYJD20:BTY080X:2P0P2JVYX209RHV080VYZJ0P2DU9@2096A
T@@0R8R80P26QXH208N7Q`<0R8R80P26QXH608R8R080QhN70P1oOgl40820P0@0OGem101iNGT608:2
PQl0b>3H000M0<SPf080MWIf0P2EUID20;>c/`80VIVI0P1cLg<202/[:`80:RXZ0P0R8R8202HV9P80
9bLW1P0Y:BT202PX:080;Rh^0P1QHF4308b<S080WYjN0P1UIFD206YZJP80KVi^0P1hN7P208F5Q@80
bLW90P35aLD20<_;b`80a/K60P39bLT20<[:bP80fMWI0P3Cdm<20:BTY080<30`100V9RH202<S8`80
92@T0P0c<c<203lo?`@0>c/k0P0h>3P203Ti>@80@T920P1>CTh205IFEP80GEeM0P1UIFD306][J`80
Kfm_0P1cLg<207IfMP80NGUi0P1mOGd20861P@80PX:21P21PH4208B4Q080QhN70P28R8P208Z:RP80
S8b<0P2>SXh208n?S`80T92@0P2CTi<209JFUP@0UiNG0P2HV9P209VIV@80Vi^K0P2MWId409bLW080
X:2P0P2UYJD20:RXZ0<0ZJVY0P2ZZZX20:^[Z`80[jn_0P2b/[820;2`/080[Jf]0P2_[jl40;6a/@80
/;2`0P2_[jl20:f][@80ZZZZ0P2XZ:P20:VYZ@80Zj^[0P2ZZZX20:RXZ080YZJV0P2SXj<20::RXP80
X:2P0P2LW9`209VIV@80UiNG0P2FUYH2096AT@80S8b<0P2:RXX208R8R0D0QhN70P26QXH208F5Q@80
RXZ:0P2>SXh208N7Q`H0P8200P1oOgl207inOP@0O7al0P20P80208>3P`80Q8B4:@38h=P207UiN@80
Ti>C0P2b/[8209RHV080KVi^0P0b<S82024Q8@80;Rh^0P0R8R8202HV9P@0:b/[0P0X:2P202LW9`80
<30`0P1PH603092@T080UIFE0P1]KFd206ATI080L71`0P1iNGT208F5Q@80`l?30P3:b/X20<G5a@80
b<S80P3;bl/20<k>cP80dM7A0P3De=@20:NWY`80;bl_0P0R8R8402DU9@80:2PX0P0_;bl203Ti>@80
B4Q80P0g=cL203Hf=P80?3`l0P17AdL2055AD@80De=C0P1NGUh206EUI@<0KVi^0P1]KFd207MgM`80
M7Ad0P1jNWX20820P080OWin1023Ph<207inOP80Q8B40P22PX8208J6QP80QhN70P2:RXX608f=S@80
T92@0P2GUiL209BDU080V9RH0P2FUYH209NGU`80V9RH102LW9`209^KV`80WIfM0P2LW9`20:FUY@80
ZJVY0`2WYjL20:f][@@0Zj^[0P2d];@20:n_[`80[Jf]0P2_[jl20;6a/@80[jn_0P2b/[820:n_[`80
[:b/0P2XZ:P20:NWY`@0[:b/0P2WYjL20:VYZ@80YjNW0P2TY:@20:6QX@80XZ:R0P2NWYh209ZJVP80
VIVI0P2CTi<2096AT@80RXZ:0P29RHT208F5Q@80R8R80`26QXH208F5Q@80QhN70P28R8P2096AT@80
QXJ60P23Ph<207moO`@0PH610P1jNWX207emO@@0O7al0P24Q8@208V9RBT0b>3H0P1dM7@209RHV080
/[:b0P2LW9`206m_K`80;Bd]0P0X:2P201dM7@809BDU100Y:BT202DU9@80;2`/0P0V9RH2030`<080
GUiN0`2=SHd209nOW`80IfMW0P1UIFD206i^KP80NWYj0P25QHD20<_;b`@0alO70P36a/H20<[:bP80
c<c<0P3GemL20<o?c`80YjNW0P0[:b/202@T9080:2PX0P0Q8B4202PX:080<c<c0P11@D4203dm?@80
>CTi0P0k>c/203Hf=P80?Shn0P1<C4`205QHF080GUiN0P1UIFD306UYJ@80L71`0P1bLW8207=cL`80
N7Qh0P20P8020861P@@0P8200P24Q8@20820P080QhN70P28R8P208b<S080RHV90P2=SHd208j>SPH0
TI6A0P2FUYH409NGU`80VIVI0P2JVYX209VIV@@0W9bL0P2KVi/20:6QX@80Y:BT1`2YZJT20:ZZZP80
[Zj^0P2a/K420;:b/P80[:b/0P2_[jl20;>c/`@0/K6a0P2^[Zh20:f][@80Zj^[0P2XZ:P20:^[Z`80
[:b/0P2[Zj/20:VYZ@80Xj>S0P2QXJ420:FUY@80WinO102JVYX209VIV@80UIFE0P2ATI4208V9R@80
S8b<0P27QhL208F5Q@D0QhN70P26QXH208R8R080SHf=0P2;Rh/20820P080OGem0P1oOgl208>3P`80
OGem101lO7`207inOP80QHF50P27QhLO0<SPf0007@38h=P207IfMP80UIFE0P2c/k<209VIV@80Lg=c
0P0[:b/202XZ:P808R8R0P0V9RH202LW9`H0:BTY0P0X:2P202h^;P80HF5Q0`2<S8`209jNWP80IFEU
0P1ZJVX206i^KP80N7Qh0P25QHD20<W9b@80aLG50P3;bl/20<K6aP80bLW90P3:b/X20=WIf@80dm?C
0P2TY:@2030`<0@09RHV0P0S8b<202@T9080<c<c0P0o?cl403/k>`80>3Ph0P0i>CT20492@P80CTi>
0P1FEUH205eMG@80IFEU0`1[Jf/206m_K`80Lg=c0P1fMWH207UiN@80OGem0P21PH4208:2PPH0PH61
0P24Q8@208N7Q`80R8R80P2:RXX208b<S080SXj>0P2?Shl2092@T080Ti>C0P2FUYH409NGU`80V9RH
0P2IVIT209^KV`80WIfM102LW9`20:2PX080YJFU0P2XZ:P30:VYZ@80ZZZZ0P2[Zj/20:n_[`80/[:b
0P2`/;020:f][@80[jn_102a/K420;2`/080[jn_0P2][Jd20:ZZZP80Z:RX0P2YZJT20:^[Z`80ZZZZ
0P2XZ:P20:JVYP80Xj>S0P2RXZ820:2PX080W9bL0P2IVIT209NGU`80UYJF0P2ATI4208b<S080RXZ:
0P28R8P508N7Q`80QXJ60P25QHD208Z:RP80SXj>0P27QhL60820P080Ogmo0P1nOWh407alO080P820
0P23Ph<208B4Q2T0b>3H0P1iNGT209>CT`80/[:b0P2HV9P206i^KP80<S8b0P0Q8B4202h^;P808R8R
0P0V9RH402/[:`80:2PX0P0W9bL2030`<080H61P0`2@T90209FEU@80KFe]0P1TI6@2071`L080NGUi
0P25QHD20<?3``80b/[:0P35aLD20<S8b080bl_;0P3>c/h20=7Ad@80e=CD0P2WYjL202l_;`808R8R
100U9BD202PX:080;bl_0P0i>CT204Q8B080=cLg0P0f=SH203`l?080AdM70P1ADE4205=CD`80GUiN
0P1UIFD306i^KP80KFe]0P1gMgL207AdM080NWYj0P20P80207inOP@0Ph>30P1nOWh208B4Q080PX:2
0P26QXH208N7Q`80RXZ:1P2=SHd2092@T080UiNG0P2DU9@209RHV080UYJF0P2GUiL209RHV0@0W9bL
0P2KVi/209fMW@80W9bL0P2UYJD20:VYZ@<0YjNW0P2][Jd40:^[Z`80];Bd0P2_[jl20:f][@80[jn_
0P2a/K420:n_[`80/[:b0P2_[jl20:b/[080Z:RX0P2WYjL40:b/[080YjNW0P2YZJT20:NWY`80Y:BT
0P2QXJ420::RXP80WYjN0P2JVYX209VIV@80Ti>C0P2ATI4208Z:RP80RHV90P25QHD208R8R0<0QXJ6
0P25QHD208N7Q`80R8R80P2ATI4208J6QP80Ph>30P1oOgl40861P@80NWYj0P1mOGd407alO080Q8B4
0P29RHTY0<SPf080M7Ad0P2HV9P20;:b/P80W9bL0P1_Kfl202d];@80:2PX0P0M7Ad202DU9@@0:BTY
0P0U9BD202`/;0809RHV0P0`<30205iNGP<0SHf=0P2OWil206MWI`80IFEU0P1^KVh207YjNP80QHF5
0P3;bl/40<O7a`80a/K60P3:b/X20<c<c080emOG0P3?cll20:NWY`80:b/[0P0T92@202PX:0808B4Q
0P0X:2P203<c<`80@D510P0m?Cd203Ti>@80>c/k0P0f=SH203hn?P80C4a<0P1HF5P205iNGP80IFEU
0`1YJFT2071`L080LW9b0P1cLg<207QhN080P8200P21PH440820P080Q8B40P20P80208N7Q`80R8R8
0P2<S8`208V9R@80SHf=0P2>SXh6096AT@80UYJF102GUiL209VIV@80VYZJ0P2IVIT409bLW080Vi^K
0P2QXJ420:BTY0L0ZJVY0P2ZZZX20:j^[P80/K6a0P2b/[820:b/[080[jn_0P2c/k<40;6a/@80[Zj^
0P2][Jd20:^[Z`80Z:RX0P2[Zj/20:b/[080Zj^[0P2YZJT20:>SX`80XJ6Q0P2UYJD209nOW`@0VYZJ
0P2IVIT209FEU@80TI6A0P29RHT208b<S080QhN70P25QHD508N7Q`80QXJ60P28R8P208f=S@80Rh^;
0P20P80207emO@80Ogmo0P23Ph<207emO@@0O7al0P1nOWh208F5Q@80QhN77`38h=P001d0b>3H0P2I
VIT209^KV`80U9BD0P1aLG4204e=C@809bLW0P0[:b/602@T90@09bLW0P0X:2P202HV9P80:b/[0P16
ATH308F5Q@80UIFE0P1lO7`206EUI@80LW9b0P1cLg<20820P080ZJVY0P3:b/X20<K6aP80`L710P34
a<@20<W9b@80e]KF0P3GemL20;jn_P80MWIf0P0a<C4202DU9@807alO0P0T92@2030`<080=CDe0P12
@T82034a<@80=CDe0P0j>SX20492@P80Bd];0P1EEED205mOG`80IFEU0`1[Jf/2075aL@80MgMg0P1i
NGT207YjNP80O7al0P1nOWh207moO`80P8200P22PX8408B4Q080QHF50P28R8P208^;R`80S8b<0P2=
SHd208j>SP80T92@0P2CTi<209JFUP@0V9RH1P2IVIT209ZJVP80Vi^K0P2LW9`20:6QX@80YJFU0P2W
YjL30:RXZ080ZJVY0P2ZZZX20:j^[P80/[:b0P2`/;020:f][@80[jn_102b/[820;6a/@80/;2`0P2^
[Zh20:^[Z`80Z:RX0P2ZZZX20:b/[080ZZZZ0P2XZ:P20:NWY`80YJFU0P2SXj<20:2PX080WYjN0P2K
Vi/209RHV080UIFE0P2CTi<2092@T080SHf=0P2:RXX208V9R@D0R8R80P29RHT208^;R`80SHf=0P28
R8P208>3P`@0PH610P1oOgl207emO@@0O7al0P20P80208>3P`80Q8B4:@38h=P20:BTY080VYZJ0P2D
U9@2071`L080BDU90P0];Bd202HV9P808B4Q0P0R8R8202DU9@80:2PX0P0T92@202XZ:P80:b/[0P0Z
:RX204e=C@<0P8200P2GUiL207UiN@80I6AT0P1`L70207]kN`80OGem0P2][Jd20<c<c080_;bl0P34
a<@20<S8b080c<c<0P3@d=020=GEe@80b<S80P1eMGD203De=@80:BTY0P0R8R8202HV9P809bLW0P0o
?cl204=3@`80<C4a0P0_;bl203Hf=P80?Cdm0P17AdL2055AD@80I6AT0P1XJ6P306a/K080L71`0P1g
MgL407UiN@H0P8200P1oOgl208:2PP80P8200P24Q8@208V9R@80S8b<0P2=SHd208^;R`80SHf=0P2C
Ti<209:BTP80T92@0P2HV9P2096AT@80VIVI0P2GUiL209RHV080VIVI0P2JVYX209jNWP80WinO0P2R
XZ820:JVYP80ZJVY0`2UYJD20:f][@80Z:RX0P2[Zj/20;>c/`H0[Zj^0P2a/K420;2`/080/K6a0P2`
/;020;:b/P80ZZZZ0P2XZ:P20:^[Z`80[Jf]1P2XZ:P20:BTY080Xj>S0P2OWil209fMW@80Vi^K0P2G
UiL209RHV080UIFE0P2BTY82092@T080Rh^;0P2<S8`308^;R`@0RHV9102;Rh/208J6QP80Q8B40P1n
OWh20861P@80OWin0P1mOGd20861P@80O7al0P23Ph<20861P@80Q8B4:@38h=P209NGU`80VYZJ0P2@
T90207=cL`80CDe=0P0X:2P202XZ:P80:2PX0P0S8b<202DU9@80:2PX100V9RH202<S8`80:b/[0P16
ATH308N7Q`80TY:B0P1mOGd206MWI`80LW9b0P1gMgL207inOP80XZ:R0P3=cLd20<G5a@80`l?30P35
aLD20<O7a`80emOG0P3Lg=`20<G5a@80MWIf0P0b<S8202<S8`@0820P0P0];Bd203Lg=`80@D510P0_
;bl203Hf=P80>SXj0P13@d<2051@D080De=C0P1QHF4206EUI@<0Jf][0P1bLW8407MgM`80NWYj0P1n
OWh207]kN`80OGem0P21PH4408B4Q080QXJ60P22PX8208B4Q080SXj>0P2?Shl208f=S@80Shn?0P2@
T902096AT@80V9RH0P2IVIT209RHV080UiNG0P2HV9P209VIV@@0W9bL0P2KVi/20:6QX@80Xj>S0P2Y
ZJT30:RXZ080YZJV0P2[Zj/20:n_[`80/K6a0P2`/;020:b/[080[Zj^0P2b/[820;2`/080/[:b102_
[jl20:ZZZP@0Z:RX0P2ZZZX20:RXZ080ZJVY102VYZH20:>SX`80XJ6Q0P2NWYh209ZJVP80UIFE0P2H
V9P209:BTP80U9BD0P2@T90208V9R@80RXZ:0`28R8P208J6QP80R8R80P2;Rh/208b<S080RHV90P22
PX860820P080O7al0P1mOGd407inOP80PH610P22PX8O0<SPf0007@38h=P209VIV@80Vi^K0P2DU9@2
075aL@80CDe=0P0W9bL202/[:`H092@T100W9bL202PX:0809RHV0P0[:b/204I6AP<0QHF50P2EUID2
07alO080IFEU0P1bLW8207=cL`80P8200P2YZJT20<[:bP80a/K60P31`L420<C4a080bLW90P3Fe]H2
0=OGe`80_[jn0P1fMWH2034a<@809BDU0P0O7al202@T9080<30`0P0e=CD20492@P80<C4a0P0e=CD2
03Xj>P80@T920P1;Bd/205EEE@80GemO0P1UIFD306][J`80LG5a0P1gMgL207UiN@80NWYj0P1lO7`2
07inOP80Ogmo0P20P80208:2PP@0Q8B40P25QHD208R8R080Rh^;0P2<S8`208f=S@80SXj>0P2@T902
09>CT`80UYJF102HV9P609VIV@80VYZJ0P2KVi/209bLW080XJ6Q0P2UYJD20:NWY`<0Z:RX0P2YZJT2
0:ZZZP80[Zj^0P2b/[820;2`/080[Jf]0P2_[jl40;:b/P80/K6a0P2`/;020:j^[P80Zj^[0P2XZ:P2
0:ZZZP80[:b/0P2ZZZX20:RXZ080YjNW0P2UYJD20:>SX`80X:2P0P2NWYh209^KV`80V9RH0P2EUID2
09>CT`80T92@0P2=SHd208Z:RP80RHV91@28R8P208V9R@80Rh^;0P2=SHd208R8R080Ph>31021PH42
07moO`80OGem101lO7`20820P080Ph>30P24Q8@Y0<SPf080Y:BT0P2JVYX209BDU080L71`0P19BDT2
02d];@809RHV0P0Q8B42028R8P809BDU0P0X:2P202@T9080:RXZ0P0[:b/202XZ:P80CDe=0`20P802
09NGU`80NGUi0P1TI6@2071`L080Ng]k0P1mOGd20:f][@80c<c<0P2l_;`20<C4a080b<S80P3<c<`2
0=3@d080eMGE0P38b<P207EeM@80=CDe0P0Y:BT2028R8P809RHV0P0W9bL203lo?`80@d=30P0a<C42
02l_;`80=SHf0P0m?Cd204M7A`80DE5A0P1TI6@206QXJ0<0K6a/0P1`L70207MgM`@0NGUi1P20P802
07moO`80PX:20P20P80208B4Q080RHV90P2<S8`208f=S@80Rh^;0P2=SHd209>CT`80TY:B0P2@T902
09RHV080TI6A0P2IVIT209NGU`80V9RH0P2IVIT209ZJVP80WYjN0P2OWil20::RXP80YZJV0P2YZJT3
0:FUY@80[Jf]0P2XZ:P20:^[Z`80/k>c1P2^[Zh20;6a/@80/;2`0P2a/K420;2`/080/[:b0P2ZZZX2
0:RXZ080Zj^[0P2][Jd60:RXZ080Y:BT0P2SXj<209nOW`80WIfM0P2KVi/209NGU`80V9RH0P2EUID2
09:BTP80T92@0P2;Rh/208b<S0<0Rh^;1029RHT408^;R`80QXJ60P24Q8@207inOP80PH610P1nOWh2
07emO@80PH610P1lO7`208>3P`80PH610P24Q8@Y0<SPf080UiNG0P2JVYX2092@T080Lg=c0P1=CDd2
02PX:080:RXZ0P0X:2P202<S8`809BDU0P0X:2P402HV9P808b<S0P0[:b/204I6AP<0QhN70P2BTY82
07emO@80IfMW0P1bLW8207MgM`80OWin0P2RXZ820<g=c@80aLG50P33`l<20<G5a@80alO70P3GemL2
0=cLg080aLG50P1fMWH2038b<P808b<S100P820202d];@80=cLg0P11@D4202l_;`80=SHf0P0j>SX2
04=3@`80D51@0P1CDe<2065QH@80IFEU0`1[Jf/2079bLP@0MgMg0P1jNWX207inOP80Ng]k0P1mOGd2
0861P@@0Q8B40P26QXH208:2PP80Q8B40P2>SXh208n?S`80SHf=0P2?Shl2092@T080TI6A0P2HV9P2
09VIV@80V9RH0P2GUiL209RHV080VIVI102LW9`209^KV`80XJ6Q0P2SXj<20:VYZ@<0Z:RX0P2VYZH2
0:^[Z`80[jn_0P2a/K420;2`/080[:b/0P2^[Zh20;:b/P80/;2`0P2b/[840:n_[`80ZZZZ102XZ:P2
0:ZZZP80Z:RX0P2YZJT40:JVYP80Xj>S0P2QXJ4209jNWP80VYZJ0P2EUID209RHV080TY:B0P2DU9@2
092@T080RHV90P2:RXX308R8R080QXJ60P28R8P208^;R`80S8b<0P29RHT208:2PPH0P8200P1lO7`2
07emO@@0OWin0P21PH4208:2PQl0b>3H000M0<SPf080/;2`0P2EUID206YZJP80ATI6100Y:BT202`/
;0809RHV100Q8B4202<S8`8092@T0P0U9BD202<S8`80;Bd]0P0`<30307IfMP80QhN70P2EUID206IV
IP80MGEe0P1aLG420820P080QHF50P3:b/X20<?3``80^k^k0P30`<020<S8b080c/k>0P3AdM420<c<
c080_[jn0P13@d<202d];@807alO0P0U9BD202XZ:P80;Bd]0P1:BTX202PX:080<C4a0P0j>SX20451
@@80BDU90P1EEED2061PH080IVIV0`1[Jf/207=cL`80NWYj0P1kNg/207YjNP@0Ng]k0P1mOGd20820
P080Ph>30P26QXH208B4Q080Ph>30P27QhL208^;R`@0S8b<0P2>SXh2092@T080Ti>C0P2FUYH209RH
V0H0VIVI102HV9P209ZJVP80WIfM0P2RXZ820:FUY@D0YZJV0P2WYjL20:VYZ@80[Jf]0P2a/K420;2`
/080[Zj^0P2`/;020;:b/P80/k>c0P2b/[820;2`/080[jn_0P2[Zj/20:VYZ@80ZZZZ0P2/[:`20:^[
Z`@0Z:RX0P2WYjL20:BTY080X:2P0P2OWil209fMW@80VIVI102DU9@209>CT`80T92@0P2<S8`508Z:
RP80Rh^;0P2=SHd208b<S080Rh^;0P28R8P208F5Q@80Ph>30P21PH4207inOP@0O7al0P1mOGd20820
P080Ph>30P24Q8@Y0<SPf080[:b/0P2GUiL206a/K080A4A40P0/;2`202PX:080:b/[0P0V9RH2024Q
8@809RHV0P0R8R8202<S8`80820P100X:2P203<c<`<0LG5a0P2?Shl208j>SP80JFUY0P1`L70207Ad
M080MgMg0P2?Shl20<O7a`80_;bl0P2m_Kd20<C4a080alO70P3;bl/20<o?c`80dM7A0P2c/k<204A4
A080:RXZ0P0S8b<202@T9080:2PX0P0_;bl203hn?P80;bl_0P0d=3@203`l?080@d=30P1?Cdl2055A
D@80Hf=S0P1XJ6P306a/K080L71`101jNWX607]kN`80OWin0P21PH4208>3P`80R8R81022PX8208J6
QP80S8b<0P2:RXX208f=S@80Shn?0P2@T90209:BTP80V9RH0P2EUID209ZJVP80VIVI0P2KVi/209JF
UP80VIVI102MWId20:2PX0L0YJFU0P2][Jd20:NWY`80[Zj^0P2a/K420;2`/080[:b/0P2a/K420;Fe
]@80/K6a0P2b/[820:n_[`80[Jf]0P2[Zj/20:VYZ@80Zj^[0P2ZZZX20:b/[080ZZZZ102WYjL20:FU
Y@@0XJ6Q0P2MWId209ZJVP80TY:B102CTi<208n?S`80S8b<0P28R8P508Z:RP80T92@0P28R8P208n?
S`80R8R80P25QHD208>3P`80P8200P22PX8207]kN`80OGem0P1iNGT408:2PP80Ph>3:@38h=P20:n_
[`80UiNG0P1ZJVX204M7A`80:b/[0P0S8b<202l_;`80:BTY100P820202<S8`809BDU0P0T92@202LW
9`80;2`/0P0c<c<307MgM`80QhN70P2GUiL2069RHP80MWIf0P1`L70208>3P`80PH610P3>c/h20;jn
_P80^k^k0P35aLD20<O7a`80bLW90P3?cll20<_;b`80_kno0P10@40202d];@808B4Q0P0U9BD202/[
:`80;Rh^0P19BDT202TY:@80;bl_0P0f=SH204=3@`80ADE50P1GEeL2061PH080J6QX0`1YJFT207If
MP80NGUi0P1jNWX207QhN080P8200P1lO7`207moO`80PH610P1oOgl208V9R@@0QXJ60P24Q8@208^;
R`80SXj>0P2;Rh/208j>SP80TY:B102EUID209BDU080VIVI0P2KVi/209VIV@80VYZJ0P2HV9P209VI
V@80WIfM0P2TY:@20:FUY@80YZJV1@2WYjL20:VYZ@80[Jf]0P2a/K420:n_[`80[Jf]0P2a/K420;Bd
]080/[:b0P2c/k<20;2`/080[Zj^0P2][Jd40:VYZ@80[Zj^0P2YZJT20:ZZZP80YjNW0P2XZ:P20:>S
X`80XZ:R0P2MWId20:6QX@@0UiNG0P2ATI4209BDU080T92@102<S8`308^;R`80RHV90P2>SXh208f=
S@80RHV90P2:RXX208J6QP@0PX:20P20P80207inOP80Ng]k101oOgl208B4Q080QHF57`38h=P001d0
b>3H0P2`/;0209FEU@80JVYZ0P16ATH402TY:@80;2`/0P0V9RH4024Q8@808b<S0P0T92@202DU9@80
8b<S0P0];Bd2030`<0<0MWIf0P27QhL209FEU@80IVIV0P1eMGD2075aL@80P8200P25QHD20<[:bP80
`l?30P2k^k/20<30`080b<S80P3>c/h20=7Ad@80c<c<0P2n_[h204=3@`80;Bd]0P0O7al202DU9@80
:RXZ0P0];Bd204Y:BP80:2PX0P0a<C4203Xj>P80@D510P19BDT205EEE@80H61P0P1VIVH306][J`80
Lg=c0P1jNWX207]kN`80NWYj101kNg/207emO@80P8200P23Ph<208J6QP80Q8B40P23Ph<208N7Q`80
Rh^;102<S8`208j>SP80T92@0P2CTi<209JFUP80V9RH1P2IVIT409RHV080VYZJ0P2MWId20::RXP80
YJFU1@2VYZH20:NWY`80ZJVY0P2][Jd20;6a/@80/;2`0P2^[Zh20;2`/080/[:b0P2c/k<20;:b/P80
/;2`0P2_[jl20:^[Z`80ZJVY0P2ZZZX20:b/[080Zj^[102XZ:P20:NWY`80Y:BT0P2PX:0209nOW`80
WIfM0P2IVIT409BDU080Ti>C0P2@T90208b<S0D0RXZ:0P2;Rh/208f=S@80S8b<0P2;Rh/208R8R080
QHF50P23Ph<20861P@80OWin101lO7`207emO@80P8200P23Ph<208B4Q2T0b>3H0P2/[:`209NGU`80
K6a/0P14A4@202`/;080:2PX0P0[:b/202HV9P808B4Q0P0V9RH2028R8P808b<S0P0P820402PX:080
<c<c0`1aLG4208n?S`80SXj>0P1YJFT2071`L080M7Ad0P1gMgL208n?S`80alO70P2l_;`20;fm_@80
a<C40P37alL20<_;b`80clo?0P3AdM420;>c/`80A4A40P0Z:RX202<S8`8092@T0P0X:2P202l_;`80
?Shn0P0_;bl203@d=080?3`l0P13@d<204m?C`80DE5A0P1SHf<206QXJ0<0K6a/0P1`L70407YjNPH0
Ng]k0P1nOWh20861P@80Ph>30P28R8P408:2PP80QXJ60P2<S8`208Z:RP80SHf=0P2?Shl2092@T080
TY:B0P2HV9P209FEU@80VYZJ0P2IVIT209^KV`80UYJF0P2IVIT409fMW@80X:2P1`2UYJD20:f][@80
YjNW0P2^[Zh20;6a/@80/;2`0P2/[:`20;6a/@80]KFe0P2a/K420;:b/P80[jn_0P2][Jd20:^[Z`80
ZJVY0P2[Zj/20:ZZZP80[:b/0P2ZZZX40:NWY`80YJFU102QXJ4209fMW@80VYZJ0P2BTY8409>CT`80
Shn?0P2<S8`208R8R0D0RXZ:0P2@T90208R8R080Shn?0P28R8P208F5Q@80Ph>30P20P80208:2PP80
Ng]k0P1mOGd207UiN@@0PX:20P23Ph<Y0<SPf080[jn_0P2GUiL206YZJP80AdM70P0[:b/202<S8`80
;bl_0P0Y:BT4020P80808b<S0P0U9BD202@T90809bLW0P0/;2`203<c<`<0MgMg0P27QhL209NGU`80
HV9R0P1fMWH2071`L080Ph>30P21PH420<k>cP80_[jn0P2k^k/20<G5a@80alO70P39bLT20<o?c`80
bl_;0P2o_kl20410@080;Bd]0P0Q8B4202DU9@80:b/[0P0^;Rh204U9B@80:BTY0P0_;bl203Hf=P80
@d=30P15ADD205MGE`80H61P0P1XJ6P306UYJ@80MWIf0P1iNGT207YjNP80N7Qh0P20P80207alO080
Ogmo0P21PH4207moO`80RHV91026QXH208B4Q080Rh^;0P2>SXh208^;R`80SXj>0P2BTY8409FEU@80
U9BD0P2IVIT209^KV`80VIVI0P2JVYX209RHV080VIVI0P2MWId20:BTY080YJFU0P2VYZH50:NWY`80
ZJVY0P2][Jd20;6a/@80[jn_0P2][Jd20;6a/@80];Bd0P2b/[820;>c/`80/;2`0P2^[Zh20:f][@@0
ZJVY0P2^[Zh20:VYZ@80ZZZZ0P2WYjL20:RXZ080Xj>S0P2RXZ8209fMW@80XJ6Q102GUiL2096AT@80
U9BD0P2@T90408b<S0<0Rh^;0P29RHT208j>SP80SHf=0P29RHT208Z:RP80QXJ61022PX820820P080
OWin0P1kNg/407moO`80Q8B40P25QHDO0<SPf0007@38h=P209ZJVP80MgMg0P17AdL202l_;`808B4Q
0P0V9RH202TY:@809RHV0P0Q8B42028R8P@08b<S0P0T92@2024Q8@809BDU0P0Z:RX305QHF080O7al
0P2NWYh207UiN@80LG5a0P1`L70207YjNP80MGEe0P2g]kL20<W9b@80]kNg0P2n_[h20<C4a080b<S8
0P39bLT20<c<c080`L710P2OWil203Ph>0807QhN0P0Y:BT202`/;080<30`0P0o?cl202d];@80<S8b
0P0g=cL20410@080BTY:0P1GEeL206=SH`80JFUY0`1]KFd207EeM@80NWYj0P1iNGT207MgM`80NGUi
0P1lO7`207moO`80PX:20P25QHD208N7Q`80QHF50P24Q8@208J6QP80RHV90P2<S8`208n?S`@0T92@
0P2ATI4209>CT`80U9BD0P2FUYH209RHV080VIVI102JVYX209bLW080WinO0P2RXZ820:FUY@80YjNW
0`2XZ:P20:ZZZP80[Jf]0P2`/;020;>c/`80/K6a0P2_[jl20;2`/080/K6a0P2c/k<20;Bd]080/[:b
0P2_[jl20:b/[080Zj^[0P2][Jd20:n_[`80[Jf]0P2YZJT20:RXZ080YZJV0P2TY:@20:6QX@80X:2P
0P2NWYh209ZJVP80UIFE0P2BTY8408n?S`80SXj>0P2<S8`308^;R`80SXj>0P2@T90208j>SP80RXZ:
0P29RHT208N7Q`80Q8B40P21PH4207inOP80O7al0P1mOGd207moO`80PX:20P23Ph<208B4Q2T0b>3H
0P2@T90207YjNP80ADE50P0Z:RX2028R8P80:b/[0P0_;bl202TY:@808R8R0P0Q8B42028R8P80:BTY
0P0V9RH2028R8P8092@T0P0Z:RX305=CD`80QHF50P2OWil207QhN080Lg=c0P1dM7@207MgM`80Ng]k
0P2f][H20<G5a@80^;Rh0P2m_Kd20<C4a080aLG50P39bLT20=3@d080c<c<0P2GUiL2038b<PH0:BTY
0P0e=CD204=3@`80;2`/0P0`<30203`l?080?Cdm0P1;Bd/205EEE@80GemO0P1UIFD306i^KP80M7Ad
0P1oOgl207UiN@80MWIf0P1hN7P207UiN@80Ogmo0P23Ph<208:2PP80S8b<1024Q8@208F5Q@@0RHV9
102?Shl2096AT@80SXj>0P2EUID209JFUP80V9RH0P2IVIT209bLW080TY:B102KVi/209ZJVP80XZ:R
0P2WYjL20:>SX`<0YjNW0P2YZJT20:ZZZP80/[:b0P2_[jl20;>c/`80[jn_0P2a/K420:n_[`80/K6a
0P2h^;P20;6a/@@0[Zj^0P2YZJT20:^[Z`80/;2`0P2^[Zh20:FUY@80YZJV0P2UYJD20:BTY080WYjN
0P2MWId209^KV`80WinO102BTY8208b<S080SXj>0P2?Shl208V9R@<0Rh^;0P2<S8`2096AT@80Rh^;
0P2:RXX408V9R@80Q8B40P21PH4207alO080MWIf0P24Q8@207moO`80P8200P23Ph<208R8R2T0b>3H
0P2HV9P207MgM`80ADE50P0f=SH2024Q8@808b<S0P0X:2P202<S8`808R8R0P0O7al2024Q8@809bLW
0P0T92@201hN7P808R8R0P0/;2`305ADE080NGUi0P2PX:0207MgM`80Lg=c0P1^KVh207]kN`80NWYj
0P2g]kL20<C4a080]kNg0P30`<020<K6aP80bLW90P3=cLd20<S8b080_kno0P2TY:@203Hf=P807QhN
0P0Y:BT202l_;`80;Bd]0P0o?cl202h^;P80=3@d0P0k>c/20492@P80BDU90P1EEED2065QH@80IfMW
0`1]KFd207EeM@80Ng]k0P1fMWH207MgM`80O7al0P1hN7P20820P080PX:21025QHD208>3P`80QXJ6
0P24Q8@208Z:RP80SHf=102?Shl208j>SP80TY:B102EUID209JFUP80VIVI0P2JVYX209RHV080VYZJ
0P2LW9`20:2PX080XJ6Q0P2VYZH20:BTY0<0YjNW0P2YZJT20:j^[P80[jn_0P2d];@20;6a/@80/[:b
0P2_[jl40;6a/@80/k>c0P2b/[820:n_[`80[Jf]0P2ZZZX20:n_[`80/;2`0P2][Jd20:^[Z`80YJFU
0P2VYZH40::RXP80W9bL0P2OWil209VIV@80U9BD0P2BTY8208f=S@80S8b<0P2>SXh208^;R`<0RHV9
102?Shl208j>SP80S8b<0P29RHT208J6QP80Q8B40P1oOgl207emO@@0Ng]k0P1oOgl208:2PP80Ph>3
0P27QhLO0<SPf0007@38h=P209ZJVP80MgMg0P17AdL202l_;`808B4Q0P0V9RH202TY:@809RHV0P0Q
8B42028R8P@08b<S0P0T92@2024Q8@809BDU0P0Z:RX305QHF080O7al0P2NWYh207UiN@80LG5a0P1`
L70207YjNP80MGEe0P2g]kL20<W9b@80]kNg0P2n_[h20<C4a080b<S80P39bLT20<c<c080`L710P2O
Wil203Ph>0807QhN0P0Y:BT202`/;080<30`0P0o?cl202d];@80<S8b0P0g=cL20410@080BTY:0P1G
EeL206=SH`80JFUY0`1]KFd207EeM@80NWYj0P1iNGT207MgM`80NGUi0P1lO7`207moO`80PX:20P25
QHD208N7Q`80QHF50P24Q8@208J6QP80RHV90P2<S8`208n?S`@0T92@0P2ATI4209>CT`80U9BD0P2F
UYH209RHV080VIVI102JVYX209bLW080WinO0P2RXZ820:FUY@80YjNW0`2XZ:P20:ZZZP80[Jf]0P2`
/;020;>c/`80/K6a0P2_[jl20;2`/080/K6a0P2c/k<20;Bd]080/[:b0P2_[jl20:b/[080Zj^[0P2]
[Jd20:n_[`80[Jf]0P2YZJT20:RXZ080YZJV0P2TY:@20:6QX@80X:2P0P2NWYh209ZJVP80UIFE0P2B
TY8408n?S`80SXj>0P2<S8`308^;R`80SXj>0P2@T90208j>SP80RXZ:0P29RHT208N7Q`80Q8B40P21
PH4207inOP80O7al0P1mOGd207moO`80PX:20P23Ph<208B4Q2T0b>3H0P2@T90207YjNP80ADE50P0Z
:RX2028R8P80:b/[0P0_;bl202TY:@808R8R0P0Q8B42028R8P80:BTY0P0V9RH2028R8P8092@T0P0Z
:RX305=CD`80QHF50P2OWil207QhN080Lg=c0P1dM7@207MgM`80Ng]k0P2f][H20<G5a@80^;Rh0P2m
_Kd20<C4a080aLG50P39bLT20=3@d080c<c<0P2GUiL2038b<PH0:BTY0P0e=CD204=3@`80;2`/0P0`
<30203`l?080?Cdm0P1;Bd/205EEE@80GemO0P1UIFD306i^KP80M7Ad0P1oOgl207UiN@80MWIf0P1h
N7P207UiN@80Ogmo0P23Ph<208:2PP80S8b<1024Q8@208F5Q@@0RHV9102?Shl2096AT@80SXj>0P2E
UID209JFUP80V9RH0P2IVIT209bLW080TY:B102KVi/209ZJVP80XZ:R0P2WYjL20:>SX`<0YjNW0P2Y
ZJT20:ZZZP80/[:b0P2_[jl20;>c/`80[jn_0P2a/K420:n_[`80/K6a0P2h^;P20;6a/@@0[Zj^0P2Y
ZJT20:^[Z`80/;2`0P2^[Zh20:FUY@80YZJV0P2UYJD20:BTY080WYjN0P2MWId209^KV`80WinO102B
TY8208b<S080SXj>0P2?Shl208V9R@<0Rh^;0P2<S8`2096AT@80Rh^;0P2:RXX408V9R@80Q8B40P21
PH4207alO080MWIf0P24Q8@207moO`80P8200P23Ph<208R8R2T0b>3H0P2HV9P207MgM`80ADE50P0f
=SH2024Q8@808b<S0P0X:2P202<S8`808R8R0P0O7al2024Q8@809bLW0P0T92@201hN7P808R8R0P0/
;2`305ADE080NGUi0P2PX:0207MgM`80Lg=c0P1^KVh207]kN`80NWYj0P2g]kL20<C4a080]kNg0P30
`<020<K6aP80bLW90P3=cLd20<S8b080_kno0P2TY:@203Hf=P807QhN0P0Y:BT202l_;`80;Bd]0P0o
?cl202h^;P80=3@d0P0k>c/20492@P80BDU90P1EEED2065QH@80IfMW0`1]KFd207EeM@80Ng]k0P1f
MWH207MgM`80O7al0P1hN7P20820P080PX:21025QHD208>3P`80QXJ60P24Q8@208Z:RP80SHf=102?
Shl208j>SP80TY:B102EUID209JFUP80VIVI0P2JVYX209RHV080VYZJ0P2LW9`20:2PX080XJ6Q0P2V
YZH20:BTY0<0YjNW0P2YZJT20:j^[P80[jn_0P2d];@20;6a/@80/[:b0P2_[jl40;6a/@80/k>c0P2b
/[820:n_[`80[Jf]0P2ZZZX20:n_[`80/;2`0P2][Jd20:^[Z`80YJFU0P2VYZH40::RXP80W9bL0P2O
Wil209VIV@80U9BD0P2BTY8208f=S@80S8b<0P2>SXh208^;R`<0RHV9102?Shl208j>SP80S8b<0P29
RHT208J6QP80Q8B40P1oOgl207emO@@0Ng]k0P1oOgl208:2PP80Ph>30P27QhLO0<SPf0007@38h=P2
07IfMP80EEEE0P0[:b/4028R8P8092@T0P0V9RH202DU9@H08b<S100T92@2020P80807alO0P0X:2P3
03Ti>@80Kfm_0P2LW9`208f=S@80L71`0P1_Kfl207EeM@80K6a/0P2NWYh20<_;b`80]kNg0P2n_[h6
0<30`080clo?0P3AdM420;Bd]080Jf][0P0e=CD402/[:`80=3@d0P0b<S8403<c<`80=CDe0P0o?cl2
04];B`80F5QH0P1TI6@206][J`<0L71`0P1fMWH207UiN@80MgMg0P1eMGD207UiN@80OWin0P21PH42
08B4Q080QXJ60P27QhL208J6QP@0QHF50P26QXH208b<S0@0TI6A1P2@T90209:BTP80U9BD0P2GUiL2
09ZJVP80W9bL0P2MWId209nOW`80XZ:R0P2TY:@20:JVYP80Z:RX0`2ZZZX20:j^[P80/K6a0P2c/k<2
0;Bd]080/[:b1P2a/K420;Bd]080][Jf0P2c/k<20:n_[`@0[Jf]0P2`/;020;:b/P80[Zj^0P2YZJT2
0:RXZ080YjNW0P2TY:@20::RXP80X:2P0P2NWYh209^KV`80UiNG0P2ATI4208b<S080SXj>0P2@T902
08j>SP<0S8b<0P2@T90209>CT`80T92@0P2;Rh/208V9R@80QhN70P25QHD208:2PP80OWin0P1lO7`2
07inOP80PH610P23Ph<408B4Q2T0b>3H0P1gMgL205QHF080;Bd]0P0U9BD202<S8`80820P0P0S8b<2
028R8P809BDU0P0T92@202<S8`@08R8R0P0O7al2024Q8@809BDU0`0i>CT2079bLP80VYZJ0P2;Rh/2
07=cL`80LW9b0P1`L70207AdM080Vi^K0P36a/H20;Vi^@80^k^k0P2o_kl20<C4a080`l?30P35aLD2
0<c<c080`/;20P1ZJVX2038b<P80<30`0P0Z:RX202d];@80>SXj0P0];Bd203Lg=`80=3@d0P0l?3`2
04e=C@80FEUI0P1UIFD206a/K0<0LG5a0P1eMGD207YjNP80N7Qh0P1fMWH207QhN080OWin0P23Ph<2
08J6QP80Q8B40P27QhL208:2PP@0QHF50P27QhL208b<S080T92@0P2DU9@209:BTP80SXj>0P2BTY82
096AT@80U9BD0P2EUID209bLW080WIfM0P2KVi/60::RXP80Z:RX0P2VYZH30:b/[080[jn_0P2`/;02
0;6a/@80/;2`0P2h^;P20:j^[P80/[:b0P2d];@20;Fe]@80]kNg0P2`/;060:n_[`80Zj^[0P2b/[82
0:f][@80ZJVY0P2XZ:P20:JVYP80YjNW102RXZ820:2PX080VYZJ0P2FUYH209FEU@80Rh^;0P2?Shl2
096AT@80S8b<0`2=SHd209BDU080Ti>C0P2>SXh208Z:RP80Rh^;0P25QHD208J6QP80PH610P1oOgl2
07inOP80OGem0P23Ph<20820P080QXJ60P22PX8Y0<SPf080MWIf0P1GEeL202XZ:P808R8R0P0O7al2
02PX:0809RHV0P0W9bL2024Q8@8092@T0P0U9BD202@T90808b<S100N7Qh202h^;P<0>CTi0P1ZJVX2
09nOW`80Shn?0P1bLW8206i^KP80MGEe0P1`L70209bLW080c<c<0P2h^;P20;jn_P80`L710P2l_;`2
0<30`080clo?0P3Cdm<20;Ng]`80JVYZ0P0d=3@202TY:@80;2`/0P0d=3@203<c<`80=3@d0P0_;bl2
03Hf=P80?clo0P1:BTX205MGE`80I6AT0P1/K6`306m_K`80MWIf0P1lO7`207MgM`80MGEe0P1kNg/2
07moO`80P8200P22PX8208V9R@80R8R80P25QHD408J6QP80QHF50P2=SHd2096AT@80T92@0P2CTi<2
096AT@80T92@0P2?Shl209FEU@80VYZJ0P2IVIT209^KV`80WYjN0P2QXJ440:>SX`@0YjNW0`2/[:`2
0:f][@@0/K6a0P2c/k<20;:b/P80/;2`102a/K420;Bd]080]KFe0P2c/k<20:j^[P80[jn_0P2/[:`2
0;>c/`80/K6a0P2/[:`20:VYZ@80Z:RX0P2WYjL20:RXZ080X:2P0P2QXJ4209fMW@80W9bL0P2FUYH2
096AT@80S8b<102?Shl209:BTP<0Rh^;0P2BTY8209BDU080SXj>0P29RHT208Z:RP80QhN70P24Q8@2
08>3P`80PH610P1mOGd207alO080PX:21023Ph<208J6QQl0b>3H000M0<SPf080MWIf0P1EEED202/[
:`@08R8R0P0T92@202HV9P809BDU1P0S8b<402@T9080820P0P0O7al202PX:0<0>CTi0P1_Kfl209bL
W080SHf=0P1`L70206m_K`80MGEe0P1/K6`209jNWP80bl_;0P2g]kL20;jn_PH0`<300P3?cll20=7A
d@80];Bd0P1[Jf/203De=@@0:b/[0P0d=3@2038b<P@0<c<c0P0e=CD203lo?`80Bd];0P1HF5P206AT
I080Jf][0`1`L70207IfMP80NGUi0P1gMgL207EeM@80NGUi0P1nOWh20861P@80Q8B40P26QXH208N7
Q`80QXJ61025QHD208J6QP80S8b<102ATI46092@T080TY:B0P2DU9@209NGU`80VYZJ0P2LW9`209fM
W@80WinO0P2RXZ820:BTY080YZJV0P2XZ:P30:ZZZP80[Zj^0P2a/K420;>c/`80];Bd0P2b/[860;6a
/@80];Bd0P2f][H20;>c/`80[jn_102][Jd20;2`/080/[:b0P2^[Zh20:VYZ@80Z:RX0P2WYjL20:BT
Y080XZ:R0P2PX:0209jNWP80Vi^K0P2GUiL2096AT@80S8b<0P2>SXh2092@T080SXj>0`2<S8`2092@
T080Ti>C0P2@T90208^;R`80RHV90P27QhL208F5Q@80PX:20P1nOWh207alO080OWin0P21PH4208>3
P`@0Q8B4:@38h=P207MgM`80F5QH0P0];Bd202DU9@808b<S0P0P820202<S8`808R8R0P0U9BD202@T
90808b<S100R8R8201lO7`808B4Q0P0U9BD303Ti>@80LW9b0P2JVYX208^;R`80Lg=c0P1bLW82071`
L080M7Ad0P2KVi/20<K6aP80^KVi0P2k^k/20;no_`80a<C40P33`l<20<G5a@80c<c<0P32`/8206YZ
JP80<S8b0P0`<30202XZ:P80;Bd]0P0j>SX202d];@80=cLg0P0d=3@203`l?080CDe=0P1IFET206EU
I@80K6a/0`1aLG4207EeM@80NWYj0P1hN7P207IfMP80N7Qh0P1nOWh208>3P`80QXJ60P24Q8@208N7
Q`80PX:21025QHD208N7Q`80S8b<0P2@T90209BDU080TY:B0P2>SXh209:BTP80TI6A0P2DU9@209FE
U@80W9bL0P2MWId209^KV`H0XZ:R0P2XZ:P20:JVYP<0[:b/0P2_[jl20;2`/080/K6a0P2`/;020;Rh
^080[Zj^0P2b/[820;Bd]080]KFe0P2g]kL20;2`/0H0[jn_0P2[Zj/20;:b/P80[Jf]0P2YZJT20:RX
Z080YZJV0P2WYjL40::RXP80X:2P0P2JVYX209JFUP80UIFE0P2;Rh/208n?S`80TI6A0P2<S8`308f=
S@80U9BD0P2CTi<208j>SP80RXZ:0P2;Rh/208F5Q@80QXJ60P21PH4207moO`80OWin0P1mOGd208>3
P`80P8200P26QXH208:2PRT0b>3H0P1fMWH205MGE`80:RXZ0P0R8R8201lO7`80:2PX0P0V9RH202LW
9`808B4Q0P0T92@202DU9@8092@T0P0S8b<401hN7P80;Rh^0`0i>CT206YZJP80WinO0P2?Shl2079b
LP80KVi^0P1eMGD2071`L080W9bL0P3<c<`20;Rh^080_[jn0P31`L420;bl_080`<300P3?cll20=?C
d`80]kNg0P1ZJVX203@d=080:BTY0P0/;2`203@d=080<c<c0P0d=3@202l_;`80=SHf0P0o?cl204Y:
BP80EeMG0P1TI6@206a/K0<0Kfm_0P1fMWH207alO080MgMg0P1eMGD207]kN`80Ogmo0P20P80208:2
PP80RHV90P28R8P208F5Q@@0QXJ60P25QHD208f=S@80TI6A0P2@T90209>CT`80TI6A0P2@T90208n?
S`80UIFE0P2JVYX209VIV@80Vi^K0P2NWYh20:6QX@@0Xj>S102WYjL30:b/[080[Jf]102a/K420;>c
/`80/[:b0P2`/;040;6a/@80];Bd0P2e]KD20;>c/`80[Zj^0P2_[jl20:b/[080/k>c0P2a/K420:b/
[080ZJVY0P2XZ:P20:NWY`80Z:RX0P2PX:020:6QX@80WIfM0P2LW9`209JFUP80TI6A0P2<S8`408n?
S`80TY:B0`2;Rh/209:BTP80U9BD0P2>SXh208V9R@80RXZ:0P27QhL208B4Q080Ph>30P21PH4207em
O@80O7al0P22PX8408>3P`80QXJ67`38h=P001d0b>3H0P1DE5@204=3@`80:2PX100T92@202DU9@80
:2PX0P0V9RH202@T90809RHV100W9bL202HV9P808b<S100P820302LW9`80Fe]K0P2=SHd2096AT@80
Q8B40P1[Jf/207MgM`80KFe]0P28R8P20;Zj^P80`l?30P31`L420;bl_080_[jn0P30`<040<G5a@80
cLg=0P2^[Zh203/k>`80=CDe0P0[:b/202d];@80:b/[0P0`<302034a<@80=SHf0P11@D4204i>CP80
F5QH0P1RHV8206][J`<0LW9b0P1eMGD407MgM`80N7Qh0P1lO7`20820P080PH610P22PX8208>3P`80
Q8B41P25QHD208J6QP80RXZ:0P2>SXh2096AT@@0Ti>C0P2BTY8209>CT`80UIFE0P2GUiL209^KV`80
WYjN0P2QXJ420:>SX`80YZJV0P2WYjL20:VYZ@80Zj^[0`2][Jd20:n_[`80/K6a0P2b/[840;>c/`80
/[:b0P2e]KD40;Ng]`80]KFe0P2b/[820:j^[P80[:b/0P2[Zj/20:f][@80[jn_0P2/[:`20:VYZ@@0
ZZZZ0P2VYZH20:6QX@80WinO0P2NWYh209bLW080VIVI0P2EUID4096AT@80TY:B0P2@T90308n?S`80
TY:B0P2CTi<2092@T080S8b<0P2:RXX208R8R080QhN70P24Q8@20820P080O7al0P1oOgl208:2PP80
Q8B41025QHDY0<SPf080FEUI0P0n?Sh202LW9`809BDU0P0T92@202LW9`80;2`/0P0W9bL202<S8`80
8R8R0P0V9RH2038b<P809BDU100R8R8201lO7`<0:BTY0P1KFe/208V9R@80U9BD0P1fMWH406m_K`80
Lg=c0P24Q8@20<30`080alO70P2k^k/20;fm_@80a/K6102m_Kd20<?3``80c/k>0P2/[:`203Xj>P80
;bl_0P0[:b/202d];@80=CDe0P0^;Rh2038b<P80=SHf0P10@40204m?C`80FEUI0P1UIFD206a/K0<0
LW9b0P1aLG4407EeM@@0Ng]k0P22PX8208>3P`80OWin0P22PX8208V9R@80QHF50P28R8P208J6QP80
Q8B40P2;Rh/208n?S`80TI6A0P2@T90209>CT`@0T92@0P2EUID209NGU`80V9RH0P2MWId20::RXP80
YjNW0P2YZJT20:FUY@80Z:RX0P2[Zj/30:b/[080/;2`0P2b/[820;Bd]080][Jf0P2c/k<20;2`/080
[jn_0P2d];@20;Ng]`80/k>c0P2][Jd20:n_[`80[Zj^0P2YZJT20:n_[`80/;2`0P2_[jl20:^[Z`80
[Jf]0P2YZJT20::RXP80Xj>S0P2NWYh409^KV`80UiNG0P2FUYH2096AT@80Shn?0P2CTi<2092@T0<0
SHf=0P2BTY8209BDU080S8b<0P2ATI4408R8R0@0QXJ60P1nOWh207moO`80O7al0P22PX8208B4Q0@0
QHF5:@38h=P205EEE@80@D510P0X:2P202DU9@808R8R0P0Y:BT202<S8`809RHV0P0W9bL202@T90@0
9bLW0P0Y:BT202DU9@807QhN0P0T92@302LW9`80G5aL0P2<S8`2092@T080Q8B40P1VIVH2079bLP80
LG5a0P26QXH20;Rh^080aLG50P2m_Kd20;^k^`80`<300P31`L420<?3``80a<C40P3:b/X20:n_[`80
?clo0P0d=3@202l_;`80;2`/0P0[:b/2038b<P80;Bd]0P0d=3@204=3@`80DE5A0P1GEeL206ATI080
KVi^0`1cLg<207AdM080LW9b0P1fMWH207QhN080NWYj0P1oOgl208>3P`80PH610P26QXH208B4Q080
Ph>30P25QHD20861P@@0R8R80P2?Shl4096AT@80Ti>C0P2ATI42092@T080TY:B0P2HV9P209ZJVP@0
WIfM0P2SXj<20:BTY080YjNW0P2ZZZX50:b/[080[jn_0P2a/K420;Bd]080]KFe0P2c/k<20;6a/@80
];Bd0P2i^KT20;Rh^080^KVi0P2b/[820:j^[P80Zj^[0P2ZZZX20:^[Z`80[Zj^0P2][Jd20:VYZ@80
ZZZZ0P2YZJT20:NWY`80Xj>S0P2NWYh209nOW`80WIfM0P2KVi/409>CT`80UIFE0P2BTY8508j>SP80
TY:B0P2CTi<208n?S`@0SHf=0P27QhL208J6QP80Ph>30P22PX8407inOP80Q8B40P25QHD408>3Pal0
b>3H000M0<SPf080E5AD0P13@d<202PX:0@092@T0P0U9BD202PX:0809RHV0P0T92@202HV9P@09bLW
0P0V9RH202<S8`@0820P0`0W9bL205]KF`80SHf=0P2ATI4208B4Q080Jf][0P1gMgL206e]K@80R8R8
0P2j^[X20<?3``80`L710P2l_;`20;jn_P80`<301035aLD20<g=c@80[Zj^0P0k>c/203De=@80:b/[
0P0];Bd202/[:`80<30`0P0a<C4203Hf=P80@D510P1>CTh205QHF080HV9R0P1[Jf/3079bLP80MGEe
101gMgL207QhN080O7al0P20P8020861P@80PX:20P23Ph<208B4Q0H0QHF50P26QXH208Z:RP80SXj>
0P2ATI4409>CT`80TY:B0P2CTi<209FEU@80UiNG0P2KVi/209jNWP80XJ6Q0P2SXj<20:JVYP80YjNW
0P2YZJT20:^[Z`<0[Jf]0P2_[jl20;6a/@80/[:b102c/k<20;:b/P80]KFe102g]kL20;Fe]@80/[:b
0P2^[Zh20:b/[080Zj^[0P2][Jd20:n_[`80[:b/0P2YZJT40:ZZZP80YZJV0P2QXJ4209nOW`80WYjN
0P2LW9`209VIV@80UIFE102ATI4209:BTP80T92@0`2?Shl209:BTP80Ti>C0P2@T90208b<S080RXZ:
0P28R8P208N7Q`80Q8B40P20P80207alO080Ogmo0P22PX8208B4Q0@0QHF5:@38h=P205UIF@80?Shn
0P0W9bL202DU9@8092@T0P0W9bL202`/;0809bLW0P0S8b<2028R8P809RHV0P0b<S8202DU9@@08R8R
0P0O7al302TY:@80Fe]K0P29RHT209BDU080MWIf101_Kfl207=cL`80Q8B40P30`<020<O7a`80^k^k
0P2m_Kd20<K6aP@0_Kfm0P33`l<20<k>cP80[:b/0P0j>SX202l_;`80:b/[0P0];Bd203De=@80;Rh^
0P0b<S8203Hf=P80@4100P1?Cdl205UIF@80IFEU0P1/K6`3079bLP80LG5a101eMGD407]kN`80PX:2
0P23Ph<207inOP80PX:20P29RHT208F5Q@80R8R80P26QXH208B4Q080Rh^;0P2?Shl2096AT@80T92@
0P2CTi<4092@T080UIFE0P2GUiL209RHV080WIfM0P2RXZ820:NWY`80ZJVY0P2UYJD20:RXZ080Zj^[
0`2/[:`20;2`/080/[:b0P2d];@20;Jf]P80/k>c0P2`/;020:n_[`80];Bd0P2g]kL20;>c/`80[Jf]
0P2_[jl20:j^[P80ZJVY0P2_[jl20;2`/080[jn_0P2[Zj/20:f][@80ZJVY0P2RXZ820:>SX`80WYjN
102KVi/209NGU`80UYJF0P2ATI4208n?S`80Ti>C0P2@T90308f=S@80TY:B0P2DU9@208b<S080TI6A
1028R8P408J6QP80OWin0P1oOgl207alO080PX:20P24Q8@408F5QBT0b>3H0P1EEED20451@@80:2PX
0P0U9BD2028R8P80:BTY0P0S8b<202HV9P809bLW0P0T92@402LW9`80:BTY0P0U9BD201hN7P8092@T
0`0W9bL205aLG080S8b<0P2@T90208B4Q080IVIV0P1bLW82075aL@80QXJ60P2h^;P20<G5a@80_Kfm
0P2k^k/20<30`080`L710P33`l<20<C4a080b/[:0P2_[jl203lo?`80=3@d0P0_;bl202`/;080:b/[
0P0b<S8202d];@80=3@d0P13@d<2055AD@80EeMG0P1TI6@206i^KP<0Lg=c0P1dM7@2079bLP80MWIf
0P1hN7P207YjNP80Ogmo0P23Ph<20861P@80QXJ60P24Q8@208>3P`80QHF50P21PH4408R8R080Shn?
102ATI4209>CT`80TI6A0P2@T90209:BTP80V9RH0P2JVYX409fMW@80Xj>S0P2TY:@20:NWY`80ZZZZ
1@2/[:`20:n_[`80/K6a0P2d];@20;Fe]@80/k>c0P2a/K420;Bd]080^KVi0P2h^;P20;Vi^@80/[:b
0P2^[Zh20:^[Z`80ZZZZ0P2[Zj/20:j^[P80[Jf]0P2YZJT20:ZZZP80ZJVY0P2WYjL20:>SX`80WYjN
0P2OWil209fMW@80Vi^K102CTi<209FEU@80TY:B1@2>SXh209:BTP80Ti>C0P2?Shl408f=S@80QhN7
0P26QXH208>3P`80PX:2101nOWh208B4Q080QHF51023Ph<O0<SPf0007@38h=P203`l?080>3Ph0P0^
;Rh202LW9`808b<S0P0V9RH202XZ:P80:2PX0P0W9bL202TY:@@0:b/[0P0Y:BT202LW9`8092@T0P0K
6a/301dM7@80AdM70P1fMWH208f=S@80VIVI0P1[Jf/207YjNP80LW9b0P1fMWH20::RXP80bl_;0P35
aLD20;Vi^@80_Kfm0P32`/820;jn_P80^KVi0P3;bl/20<c<c080SXj>0P0^;Rh202HV9P80:2PX0P0Y
:BT202/[:`80<30`0P0f=SH20492@P80Cdm?0P1HF5P2061PH080JVYZ0`1cLg<407EeM@80N7Qh0P1j
NWX207inOP@0PH610P1oOgl20820P080PH610P23Ph<608J6QP80R8R80P2;Rh/2096AT@@0UYJF0P2D
U9@209FEU@80UiNG0P2IVIT209bLW080X:2P0P2TY:@20:NWY`80ZZZZ0P2[Zj/20:b/[080[Zj^0`2_
[jl20;2`/080/K6a1P2b/[820;Bd]080^KVi0P2m_Kd20;Vi^@80];Bd0P2a/K420:j^[P80Zj^[0P2Z
ZZX20:^[Z`80[:b/0P2[Zj/20:ZZZP80[:b/0P2][Jd20:NWY`80XJ6Q0P2OWil209fMW@80W9bL0P2K
Vi/209VIV@80UiNG0P2EUID209>CT`D0TY:B102CTi<2092@T080SHf=0P2;Rh/208V9R@80R8R80P26
QXH208:2PP80OWin0P1oOgl208:2PP80Q8B40P25QHD208J6QRT0b>3H0P13@d<2034a<@80<c<c0P0/
;2`202PX:0809bLW0P0Y:BT202XZ:P80:BTY0P0U9BD202PX:080<C4a0P0U9BD202XZ:P80820P0P0M
7Ad3028R8P80>SXj0P1fMWH209BDU080Ti>C0P1`L70207AdM080N7Qh0P1eMGD209nOW`80c<c<0P2n
_[h20;Vi^@80`/;20P30`<020;bl_080^k^k103:b/X2092@T080=CDe0P0S8b<202DU9@80;2`/0P0[
:b/202h^;P80=cLg0P15ADD204e=C@80FEUI0P1QHF4206MWI`<0MGEe0P1cLg<207UiN@80MGEe0P1l
O7`207emO@80OWin0P23Ph<208:2PP80NWYj0P24Q8@20861P@80QXJ60P24Q8@208F5Q@80RHV90P28
R8P209:BTP@0UYJF0P2EUID209>CT`80UiNG0P2JVYX409jNWP80YJFU0P2WYjL20:RXZ080ZZZZ0P2]
[Jd20:b/[0<0/[:b0P2][Jd20;6a/@80/;2`0P2a/K440;Bd]080]kNg0P2n_[h20;Vi^@80]KFe0P2_
[jl20:f][@80[Zj^0P2XZ:P40:^[Z`80ZJVY0P2[Zj/20:RXZ080[jn_0P2XZ:P20:6QX@80WinO0P2P
X:0209ZJVP80Vi^K0P2LW9`209RHV0@0Ti>C0P2FUYH3092@T080UIFE0P2BTY8208b<S080SHf=0P2<
S8`208Z:RP80Q8B40P26QXH208F5Q@80Ng]k0P20P8020861P@80QHF50P24Q8@208V9RBT0b>3H0P11
@D4203@d=080<S8b0P0X:2P202HV9P8092@T100];Bd402HV9P80;bl_0P0V9RH202/[:`808b<S0P0T
92@201dM7@<06a/K0P18B4P207IfMP80Rh^;0P2JVYX2071`L080OWin0P1]KFd207QhN080XJ6Q0P39
bLT20<[:bP80]KFe0P2o_kl20;jn_P80`<300P2h^;P20<[:bP80cLg=0P2>SXh202d];@809RHV100W
9bL402h^;P80>CTi0P13@d<204m?C`80Fe]K0P1NGUh206UYJ@<0LW9b101hN7P207MgM`@0Ng]k1022
PX8207inOP80PX:20P1oOgl208:2PP80R8R80P27QhL208J6QP80QhN70P2;Rh/2092@T080UIFE0P2I
VIT209:BTP80UIFE0P2GUiL409ZJVP80X:2P0P2TY:@20:RXZ080ZZZZ1P2/[:`30:j^[P80/[:b0P2a
/K420;>c/`80/K6a0P2c/k<20;Bd]080^;Rh0P2l_;`20;Vi^@80/k>c0P2`/;020:j^[P80[:b/0P2Z
ZZX20:^[Z`80[Jf]0P2/[:`20:RXZ080Zj^[0P2][Jd20:RXZ080X:2P102NWYh209^KV`80WIfM102G
UiL209JFUP80TY:B0P2CTi<309BDU080TI6A0P2DU9@208n?S`80SXj>0P2:RXX208^;R`@0QhN70P24
Q8@207alO080Ogmo0P20P80208F5Q@80QXJ60P24Q8@O0<SPf0007@38h=P203`l?080>3Ph0P0^;Rh2
02LW9`808b<S0P0V9RH202XZ:P80:2PX0P0W9bL202TY:@@0:b/[0P0Y:BT202LW9`8092@T0P0K6a/3
01dM7@80AdM70P1fMWH208f=S@80VIVI0P1[Jf/207YjNP80LW9b0P1fMWH20::RXP80bl_;0P35aLD2
0;Vi^@80_Kfm0P32`/820;jn_P80^KVi0P3;bl/20<c<c080SXj>0P0^;Rh202HV9P80:2PX0P0Y:BT2
02/[:`80<30`0P0f=SH20492@P80Cdm?0P1HF5P2061PH080JVYZ0`1cLg<407EeM@80N7Qh0P1jNWX2
07inOP@0PH610P1oOgl20820P080PH610P23Ph<608J6QP80R8R80P2;Rh/2096AT@@0UYJF0P2DU9@2
09FEU@80UiNG0P2IVIT209bLW080X:2P0P2TY:@20:NWY`80ZZZZ0P2[Zj/20:b/[080[Zj^0`2_[jl2
0;2`/080/K6a1P2b/[820;Bd]080^KVi0P2m_Kd20;Vi^@80];Bd0P2a/K420:j^[P80Zj^[0P2ZZZX2
0:^[Z`80[:b/0P2[Zj/20:ZZZP80[:b/0P2][Jd20:NWY`80XJ6Q0P2OWil209fMW@80W9bL0P2KVi/2
09VIV@80UiNG0P2EUID209>CT`D0TY:B102CTi<2092@T080SHf=0P2;Rh/208V9R@80R8R80P26QXH2
08:2PP80OWin0P1oOgl208:2PP80Q8B40P25QHD208J6QRT0b>3H0P13@d<2034a<@80<c<c0P0/;2`2
02PX:0809bLW0P0Y:BT202XZ:P80:BTY0P0U9BD202PX:080<C4a0P0U9BD202XZ:P80820P0P0M7Ad3
028R8P80>SXj0P1fMWH209BDU080Ti>C0P1`L70207AdM080N7Qh0P1eMGD209nOW`80c<c<0P2n_[h2
0;Vi^@80`/;20P30`<020;bl_080^k^k103:b/X2092@T080=CDe0P0S8b<202DU9@80;2`/0P0[:b/2
02h^;P80=cLg0P15ADD204e=C@80FEUI0P1QHF4206MWI`<0MGEe0P1cLg<207UiN@80MGEe0P1lO7`2
07emO@80OWin0P23Ph<208:2PP80NWYj0P24Q8@20861P@80QXJ60P24Q8@208F5Q@80RHV90P28R8P2
09:BTP@0UYJF0P2EUID209>CT`80UiNG0P2JVYX409jNWP80YJFU0P2WYjL20:RXZ080ZZZZ0P2][Jd2
0:b/[0<0/[:b0P2][Jd20;6a/@80/;2`0P2a/K440;Bd]080]kNg0P2n_[h20;Vi^@80]KFe0P2_[jl2
0:f][@80[Zj^0P2XZ:P40:^[Z`80ZJVY0P2[Zj/20:RXZ080[jn_0P2XZ:P20:6QX@80WinO0P2PX:02
09ZJVP80Vi^K0P2LW9`209RHV0@0Ti>C0P2FUYH3092@T080UIFE0P2BTY8208b<S080SHf=0P2<S8`2
08Z:RP80Q8B40P26QXH208F5Q@80Ng]k0P20P8020861P@80QHF50P24Q8@208V9RBT0b>3H0P11@D42
03@d=080<S8b0P0X:2P202HV9P8092@T100];Bd402HV9P80;bl_0P0V9RH202/[:`808b<S0P0T92@2
01dM7@<06a/K0P18B4P207IfMP80Rh^;0P2JVYX2071`L080OWin0P1]KFd207QhN080XJ6Q0P39bLT2
0<[:bP80]KFe0P2o_kl20;jn_P80`<300P2h^;P20<[:bP80cLg=0P2>SXh202d];@809RHV100W9bL4
02h^;P80>CTi0P13@d<204m?C`80Fe]K0P1NGUh206UYJ@<0LW9b101hN7P207MgM`@0Ng]k1022PX82
07inOP80PX:20P1oOgl208:2PP80R8R80P27QhL208J6QP80QhN70P2;Rh/2092@T080UIFE0P2IVIT2
09:BTP80UIFE0P2GUiL409ZJVP80X:2P0P2TY:@20:RXZ080ZZZZ1P2/[:`30:j^[P80/[:b0P2a/K42
0;>c/`80/K6a0P2c/k<20;Bd]080^;Rh0P2l_;`20;Vi^@80/k>c0P2`/;020:j^[P80[:b/0P2ZZZX2
0:^[Z`80[Jf]0P2/[:`20:RXZ080Zj^[0P2][Jd20:RXZ080X:2P102NWYh209^KV`80WIfM102GUiL2
09JFUP80TY:B0P2CTi<309BDU080TI6A0P2DU9@208n?S`80SXj>0P2:RXX208^;R`@0QhN70P24Q8@2
07alO080Ogmo0P20P80208F5Q@80QXJ60P24Q8@O0<SPf0007@38h=P2055AD@@0<30`0P0h>3P20451
@@80=SHf100Y:BT202/[:`80:RXZ0P0Y:BT202d];@80;bl_0P0Z:RX202@T90807QhN0`0P820203Ti
>@80FUYJ0P23Ph<20:>SX`80O7al0P1eMGD207=cL`80MWIf0P27QhL20;fm_@80c<c<0P2d];@20;fm
_@80`<300P2k^k/20;Ng]`80b<S80P3>c/h20;Vi^@80K6a/0P0Z:RX202<S8`8092@T0P0_;bl2038b
<P80=cLg0P0o?cl204Y:BP80EEEE0P1QHF4206YZJP<0LG5a0P1eMGD207MgM`80N7Qh0P1jNWX207em
O@80Ogmo0P1mOGd207alO080OWin0P20P80208>3P`80QXJ60P28R8P408^;R`80S8b<0P2BTY8609NG
U`80V9RH0P2IVIT209^KV`80WIfM0P2PX:020:BTY080ZJVY0P2/[:`40:f][@80[Zj^0`2`/;020;:b
/P@0/k>c0P2b/[820;>c/`80];Bd0P2g]kL20;Rh^080];Bd102`/;020;6a/@80[Jf]0P2ZZZX20:f]
[@80[jn_0P2][Jd20:^[Z`80[:b/0P2][Jd20:VYZ@80Y:BT0P2RXZ8209nOW`80WYjN0P2MWId209ZJ
VP80UiNG0P2FUYH209FEU@80U9BD0`2BTY8209>CT`80U9BD0P2ATI4208j>SP80S8b<0P2;Rh/208V9
R@80QXJ60P23Ph<20861P@80P8200P1oOgl208:2PP@0QHF5:@38h=P205ADE0@0;bl_0P0h>3P203<c
<`80=CDe0P0T92@202XZ:P80;2`/0P0Z:RX202TY:@80<S8b0P0[:b/202LW9`80:2PX0P0R8R8302@T
9080<c<c0P1OGel2092@T080Y:BT0P23Ph<207=cL`80MgMg0P1bLW8208J6QP80_kno0P3<c<`20;6a
/@80_[jn0P31`L420;no_`80^[Zj0P31`L420=7Ad@80`L710P1RHV8202PX:0809bLW0P0X:2P202`/
;080<30`0P0d=3@204A4A080B4Q80P1EEED205mOG`80J6QX1@1dM7@407UiN@80N7Qh0P1lO7`40820
P080Ogmo0P1iNGT20820P080Ph>30P26QXH208Z:RP80S8b<0P2>SXh208f=S@80TY:B1P2HV9P209NG
U`80Vi^K0P2HV9P209bLW080X:2P0P2QXJ420:JVYP@0[Jf]0P2`/;050:j^[P80/k>c0P2e]KD20;>c
/`80[Zj^0P2f][H20;>c/`@0^[Zj0P2f][H20;Bd]080[Jf]0P2c/k<40:^[Z`80[:b/0P2`/;020:f]
[@80[:b/0P2XZ:P20;2`/080YZJV0P2TY:@20:FUY@80WIfM102OWil209RHV080UYJF0P2CTi<209BD
U080UIFE0`2ATI4209BDU0@0UIFE0P2<S8`208j>SP80S8b<0P2:RXX208F5Q@80QhN70P21PH4207in
OP80PH610P23Ph<208B4Q080Ph>3:@38h=P2059BDP@0;bl_0P0f=SH20451@@80;Bd]0P0W9bL202XZ
:P80:BTY0P0X:2P202/[:`80;Bd]0P0`<30202XZ:P808b<S1@0M7Ad203dm?@80FUYJ0P22PX820::R
XP80OWin0P1dM7@2071`L080N7Qh0P2<S8`20;bl_080alO70P2e]KD40<;2`P80_Kfm0P2k^k/20<S8
b080cLg=0P2d];@206e]K@80:b/[0P0W9bL202HV9P80;Rh^0P0`<30203Lg=`80?Cdm0P15ADD205EE
E@80HF5Q0P1WIfL3075aL@80L71`0P1fMWH207]kN`80O7al0P1kNg/20861P@@0Ng]k0P1mOGd20820
P080QXJ60P25QHD208N7Q`80RXZ:0P2>SXh208^;R`80Ti>C0P2GUiL209VIV@80UYJF0P2JVYX209RH
V080W9bL0P2MWId20:2PX080YZJV102[Zj/20:j^[P80[Jf]0P2^[Zh30;Bd]080[jn_0P2c/k<20;:b
/P80/K6a102d];@20;Ng]`80^;Rh0P2d];@20:n_[`80/K6a0P2^[Zh20;2`/080Zj^[0P2ZZZX20;2`
/0@0[jn_102/[:`20:VYZ@80Y:BT0P2SXj<20:2PX080W9bL0P2NWYh209ZJVP80Ti>C0P2GUiL209FE
U@80TY:B1@2CTi<209NGU`80TI6A0P2?Shl408V9R@80S8b<0P25QHD40861P@80Ogmo0P21PH4208B4
Q080QXJ60P23Ph<O0<SPf0007@38h=P2055AD@@0<30`0P0h>3P20451@@80=SHf100Y:BT202/[:`80
:RXZ0P0Y:BT202d];@80;bl_0P0Z:RX202@T90807QhN0`0P820203Ti>@80FUYJ0P23Ph<20:>SX`80
O7al0P1eMGD207=cL`80MWIf0P27QhL20;fm_@80c<c<0P2d];@20;fm_@80`<300P2k^k/20;Ng]`80
b<S80P3>c/h20;Vi^@80K6a/0P0Z:RX202<S8`8092@T0P0_;bl2038b<P80=cLg0P0o?cl204Y:BP80
EEEE0P1QHF4206YZJP<0LG5a0P1eMGD207MgM`80N7Qh0P1jNWX207emO@80Ogmo0P1mOGd207alO080
OWin0P20P80208>3P`80QXJ60P28R8P408^;R`80S8b<0P2BTY8609NGU`80V9RH0P2IVIT209^KV`80
WIfM0P2PX:020:BTY080ZJVY0P2/[:`40:f][@80[Zj^0`2`/;020;:b/P@0/k>c0P2b/[820;>c/`80
];Bd0P2g]kL20;Rh^080];Bd102`/;020;6a/@80[Jf]0P2ZZZX20:f][@80[jn_0P2][Jd20:^[Z`80
[:b/0P2][Jd20:VYZ@80Y:BT0P2RXZ8209nOW`80WYjN0P2MWId209ZJVP80UiNG0P2FUYH209FEU@80
U9BD0`2BTY8209>CT`80U9BD0P2ATI4208j>SP80S8b<0P2;Rh/208V9R@80QXJ60P23Ph<20861P@80
P8200P1oOgl208:2PP@0QHF5:@38h=P205ADE0@0;bl_0P0h>3P203<c<`80=CDe0P0T92@202XZ:P80
;2`/0P0Z:RX202TY:@80<S8b0P0[:b/202LW9`80:2PX0P0R8R8302@T9080<c<c0P1OGel2092@T080
Y:BT0P23Ph<207=cL`80MgMg0P1bLW8208J6QP80_kno0P3<c<`20;6a/@80_[jn0P31`L420;no_`80
^[Zj0P31`L420=7Ad@80`L710P1RHV8202PX:0809bLW0P0X:2P202`/;080<30`0P0d=3@204A4A080
B4Q80P1EEED205mOG`80J6QX1@1dM7@407UiN@80N7Qh0P1lO7`40820P080Ogmo0P1iNGT20820P080
Ph>30P26QXH208Z:RP80S8b<0P2>SXh208f=S@80TY:B1P2HV9P209NGU`80Vi^K0P2HV9P209bLW080
X:2P0P2QXJ420:JVYP@0[Jf]0P2`/;050:j^[P80/k>c0P2e]KD20;>c/`80[Zj^0P2f][H20;>c/`@0
^[Zj0P2f][H20;Bd]080[Jf]0P2c/k<40:^[Z`80[:b/0P2`/;020:f][@80[:b/0P2XZ:P20;2`/080
YZJV0P2TY:@20:FUY@80WIfM102OWil209RHV080UYJF0P2CTi<209BDU080UIFE0`2ATI4209BDU0@0
UIFE0P2<S8`208j>SP80S8b<0P2:RXX208F5Q@80QhN70P21PH4207inOP80PH610P23Ph<208B4Q080
Ph>3:@38h=P2059BDP@0;bl_0P0f=SH20451@@80;Bd]0P0W9bL202XZ:P80:BTY0P0X:2P202/[:`80
;Bd]0P0`<30202XZ:P808b<S1@0M7Ad203dm?@80FUYJ0P22PX820::RXP80OWin0P1dM7@2071`L080
N7Qh0P2<S8`20;bl_080alO70P2e]KD40<;2`P80_Kfm0P2k^k/20<S8b080cLg=0P2d];@206e]K@80
:b/[0P0W9bL202HV9P80;Rh^0P0`<30203Lg=`80?Cdm0P15ADD205EEE@80HF5Q0P1WIfL3075aL@80
L71`0P1fMWH207]kN`80O7al0P1kNg/20861P@@0Ng]k0P1mOGd20820P080QXJ60P25QHD208N7Q`80
RXZ:0P2>SXh208^;R`80Ti>C0P2GUiL209VIV@80UYJF0P2JVYX209RHV080W9bL0P2MWId20:2PX080
YZJV102[Zj/20:j^[P80[Jf]0P2^[Zh30;Bd]080[jn_0P2c/k<20;:b/P80/K6a102d];@20;Ng]`80
^;Rh0P2d];@20:n_[`80/K6a0P2^[Zh20;2`/080Zj^[0P2ZZZX20;2`/0@0[jn_102/[:`20:VYZ@80
Y:BT0P2SXj<20:2PX080W9bL0P2NWYh209ZJVP80Ti>C0P2GUiL209FEU@80TY:B1@2CTi<209NGU`80
TI6A0P2?Shl408V9R@80S8b<0P25QHD40861P@80Ogmo0P21PH4208B4Q080QXJ60P23Ph<O0<SPf000
7@38h=P206QXJ080<C4a0P0e=CD202HV9P808B4Q0P0U9BD202/[:`80;Bd]0P0^;Rh202XZ:P809bLW
0P0^;Rh203<c<`80;2`/0P0T92@202<S8`<09bLW0P0^;Rh20410@080M7Ad0P2QXJ4208n?S`80M7Ad
0P1cLg<207]kN`80LW9b0P2VYZH20<c<c080/K6a0P2k^k/20;fm_@80_;bl0P2i^KT20<71`@80`l?3
0P3MgMd20:j^[P80>c/k0P0Z:RX202@T9080<C4a0P0b<S8203Hf=P80?3`l0P14A4@205=CD`80HF5Q
0P1YJFT306i^KP80MGEe1P1iNGT207]kN`80O7al0P1kNg/207YjNP80OGem0P21PH4208>3P`80QXJ6
0P2;Rh/608n?S`80Ti>C0P2GUiL209RHV080VIVI0P2JVYX209^KV`80WIfM0P2NWYh20:6QX@80YJFU
0P2ZZZX40:j^[P80[Jf]0P2^[Zh30;2`/080/k>c0P2e]KD20;Bd]0X0/k>c0P2_[jl20:f][@80/;2`
0P2c/k<20;2`/080[:b/0P2_[jl20;:b/P80/;2`0P2][Jd20:b/[080Zj^[0P2ZZZX20:RXZ080YJFU
0P2QXJ4209nOW`80WIfM0P2JVYX409JFUP80UiNG0P2DU9@309:BTP80Ti>C0P2DU9@209:BTP80Shn?
0P2=SHd208b<S080RHV91025QHD208B4Q080P8200P1mOGd20820P080Ph>30P24Q8@Y0<SPf080GemO
0P0g=cL2030`<080:b/[0P0S8b<202TY:@80:b/[0P0_;bl202`/;0809bLW0P0V9RH2038b<P80<c<c
0P0`<30202HV9P808B4Q0`0Z:RX202`/;080?3`l0P1hN7P209NGU`80U9BD0P1fMWH206e]K@80OGem
0P1fMWH20:BTY080cLg=0P2c/k<20;Jf]P80_kno0P2k^k/20;bl_080_Kfm0P3:b/X20=7Ad@80[jn_
0P12@T8202TY:@809bLW0P0];Bd203Ti>@80=SHf0P0g=cL204M7A`80EeMG0P1QHF4206UYJ@<0KFe]
0P1eMGD207QhN080NWYj0P1hN7P207alO080NWYj0P1kNg/407YjNP@0Ph>30P26QXH208Z:RP80Shn?
0P2ATI4208n?S`80TI6A102HV9P209VIV@80V9RH0P2MWId209bLW080WYjN0P2RXZ820:JVYP80Z:RX
0P2_[jl40:j^[P80[Jf]1@2a/K420;Bd]080/k>c102d];@20;:b/P80];Bd0P2b/[820;2`/080[jn_
0P2/[:`20;Jf]P80[Jf]0P2_[jl20;2`/080/k>c0P2^[Zh20;2`/080ZZZZ0P2/[:`20:j^[P80YjNW
0P2VYZH20::RXP80WinO0P2MWId209ZJVP80V9RH0P2BTY8409VIV@<0TY:B0P2ATI4209FEU@80U9BD
0P2?Shl408b<S080RXZ:0P24Q8@208V9R@80Ph>30P21PH4207alO080PH610P24Q8@208:2PRT0b>3H
0P1XJ6P2038b<P80<c<c0P0/;2`201dM7@809RHV0P0Z:RX203<c<`80:b/[0P0];Bd202HV9P80:b/[
0P0a<C4202h^;P808R8R0P0T92@302<S8`80<C4a0P0o?cl2071`L080XZ:R0P2@T90207=cL`80MWIf
0P1gMgL2075aL@80YjNW0P39bLT20;>c/`80^[Zj102l_;`20;Ng]`80`<300P35aLD20=gMg@80[Jf]
0P0j>SX202HV9P808R8R0P0c<c<2038b<P80=CDe0P10@40204A4A080De=C0P1PH60206UYJ@<0Kfm_
0P1cLg<207UiN@80OGem101hN7P207inOP80N7Qh0P1kNg/207QhN080P8200P27QhL208F5Q@80RXZ:
0P2>SXh2092@T080Shn?0P2BTY8209JFUP80VIVI0P2HV9P209VIV@80WIfM0P2LW9`209nOW`80X:2P
0P2TY:@20:ZZZP80[Jf]0P2a/K420:f][@80[Zj^0`2_[jl20;>c/`80]KFe0P2c/k<20;Bd]0@0/[:b
0P2d];@20;:b/P80/K6a0P2][Jd20;2`/080/k>c0P2a/K420:ZZZP80[jn_0P2d];@20:n_[`80[Jf]
102/[:`20:ZZZP80Z:RX0P2VYZH20:6QX@80WinO0P2LW9`209jNWP80UiNG0P2CTi<209RHV080Ti>C
0`2BTY8209BDU080UIFE0P2?Shl2092@T080SXj>0P2;Rh/208Z:RP80QHF50P24Q8@208F5Q@80OWin
0P1mOGd20820P080Ph>30P20P80O0<SPf0007@38h=P206QXJ080<C4a0P0e=CD202HV9P808B4Q0P0U
9BD202/[:`80;Bd]0P0^;Rh202XZ:P809bLW0P0^;Rh203<c<`80;2`/0P0T92@202<S8`<09bLW0P0^
;Rh20410@080M7Ad0P2QXJ4208n?S`80M7Ad0P1cLg<207]kN`80LW9b0P2VYZH20<c<c080/K6a0P2k
^k/20;fm_@80_;bl0P2i^KT20<71`@80`l?30P3MgMd20:j^[P80>c/k0P0Z:RX202@T9080<C4a0P0b
<S8203Hf=P80?3`l0P14A4@205=CD`80HF5Q0P1YJFT306i^KP80MGEe1P1iNGT207]kN`80O7al0P1k
Ng/207YjNP80OGem0P21PH4208>3P`80QXJ60P2;Rh/608n?S`80Ti>C0P2GUiL209RHV080VIVI0P2J
VYX209^KV`80WIfM0P2NWYh20:6QX@80YJFU0P2ZZZX40:j^[P80[Jf]0P2^[Zh30;2`/080/k>c0P2e
]KD20;Bd]0X0/k>c0P2_[jl20:f][@80/;2`0P2c/k<20;2`/080[:b/0P2_[jl20;:b/P80/;2`0P2]
[Jd20:b/[080Zj^[0P2ZZZX20:RXZ080YJFU0P2QXJ4209nOW`80WIfM0P2JVYX409JFUP80UiNG0P2D
U9@309:BTP80Ti>C0P2DU9@209:BTP80Shn?0P2=SHd208b<S080RHV91025QHD208B4Q080P8200P1m
OGd20820P080Ph>30P24Q8@Y0<SPf080GemO0P0g=cL2030`<080:b/[0P0S8b<202TY:@80:b/[0P0_
;bl202`/;0809bLW0P0V9RH2038b<P80<c<c0P0`<30202HV9P808B4Q0`0Z:RX202`/;080?3`l0P1h
N7P209NGU`80U9BD0P1fMWH206e]K@80OGem0P1fMWH20:BTY080cLg=0P2c/k<20;Jf]P80_kno0P2k
^k/20;bl_080_Kfm0P3:b/X20=7Ad@80[jn_0P12@T8202TY:@809bLW0P0];Bd203Ti>@80=SHf0P0g
=cL204M7A`80EeMG0P1QHF4206UYJ@<0KFe]0P1eMGD207QhN080NWYj0P1hN7P207alO080NWYj0P1k
Ng/407YjNP@0Ph>30P26QXH208Z:RP80Shn?0P2ATI4208n?S`80TI6A102HV9P209VIV@80V9RH0P2M
WId209bLW080WYjN0P2RXZ820:JVYP80Z:RX0P2_[jl40:j^[P80[Jf]1@2a/K420;Bd]080/k>c102d
];@20;:b/P80];Bd0P2b/[820;2`/080[jn_0P2/[:`20;Jf]P80[Jf]0P2_[jl20;2`/080/k>c0P2^
[Zh20;2`/080ZZZZ0P2/[:`20:j^[P80YjNW0P2VYZH20::RXP80WinO0P2MWId209ZJVP80V9RH0P2B
TY8409VIV@<0TY:B0P2ATI4209FEU@80U9BD0P2?Shl408b<S080RXZ:0P24Q8@208V9R@80Ph>30P21
PH4207alO080PH610P24Q8@208:2PRT0b>3H0P1XJ6P2038b<P80<c<c0P0/;2`201dM7@809RHV0P0Z
:RX203<c<`80:b/[0P0];Bd202HV9P80:b/[0P0a<C4202h^;P808R8R0P0T92@302<S8`80<C4a0P0o
?cl2071`L080XZ:R0P2@T90207=cL`80MWIf0P1gMgL2075aL@80YjNW0P39bLT20;>c/`80^[Zj102l
_;`20;Ng]`80`<300P35aLD20=gMg@80[Jf]0P0j>SX202HV9P808R8R0P0c<c<2038b<P80=CDe0P10
@40204A4A080De=C0P1PH60206UYJ@<0Kfm_0P1cLg<207UiN@80OGem101hN7P207inOP80N7Qh0P1k
Ng/207QhN080P8200P27QhL208F5Q@80RXZ:0P2>SXh2092@T080Shn?0P2BTY8209JFUP80VIVI0P2H
V9P209VIV@80WIfM0P2LW9`209nOW`80X:2P0P2TY:@20:ZZZP80[Jf]0P2a/K420:f][@80[Zj^0`2_
[jl20;>c/`80]KFe0P2c/k<20;Bd]0@0/[:b0P2d];@20;:b/P80/K6a0P2][Jd20;2`/080/k>c0P2a
/K420:ZZZP80[jn_0P2d];@20:n_[`80[Jf]102/[:`20:ZZZP80Z:RX0P2VYZH20:6QX@80WinO0P2L
W9`209jNWP80UiNG0P2CTi<209RHV080Ti>C0`2BTY8209BDU080UIFE0P2?Shl2092@T080SXj>0P2;
Rh/208Z:RP80QHF50P24Q8@208F5Q@80OWin0P1mOGd20820P080Ph>30P20P80O0<SPf0007@38h=P2
05=CD`80<S8b0P0a<C4202XZ:P80:BTY0P0Z:RX602d];@80;2`/0P0[:b/202d];@80;bl_0P0];Bd2
02XZ:PL0:BTY0P0c<c<205iNGP80QXJ60P2MWId208>3P`80KVi^0P1kNg/206m_K`80Rh^;0P2d];@2
0;Rh^080Zj^[102n_[h20;no_`80`l?30P34a<@20=SHf080^k^k0P2QXJ4203lo?`807alO0P0Y:BT2
02XZ:P80=3@d0P0k>c/204A4A080DU9B0P1PH60206MWI`<0K6a/0P1cLg<207QhN0@0NWYj0P1kNg/2
07emO@@0O7al0P1oOgl208:2PP80Q8B40P26QXH208Z:RP80SXj>0P2ATI4209:BTP80Ti>C0P2EUID2
09NGU`80VYZJ0P2KVi/209bLW080WinO0P2RXZ820:BTY080YJFU0P2YZJT20:b/[0@0[Jf]0P2^[Zh3
0;2`/080/[:b1P2d];@20;:b/P80/K6a102b/[820;6a/@80[jn_0P2`/;020;6a/@80/;2`0P2_[jl2
0;6a/@@0/[:b0P2a/K420:j^[P80[:b/0P2ZZZX20:RXZ080YJFU0P2RXZ8209nOW`80W9bL0P2KVi/2
09ZJVP80UiNG0P2DU9@909>CT`80T92@0P2>SXh208b<S080RXZ:0P27QhL208F5Q@@0Q8B40P22PX88
0820P2T0b>3H0P1@D50203Xj>P@0;Rh^0P0V9RH2038b<P80:RXZ0P0`<302038b<P80:RXZ0P0];Bd2
02h^;P80;bl_0P0Y:BT202LW9`809RHV0`0X:2P202XZ:P80<S8b0P1LG5`208R8R080Vi^K0P1oOgl2
06UYJ@@0NGUi0P23Ph<20;:b/P80^;Rh0P2/[:`20;^k^`80_Kfm0P30`<020;jn_P80b<S80P3AdM42
0<g=c@80V9RH0P0e=CD202@T90809RHV0P0_;bl2038b<P80>c/k0P11@D4205ADE080HF5Q0P1UIFD3
06i^KP80LW9b0P1jNWX207MgM`80Ng]k101lO7`207moO`80OGem0P1lO7`208J6QP80PH610P27QhL2
08V9R@80Rh^;0P2?Shl209>CT`80SXj>0P2EUID209JFUP@0Vi^K102LW9`20:FUY@80Y:BT0P2WYjL2
0:RXZ080[:b/0P2ZZZX40:b/[0<0/K6a0P2c/k<40;Bd]0@0/k>c0P2`/;020:f][@80/;2`1P2^[Zh2
0;>c/`80/;2`102][Jd20;:b/P80/k>c0P2a/K420:^[Z`80ZZZZ0P2YZJT20:FUY@80XZ:R0P2QXJ42
09jNWPH0Vi^K0P2JVYX2092@T080TY:B0`2ATI42092@T080SXj>0P2BTY8408^;R`80R8R81024Q8@2
0820P080PH610P24Q8@407moO`80P8200P22PX8Y0<SPf080DE5A0P0b<S82030`<080;Rh^100/;2`2
02/[:`80<30`0P0Z:RX202l_;`80:RXZ0P0`<302034a<@@0;Bd]1@0[:b/202d];@80<30`0P1QHF42
08J6QP80X:2P0P22PX8206i^KP80OGem0P1`L70208j>SP80/[:b0P2i^KT20:VYZ@80_;bl0P31`L42
0;bl_080b<S80P33`l<20=KFeP80_Kfm0P2UYJD20451@@808R8R0P0X:2P202DU9@80=CDe0P0m?Cd2
04A4A080De=C0P1PH60206][J`<0K6a/0P1fMWH607QhN080Ng]k0P1oOgl207YjNP80Ph>30P24Q8@2
0861P@80QHF50P23Ph<208b<S080SHf=0P2DU9@2096AT@80Ti>C0P2BTY8209bLW080Vi^K0P2GUiL4
09jNWP80Y:BT0P2QXJ420:JVYP80ZZZZ0P2[Zj/20:f][@80Zj^[0P2/[:`30;2`/080/k>c0P2g]kL2
0;:b/P80]KFe0P2d];@40;:b/P@0/K6a102_[jl20;2`/080/k>c0P2_[jl20;2`/080/[:b0P2_[jl2
0;2`/080[Jf]0P2/[:`20:VYZ@80Z:RX0P2UYJD40:6QX@80VYZJ102KVi/209FEU@80UiNG0P2DU9@3
09>CT`80UIFE0P2BTY8208n?S`80SHf=0P2?Shl208^;R`80QHF50P26QXH208B4Q080QHF50P21PH44
0820P080Ph>30P1oOglO0<SPf0007@38h=P205=CD`80<S8b0P0a<C4202XZ:P80:BTY0P0Z:RX602d]
;@80;2`/0P0[:b/202d];@80;bl_0P0];Bd202XZ:PL0:BTY0P0c<c<205iNGP80QXJ60P2MWId208>3
P`80KVi^0P1kNg/206m_K`80Rh^;0P2d];@20;Rh^080Zj^[102n_[h20;no_`80`l?30P34a<@20=SH
f080^k^k0P2QXJ4203lo?`807alO0P0Y:BT202XZ:P80=3@d0P0k>c/204A4A080DU9B0P1PH60206MW
I`<0K6a/0P1cLg<207QhN0@0NWYj0P1kNg/207emO@@0O7al0P1oOgl208:2PP80Q8B40P26QXH208Z:
RP80SXj>0P2ATI4209:BTP80Ti>C0P2EUID209NGU`80VYZJ0P2KVi/209bLW080WinO0P2RXZ820:BT
Y080YJFU0P2YZJT20:b/[0@0[Jf]0P2^[Zh30;2`/080/[:b1P2d];@20;:b/P80/K6a102b/[820;6a
/@80[jn_0P2`/;020;6a/@80/;2`0P2_[jl20;6a/@@0/[:b0P2a/K420:j^[P80[:b/0P2ZZZX20:RX
Z080YJFU0P2RXZ8209nOW`80W9bL0P2KVi/209ZJVP80UiNG0P2DU9@909>CT`80T92@0P2>SXh208b<
S080RXZ:0P27QhL208F5Q@@0Q8B40P22PX880820P2T0b>3H0P1@D50203Xj>P@0;Rh^0P0V9RH2038b
<P80:RXZ0P0`<302038b<P80:RXZ0P0];Bd202h^;P80;bl_0P0Y:BT202LW9`809RHV0`0X:2P202XZ
:P80<S8b0P1LG5`208R8R080Vi^K0P1oOgl206UYJ@@0NGUi0P23Ph<20;:b/P80^;Rh0P2/[:`20;^k
^`80_Kfm0P30`<020;jn_P80b<S80P3AdM420<g=c@80V9RH0P0e=CD202@T90809RHV0P0_;bl2038b
<P80>c/k0P11@D4205ADE080HF5Q0P1UIFD306i^KP80LW9b0P1jNWX207MgM`80Ng]k101lO7`207mo
O`80OGem0P1lO7`208J6QP80PH610P27QhL208V9R@80Rh^;0P2?Shl209>CT`80SXj>0P2EUID209JF
UP@0Vi^K102LW9`20:FUY@80Y:BT0P2WYjL20:RXZ080[:b/0P2ZZZX40:b/[0<0/K6a0P2c/k<40;Bd
]0@0/k>c0P2`/;020:f][@80/;2`1P2^[Zh20;>c/`80/;2`102][Jd20;:b/P80/k>c0P2a/K420:^[
Z`80ZZZZ0P2YZJT20:FUY@80XZ:R0P2QXJ4209jNWPH0Vi^K0P2JVYX2092@T080TY:B0`2ATI42092@
T080SXj>0P2BTY8408^;R`80R8R81024Q8@20820P080PH610P24Q8@407moO`80P8200P22PX8Y0<SP
f080DE5A0P0b<S82030`<080;Rh^100/;2`202/[:`80<30`0P0Z:RX202l_;`80:RXZ0P0`<302034a
<@@0;Bd]1@0[:b/202d];@80<30`0P1QHF4208J6QP80X:2P0P22PX8206i^KP80OGem0P1`L70208j>
SP80/[:b0P2i^KT20:VYZ@80_;bl0P31`L420;bl_080b<S80P33`l<20=KFeP80_Kfm0P2UYJD20451
@@808R8R0P0X:2P202DU9@80=CDe0P0m?Cd204A4A080De=C0P1PH60206][J`<0K6a/0P1fMWH607Qh
N080Ng]k0P1oOgl207YjNP80Ph>30P24Q8@20861P@80QHF50P23Ph<208b<S080SHf=0P2DU9@2096A
T@80Ti>C0P2BTY8209bLW080Vi^K0P2GUiL409jNWP80Y:BT0P2QXJ420:JVYP80ZZZZ0P2[Zj/20:f]
[@80Zj^[0P2/[:`30;2`/080/k>c0P2g]kL20;:b/P80]KFe0P2d];@40;:b/P@0/K6a102_[jl20;2`
/080/k>c0P2_[jl20;2`/080/[:b0P2_[jl20;2`/080[Jf]0P2/[:`20:VYZ@80Z:RX0P2UYJD40:6Q
X@80VYZJ102KVi/209FEU@80UiNG0P2DU9@309>CT`80UIFE0P2BTY8208n?S`80SHf=0P2?Shl208^;
R`80QHF50P26QXH208B4Q080QHF50P21PH440820P080Ph>30P1oOglO0<SPf0007@38h=P205=CD`80
<S8b0P0a<C4202XZ:P80:BTY0P0Z:RX602d];@80;2`/0P0[:b/202d];@80;bl_0P0];Bd202XZ:PL0
:BTY0P0c<c<205iNGP80QXJ60P2MWId208>3P`80KVi^0P1kNg/206m_K`80Rh^;0P2d];@20;Rh^080
Zj^[102n_[h20;no_`80`l?30P34a<@20=SHf080^k^k0P2QXJ4203lo?`807alO0P0Y:BT202XZ:P80
=3@d0P0k>c/204A4A080DU9B0P1PH60206MWI`<0K6a/0P1cLg<207QhN0@0NWYj0P1kNg/207emO@@0
O7al0P1oOgl208:2PP80Q8B40P26QXH208Z:RP80SXj>0P2ATI4209:BTP80Ti>C0P2EUID209NGU`80
VYZJ0P2KVi/209bLW080WinO0P2RXZ820:BTY080YJFU0P2YZJT20:b/[0@0[Jf]0P2^[Zh30;2`/080
/[:b1P2d];@20;:b/P80/K6a102b/[820;6a/@80[jn_0P2`/;020;6a/@80/;2`0P2_[jl20;6a/@@0
/[:b0P2a/K420:j^[P80[:b/0P2ZZZX20:RXZ080YJFU0P2RXZ8209nOW`80W9bL0P2KVi/209ZJVP80
UiNG0P2DU9@909>CT`80T92@0P2>SXh208b<S080RXZ:0P27QhL208F5Q@@0Q8B40P22PX880820P2T0
b>3H0P1@D50203Xj>P@0;Rh^0P0V9RH2038b<P80:RXZ0P0`<302038b<P80:RXZ0P0];Bd202h^;P80
;bl_0P0Y:BT202LW9`809RHV0`0X:2P202XZ:P80<S8b0P1LG5`208R8R080Vi^K0P1oOgl206UYJ@@0
NGUi0P23Ph<20;:b/P80^;Rh0P2/[:`20;^k^`80_Kfm0P30`<020;jn_P80b<S80P3AdM420<g=c@80
V9RH0P0e=CD202@T90809RHV0P0_;bl2038b<P80>c/k0P11@D4205ADE080HF5Q0P1UIFD306i^KP80
LW9b0P1jNWX207MgM`80Ng]k101lO7`207moO`80OGem0P1lO7`208J6QP80PH610P27QhL208V9R@80
Rh^;0P2?Shl209>CT`80SXj>0P2EUID209JFUP@0Vi^K102LW9`20:FUY@80Y:BT0P2WYjL20:RXZ080
[:b/0P2ZZZX40:b/[0<0/K6a0P2c/k<40;Bd]0@0/k>c0P2`/;020:f][@80/;2`1P2^[Zh20;>c/`80
/;2`102][Jd20;:b/P80/k>c0P2a/K420:^[Z`80ZZZZ0P2YZJT20:FUY@80XZ:R0P2QXJ4209jNWPH0
Vi^K0P2JVYX2092@T080TY:B0`2ATI42092@T080SXj>0P2BTY8408^;R`80R8R81024Q8@20820P080
PH610P24Q8@407moO`80P8200P22PX8Y0<SPf080DE5A0P0b<S82030`<080;Rh^100/;2`202/[:`80
<30`0P0Z:RX202l_;`80:RXZ0P0`<302034a<@@0;Bd]1@0[:b/202d];@80<30`0P1QHF4208J6QP80
X:2P0P22PX8206i^KP80OGem0P1`L70208j>SP80/[:b0P2i^KT20:VYZ@80_;bl0P31`L420;bl_080
b<S80P33`l<20=KFeP80_Kfm0P2UYJD20451@@808R8R0P0X:2P202DU9@80=CDe0P0m?Cd204A4A080
De=C0P1PH60206][J`<0K6a/0P1fMWH607QhN080Ng]k0P1oOgl207YjNP80Ph>30P24Q8@20861P@80
QHF50P23Ph<208b<S080SHf=0P2DU9@2096AT@80Ti>C0P2BTY8209bLW080Vi^K0P2GUiL409jNWP80
Y:BT0P2QXJ420:JVYP80ZZZZ0P2[Zj/20:f][@80Zj^[0P2/[:`30;2`/080/k>c0P2g]kL20;:b/P80
]KFe0P2d];@40;:b/P@0/K6a102_[jl20;2`/080/k>c0P2_[jl20;2`/080/[:b0P2_[jl20;2`/080
[Jf]0P2/[:`20:VYZ@80Z:RX0P2UYJD40:6QX@80VYZJ102KVi/209FEU@80UiNG0P2DU9@309>CT`80
UIFE0P2BTY8208n?S`80SHf=0P2?Shl208^;R`80QHF50P26QXH208B4Q080QHF50P21PH440820P080
Ph>30P1oOglO0<SPf0007@38h=P203Xj>P80=CDe0P0/;2`202d];@H0;Rh^0P0];Bd202`/;080;Bd]
0P0_;bl202`/;080:RXZ0P0];Bd202l_;`80;Bd]0`0Z:RX202LW9`80:b/[0P17AdL206ATI080X:2P
0P2EUID206a/K080Ng]k0P1bLW8207AdM080UiNG0P2m_Kd209nOW`80_Kfm0P2o_kl20<C4a0@0`/;2
0P3AdM420=OGe`80`<300P1jNWX203De=@807alO0P0P8202034a<@80>SXj0P15ADD2059BDP80GUiN
0P1UIFD306YZJP80LG5a0P1gMgL207UiN@80NWYj0P1lO7`207emO@80OWin0P20P80208:2PP80Q8B4
0P25QHD208N7Q`80RXZ:0P2=SHd2096AT@@0U9BD0P2CTi<209JFUP80VIVI0P2KVi/209bLW080X:2P
0P2TY:@40:JVYP80Z:RX0P2ZZZX20:b/[080[Jf]0P2^[Zh30:n_[`80/K6a0P2b/[820;>c/`80];Bd
0P2a/K420:n_[`80/K6a102c/k<20;:b/P80/;2`0P2^[Zh20;2`/080/[:b102a/K420;:b/P80/k>c
0P2a/K420:f][@80ZZZZ0P2WYjL20:FUY@80Xj>S0P2OWil209^KV`@0W9bL0P2FUYH2096AT@80TY:B
0`2DU9@209>CT`80TI6A0P2?Shl208f=S@80RXZ:0P27QhL208F5Q@80Q8B40P23Ph<408B4Q080Ph>3
0P21PH4407inORT0b>3H0P0g=cL203Ph>080:BTY0P0^;Rh202l_;`80<S8b0P0^;Rh202d];@80:b/[
0P0/;2`202d];@80;bl_0P0Z:RX202l_;`80<c<c1@0Y:BT202XZ:P80<30`0P0j>SX206a/K080U9BD
0P2GUiL407=cL`80N7Qh0P1eMGD2092@T080_;bl0P2XZ:P20;Jf]P@0`L711033`l<20<g=c@80d];B
0P39bLT207alO080;Bd]0P0Q8B4202PX:080;Bd]0P0h>3P204M7A`80EEEE0P1PH602069RHP<0K6a/
0P1_Kfl207MgM`80O7al0P1kNg/207YjNP80OWin1020P80207moO`80QhN70P21PH4208Z:RP80R8R8
0P2>SXh409BDU080TI6A0P2CTi<409NGU`H0WIfM102UYJD40:NWY`80ZZZZ0P2^[Zh20:f][@80[:b/
0`2`/;020;6a/@80/k>c0P2`/;020;Fe]@80[jn_0P2`/;020;Bd]080/[:b0P2g]kL20;Bd]0@0[Zj^
0P2_[jl20;Bd]080/k>c0P2`/;020;>c/`@0/[:b0P2][Jd20:ZZZP80Z:RX0P2VYZH40:6QX@80VYZJ
0P2MWId209VIV@80VYZJ0P2@T90509:BTP80U9BD0P2@T90209BDU080RXZ:0P2=SHd208Z:RP80PH61
0P25QHD208N7Q`80QHF50P23Ph<408:2PP80Ng]k0P1oOglY0<SPf080?Cdm0P0d=3@202/[:`80;bl_
0P0Y:BT203<c<`80:BTY0P0];Bd402/[:`80<30`100];Bd202TY:@80<S8b0P0^;Rh302PX:0809bLW
0P0^;Rh204A4A080I6AT0P2OWil209VIV@80I6AT0P20P80206a/K080MGEe0P2JVYX20;bl_080Xj>S
0P2i^KT40<30`080aLG50P32`/820<k>cP80e]KF0P2n_[h207QhN080>SXj0P0M7Ad201hN7P80<C4a
0P0j>SX204=3@`80D51@0P1MGEd206IVIP<0JVYZ101cLg<207moO`@0NWYj0P1mOGd207]kN`80PH61
0P20P80208B4Q0@0R8R80P2;Rh/208b<S080TY:B0P2EUID409:BTP80VIVI0P2HV9P209VIV@80WIfM
0P2QXJ420:FUY@80XZ:R0P2WYjL20:ZZZP80Zj^[0P2/[:`40:j^[P<0[jn_0P2a/K440;:b/P80/k>c
0P2b/[820:f][@80/[:b0P2c/k<20;Bd]080/k>c102_[jl20:j^[P80/k>c0P2a/K420;:b/P80/k>c
0P2d];@20;2`/080[Jf]0P2/[:`20:RXZ0@0Xj>S0P2QXJ4209ZJVP80WYjN0P2MWId209>CT`@0TY:B
0`2CTi<209:BTP80TI6A102>SXh208V9R@80R8R81024Q8@408>3P`80QHF50P23Ph<207inOP80P820
0P1mOGdO0<SPf0007@38h=P203Xj>P80=CDe0P0/;2`202d];@H0;Rh^0P0];Bd202`/;080;Bd]0P0_
;bl202`/;080:RXZ0P0];Bd202l_;`80;Bd]0`0Z:RX202LW9`80:b/[0P17AdL206ATI080X:2P0P2E
UID206a/K080Ng]k0P1bLW8207AdM080UiNG0P2m_Kd209nOW`80_Kfm0P2o_kl20<C4a0@0`/;20P3A
dM420=OGe`80`<300P1jNWX203De=@807alO0P0P8202034a<@80>SXj0P15ADD2059BDP80GUiN0P1U
IFD306YZJP80LG5a0P1gMgL207UiN@80NWYj0P1lO7`207emO@80OWin0P20P80208:2PP80Q8B40P25
QHD208N7Q`80RXZ:0P2=SHd2096AT@@0U9BD0P2CTi<209JFUP80VIVI0P2KVi/209bLW080X:2P0P2T
Y:@40:JVYP80Z:RX0P2ZZZX20:b/[080[Jf]0P2^[Zh30:n_[`80/K6a0P2b/[820;>c/`80];Bd0P2a
/K420:n_[`80/K6a102c/k<20;:b/P80/;2`0P2^[Zh20;2`/080/[:b102a/K420;:b/P80/k>c0P2a
/K420:f][@80ZZZZ0P2WYjL20:FUY@80Xj>S0P2OWil209^KV`@0W9bL0P2FUYH2096AT@80TY:B0`2D
U9@209>CT`80TI6A0P2?Shl208f=S@80RXZ:0P27QhL208F5Q@80Q8B40P23Ph<408B4Q080Ph>30P21
PH4407inORT0b>3H0P0g=cL203Ph>080:BTY0P0^;Rh202l_;`80<S8b0P0^;Rh202d];@80:b/[0P0/
;2`202d];@80;bl_0P0Z:RX202l_;`80<c<c1@0Y:BT202XZ:P80<30`0P0j>SX206a/K080U9BD0P2G
UiL407=cL`80N7Qh0P1eMGD2092@T080_;bl0P2XZ:P20;Jf]P@0`L711033`l<20<g=c@80d];B0P39
bLT207alO080;Bd]0P0Q8B4202PX:080;Bd]0P0h>3P204M7A`80EEEE0P1PH602069RHP<0K6a/0P1_
Kfl207MgM`80O7al0P1kNg/207YjNP80OWin1020P80207moO`80QhN70P21PH4208Z:RP80R8R80P2>
SXh409BDU080TI6A0P2CTi<409NGU`H0WIfM102UYJD40:NWY`80ZZZZ0P2^[Zh20:f][@80[:b/0`2`
/;020;6a/@80/k>c0P2`/;020;Fe]@80[jn_0P2`/;020;Bd]080/[:b0P2g]kL20;Bd]0@0[Zj^0P2_
[jl20;Bd]080/k>c0P2`/;020;>c/`@0/[:b0P2][Jd20:ZZZP80Z:RX0P2VYZH40:6QX@80VYZJ0P2M
WId209VIV@80VYZJ0P2@T90509:BTP80U9BD0P2@T90209BDU080RXZ:0P2=SHd208Z:RP80PH610P25
QHD208N7Q`80QHF50P23Ph<408:2PP80Ng]k0P1oOglY0<SPf080?Cdm0P0d=3@202/[:`80;bl_0P0Y
:BT203<c<`80:BTY0P0];Bd402/[:`80<30`100];Bd202TY:@80<S8b0P0^;Rh302PX:0809bLW0P0^
;Rh204A4A080I6AT0P2OWil209VIV@80I6AT0P20P80206a/K080MGEe0P2JVYX20;bl_080Xj>S0P2i
^KT40<30`080aLG50P32`/820<k>cP80e]KF0P2n_[h207QhN080>SXj0P0M7Ad201hN7P80<C4a0P0j
>SX204=3@`80D51@0P1MGEd206IVIP<0JVYZ101cLg<207moO`@0NWYj0P1mOGd207]kN`80PH610P20
P80208B4Q0@0R8R80P2;Rh/208b<S080TY:B0P2EUID409:BTP80VIVI0P2HV9P209VIV@80WIfM0P2Q
XJ420:FUY@80XZ:R0P2WYjL20:ZZZP80Zj^[0P2/[:`40:j^[P<0[jn_0P2a/K440;:b/P80/k>c0P2b
/[820:f][@80/[:b0P2c/k<20;Bd]080/k>c102_[jl20:j^[P80/k>c0P2a/K420;:b/P80/k>c0P2d
];@20;2`/080[Jf]0P2/[:`20:RXZ0@0Xj>S0P2QXJ4209ZJVP80WYjN0P2MWId209>CT`@0TY:B0`2C
Ti<209:BTP80TI6A102>SXh208V9R@80R8R81024Q8@408>3P`80QHF50P23Ph<207inOP80P8200P1m
OGdO0<SPf0007@38h=P203hn?P80>3Ph0P0[:b/202h^;P80<S8b0P0a<C4602l_;``0;Rh^0P0];Bd3
02/[:`80:2PX0P0Y:BT203De=@80B4Q80P2<S8`20::RXP80OGem0P1cLg<206m_K`80LG5a0P1oOgl4
0;Fe]@80/K6a0P2k^k/20<71`@@0`/;20P39bLT20=3@d080f=SH0P2e]KD204m?C`80<30`0P0X:2P2
02TY:@80=CDe0P14A4@204m?C`80FEUI0P1QHF4306MWI`80Kfm_0P1fMWH407QhN080NWYj0P1mOGd2
07inOP80P8200P21PH4208>3P`80QXJ60P29RHT208^;R`80SHf=0P2@T90209>CT`@0UIFE0P2FUYH2
09RHV080Vi^K0P2NWYh20:6QX@80XZ:R0P2UYJD20:NWY`80ZZZZ102/[:`20:^[Z`80[Jf]0`2`/;02
0;>c/`80];Bd0P2a/K420:j^[P80[Jf]0P2^[Zh20;6a/@@0/k>c0P2b/[880;6a/@80/;2`0P2_[jl2
0;2`/080/K6a0P2`/;020:n_[`80[:b/0P2YZJT20:NWY`80YJFU0P2QXJ4209fMW@80VYZJ0P2GUiL2
09FEU@@0Ti>C0`2EUID209>CT`80TI6A0P2?Shl208f=S@80RXZ:0P27QhL208F5Q@H0Q8B40P23Ph<2
08:2PPH0PH61:@38h=P203hn?P80=CDe0P0_;bl202d];@H0;Rh^0P0_;bl202d];@80;Rh^0P0`<302
02h^;P80;Bd]0P0^;Rh202l_;`80<C4a0`0`<30202/[:`80;2`/0P0f=SH205=CD`80RHV90P2ZZZX2
0820P080Lg=c0P1bLW8207AdM080OGem102e]KD20;>c/`80_;bl0P30`<040<?3``80a/K6103?cll2
0;fm_@80F5QH0P0Y:BT202@T9080;Rh^0P0d=3@204A4A080CDe=0P1GEeL205mOG`<0JFUY0P1_Kfl2
07MgM`80MGEe0P1gMgL207UiN@80O7al0P1mOGd207inOP80QXJ60P22PX8208>3P`80SHf=0P29RHT2
08f=S@80U9BD0P2CTi<209NGU`80V9RH0P2GUiL209RHV080VYZJ0P2NWYh20:6QX@80XZ:R0P2SXj<2
0:NWY`80ZJVY0P2[Zj/20:j^[P80[Jf]0P2[Zj/30:j^[P80/k>c0P2b/[820;Bd]080/;2`0P2/[:`2
0:ZZZP80];Bd0P2c/k<20;2`/0@0/K6a0P2b/[820;6a/@80/;2`0P2][Jd20:j^[P80/[:b0P2_[jl2
0;:b/P80[jn_0P2][Jd20:ZZZP80ZJVY0P2WYjL20:BTY080Vi^K0P2LW9`209BDU080Ti>C102DU9@3
09RHV080UIFE0P2>SXh209:BTP80RXZ:0P2=SHd208J6QP80PX:20P28R8P208J6QP80Q8B40P1oOgl2
08B4Q080Ph>30P22PX8208F5QBT0b>3H0P0n?Sh203Ph>080;Bd]0P0^;Rh2038b<P80;2`/0P0d=3@2
034a<@80<30`100];Bd202PX:080;Bd]0P0V9RH202h^;P80:2PX0`0[:b/202d];@809BDU0P0a<C42
04Y:BP80SHf=0P2SXj<207]kN`80MGEe0P1_Kfl207=cL`80OGem102c/k<20;:b/P80^k^k0P33`l<2
0;no_`80`/;20P3:b/X20=CDe080fMWI0P2a/K42055AD@80<30`0P0W9bL202TY:@80>3Ph0P16ATH2
05=CD`80EEEE0P1UIFD3065QH@80K6a/0P1dM7@207emO@80M7Ad0P1kNg/20820P080PH610P1lO7`2
07emO@80PX:20P28R8P208F5Q@80RXZ:0P2;Rh/208n?S`80UIFE0P2DU9@209RHV0@0UiNG0P2KVi/2
09nOW`80XJ6Q0P2UYJD20:BTY080Z:RX0P2[Zj/20:ZZZP80ZJVY0P2[Zj/20;2`/0<0/K6a0P2`/;02
0;>c/`80];Bd0P2_[jl20:^[Z`80[Zj^102b/[840;>c/`80/K6a0P2c/k<20:j^[P80/[:b0P2[Zj/2
0;2`/0@0/K6a0P2b/[820:j^[P80[Jf]0P2[Zj/20:JVYP80YJFU0P2SXj<209jNWP80VIVI0P2GUiL2
09>CT`80TI6A0P2DU9@309>CT`80UIFE0P2@T902096AT@80SHf=1028R8P208B4Q0@0QHF50P23Ph<2
08F5Q@80PX:20P20P8020861P@80OWin7`38h=P001d0b>3H0P0n?Sh203Ph>080:b/[0P0^;Rh2038b
<P80<C4a1P0_;bl<02h^;P80;Bd]0`0[:b/202PX:080:BTY0P0e=CD204Q8B080S8b<0P2RXZ8207em
O@80Lg=c0P1_Kfl2075aL@80Ogmo102e]KD20;6a/@80^k^k0P31`L440<;2`P80bLW90P3@d=020=SH
f080]KFe0P1?Cdl2030`<080:2PX0P0Y:BT203De=@80A4A40P1?Cdl205UIF@80HF5Q0`1WIfL206m_
K`80MWIf101hN7P207YjNP80OGem0P1nOWh20820P080PH610P23Ph<208J6QP80RHV90P2;Rh/208f=
S@80T92@0P2CTi<409FEU@80UYJF0P2HV9P209^KV`80WYjN0P2QXJ420::RXP80YJFU0P2WYjL20:ZZ
ZP@0[:b/0P2[Zj/20:f][@<0/;2`0P2c/k<20;Bd]080/K6a0P2^[Zh20:f][@80[Zj^0P2a/K440;>c
/`80/[:b202a/K420;2`/080[jn_0P2`/;020;6a/@80/;2`0P2_[jl20:b/[080ZJVY0P2WYjL20:FU
Y@80XJ6Q0P2MWId209ZJVP80UiNG0P2EUID409>CT`<0UIFE0P2CTi<2096AT@80Shn?0P2=SHd208Z:
RP80QhN70P25QHD608B4Q080Ph>30P22PX860861PBT0b>3H0P0n?Sh203De=@80;bl_0P0];Bd602h^
;P80;bl_0P0];Bd202h^;P80<30`0P0^;Rh202d];@80;Rh^0P0_;bl2034a<@<0<30`0P0[:b/202`/
;080=SHf0P1CDe<208V9R@80ZZZZ0P20P80207=cL`80LW9b0P1dM7@207emO@@0]KFe0P2c/k<20;bl
_080`<301033`l<20<K6aP@0clo?0P2m_Kd205QHF080:BTY0P0T92@202h^;P80=3@d0P14A4@204e=
C@80EeMG0P1OGel306UYJ@80Kfm_0P1gMgL207EeM@80MgMg0P1iNGT207alO080OGem0P1nOWh208J6
QP80PX:20P23Ph<208f=S@80RHV90P2=SHd209BDU080Ti>C0P2GUiL209RHV080UiNG0P2HV9P209ZJ
VP80WYjN0P2QXJ420::RXP80Xj>S0P2WYjL20:VYZ@80Zj^[0P2^[Zh20:f][@80Zj^[0`2^[Zh20;>c
/`80/[:b0P2d];@20;2`/080[:b/0P2ZZZX20;Bd]080/k>c0P2`/;040;6a/@80/[:b0P2a/K420;2`
/080[Jf]0P2^[Zh20;:b/P80[jn_0P2b/[820:n_[`80[Jf]0P2ZZZX20:VYZ@80YjNW0P2TY:@209^K
V`80W9bL0P2DU9@209>CT`@0U9BD0`2HV9P209FEU@80SXj>0P2BTY8208Z:RP80SHf=0P26QXH208:2
PP80R8R80P26QXH208B4Q080Ogmo0P24Q8@208>3P`80PX:20P25QHDY0<SPf080?Shn0P0h>3P202d]
;@80;Rh^0P0b<S8202`/;080=3@d0P0a<C42030`<0@0;Bd]0P0X:2P202d];@809RHV0P0^;Rh202PX
:0<0:b/[0P0];Bd202DU9@80<C4a0P1:BTX208f=S@80Xj>S0P1kNg/207EeM@80Kfm_0P1cLg<207em
O@@0/k>c0P2b/[820;^k^`80`l?30P2o_kl20<;2`P80b/[:0P3De=@20=WIf@80/K6a0P1ADE42030`
<0809bLW0P0Y:BT203Ph>080ATI60P1CDe<205EEE@80IFEU0`1QHF4206a/K080M7Ad0P1mOGd207Ad
M080Ng]k0P20P8020861P@80O7al0P1mOGd208:2PP80R8R80P25QHD208Z:RP80Rh^;0P2?Shl209FE
U@80U9BD0P2HV9P409NGU`80Vi^K0P2OWil20:6QX@80YJFU0P2TY:@20:RXZ080Zj^[0P2ZZZX20:VY
Z@80Zj^[0P2`/;030;6a/@80/;2`0P2c/k<20;Bd]080[jn_0P2[Zj/20:j^[P@0/[:b102c/k<20;6a
/@80/k>c0P2^[Zh20;:b/P80Zj^[0P2`/;040;6a/@80/[:b0P2^[Zh20:f][@80Zj^[0P2VYZH20:FU
Y@80Xj>S0P2NWYh209VIV@80UiNG0P2CTi<2096AT@80U9BD0`2CTi<209FEU@80T92@0P2ATI4208f=
S@@0R8R80P24Q8@408F5Q@80Ph>30P25QHD208:2PP80P8200P21PH4207inOQl0b>3H000M0<SPf080
ADE50P0i>CT202/[:`80;Rh^0P0d=3@203<c<`80<30`100a<C4202h^;P80;2`/0P0_;bl2038b<P80
;bl_1`0/;2`202XZ:P80:BTY0P0X:2P203<c<`80L71`0P2UYJD2092@T080Kfm_0P1[Jf/2079bLP80
KFe]0P2UYJD20<W9b@80Z:RX0P2e]KD20;bl_080`<300P32`/820<C4a080aLG50P3Bd]820<W9b@80
/K6a0P0b<S8203@d=08092@T0P0b<S820492@P80C4a<0P1DE5@205eMG@<0IFEU0P1^KVh207EeM@@0
MWIf0P1iNGT207alO080OWin0P1oOgl20820P080PH610P26QXH208Z:RP80S8b<0P2=SHd208n?S`80
TY:B0P2FUYH209RHV0@0UiNG0P2KVi/60:2PX080Y:BT0P2XZ:P20:^[Z`80[Zj^0P2/[:`20:ZZZP80
[Jf]0`2`/;020;Bd]080]KFe0P2_[jl20:VYZ@80ZZZZ0P2^[Zh20;6a/@80/k>c0P2b/[820;2`/080
/[:b0P2d];@20;6a/@H0[Zj^102_[jl40;2`/080[Zj^0P2[Zj/20:VYZ@80YjNW0P2SXj<209nOW`80
V9RH102CTi<709BDU080Ti>C0P2ATI42092@T080SHf=0P2:RXX208J6QPP0QHF50P22PX820820P080
PX:20P24Q8@208F5QBT0b>3H0P1:BTX2030`<080;Bd]0P0c<c<203De=@80=3@d0P0_;bl203Xj>P@0
;Bd]0P0/;2`4030`<080;Bd]0P0[:b/2030`<0L0:BTY0P0V9RH2034a<@80Kfm_0P2NWYh209BDU080
L71`0P1VIVH206m_K`80MWIf0P2VYZH20<30`080Zj^[0P2d];@20;fm_@80_;bl0P34a<@20<;2`P80
bLW90P3@d=020<c<c080Z:RX0P0m?Cd202XZ:P80:2PX0P0f=SH20451@@80Bd];0P1DE5@205YJFP<0
IVIV0P1aLG4207EeM@80M7Ad0P1eMGD207YjNP80OGem0P1nOWh20820P080OWin0P21PH4208J6QP80
RXZ:0P2<S8`208f=S@80TY:B0P2@T90209BDU0@0V9RH0P2EUID409jNWP80XZ:R0P2OWil20:BTY080
YjNW0P2^[Zh20:b/[080[Jf]0P2YZJT20:f][@<0[jn_0P2f][H20;Fe]@80[Zj^0P2XZ:P20:ZZZP80
Zj^[102b/[820;6a/@80[jn_0P2f][H20;>c/`80/K6a102`/;020:f][@80[Zj^0P2_[jl20;6a/@@0
/;2`0P2YZJT20:ZZZP80Y:BT0P2SXj<209nOW`80VYZJ0P2CTi<2096AT@@0UIFE0`2DU9@2096AT@80
Ti>C0P2@T90408b<S0H0QHF50P26QXH208N7Q`80OGem0P21PH4208>3P`80PX:20P25QHDY0<SPf080
A4A40P0k>c/202TY:@80;bl_0P0e=CD202d];@80<30`0P0c<c<2030`<080;2`/0P0^;Rh2034a<@80
=3@d0P0/;2`2034a<@80:BTY0`0];Bd202XZ:P80:b/[0P0R8R8203@d=080L71`0P2SXj<208n?S`80
Kfm_0P1ZJVX207EeM@80JFUY0P2UYJD20<c<c080YJFU0P2h^;P40;^k^`@0aLG50P32`/820=CDe080
bl_;0P2`/;0403@d=08092@T0P0`<3020410@080BTY:0P1CDe<506=SH`80KVi^0P1dM7@807QhN080
OWin0P22PX8207inOP80P8200P2:RXX208J6QP80S8b<0P2ATI42092@T0@0U9BD0P2JVYX209FEU@80
UYJF0P2KVi/20:2PX080WinO0P2PX:020:FUY@80YjNW0P2][Jd20;2`/080ZJVY0P2ZZZX20:f][@<0
[jn_0P2b/[820;Ng]`80/;2`0P2ZZZX20:NWY`80[Jf]0P2f][H20;>c/`80/;2`0P2_[jl20;Fe]@80
];Bd0P2^[Zh20;6a/@80[Jf]0P2_[jl20;:b/P80[jn_0P2][Jd20;2`/080[Zj^0P2ZZZX20:RXZ080
YZJV0P2TY:@20:2PX080V9RH0P2DU9@2092@T080UIFE0P2CTi<309FEU@@0TY:B102?Shl208V9R@80
QHF50P28R8P208:2PP@0QHF50P22PX8207moO`80PX:20P25QHD208J6QQl0b>3H000M0<SPf080ADE5
0P0i>CT202/[:`80;Rh^0P0d=3@203<c<`80<30`100a<C4202h^;P80;2`/0P0_;bl2038b<P80;bl_
1`0/;2`202XZ:P80:BTY0P0X:2P203<c<`80L71`0P2UYJD2092@T080Kfm_0P1[Jf/2079bLP80KFe]
0P2UYJD20<W9b@80Z:RX0P2e]KD20;bl_080`<300P32`/820<C4a080aLG50P3Bd]820<W9b@80/K6a
0P0b<S8203@d=08092@T0P0b<S820492@P80C4a<0P1DE5@205eMG@<0IFEU0P1^KVh207EeM@@0MWIf
0P1iNGT207alO080OWin0P1oOgl20820P080PH610P26QXH208Z:RP80S8b<0P2=SHd208n?S`80TY:B
0P2FUYH209RHV0@0UiNG0P2KVi/60:2PX080Y:BT0P2XZ:P20:^[Z`80[Zj^0P2/[:`20:ZZZP80[Jf]
0`2`/;020;Bd]080]KFe0P2_[jl20:VYZ@80ZZZZ0P2^[Zh20;6a/@80/k>c0P2b/[820;2`/080/[:b
0P2d];@20;6a/@H0[Zj^102_[jl40;2`/080[Zj^0P2[Zj/20:VYZ@80YjNW0P2SXj<209nOW`80V9RH
102CTi<709BDU080Ti>C0P2ATI42092@T080SHf=0P2:RXX208J6QPP0QHF50P22PX820820P080PX:2
0P24Q8@208F5QBT0b>3H0P1:BTX2030`<080;Bd]0P0c<c<203De=@80=3@d0P0_;bl203Xj>P@0;Bd]
0P0/;2`4030`<080;Bd]0P0[:b/2030`<0L0:BTY0P0V9RH2034a<@80Kfm_0P2NWYh209BDU080L71`
0P1VIVH206m_K`80MWIf0P2VYZH20<30`080Zj^[0P2d];@20;fm_@80_;bl0P34a<@20<;2`P80bLW9
0P3@d=020<c<c080Z:RX0P0m?Cd202XZ:P80:2PX0P0f=SH20451@@80Bd];0P1DE5@205YJFP<0IVIV
0P1aLG4207EeM@80M7Ad0P1eMGD207YjNP80OGem0P1nOWh20820P080OWin0P21PH4208J6QP80RXZ:
0P2<S8`208f=S@80TY:B0P2@T90209BDU0@0V9RH0P2EUID409jNWP80XZ:R0P2OWil20:BTY080YjNW
0P2^[Zh20:b/[080[Jf]0P2YZJT20:f][@<0[jn_0P2f][H20;Fe]@80[Zj^0P2XZ:P20:ZZZP80Zj^[
102b/[820;6a/@80[jn_0P2f][H20;>c/`80/K6a102`/;020:f][@80[Zj^0P2_[jl20;6a/@@0/;2`
0P2YZJT20:ZZZP80Y:BT0P2SXj<209nOW`80VYZJ0P2CTi<2096AT@@0UIFE0`2DU9@2096AT@80Ti>C
0P2@T90408b<S0H0QHF50P26QXH208N7Q`80OGem0P21PH4208>3P`80PX:20P25QHDY0<SPf080A4A4
0P0k>c/202TY:@80;bl_0P0e=CD202d];@80<30`0P0c<c<2030`<080;2`/0P0^;Rh2034a<@80=3@d
0P0/;2`2034a<@80:BTY0`0];Bd202XZ:P80:b/[0P0R8R8203@d=080L71`0P2SXj<208n?S`80Kfm_
0P1ZJVX207EeM@80JFUY0P2UYJD20<c<c080YJFU0P2h^;P40;^k^`@0aLG50P32`/820=CDe080bl_;
0P2`/;0403@d=08092@T0P0`<3020410@080BTY:0P1CDe<506=SH`80KVi^0P1dM7@807QhN080OWin
0P22PX8207inOP80P8200P2:RXX208J6QP80S8b<0P2ATI42092@T0@0U9BD0P2JVYX209FEU@80UYJF
0P2KVi/20:2PX080WinO0P2PX:020:FUY@80YjNW0P2][Jd20;2`/080ZJVY0P2ZZZX20:f][@<0[jn_
0P2b/[820;Ng]`80/;2`0P2ZZZX20:NWY`80[Jf]0P2f][H20;>c/`80/;2`0P2_[jl20;Fe]@80];Bd
0P2^[Zh20;6a/@80[Jf]0P2_[jl20;:b/P80[jn_0P2][Jd20;2`/080[Zj^0P2ZZZX20:RXZ080YZJV
0P2TY:@20:2PX080V9RH0P2DU9@2092@T080UIFE0P2CTi<309FEU@@0TY:B102?Shl208V9R@80QHF5
0P28R8P208:2PP@0QHF50P22PX8207moO`80PX:20P25QHD208J6QQl0b>3H000M0<SPf080@D510P0d
=3@202DU9@80:b/[0P0d=3@203<c<`80<C4a0P0_;bl202d];@@0;2`/0P0^;Rh2030`<080;Rh^0P0/
;2`502d];@80:RXZ0P0X:2P202HV9P80<C4a0P1@D50209:BTP80Xj>S0P23Ph<206=SH`80Jf][0P1X
J6P208n?S`80]kNg0P2h^;P20:VYZ@80^k^k0P2m_Kd20<71`@@0`<300P3<c<`20<o?c`80b/[:0P2=
SHd2038b<P80<C4a0P0d=3@20410@080AdM70P1@D50205YJFP<0IFEU0P1]KFd207=cL`@0M7Ad0P1g
MgL207]kN`80OWin1P21PH4208F5Q@80RHV90P2;Rh/208j>SP80T92@0P2BTY8209JFUP80VYZJ102I
VIT209bLW080X:2P0P2QXJ420::RXP80YJFU0P2XZ:P20:ZZZP80[:b/0P2[Zj/20:ZZZP80[:b/0`2_
[jl20;6a/@80/[:b0P2^[Zh20:ZZZP80[Zj^0P2b/[820;>c/`80/[:b0P2`/;040:n_[`80/;2`0P2/
[:`20:VYZ@80Zj^[0P2][Jd20:n_[`H0/K6a0P2_[jl20:b/[080Z:RX0P2TY:@20:2PX080W9bL0P2H
V9P209FEU@80Ti>C0P2BTY82096AT@<0T92@0P2ATI4209:BTP80T92@0P2=SHd208V9R@80QXJ60P24
Q8@208>3P`@0Q8B40P21PH4207emO@80Ogmo1022PX8Y0<SPf080De=C0P0_;bl202LW9`80;Rh^0P0b
<S8203Hf=P80;Bd]0P0/;2`2034a<@80<30`0P0[:b/2030`<080=CDe0P0`<30202/[:`80:RXZ0`0/
;2`202TY:@809bLW0P0X:2P202d];@80E5AD0P2CTi<20::RXP80OGem0P1VIVH206MWI`80L71`0P28
R8P20;^k^`80];Bd0P2^[Zh20;Vi^@80_;bl0P32`/820;no_`80`/;20P3;bl/20<k>cP80b<S80P2@
T90203@d=080<30`0P0c<c<203lo?`80C4a<0P1CDe<505mOG`80Kfm_0P1bLW8207EeM@80NGUi0P1h
N7P207YjNP80Ng]k0P23Ph<207moO`80Ph>30P24Q8@208R8R080RXZ:0P2;Rh/2092@T080TY:B0P2G
UiL209VIV@80UIFE0P2JVYX209fMW@@0X:2P0P2RXZ820:NWY`@0Z:RX0P2^[Zh40:NWY`80/K6a0`2/
[:`20;Bd]080/;2`0P2][Jd20:RXZ080/K6a102f][H40;6a/@80/;2`0P2_[jl20:b/[080Zj^[0P2U
YJD20:VYZ@80[Zj^0P2b/[820:j^[P80/[:b0P2[Zj/20:j^[P80ZZZZ0P2XZ:P20:>SX`80X:2P0P2J
VYX209RHV0@0UYJF0P2@T90508j>SP80T92@0P2ATI4208n?S`80S8b<0P2;Rh/208J6QP80PH610P1n
OWh408N7Q`80O7al0P1oOgl40820P080Q8B4:@38h=P203lo?`80<S8b0P0T92@202d];@80>SXj100a
<C4202h^;P80;2`/0P0];Bd202h^;P80;Bd]0P0c<c<2038b<P80:BTY0P0`<30302/[:`80;bl_0P0Z
:RX202HV9P80<c<c0P1CDe<209>CT`80YjNW0P22PX82069RHP80K6a/0P1XJ6P209>CT`80^k^k0P2h
^;P20:NWY`80_[jn0P2l_;`20<71`@80`<300P2o_kl20<_;b`80clo?0P37alL208^;R`80=3@d100b
<S820451@@80BDU90P1;Bd/205aLG0<0IFEU0P1]KFd207AdM080LW9b0P1eMGD207=cL`80PH610P1m
OGd208>3P`80OWin0P21PH4208V9R@@0SHf=0P2;Rh/208V9R@80U9BD0P2GUiL409VIV@80VYZJ0P2Q
XJ420:2PX080WinO0P2PX:020:NWY`@0Z:RX0P2[Zj/20:j^[P80Zj^[0P2/[:`30:n_[`80/k>c0P2`
/;020:n_[`80ZJVY0P2][Jd20;:b/P80];Bd0P2a/K420;2`/080[jn_0P2`/;020:n_[`80ZZZZ0P2[
Zj/20:RXZ080[:b/0P2`/;020:n_[`80/;2`0P2a/K420;:b/P80Zj^[0P2XZ:P20:BTY080WinO0P2K
Vi/209NGU`80UIFE0P2FUYH209BDU080TI6A1@2@T90209:BTP80T92@0P2<S8`208N7Q`80QHF50P27
QhL608>3P`80Q8B40P1lO7`207emO@80PX:20P25QHDO0<SPf0007@38h=P20451@@80=3@d0P0U9BD2
02/[:`80=3@d0P0c<c<2034a<@80;bl_0P0];Bd402`/;080;Rh^0P0`<30202h^;P80;2`/1@0];Bd2
02XZ:P80:2PX0P0V9RH2034a<@80D51@0P2BTY820:>SX`80Ph>30P1SHf<206][J`80J6QX0P2?Shl2
0;Ng]`80^;Rh0P2YZJT20;^k^`80_Kfm0P31`L440<30`080c<c<0P3?cll20<[:bP80SHf=0P0b<S82
034a<@80=3@d0P10@40204M7A`80D51@0P1JFUX306EUI@80KFe]0P1cLg<407AdM080MgMg0P1kNg/2
07inOPH0PH610P25QHD208V9R@80Rh^;0P2>SXh2092@T080TY:B0P2FUYH209ZJVP@0VIVI0P2LW9`2
0:2PX080XJ6Q0P2RXZ820:FUY@80Z:RX0P2ZZZX20:b/[080Zj^[0P2ZZZX20:b/[0<0[jn_0P2a/K42
0;:b/P80[Zj^0P2ZZZX20:j^[P80/[:b0P2c/k<20;:b/P80/;2`102_[jl20;2`/080[:b/0P2YZJT2
0:^[Z`80[Jf]0P2_[jl60;6a/@80[jn_0P2/[:`20:RXZ080Y:BT0P2PX:0209bLW080V9RH0P2EUID2
09>CT`80TY:B0P2ATI43092@T080TI6A0P2BTY82092@T080SHf=0P29RHT208J6QP80Q8B40P23Ph<4
08B4Q080PH610P1mOGd207moO`@0PX:2:@38h=P205=CD`80;bl_0P0W9bL202h^;P80<S8b0P0f=SH2
02d];@80;2`/0P0a<C42030`<080:b/[0P0`<30203De=@80<30`0P0[:b/202XZ:P<0;2`/0P0Y:BT2
02LW9`80:2PX0P0];Bd205ADE080Ti>C0P2RXZ8207emO@80IVIV0P1WIfL2071`L080R8R80P2k^k/2
0;Bd]080[Zj^0P2i^KT20;bl_080`/;20P2o_kl20<;2`P80bl_;0P3>c/h20<S8b080T92@0P0d=3@2
030`<080<c<c0P0o?cl204a<C080De=C1@1OGel206m_K`80LW9b0P1eMGD207UiN@80N7Qh0P1jNWX2
07]kN`80Ph>30P1oOgl208>3P`80Q8B40P28R8P208Z:RP80Rh^;0P2@T90209:BTP80UiNG0P2IVIT2
09FEU@80VYZJ0P2MWId40:2PX080XZ:R0P2WYjL40:RXZ080[Zj^102WYjL20;6a/@<0[:b/0P2d];@2
0;2`/080[Jf]0P2XZ:P20;6a/@@0][Jf102a/K420;2`/080[jn_0P2/[:`20:^[Z`80YJFU0P2YZJT2
0:j^[P80/[:b0P2^[Zh20;:b/P80Zj^[0P2^[Zh20:ZZZP80Z:RX0P2SXj<20:2PX080VYZJ0P2HV9P4
09JFUP80T92@1@2>SXh2092@T080TI6A0P2?Shl208b<S080Rh^;0P26QXH20861P@80OWin1027QhL2
07alO080Ogmo1020P80208B4Q2T0b>3H0P0o?cl2038b<P8092@T0P0];Bd203Xj>P@0<C4a0P0^;Rh2
02`/;080;Bd]0P0^;Rh202d];@80<c<c0P0b<S8202TY:@80<30`0`0[:b/202l_;`80:RXZ0P0V9RH2
03<c<`80De=C0P2CTi<20:NWY`80PX:20P1RHV8206a/K080J6QX0P2CTi<20;^k^`80^;Rh0P2WYjL2
0;jn_P80_;bl0P31`L420<30`080_kno0P3;bl/20<o?c`80alO70P2;Rh/203@d=0@0<S8b0P11@D42
04U9B@80Bd];0P1LG5`306EUI@80KFe]0P1dM7@2079bLP80MGEe0P1cLg<20861P@80OGem0P23Ph<2
07inOP80PH610P29RHT408f=S@80Rh^;0P29RHT209BDU080UiNG102IVIT209ZJVP80XJ6Q0P2PX:02
09nOW`80X:2P0P2WYjL40:RXZ080Zj^[0P2^[Zh20:^[Z`80[:b/0`2_[jl20;>c/`80/;2`0P2_[jl2
0:VYZ@80[Jf]0P2b/[820;Bd]080/K6a0P2`/;020:n_[`80/;2`0P2_[jl20:ZZZP80Zj^[0P2XZ:P2
0:b/[080/;2`0P2_[jl20;2`/080/K6a0P2b/[820:^[Z`80Z:RX0P2TY:@209nOW`80Vi^K0P2GUiL2
09FEU@80UYJF0P2DU9@2096AT@D0T92@0P2BTY82092@T080S8b<0P27QhL208F5Q@80QhN71P23Ph<2
08B4Q080O7al0P1mOGd208:2PP80QHF57`38h=P001d0b>3H0P0k>c/202h^;P808B4Q0P0Y:BT403<c
<`80<30`0P0/;2`202TY:@80:RXZ0P0/;2`802d];@D0;Rh^0P0[:b/202TY:@80:2PX0P0c<c<203@d
=080MWIf0P2ZZZX209RHV080HF5Q0P1WIfL206UYJ@80NGUi0P2NWYh20<K6aP80XJ6Q0P2g]kL20;Vi
^@80_kno0P2n_[h20;fm_@80a<C40P3;bl/20<o?c`80aLG50P1hN7P4034a<@80?clo0P16ATH204i>
CP80FEUI0`1TI6@206a/K080LG5a0P1cLg<207AdM080MgMg0P1jNWX207inOP@0PX:20P21PH4208B4
Q080R8R80P2;Rh/208j>SP80T92@0P2CTi<209NGU`H0Vi^K0P2MWId209nOW`80XJ6Q0P2SXj<20:JV
YP80Z:RX102YZJT20:ZZZP80Zj^[0P2/[:`30:f][@@0[Zj^102][Jd20;6a/@80]KFe0P2c/k<20:n_
[`80[Zj^0P2][Jd20:b/[080Zj^[0P2XZ:P20:JVYP80Z:RX0P2/[:`20:n_[`@0/K6a0P2`/;020:n_
[`80[Jf]0P2WYjL20:6QX@80WIfM0P2IVIT209RHV080UiNG0P2CTi<208n?S`80S8b<0`2;Rh/208n?
S`80Ti>C0P2@T90208b<S080R8R80P25QHD208>3P`80PH610P22PX8208>3P`80P8200P1lO7`207em
O@@0Ogmo:@38h=P20492@P809bLW0P0U9BD202PX:080=3@d0P0c<c<203@d=080:BTY0P0V9RH202l_
;`80:b/[0P0Z:RX202TY:@80;bl_100];Bd302h^;P80:b/[0P0Y:BT202PX:080;Bd]0P12@T8207Mg
M`80W9bL0P2HV9P206i^KP80HF5Q0P1ZJVX207IfMP80Y:BT0P2n_[h20:NWY`80/K6a0P2l_;`20;no
_`80^k^k0P2m_Kd20<K6aP80c<c<0P3=cLd20<71`@80NWYj0P0f=SH203@d=080?Cdm0P17AdL204];
B`80EUIF0`1WIfL206e]K@80LW9b0P1`L70207EeM@80N7Qh0P1lO7`207]kN`80Ph>30P21PH420820
P080Q8B40P27QhL208b<S080T92@0P2?Shl209BDU080V9RH0P2LW9`209JFUP80Vi^K0P2MWId209nO
W`80X:2P0P2UYJD20:BTY0@0Z:RX0P2/[:`20:NWY`@0[Jf]0`2/[:`20;2`/080[Jf]0P2^[Zh20:f]
[@80/;2`102b/[820:f][@80[jn_0P2/[:`20:ZZZP80[:b/0P2][Jd20:RXZ080Y:BT0P2][Jd40;6a
/@80/[:b0P2^[Zh20;:b/P80[:b/0P2WYjL20::RXP@0Vi^K0P2HV9P209FEU@80Ti>C0P2@T90208Z:
RP<0SXj>0P2=SHd209BDU080Shn?0P2;Rh/208R8R080Q8B40P27QhL20861P@80PX:20P27QhL207al
O080P8200P1jNWX207moO`80Ph>3:@38h=P203dm?@80;bl_0P0P820202/[:`80<30`0P0e=CD2030`
<0@0:RXZ0P0X:2P202`/;080<30`0P0[:b/402`/;080<30`1@0[:b/202TY:@8092@T0P0b<S8203@d
=080LW9b0P2^[Zh209NGU`80HF5Q0P1WIfL206QXJ080NGUi0P2MWId20<G5a@80XZ:R0P2g]kL20;Rh
^080`<301P2o_kl20=3@d080cLg=0P39bLT207UiN@80<S8b0P0/;2`203lo?`80BDU90P1?Cdl205MG
E`<0Hf=S0P1]KFd2079bLP80L71`0P1jNWX207EeM@80OGem0P1nOWh208>3P`80OWin0P24Q8@207in
OP80QXJ60P2?Shl2096AT@80RXZ:0P2EUID209ZJVP80Vi^K0P2JVYX209VIV@80WIfM0P2NWYh20:2P
X080Xj>S0P2XZ:P20:VYZ@80YZJV0P2ZZZX20:b/[080Zj^[0P2ZZZX50:j^[P80/K6a0P2][Jd20:j^
[P80/;2`0P2e]KD20;:b/P80[jn_0P2a/K420:b/[080[Jf]0P2/[:`20:NWY`80YZJV0P2YZJT40:j^
[P80/[:b0P2_[jl40;2`/080Zj^[0P2XZ:P209nOW`80X:2P0P2JVYX209NGU`80UYJF0P2CTi<708f=
S@80RXZ:0P2FUYH2096AT@80SHf=0P27QhL208J6QP@0PH610P23Ph<20861P@80Ph>30P1mOGd207Yj
NP80PH610P1oOglO0<SPf0007@38h=P203/k>`80;Rh^0P0Q8B4202TY:@@0<c<c0P0`<30202`/;080
:BTY0P0Z:RX202`/;0P0;Bd]1@0^;Rh202/[:`80:BTY0P0X:2P203<c<`80=3@d0P1fMWH20:ZZZP80
V9RH0P1QHF4206MWI`80JFUY0P1iNGT209jNWP80a/K60P2QXJ420;Ng]`80^KVi0P2o_kl20;jn_P80
_Kfm0P34a<@20<_;b`80clo?0P35aLD207QhN0@0<C4a0P0o?cl204I6AP80CTi>0P1IFET306ATI080
K6a/0P1aLG4207=cL`80M7Ad0P1gMgL207YjNP80OWin1022PX820861P@80Q8B40P28R8P208^;R`80
SXj>0P2@T90209>CT`80UiNG1P2KVi/209fMW@80WinO0P2QXJ420:>SX`80YZJV0P2XZ:P40:VYZ@80
ZZZZ0P2[Zj/20:b/[0<0[Jf]102^[Zh40:f][@80/K6a0P2e]KD20;>c/`80[jn_0P2^[Zh20:f][@80
[:b/0P2[Zj/20:RXZ080YZJV0P2XZ:P20:b/[080[jn_102a/K420;2`/080[jn_0P2][Jd20:NWY`80
XJ6Q0P2MWId209VIV@80V9RH0P2GUiL209>CT`80Shn?0P2<S8`308^;R`80Shn?0P2CTi<2092@T080
S8b<0P28R8P208F5Q@80Ph>30P21PH4208:2PP80Ph>30P20P80207alO080OGem101oOglY0<SPf080
@T920P0W9bL202DU9@80:2PX0P0d=3@203<c<`80=3@d0P0Y:BT202HV9P80;bl_0P0[:b/202XZ:P80
:BTY0P0_;bl402d];@<0;Rh^0P0[:b/202TY:@80:2PX0P0];Bd20492@P80MgMg0P2LW9`209RHV080
KVi^0P1QHF4206YZJP80MWIf0P2TY:@20;jn_P80YjNW0P2a/K420;bl_080_kno0P2k^k/20;fm_@80
a/K60P3<c<`20<g=c@80`L710P1jNWX203Hf=P80=3@d0P0m?Cd204M7A`80Bd];0P1FEUH306MWI`80
KFe]0P1bLW82071`L080MGEe0P1hN7P207alO080Ng]k0P23Ph<20861P@80P8200P24Q8@208N7Q`80
S8b<0P2@T90208n?S`80U9BD0P2HV9P209bLW080UYJF0P2KVi/209fMW@80WinO0P2PX:020:FUY@80
Y:BT102XZ:P20:b/[080YjNW102][Jd30:b/[080/;2`0P2][Jd20:j^[P80[Jf]0P2`/;040;:b/P80
[Jf]0P2_[jl20:b/[080ZZZZ0P2/[:`20:f][@80Z:RX0P2TY:@20:f][@@0/K6a0P2b/[820:j^[P80
/[:b0P2/[:`20:NWY`80XZ:R102KVi/209RHV080UIFE0P2CTi<2092@T080RXZ:0`2>SXh208f=S@80
U9BD0P2?Shl208^;R`80R8R80P24Q8@208N7Q`80PH610P22PX8208N7Q`80O7al0P20P80207YjNP80
Ogmo0P23Ph<Y0<SPf080?Cdm0P0_;bl2020P8080:b/[0P0`<30203De=@80<30`100Z:RX202PX:080
;2`/0P0`<30202/[:`@0;2`/0P0`<30502/[:`80:BTY0P0T92@2038b<P80=3@d0P1bLW820:j^[P80
UiNG0P1QHF4206MWI`80J6QX0P1iNGT209fMW@80aLG50P2RXZ820;Ng]`80^;Rh0P30`<060;no_`80
d=3@0P3=cLd20<W9b@80NGUi0P0b<S8202`/;080?clo0P19BDT204m?C`80EeMG0`1SHf<206e]K@80
LW9b0P1`L70207YjNP80MGEe0P1mOGd207inOP80Ph>30P1nOWh208B4Q080OWin0P26QXH208n?S`80
TI6A0P2:RXX209FEU@80VYZJ0P2KVi/209ZJVP80VIVI0P2MWId209jNWP80X:2P0P2SXj<20:RXZ080
ZJVY0P2VYZH20:ZZZP80[:b/0P2[Zj/20:ZZZPD0[Zj^0P2a/K420:f][@80[Zj^0P2`/;020;Fe]@80
/[:b0P2_[jl20;6a/@80[:b/0P2][Jd20:b/[080YjNW0P2VYZH20:VYZ@@0[Zj^0P2b/[820:n_[`@0
/;2`0P2[Zj/20:RXZ080WinO0P2PX:0209ZJVP80UiNG0P2FUYH209>CT`L0SHf=0P2:RXX209JFUP80
TI6A0P2=SHd208N7Q`80QXJ61021PH4208>3P`80PH610P23Ph<207emO@80NWYj0P21PH4207moOal0
b>3H000M0<SPf080=CDe0P0_;bl202TY:@80;bl_0P0f=SH2038b<P80;Rh^0P0];Bd202`/;0@0:RXZ
0P0/;2`202h^;PH0<30`0`0_;bl402h^;P80:RXZ0P0];Bd202`/;080De=C0P2ATI420:2PX080N7Qh
0P1/K6`206YZJP80KFe]0P2BTY820;Zj^P80]KFe0P2YZJT20;>c/`80_[jn0P2o_kl20;jn_P80`l?3
0P37alL20<S8b080_kno0P39bLT2065QH@80<C4a0P0h>3P20492@P80D51@0P1HF5P3061PH080J6QX
0P1_Kfl2079bLP80M7Ad0P1hN7P207]kN`80OWin0P20P8020861P@80PX:20P26QXH208^;R`80S8b<
0P2=SHd2092@T080U9BD0P2GUiL209VIV@80Vi^K0P2LW9`209fMW@80WYjN0P2QXJ420:FUY@80YjNW
0P2XZ:P20:JVYP80YJFU0P2WYjL20:ZZZP80[:b/0`2^[Zh40:n_[`80[Jf]0P2[Zj/20:b/[080[Jf]
0P2/[:`60:^[Z`80[:b/0P2][Jd20:^[Z`80ZZZZ102YZJT20:ZZZP80[:b/102][Jd20:b/[080Zj^[
0P2WYjL20::RXP80WYjN0P2KVi/209VIV@80UiNG0P2ATI4208b<S080RXZ:0`2;Rh/208n?S`80TI6A
0P2=SHd208R8R080QXJ60P25QHD208>3P`H0PX:20P21PH4207moO`H0P820:@38h=P202l_;`80;2`/
100];Bd203Hf=P80<c<c100^;Rh202`/;080;Bd]0P0X:2P2030`<080<C4a0P0/;2`203@d=080<C4a
0`0g=cL202`/;080:b/[0P0b<S8202`/;080:BTY0P1BDU8208^;R`80YJFU0P1nOWh206UYJ@80IfMW
0P1`L70208b<S080`<300P2b/[820:^[Z`80]KFe0P2l_;`20;jn_P80_Kfm0P32`/820<K6aP@0bLW9
0P2k^k/205UIF@80=SHf0P0g=cL204E5A@80DE5A0P1BDU83065QH@80Jf][0P1`L702075aL@80Kfm_
0P1iNGT207inOP80NWYj0P24Q8@408:2PP80RXZ:102;Rh/408f=S@80TY:B0P2GUiL209fMW@80VYZJ
0P2QXJ4209^KV`@0WinO0P2RXZ840:VYZ@80Y:BT102UYJD20:ZZZP80[Jf]0`2YZJT20;6a/@@0[Jf]
0P2/[:`20:^[Z`80[Jf]0P2[Zj/20:b/[080[Jf]0P2[Zj/20:ZZZP80[:b/0P2][Jd20:RXZ080ZJVY
0P2XZ:P40:VYZ@@0/;2`0P2][Jd20:RXZ080[:b/0P2PX:0209bLW0@0VYZJ0P2EUID209BDU080SHf=
0P28R8P508j>SP80UYJF0P29RHT208^;R`80RHV90P20P80208>3P`80PX:21021PH4207YjNP80QXJ6
0P1jNWX207inOP80QhN7:@38h=P203@d=080;Bd]0P0W9bL4038b<P80;Rh^0P0c<c<202d];@80;bl_
0P0[:b/202LW9`80<30`0P0Y:BT2038b<P80;Rh^1@0c<c<202h^;P80;Bd]0P0Y:BT2030`<080;Bd]
0P1BDU82096AT@80WYjN0P1eMGD206m_K`80J6QX0P1YJFT209:BTP80^KVi0P2e]KD20:NWY`80]KFe
0P2o_kl20;bl_080`<300P33`l<20<S8b080a/K60P2l_;`20<c<c080H61P0P0a<C4203Xj>P80@T92
0P1?Cdl205QHF0<0GemO0P1]KFd206i^KP80L71`0P1eMGD2075aL@80N7Qh0P1lO7`408>3P`80Q8B4
0P23Ph<208V9R@80Shn?0P2<S8`2096AT@80UIFE102GUiL409bLW0@0WIfM0P2SXj<20:NWY`80YJFU
0P2YZJT20:NWY`80YZJV0P2TY:@40:ZZZP<0[jn_102][Jd60:b/[080[jn_0P2][Jd20:ZZZP80ZJVY
0P2ZZZX20:b/[080[Jf]0P2[Zj/20:b/[080Z:RX0P2YZJT40:f][@80/;2`0P2][Jd40:^[Z`80Z:RX
0P2QXJ4209nOW`@0V9RH0P2FUYH209FEU@80Rh^;0P28R8P508f=S@80TI6A0P2=SHd408N7Q`80Q8B4
1P21PH4408:2PP80PH610P1nOWh20820P080Ogmo7`38h=P001d0b>3H0P0e=CD202l_;`80:BTY0P0_
;bl203Hf=P80<S8b0P0^;Rh202d];@80;2`/100Z:RX202`/;080;Rh^1P0`<30302l_;`@0;Rh^0P0Z
:RX202d];@80;2`/0P1CDe<2096AT@80X:2P0P1hN7P206a/K080JVYZ0P1]KFd209:BTP80^[Zj0P2e
]KD20:VYZ@80/k>c0P2n_[h20;no_`80_[jn0P33`l<20<O7a`80b<S80P2o_kl20<W9b@80HF5Q0P0a
<C4203Ph>080@T920P1@D50205QHF0<0H61P0P1XJ6P206m_K`80LW9b0P1dM7@207QhN080Ng]k0P1n
OWh20820P080PH610P22PX8208J6QP80Rh^;0P2<S8`208f=S@80T92@0P2DU9@209NGU`80VIVI0P2K
Vi/209bLW080WIfM0P2NWYh20:6QX@80YJFU0P2WYjL20:RXZ080YZJV0P2UYJD20:NWY`80ZZZZ0P2/
[:`30:j^[P@0[jn_0P2][Jd20:^[Z`80[:b/0P2][Jd20:b/[0H0Zj^[0P2/[:`20:f][@80Zj^[0P2Z
ZZX40:VYZ@80ZZZZ0P2/[:`40:f][@80[:b/0P2[Zj/20:NWY`80XZ:R0P2NWYh209^KV`80VIVI0P2G
UiL2096AT@80S8b<0P2:RXX308^;R`80Shn?0P2ATI4208f=S@80R8R80P26QXH208F5Q@80Ph>31P22
PX820861P@80Ogmo1P20P80Y0<SPf080;bl_0P0/;2`402d];@80=SHf0P0c<c<402h^;P80;2`/0P0]
;Bd202PX:080<30`0P0a<C4202`/;080=3@d0P0a<C4303Lg=`80;2`/0P0[:b/2038b<P80;2`/0P0Y
:BT2059BDP80Rh^;0P2UYJD207inOP80JFUY0P1WIfL2071`L080S8b<0P30`<020;:b/P80Zj^[0P2e
]KD20;bl_080_[jn0P2m_Kd20<;2`P80a/K61039bLT20;^k^`80FEUI0P0f=SH203Lg=`80ADE50P1A
DE42059BDP<0HF5Q0P1[Jf/2071`L080LG5a0P1_Kfl207UiN@80OWin0P1jNWX208B4Q0@0PX:20P2:
RXX408^;R`@0SHf=0P2BTY8209NGU`80WIfM0P2JVYX20:6QX@80Vi^K102OWil20::RXP@0ZJVY0P2T
Y:@40:FUY@80ZZZZ0P2][Jd30:VYZ@80/K6a102][Jd20:b/[080Zj^[0P2][Jd20:^[Z`80[:b/0P2]
[Jd20:^[Z`80ZZZZ0P2/[:`20:f][@80Z:RX0P2YZJT20:RXZ0@0ZJVY102`/;020:f][@80Z:RX0P2/
[:`20:2PX080W9bL102JVYX209FEU@80U9BD0P2=SHd208R8R0D0SXj>0P2FUYH208V9R@80Rh^;0P29
RHT20820P080Ph>30P22PX840861P@80NWYj0P26QXH207YjNP80OWin0P27QhLY0<SPf080=3@d0P0]
;Bd202LW9`@0<S8b0P0^;Rh203<c<`80;Bd]0P0_;bl202/[:`809bLW0P0`<30202TY:@80<S8b0P0^
;Rh503<c<`80;Rh^0P0];Bd202TY:@80<30`0P0];Bd2059BDP80TI6A0P2NWYh207EeM@80Kfm_0P1X
J6P206UYJ@80TY:B0P2i^KT20;Fe]@80YjNW0P2e]KD20;no_`80_;bl0P30`<020<?3``80b<S80P36
a/H20;bl_080c<c<0P1PH602034a<@80>SXj0P12@T8204m?C`80F5QH0`1OGel206e]K@80KVi^0P1`
L70207EeM@80LG5a0P1hN7P207alO0@0Ph>30P24Q8@208>3P`80RHV90P2?Shl208b<S080TI6A0P2E
UID409NGU`@0W9bL102MWId20:>SX`80YjNW0P2UYJD20:VYZ@80YjNW0P2VYZH20:BTY0@0ZZZZ0`2_
[jl40:f][@H0[:b/0P2_[jl20:f][@80ZZZZ0P2YZJT20:ZZZP80[:b/0P2][Jd20:^[Z`80[:b/0P2X
Z:P20:VYZ@@0[Jf]0P2`/;020:f][@@0Zj^[0P2XZ:P20:6QX@80WinO102HV9P209JFUP80UIFE0P2;
Rh/208R8R0D0SHf=0P2ATI4208f=S@@0QhN70P24Q8@60861P@@0PX:20P21PH4207inOP80P8200P1o
OglO0<SPf0007@38h=P6034a<@80=CDe0P0g=cL2038b<P80;2`/0P0];Bd202l_;`80:b/[0P0X:2P2
02`/;080<C4a100c<c<2038b<P<0<30`100b<S8202d];@80:BTY0P0[:b/203Hf=P80KFe]0P2NWYh2
096AT@80MgMg0P1[Jf/206IVIP80QhN70P2VYZH20<K6aP80WYjN0P2^[Zh20;bl_0@0_kno0P30`<02
0<71`@@0aLG50P3@d=020;>c/`80A4A40P0k>c/203hn?P80DE5A0P1FEUH305aLG080IFEU0P1]KFd2
075aL@80MGEe0P1hN7P207alO080OGem0P1oOgl20820P080PX:20P28R8P208j>SP80SHf=0P2<S8`2
092@T080UIFE0P2FUYH209RHV080Vi^K1P2MWId20::RXP80YZJV0P2XZ:P20:VYZ@80Y:BT0P2QXJ42
0:BTY080ZJVY0P2/[:`70:n_[`80[:b/0P2XZ:P20:JVYP80YJFU0P2VYZH20:NWY`80Z:RX0P2YZJT2
0:b/[0@0[jn_0P2^[Zh20:ZZZP@0YZJV0P2WYjL20:VYZ@@0ZZZZ0P2YZJT20:JVYP80Y:BT0P2QXJ42
09jNWP80VYZJ0P2EUID208j>SP80RHV90P2:RXX308b<S080SXj>0P2?Shl208^;R`80QXJ60P25QHD2
08B4Q0@0Ph>30P22PX820861P@80PX:20P23Ph<608:2PRT0b>3H0P0a<C4203@d=080<C4a0P0c<c<2
03Lg=`80=SHf0P0^;Rh202/[:`80<30`0P0/;2`202PX:080;bl_0P0b<S8202l_;`80=CDe0P0c<c<3
02d];@80;Rh^100a<C4402LW9`80>SXj0P1_Kfl209JFUP80Vi^K0P1dM7@206a/K080JFUY0P22PX82
0:b/[080_[jn0P2PX:020;>c/`80^;Rh0P2o_kl20<30`080_[jn0P34a<@20<?3``80alO70P3<c<`2
0;2`/080C4a<0P0i>CT204=3@`80Bd];0P1GEeL305mOG`80I6AT101`L70207IfMP80O7al0P1jNWX2
07UiN@H0Ogmo0P2<S8`408^;R`80RXZ:102CTi<209JFUP80V9RH0P2GUiL209jNWP80WIfM102OWil2
0:NWY`80ZZZZ0P2YZJT20:6QX@80Xj>S0P2RXZ820:ZZZP80[:b/0`2^[Zh20;Bd]080[:b/0P2[Zj/2
0:VYZ@80Xj>S0P2VYZH20:FUY@80Z:RX0P2VYZH20:VYZ@80[:b/102^[Zh20:f][@80[:b/102XZ:P2
0:ZZZP80YZJV0P2XZ:P20:b/[080Z:RX0P2ZZZX20:>SX`80XZ:R0P2PX:0209VIV@80U9BD0P2>SXh2
08Z:RP80R8R81`2=SHd208Z:RP80QHF50P23Ph<208N7Q`80PX:20P21PH4208>3P`80Q8B40P1oOgl2
08F5Q@80P8200P1oOgl208V9RBT0b>3H100a<C42030`<0@0>CTi0P0];Bd2030`<080;2`/100`<302
02DU9@80:RXZ0P0a<C4203Hf=P80<C4a0P0b<S83030`<080<C4a0P0c<c<202h^;P80:2PX0P0[:b/2
03Hf=P80Jf][0P2SXj<208f=S@80N7Qh0P1^KVh206ATI080S8b<0P2TY:@20<K6aP80WinO0P2b/[82
0;^k^`80_[jn0P2m_Kd20<K6aP80`<300P31`L420<O7a`80e=CD0P2a/K4204E5A@@0>SXj0P1CDe<2
05ADE0<0G5aL0P1WIfL206a/K080Lg=c0P1gMgL207QhN0@0Ogmo0P20P80207emO@80QXJ60P25QHD2
08j>SP80S8b<0P2;Rh/208f=S@80UIFE0P2GUiL209RHV080Vi^K1P2MWId209nOW`80YjNW102XZ:P2
0:NWY`80X:2P0P2TY:@20:ZZZP80[:b/0`2^[Zh20;6a/@80/;2`0P2ZZZX20:RXZ080YjNW0P2TY:@2
0:JVYP80Z:RX0P2WYjL20:ZZZP80[Jf]0P2_[jl20;6a/@80[jn_0P2YZJT20:FUY@80ZJVY0P2UYJD2
0:NWY`80ZJVY0P2[Zj/20:VYZ@80YjNW0P2UYJD209jNWP80WinO0P2KVi/409:BTP80RHV90P26QXH3
08f=S@80T92@0P2>SXh208b<S080QHF51023Ph<208J6QPH0PX:20P20P80208B4Q080PX:20P23Ph<2
08:2PQl0b>3H000M0<SPf0H0<C4a0P0e=CD203Lg=`80<S8b0P0/;2`202d];@80;bl_0P0[:b/202PX
:080;2`/0P0a<C4403<c<`80<S8b0`0`<304038b<P80;Bd]0P0Y:BT202/[:`80=SHf0P1]KFd209jN
WP80TI6A0P1gMgL206][J`80IVIV0P27QhL20:JVYP80a/K60P2NWYh20:j^[P80_;bl102o_kl20<30
`080`L711035aLD20=3@d080/k>c0P14A4@203/k>`80?Shn0P1ADE4205IFEP<0G5aL0P1UIFD206e]
K@80LG5a0P1eMGD207QhN080O7al0P1mOGd207moO`80P8200P22PX8208R8R080SXj>0P2=SHd208b<
S080T92@0P2EUID209JFUP80V9RH0P2KVi/609fMW@80XZ:R0P2VYZH20:RXZ080ZJVY0P2TY:@20:6Q
X@80Y:BT0P2YZJT20:b/[0L0[jn_0P2/[:`20:RXZ080YZJV0P2UYJD20:JVYP80YjNW0P2XZ:P20:VY
Z@80[:b/102_[jl20:j^[P80ZZZZ102VYZH20:NWY`80ZJVY102ZZZX20:VYZ@80YZJV0P2TY:@20:6Q
X@80WYjN0P2JVYX209FEU@80SXj>0P29RHT208Z:RP<0S8b<0P2>SXh208n?S`80Rh^;0P26QXH208F5
Q@80Q8B41023Ph<208:2PP80PH610P22PX8208>3P`H0PX:2:@38h=P2034a<@80=3@d0P0a<C4203<c
<`80=cLg0P0f=SH202h^;P80:b/[0P0`<30202`/;080:2PX0P0_;bl2038b<P80;bl_0P0e=CD203<c
<`<0;Bd]0P0^;Rh4034a<@@09bLW0P0j>SX206m_K`80UYJF0P2KVi/207AdM080K6a/0P1YJFT208:2
PP80[:b/0P2n_[h20:2PX080/k>c0P2h^;P20;no_`80`<300P2n_[h20<C4a080`l?30P37alL20<c<
c080/;2`0P1<C4`203Ti>@80@d=30P1;Bd/205MGE`<0GemO0P1TI6@4071`L080MWIf0P1lO7`207Yj
NP80NGUi1P1oOgl208b<S0@0Rh^;0P2:RXX409>CT`80UYJF0P2HV9P209NGU`80WYjN0P2MWId409nO
W`80YjNW0P2ZZZX20:VYZ@80XJ6Q0P2SXj<20::RXP80ZZZZ0P2/[:`30:j^[P80];Bd0P2/[:`20:^[
Z`80ZJVY0P2SXj<20:JVYP80YJFU0P2XZ:P20:JVYP80ZJVY0P2/[:`40:j^[P80[Jf]0P2/[:`40:RX
Z080ZZZZ0P2VYZH20:RXZ080[:b/0P2XZ:P20:ZZZP80Xj>S0P2RXZ820:2PX080VIVI0P2DU9@208j>
SP80RXZ:0P28R8P708f=S@80RXZ:0P25QHD208>3P`80QhN70P22PX820861P@80Ph>30P24Q8@207mo
O`80QHF50P20P80207moO`80RHV9:@38h=P4034a<@80<30`100i>CT202d];@80<30`0P0/;2`4030`
<0809BDU0P0Z:RX2034a<@80=SHf0P0a<C42038b<P<0<30`0P0a<C4203<c<`80;Rh^0P0X:2P202/[
:`80=SHf0P1[Jf/20:>SX`80SHf=0P1hN7P206i^KP80I6AT0P2<S8`20:BTY080a/K60P2OWil20;:b
/P80^k^k0P2n_[h20;fm_@80a/K60P30`<020<71`@80alO70P3De=@20;6a/@80ADE5100j>SX205=C
D`80E5AD0`1LG5`206MWI`80K6a/0P1cLg<207MgM`80N7Qh101oOgl20820P080OGem0P26QXH208F5
Q@80SXj>0P2<S8`208^;R`80SHf=0P2EUID209NGU`80V9RH0P2KVi/609fMW@80WinO0P2WYjL40:RX
Z080YjNW0P2PX:020:BTY080ZZZZ0P2/[:`30:j^[P80/K6a0P2`/;020:ZZZP80Z:RX0P2WYjL20:BT
Y080YZJV0P2XZ:P20:NWY`80ZZZZ0P2][Jd20:n_[`80/K6a0P2_[jl20:VYZ@80YJFU0P2YZJT20:FU
Y@80YjNW0P2YZJT20:^[Z`80ZJVY0P2WYjL20:FUY@80WYjN0P2OWil209^KV`@0TY:B0P29RHT208J6
QP<0SHf=0P2@T90208j>SP80S8b<0P25QHD408>3P`80QXJ61P22PX820820P080Q8B40P22PX8208>3
P`80PX:27`38h=P001d0b>3H0P0_;bl2030`<080<C4a100c<c<2030`<0@0;2`/0P0];Bd202/[:`80
:RXZ0P0^;Rh203<c<`80=3@d0P0c<c<2038b<P<0<C4a0P0b<S8203<c<`80;Rh^100Z:RX2034a<@80
BTY:0P27QhL20:2PX080R8R80P1QHF4206ATI080MWIf0P2?Shl20;6a/@80ZJVY0P2_[jl20;Jf]P80
^[Zj0P2m_Kd20;no_`80`<300P35aLD20<O7a`80e=CD0P2j^[X20:NWY`80D51@0P0b<S8204I6AP80
DE5A0`1LG5`206EUI@80K6a/0P1aLG4207AdM080MWIf0P1iNGT207alO080Ogmo0P22PX8208F5Q@80
R8R80P2:RXX208b<S080SHf=0P2ATI4209FEU@80UiNG0P2HV9P209^KV`@0WYjN0P2OWil20::RXP80
YZJV0P2WYjL20:RXZ080Y:BT0P2QXJ420:BTY080ZJVY0P2/[:`30:n_[`80[Zj^0P2/[:`20:VYZ@P0
YZJV102WYjL20:RXZ080[:b/0P2`/;020:n_[`80[Jf]0P2/[:`20:^[Z`80ZJVY0P2XZ:P40:NWY`80
ZJVY0P2[Zj/20:RXZ080YJFU0P2TY:@20:>SX`80W9bL0P2DU9@208j>SP@0RXZ:0`2;Rh/208j>SP80
TI6A0P2=SHd208R8R080QhN70P26QXH208B4Q080Ph>30P22PX840861P@P0PX:2:@38h=P203<c<`@0
<30`0P0c<c<203@d=080<C4a0P0V9RH402/[:`80;2`/0P0X:2P202`/;080<C4a0P0e=CD2034a<@80
=SHf0`0e=CD2038b<P80=3@d0P0e=CD202XZ:P80;Rh^0P0/;2`2051@D080PX:20P2SXj<207moO`80
IfMW0P1UIFD206i^KP80SXj>0P2i^KT20:>SX`80/K6a0P2f][H20;bl_080^k^k0P2m_Kd20<30`080
`/;20P38b<P40<c<c080Y:BT0P10@40203lo?`80AdM70P1ADE4305aLG080GemO0P1/K6`2071`L080
M7Ad0P1hN7P207]kN`80O7al0P23Ph<207emO@80QXJ60P2=SHd208V9R@80S8b<0P2>SXh209FEU@80
UYJF1P2HV9P209fMW@80WinO0P2PX:0209jNWP80Z:RX0P2YZJT20:NWY`80Xj>S0P2UYJD20::RXP80
ZZZZ1@2/[:`20;:b/P80Zj^[0P2YZJT20:RXZ080Xj>S0P2VYZH20:ZZZP80Y:BT0P2WYjL20:RXZ080
[Zj^0P2a/K420;2`/080[Zj^0P2/[:`20:FUY@80ZJVY1P2VYZH40:NWY`80YZJV0P2QXJ420:JVYP80
Vi^K0P2OWil209FEU@80SHf=0P28R8P208V9R@<0Rh^;0P2>SXh209:BTP80T92@0P2:RXX208J6QP80
QhN70P25QHD208B4Q080QXJ60P1oOgl208:2PP@0PH610P24Q8@208R8R2T0b>3H0P0a<C4202d];@80
<S8b0P0d=3@203Ph>0@0:RXZ0P0Y:BT202LW9`80:RXZ0P0/;2`2038b<P80<C4a0P0f=SH203De=@80
;Rh^0`0a<C4203<c<`80<C4a0P0c<c<202TY:@808b<S0P0f=SH204U9B@80Rh^;0P2OWil208Z:RP80
FUYJ0P1UIFD207UiN@80SXj>0P2`/;020:RXZ080[Zj^0P2e]KD20;Jf]P80_Kfm0P2n_[h20<?3``80
`/;20P37alL20=?Cd`80^;Rh0P2XZ:P2051@D080=3@d0P17AdL2051@D0<0G5aL0P1VIVH206e]K@80
Jf][0P1eMGD207IfMP80NGUi0P1kNg/207inOP80Ogmo0P23Ph<208N7Q`80Shn?0P2<S8`208n?S`H0
UIFE0P2HV9P409bLW080WYjN0P2SXj<20:6QX@@0YjNW0P2YZJT40:6QX@80YJFU102[Zj/30;6a/@80
[jn_0P2][Jd20:ZZZP80YjNW0P2SXj<60:JVYP80ZJVY0P2XZ:P20:b/[080[Zj^0P2_[jl20:^[Z`80
[:b/0P2[Zj/20:ZZZP80Z:RX0P2WYjL20:VYZ@80YjNW0P2[Zj/40:FUY@80YjNW0P2QXJ4209fMW@80
UIFE0P2=SHd208Z:RP80QhN70`2=SHd208j>SP80TI6A0P2>SXh208V9R@80R8R80P26QXH208N7Q`80
PX:20P21PH4208:2PP80OWin0P21PH4208B4Q080PH610P22PX8O0<SPf0007@38h=P202l_;`80<30`
0P0a<C4403<c<`80<30`100/;2`202d];@80:b/[0P0Z:RX202h^;P80<c<c0P0d=3@203<c<`80<S8b
0`0a<C42038b<P80<c<c0P0^;Rh402XZ:P80<C4a0P1:BTX208N7Q`80X:2P0P28R8P2065QH@80I6AT
0P1fMWH208n?S`80/K6a0P2YZJT20:n_[`80][Jf0P2j^[X20;fm_@80_kno0P30`<020<G5a@80alO7
0P3De=@20;Zj^P80YjNW0P1@D502038b<P80ATI60P1ADE4305aLG080IFEU0P1/K6`2075aL@80M7Ad
0P1fMWH207UiN@80O7al0P1oOgl208:2PP80QHF50P28R8P208Z:RP80S8b<0P2=SHd2096AT@80UIFE
0P2GUiL209RHV080Vi^K102NWYh209nOW`80XZ:R0P2VYZH20:NWY`80Z:RX0P2TY:@20:6QX@80Y:BT
0P2YZJT20:b/[0<0[jn_0P2^[Zh20:b/[080ZJVY202VYZH40:NWY`80Z:RX0P2/[:`20;2`/080[jn_
0P2][Jd20:b/[080Zj^[0P2YZJT20:RXZ0@0YjNW0P2YZJT20:^[Z`80Z:RX0P2UYJD20:BTY080Xj>S
0P2LW9`209BDU080SXj>102:RXX308^;R`80SXj>0P2ATI4208f=S@80R8R80P27QhL208J6QP80Q8B4
0P23Ph<208:2PP@0PH612022PX8Y0<SPf080<c<c100`<30203<c<`80=3@d0P0a<C4202HV9P@0:b/[
0P0/;2`202PX:080;2`/0P0a<C4203De=@80<C4a0P0f=SH303De=@80<S8b0P0d=3@203De=@80:RXZ
0P0^;Rh202`/;080D51@0P22PX820:>SX`80Ogmo0P1WIfL206EUI@80KVi^0P2>SXh20;Vi^@80Xj>S
0P2a/K420;Jf]P80_;bl0P2k^k/20;fm_@80`<300P32`/820<S8b0@0c<c<0P2TY:@20410@080?clo
0P17AdL2055AD@<0G5aL0P1OGel206a/K080L71`0P1dM7@207QhN080Ng]k0P1lO7`208>3P`80OGem
0P26QXH208f=S@80RHV90P2<S8`208j>SP80UIFE0P2FUYH609RHV080WIfM0P2OWil20:2PX080WYjN
0P2XZ:P20:VYZ@80YjNW0P2SXj<20:FUY@80XZ:R0P2ZZZX50:b/[080/[:b0P2[Zj/20:VYZ@80Z:RX
0P2SXj<20:JVYP80ZZZZ0P2TY:@20:NWY`80Z:RX0P2^[Zh20;6a/@80/;2`0P2^[Zh20:b/[080YJFU
0P2YZJT60:JVYP@0YjNW0P2VYZH20:6QX@80YZJV0P2KVi/209nOW`80UIFE0P2=SHd208R8R080RHV9
0`2;Rh/208j>SP80TY:B0P2@T90208Z:RP80QXJ60P27QhL208F5Q@80Q8B40P26QXH207moO`80PX:2
1021PH4208B4Q080R8R8:@38h=P2034a<@80;Bd]0P0b<S8203@d=080>3Ph100Z:RX202TY:@809bLW
0P0Z:RX202`/;080<S8b0P0a<C4203Hf=P80=CDe0P0^;Rh3034a<@80<c<c0P0a<C4203<c<`80:BTY
0P0S8b<203Hf=P80BDU90P2;Rh/209nOW`80RXZ:0P1JFUX206EUI@80NGUi0P2>SXh20;2`/080Z:RX
0P2^[Zh20;Fe]@80][Jf0P2m_Kd20;jn_P80`l?30P32`/820<O7a`80dm?C0P2h^;P20:RXZ080D51@
0P0d=3@204M7A`80D51@0`1LG5`206IVIP80KFe]0P1[Jf/207EeM@80MWIf0P1iNGT207]kN`80OWin
0P1oOgl208>3P`80QhN70P2?Shl208b<S080Shn?1P2EUID209RHV0@0W9bL0P2NWYh20:>SX`80XJ6Q
102WYjL20:VYZ@@0XJ6Q0P2UYJD40:^[Z`<0/K6a0P2_[jl20:f][@80ZZZZ0P2WYjL20:>SX`H0YZJV
0P2YZJT20:RXZ080[:b/0P2^[Zh20:n_[`80Zj^[0P2/[:`20:^[Z`80ZZZZ0P2XZ:P20:NWY`80ZJVY
0P2WYjL20:^[Z`@0YJFU0P2WYjL20:6QX@80WIfM0P2EUID208f=S@80RXZ:0P27QhL308f=S@80SXj>
0P2ATI4208j>SP80RHV90P28R8P208J6QP80QhN70P22PX820861P@80PX:20P1nOWh20861P@80Q8B4
0P21PH4208:2PQl0b>3H000M0<SPf0H0;Rh^100_;bl202h^;P80;2`/0P0[:b/202XZ:P80:b/[0P0]
;Bd2034a<@80=CDe0P0d=3@203<c<`T0<S8b0P0^;Rh202`/;080:RXZ0P0b<S8202`/;080JFUY0P2R
XZ8209JFUP80GemO0P1VIVH206QXJ080NGUi0P2FUYH20;Fe]@80/k>c0P2_[jl20;Bd]080^[Zj0P2m
_Kd20<30`080`l?30P37alL40=;BdP80aLG50P2<S8`203lo?`80@4100P18B4P305aLG080I6AT0P1Z
JVX206m_K`80Lg=c0P1dM7@207EeM@80NWYj0P1oOgl208B4Q080R8R80P27QhL208J6QP80RXZ:0P2@
T90209>CT`80UYJF0P2GUiL209RHV080Vi^K0P2NWYh409nOW`80XZ:R0P2UYJD40:JVYP80Y:BT0P2R
XZ820:BTY080YjNW0P2ZZZX30:f][@80ZZZZ0P2WYjL20:BTY080Xj>S0P2UYJD20:RXZ080YZJV102U
YJD20:NWY`80Zj^[0P2_[jl20:b/[080ZJVY0P2/[:`20:n_[`80[Jf]0P2YZJT20:JVYP80YJFU0P2Y
ZJT20:f][@80ZJVY0P2UYJD40:NWY`80WYjN0P2CTi<208j>SP80Rh^;1@29RHT208f=S@80TI6A0P2?
Shl208^;R`80RHV90P28R8P208F5Q@80Ph>31022PX820861P@80P8200P21PH4408:2PRT0b>3H0P0b
<S8202/[:`80;bl_0P0b<S82030`<080;2`/0P0`<30202h^;P809bLW0P0`<30202h^;P80<C4a0P0b
<S8203lo?`T0<30`0P0c<c<202/[:`@0:RXZ0P0/;2`203Ph>080Jf][0P2BTY8209FEU@80Kfm_0P1R
HV8206ATI080MGEe0P2RXZ820;Fe]@80ZZZZ0P2b/[820;Fe]@80^[Zj102m_Kd20<K6aP80bLW90P3?
cll20<k>cP80alO70P2:RXX40410@080CDe=0`1IFET2065QH@80JVYZ101aLG4207EeM@80MWIf0P1g
MgL207emO@80QHF50P26QXH208V9R@80QHF50P2:RXX208f=S@80UiNG0P2DU9@209NGU`80UYJF0P2L
W9`20:6QX@80V9RH0P2QXJ420::RXP80Y:BT0P2WYjL20:BTY080YZJV0P2PX:020:BTY080YjNW0P2Z
ZZX30:f][@80[:b/102VYZH20:2PX080YJFU0P2WYjL20:FUY@80Z:RX0P2SXj<20:NWY`80ZJVY0P2[
Zj/20:f][@@0ZJVY0P2a/K420:j^[P80ZJVY0P2TY:@20:JVYP80[:b/0P2`/;020:BTY080YZJV0P2^
[Zh20:FUY@80WYjN0P2CTi<208b<S080SXj>1@28R8P2092@T080Shn?0P2>SXh208^;R`80QXJ60P29
RHT208J6QP@0PH610P23Ph<20861P@80PX:20P20P80207moO`80Rh^;:@38h=P202d];@80<30`0P0]
;Bd2030`<080;2`/0P0Z:RX202`/;080=CDe0P0Z:RX202`/;080:b/[0P0`<30203Lg=`80<C4a0P0f
=SH202h^;P<0=CDe0P0`<30202l_;`80<C4a0P0];Bd202DU9@80=cLg0P0W9bL206e]K@80WinO0P2I
VIT205UIF@80J6QX0P1[Jf/207MgM`80UYJF0P2e]KD20;>c/`80[Zj^0P2e]KD20;Rh^0@0_kno0P33
`l<20<O7a`80e=CD0P3AdM420<K6aP80Rh^;0P0l?3`20410@080AdM70`1NGUh206ATI080Jf][0P1_
Kfl2079bLP80M7Ad0P1cLg<207]kN`80OGem0P28R8P208F5Q@80Rh^;0P23Ph<208^;R`80SHf=0P2F
UYH209FEU@@0UiNG0P2LW9`209fMW@80X:2P0P2NWYh20:>SX`80YJFU0P2VYZH20:FUY@@0XZ:R0P2S
Xj<20:NWY`80ZJVY1@2/[:`20:JVYP80YJFU0P2TY:@20::RXP80Z:RX0P2WYjL20:FUY@@0YZJV0P2]
[Jd20:n_[`80[:b/0P2YZJT20:j^[P80[jn_0P2][Jd20:ZZZP80Xj>S0P2VYZH20:RXZ080[jn_0P2Y
ZJT20:FUY@80ZZZZ0P2UYJD209bLW080U9BD0P2;Rh/208f=S@80R8R80`2;Rh/208V9R@80U9BD0P2?
Shl208^;R`@0QhN70P29RHT208>3P`80PH610P23Ph<20861P@80P8200P24Q8@208:2PP80P8207`38
h=P001d0b>3H1P0^;Rh402l_;`80;Rh^0P0/;2`202/[:`80:RXZ0P0[:b/202d];@80<C4a0P0e=CD2
03@d=080<c<c2@0b<S8202h^;P80;2`/0P0Z:RX2038b<P80;2`/0P1YJFT20::RXP80UYJF0P1OGel2
06IVIP80J6QX0P1iNGT209JFUP80]KFe0P2c/k<20:n_[`80];Bd0P2j^[X20;fm_@80`<300P33`l<2
0<O7a`@0d];B0P35aLD208b<S080?clo0P10@40204Q8B0<0G5aL0P1TI6@206YZJP80Kfm_0P1cLg<2
07AdM080MGEe0P1jNWX207moO`80Q8B40P28R8P208N7Q`80QXJ60P2:RXX2092@T080Ti>C0P2FUYH2
09NGU`80V9RH0P2KVi/209jNWP@0WinO0P2RXZ820:FUY@@0YZJV0P2TY:@20::RXP80Y:BT0P2WYjL2
0:ZZZP<0[Jf]0P2ZZZX20:NWY`80Y:BT0P2SXj<20:FUY@80Z:RX0P2VYZH40:FUY@80YjNW0P2[Zj/2
0:n_[`80[:b/0P2YZJT20:b/[080[jn_0P2][Jd20:VYZ@80YZJV0P2UYJD20:VYZ@80[Jf]0P2YZJT2
0:FUY@@0YjNW0P2NWYh209>CT`80SXj>0P2;Rh/508V9R@80SHf=0P2ATI4208n?S`80Rh^;0P29RHT2
08R8R080QHF50P23Ph<408:2PP80PH610P20P8020861P@@0PX:2:@38h=P2038b<P80:b/[0P0_;bl2
038b<P80<30`0P0/;2`2030`<080;Rh^0P0W9bL2030`<080;Rh^0P0a<C42038b<P80?clo2@0`<302
03<c<`80:b/[100Z:RX202`/;080>3Ph0P1[Jf/209:BTP80UIFE0P1_Kfl2069RHP80I6AT0P1eMGD2
0::RXP80]KFe0P2ZZZX20;:b/P80]KFe0P2j^[X40;fm_@80a/K60P39bLT20<o?c`80c/k>0P37alL2
08Z:RP@0@4100P1=CDd305UIF@80HF5Q0P1ZJVX4075aL@80MGEe0P1fMWH207MgM`80OGem0P25QHD2
08J6QP80RHV90P25QHD208Z:RP80SHf=0P2GUiL209BDU080UiNG0P2FUYH209bLW080XJ6Q0P2HV9P2
0:6QX@80XZ:R0P2TY:@20:NWY`80Y:BT0P2VYZH20:2PX080Y:BT0P2WYjL20:ZZZP<0[Jf]0P2/[:`4
0:JVYP80X:2P0P2UYJD20:NWY`80YJFU0P2XZ:P20:>SX`80YjNW0P2YZJT20:^[Z`80[Jf]102YZJT2
0;6a/@80[Zj^0P2YZJT20:BTY080YZJV0P2/[:`20;2`/080Y:BT0P2VYZH20:j^[P80YJFU0P2NWYh2
09>CT`80S8b<0P2>SXh508R8R080T92@0P2?Shl208j>SP80Rh^;0P26QXH208V9R@80QXJ61021PH42
08>3P`80PH610P22PX820820P080Ogmo0P2;Rh/Y0<SPf080;Bd]0P0`<30202d];@80<30`0P0/;2`2
02XZ:P80;2`/0P0e=CD202XZ:P80;2`/0P0[:b/2030`<080=cLg0P0a<C4203Hf=P80;Rh^0`0e=CD2
030`<080;bl_0P0a<C4202d];@809BDU0P0g=cL202LW9`80KFe]0P2OWil209VIV@80FEUI0P1XJ6P2
06][J`80MgMg0P2FUYH20;Fe]@80/k>c0P2^[Zh20;Fe]@80^;Rh102o_kl20<?3``80alO70P3De=@2
0=7Ad@80a/K60P2;Rh/203`l?080@4100P17AdL305iNGP80I6AT0P1[Jf/206m_K`80LW9b0P1dM7@2
07=cL`80Ng]k0P1mOGd208R8R080QHF50P2;Rh/208>3P`80Rh^;0P2=SHd209JFUP80UIFE102GUiL2
09bLW080WIfM0P2PX:0209jNWP80Xj>S0P2UYJD20:JVYP80YJFU102RXZ820:>SX`80YjNW0P2YZJT5
0:b/[080YZJV0P2UYJD20:BTY080XZ:R0P2XZ:P20:NWY`80YJFU102VYZH20:f][@80[jn_0P2/[:`2
0:VYZ@80[Zj^0P2_[jl20:f][@80ZZZZ0P2SXj<20:JVYP80Z:RX0P2_[jl20:VYZ@80YJFU0P2ZZZX2
0:FUY@80W9bL0P2DU9@208^;R`80SHf=0P28R8P308^;R`80RHV90P2DU9@208n?S`80Rh^;1027QhL2
08V9R@80Ph>30P21PH4208>3P`80PH610P20P80208B4Q080PX:20P20P80O0<SPf0007@38h=P202l_
;`80;Bd]0P0[:b/202d];@@0;Rh^0P0];Bd202/[:`@0:RXZ0P0/;2`2038b<P80=SHf0P0d=3@2034a
<@D0<30`100a<C4202`/;0809bLW0P0U9BD202XZ:P809RHV0P19BDT208N7Q`80UYJF0P25QHD206][
J`80IFEU0P1[Jf/208Z:RP80[:b/0P2o_kl20:ZZZP80/[:b0P2g]kL20;Vi^@80^k^k0P2o_kl20<G5
a@80c<c<0P3?cll20=GEe@80/K6a0P1oOgl2055AD@80>c/k0`1DE5@205YJFP80IfMW0P1/K6`2071`
L080LW9b0P1dM7@207QhN080OGem0P23Ph<208R8R080QhN70P26QXH208^;R`80T92@0P2DU9@209NG
U`80V9RH0P2IVIT209ZJVP80Vi^K0P2LW9`209fMW@80X:2P0P2RXZ860:>SX`@0XZ:R1`2SXj<20:2P
X080WIfM102LW9`209nOW`80XJ6Q0P2PX:0209nOW`80X:2P0P2RXZ820:FUY@80Z:RX0P2VYZH20:FU
Y@80Z:RX102/[:`20:^[Z`80Z:RX0P2VYZH20:RXZ080ZJVY0P2VYZH20:>SX`80YZJV0P2XZ:P20:2P
X080UiNG0P2@T90208Z:RP80QXJ60`25QHD208R8R080S8b<0P2=SHd208b<S080RXZ:0P27QhL208>3
P`80P8200P21PH4208:2PP80PH610P20P80208:2PP@0QHF5:@38h=P402`/;080;Bd]0P0_;bl202d]
;@809bLW0P0/;2`2034a<@80:2PX0P0[:b/202TY:@80<30`0P0f=SH203Lg=`80;Bd]0P0c<c<3038b
<P80<C4a100`<30202HV9P809bLW0P0X:2P202d];@80AdM70P22PX8209jNWP80Q8B40P1YJFT206EU
I@80Jf][0P27QhL20;Bd]080[Jf]0P2a/K420;Bd]080][Jf102k^k/40<?3``80b/[:0P3?cll20<g=
c@80`L710P21PH4203lo?`80ADE50`1DE5@2061PH080IVIV0P1aLG42071`L080Kfm_0P1bLW8207Qh
N080Ogmo0P27QhL208J6QP80QhN70P23Ph<208j>SP80S8b<0P2FUYH209BDU080UiNG1P2LW9`209^K
V`80WinO0P2TY:@40:6QX@80XZ:R0P2TY:@209jNWP80YZJV102QXJ430:>SX`80WinO0P2JVYX209nO
W`80Vi^K102RXZ8209fMW@80WYjN0P2OWil20:JVYP80Y:BT0P2[Zj/20:ZZZP80Xj>S0P2VYZH20;6a
/@80[:b/0P2^[Zh20:FUY@80XZ:R102/[:`20:2PX080XZ:R0P2ZZZX40:BTY080UIFE0P2<S8`208f=
S@D0QHF50P28R8P208Z:RP80Shn?0P2>SXh408R8R0@0PX:20P1nOWh208B4Q0@0Ogmo0P20P80207em
O@80S8b<:@38h=P202/[:`80;Rh^0P0Z:RX402l_;`80<S8b0P0Z:RX202d];@809RHV0P0Y:BT202`/
;080<S8b0P0h>3P403<c<`80;Bd]0`0`<30203@d=080<C4a0P0`<30202HV9P808b<S0P0Z:RX202DU
9@80BDU90P21PH4209fMW@80PX:20P1]KFd206ATI080J6QX0P2=SHd20:b/[080_kno0P2][Jd20;Bd
]080^k^k0P2j^[X20;Rh^080`/;20P33`l<20<W9b@80d=3@0P3GemL20;>c/`80PX:20P1ADE4203/k
>`<0DE5A0P1JFUX406UYJ@80M7Ad0P1bLW8207IfMP80NGUi0P1lO7`208B4Q080QXJ60P2;Rh/208:2
PP80RHV90P2?Shl409JFUP80UiNG0P2JVYX209VIV@80WYjN0P2JVYX209bLW080WYjN0P2QXJ460:BT
Y080Xj>S0P2TY:@20:>SX`L0XZ:R0P2LW9`209^KV`@0WYjN0P2SXj<20::RXP80WIfM0P2OWil20:6Q
X@80YJFU0P2WYjL20:BTY080YZJV0P2XZ:P20:ZZZP80[Jf]0P2[Zj/20:FUY@@0YZJV0P2ZZZX20:NW
Y`80X:2P0P2TY:@20:VYZ@80XZ:R0P2HV9P208n?S`80Rh^;0P28R8P308B4Q080QHF50P2<S8`208f=
S@80SXj>0P28R8P208J6QP80PX:20P1nOWh408:2PP80P8200P1nOWh208F5Q@80Q8B40P25QHDO0<SP
f0007@38h=P202l_;`80;Bd]0P0[:b/202d];@@0;Rh^0P0];Bd202/[:`@0:RXZ0P0/;2`2038b<P80
=SHf0P0d=3@2034a<@D0<30`100a<C4202`/;0809bLW0P0U9BD202XZ:P809RHV0P19BDT208N7Q`80
UYJF0P25QHD206][J`80IFEU0P1[Jf/208Z:RP80[:b/0P2o_kl20:ZZZP80/[:b0P2g]kL20;Vi^@80
^k^k0P2o_kl20<G5a@80c<c<0P3?cll20=GEe@80/K6a0P1oOgl2055AD@80>c/k0`1DE5@205YJFP80
IfMW0P1/K6`2071`L080LW9b0P1dM7@207QhN080OGem0P23Ph<208R8R080QhN70P26QXH208^;R`80
T92@0P2DU9@209NGU`80V9RH0P2IVIT209ZJVP80Vi^K0P2LW9`209fMW@80X:2P0P2RXZ860:>SX`@0
XZ:R1`2SXj<20:2PX080WIfM102LW9`209nOW`80XJ6Q0P2PX:0209nOW`80X:2P0P2RXZ820:FUY@80
Z:RX0P2VYZH20:FUY@80Z:RX102/[:`20:^[Z`80Z:RX0P2VYZH20:RXZ080ZJVY0P2VYZH20:>SX`80
YZJV0P2XZ:P20:2PX080UiNG0P2@T90208Z:RP80QXJ60`25QHD208R8R080S8b<0P2=SHd208b<S080
RXZ:0P27QhL208>3P`80P8200P21PH4208:2PP80PH610P20P80208:2PP@0QHF5:@38h=P402`/;080
;Bd]0P0_;bl202d];@809bLW0P0/;2`2034a<@80:2PX0P0[:b/202TY:@80<30`0P0f=SH203Lg=`80
;Bd]0P0c<c<3038b<P80<C4a100`<30202HV9P809bLW0P0X:2P202d];@80AdM70P22PX8209jNWP80
Q8B40P1YJFT206EUI@80Jf][0P27QhL20;Bd]080[Jf]0P2a/K420;Bd]080][Jf102k^k/40<?3``80
b/[:0P3?cll20<g=c@80`L710P21PH4203lo?`80ADE50`1DE5@2061PH080IVIV0P1aLG42071`L080
Kfm_0P1bLW8207QhN080Ogmo0P27QhL208J6QP80QhN70P23Ph<208j>SP80S8b<0P2FUYH209BDU080
UiNG1P2LW9`209^KV`80WinO0P2TY:@40:6QX@80XZ:R0P2TY:@209jNWP80YZJV102QXJ430:>SX`80
WinO0P2JVYX209nOW`80Vi^K102RXZ8209fMW@80WYjN0P2OWil20:JVYP80Y:BT0P2[Zj/20:ZZZP80
Xj>S0P2VYZH20;6a/@80[:b/0P2^[Zh20:FUY@80XZ:R102/[:`20:2PX080XZ:R0P2ZZZX40:BTY080
UIFE0P2<S8`208f=S@D0QHF50P28R8P208Z:RP80Shn?0P2>SXh408R8R0@0PX:20P1nOWh208B4Q0@0
Ogmo0P20P80207emO@80S8b<:@38h=P202/[:`80;Rh^0P0Z:RX402l_;`80<S8b0P0Z:RX202d];@80
9RHV0P0Y:BT202`/;080<S8b0P0h>3P403<c<`80;Bd]0`0`<30203@d=080<C4a0P0`<30202HV9P80
8b<S0P0Z:RX202DU9@80BDU90P21PH4209fMW@80PX:20P1]KFd206ATI080J6QX0P2=SHd20:b/[080
_kno0P2][Jd20;Bd]080^k^k0P2j^[X20;Rh^080`/;20P33`l<20<W9b@80d=3@0P3GemL20;>c/`80
PX:20P1ADE4203/k>`<0DE5A0P1JFUX406UYJ@80M7Ad0P1bLW8207IfMP80NGUi0P1lO7`208B4Q080
QXJ60P2;Rh/208:2PP80RHV90P2?Shl409JFUP80UiNG0P2JVYX209VIV@80WYjN0P2JVYX209bLW080
WYjN0P2QXJ460:BTY080Xj>S0P2TY:@20:>SX`L0XZ:R0P2LW9`209^KV`@0WYjN0P2SXj<20::RXP80
WIfM0P2OWil20:6QX@80YJFU0P2WYjL20:BTY080YZJV0P2XZ:P20:ZZZP80[Jf]0P2[Zj/20:FUY@@0
YZJV0P2ZZZX20:NWY`80X:2P0P2TY:@20:VYZ@80XZ:R0P2HV9P208n?S`80Rh^;0P28R8P308B4Q080
QHF50P2<S8`208f=S@80SXj>0P28R8P208J6QP80PX:20P1nOWh408:2PP80P8200P1nOWh208F5Q@80
Q8B40P25QHDO0<SPf0007@38h=P202l_;`80;2`/0P0Z:RX202`/;0H0;Rh^0P0/;2`402/[:`80;2`/
0P0b<S8203Hf=P80<c<c0P0_;bl202h^;P<0;Bd]0P0_;bl2030`<080:BTY0P0S8b<2028R8P8092@T
0P0V9RH202h^;P80HV9R0P2>SXh20:VYZ@80M7Ad0P1YJFT206=SH`80PH610P2NWYh20<O7a`80ZJVY
0P2`/;020;:b/P80];Bd0P2f][H20;^k^`80`<300P35aLD20<S8b080d];B0P3>c/h20<71`@80Kfm_
0P0i>CT304i>CP80De=C0P1RHV8206MWI`80K6a/0P1`L70207AdM080MgMg0P1kNg/20861P@80QXJ6
1027QhL208b<S080TI6A0P2EUID209RHV0@0VIVI0P2HV9P209NGU`80V9RH0P2JVYX209fMW@80WinO
102PX:040:6QX@80WinO0P2MWId209^KV`<0VIVI0P2FUYH209>CT`80U9BD0P2FUYH609RHV080UiNG
0P2IVIT209bLW080WYjN0P2OWil40:2PX080Xj>S0P2UYJD20:RXZ080ZZZZ0P2YZJT20:NWY`80YZJV
0P2UYJD20::RXP80X:2P0P2TY:@20:NWY`80Xj>S0P2LW9`2096AT@80R8R80P23Ph<30861P@80Ph>3
0P26QXH208Z:RP80S8b<0P2:RXX208N7Q`80PH610P1mOGd20820P080Ph>30P21PH420820P080Ph>3
0P27QhL208R8R2T0b>3H0P0`<30202d];@80:BTY0P0/;2`402h^;P80;Bd]0P0/;2`202/[:`80;bl_
0P0Y:BT203@d=080=CDe100_;bl2038b<P<0:RXZ0P0_;bl2038b<P80:BTY0P0U9BD2024Q8@809BDU
0P0S8b<2030`<080IVIV0P2?Shl209nOW`80O7al0P1TI6@206QXJ080Ng]k0P2TY:@20;^k^`80[:b/
0P2f][H20;6a/@80/k>c0P2g]kL20;Zj^P80`<300P36a/H20<_;b`80c<c<0P3>c/h20;^k^`80L71`
0P0l?3`304i>CP80EEEE0P1NGUh206EUI@80KVi^0P1`L70207IfMP80N7Qh0P1iNGT208:2PP@0QhN7
0P26QXH208f=S@80SXj>0P2HV9P209JFUP80VIVI0P2GUiL209ZJVP@0UiNG0P2JVYX209^KV`80X:2P
0P2SXj<209jNWP80Xj>S0P2OWil20:2PX080W9bL1@2JVYX209NGU`80U9BD102FUYH209RHV080Vi^K
0P2FUYH209VIV@80WYjN0P2KVi/409bLW080YJFU0P2PX:020::RXP80Y:BT0P2UYJD20:NWY`80ZZZZ
0P2UYJD20:NWY`80YJFU0P2RXZ8209nOW`80YZJV0P2SXj<20:NWY`80W9bL0P2>SXh208^;R`80PX:2
0`1oOgl208B4Q080QXJ60P2;Rh/208b<S080QhN70P29RHT20820P080OWin0P20P80208B4Q0@0PX:2
0P23Ph<208N7Q`80SHf=:@38h=P202d];@80<C4a0P0[:b/202<S8`80;2`/0P0c<c<202h^;P80:2PX
0P0Y:BT202d];@80:b/[0P0`<30203De=@80<C4a0P0_;bl202h^;P<0:b/[0P0_;bl202`/;080;Rh^
0P0T92@2024Q8@809bLW0P0S8b<202l_;`80GUiN0P2?Shl20:FUY@80M7Ad0P1WIfL206EUI@80P820
0P2MWId20<G5a@80YjNW0P2][Jd20;:b/P80];Bd0P2f][H20;bl_080`<300P32`/820<[:bP80d];B
0P3=cLd20;jn_P80L71`0P0i>CT3055AD@80De=C0P1RHV8206ATI080KFe]0P1aLG42079bLP80N7Qh
0P1kNg/20861P@80Q8B41027QhL208b<S080TY:B0P2EUID209JFUP80Vi^K0P2IVIT209NGU`80UYJF
0P2GUiL209^KV`80W9bL0P2OWil40:6QX@80X:2P0P2QXJ4409fMW@80W9bL0`2HV9P209VIV@@0U9BD
0P2FUYH209VIV@80V9RH0P2GUiL409RHV0@0WIfM0P2NWYh20:6QX@@0X:2P0P2UYJD20:^[Z`80ZJVY
1P2WYjL20:JVYP80XZ:R0P2PX:020:FUY@80YjNW0P2QXJ4209bLW080TY:B0P27QhL208:2PP<0PH61
0P22PX8208V9R@@0RXZ:0P2<S8`208N7Q`80Ph>30P1mOGd20861P@80Ph>30P20P80207moO`H0QXJ6
7`38h=P001d0b>3H0P0_;bl202`/;080:RXZ0P0/;2`602h^;P80;2`/100[:b/202`/;080<S8b0P0f
=SH203<c<`80;bl_0P0^;Rh302d];@80;bl_0P0`<30202TY:@808b<S0P0R8R8202@T90809RHV0P0^
;Rh2069RHP80SXj>0P2YZJT207AdM080JFUY0P1SHf<20861P@80WYjN0P37alL20:VYZ@80/;2`0P2b
/[820;Bd]080][Jf0P2k^k/20<30`080aLG50P38b<P20=;BdP80c/k>0P31`L4206m_K`80>CTi0`1>
CTh205=CD`80HV9R0P1WIfL206a/K080L71`0P1dM7@207MgM`80Ng]k0P21PH4208J6QP@0QhN70P2<
S8`2096AT@80UIFE0P2HV9P409VIV@80V9RH0P2GUiL209RHV080VYZJ0P2MWId209nOW`@0X:2P102Q
XJ4209nOW`80WIfM0P2KVi/309VIV@80UYJF0P2CTi<209BDU080UYJF1P2HV9P209NGU`80VIVI0P2L
W9`209jNWP80WinO102PX:020:>SX`80YJFU0P2XZ:P20:ZZZP80ZJVY0P2WYjL20:JVYP80YJFU0P2R
XZ820:2PX080Y:BT0P2WYjL20:>SX`80W9bL0P2ATI4208R8R080Ph>30`21PH4208>3P`80QXJ60P2:
RXX208b<S080RXZ:0P27QhL20861P@80OGem0P20P80208>3P`80PH610P20P80208>3P`80QhN70P28
R8PY0<SPf080<30`0P0];Bd202TY:@80;2`/100^;Rh202d];@80;2`/0P0[:b/202l_;`80:BTY0P0d
=3@203De=@@0;bl_0P0b<S8302XZ:P80;bl_0P0b<S8202TY:@809BDU0P0Q8B4202DU9@808b<S0P0`
<30206IVIP80Shn?0P2OWil207alO080I6AT0P1XJ6P207]kN`80Y:BT0P2k^k/20:b/[080][Jf0P2a
/K420;>c/`80]kNg0P2j^[X20<30`080a/K60P3;bl/20<c<c080c/k>0P2k^k/2071`L080?3`l0`1>
CTh205EEE@80GUiN0P1UIFD206i^KP80L71`0P1fMWH207QhN080NGUi0P22PX8408N7Q`80QXJ60P2=
SHd208j>SP80V9RH0P2FUYH209VIV@80UiNG0P2JVYX409NGU`80VYZJ0P2KVi/20:2PX080Xj>S0P2N
WYh20:>SX`80WinO0P2PX:0209bLW0D0VYZJ0P2GUiL209BDU0@0UYJF0P2HV9P209^KV`80UYJF0P2I
VIT209jNWP80Vi^K102LW9`20:FUY@80X:2P0P2RXZ820:BTY080YJFU0P2WYjL20:ZZZP80YJFU0P2W
YjL20:FUY@80XZ:R0P2OWil20:JVYP80Xj>S0P2WYjL209bLW080SXj>0P2;Rh/208:2PP<0Ogmo0P24
Q8@208J6QP80Rh^;0P2<S8`208N7Q`80RHV90P20P80207inOP80P8200P24Q8@408:2PP80Ph>30P27
QhL208f=SBT0b>3H0P0];Bd2034a<@80:b/[0P0S8b<202`/;080<c<c0P0^;Rh202PX:080:BTY0P0]
;Bd202/[:`80<30`0P0e=CD2034a<@80;bl_0P0^;Rh302/[:`80;bl_0P0/;2`202h^;P8092@T0P0Q
8B4202LW9`808b<S0P0_;bl205iNGP80Shn?0P2UYJD207AdM080IfMW0P1UIFD20820P080WIfM0P35
aLD20:NWY`80[Jf]0P2b/[820;Bd]080][Jf0P2l_;`20<30`080`/;20P3:b/X20=;BdP80cLg=0P2n
_[h2071`L080>CTi0`1ADE4205=CD`80HV9R0P1TI6@206e]K@80LG5a0P1bLW8207QhN080Ng]k0P21
PH4208B4Q0@0QhN70P2<S8`209:BTP80UIFE0P2FUYH209^KV`80VIVI0P2GUiL209JFUP80UiNG0P2K
Vi/209bLW080WinO102QXJ420:2PX080XJ6Q102MWId209bLW0<0V9RH0P2IVIT409BDU080UYJF0P2I
VIT209RHV080UiNG102HV9P409fMW@80WYjN0P2QXJ440:2PX080YJFU0P2[Zj/20:VYZ@H0YjNW0P2V
YZH20::RXP80X:2P0P2UYJD20:NWY`80XJ6Q0P2LW9`209:BTP80QhN70P22PX830861P@80PX:20P29
RHT408Z:RP80S8b<0P27QhL208>3P`80OGem0P21PH4208>3P`80P8200P1oOgl608J6QQl0b>3H000M
0<SPf0@0;2`/100];Bd202h^;P@0;bl_0P0/;2`202/[:`80;Bd]0P0`<302038b<P80=3@d0P0b<S82
02l_;`80;Rh^1`0];Bd202TY:@8092@T0P0S8b<202@T90808R8R0P0W9bL203hn?P80Ng]k0P2NWYh2
08f=S@80MGEe0P1SHf<207IfMP80T92@0P2i^KT20;Bd]080/;2`0P2WYjL20:f][@80]KFe0P2h^;P2
0;^k^`80_kno0P34a<@20<g=c@80clo?0P3AdM420:BTY080IfMW0`1?Cdl2055AD@80EeMG0P1OGel2
06UYJ@80Kfm_0P1dM7@207QhN080Ng]k0P20P80208J6QP80QhN70P29RHT208f=S@80TY:B0P2DU9@2
09JFUP80VIVI0P2KVi/209ZJVPH0V9RH0P2IVIT209ZJVP80Vi^K102LW9`209^KV`80VIVI0P2GUiL2
09JFUP<0UIFE0P2BTY82092@T080TY:B1P2DU9@209>CT`80TY:B0P2DU9@209FEU@80UYJF0P2GUiL2
09ZJVP80W9bL0P2PX:0209jNWP80XJ6Q0P2TY:@20:FUY@80Y:BT0P2VYZH20:NWY`80XZ:R0P2NWYh2
0:6QX@@0Y:BT0P2QXJ4209FEU@80R8R80P23Ph<30861P@80PX:20P25QHD208R8R080RXZ:0P29RHT2
08N7Q`80Ph>31020P8020861P@80P8200P1oOgl208>3P`80QXJ60P27QhLY0<SPf080:b/[0P0_;bl2
02`/;080;bl_0P0b<S82034a<@80<c<c0P0/;2`202LW9`80;Rh^0P0a<C4203Ph>080=SHf0P0c<c<2
030`<080;bl_1@0];Bd202`/;0809bLW0P0S8b<202@T90809BDU0P0S8b<202@T9080?clo0P1iNGT2
09bLW080Shn?0P1cLg<206][J`80Kfm_0P2FUYH20<71`@80/[:b0P2[Zj/20:JVYP80ZZZZ0P2a/K42
0;Fe]@80_;bl0P2o_kl20<S8b080c<c<0P3?cll20<c<c080][Jf0P1PH60304M7A`80DE5A0P1LG5`2
05mOG`80IfMW0P1^KVh2079bLP80Ng]k0P1jNWX207alO080Ph>30P2;Rh/208R8R080T92@0P2BTY82
09BDU080VIVI102JVYX209RHV080UiNG0P2CTi<209JFUP80WYjN0P2DU9@409^KV`80WinO0P2JVYX2
09fMW@80VYZJ0P2EUID309NGU`80TI6A0P2>SXh209:BTP80TI6A0P2CTi<208n?S`@0T92@0P2CTi<4
09:BTP80V9RH0P2FUYH209bLW080WIfM0P2PX:020:6QX@@0Z:RX0P2WYjL20:>SX`@0Y:BT0P2LW9`2
0:6QX@80Xj>S0P2WYjL20:2PX080TY:B0P26QXH208>3P`<0QHF51024Q8@208J6QP80RXZ:0P2;Rh/2
08N7Q`80Q8B40P1oOgl20861P@80O7al0P23Ph<207alO080PH610P24Q8@208j>SRT0b>3H0P0[:b/2
02`/;080;Bd]0P0^;Rh202l_;`80<c<c0P0];Bd202XZ:P80=3@d0P0];Bd203<c<`80<S8b0P0h>3P2
038b<P80;Rh^0P0b<S8302h^;P80;Bd]0P0/;2`202d];@807alO0P0P820202@T90809RHV0P0Z:RX2
0492@P80O7al0P2LW9`209:BTP80Lg=c0P1TI6@207UiN@80Shn?0P2j^[X20;Vi^@80[jn_0P2UYJD2
0:j^[P80];Bd0P2f][H20;bl_080`/;20P34a<@20<c<c080dM7A0P3@d=020::RXP80IVIV0`1=CDd2
059BDP80FEUI0P1QHF4206EUI@80L71`0P1cLg<207IfMP80NGUi0P25QHD208N7Q`80Q8B40P2=SHd2
08n?S`@0TI6A0P2JVYX209^KV`80W9bL0P2GUiL209RHV080VYZJ0P2IVIT209RHV080WIfM0P2JVYX2
09^KV`80VYZJ102LW9`209NGU`80UYJF0`2DU9@209FEU@80S8b<0P2ATI4209>CT`80U9BD1P2BTY84
09JFUP80Ti>C0P2JVYX409fMW@80X:2P0P2NWYh20:FUY@80Xj>S0P2VYZH20:BTY080YZJV0P2TY:@2
0:FUY@80WIfM0P2PX:040:BTY080XJ6Q0P2DU9@208N7Q`D0Q8B40P21PH4208>3P`80QhN70P29RHT2
08f=S@80QXJ61021PH4208>3P`80Ogmo1020P80208:2PP80R8R80P27QhLO0<SPf0007@38h=P402`/
;0@0;Bd]0P0^;Rh402l_;`80;2`/0P0[:b/202d];@80<30`0P0b<S8203@d=080<S8b0P0_;bl202h^
;PL0;Bd]0P0Y:BT202@T90808b<S0P0T92@2028R8P809bLW0P0n?Sh207]kN`80WYjN0P2=SHd207Ee
M@80Hf=S0P1fMWH2092@T080^KVi0P2d];@20;2`/080YjNW0P2][Jd20;Fe]@80^;Rh0P2k^k/20;no
_`80a<C40P3=cLd20<o?c`80dM7A0P2TY:@206MWI`<0Cdm?0P1ADE4205MGE`80GemO0P1YJFT206m_
K`80M7Ad0P1hN7P207]kN`80P8200P26QXH208N7Q`80RHV90P2=SHd209:BTP80U9BD0P2FUYH209VI
V@80Vi^K0P2JVYX609RHV080VIVI0P2JVYX209^KV`@0W9bL0P2KVi/209VIV@80UiNG0P2FUYH309FE
U@80TY:B0P2@T90209:BTPH0U9BD0P2CTi<209:BTP80U9BD0P2EUID209JFUP80UiNG0P2JVYX209bL
W080X:2P0P2NWYh20:6QX@80Y:BT0P2UYJD20:BTY080YZJV0P2WYjL20::RXP80WYjN0P2QXJ440:BT
Y080XJ6Q0P2EUID208R8R080Ph>30`21PH4208:2PP80QHF50P28R8P208Z:RP80RHV90P27QhL208>3
P`@0P8200P21PH420820P080Ogmo0P23Ph<208J6QP80QhN7:@38h=P202/[:`80;bl_0P0/;2`202l_
;`80<S8b0P0a<C4203<c<`80;2`/0P0W9bL202h^;P80<C4a0P0h>3P203Hf=P80<c<c0P0`<30202l_
;`D0;Bd]0P0/;2`202LW9`808b<S0P0T92@202DU9@808b<S0P0T92@203lo?`80NGUi0P2LW9`208n?
S`80Lg=c0P1[Jf/206m_K`80UYJF0P31`L420;:b/P80Zj^[0P2VYZH20:ZZZP80/K6a0P2e]KD20;bl
_080_kno0P38b<P20<c<c080clo?0P3<c<`20;Jf]P80H61P0`17AdL2055AD@80G5aL0P1OGel206MW
I`80KVi^0P1bLW8207]kN`80NWYj0P1lO7`208>3P`80Rh^;0P28R8P2092@T080TY:B0P2DU9@209VI
V@@0VYZJ0P2HV9P209NGU`80Ti>C0P2FUYH209jNWP80U9BD102KVi/209nOW`80VYZJ0P2MWId209ZJ
VP80UIFE0`2GUiL2096AT@80SXj>0P2BTY82096AT@80Ti>C0P2?Shl4092@T080Ti>C102BTY8209RH
V080UYJF0P2LW9`209fMW@80X:2P0P2QXJ440:RXZ080YjNW0P2SXj<40:BTY080W9bL0P2QXJ420:>S
X`80YjNW0P2PX:0209:BTP80QXJ60P23Ph<308F5Q@@0Q8B40P26QXH208Z:RP80Rh^;0P27QhL208B4
Q080Ogmo0P21PH4207alO080Ph>30P1lO7`20861P@80Q8B40P2>SXhY0<SPf080:b/[0P0/;2`202d]
;@80;Rh^0P0_;bl203<c<`80;Bd]0P0Z:RX203@d=080;Bd]0P0c<c<2038b<P80>3Ph0P0b<S8202h^
;P80<S8b0`0^;Rh202d];@80;2`/0P0];Bd201lO7`80820P0P0T92@202HV9P80:RXZ0P12@T8207al
O080W9bL0P2BTY8207=cL`80I6AT0P1iNGT208n?S`80^[Zj0P2i^KT20:n_[`80YJFU0P2^[Zh20;Bd
]080][Jf0P2l_;`20<;2`P80a<C40P3<c<`20=7Ad@80d=3@0P2RXZ8206IVIP<0CDe=0P1BDU8205UI
F@80HF5Q0P1UIFD2071`L080Lg=c0P1fMWH207UiN@80QHF50P27QhL208B4Q080SHf=0P2?Shl4096A
T@80VYZJ0P2KVi/209bLW080UiNG0P2HV9P209ZJVP80VIVI0P2HV9P209fMW@80VYZJ0P2KVi/209ZJ
VP@0W9bL0P2GUiL209JFUP<0U9BD0P2EUID208b<S080TI6A0P2CTi<209BDU0H0TY:B102FUYH209>C
T`80VYZJ102MWId20:2PX080WYjN0P2UYJD20:>SX`80YZJV0P2TY:@20:JVYP80Y:BT0P2UYJD209fM
W@80X:2P102TY:@20:6QX@80U9BD0P27QhL508B4Q080PH610P23Ph<208N7Q`80RHV90P2=SHd208J6
QP@0PH610P23Ph<207moO`@0P8200P22PX8208R8R080QhN77`38h=P001d0b>3H0P0Y:BT202`/;0@0
<30`0P0^;Rh402l_;`80;Bd]0P0[:b/202l_;`80<c<c0P0b<S82034a<@@0<30`0P0_;bl302d];@80
;2`/0P0[:b/202TY:@809bLW100V9RH2020P80809BDU0P0P820206=SH`80QHF50P2QXJ4208F5Q@80
IfMW0P1]KFd20861P@80Xj>S0P2o_kl20;2`/080WIfM0P2VYZH20;>c/`@0]KFe0P2k^k/20<30`080
a<C40P38b<P40=;BdP80Vi^K1@1LG5`204e=C@80EeMG0P1UIFD206e]K@80M7Ad0P1hN7P207]kN`80
P8200P24Q8@208N7Q`80RXZ:0P2>SXh209:BTP80Ti>C0P2DU9@209RHV080Vi^K0P2JVYX209VIV@80
UiNG1P2FUYH409NGU`80UYJF0P2EUID209>CT`80TY:B0P2CTi<309BDU080TI6A0P2>SXh2092@T080
Ti>C0P2ATI4208n?S`80SXj>0P2=SHd208j>SP@0Shn?0P2@T90209BDU080V9RH0P2IVIT209NGU`80
VYZJ0P2MWId209nOW`80XJ6Q0P2UYJD20:NWY`80XZ:R0P2LW9`209fMW@80X:2P102SXj<209NGU`80
RXZ:0P24Q8@30861P@80PX:20P24Q8@208J6QP@0R8R80P27QhL208J6QP80Ph>30P21PH4207moO`80
OWin0P1oOgl208:2PP80QXJ60P27QhLY0<SPf0809bLW0P0[:b/203@d=080;Rh^0P0];Bd202/[:`80
;Rh^0P0_;bl2030`<080;Bd]0P0^;Rh203Hf=P80;2`/0P0^;Rh202l_;`80:b/[0`0_;bl202XZ:P80
<30`0P0W9bL202PX:080:b/[0P0V9RH2024Q8@808R8R0P0X:2P2061PH080QHF50P2QXJ4208:2PP80
Jf][0P1WIfL207inOP80ZJVY0P30`<020:RXZ080XJ6Q0P2[Zj/20;:b/P80][Jf0P2g]kL20;Fe]@80
`L710P37alL20<W9b@@0b/[:0P2YZJT305mOG`80BTY:0P1FEUH205eMG@80Hf=S0P1]KFd407EeM@80
OGem0P1oOgl208>3P`80RXZ:0P28R8P208f=S@80Ti>C102DU9@209FEU@80Vi^K0P2IVIT409ZJVP80
UYJF0P2HV9P209JFUP80U9BD0P2GUiL209VIV@80UIFE0P2DU9@209>CT`80T92@0`2EUID2092@T080
Rh^;0P2DU9@209:BTP80Shn?0P2@T90208f=S@80SXj>0P2@T90208j>SP80Shn?0P2>SXh209JFUP80
UiNG0P2FUYH209NGU`80VYZJ0P2KVi/209fMW@80XJ6Q0P2SXj<20:FUY@80Y:BT0P2JVYX209fMW@80
XJ6Q0P2SXj<20:6QX@80V9RH0P2;Rh/70861P@80R8R80P24Q8@208Z:RP80R8R80P26QXH208N7Q`80
PH610P23Ph<207inOP80PX:20P1oOgl208:2PP80Ph>30P2<S8`Y0<SPf080:2PX0P0^;Rh2030`<080
;Bd]0P0_;bl202`/;0@0<30`0P0W9bL2034a<@80<S8b0P0_;bl2034a<@@0<30`0P0^;Rh302l_;`80
:BTY0P0];Bd202/[:`80:2PX0P0T92@202HV9P807alO0P0P8202028R8P80H61P0P27QhL20:>SX`80
P8200P1XJ6P2075aL@80OWin0P2RXZ820;fm_@80[Zj^0P2MWId20:ZZZP80/;2`0P2h^;P20;Fe]@80
^k^k0P2m_Kd20<W9b@80aLG50P3?cll20=7Ad@80W9bL0`1KFe/205iNGP80Cdm?0P1GEeL206MWI`80
Jf][0P1dM7@207EeM@80NGUi0P25QHD40861P@@0S8b<0P2FUYH2096AT@80Ti>C0P2GUiL409^KV`80
VIVI102GUiL209BDU080V9RH0P2FUYH209ZJVP80V9RH102DU9@209:BTP80Ti>C1@2BTY8208b<S080
TY:B0P2ATI4209BDU080T92@0P2<S8`208f=S@@0T92@0P2>SXh208n?S`80UIFE0P2FUYH209VIV@80
UiNG0P2KVi/409jNWP80X:2P102WYjL20:>SX`80W9bL0P2MWId20:6QX@80Xj>S0P2TY:@209FEU@80
SHf=0P22PX830861P@80P8200P24Q8@408R8R080Rh^;0P27QhL208B4Q0@0PX:2101oOgl207inOP80
PX:20P24Q8@208R8R1l0b>3H000M0<SPf080:BTY0P0/;2`4030`<080;Rh^100_;bl202d];@80:b/[
0P0_;bl203<c<`80<S8b0P0a<C44030`<080;bl_0`0];Bd202`/;080:b/[0P0Y:BT202LW9`@09RHV
0P0P820202DU9@80820P0P1SHf<208F5Q@80XJ6Q0P25QHD206MWI`80KFe]0P21PH420:>SX`80_kno
0P2`/;0209fMW@80YZJV0P2c/k<40;Fe]@80^k^k0P30`<020<C4a080b<S8103Bd]8209^KV`D0G5aL
0P1=CDd205MGE`80IFEU0P1]KFd207AdM080N7Qh0P1kNg/20820P080Q8B40P27QhL208Z:RP80SXj>
0P2BTY8209>CT`80U9BD0P2HV9P209^KV`80VYZJ0P2IVIT209NGU`H0UYJF102GUiL209JFUP80UIFE
0P2CTi<209:BTP80Ti>C0`2DU9@2096AT@80SXj>0P2@T90209>CT`80TI6A0P2?Shl208j>SP80SHf=
0P2>SXh408n?S`80T92@0P2DU9@209RHV080VIVI0P2GUiL209ZJVP80WIfM0P2OWil20:6QX@80YJFU
0P2WYjL20::RXP80W9bL0P2MWId20:2PX0@0Xj>S0P2GUiL208Z:RP80Q8B40`21PH4208:2PP80Q8B4
0P26QXH408R8R080QhN70P26QXH208>3P`80PH610P1oOgl207inOP80Ogmo0P22PX8208J6QP80QhN7
:@38h=P202LW9`80:b/[0P0d=3@202h^;P80;Bd]0P0[:b/202h^;P80;bl_0P0`<30202d];@80;Rh^
0P0f=SH202`/;080;Rh^0P0_;bl202/[:`<0;bl_0P0Z:RX2030`<0809bLW0P0X:2P202/[:`809RHV
0P0Q8B42028R8P80:2PX0P1PH60208F5Q@80XJ6Q0P22PX8206][J`80IfMW0P1nOWh20:VYZ@80`<30
0P2XZ:P20:6QX@80Zj^[0P2b/[820;Jf]P80]kNg0P2e]KD20<71`@80alO70P39bLT40<[:bP80ZJVY
0`1OGel204Y:BP80EUIF0P1MGEd206=SH`80KFe]101eMGD207emO@80Ogmo0P23Ph<208Z:RP80R8R8
0P2=SHd209>CT`@0U9BD0P2EUID209^KV`80VIVI102JVYX209JFUP80V9RH0P2FUYH209BDU080UiNG
0P2IVIT209FEU@80U9BD0P2CTi<2092@T0<0UIFE0P2@T90208^;R`80U9BD0P2BTY8208n?S`80T92@
0P2=SHd208j>SP80T92@0P2>SXh208n?S`80SXj>0P2FUYH209NGU`80UYJF0P2GUiL209ZJVP80Vi^K
0P2MWId20:6QX@80Xj>S0P2UYJD20:BTY080VYZJ0P2MWId20:6QX@80Xj>S0P2QXJ4209RHV080Rh^;
1`21PH4208R8R080Q8B40P2:RXX208R8R080QXJ60P27QhL20861P@80Ph>30P1nOWh208:2PP80Ogmo
0P22PX8208>3P`80S8b<:@38h=P202PX:080;Rh^0P0`<30202d];@80;bl_0P0/;2`4030`<0809bLW
0P0a<C42038b<P80;bl_0P0a<C44030`<080;Rh^0`0_;bl202TY:@80;Bd]0P0[:b/202PX:08092@T
0P0V9RH201lO7`80820P0P0R8R82061PH080QhN70P2SXj<20820P080J6QX0P1aLG4207inOP80XZ:R
0P2m_Kd20:j^[P80WIfM0P2ZZZX20;2`/080^;Rh0P2e]KD20;^k^`80_Kfm0P39bLT20<G5a@80clo?
0P3AdM4209bLW0<0Fe]K0P1NGUh204m?C`80EeMG0P1WIfL206][J`80M7Ad0P1eMGD207UiN@80QHF5
1021PH4408b<S080UYJF0P2ATI4209>CT`80UiNG102KVi/209VIV@@0UiNG0P2DU9@209RHV080UYJF
0P2JVYX209RHV0@0U9BD0P2BTY8209>CT`D0TY:B0P2<S8`209:BTP80TI6A0P2DU9@2092@T080S8b<
0P2=SHd4092@T080SXj>0P2?Shl209FEU@80UYJF0P2IVIT209NGU`80Vi^K102NWYh20:2PX0@0YjNW
0P2SXj<209bLW080WIfM0P2QXJ420:>SX`80Y:BT0P2EUID208f=S@80PX:20`21PH420820P080Q8B4
1028R8P208^;R`80QhN70P24Q8@408:2PP@0Ogmo0P1nOWh208:2PP80Q8B40P28R8PO0<SPf0007@38
h=P202/[:`80;Bd]0P0`<306034a<@80<30`0P0];Bd202`/;080;bl_0P0b<S82034a<@H0;bl_1@0`
<302034a<@80<30`0P0[:b/202LW9`809BDU0P0T92@201lO7`808B4Q0P0L71`204=3@`80L71`102I
VIT206i^KP80JVYZ0P1bLW8208F5Q@80_Kfm0P2^[Zh20:2PX080YZJV0P2_[jl20;6a/@80/k>c0P2f
][H20;^k^`80`L710P37alL20<g=c@80dM7A0P2n_[h30:6QX@80F5QH0P1JFUX205IFEP80F5QH0P1S
Hf<2071`L080MWIf0P1jNWX207moO`80Ph>30P25QHD208R8R080Rh^;0P2?Shl209:BTP80Ti>C102D
U9@209FEU@P0UYJF0P2EUID209BDU080TY:B102@T902096AT@80TY:B0P2EUID309JFUP80T92@0P29
RHT208f=S@80T92@0P2=SHd608R8R080QXJ60P29RHT208^;R`80SXj>0P2=SHd209>CT`80Ph>3102F
UYH209RHV080Vi^K0P2NWYh40:2PX080W9bL0P2HV9P409NGU`80VYZJ0P2LW9`209JFUP80SXj>0P23
Ph<307]kN`80OGem0P22PX8208F5Q@@0QhN70P25QHD208B4Q080Ph>30P21PH4207moO`80OWin0P1o
Ogl208B4Q080R8R80P29RHTY0<SPf080=3@d0P0Z:RX202`/;0@0=3@d0P0b<S82034a<@80;Rh^0P0X
:2P202h^;P80=cLg100c<c<202h^;P80=3@d0P0g=cL303@d=080;2`/100`<30202LW9`807QhN0P0Q
8B44020P80808b<S0P0l?3`207IfMP80VIVI0P2KVi/206i^KP80Hf=S0P1`L70208b<S080^KVi0P2Z
ZZX209nOW`80YjNW0P2`/;040;>c/`80/;2`0P2k^k/20<;2`P80b/[:0P39bLT20<_;b`80b<S80`2R
XZ8205eMG@80Cdm?0P1CDe<205aLG080Hf=S0P1aLG4207IfMP80NGUi0P24Q8@208>3P`80QXJ60P27
QhL208^;R`80S8b<0P2?Shl209>CT`80TY:B0P2GUiL209ZJVP80TY:B0P2FUYH209:BTP80UiNG0P2I
VIT2096AT@80Ti>C0P2ATI4208^;R`80Shn?0P2ATI4209BDU0D0UIFE0P2<S8`208Z:RP80U9BD0P2@
T90208f=S@80RHV90P28R8P208V9R@80Rh^;102=SHd209BDU080TI6A0P2<S8`409FEU@80Vi^K0P2I
VIT409nOW`80Y:BT0P2NWYh209ZJVP80U9BD0P2FUYH209VIV@@0W9bL0P2=SHd208>3P`<0NWYj0P1k
Ng/20861P@80Q8B40P26QXH208V9R@80QXJ60P22PX8208F5Q@80PH61101oOgl207emO@80Ph>30P25
QHD2092@T2T0b>3H0P0[:b/202l_;`80<C4a100b<S82030`<080;Bd]0P0`<30202LW9`80:b/[100c
<c<202d];@80;bl_0P0`<30202`/;0<0;Bd]0P0b<S8202d];@80;2`/0P0W9bL202PX:08092@T0P0Q
8B4202@T90806QXJ0P14A4@206m_K`80VYZJ0P2CTi<406e]K@80KVi^0P28R8P20;fm_@80ZJVY0P2Q
XJ420:RXZ080[Jf]0P2e]KD20:b/[080];Bd0P2l_;`20<;2`P80b<S80P3?cll20=KFeP80_Kfm0`2Q
XJ4205YJFP80E5AD0P1ADE4205QHF080Jf][0P1_Kfl207MgM`80N7Qh0P25QHD208>3P`@0QhN70P2;
Rh/208n?S`80SHf=102DU9@209:BTP80UYJF0P2DU9@209JFUP80UIFE0P2FUYH409>CT`@0T92@0P2>
SXh2096AT@80Ti>C0P2GUiL309RHV080T92@0P2:RXX2096AT@80Shn?0P2=SHd208R8R080QHF50P2;
Rh/208F5Q@80RHV90P26QXH208j>SP80T92@0P2CTi<208:2PP80U9BD0P2HV9P209FEU@80VYZJ0P2L
W9`20::RXP80WYjN0P2JVYX209NGU`80V9RH0P2FUYH209VIV@80WYjN0P2EUID208j>SP80PH610`1l
O7`207moO`80Ph>30P26QXH408B4Q080QhN70P23Ph<208J6QP80P820101oOgl20861P@80PX:20P2:
RXX208^;Ral0b>3H000M0<SPf080:b/[0P0];Bd2030`<0H0<C4a0P0`<30202d];@80;2`/0P0_;bl2
038b<P80<C4a1P0_;bl5030`<080<C4a0P0`<30202/[:`809bLW0P0U9BD202@T90807alO0P0Q8B42
01`L7080@d=30P1`L70409VIV@80KVi^0P1ZJVX2079bLP80QHF50P2m_Kd20:j^[P80X:2P0P2VYZH2
0:n_[`80/K6a0P2c/k<20;Jf]P80^k^k0P31`L420<O7a`80cLg=0P3AdM420;jn_P<0XJ6Q0P1HF5P2
05YJFP80EUIF0P1HF5P206=SH`80L71`0P1fMWH207YjNP80Ogmo0P23Ph<208F5Q@80R8R80P2;Rh/2
08n?S`80TY:B0P2CTi<409BDU080UIFE202FUYH209FEU@80U9BD0P2BTY84092@T080TI6A0P2BTY82
09FEU@<0UYJF0P2@T90208V9R@80SHf=0P2@T90208f=S@H0R8R80P26QXH208V9R@80Rh^;0P2>SXh2
08f=S@80Ti>C0P23Ph<409JFUP80V9RH0P2KVi/209jNWP@0X:2P0P2LW9`209RHV0@0UiNG0P2JVYX2
09bLW080UYJF0P2>SXh208>3P`<0Ng]k0P1mOGd208:2PP80QHF51027QhL208F5Q@80Q8B40P23Ph<2
0861P@80Ogmo0P1nOWh207moO`80Q8B40P28R8P208V9RBT0b>3H0P0d=3@202XZ:P80;2`/100d=3@2
038b<P80<C4a0P0^;Rh202PX:080;Rh^0P0g=cL403<c<`80;Rh^0P0d=3@203Lg=`<0=3@d0P0/;2`4
030`<0809bLW0P0N7Qh2024Q8@@0820P0P0S8b<203`l?080MWIf0P2IVIT209^KV`80KVi^0P1SHf<2
071`L080S8b<0P2i^KT20:ZZZP80WinO0P2WYjL20;2`/0@0/k>c0P2`/;020;^k^`80`/;20P3:b/X2
0<W9b@80bl_;0P38b<P30::RXP80GEeM0P1?Cdl205=CD`80G5aL0P1SHf<2075aL@80MWIf0P1iNGT2
08B4Q080Ph>30P26QXH208N7Q`80Rh^;0P2<S8`208n?S`80Ti>C0P2BTY8209NGU`80VYZJ0P2BTY82
09JFUP80TY:B0P2GUiL209VIV@80TI6A0P2CTi<2096AT@80Rh^;0P2?Shl2096AT@80U9BD1@2EUID2
08b<S080RXZ:0P2DU9@2092@T080SHf=0P29RHT208R8R080RHV90P2;Rh/408f=S@80U9BD0P2ATI42
08b<S0@0UIFE0P2KVi/209VIV@@0WinO0P2TY:@209jNWP80VYZJ0P2DU9@209JFUP80VIVI102LW9`2
08f=S@80Ph>30`1jNWX207]kN`80PH610P24Q8@208J6QP80RHV90P26QXH208:2PP80QHF50P21PH44
07moO`80OGem0P23Ph<208F5Q@80T92@:@38h=P202/[:`80;bl_0P0a<C44038b<P80<30`0P0];Bd2
030`<0809bLW0P0[:b/403<c<`80;Bd]0P0_;bl2030`<080;2`/0`0];Bd2038b<P80;Bd]0P0/;2`2
02LW9`80:2PX0P0T92@2024Q8@8092@T0P0J6QX204A4A080Kfm_0P2JVYX209>CT`@0KFe]0P1^KVh2
08R8R080_Kfm0P2YZJT20:6QX@80Z:RX0P2][Jd20;Fe]@80[:b/0P2d];@20;bl_080`/;20P38b<P2
0<o?c`80e]KF0P2m_Kd30:6QX@80FUYJ0P1DE5@2055AD@80F5QH0P1[Jf/206m_K`80MgMg0P1hN7P2
08F5Q@80Ph>31027QhL208^;R`80Shn?0P2=SHd409BDU080TY:B0P2FUYH209BDU080UYJF0P2EUID2
09JFUP@0Ti>C102@T90208j>SP80TI6A0P2CTi<209NGU`<0V9RH0P2@T90208Z:RP80TI6A0P2?Shl2
08f=S@80R8R80P25QHD208^;R`80QHF50P29RHT208J6QP80SXj>0P2@T90209>CT`80PX:20P2DU9@2
09RHV080UIFE0P2JVYX209bLW080XZ:R0P2NWYh209ZJVP80UiNG0P2HV9P209JFUP80VIVI0P2NWYh2
09FEU@80SXj>0P21PH4307alO080Ogmo0P23Ph<208J6QP@0Q8B40P27QhL208>3P`80QXJ60P20P804
07moO`80PH610P22PX8208Z:RP80Rh^;7`38h=P001d0b>3H100^;Rh202l_;`80<C4a0P0c<c<2038b
<P80<30`0P0^;Rh202`/;080;Rh^0P0a<C4202l_;`80;Bd]0P0^;Rh202l_;`80<C4a0`0d=3@203De
=@80=3@d0P0^;Rh202LW9`8092@T0P0R8R82020P80@07alO0P0W9bL205UIF@80QHF50P2UYJD207Ui
N@80Jf][0P1VIVH206][J`80/K6a0P2][Jd20:NWY`80Z:RX0P2ZZZX20:f][@80/K6a0P2c/k<20;Jf
]P80_[jn0P36a/H20<S8b080alO70P3>c/h30<G5a@80WIfM0P1DE5@205UIF@80CTi>0P1LG5`206][
J`80Lg=c0P1iNGT207inOP80PH610P23Ph<208F5Q@80R8R80P2<S8`2092@T080Ti>C0P2@T90208f=
S@80Shn?0P2BTY8209BDU080UIFE0P2FUYH209FEU@80TI6A0P2>SXh408b<S080Shn?0P2CTi<209NG
U`<0V9RH0P2?Shl208F5Q@80R8R80P2;Rh/208N7Q`80PX:21P20P80208B4Q080R8R80P2<S8`208R8
R080S8b<0P1`L70209BDU080TI6A0P2BTY8209NGU`80W9bL0P2KVi/209RHV080UiNG0P2FUYH209>C
T`80T92@0P2BTY8409BDU080Shn?0P22PX8307IfMP80NGUi0P20P80208>3P`80QXJ60P25QHD208>3
P`@0PX:20P21PH4407moO`80P8200P25QHD208^;R`80S8b<:@38h=P202d];@80:RXZ0P0/;2`2034a
<@80;bl_0P0d=3@203<c<`80:BTY0P0^;Rh203<c<`80<30`0P0^;Rh202l_;`80;2`/0P0_;bl203@d
=0<0=CDe0P0b<S8203Hf=P80;Bd]0P0V9RH202LW9`809RHV0P0L71`201hN7P808b<S0P0V9RH205UI
F@80QhN70P2QXJ420820P080Hf=S0P1VIVH207=cL`80Z:RX0P2h^;P40:>SX`80Z:RX0P2c/k<20:f]
[@80/[:b0P2e]KD20;fm_@80aLG50P38b<P20<_;b`80a/K60`34a<@209jNWP80FEUI101ADE42061P
H080Jf][0P1^KVh207]kN`80P8200P1nOWh208>3P`80QHF50P27QhL208j>SP80TY:B0P2EUID408f=
S@@0T92@0P2FUYH209BDU080UiNG0P2BTY8209BDU080Rh^;0P2?Shl208b<S080Shn?0P2CTi<209JF
UP<0UiNG0P2@T90208B4Q080Ph>30P2<S8`208V9R@80PX:20P1lO7`207inOP80Q8B40P1oOgl408R8
R0@0QHF50P1gMgL208b<S080UIFE0P2>SXh2092@T080X:2P102IVIT609JFUP@0TI6A0P2FUYH209FE
U@80Shn?0P23Ph<307MgM`80NWYj0P20P8020861P@80R8R80P24Q8@208F5Q@80OWin1023Ph<20820
P080OGem0P20P80208J6QP80RHV90P2ATI4Y0<SPf080<S8b100];Bd203<c<`@0<S8b0P0_;bl203<c
<`80:RXZ0P0a<C4202h^;P80<S8b0P0];Bd202`/;080;bl_1@0c<c<403De=@80:b/[0P0Y:BT202<S
8`809BDU1P0N7Qh202DU9@80FEUI0P28R8P20:BTY080N7Qh0P1dM7@206EUI@80IVIV0P2d];@20:^[
Z`80YJFU0P2/[:`20:VYZ@80/;2`0P2a/K420;Ng]`80]KFe0P2o_kl20<O7a`80a<C40P38b<P20<c<
c0<0aLG50P2OWil205UIF@80EEEE0P1>CTh2061PH080JFUY0P1bLW8207QhN080Ogmo0P20P80208:2
PP80Ph>3102:RXX209BDU080Ti>C0P2<S8`208f=S@H0TI6A102FUYH209FEU@80T92@0P2=SHd208n?
S`80SHf=0P2@T90209>CT`D0UiNG0P2>SXh208J6QP80QhN70P2<S8`208R8R080Ph>30P20P8020861
P@80Ogmo1028R8P208f=S@80R8R80P2;Rh/2079bLP80U9BD0P2BTY82096AT@@0VIVI0P2MWId209VI
V@80UIFE0P2HV9P2092@T0@0TY:B0P2EUID209:BTP80Shn?0P24Q8@307EeM@80N7Qh0P1nOWh208N7
Q`80Q8B40P25QHD208>3P`80P8200P22PX8208>3P`80PH610P1lO7`20861P@80QHF50P2<S8`208V9
RAl0b>3H000M0<SPf0@0;Rh^0P0_;bl2034a<@80<c<c0P0b<S82030`<080;Rh^0P0/;2`202h^;P80
<C4a0P0_;bl202d];@80;Rh^0P0_;bl2034a<@<0=3@d0P0e=CD203@d=080;Rh^0P0W9bL202@T9080
8R8R0P0P820401lO7`809bLW0P1IFET208F5Q@80YJFU0P1iNGT206][J`80IVIV0P1[Jf/20;6a/@80
[Jf]0P2WYjL20:RXZ080ZZZZ0P2][Jd20;6a/@80/k>c0P2f][H20;jn_P80a/K60P38b<P20<O7a`80
c/k>0`35aLD209fMW@80E5AD0P1IFET204i>CP80G5aL0P1[Jf/207=cL`80NGUi0P1nOWh20861P@80
Ph>30P25QHD208R8R080S8b<0P2@T90209>CT`80T92@0P2=SHd208n?S`80TY:B0P2DU9@209FEU@80
UYJF0P2EUID2096AT@80SXj>102<S8`208n?S`80Ti>C0P2GUiL309RHV080Shn?0P25QHD208R8R080
Rh^;0P27QhL208:2PPH0P8200P24Q8@208R8R080S8b<0P28R8P208b<S080L71`0P2DU9@2096AT@80
TY:B0P2GUiL209bLW080Vi^K0P2HV9P209NGU`80UYJF0P2CTi<2092@T080TY:B102DU9@208n?S`80
PX:20`1fMWH207UiN@80P8200P23Ph<208J6QP80QHF50P23Ph<408:2PP80PH61101oOgl20820P080
QHF50P2;Rh/208b<S2T0b>3H0P0];Bd202XZ:P80;2`/0P0a<C4202l_;`80=3@d0P0c<c<202TY:@80
;Rh^0P0c<c<2030`<080;Rh^0P0_;bl202`/;080;bl_0P0d=3@303De=@80<S8b0P0f=SH202d];@80
9RHV0P0W9bL202HV9P8071`L0P0N7Qh202<S8`809RHV0P1IFET208N7Q`80XJ6Q0P20P80206=SH`80
IVIV0P1cLg<20:RXZ080^;Rh102SXj<20:RXZ080/k>c0P2][Jd20;:b/P80]KFe0P2m_Kd20<G5a@80
b<S80P3;bl/20<K6aP<0a<C40P2NWYh205UIF@@0DE5A0P1PH60206][J`80KVi^0P1kNg/20820P080
OWin0P23Ph<208F5Q@80QhN70P2>SXh209:BTP80UIFE102=SHd4092@T080UYJF0P2DU9@209NGU`80
TY:B0P2DU9@208^;R`80Shn?0P2<S8`208n?S`80Ti>C0P2FUYH309NGU`80T92@0P24Q8@208>3P`80
S8b<0P29RHT208:2PP80O7al0P1nOWh208B4Q080Ogmo1028R8P408F5Q@80MgMg0P2<S8`209FEU@80
SXj>0P2@T9020:2PX0@0VIVI1P2FUYH4096AT@80UYJF0P2EUID208n?S`80Ph>30`1gMgL207YjNP80
P8200P21PH4208R8R080Q8B40P25QHD207inOP@0Ph>30P20P80207emO@80P8200P26QXH208V9R@80
TI6A:@38h=P2038b<P@0;Bd]0P0c<c<4038b<P80;bl_0P0c<c<202XZ:P80<C4a0P0^;Rh2038b<P80
;Bd]0P0/;2`202l_;`D0<c<c100e=CD202/[:`80:BTY0P0S8b<202DU9@H07QhN0P0U9BD205UIF@80
R8R80P2TY:@207QhN080M7Ad0P1UIFD206IVIP80];Bd0P2[Zj/20:FUY@80[:b/0P2YZJT20;2`/080
/K6a0P2g]kL20;Fe]@80_kno0P37alL20<C4a080b<S80P3<c<`30<G5a@80WinO0P1IFET205EEE@80
CTi>0P1PH60206UYJ@80LW9b0P1hN7P207moO`80P8200P22PX8208>3P`@0RXZ:0P2DU9@209>CT`80
S8b<0P2=SHd6096AT@@0UYJF0P2EUID2092@T080SHf=0P2?Shl208f=S@80T92@0P2CTi<509NGU`80
SXj>0P26QXH208N7Q`80S8b<0P28R8P208>3P`80P8200P21PH4207moO`@0R8R80P2=SHd208R8R080
Rh^;0P1bLW8209BDU080TY:B0P2ATI4409VIV@80WIfM0P2IVIT209FEU@80V9RH0P2@T90409:BTP80
UIFE0P2BTY8208n?S`80Q8B40`1eMGD207QhN080OWin0P27QhL208B4Q080QHF50P23Ph<20820P080
PX:20P23Ph<20861P@80O7al0P21PH4208F5Q@80S8b<0P29RHTO0<SPf0007@38h=P202/[:`80;Bd]
1P0_;bl202h^;P80;Bd]100/;2`202l_;`80<C4a0P0_;bl202`/;080;Bd]0P0`<30203<c<`D0=CDe
0P0c<c<202`/;0809RHV100U9BD202<S8`808B4Q0P0N7Qh201lO7`80@4100P1TI6@209>CT`80Shn?
0P1cLg<205iNGP80IVIV0P2CTi<20;Ng]`80/k>c0P2/[:`20:6QX@80YjNW0P2`/;020;>c/`80]KFe
0P2l_;`20<?3``80a/K60P38b<P20<g=c@<0b/[:0P2i^KT209bLW080EEEE101JFUX206MWI`80Kfm_
0P1hN7P207alO080P8200P23Ph<208J6QP80R8R80P2;Rh/208j>SP80T92@0P2>SXh208b<S080SXj>
0P2@T90209:BTP80Ti>C0P2BTY82096AT@80T92@0P2?Shl408j>SP80T92@0P2CTi<209FEU@<0U9BD
0P2:RXX20820P080Ogmo0P20P8020861P@80Ogmo0P1dM7@206YZJP80Q8B40P1oOgl208J6QP80QHF5
0P2>SXh207MgM`80Kfm_0P28R8P20820P080Ng]k0P2<S8`209fMW@80VYZJ0P2CTi<209RHV080WIfM
0P2KVi/209RHV080UIFE0P2CTi<208j>SP80R8R80P1nOWh307IfMP80N7Qh0P1lO7`20861P@@0Q8B4
0P23Ph<408:2PP@0PH610P1oOgl20820P080QhN70P2?Shl2092@T2T0b>3H0P0^;Rh2034a<@80<c<c
0P14A4@402TY:@80:b/[100_;bl202h^;P80;Bd]0P0^;Rh202XZ:P@0;2`/0P0`<303038b<P80=SHf
0P0d=3@202d];@80:2PX0P0U9BD202HV9P808b<S100R8R8202<S8`80<S8b0P1[Jf/208f=S@80UIFE
0P1^KVh2069RHP80JFUY0P2@T9020;^k^`80]kNg0P2RXZ820:6QX@80/;2`0P2][Jd20;Jf]P80^;Rh
0P2l_;`40<C4a080bl_;0P39bLT50<G5a@80VYZJ0P1IFET2055AD@80GemO0P1VIVH206i^KP80MWIf
0P1lO7`20861P@80PX:20P29RHT208F5Q@80S8b<0P2=SHd209>CT`80QHF50P2=SHd208^;R`80TI6A
0P2DU9@209>CT`80TY:B0P2>SXh209:BTP80SHf=0P2ATI44092@T080UYJF0P2EUID309BDU080SXj>
0P23Ph<207MgM`@0PH610P1kNg/2075aL@80KVi^0P26QXH207moO`80R8R80P2:RXX208n?S`80Ng]k
0P1/K6`208J6QP80RXZ:0P21PH4208J6QP80YZJV102BTY8209NGU`80VIVI0P2GUiL209VIV@80TY:B
102>SXh208B4Q080Ogmo0`1eMGD207UiN@80Ogmo1023Ph<408B4Q080Ogmo0P21PH4208>3P`80OWin
0P1oOgl208:2PP80R8R80P2:RXX2096ATBT0b>3H0P0V9RH202XZ:P80;bl_0P0c<c<202d];@809RHV
0P0_;bl202h^;P80;Bd]0P0_;bl2030`<080<c<c0P0^;Rh202PX:080<30`0P0i>CT303Lg=`80=3@d
0P0h>3P202TY:@809BDU0P0S8b<2020P80809RHV0P0Q8B4201dM7@8092@T0P12@T8206ATI080Shn?
0P2;Rh/207QhN080FUYJ0P1XJ6P209BDU080]kNg0P2e]KD20:f][@80WYjN0P2OWil20;:b/P80/K6a
0P2b/[820<30`080_kno0P34a<@20<[:bP80bl_;0`3=cLd20;Jf]P80W9bL0P1DE5@205]KF`80EUIF
0P1VIVH206m_K`80NGUi0P1jNWX207moO`80PH611P2:RXX208n?S`@0SXj>0P2;Rh/208j>SP@0TY:B
0P2CTi<209BDU080TI6A0P2DU9@2092@T080Shn?0P2<S8`208n?S`80TY:B1@2FUYH208V9R@80PH61
0P1jNWX20820P080PH610P1mOGd207AdM080K6a/0P22PX8207inOP80QHF50P26QXH208f=S@80MgMg
0P1^KVh208N7Q`80Ogmo0P1kNg/208j>SP80WYjN0P2IVIT209FEU@80U9BD102OWil209NGU`80U9BD
0P2BTY8208n?S`80R8R80P20P80307EeM@80Ng]k0P1hN7P408B4Q080R8R80P22PX820861P@80OWin
0P27QhL207inOP80O7al0P20P80208N7Q`80SXj>0P2?ShlO0<SPf0007@38h=P202/[:`80;Bd]1P0_
;bl202h^;P80;Bd]100/;2`202l_;`80<C4a0P0_;bl202`/;080;Bd]0P0`<30203<c<`D0=CDe0P0c
<c<202`/;0809RHV100U9BD202<S8`808B4Q0P0N7Qh201lO7`80@4100P1TI6@209>CT`80Shn?0P1c
Lg<205iNGP80IVIV0P2CTi<20;Ng]`80/k>c0P2/[:`20:6QX@80YjNW0P2`/;020;>c/`80]KFe0P2l
_;`20<?3``80a/K60P38b<P20<g=c@<0b/[:0P2i^KT209bLW080EEEE101JFUX206MWI`80Kfm_0P1h
N7P207alO080P8200P23Ph<208J6QP80R8R80P2;Rh/208j>SP80T92@0P2>SXh208b<S080SXj>0P2@
T90209:BTP80Ti>C0P2BTY82096AT@80T92@0P2?Shl408j>SP80T92@0P2CTi<209FEU@<0U9BD0P2:
RXX20820P080Ogmo0P20P8020861P@80Ogmo0P1dM7@206YZJP80Q8B40P1oOgl208J6QP80QHF50P2>
SXh207MgM`80Kfm_0P28R8P20820P080Ng]k0P2<S8`209fMW@80VYZJ0P2CTi<209RHV080WIfM0P2K
Vi/209RHV080UIFE0P2CTi<208j>SP80R8R80P1nOWh307IfMP80N7Qh0P1lO7`20861P@@0Q8B40P23
Ph<408:2PP@0PH610P1oOgl20820P080QhN70P2?Shl2092@T2T0b>3H0P0^;Rh2034a<@80<c<c0P14
A4@402TY:@80:b/[100_;bl202h^;P80;Bd]0P0^;Rh202XZ:P@0;2`/0P0`<303038b<P80=SHf0P0d
=3@202d];@80:2PX0P0U9BD202HV9P808b<S100R8R8202<S8`80<S8b0P1[Jf/208f=S@80UIFE0P1^
KVh2069RHP80JFUY0P2@T9020;^k^`80]kNg0P2RXZ820:6QX@80/;2`0P2][Jd20;Jf]P80^;Rh0P2l
_;`40<C4a080bl_;0P39bLT50<G5a@80VYZJ0P1IFET2055AD@80GemO0P1VIVH206i^KP80MWIf0P1l
O7`20861P@80PX:20P29RHT208F5Q@80S8b<0P2=SHd209>CT`80QHF50P2=SHd208^;R`80TI6A0P2D
U9@209>CT`80TY:B0P2>SXh209:BTP80SHf=0P2ATI44092@T080UYJF0P2EUID309BDU080SXj>0P23
Ph<207MgM`@0PH610P1kNg/2075aL@80KVi^0P26QXH207moO`80R8R80P2:RXX208n?S`80Ng]k0P1/
K6`208J6QP80RXZ:0P21PH4208J6QP80YZJV102BTY8209NGU`80VIVI0P2GUiL209VIV@80TY:B102>
SXh208B4Q080Ogmo0`1eMGD207UiN@80Ogmo1023Ph<408B4Q080Ogmo0P21PH4208>3P`80OWin0P1o
Ogl208:2PP80R8R80P2:RXX2096ATBT0b>3H0P0V9RH202XZ:P80;bl_0P0c<c<202d];@809RHV0P0_
;bl202h^;P80;Bd]0P0_;bl2030`<080<c<c0P0^;Rh202PX:080<30`0P0i>CT303Lg=`80=3@d0P0h
>3P202TY:@809BDU0P0S8b<2020P80809RHV0P0Q8B4201dM7@8092@T0P12@T8206ATI080Shn?0P2;
Rh/207QhN080FUYJ0P1XJ6P209BDU080]kNg0P2e]KD20:f][@80WYjN0P2OWil20;:b/P80/K6a0P2b
/[820<30`080_kno0P34a<@20<[:bP80bl_;0`3=cLd20;Jf]P80W9bL0P1DE5@205]KF`80EUIF0P1V
IVH206m_K`80NGUi0P1jNWX207moO`80PH611P2:RXX208n?S`@0SXj>0P2;Rh/208j>SP@0TY:B0P2C
Ti<209BDU080TI6A0P2DU9@2092@T080Shn?0P2<S8`208n?S`80TY:B1@2FUYH208V9R@80PH610P1j
NWX20820P080PH610P1mOGd207AdM080K6a/0P22PX8207inOP80QHF50P26QXH208f=S@80MgMg0P1^
KVh208N7Q`80Ogmo0P1kNg/208j>SP80WYjN0P2IVIT209FEU@80U9BD102OWil209NGU`80U9BD0P2B
TY8208n?S`80R8R80P20P80307EeM@80Ng]k0P1hN7P408B4Q080R8R80P22PX820861P@80OWin0P27
QhL207inOP80O7al0P20P80208N7Q`80SXj>0P2?ShlO0<SPf0007@38h=P202PX:080;2`/0P0_;bl2
02d];@P0:b/[0P0/;2`202l_;`80<S8b0P0_;bl202`/;080;Bd]0P0`<30203<c<`<0=SHf0P0d=3@2
034a<@80:b/[100V9RH202LW9`809BDU0P0S8b<401hN7P80;2`/0P13@d<207IfMP80WYjN0P20P802
05iNGP80IVIV0P1dM7@20;bl_080_Kfm0P2b/[8209fMW@80Y:BT0P2_[jl20;:b/P80]KFe0P2j^[X2
0<30`080aLG50P39bLT20<S8b0<0aLG50P39bLT20<;2`P80Vi^K0P1FEUH205QHF080IVIV0P1]KFd2
07EeM@80NWYj0P1nOWh208>3P`80QhN70P28R8P208V9R@80Rh^;1P2<S8`208f=S@80Shn?0P2@T902
096AT@80Shn?0P2>SXh2092@T080TY:B0P2ATI44092@T080Shn?0P2@T90308j>SP80QHF50P1kNg/2
07IfMP80M7Ad0P1jNWX207emO@80Jf][0P1HF5P208R8R080O7al0P25QHD20861P@80UYJF0P1/K6`2
07]kN`80Ph>30P1gMgL206e]K@80QXJ60P2OWil209^KV`80Ti>C0P2LW9`20:FUY@80YZJV0P2RXZ82
09bLW080U9BD0P2:RXX208:2PP80O7al1@1hN7P207YjNP80OWin0P22PX8408>3P`80PX:20P21PH44
08:2PP@0P8200P29RHT209:BTP80U9BD:@38h=P202PX:080:b/[0P0];Bd202HV9P80;Bd]0P0Y:BT2
02d];@@0;2`/0P0`<30403@d=080:b/[0P0Z:RX202l_;`80>CTi0`0h>3P202l_;`80<30`0P0/;2`2
02<S8`809bLW0P0V9RH402<S8`808R8R0P0Q8B4202HV9P80ATI60P1lO7`209VIV@80P8200P1RHV82
05aLG080Ogmo0P2c/k<20<?3``80[Jf]0P2OWil20:VYZ@80ZZZZ102c/k<20;Rh^080`L710P32`/82
0<S8b080b/[:0`35aLD20<O7a`80`L710P2FUYH205UIF@80De=C0P1YJFT206a/K080M7Ad101nOWh2
08>3P`80R8R80P25QHD208Z:RP@0SHf=0P2:RXX408j>SP80T92@102?Shl2096AT@80SXj>0P2<S8`2
096AT@80UIFE0P2?Shl208b<S080T92@0P2=SHd308j>SP80QHF50P21PH4206e]K@80MgMg0P20P802
07YjNP80KVi^0P1LG5`40820P080RHV90P26QXH208^;R`80LG5a0P1^KVh20820P080Ng]k0P1VIVH2
07emO@80YZJV0P2HV9P209>CT`80W9bL0P2UYJD20::RXP80Xj>S0P2IVIT209NGU`80RXZ:0P23Ph<2
07inOP<0NWYj0P1gMgL207YjNP80O7al0P22PX8408B4Q080OGem0P23Ph<20820P080PH610P20P802
07inOP80RXZ:0P2DU9@209FEUBT0b>3H0P0V9RH402l_;`80:b/[0P0/;2`202h^;P80:b/[0P0_;bl2
02`/;080;Rh^0P0b<S82034a<@80:RXZ0P0X:2P2038b<P80<C4a0`0h>3P203De=@80<30`0P0Y:BT2
02HV9P80:RXZ0P0V9RH202TY:@808R8R0P0H61P2020P8080;2`/0P14A4@207MgM`80W9bL0P25QHD2
05mOG`80Hf=S0P1dM7@20;fm_@80^k^k0P2`/;020:>SX`80X:2P0P2f][H20:b/[080]KFe0P32`/82
0;no_`80`/;20P38b<P20<W9b@<0aLG50P34a<@20<G5a@80VYZJ0P1HF5P205IFEP80IVIV0P1/K6`2
07EeM@80NWYj0P1oOgl208J6QP80R8R80P24Q8@408b<S080RXZ:0P2CTi<208R8R080S8b<0P2=SHd2
09:BTP@0Shn?0P2:RXX2096AT@80Shn?0P2DU9@2092@T080S8b<102?Shl308j>SP80QHF50P1nOWh2
07MgM`80MGEe0P1jNWX207]kN`80Kfm_0P1GEeL208J6QP80OWin0P2<S8`207moO`80Ti>C0P1_Kfl2
07IfMP80R8R80P1dM7@2079bLP80QhN70P2NWYh209bLW080Ti>C0P2JVYX20:JVYP80ZJVY0P2QXJ42
09ZJVP80Ti>C0P2<S8`20861P@80O7al0`1gMgL207QhN080Ng]k0P21PH4208:2PP80Ogmo0P22PX82
08F5Q@80P8200P27QhL208F5Q@80OGem0P20P80208V9R@80Ti>C0P2GUiLO0<SPf0007@38h=P202PX
:080;2`/0P0_;bl202d];@P0:b/[0P0/;2`202l_;`80<S8b0P0_;bl202`/;080;Bd]0P0`<30203<c
<`<0=SHf0P0d=3@2034a<@80:b/[100V9RH202LW9`809BDU0P0S8b<401hN7P80;2`/0P13@d<207If
MP80WYjN0P20P80205iNGP80IVIV0P1dM7@20;bl_080_Kfm0P2b/[8209fMW@80Y:BT0P2_[jl20;:b
/P80]KFe0P2j^[X20<30`080aLG50P39bLT20<S8b0<0aLG50P39bLT20<;2`P80Vi^K0P1FEUH205QH
F080IVIV0P1]KFd207EeM@80NWYj0P1nOWh208>3P`80QhN70P28R8P208V9R@80Rh^;1P2<S8`208f=
S@80Shn?0P2@T902096AT@80Shn?0P2>SXh2092@T080TY:B0P2ATI44092@T080Shn?0P2@T90308j>
SP80QHF50P1kNg/207IfMP80M7Ad0P1jNWX207emO@80Jf][0P1HF5P208R8R080O7al0P25QHD20861
P@80UYJF0P1/K6`207]kN`80Ph>30P1gMgL206e]K@80QXJ60P2OWil209^KV`80Ti>C0P2LW9`20:FU
Y@80YZJV0P2RXZ8209bLW080U9BD0P2:RXX208:2PP80O7al1@1hN7P207YjNP80OWin0P22PX8408>3
P`80PX:20P21PH4408:2PP@0P8200P29RHT209:BTP80U9BD:@38h=P202PX:080:b/[0P0];Bd202HV
9P80;Bd]0P0Y:BT202d];@@0;2`/0P0`<30403@d=080:b/[0P0Z:RX202l_;`80>CTi0`0h>3P202l_
;`80<30`0P0/;2`202<S8`809bLW0P0V9RH402<S8`808R8R0P0Q8B4202HV9P80ATI60P1lO7`209VI
V@80P8200P1RHV8205aLG080Ogmo0P2c/k<20<?3``80[Jf]0P2OWil20:VYZ@80ZZZZ102c/k<20;Rh
^080`L710P32`/820<S8b080b/[:0`35aLD20<O7a`80`L710P2FUYH205UIF@80De=C0P1YJFT206a/
K080M7Ad101nOWh208>3P`80R8R80P25QHD208Z:RP@0SHf=0P2:RXX408j>SP80T92@102?Shl2096A
T@80SXj>0P2<S8`2096AT@80UIFE0P2?Shl208b<S080T92@0P2=SHd308j>SP80QHF50P21PH4206e]
K@80MgMg0P20P80207YjNP80KVi^0P1LG5`40820P080RHV90P26QXH208^;R`80LG5a0P1^KVh20820
P080Ng]k0P1VIVH207emO@80YZJV0P2HV9P209>CT`80W9bL0P2UYJD20::RXP80Xj>S0P2IVIT209NG
U`80RXZ:0P23Ph<207inOP<0NWYj0P1gMgL207YjNP80O7al0P22PX8408B4Q080OGem0P23Ph<20820
P080PH610P20P80207inOP80RXZ:0P2DU9@209FEUBT0b>3H0P0V9RH402l_;`80:b/[0P0/;2`202h^
;P80:b/[0P0_;bl202`/;080;Rh^0P0b<S82034a<@80:RXZ0P0X:2P2038b<P80<C4a0`0h>3P203De
=@80<30`0P0Y:BT202HV9P80:RXZ0P0V9RH202TY:@808R8R0P0H61P2020P8080;2`/0P14A4@207Mg
M`80W9bL0P25QHD205mOG`80Hf=S0P1dM7@20;fm_@80^k^k0P2`/;020:>SX`80X:2P0P2f][H20:b/
[080]KFe0P32`/820;no_`80`/;20P38b<P20<W9b@<0aLG50P34a<@20<G5a@80VYZJ0P1HF5P205IF
EP80IVIV0P1/K6`207EeM@80NWYj0P1oOgl208J6QP80R8R80P24Q8@408b<S080RXZ:0P2CTi<208R8
R080S8b<0P2=SHd209:BTP@0Shn?0P2:RXX2096AT@80Shn?0P2DU9@2092@T080S8b<102?Shl308j>
SP80QHF50P1nOWh207MgM`80MGEe0P1jNWX207]kN`80Kfm_0P1GEeL208J6QP80OWin0P2<S8`207mo
O`80Ti>C0P1_Kfl207IfMP80R8R80P1dM7@2079bLP80QhN70P2NWYh209bLW080Ti>C0P2JVYX20:JV
YP80ZJVY0P2QXJ4209ZJVP80Ti>C0P2<S8`20861P@80O7al0`1gMgL207QhN080Ng]k0P21PH4208:2
PP80Ogmo0P22PX8208F5Q@80P8200P27QhL208F5Q@80OGem0P20P80208V9R@80Ti>C0P2GUiLO0<SP
f0007@38h=P802XZ:P80:b/[0P0/;2`402d];@80;Rh^0P0_;bl2030`<080;Rh^100/;2`202d];@80
<30`1@0c<c<2034a<@80;bl_0P0/;2`202PX:0H09BDU0P0Q8B42020P80808R8R0P0`<302055AD@80
T92@0P2GUiL207=cL`80EeMG0P1VIVH20:BTY080`<300P2j^[X20:VYZ@80Z:RX0P2YZJT20:j^[P80
];Bd0P2i^KT20;fm_@80`l?30P37alL20<W9b@<0b<S80P3;bl/20<W9b@80/[:b0P2=SHd2071`L080
G5aL0P1RHV8206m_K`80MWIf0P1lO7`20820P080Ph>30P25QHD208J6QP80QhN70P28R8P408N7Q`80
Rh^;0P2?Shl4092@T080Shn?0P2>SXh2092@T080TY:B0P2?Shl208b<S080QhN70P23Ph<208N7Q`<0
RHV90P24Q8@207alO080LG5a0P1YJFT2079bLP80NWYj0P1YJFT205YJFP80O7al0P20P80208Z:RP80
QhN70P23Ph<205eMG@80K6a/0P1fMWH206QXJ080GUiN0P20P8020:>SX`80YJFU0P2QXJ420:JVYP80
[:b/0P2][Jd20:^[Z`80YJFU0P2LW9`2096AT@80QhN70P1oOgl307]kN`80NWYj101lO7`207emO@80
Ogmo0P21PH440820P080PH610P23Ph<20861P@80PX:20P2:RXX209>CT`80U9BD:@38h=P202`/;080
9RHV0P0Z:RX202d];@80;Rh^0P0[:b/2030`<080;bl_0P0[:b/202d];@80;Rh^0P0a<C4202l_;`@0
<30`0P0c<c<3038b<P80>CTi0P0c<c<202h^;P80:b/[0P0a<C4202@T90809RHV0P0R8R8202<S8`@0
820P0P0Z:RX205iNGP80RHV90P2LW9`206m_K`80FEUI0P1WIfL209bLW080`<300P32`/820::RXP80
Y:BT0P2XZ:P20:n_[`80/;2`0P2k^k/20;fm_@80`/;20P38b<P20<k>cP<0a/K60P35aLD20<K6aP80
`/;20P2FUYH4061PH080JFUY0P1^KVh207IfMP80N7Qh0P1oOgl208F5Q@80Ph>30P26QXH208^;R`80
Q8B40P27QhL408V9R@80Shn?0P2=SHd209:BTP80TI6A0P2@T90208n?S`@0TY:B0P29RHT208J6QP80
Q8B40P28R8P308Z:RP80Ph>30P1jNWX206e]K@80J6QX0P1gMgL207emO@80I6AT0P1IFET207IfMP80
PH610P22PX8208B4Q080Ogmo0P1YJFT206YZJP80P8200P1cLg<206EUI@80Ogmo0P2OWil20:>SX`80
Z:RX0P2WYjL20;>c/`@0[jn_0P2XZ:P209jNWP80T92@0P28R8P207emO@<0MgMg0P1mOGd207QhN080
OWin0P1lO7`40861P@80PX:20P23Ph<208B4Q080QhN70P22PX820861P@80RXZ:0P2?Shl209JFURT0
b>3H0P0];Bd202l_;`809bLW100Z:RX202h^;P80:b/[0P0Y:BT202`/;080;Rh^0P0`<30202d];@80
<C4a0P0_;bl202d];@80<C4a0`0/;2`203<c<`80<C4a100];Bd402HV9P808b<S0P0X:2P2024Q8@@0
7alO0P0b<S82059BDP80TI6A0P2BTY82075aL@80F5QH0P1VIVH20:6QX@80`/;20P2o_kl40:VYZ@80
Z:RX0P2^[Zh20;Bd]080^[Zj0P2k^k/20<O7a`80b<S80P3<c<`30<W9b@80cLg=0P3;bl/20;>c/`80
SXj>0P1aLG42069RHP80Hf=S0P1_Kfl207UiN@80Ogmo0P1hN7P208>3P`80QhN70P25QHD408>3P`80
S8b<0P26QXH208^;R`80T92@0P2ATI4209>CT`80RXZ:0P2BTY8209BDU080Shn?0P2>SXh208^;R`80
Shn?0P23Ph<208Z:RP<0Rh^;0P1lO7`207emO@80KVi^0P1YJFT207=cL`80O7al0P1/K6`205YJFP80
N7Qh0P1nOWh408N7Q`80Ph>30P1OGel206a/K080NGUi0P1SHf<205]KF`80N7Qh0P2SXj<20:^[Z`80
X:2P0P2TY:@20:RXZ080[Jf]0P2[Zj/20:FUY@80WIfM0P2BTY8208B4Q080Ph>30`1jNWX207]kN`80
NGUi0P1hN7P207]kN`80PH610P23Ph<407inOP80PH610P1mOGd20820P080QXJ60P2:RXX208j>SP80
UIFE7`38h=P001d0b>3H200Z:RX202/[:`80;2`/100];Bd202h^;P80;bl_0P0`<30202h^;P@0;2`/
0P0];Bd2030`<0D0<c<c0P0a<C4202l_;`80;2`/0P0X:2P602DU9@808B4Q0P0P8202028R8P80<30`
0P1ADE42092@T080UiNG0P1cLg<205MGE`80IVIV0P2TY:@20<30`080^[Zj0P2YZJT20:RXZ080ZJVY
0P2^[Zh20;Bd]080^KVi0P2m_Kd20<?3``80alO70P39bLT30<S8b080bl_;0P39bLT20;:b/P80SHf=
0P1`L70205aLG080HV9R0P1_Kfl207IfMP80O7al0P20P80208>3P`80QHF50P26QXH208N7Q`80R8R8
1027QhL208^;R`80Shn?102@T90208n?S`80SXj>0P2@T90209:BTP80Shn?0P2<S8`208N7Q`80Ph>3
0P27QhL308V9R@80Q8B40P1lO7`2075aL@80JFUY0P1bLW8207YjNP80JFUY0P1JFUX207alO080P820
0P2:RXX208N7Q`80Ph>30P1MGEd206a/K080MWIf0P1XJ6P205iNGP80P8200P2SXj<20:FUY@80XJ6Q
0P2VYZH20:b/[080[Jf]0P2[Zj/20:FUY@80W9bL0P2ATI4208N7Q`80Ogmo0`1kNg/207YjNP@0O7al
0P1mOGd207moO`80PH611020P8020861P@80Ph>30P21PH4208:2PP80RXZ:0P2CTi<209BDU2T0b>3H
0P0/;2`202HV9P80:RXZ0P0];Bd202h^;P80:b/[0P0`<30202l_;`80:b/[0P0];Bd202h^;P80<C4a
0P0_;bl4030`<080<c<c0`0b<S8203Ti>@80<c<c0P0^;Rh202/[:`80<C4a0P0T92@202HV9P808R8R
0P0S8b<4020P8080:RXZ0P1NGUh208V9R@80W9bL0P1_Kfl205UIF@80IfMW0P2LW9`20<30`080`/;2
0P2RXZ820:BTY080Z:RX0P2_[jl20;2`/080^k^k0P2m_Kd20<;2`P80b<S80P3>c/h30<K6aP80aLG5
0P36a/H20<;2`P80UYJF101PH60206UYJ@80KVi^0P1fMWH207QhN080Ogmo0P25QHD208>3P`80QXJ6
0P2;Rh/208B4Q080QhN71029RHT208n?S`80SHf=0P2BTY82096AT@80T92@0P2?Shl409:BTP80RHV9
0P26QXH208B4Q080R8R80`2:RXX208>3P`80NWYj0P1]KFd206QXJ080MgMg0P1mOGd206ATI080FEUI
0P1fMWH20861P@80PX:20P24Q8@207moO`80JFUY0P1ZJVX20820P080Lg=c0P1UIFD207moO`80WinO
0P2SXj<20:RXZ080YjNW0P2c/k<40:n_[`80Z:RX0P2NWYh2092@T080R8R80P1mOGd307MgM`80OGem
0P1hN7P207inOP80O7al1021PH4208:2PP80Ph>30P24Q8@208N7Q`80PX:20P21PH4208Z:RP80Shn?
0P2FUYHY0<SPf080;Bd]0P0_;bl202LW9`@0:RXZ0P0^;Rh202/[:`80:BTY0P0/;2`202h^;P80<30`
0P0];Bd2034a<@80;bl_0P0];Bd2034a<@<0;2`/0P0c<c<2034a<@@0;Bd]100V9RH202<S8`80:2PX
0P0Q8B4401lO7`80<S8b0P1BDU82096AT@80TY:B0P1aLG4205QHF080IVIV0P2QXJ420<;2`P80_kno
102YZJT20:RXZ080[Zj^0P2d];@20;Zj^P80^k^k0P37alL20<S8b080c<c<0`39bLT20<g=c@80bl_;
0P2c/k<208j>SP80LG5a0P1RHV8206=SH`80Kfm_0P1iNGT207moO`80N7Qh0P23Ph<208N7Q`80QHF5
1023Ph<208b<S080QXJ60P2;Rh/2092@T080TI6A0P2CTi<208Z:RP80TY:B0P2DU9@208n?S`80SXj>
0P2;Rh/208n?S`80Ph>30P2:RXX308^;R`80O7al0P1mOGd206i^KP80JFUY0P1cLg<207alO080K6a/
0P1JFUX207QhN080OWin1027QhL208>3P`80GemO0P1/K6`207UiN@80Hf=S0P1KFe/207QhN080Xj>S
0P2[Zj/20:2PX080Y:BT0P2XZ:P20:f][@80Zj^[0P2UYJD209fMW@80TY:B0P24Q8@208>3P`<0NWYj
0P1kNg/207UiN@80N7Qh0P1kNg/20861P@80Ph>3101nOWh20861P@80OGem0P20P80208J6QP80RXZ:
0P2>SXh209FEUAl0b>3H000M0<SPf080;2`/0P0X:2P202DU9@809bLW0P0[:b/202h^;PH0<30`0P0_
;bl202h^;P@0;bl_0P0];Bd202/[:`80;Bd]0`0`<304034a<@80<c<c0P0b<S8202/[:`808b<S0P0T
92@202HV9P8092@T0P0S8b<201hN7P809RHV0P0`<30207MgM`80Y:BT0P2;Rh/2055AD@80GemO0P27
QhL20;Zj^P80_kno0P2i^KT20:j^[P80Y:BT0P2YZJT20;:b/P80]kNg0P2k^k/20<30`080a<C40P39
bLT30<_;b`80b<S80P32`/820<K6aP80`L710P2?Shl205mOG`80GEeM0P1YJFT2075aL@80NWYj0P1m
OGd207moO`80PH610P23Ph<408B4Q0@0PX:20P28R8P208n?S`@0T92@0P2?Shl208j>SP@0Shn?0P2;
Rh/208F5Q@80O7al0P1fMWH207]kN`<0PH610P20P80207]kN`80KVi^0P1TI6@206i^KP80NGUi0P1_
Kfl206IVIP80Lg=c0P27QhL208f=S@@0Shn?0P2DU9@209nOW`80Z:RX0P2OWil209JFUP80W9bL0P2V
YZH20:VYZ@80Zj^[0P2/[:`20:j^[P@0[jn_0P2YZJT20:2PX080UYJF0P2<S8`208B4Q0<0OWin101m
OGd207YjNP80MgMg0P1jNWX207inOP@0Ogmo0P21PH4408>3P`80Q8B40P2;Rh/209:BTP80U9BD:@38
h=P2030`<080:RXZ0P0S8b<202TY:@80:RXZ0P0_;bl202`/;080=SHf0P0];Bd202h^;P80;bl_100`
<30202/[:`80:RXZ0P0[:b/3038b<P80;2`/0P0j>SX202d];@80>CTi0P0X:2P202@T90809BDU0P0T
92@202DU9@808b<S100R8R8203Ti>@80MgMg0P2LW9`208N7Q`80GemO0P1QHF420861P@80]kNg0P3:
b/X20;Vi^@80YZJV0P2WYjL20:ZZZP80/K6a0P2f][H20;Zj^P80_[jn0P33`l<20<[:bP<0bl_;0P39
bLT40<;2`P80_kno0P2:RXX205iNGP80GemO0P1XJ6P207EeM@80MgMg0P21PH4208:2PP80O7al0P22
PX8208Z:RP80PH610P27QhL208:2PP80QHF50P2BTY8208j>SP@0Shn?0P2=SHd408n?S`80SHf=0P26
QXH207QhN080MWIf0P1mOGd307inOP80Ogmo0P1nOWh206a/K080KFe]0P1[Jf/207alO080Kfm_0P1P
H60207YjNP80QHF50P28R8P209:BTP80UYJF0P2ATI4209>CT`80YjNW0P2PX:0208f=S@80WinO0P2R
XZ820:BTY080[jn_102/[:`20:^[Z`80[Zj^0P2][Jd209nOW`80U9BD0P2<S8`208>3P`<0OWin0P20
P80207alO080Ogmo0P1dM7@207]kN`80PX:20P1kNg/207inOP80P8201023Ph<208J6QP80SHf=0P2B
TY8209FEUBT0b>3H0P0Y:BT202`/;0809RHV0P0R8R8202/[:`80=3@d0P0/;2`4034a<@80;Rh^0P0]
;Bd2030`<080;2`/0P0];Bd202/[:`80:RXZ0`0a<C4203Lg=`80<30`0P0a<C42038b<P80;Bd]0P0S
8b<202HV9P808b<S0P0W9bL4024Q8@808R8R0P0c<c<207AdM080YZJV0P2<S8`204e=C@80HF5Q0P25
QHD20;bl_0@0^[Zj0P2d];@20:>SX`80YjNW0P2a/K420;Vi^@80_;bl0P30`<020<?3``80b<S80`3=
cLd20<O7a`80`l?30P34a<@20<;2`P80SHf=0P1NGUh205eMG@80JVYZ0P1aLG4207]kN`80OWin0P20
P8020861P@80Ph>30P24Q8@208J6QP80Q8B40P1oOgl408f=S@@0Shn?0P2=SHd608n?S`80R8R80P22
PX8207alO080Lg=c0P1kNg/308>3P`80Ogmo0P1jNWX207AdM080I6AT0P1/K6`207QhN080KVi^0P1V
IVH2075aL@80SHf=0P2;Rh/2096AT@80Shn?0P2FUYH209jNWP80YjNW0P2RXZ8209NGU`80XZ:R0P2T
Y:@20:NWY`80[Zj^0P2[Zj/20;2`/080/[:b0P2_[jl20:NWY`80XZ:R0P2EUID208j>SP80Q8B41@1m
OGd207inOP80NWYj0P1fMWH207]kN`80OGem0P21PH420820P080PH610P23Ph<208N7Q`@0QHF50P2D
U9@209jNWQl0b>3H000M0<SPf080;2`/0P0X:2P202DU9@809bLW0P0[:b/202h^;PH0<30`0P0_;bl2
02h^;P@0;bl_0P0];Bd202/[:`80;Bd]0`0`<304034a<@80<c<c0P0b<S8202/[:`808b<S0P0T92@2
02HV9P8092@T0P0S8b<201hN7P809RHV0P0`<30207MgM`80Y:BT0P2;Rh/2055AD@80GemO0P27QhL2
0;Zj^P80_kno0P2i^KT20:j^[P80Y:BT0P2YZJT20;:b/P80]kNg0P2k^k/20<30`080a<C40P39bLT3
0<_;b`80b<S80P32`/820<K6aP80`L710P2?Shl205mOG`80GEeM0P1YJFT2075aL@80NWYj0P1mOGd2
07moO`80PH610P23Ph<408B4Q0@0PX:20P28R8P208n?S`@0T92@0P2?Shl208j>SP@0Shn?0P2;Rh/2
08F5Q@80O7al0P1fMWH207]kN`<0PH610P20P80207]kN`80KVi^0P1TI6@206i^KP80NGUi0P1_Kfl2
06IVIP80Lg=c0P27QhL208f=S@@0Shn?0P2DU9@209nOW`80Z:RX0P2OWil209JFUP80W9bL0P2VYZH2
0:VYZ@80Zj^[0P2/[:`20:j^[P@0[jn_0P2YZJT20:2PX080UYJF0P2<S8`208B4Q0<0OWin101mOGd2
07YjNP80MgMg0P1jNWX207inOP@0Ogmo0P21PH4408>3P`80Q8B40P2;Rh/209:BTP80U9BD:@38h=P2
030`<080:RXZ0P0S8b<202TY:@80:RXZ0P0_;bl202`/;080=SHf0P0];Bd202h^;P80;bl_100`<302
02/[:`80:RXZ0P0[:b/3038b<P80;2`/0P0j>SX202d];@80>CTi0P0X:2P202@T90809BDU0P0T92@2
02DU9@808b<S100R8R8203Ti>@80MgMg0P2LW9`208N7Q`80GemO0P1QHF420861P@80]kNg0P3:b/X2
0;Vi^@80YZJV0P2WYjL20:ZZZP80/K6a0P2f][H20;Zj^P80_[jn0P33`l<20<[:bP<0bl_;0P39bLT4
0<;2`P80_kno0P2:RXX205iNGP80GemO0P1XJ6P207EeM@80MgMg0P21PH4208:2PP80O7al0P22PX82
08Z:RP80PH610P27QhL208:2PP80QHF50P2BTY8208j>SP@0Shn?0P2=SHd408n?S`80SHf=0P26QXH2
07QhN080MWIf0P1mOGd307inOP80Ogmo0P1nOWh206a/K080KFe]0P1[Jf/207alO080Kfm_0P1PH602
07YjNP80QHF50P28R8P209:BTP80UYJF0P2ATI4209>CT`80YjNW0P2PX:0208f=S@80WinO0P2RXZ82
0:BTY080[jn_102/[:`20:^[Z`80[Zj^0P2][Jd209nOW`80U9BD0P2<S8`208>3P`<0OWin0P20P802
07alO080Ogmo0P1dM7@207]kN`80PX:20P1kNg/207inOP80P8201023Ph<208J6QP80SHf=0P2BTY82
09FEUBT0b>3H0P0Y:BT202`/;0809RHV0P0R8R8202/[:`80=3@d0P0/;2`4034a<@80;Rh^0P0];Bd2
030`<080;2`/0P0];Bd202/[:`80:RXZ0`0a<C4203Lg=`80<30`0P0a<C42038b<P80;Bd]0P0S8b<2
02HV9P808b<S0P0W9bL4024Q8@808R8R0P0c<c<207AdM080YZJV0P2<S8`204e=C@80HF5Q0P25QHD2
0;bl_0@0^[Zj0P2d];@20:>SX`80YjNW0P2a/K420;Vi^@80_;bl0P30`<020<?3``80b<S80`3=cLd2
0<O7a`80`l?30P34a<@20<;2`P80SHf=0P1NGUh205eMG@80JVYZ0P1aLG4207]kN`80OWin0P20P802
0861P@80Ph>30P24Q8@208J6QP80Q8B40P1oOgl408f=S@@0Shn?0P2=SHd608n?S`80R8R80P22PX82
07alO080Lg=c0P1kNg/308>3P`80Ogmo0P1jNWX207AdM080I6AT0P1/K6`207QhN080KVi^0P1VIVH2
075aL@80SHf=0P2;Rh/2096AT@80Shn?0P2FUYH209jNWP80YjNW0P2RXZ8209NGU`80XZ:R0P2TY:@2
0:NWY`80[Zj^0P2[Zj/20;2`/080/[:b0P2_[jl20:NWY`80XZ:R0P2EUID208j>SP80Q8B41@1mOGd2
07inOP80NWYj0P1fMWH207]kN`80OGem0P21PH420820P080PH610P23Ph<208N7Q`@0QHF50P2DU9@2
09jNWQl0b>3H000M0<SPf080:b/[0P0W9bL202<S8`809BDU0P0Y:BT202d];@80<30`0P0a<C42030`
<0@0;bl_0P0d=3@203Ti>@80=3@d100_;bl5034a<@80<S8b0P0e=CD203Lg=`80<30`0P0Y:BT202LW
9`809RHV0P0T92@202<S8`808B4Q0P0W9bL202HV9P80EUIF0P2;Rh/209FEU@80MWIf0P1GEeL2075a
L@80W9bL0P2l_;`20<[:bP80]KFe0P2PX:020:>SX`80[Jf]0P2b/[820;Rh^080_;bl0P30`<020<O7
a`<0bl_;0P39bLT20<K6aP@0b<S80P2][Jd208j>SP80LG5a0P1MGEd206IVIP80MgMg0P1kNg/207in
OP80Ogmo0P20P80208:2PP80Ph>30P20P80207moO`80R8R8102ATI44092@T080Shn?0P2=SHd208^;
R`80QXJ60P1oOgl207MgM`80Kfm_0P1YJFT306MWI`80KFe]1P1dM7@207emO@80QXJ60P27QhL208R8
R080SHf=0P2HV9P209^KV`80WinO0P2PX:020:NWY`80[jn_0P2d];@20;6a/@80[Jf]0P2ZZZX20:^[
Z`80^k^k0P36a/H20;Bd]080WinO102MWId209:BTP80Rh^;0P28R8P208N7Q`80Q8B40`22PX8207mo
O`80O7al0P1iNGT207IfMP80N7Qh0P1lO7`207moO`P0PX:20P23Ph<208b<S080U9BD0P2FUYHY0<SP
f080:2PX0P0T92@202DU9@80:b/[0P0U9BD202`/;080;bl_0P0d=3@2038b<P80<C4a0P0`<302034a
<@80>3Ph0P0b<S8202h^;P80>CTi0`0`<302034a<@80;bl_0P0Z:RX203Ph>080;bl_0P0W9bL202HV
9P80;Bd]0P0R8R82024Q8@807alO0P0S8b<202`/;080DU9B0P24Q8@209nOW`80KFe]0P1FEUH206a/
K080Vi^K0P32`/820<_;b`80[jn_0P2SXj<20:NWY`80[:b/0P2f][H20;Vi^@80_;bl0P2n_[h20<S8
b0<0bLW90P3:b/X20<K6aP80a<C40P35aLD20;jn_P80U9BD0P1RHV8205aLG080K6a/0P1hN7P207]k
N`80O7al0P1kNg/20861P@80QXJ60P1nOWh20861P@80OGem0P24Q8@409>CT`80TI6A0P2@T90208n?
S`80SHf=0P27QhL208R8R080PH610P1`L70206e]K@80LW9b0`1YJFT206a/K080N7Qh0P1bLW8206m_
K`80M7Ad1025QHD208n?S`80UiNG0P2KVi/209NGU`80WYjN0P2YZJT20:NWY`80[:b/102b/[820:ZZ
ZP80/K6a0P2d];@20;^k^`80_Kfm0P2a/K420:2PX080Vi^K0P2GUiL209BDU0@0R8R80P29RHT208B4
Q0<0Ph>30P1nOWh207UiN@80MgMg0P1iNGT207=cL`80N7Qh0P20P80208>3P`80PH610P20P80207Ui
N@80PX:20P2=SHd209BDU080UiNG:@38h=P202DU9@809RHV0P0U9BD2020P8080:RXZ0P0];Bd203@d
=080<30`0P0a<C4202l_;`80<S8b0P0c<c<203`l?080<S8b0P0a<C42038b<P<0=CDe0P0_;bl2034a
<@80=SHf0P0g=cL2034a<@8092@T0P0U9BD202LW9`808R8R0P0U9BD2020P80@09bLW0P1GEeL208Z:
RP80V9RH0P1iNGT205YJFP80Kfm_0P2MWId20;jn_P80a/K60P2a/K420:>SX`80WinO0P2/[:`20;Jf
]P80/k>c0P2l_;`20<71`@80`/;20`3=cLd20<?3``80aLG50P3<c<`20<K6aP80[Zj^0P2>SXh206e]
K@80H61P0P1RHV8207IfMP80O7al0P1oOgl20820P080Q8B40P21PH4208B4Q080O7al0P1mOGd208V9
R@80SXj>0P2EUID209:BTP80SHf=0P2?Shl208j>SP80T92@0P24Q8@208>3P`80MGEe0P1aLG4206AT
I0<0IFEU0P1fMWH207=cL`80LW9b0P1dM7@207]kN`@0QhN70P2:RXX209:BTP80U9BD0P2IVIT209nO
W`80X:2P0P2UYJD20:b/[080]KFe0P2b/[820:ZZZP80Zj^[0P2^[Zh20;Ng]`80a/K60P2`/;020:6Q
X@80W9bL0P2MWId209>CT`80RXZ:0P27QhL208B4Q080Ph>30`22PX8207emO@80P8200P1gMgL207Ui
N@@0Ng]k0P1lO7`208:2PP80P8200P22PX8208J6QP80P8200P2:RXX209FEU@80Ti>C7`38h=P001d0
b>3H0P0[:b/202LW9`808b<S0P0U9BD202TY:@80;Bd]0P0`<302034a<@80<30`100_;bl203@d=080
>CTi0P0d=3@402l_;`D0<C4a0P0b<S8203De=@80=cLg0P0`<30202TY:@809bLW0P0V9RH202@T9080
8b<S0P0Q8B4202LW9`809RHV0P1FEUH208^;R`80UIFE0P1fMWH205MGE`80LG5a0P2LW9`20;bl_080
b/[:0P2e]KD20:2PX080Xj>S0P2][Jd20;:b/P80^;Rh0P2l_;`20<30`080alO70`3;bl/20<W9b@80
a/K61038b<P20:f][@80SXj>0P1aLG4205eMG@80IVIV0P1gMgL207]kN`80OWin0P1oOgl20820P080
PX:20P23Ph<20820P080Ogmo0P28R8P4096AT@@0T92@0P2?Shl208f=S@80Rh^;0P26QXH207moO`80
MgMg0P1_Kfl206UYJ@<0IfMW0P1]KFd607AdM080OGem0P26QXH208N7Q`80R8R80P2=SHd209RHV080
Vi^K0P2OWil20:2PX080YjNW0P2_[jl20;Bd]080/K6a0P2][Jd20:ZZZP80Zj^[0P2k^k/20<K6aP80
];Bd0P2OWil409fMW@80TY:B0P2;Rh/208R8R080QhN70P24Q8@308:2PP80Ogmo0P1lO7`207UiN@80
MWIf0P1hN7P207alO080Ogmo2022PX8208>3P`80S8b<0P2DU9@209JFURT0b>3H0P0X:2P202@T9080
9BDU0P0[:b/202DU9@80;2`/0P0_;bl203@d=080<S8b0P0a<C42030`<080<C4a0P0h>3P2038b<P80
;Rh^0P0i>CT3030`<080<C4a0P0_;bl202XZ:P80>3Ph0P0_;bl202LW9`809RHV0P0];Bd2028R8P80
8B4Q0P0O7al202<S8`80;2`/0P1BDU8208B4Q080WinO0P1]KFd205IFEP80K6a/0P2KVi/20<;2`P80
bl_;0P2_[jl20:>SX`80YjNW0P2/[:`20;Jf]P80^KVi0P2l_;`20;jn_P80b<S80`39bLT20<[:bP80
a/K60P34a<@20<G5a@80_[jn0P2DU9@2069RHP80G5aL0P1/K6`207QhN080Ng]k0P1lO7`207]kN`80
PH610P26QXH207inOP80PH610P1mOGd208B4Q0@0Ti>C0P2ATI42092@T080Shn?0P2=SHd208N7Q`80
R8R80P21PH42071`L080KFe]0P1bLW8306UYJ@80K6a/0P1hN7P2079bLP80Kfm_0P1dM7@408F5Q@80
Shn?0P2GUiL209^KV`80UiNG0P2NWYh20:VYZ@80YjNW0P2/[:`40;:b/P80ZZZZ0P2a/K420;Bd]080
^k^k0P2m_Kd20;6a/@80X:2P0P2KVi/209NGU`80U9BD1028R8P208V9R@80Q8B40`23Ph<207inOP80
NGUi0P1gMgL207UiN@80Lg=c0P1hN7P20820P080Ph>30P21PH420820P080NGUi0P22PX8208f=S@80
U9BD0P2GUiLY0<SPf0809BDU0P0V9RH202DU9@80820P0P0Z:RX202d];@80=3@d0P0`<302034a<@80
;bl_0P0b<S8203<c<`80?3`l0P0b<S82034a<@80<S8b0`0e=CD202l_;`80<C4a0P0f=SH203Lg=`80
<C4a0P0T92@202DU9@809bLW0P0R8R8202DU9@80820P100W9bL205MGE`80RXZ:0P2HV9P207UiN@80
FUYJ0P1_Kfl209fMW@80_[jn0P36a/H20;6a/@80Xj>S0P2OWil20:b/[080][Jf0P2c/k<20;bl_080
`L710P32`/830<g=c@80`l?30P35aLD20<c<c080a/K60P2^[Zh208j>SP80KFe]0P1PH602069RHP80
MWIf0P1lO7`207moO`80P8200P24Q8@20861P@80Q8B40P1lO7`207emO@80RHV90P2>SXh209FEU@80
TY:B0P2=SHd208n?S`80SXj>0P2@T90208B4Q080Ph>30P1eMGD2075aL@80I6AT0`1UIFD207IfMP80
Lg=c0P1bLW8207AdM080Ng]k1027QhL208Z:RP80TY:B0P2DU9@209VIV@80WinO0P2PX:020:FUY@80
[:b/0P2e]KD20;:b/P80ZZZZ0P2[Zj/20:j^[P80]kNg0P36a/H20;2`/080XJ6Q0P2LW9`209fMW@80
Ti>C0P2:RXX208N7Q`80Q8B40P23Ph<308:2PP80OGem0P20P80207MgM`80NGUi101kNg/207alO080
PX:20P20P80208:2PP80QXJ60P20P80208Z:RP80UIFE0P2CTi<O0<SPf0007@38h=P202/[:`809bLW
100T92@202LW9`80;2`/0P0a<C42038b<P80<C4a100`<30203Ti>@80@D510P0k>c/203<c<`L0<C4a
0P0b<S8203Hf=P80>CTi0P0d=3@202h^;P80:BTY0P0V9RH402<S8`809RHV0P0];Bd2028R8P80>c/k
0P1[Jf/209BDU080VYZJ0P1GEeL206=SH`80Ng]k0P2][Jd20=;BdP80^k^k0P2NWYh209nOW`80YjNW
0P2^[Zh20;Fe]@80^;Rh0P2l_;`20<?3``D0b/[:0P38b<P20<K6aP80`l?30P35aLD20;jn_P80SHf=
0P1NGUh206=SH`80M7Ad0P1iNGT207alO080OGem0P1nOWh20820P080PH610P1nOWh207emO@80QhN7
102ATI4408n?S`80SHf=0P29RHT208>3P`80O7al0P1eMGD206m_K`80J6QX0P1KFe/305=CD`80GUiN
0P1^KVh207]kN`80QHF50P2;Rh/208n?S`80VIVI0P2QXJ420:>SX`80Y:BT0P2XZ:P20:j^[P80];Bd
0P2k^k/20;no_`80`L711034a<@20;jn_P80][Jf0P2ZZZX209nOW`80V9RH0P2BTY8208j>SP80RXZ:
0P1lO7`207AdM080N7Qh0P20P80208>3P`<0Q8B40P20P80207YjNP80MgMg0P1fMWH207MgM`80NWYj
0P1oOgl208B4Q080Ph>31021PH4208>3P`80S8b<0P2FUYH209RHV2T0b>3H0P0/;2`202LW9`8092@T
0P0W9bL202TY:@80<C4a0P0d=3@202`/;080<C4a0P0];Bd2030`<080?3`l0P10@40203Xj>P80=SHf
0P0^;Rh302`/;080<30`0P0b<S8204A4A080>c/k0P0_;bl203@d=080:b/[0P0S8b<202LW9`809BDU
0P0R8R8202`/;080:BTY0P0k>c/206i^KP80TI6A0P2CTi<205mOG`80H61P0P1lO7`20:b/[080c/k>
0P2o_kl209jNWP80Xj>S0P2VYZH20:j^[P80];Bd0P2j^[X20;^k^`80aLG50`38b<P20<[:bP80b<S8
0P36a/H20<C4a080_kno0P2l_;`208n?S`80H61P0P1RHV8207MgM`80NGUi101kNg/207moO`@0PH61
0P20P80207inOP80R8R80P2@T90209>CT`80T92@102=SHd208b<S080PX:20P1lO7`207AdM080Jf][
0P1SHf<206UYJ@<0De=C0P1;Bd/2075aL@80OGem0P27QhL208Z:RP80TY:B0P2EUID409fMW@80WinO
0P2XZ:P20:f][@80/;2`102k^k/20<71`@80a<C40P31`L420;Vi^@80[jn_0P2WYjL20:ZZZP80Vi^K
0P2BTY8208j>SP80QhN70P1lO7`207EeM@80MWIf0P22PX820820P0<0QXJ60P1nOWh207emO@80N7Qh
0P1gMgL207UiN@80Ng]k0P20P80408:2PP80QHF50P20P80208B4Q080SXj>0P2DU9@209ZJVRT0b>3H
0P0];Bd202PX:0808b<S0P0V9RH202DU9@80:2PX0P0];Bd203Ph>080<C4a0P0`<30202l_;`80>3Ph
0P13@d<203/k>`80=SHf0P0a<C4303@d=080<C4a0P0c<c<203@d=080=SHf0P0h>3P402d];@809RHV
100S8b<202TY:@80:b/[0P0R8R8203`l?080IFEU0P2DU9@209RHV080F5QH0P1PH60207emO@80[Zj^
0P3EeMD20;Rh^080XJ6Q0P2PX:020:NWY`80/k>c0P2e]KD20;Vi^@80_;bl0P33`l<30<S8b080clo?
0P33`l<20<[:bP80_Kfm0P37alL20;Zj^P80Shn?0P1NGUh2065QH@80Lg=c0P1mOGd207]kN`80NGUi
101oOgl208>3P`80P8200P1oOgl208N7Q`@0TI6A0P2=SHd408n?S`80RHV90P20P80207UiN@80LG5a
0P1`L70206IVIP80EeMG0`1EEED205iNGP80K6a/0P1lO7`208R8R080RHV90P2@T90209NGU`80XJ6Q
0P2TY:@20:JVYP80YJFU0P2^[Zh20;Jf]P80_;bl0P2o_kl20<30`080`/;20P35aLD20;fm_@80][Jf
0P2XZ:P20::RXP80VIVI102@T90208Z:RP80Ogmo0P1dM7@207UiN@@0PX:20`27QhL207inOP80Ng]k
0P1gMgL207IfMP80Lg=c0P1nOWh207alO080QhN70P24Q8@40820P080PX:20P2<S8`209VIV@80UiNG
7`38h=P001d0b>3H0P0[:b/202LW9`@092@T0P0W9bL202`/;080<C4a0P0b<S82034a<@@0<30`0P0i
>CT20451@@80>c/k0P0c<c<7034a<@80<S8b0P0f=SH203Ti>@80=3@d0P0^;Rh202TY:@809RHV100S
8b<202HV9P80;Bd]0P0R8R8203/k>`80Jf][0P2DU9@209ZJVP80EeMG0P1SHf<207]kN`80[Jf]0P3B
d]820;^k^`80WYjN0P2OWil20:NWY`80[Zj^0P2e]KD20;Rh^080_;bl0P33`l<50<[:bP80b<S80P36
a/H20<?3``80aLG50P2n_[h208f=S@80GUiN0P1SHf<207AdM080NGUi0P1lO7`207emO@80OWin0P20
P8020861P@80OWin0P1mOGd208N7Q`@0TI6A102?Shl208f=S@80RHV90P23Ph<207alO080MGEe0P1_
Kfl206QXJ080Fe]K0`1CDe<205iNGP80KVi^0P1kNg/208F5Q@80Rh^;0P2?Shl209VIV@80XJ6Q0P2S
Xj<20:BTY080Z:RX0P2^[Zh20;Bd]080^k^k0P2o_kl20<71`@@0a<C40P2n_[h20;Jf]P80ZZZZ0P2O
Wil209RHV080TY:B0P2>SXh208Z:RP80O7al0P1dM7@207QhN080P8200P23Ph<308B4Q080P8200P1j
NWX207MgM`80MWIf0P1gMgL207YjNP80Ogmo0P24Q8@208>3P`@0PH610P23Ph<208b<S080UYJF0P2H
V9PY0<SPf080;2`/0P0W9bL202@T90809bLW0P0Y:BT2034a<@80=3@d0P0/;2`2034a<@80;Bd]0P0`
<30203`l?080@4100P0j>SX203Hf=P80;Rh^0`0/;2`2030`<080<S8b0P14A4@203/k>`80;bl_0P0d
=3@202/[:`808b<S0P0W9bL202DU9@808R8R0P0/;2`202TY:@80>c/k0P1^KVh2096AT@80Ti>C0P1O
Gel2061PH080O7al0P2/[:`20<k>cP80_kno0P2NWYh20:>SX`80YZJV0P2^[Zh20;Bd]080^[Zj0P2k
^k/20<G5a@<0b<S80P3:b/X20<S8b080a/K60P34a<@20;no_`80_;bl0P2?Shl2061PH080HV9R0P1g
MgL207UiN@@0Ng]k0P1oOgl40861P@80P8200P1nOWh208R8R080T92@0P2CTi<2092@T0@0SHf=0P2<
S8`208:2PP80O7al0P1dM7@206][J`80Hf=S0P1YJFT305=CD`80Bd];0P1aLG4207emO@80QhN70P2:
RXX209:BTP80UIFE102MWId209nOW`80Z:RX0P2][Jd20;2`/0@0^k^k0P31`L420<C4a080`L710P2i
^KT20:n_[`80YjNW0P2ZZZX209^KV`80TY:B0P2>SXh208N7Q`80O7al0P1eMGD207IfMP80PX:20P20
P80308J6QP80OWin0P1mOGd207QhN080MgMg0P1iNGT207]kN`80P8201022PX8208F5Q@80P8200P24
Q8@208j>SP80U9BD0P2JVYXY0<SPf080;Bd]0P0X:2P202<S8`809RHV0P0U9BD202PX:080;Bd]0P0h
>3P2034a<@80<30`0P0_;bl203Ph>080@d=30P0k>c/203Hf=P80<C4a0`0d=3@2034a<@80<c<c0P0d
=3@203Hf=P80>3Ph100];Bd202HV9P@08b<S0P0Y:BT202/[:`808R8R0P0l?3`206EUI@80U9BD0P2H
V9P205QHF080H61P0P1mOGd20:j^[P80eMGE0P2h^;P20:6QX@80X:2P0P2WYjL20;>c/`80]KFe0P2i
^KT20;bl_080`l?30`38b<P20<o?c`80`l?30P3:b/X20;fm_@80alO70P2j^[X208n?S`80GUiN0P1Q
HF4207=cL`80OGem0P1kNg/207UiN@@0Ogmo0P23Ph<20820P080Ogmo0P27QhL4096AT@80SHf=102?
Shl208V9R@80P8200P1iNGT2075aL@80L71`0P1VIVH205MGE`<0EEEE0P1NGUh206a/K080O7al0P28
R8P208V9R@80T92@0P2GUiL20:6QX@80Y:BT0P2VYZH20:FUY@80[Zj^0P2f][H20;bl_080_kno0P30
`<020<;2`P80aLG50P2m_Kd20;Jf]P80Z:RX0P2RXZ8209VIV@@0T92@0P2:RXX207moO`80M7Ad0P1i
NGT408:2PP<0QhN70P1nOWh207]kN`80MgMg0P1fMWH207=cL`80OWin0P1lO7`208N7Q`80Q8B41020
P80208:2PP80S8b<0P2IVIT209NGUal0b>3H000M0<SPf080;2`/0P0[:b/202XZ:P80:BTY0P0X:2P2
02d];@80<c<c100d=3@2030`<080;Bd]0P0f=SH203hn?P80>SXj0P0c<c<202l_;`<0;Bd]0P0/;2`2
02h^;P80<c<c0P0f=SH2034a<@80:b/[0P0Y:BT202PX:0809RHV0P0S8b<2020P80806a/K0P11@D42
02LW9`80De=C0P1lO7`209NGU`80NGUi0P1WIfL206=SH`80QHF50P30`<020<K6aP80XJ6Q0P2OWil2
0:6QX@80[:b/0P2g]kL40;Rh^080`<300`37alL40<S8b080alO70P35aLD20<S8b080aLG50P2][Jd2
092@T080NWYj0P1[Jf/206m_K`80N7Qh0P1kNg/407alO080Ng]k0P1lO7`207inOP80QXJ60P2>SXh2
08n?S`80SHf=0P2;Rh/208N7Q`80Ogmo0P1eMGD206MWI`80Fe]K0P1JFUX205aLG080GEeM0`1QHF42
06QXJ080LG5a0P1oOgl208Z:RP80QhN70P22PX8208>3P`80R8R80P2@T90209bLW080[Jf]0P2m_Kd2
0<;2`P80`l?30P36a/H20<S8b080bl_;0P3=cLd20<W9b@80`/;20P2e]KD20:NWY`80UiNG0P2:RXX2
08b<S0@0SHf=0P1]KFd207=cL`80O7al0P21PH4308>3P`80OGem101fMWH207MgM`80NGUi0P1lO7`2
07moO`80PH611P22PX8208B4Q080Rh^;0P2CTi<209BDU2T0b>3H0P0b<S8202`/;0@09bLW0P0T92@2
02TY:@80<30`0P0i>CT203Ph>080<S8b0P0^;Rh203Hf=P80@d=30P0o?cl402h^;P<0=SHf0P0`<302
02`/;080;Rh^0P0a<C4203Lg=`809bLW0P0T92@202PX:0809BDU0P0T92@2024Q8@80820P0P0i>CT2
02XZ:P80CDe=0P25QHD209^KV`80O7al0P1SHf<206IVIP80R8R80P32`/820<G5a@80W9bL0P2EUID2
09nOW`80[Jf]0P2a/K420;Vi^@80]KFe0P30`<050<O7a`80a/K60P37alL20<G5a@@0`L710P2l_;`2
09:BTP80IVIV0P1YJFT2079bLP80Ogmo0P1lO7`207]kN`80NWYj0P1lO7`207inOP80Ng]k0P27QhL2
08j>SP80Rh^;0P2=SHd408J6QP80QHF50P1bLW8206YZJP80GemO0P1KFe/205eMG@80GemO0`1NGUh2
06i^KP80MgMg0P22PX8208^;R`80SHf=0P23Ph<208F5Q@80RXZ:0P2CTi<209jNWP80][Jf0P2k^k/2
0<71`@80aLG50P37alL20<_;b`80c/k>0P3AdM420<k>cP80alO70P2f][H209jNWP80T92@0P29RHT2
096AT@80V9RH0P2;Rh/207=cL`80L71`0P1lO7`208>3P`<0PX:20P1mOGd207UiN@80LW9b0P1eMGD2
07UiN@80O7al0P24Q8@20861P@80PX:20P21PH4208F5Q@80Q8B4102=SHd209VIVBT0b>3H0P0Z:RX2
02l_;`80:2PX0P0V9RH202d];@80<C4a0P0c<c<203@d=080;Rh^0P0_;bl202d];@80=cLg0P0m?Cd2
03Hf=P80;bl_0P0[:b/302HV9P80:BTY0P0_;bl203Hf=P80=cLg0P0b<S8202XZ:P@09bLW0P0Q8B42
02@T90806ATI0P0L71`204E5A@809RHV0P1GEeL20820P080Ti>C0P1lO7`206IVIP80H61P0P23Ph<4
0<C4a080XJ6Q0P2MWId20:2PX080YjNW0P2g]kL20;Vi^@80^k^k0P2n_[h30<S8b080c<c<1036a/H2
0<G5a@80c/k>0P38b<P20:VYZ@80TY:B0P1iNGT206YZJP80LW9b0P1gMgL207alO080OGem101jNWX2
07inOP80Ng]k0P24Q8@208Z:RP80UiNG0P29RHT208^;R`80Q8B40P1oOgl207QhN080I6AT0P1NGUh2
06ATI080HF5Q0P1HF5P306=SH`80JVYZ0P1bLW8207moO`80R8R80P26QXH408B4Q080QhN70P28R8P2
0:2PX080[Jf]0P2o_kl20<;2`P80`L710P38b<P20<[:bP80cLg=0P3>c/h20<W9b@80`l?30P2c/k<2
0:JVYP80VIVI102<S8`208^;R`80S8b<0P1[Jf/207EeM@80O7al0P1oOgl308:2PP80NWYj0P1fMWH2
07EeM@80Ng]k0P1eMGD207moO`80PX:20P20P80207moO`80PH610P28R8P208F5Q@80SXj>0P2?Shl2
09:BTQl0b>3H000M0<SPf080;2`/0P0[:b/202XZ:P80:BTY0P0X:2P202d];@80<c<c100d=3@2030`
<080;Bd]0P0f=SH203hn?P80>SXj0P0c<c<202l_;`<0;Bd]0P0/;2`202h^;P80<c<c0P0f=SH2034a
<@80:b/[0P0Y:BT202PX:0809RHV0P0S8b<2020P80806a/K0P11@D4202LW9`80De=C0P1lO7`209NG
U`80NGUi0P1WIfL206=SH`80QHF50P30`<020<K6aP80XJ6Q0P2OWil20:6QX@80[:b/0P2g]kL40;Rh
^080`<300`37alL40<S8b080alO70P35aLD20<S8b080aLG50P2][Jd2092@T080NWYj0P1[Jf/206m_
K`80N7Qh0P1kNg/407alO080Ng]k0P1lO7`207inOP80QXJ60P2>SXh208n?S`80SHf=0P2;Rh/208N7
Q`80Ogmo0P1eMGD206MWI`80Fe]K0P1JFUX205aLG080GEeM0`1QHF4206QXJ080LG5a0P1oOgl208Z:
RP80QhN70P22PX8208>3P`80R8R80P2@T90209bLW080[Jf]0P2m_Kd20<;2`P80`l?30P36a/H20<S8
b080bl_;0P3=cLd20<W9b@80`/;20P2e]KD20:NWY`80UiNG0P2:RXX208b<S0@0SHf=0P1]KFd207=c
L`80O7al0P21PH4308>3P`80OGem101fMWH207MgM`80NGUi0P1lO7`207moO`80PH611P22PX8208B4
Q080Rh^;0P2CTi<209BDU2T0b>3H0P0b<S8202`/;0@09bLW0P0T92@202TY:@80<30`0P0i>CT203Ph
>080<S8b0P0^;Rh203Hf=P80@d=30P0o?cl402h^;P<0=SHf0P0`<30202`/;080;Rh^0P0a<C4203Lg
=`809bLW0P0T92@202PX:0809BDU0P0T92@2024Q8@80820P0P0i>CT202XZ:P80CDe=0P25QHD209^K
V`80O7al0P1SHf<206IVIP80R8R80P32`/820<G5a@80W9bL0P2EUID209nOW`80[Jf]0P2a/K420;Vi
^@80]KFe0P30`<050<O7a`80a/K60P37alL20<G5a@@0`L710P2l_;`209:BTP80IVIV0P1YJFT2079b
LP80Ogmo0P1lO7`207]kN`80NWYj0P1lO7`207inOP80Ng]k0P27QhL208j>SP80Rh^;0P2=SHd408J6
QP80QHF50P1bLW8206YZJP80GemO0P1KFe/205eMG@80GemO0`1NGUh206i^KP80MgMg0P22PX8208^;
R`80SHf=0P23Ph<208F5Q@80RXZ:0P2CTi<209jNWP80][Jf0P2k^k/20<71`@80aLG50P37alL20<_;
b`80c/k>0P3AdM420<k>cP80alO70P2f][H209jNWP80T92@0P29RHT2096AT@80V9RH0P2;Rh/207=c
L`80L71`0P1lO7`208>3P`<0PX:20P1mOGd207UiN@80LW9b0P1eMGD207UiN@80O7al0P24Q8@20861
P@80PX:20P21PH4208F5Q@80Q8B4102=SHd209VIVBT0b>3H0P0Z:RX202l_;`80:2PX0P0V9RH202d]
;@80<C4a0P0c<c<203@d=080;Rh^0P0_;bl202d];@80=cLg0P0m?Cd203Hf=P80;bl_0P0[:b/302HV
9P80:BTY0P0_;bl203Hf=P80=cLg0P0b<S8202XZ:P@09bLW0P0Q8B4202@T90806ATI0P0L71`204E5
A@809RHV0P1GEeL20820P080Ti>C0P1lO7`206IVIP80H61P0P23Ph<40<C4a080XJ6Q0P2MWId20:2P
X080YjNW0P2g]kL20;Vi^@80^k^k0P2n_[h30<S8b080c<c<1036a/H20<G5a@80c/k>0P38b<P20:VY
Z@80TY:B0P1iNGT206YZJP80LW9b0P1gMgL207alO080OGem101jNWX207inOP80Ng]k0P24Q8@208Z:
RP80UiNG0P29RHT208^;R`80Q8B40P1oOgl207QhN080I6AT0P1NGUh206ATI080HF5Q0P1HF5P306=S
H`80JVYZ0P1bLW8207moO`80R8R80P26QXH408B4Q080QhN70P28R8P20:2PX080[Jf]0P2o_kl20<;2
`P80`L710P38b<P20<[:bP80cLg=0P3>c/h20<W9b@80`l?30P2c/k<20:JVYP80VIVI102<S8`208^;
R`80S8b<0P1[Jf/207EeM@80O7al0P1oOgl308:2PP80NWYj0P1fMWH207EeM@80Ng]k0P1eMGD207mo
O`80PX:20P20P80207moO`80PH610P28R8P208F5Q@80SXj>0P2?Shl209:BTQl0b>3H000M0<SPf080
;bl_100`<30202`/;080:RXZ0P0^;Rh203@d=080>CTi0P0l?3`2038b<P80:RXZ0P0`<30203Ph>080
=SHf0P0a<C4202d];@<0:BTY0P0X:2P202XZ:P80;bl_0P0c<c<202d];@809bLW0P0X:2P202XZ:P80
9RHV0P0R8R8202<S8`80:BTY0P0N7Qh203Lg=`80AdM70P1LG5`20820P080V9RH0P1bLW8205EEE@80
G5aL0P2UYJD20<W9b@80YZJV0P2QXJ4209^KV`80ZJVY102g]kL20;Fe]@80_;bl0`33`l<20<K6aPH0
alO70P34a<@20<;2`P80alO70P33`l<209RHV080K6a/0P1[Jf/207AdM080MgMg0P1iNGT207MgM`80
MWIf0P1jNWX207moO`80Q8B40P28R8P208Z:RP80RHV90P26QXH207moO`80M7Ad0P1VIVH2055AD@80
@D510P15ADD2051@D080Hf=S0`1dM7@407IfMP80Ogmo0P25QHD207YjNP80KFe]0P1TI6@206=SH`80
LW9b0P29RHT20:JVYP80_kno0P36a/H20<O7a`80b/[:0P3<c<`20<o?c`@0dM7A0P3=cLd20;no_`80
[Zj^0P2IVIT208R8R080SHf=0P2?Shl209fMW@80Jf][0P1bLW8207YjNPD0OWin0P1iNGT207=cL`80
M7Ad0P1hN7P207YjNP80O7al0P1mOGd207inOP80PH610P23Ph<208B4Q080QXJ60P2;Rh/2092@T080
TI6A:@38h=P202`/;080:b/[0P0f=SH202`/;080;bl_0P0[:b/203Hf=P80?Cdm0P0j>SX203Hf=P80
;Bd]0P0X:2P203Lg=`80@4100P0a<C4202LW9`<09RHV0P0Y:BT202`/;080;bl_0P0`<30203De=@80
9RHV0P0U9BD202h^;P80;Bd]0P0Q8B4202<S8`808B4Q0P0Z:RX203Hf=P80?3`l0P1HF5P208R8R080
UYJF0P1SHf<205QHF080IVIV0P2SXj<20<;2`P80Zj^[0P2FUYH209bLW080[:b/0P2e]KD20;:b/P80
];Bd0P2m_Kd50<?3``80alO70P39bLT20<G5a@80alO70P31`L420<C4a080`L710P2LW9`206a/K080
JVYZ0P1cLg<207MgM`80NWYj0P1bLW8207IfMP80OWin0P1lO7`208>3P`80S8b<0P23Ph<208n?S`80
R8R80P1lO7`207IfMP80Hf=S0P1CDe<404=3@`80DU9B0P1SHf<307=cL`@0MgMg0P1lO7`208B4Q080
N7Qh0P1/K6`206EUI@80IVIV0P1dM7@208V9R@80Xj>S0P2j^[X20<G5a@80a/K60P3:b/X20<g=c@80
clo?0P3AdM420<o?c`80b/[:0P36a/H20;2`/080UiNG0P28R8P2092@T080SXj>0P2DU9@2075aL@80
KVi^0P1iNGT208F5Q@<0OWin0P1dM7@2075aL@80NGUi0P1dM7@207alO080Ng]k0P1lO7`207moO`@0
PX:20P23Ph<408J6QP80T92@0P2DU9@Y0<SPf080;2`/0P0a<C4202h^;P80:b/[0P0W9bL202/[:`80
<c<c0P0l?3`203dm?@80<30`0P0[:b/2038b<P80>CTi0P0f=SH203<c<`80;Bd]1@0/;2`202PX:080
;Rh^0P0a<C42030`<0809bLW0P0Z:RX202/[:`80:BTY0P0U9BD2020P8080;Bd]0P0O7al203Lg=`80
ADE50P1JFUX207inOP80UiNG0P1gMgL205IFEP80Fe]K0P2VYZH20<W9b@80YZJV0P2UYJD209^KV`80
ZZZZ0P2f][H20;Rh^080/k>c0P2n_[h30;no_`80b<S80P33`l<20<O7a`80`l?30P32`/820<71`@80
a/K60P32`/8209JFUP80K6a/0P1ZJVX207=cL`80M7Ad0P1jNWX207IfMP80M7Ad0P23Ph<207alO080
Ph>30P24Q8@208f=S@80R8R80P29RHT207emO@80MWIf0P1SHf<204i>CP80@4100P17AdL204m?C`80
GemO1@1eMGD207MgM`80OGem0P27QhL207QhN080Jf][0P1WIfL206ATI080KVi^0P2:RXX20::RXP80
`L710P39bLT20<G5a@@0b/[:0P3AdM420<o?c`80dM7A0P3=cLd20;no_`80[Zj^0P2IVIT208N7Q`80
SXj>0P2@T9020::RXP80Jf][0P1`L70207UiN@D0OGem0P1iNGT206m_K`@0MGEe0P1hN7P207alO080
OGem1020P80208F5Q@@0PX:20P2>SXh208n?S`80TY:B7`38h=P001d0b>3H0P0_;bl4030`<080;2`/
0P0Z:RX202h^;P80=3@d0P0i>CT203`l?080<S8b0P0Z:RX2030`<080>3Ph0P0f=SH2034a<@80;Bd]
0`0Y:BT202PX:080:RXZ0P0_;bl203<c<`80;Bd]0P0W9bL202PX:080:RXZ0P0V9RH2028R8P808b<S
0P0Y:BT201hN7P80=cLg0P17AdL205aLG080P8200P2HV9P2079bLP80EEEE0P1LG5`20:FUY@80bLW9
0P2VYZH20:6QX@80Vi^K0P2YZJT40;Ng]`80]KFe0P2l_;`30<?3``80a/K61P37alL20<C4a080`/;2
0P37alL20<?3``80V9RH0P1/K6`206][J`80M7Ad0P1gMgL207UiN@80MgMg0P1fMWH207YjNP80Ogmo
0P24Q8@208R8R080RXZ:0P29RHT208J6QP80Ogmo0P1dM7@206IVIP80DE5A0P11@D4204E5A@80D51@
0P1SHf<307AdM0@0MWIf0P1oOgl208F5Q@80NWYj0P1]KFd206ATI080Hf=S0P1bLW8208V9R@80YZJV
0P2o_kl20<K6aP80alO70P3:b/X20<c<c080clo?103AdM420<g=c@80_kno0P2^[Zh209VIV@80R8R8
0P2=SHd208n?S`80WIfM0P1[Jf/2079bLP80NWYj1@1nOWh207UiN@80Lg=c0P1dM7@207QhN080NWYj
0P1lO7`207emO@80OWin0P21PH4208>3P`80Q8B40P26QXH208^;R`80T92@0P2ATI4Y0<SPf080;2`/
0P0[:b/203Hf=P80;2`/0P0_;bl202/[:`80=SHf0P0m?Cd203Xj>P80=SHf0P0];Bd202PX:080=cLg
0P10@402034a<@809bLW0`0V9RH202TY:@80;2`/0P0_;bl2030`<080=CDe0P0V9RH202DU9@80;Rh^
0P0];Bd2024Q8@808b<S0P0Q8B4202XZ:P80=SHf0P0l?3`205QHF080R8R80P2FUYH206=SH`80F5QH
0P1VIVH20:>SX`80`/;20P2[Zj/209JFUP80W9bL0P2/[:`20;Fe]@80/[:b0P2d];@20;fm_@D0`l?3
0P37alL20<W9b@80aLG50P37alL20<71`@80a<C40P31`L4209bLW080K6a/0P1ZJVX207=cL`80MgMg
0P1jNWX2079bLP80MWIf0P1nOWh207alO080Ph>30P2<S8`208>3P`80Shn?0P28R8P207alO080MWIf
0P1SHf<205=CD`@0@d=30P1BDU8206=SH`<0Lg=c101gMgL207alO080Q8B40P1hN7P206a/K080IFEU
0P1VIVH207AdM080RHV90P2SXj<20;Zj^P80aLG50P36a/H20<[:bP80cLg=0P3?cll20=7Ad@80clo?
0P3:b/X20<K6aP80/;2`0P2GUiL208R8R080T92@0P2>SXh209BDU080LG5a0P1^KVh207UiN@80QHF5
0`1nOWh207AdM080LG5a0P1iNGT207AdM080O7al0P1kNg/207alO080Ogmo1022PX8208>3P`@0QXJ6
0P2@T90209BDU2T0b>3H0P0/;2`2034a<@80;Rh^0P0[:b/202LW9`80:b/[0P0c<c<203`l?080?Cdm
0P0`<30202/[:`80<S8b0P0i>CT203Hf=P80<c<c0P0];Bd502`/;080:2PX0P0^;Rh2034a<@80<30`
0P0W9bL202XZ:P80:b/[0P0Y:BT202DU9@80820P0P0];Bd201lO7`80=cLg0P15ADD205YJFP80OWin
0P2GUiL207MgM`80EUIF0P1KFe/20:JVYP80bLW90P2VYZH20:FUY@80Vi^K0P2ZZZX20;Jf]P80^;Rh
0P2c/k<20;jn_P<0_kno0P38b<P20<?3``80alO70P33`l<20<;2`P80`L710P36a/H20<;2`P80UYJF
0P1/K6`206YZJP80Lg=c0P1dM7@207YjNP80MWIf0P1dM7@208>3P`80O7al0P23Ph<208B4Q080SHf=
0P28R8P208V9R@80OGem0P1fMWH206=SH`80CTi>0P10@40204M7A`80Cdm?0P1OGel507EeM@80MgMg
0P1mOGd208N7Q`80N7Qh0P1[Jf/206MWI`80I6AT0P1^KVh208Z:RP80XZ:R0P31`L420<W9b@80aLG5
103:b/X20=7Ad@80clo?0P3AdM420<g=c@80_kno0P2^[Zh209VIV@80QhN70P2>SXh2092@T080XZ:R
0P1[Jf/2071`L080NGUi1@1mOGd207UiN@80Kfm_101eMGD207QhN080O7al0P1mOGd40820P080QHF5
1022PX8208j>SP80Shn?0P2BTY8O0<SPf0007@38h=P203Hf=P80<S8b0P0/;2`402XZ:P80;Bd]0P0d
=3@204I6AP80EUIF0P12@T8202PX:080;2`/100e=CD203<c<`80;Rh^1@0Y:BT202/[:`80<30`0P0d
=3@202l_;`@0:BTY0P0[:b/202LW9`8092@T0P0U9BD202TY:@809bLW0P0`<30203De=@80A4A40P1K
Fe/2096AT@80Q8B40P1HF5P204U9B@80QXJ60P2/[:`20:^[Z`80WYjN0P2CTi<209jNWP80[Jf]0P2`
/;020;6a/@80^;Rh0`2o_kl20<C4a080alO71038b<P20<K6aP80a<C41039bLT20;Bd]080VIVI0P1m
OGd206QXJ080Jf][0P1dM7@207EeM@80MgMg0P1mOGd208:2PP80PH610P20P8040861P@80OGem0P1e
MGD206QXJ080F5QH0P11@D42038b<P80>SXj0P1:BTX205eMG@<0Kfm_0P1hN7P207]kN`80MgMg0P1^
KVh205iNGP80CTi>1018B4P2051@D080H61P0P1jNWX209RHV080^;Rh0P3=cLd40<k>cP80d=3@0P3A
dM420=3@d080c<c<0P34a<@20;Vi^@80YJFU0P2BTY8208Z:RP80PX:20P24Q8@206QXJ080LG5a0P1o
Ogl207YjNP<0LW9b0P1aLG42079bLP80MWIf0P1jNWX207UiN@80MgMg0P1kNg/207moO`80PX:20P25
QHD208N7Q`80RHV90P2>SXh209>CT`80U9BD:@38h=P203`l?080=CDe0P0X:2P202h^;P80:RXZ0P0^
;Rh203@d=080ADE50P1?Cdl203dm?@80:RXZ0P0Y:BT2034a<@80>SXj0P0b<S8202d];@<0;2`/0P0X
:2P402d];@80=SHf0P0h>3P202PX:0@09bLW0P0T92@2024Q8@809BDU0P0Z:RX2030`<080<S8b0P0e
=CD203lo?`80KVi^0P2EUID207alO080De=C0P1FEUH207inOP80[jn_0P2i^KT209nOW`80V9RH0P2Y
ZJT20;2`/080/k>c0P2d];@20;bl_0<0_[jn0P33`l<20<O7a`80bLW90P3:b/X20<C4a0H0aLG50P34
a<@20:2PX080KFe]0P1XJ6P2075aL@80MGEe101fMWH207moO`80PX:20P24Q8@208:2PP80O7al0P22
PX8207alO080MGEe0P1/K6`205IFEP80@D51100_;bl204U9B@80Hf=S0`1aLG42071`L080MGEe0P1h
N7P2075aL@80GemO0P1BDU8203lo?`80@T920P1;Bd/205QHF080Ogmo0P2NWYh20;bl_080b/[:0P3;
bl/40<[:bP80c/k>0P3<c<`20<K6aP80`l?30P2l_;`20:>SX`80U9BD0P2:RXX208B4Q080N7Qh0P1Z
JVX207AdM080OWin0P1jNWX5071`L080Lg=c0P1lO7`207emO@80N7Qh0P1fMWH207]kN`80NWYj0P26
QXH208B4Q080Rh^;0P2:RXX208n?S`80U9BD0P2KVi/Y0<SPf080<c<c0P0e=CD202/[:`80<30`0P0/
;2`202TY:@80=CDe0P1;Bd/205MGE`80@D510P0W9bL202/[:`80<c<c0P0k>c/203@d=080;Rh^0`0Y
:BT402XZ:P80<C4a0P0c<c<202l_;`8092@T100Y:BT202DU9@809RHV0P0M7Ad202HV9P809bLW0P0`
<302034a<@80B4Q80P1MGEd208n?S`80Q8B40P1HF5P204Q8B080Ph>30P2a/K420:ZZZP80VIVI0P2@
T9020:BTY080[Jf]102a/K420;Jf]P<0`<300P38b<P20<[:bP80b<S80P3;bl/20<k>cP80`L710P37
alL20<g=c@80^;Rh0P2GUiL20861P@@0Jf][0P1dM7@207QhN080MGEe0P1lO7`20820P0@0PX:20P26
QXH407alO080MgMg0P1WIfL205aLG080@T920P0a<C4203Hf=P80B4Q80P1LG5`3071`L080OGem0P1j
NWX207MgM`80L71`0P1PH602055AD@80ATI60P1=CDd2055AD@80I6AT0P1jNWX209BDU080^KVi0P3?
cll20<c<c080c/k>1P3@d=020<[:bP80a/K60P2g]kL20:NWY`80TI6A0P26QXH207moO`80QXJ60P1V
IVH206i^KP80PX:20P1oOgl307=cL`80MgMg0P1fMWH207UiN@80OGem0P1jNWX207IfMP80O7al0P1n
OWh208>3P`80PX:20P29RHT208N7Q`@0TY:B0P2FUYHO0<SPf0007@38h=P203Hf=P80<S8b0P0/;2`4
02XZ:P80;Bd]0P0d=3@204I6AP80EUIF0P12@T8202PX:080;2`/100e=CD203<c<`80;Rh^1@0Y:BT2
02/[:`80<30`0P0d=3@202l_;`@0:BTY0P0[:b/202LW9`8092@T0P0U9BD202TY:@809bLW0P0`<302
03De=@80A4A40P1KFe/2096AT@80Q8B40P1HF5P204U9B@80QXJ60P2/[:`20:^[Z`80WYjN0P2CTi<2
09jNWP80[Jf]0P2`/;020;6a/@80^;Rh0`2o_kl20<C4a080alO71038b<P20<K6aP80a<C41039bLT2
0;Bd]080VIVI0P1mOGd206QXJ080Jf][0P1dM7@207EeM@80MgMg0P1mOGd208:2PP80PH610P20P804
0861P@80OGem0P1eMGD206QXJ080F5QH0P11@D42038b<P80>SXj0P1:BTX205eMG@<0Kfm_0P1hN7P2
07]kN`80MgMg0P1^KVh205iNGP80CTi>1018B4P2051@D080H61P0P1jNWX209RHV080^;Rh0P3=cLd4
0<k>cP80d=3@0P3AdM420=3@d080c<c<0P34a<@20;Vi^@80YJFU0P2BTY8208Z:RP80PX:20P24Q8@2
06QXJ080LG5a0P1oOgl207YjNP<0LW9b0P1aLG42079bLP80MWIf0P1jNWX207UiN@80MgMg0P1kNg/2
07moO`80PX:20P25QHD208N7Q`80RHV90P2>SXh209>CT`80U9BD:@38h=P203`l?080=CDe0P0X:2P2
02h^;P80:RXZ0P0^;Rh203@d=080ADE50P1?Cdl203dm?@80:RXZ0P0Y:BT2034a<@80>SXj0P0b<S82
02d];@<0;2`/0P0X:2P402d];@80=SHf0P0h>3P202PX:0@09bLW0P0T92@2024Q8@809BDU0P0Z:RX2
030`<080<S8b0P0e=CD203lo?`80KVi^0P2EUID207alO080De=C0P1FEUH207inOP80[jn_0P2i^KT2
09nOW`80V9RH0P2YZJT20;2`/080/k>c0P2d];@20;bl_0<0_[jn0P33`l<20<O7a`80bLW90P3:b/X2
0<C4a0H0aLG50P34a<@20:2PX080KFe]0P1XJ6P2075aL@80MGEe101fMWH207moO`80PX:20P24Q8@2
08:2PP80O7al0P22PX8207alO080MGEe0P1/K6`205IFEP80@D51100_;bl204U9B@80Hf=S0`1aLG42
071`L080MGEe0P1hN7P2075aL@80GemO0P1BDU8203lo?`80@T920P1;Bd/205QHF080Ogmo0P2NWYh2
0;bl_080b/[:0P3;bl/40<[:bP80c/k>0P3<c<`20<K6aP80`l?30P2l_;`20:>SX`80U9BD0P2:RXX2
08B4Q080N7Qh0P1ZJVX207AdM080OWin0P1jNWX5071`L080Lg=c0P1lO7`207emO@80N7Qh0P1fMWH2
07]kN`80NWYj0P26QXH208B4Q080Rh^;0P2:RXX208n?S`80U9BD0P2KVi/Y0<SPf080<c<c0P0e=CD2
02/[:`80<30`0P0/;2`202TY:@80=CDe0P1;Bd/205MGE`80@D510P0W9bL202/[:`80<c<c0P0k>c/2
03@d=080;Rh^0`0Y:BT402XZ:P80<C4a0P0c<c<202l_;`8092@T100Y:BT202DU9@809RHV0P0M7Ad2
02HV9P809bLW0P0`<302034a<@80B4Q80P1MGEd208n?S`80Q8B40P1HF5P204Q8B080Ph>30P2a/K42
0:ZZZP80VIVI0P2@T9020:BTY080[Jf]102a/K420;Jf]P<0`<300P38b<P20<[:bP80b<S80P3;bl/2
0<k>cP80`L710P37alL20<g=c@80^;Rh0P2GUiL20861P@@0Jf][0P1dM7@207QhN080MGEe0P1lO7`2
0820P0@0PX:20P26QXH407alO080MgMg0P1WIfL205aLG080@T920P0a<C4203Hf=P80B4Q80P1LG5`3
071`L080OGem0P1jNWX207MgM`80L71`0P1PH602055AD@80ATI60P1=CDd2055AD@80I6AT0P1jNWX2
09BDU080^KVi0P3?cll20<c<c080c/k>1P3@d=020<[:bP80a/K60P2g]kL20:NWY`80TI6A0P26QXH2
07moO`80QXJ60P1VIVH206i^KP80PX:20P1oOgl307=cL`80MgMg0P1fMWH207UiN@80OGem0P1jNWX2
07IfMP80O7al0P1nOWh208>3P`80PX:20P29RHT208N7Q`@0TY:B0P2FUYHO0<SPf0007@38h=P203`l
?080<S8b0P0W9bL202HV9P80:BTY0P0];Bd203Hf=P80EEEE0P1_Kfl2051@D080:BTY0P0Z:RX2038b
<P@0<c<c0P0_;bl502/[:`80;Bd]0P0c<c<203Lg=`80<S8b0P0[:b/402XZ:P80:2PX0P0W9bL202PX
:080:RXZ100[:b/202PX:080<30`0P0i>CT207alO080T92@0P1SHf<204E5A@80Jf][0P2:RXX20:b/
[080WinO0P2@T90209NGU`80XJ6Q0P2WYjL20:f][@80/k>c0`2j^[X20<30`080aLG50P37alL20<S8
b080alO70P36a/H20<C4a080`l?30P39bLT20<K6aP80UiNG0P1XJ6P206IVIP80Kfm_0P1cLg<207Qh
N080Ogmo0P22PX8207emO@@0MWIf0P1eMGD2071`L080J6QX0P1JFUX204Y:BP80=SHf0P0Y:BT203De
=@80B4Q80P1IFET306QXJ080MWIf0P1kNg/206][J`80EEEE0P14A4@203Ph>0@0<c<c0P0e=CD203dm
?@80Cdm?0P1ZJVX209jNWP80b/[:0P3@d=020<k>cP@0d=3@0P3>c/h20<[:bP80b<S80P32`/820;:b
/P80WIfM0P24Q8@206m_K`80IFEU0P1WIfL207=cL`80PX:20P1eMGD306IVIP80Jf][0P1cLg<207Qh
N080Ng]k0P1fMWH2079bLP80N7Qh0P20P80208B4Q080QXJ60P28R8P208^;R`80TI6A0P2GUiL209RH
V2T0b>3H0P10@40202h^;P80;2`/0P0X:2P202`/;080:2PX0P0j>SX2059BDP80M7Ad0P1=CDd202XZ
:P80;2`/0P0d=3@2030`<080=CDe0P0/;2`302d];@@0:b/[0P0e=CD203@d=080<30`0P0Z:RX2030`
<080;2`/0P0W9bL202PX:080:b/[0P0W9bL202h^;P80:2PX0P0U9BD202`/;080@4100P1mOGd208Z:
RP80IfMW0P1ADE4206IVIP80RHV90P2VYZH20:6QX@80T92@0P2GUiL20:>SX`80Z:RX0P2[Zj/20;^k
^`<0^KVi0P31`L420<K6aP80aLG50P38b<P20<O7a`80aLG50P34a<@20<;2`P80alO70P33`l<209RH
V080K6a/0P1SHf<2071`L080LW9b0P1jNWX207inOP80PH610P1mOGd207AdM080MGEe0P1iNGT206e]
K@80I6AT0P1PH60204Y:BP80<S8b0P0[:b/203<c<`80A4A40P1LG5`306UYJ@80LW9b0P1mOGd2075a
L@80FEUI0P0n?Sh203Ti>@80=SHf0P0m?Cd203Xj>P80@D510P1=CDd206][J`80X:2P0P36a/H20=3@
d080c/k>0P3@d=020<o?c`80dM7A0P3:b/X20<S8b080`<300P2`/;0209jNWP80Ph>30P1bLW82065Q
H@80IVIV101mOGd207AdM0<0IVIV0P1_Kfl2079bLP80MgMg0P1lO7`207EeM@80LG5a0P1kNg/20861
P@80PX:20P26QXH208V9R@80RXZ:0P2>SXh209>CT`80Vi^K:@38h=P203`l?080<c<c0P0Y:BT2020P
80@0:b/[0P0e=CD205EEE@80Kfm_0P1ADE4202TY:@80:RXZ0P0a<C4203De=@80;Rh^0P0b<S8302XZ
:P@0;2`/0P0f=SH203De=@80<S8b0P0];Bd2034a<@80:b/[0P0W9bL202@T9080:b/[0P0Y:BT202h^
;P80:b/[0P0Y:BT2030`<080>CTi0P1nOWh2092@T080I6AT0P1:BTX206UYJ@80R8R80P2/[:`209fM
W@80UIFE0P2?Shl209nOW`80[jn_0P2[Zj/20;>c/`<0^[Zj0P31`L420<K6aP80`l?30P36a/H20<[:
bP@0a/K60P34a<@20<K6aP80aLG50P2HV9P206UYJ@80HV9R0P1[Jf/207AdM080N7Qh0P22PX820861
P@80O7al0P1aLG4207alO080M7Ad0P1aLG4206YZJP80GEeM0P17AdL203<c<`80;Bd]0P0a<C4204I6
AP80GEeM0`1XJ6P2075aL@80NWYj0P1/K6`2059BDP80ATI60P0i>CT202`/;080=CDe0P0g=cL203/k
>`80CTi>0P1/K6`209fMW@80bl_;0P3Cdm<20<g=c@@0clo?0P3@d=020<W9b@80c<c<0P31`L420:n_
[`80X:2P0P22PX8207AdM080IFEU0P1VIVH2079bLP80P8200P1bLW8306ATI080KFe]0P1aLG4207If
MP80MgMg0P1jNWX2075aL@80M7Ad0P23Ph<208B4Q080QhN70P2:RXX208V9R@80Ti>C0P2DU9@209FE
UAl0b>3H000M0<SPf080?3`l0P0b<S8202LW9`809RHV0P0Y:BT202d];@80=SHf0P1EEED206m_K`80
D51@0P0Y:BT202XZ:P80<S8b100c<c<202l_;`D0:b/[0P0];Bd203<c<`80=cLg0P0b<S8202/[:`@0
:RXZ0P0X:2P202LW9`80:2PX0P0Z:RX402/[:`80:2PX0P0`<30203Ti>@80O7al0P2@T90206=SH`80
ADE50P1[Jf/208Z:RP80[:b/0P2OWil2092@T080UiNG0P2QXJ420:NWY`80[Jf]0P2c/k<30;Zj^P80
`<300P35aLD20<O7a`80b<S80P37alL20<K6aP80a<C40P33`l<20<W9b@80a/K60P2GUiL206QXJ080
IVIV0P1_Kfl207=cL`80N7Qh0P1oOgl208:2PP80OGem101fMWH207EeM@80L71`0P1XJ6P205YJFP80
BTY:0P0f=SH202TY:@80=CDe0P18B4P205UIF@<0J6QX0P1fMWH207]kN`80Jf][0P1EEED204A4A080
>3Ph100c<c<203De=@80?Cdm0P1?Cdl206YZJP80WYjN0P3:b/X20=3@d080c/k>103@d=020<k>cP80
b/[:0P38b<P20<;2`P80/[:b0P2MWId208B4Q080Kfm_0P1UIFD206MWI`80Lg=c0P22PX8207EeM@<0
IVIV0P1[Jf/207=cL`80N7Qh0P1kNg/207IfMP80LW9b0P1hN7P20820P080Q8B40P26QXH208R8R080
Rh^;0P2ATI4209NGU`80V9RH:@38h=P20410@080;Rh^0P0/;2`202PX:080;2`/0P0X:2P203Xj>P80
DU9B0P1dM7@204e=C@80:RXZ0P0/;2`203@d=080<30`0P0e=CD202`/;0<0;Bd]100[:b/203De=@80
=3@d0P0`<30202XZ:P80<30`0P0/;2`202LW9`80:2PX0P0[:b/202LW9`80;Rh^0P0X:2P202DU9@80
;2`/0P10@40207emO@80RXZ:0P1WIfL2055AD@80IVIV0P29RHT20:JVYP80XJ6Q0P2@T90209NGU`80
Xj>S0P2XZ:P20:^[Z`80^k^k0`2i^KT20<71`@80a/K60P35aLD20<S8b080alO70P35aLD20<C4a080
`/;20P37alL20<?3``80V9RH0P1/K6`206=SH`80L71`0P1bLW8207YjNP80OWin0P21PH4207emO@80
M7Ad0P1eMGD207UiN@80KFe]0P1TI6@2061PH080BTY:0P0b<S8202/[:`80<c<c0P14A4@205aLG0<0
JFUY0P1bLW8207emO@80LG5a0P1IFET203hn?P80>CTi0P0f=SH203dm?@80>SXj0P11@D4204e=C@80
Jf][0P2PX:020<K6aP80d=3@0P3>c/h20=3@d080clo?0P3AdM420<[:bP80b<S80P30`<020;2`/080
WYjN0P23Ph<2079bLP80HF5Q0P1VIVH407emO@80M7Ad0`1VIVH206m_K`80LW9b0P1gMgL207alO080
MGEe0P1aLG4207]kN`80PH610P22PX8208J6QP80RHV90P2:RXX208j>SP80Ti>C0P2KVi/Y0<SPf080
?3`l0P0c<c<202TY:@80820P100[:b/203De=@80EEEE0P1_Kfl2055AD@80:BTY0P0Z:RX2034a<@80
=CDe0P0^;Rh2038b<P<0:RXZ100/;2`203Hf=P80=CDe0P0b<S8202d];@80<C4a0P0[:b/202LW9`80
92@T0P0[:b/202TY:@80;Rh^0P0[:b/202TY:@80<30`0P0i>CT207inOP80T92@0P1TI6@204Y:BP80
JFUY0P28R8P20:b/[080WIfM0P2EUID208n?S`80WinO0P2_[jl20:^[Z`80/k>c0`2j^[X20<71`@80
a/K60P33`l<20<K6aP80b/[:1036a/H20<C4a080a/K60P35aLD209RHV080JFUY0P1RHV8206][J`80
M7Ad0P1hN7P208:2PP80PH610P1lO7`2075aL@80O7al0P1dM7@2075aL@80JVYZ0P1MGEd204M7A`80
<c<c0P0];Bd2034a<@80ATI60P1MGEd306QXJ080LG5a0P1jNWX206a/K080DU9B0P16ATH203Ti>@80
;2`/0P0e=CD203Lg=`80>c/k0P1>CTh206a/K080WIfM0P3;bl/20=?Cd`80cLg=103?cll20=3@d080
bLW90P3<c<`20<71`@80[jn_0P2PX:0208:2PP80M7Ad0P1UIFD206IVIP80LW9b0P20P802079bLP<0
I6AT0P1]KFd2075aL@80MWIf0P1gMgL207YjNP80LG5a0P1dM7@208>3P`80Q8B40P27QhL208Z:RP80
RHV90P2CTi<209BDU080UIFE7`38h=P001d0b>3H0P0h>3P2030`<0809bLW0P0U9BD202PX:080<C4a
0P0j>SX206UYJ@80MgMg0P1<C4`203@d=080;2`/0P0];Bd202h^;P80;bl_0P0];Bd502/[:`80;2`/
0P0c<c<203Ph>080<C4a0P0Y:BT202PX:080:BTY0P0Z:RX202/[:`80:BTY0P0W9bL402PX:0808R8R
0P0U9BD2034a<@80HF5Q0P23Ph<207MgM`80EeMG0P1LG5`207UiN@80WYjN0P2e]KD20::RXP80X:2P
102LW9`209nOW`80YZJV0`2_[jl20;Jf]P80_Kfm0P33`l<20<O7a`@0bLW90P36a/H20<C4a0@0b/[:
0P2c/k<209JFUP80NGUi0P1TI6@206UYJ@80Lg=c0P1iNGT207]kN`80Lg=c0P1ZJVX206IVIP80Hf=S
0P1MGEd205EEE@80B4Q80P0k>c/2030`<080;Bd]0P0i>CT204];B`80GemO0`1_Kfl207EeM@80LG5a
0P1LG5`20451@@80@T920P1;Bd/205QHF080HV9R0P1EEED204M7A`80@4100P1=CDd206][J`80ZJVY
103?cll20=?Cd`80d=3@0P3?cll20<c<c080cLg=0P39bLT20;Ng]`80WYjN0P1iNGT205YJFP80EeMG
0P1RHV8207emO@80M7Ad0P1[Jf/3065QH@80J6QX0P1aLG4207AdM080MGEe101dM7@207UiN@80OWin
0P23Ph<208J6QP80QhN70P29RHT2096AT@80V9RH0P2IVITY0<SPf080>3Ph0P0X:2P202HV9P809bLW
0P0V9RH202d];@80@4100P1UIFD207moO`80Cdm?0P0e=CD202h^;P80<C4a0P0Y:BT203De=@80:b/[
0`0Y:BT2034a<@80;Bd]0P0a<C4203dm?@80;Bd]0P0X:2P202d];@809RHV0P0/;2`202/[:`80:2PX
0P0S8b<202d];@809bLW0P0T92@202HV9P80;bl_0P1JFUX207QhN080Lg=c0P1ADE4205aLG080OGem
0P2GUiL20;6a/@80WYjN0P2CTi<209NGU`80Ti>C0P2IVIT20::RXP<0ZZZZ0P2d];@20;^k^`80`l?3
0P36a/H20<W9b@80b/[:0P38b<P40<G5a@80`l?30P32`/8209RHV080IfMW0P1]KFd206EUI@80Lg=c
0P1hN7P207YjNP80MGEe0P1^KVh206ATI080HF5Q0P1OGel205IFEP80CTi>0P0g=cL202l_;`80<c<c
0P15ADD205=CD`80FUYJ0`1/K6`207moO`80Lg=c0P1HF5P203/k>`80?3`l0P1?Cdl205MGE`80FUYJ
0P1@D50204e=C@80=cLg0P11@D42075aL@80[Jf]0P3?cll20=?Cd`80d];B103Cdm<20<g=c@80c/k>
0P3:b/X20;Jf]P80WYjN0P1kNg/205eMG@80E5AD0P1SHf<207inOP80MWIf0P1VIVH3069RHP80Jf][
101_Kfl207EeM@80LW9b0P1fMWH207YjNP@0P8200P26QXH208R8R080RHV90P2@T90209NGU`80XZ:R
:@38h=P203Ti>@80;2`/0P0X:2P2020P8080;2`/0P0a<C4203/k>`80K6a/0P1aLG4204];B`80=cLg
0P0V9RH202d];@80=3@d100];Bd302/[:`@0:BTY0P0e=CD203Ti>@80<30`0P0X:2P202<S8`809BDU
0P0/;2`402d];@H0:2PX0P0Q8B4202<S8`80:RXZ0P1SHf<208>3P`80LG5a0P1EEED205eMG@80O7al
0P2NWYh20;^k^`80XZ:R0P2OWil209fMW@80X:2P0P2KVi/20:BTY0<0[Jf]0P2g]kL20;Vi^@@0aLG5
0P37alL20<C4a080alO70P2l_;`20<g=c@80bl_;0P2_[jl209FEU@80NWYj0P1[Jf/206UYJ@80Kfm_
101kNg/207=cL`80IfMW0P1ZJVX206ATI080EEEE0P1BDU8204E5A@80?clo0P0_;bl202h^;P80>CTi
0P1?Cdl206ATI0<0K6a/0P1gMgL207=cL`80GUiN0P0o?cl204=3@`80C4a<0P1BDU8206=SH`80E5AD
0P18B4P203lo?`80CTi>0P1XJ6P20:JVYP80bl_;0P3@d=020=?Cd`80dM7A0P3>c/h20<O7a`80clo?
0P38b<P20;Rh^080X:2P0P1gMgL205MGE`80F5QH0P1WIfL20820P080MgMg0P1XJ6P3065QH@80IfMW
0P1]KFd2079bLP80MWIf0P1iNGT207=cL`80MgMg0P1mOGd408B4Q080RHV90P25QHD209BDU080VYZJ
0P2LW9`O0<SPf0007@38h=P203Ph>080<30`0P0W9bL202DU9@80:2PX0P0a<C4203Xj>P80JFUY0P1g
MgL204a<C080=3@d0P0/;2`202d];@80;Rh^0P0_;bl202d];@D0:b/[0P0/;2`203<c<`80>3Ph0P0a
<C4202TY:@80:2PX0P0Y:BT202XZ:P80:b/[0P0Y:BT202LW9`@0:2PX0P0R8R8202DU9@80<C4a0P1Q
HF4208>3P`80MgMg0P1GEeL205aLG080NGUi0P2NWYh20;Fe]@80XZ:R0P2PX:0409bLW080WinO0P2V
YZH30:n_[`80][Jf0P2m_Kd20<?3``80alO71039bLT20<K6aP80a<C4103:b/X20;>c/`80UYJF0P1i
NGT206ATI080JFUY0P1cLg<207UiN@80Ng]k0P1cLg<206YZJP80IVIV0P1SHf<205eMG@80EEEE0P18
B4P203/k>`80<30`0P0];Bd203Ti>@80Bd];0P1OGel306m_K`80MGEe0P1aLG4205aLG080@D510P12
@T8204];B`80F5QH0P1RHV8205EEE@80AdM70P10@40204e=C@80Jf][0P2YZJT40<o?c`80dm?C0P3@
d=020<o?c`80c<c<0P3=cLd20<W9b@80]kNg0P2NWYh207UiN@80FUYJ0P1GEeL2069RHP80OGem0P1d
M7@206][J`<0HF5Q0P1XJ6P2075aL@80M7Ad0P1eMGD407AdM080NGUi0P1nOWh208>3P`80QXJ60P27
QhL208V9R@80TI6A0P2HV9P209VIVBT0b>3H0P0h>3P202PX:0809RHV0P0W9bL202HV9P80;Bd]0P10
@40206EUI@80Ogmo0P1?Cdl203De=@80;Rh^0P0a<C4202TY:@80=CDe0P0[:b/302TY:@80<C4a0P0]
;Bd2034a<@80?Cdm0P0];Bd202PX:080;Bd]0P0V9RH202`/;080:b/[0P0X:2P202<S8`80;Bd]0P0W
9bL202@T90809RHV0P0_;bl205YJFP80N7Qh0P1cLg<2055AD@80G5aL0P1mOGd209NGU`80/K6a0P2N
WYh209>CT`80UiNG0P2CTi<209VIV@80XZ:R0`2ZZZX20;Bd]080^k^k0P33`l<20<K6aP80bLW90P3:
b/X20<S8b0@0aLG50P33`l<20<;2`P80V9RH0P1WIfL206e]K@80IFEU0P1cLg<207QhN080NWYj0P1e
MGD206i^KP80I6AT0P1QHF4205mOG`80EUIF0P1>CTh203Lg=`80;bl_0P0c<c<204E5A@80De=C0P1J
FUX306a/K080Ogmo0P1cLg<205QHF080>c/k0P0l?3`204m?C`80EeMG0P1JFUX2051@D080CDe=0P0g
=cL20451@@80LG5a0P2][Jd20<o?c`80dm?C0P3Bd]840=?Cd`80cLg=0P3>c/h20<[:bP80][Jf0P2N
WYh207]kN`80GEeM0P1DE5@206=SH`80OWin0P1fMWH206IVIP<0HV9R0P1[Jf/406m_K`80MGEe0P1b
LW8207IfMP80NWYj1020P80208J6QP80R8R80P29RHT2092@T080UiNG0P2RXZ8Y0<SPf080>CTi0P0/
;2`202PX:080820P0P0/;2`2034a<@80>c/k0P1/K6`2075aL@80Bd];0P0g=cL202HV9P80;Bd]0P0d
=3@402d];@<0:b/[100Y:BT203De=@80>CTi0P0`<30202PX:0808b<S0P0U9BD202`/;0@0;Bd]1P0X
:2P2024Q8@808b<S0P0Z:RX206=SH`80Ph>30P1aLG4205EEE@80GEeM0P1lO7`209jNWP80^k^k0P2R
XZ8209nOW`80WIfM0P2PX:0209^KV`80Y:BT0`2][Jd20;Ng]`80^KVi1035aLD20<O7a`80a<C40P37
alL20;bl_080cLg=0P3;bl/20:n_[`80UIFE0P1jNWX206][J`80JFUY0P1_Kfl407]kN`80Lg=c0P1W
IfL206YZJP80I6AT0P1EEED2059BDP80ADE50P0o?cl202l_;`80;Rh^0P0i>CT204m?C`80I6AT0`1/
K6`207MgM`80Lg=c0P1NGUh203lo?`80@d=30P1<C4`2059BDP80Hf=S0P1DE5@204Q8B080?clo0P1>
CTh206QXJ080YZJV0P3;bl/20=3@d080dm?C0P3AdM420<k>cP80alO70P3?cll20<S8b080^;Rh0P2P
X:0207MgM`80EeMG0P1HF5P206MWI`80P8200P1gMgL206QXJ0<0HF5Q0P1WIfL206e]K@80LW9b0P1f
MWH207UiN@80Lg=c0P1gMgL207emO@@0Q8B40P29RHT208F5Q@80U9BD0P2JVYX209bLW1l0b>3H000M
0<SPf080<c<c0P0^;Rh202TY:@@09RHV0P0d=3@20451@@80Ng]k0P1eMGD20451@@80@4100P0`<302
02XZ:P80:2PX0P0Z:RX202/[:`<0;2`/0P0Z:RX202/[:`80<c<c0P0h>3P2034a<@809bLW0P0V9RH2
02PX:080;2`/0P0_;bl202/[:`@09BDU0P0V9RH2028R8P8092@T0P0d=3@204Q8B080K6a/0P27QhL2
075aL@80FEUI0P1^KVh208Z:RP80aLG50P2f][H20:j^[P80W9bL0P2FUYH209FEU@80WIfM0`2WYjL2
0:j^[P80]KFe0P2m_Kd20<G5a@80bLW90P3<c<`20<W9b@H0aLG50P3;bl/20<K6aP80UIFE0P1UIFD2
06=SH`80Jf][0P1_Kfl2075aL@80JFUY0P1NGUh205MGE`80D51@0P1:BTX204=3@`80>3Ph0P0_;bl2
02h^;P80<c<c0P0n?Sh204i>CP80IFEU0`1fMWH2071`L080HV9R0P1;Bd/203Ti>@80CDe=0P1TI6@2
05aLG080D51@0P1FEUH205aLG080ATI60P0m?Cd203`l?080PX:20P39bLT20<k>cP80eMGE103@d=02
0<k>cP80clo?0P3:b/X20;Fe]@80UiNG0P1[Jf/204M7A`80DU9B0P1RHV8208B4Q0@0Hf=S0`1QHF42
06UYJ@80LG5a0P1`L70206m_K`80Lg=c0P1gMgL207YjNP80OGem0P22PX8208J6QP80QhN70P28R8P2
092@T080UiNG0P2IVITY0<SPf080>3Ph0P0^;Rh202/[:`80:BTY0P0[:b/2034a<@80ADE50P1iNGT2
07MgM`80ATI60P0n?Sh202`/;080:BTY0P0Z:RX202`/;080:RXZ0`0];Bd202`/;080:RXZ0P0`<302
03Xj>P80;Rh^0P0Z:RX202HV9P80:2PX0P0Y:BT402/[:`809BDU0P0W9bL202<S8`@09BDU0P0^;Rh2
04Y:BP80JFUY0P24Q8@2079bLP80EUIF0P1/K6`209>CT`80_;bl0P2o_kl20:RXZ080XJ6Q0P2IVIT2
09FEU@80VIVI0`2XZ:P20:f][@80/k>c0P2n_[h20<?3``@0b/[:0P3;bl/20<K6aP80`L710P36a/H4
0<O7a`80Ti>C0P1YJFT2069RHP80IfMW0P1dM7@206i^KP80JFUY0P1LG5`205ADE080DU9B0P1>CTh2
0492@P80>c/k0P0^;Rh202/[:`80;Bd]0P15ADD204Y:BP80GEeM0`1eMGD207UiN@80Hf=S0P13@d<2
03Xj>P80E5AD0P1RHV8405IFEP80Fe]K0P1CDe<204Q8B080>CTi0P12@T8207inOP80aLG50P3AdM42
0<k>cP80d=3@0P3Bd]820<g=c@80c/k>0P38b<P20;Jf]P80UIFE0P1/K6`204a<C080ATI60P1/K6`2
07inOP80JVYZ0P1LG5`3061PH0@0L71`0P1]KFd2071`L080MWIf0P1iNGT207YjNP80OGem0P21PH42
08F5Q@80RXZ:0P28R8P208f=S@80UIFE0P2LW9`Y0<SPf080=CDe0P0_;bl202d];@8071`L0P0/;2`2
034a<@80@D510P20P80207AdM080@D510P0m?Cd2038b<P80:2PX0P0[:b/202`/;0809RHV0`0/;2`2
02XZ:P80:BTY0P0b<S8203De=@80=3@d0P0V9RH402LW9`80;Rh^0P0];Bd202PX:0809RHV0P0R8R82
02@T90809bLW0P0S8b<203De=@80C4a<0P1XJ6P208Z:RP80MGEe0P1FEUH206e]K@80RHV90P32`/82
0;Jf]P80Zj^[0P2KVi/209VIV@80UIFE0P2KVi/30:JVYP80[jn_0P2c/k<20;fm_@80bLW90P33`l<2
0<k>cP80cLg=0P35aLD20<K6aP80aLG50P37alL20<;2`P80WIfM0P1PH60205iNGP80KFe]0P1/K6`2
07AdM080IFEU0P1RHV82059BDP80De=C0P19BDT204Q8B080=CDe0P0`<30202TY:@80<C4a0P10@402
04M7A`80IVIV0`1fMWH2079bLP80GemO0P19BDT203Xj>P80B4Q80P1WIfL205]KF`80DU9B0P1IFET2
05aLG080ADE5100m?Cd208>3P`80`/;20P3@d=020=OGe`80d=3@0P3?cll40=3@d080bLW90P2g]kL2
09NGU`80KFe]0P1:BTX2059BDP80HF5Q0P20P802065QH@80Hf=S0`1QHF4206e]K@80LG5a0P1_Kfl2
06e]K@@0LW9b0P1iNGT207]kN`80QXJ61025QHD208V9R@80TI6A0P2FUYH209FEUAl0b>3H000M0<SP
f080<c<c0P0^;Rh202TY:@@09RHV0P0d=3@20451@@80Ng]k0P1eMGD20451@@80@4100P0`<30202XZ
:P80:2PX0P0Z:RX202/[:`<0;2`/0P0Z:RX202/[:`80<c<c0P0h>3P2034a<@809bLW0P0V9RH202PX
:080;2`/0P0_;bl202/[:`@09BDU0P0V9RH2028R8P8092@T0P0d=3@204Q8B080K6a/0P27QhL2075a
L@80FEUI0P1^KVh208Z:RP80aLG50P2f][H20:j^[P80W9bL0P2FUYH209FEU@80WIfM0`2WYjL20:j^
[P80]KFe0P2m_Kd20<G5a@80bLW90P3<c<`20<W9b@H0aLG50P3;bl/20<K6aP80UIFE0P1UIFD206=S
H`80Jf][0P1_Kfl2075aL@80JFUY0P1NGUh205MGE`80D51@0P1:BTX204=3@`80>3Ph0P0_;bl202h^
;P80<c<c0P0n?Sh204i>CP80IFEU0`1fMWH2071`L080HV9R0P1;Bd/203Ti>@80CDe=0P1TI6@205aL
G080D51@0P1FEUH205aLG080ATI60P0m?Cd203`l?080PX:20P39bLT20<k>cP80eMGE103@d=020<k>
cP80clo?0P3:b/X20;Fe]@80UiNG0P1[Jf/204M7A`80DU9B0P1RHV8208B4Q0@0Hf=S0`1QHF4206UY
J@80LG5a0P1`L70206m_K`80Lg=c0P1gMgL207YjNP80OGem0P22PX8208J6QP80QhN70P28R8P2092@
T080UiNG0P2IVITY0<SPf080>3Ph0P0^;Rh202/[:`80:BTY0P0[:b/2034a<@80ADE50P1iNGT207Mg
M`80ATI60P0n?Sh202`/;080:BTY0P0Z:RX202`/;080:RXZ0`0];Bd202`/;080:RXZ0P0`<30203Xj
>P80;Rh^0P0Z:RX202HV9P80:2PX0P0Y:BT402/[:`809BDU0P0W9bL202<S8`@09BDU0P0^;Rh204Y:
BP80JFUY0P24Q8@2079bLP80EUIF0P1/K6`209>CT`80_;bl0P2o_kl20:RXZ080XJ6Q0P2IVIT209FE
U@80VIVI0`2XZ:P20:f][@80/k>c0P2n_[h20<?3``@0b/[:0P3;bl/20<K6aP80`L710P36a/H40<O7
a`80Ti>C0P1YJFT2069RHP80IfMW0P1dM7@206i^KP80JFUY0P1LG5`205ADE080DU9B0P1>CTh20492
@P80>c/k0P0^;Rh202/[:`80;Bd]0P15ADD204Y:BP80GEeM0`1eMGD207UiN@80Hf=S0P13@d<203Xj
>P80E5AD0P1RHV8405IFEP80Fe]K0P1CDe<204Q8B080>CTi0P12@T8207inOP80aLG50P3AdM420<k>
cP80d=3@0P3Bd]820<g=c@80c/k>0P38b<P20;Jf]P80UIFE0P1/K6`204a<C080ATI60P1/K6`207in
OP80JVYZ0P1LG5`3061PH0@0L71`0P1]KFd2071`L080MWIf0P1iNGT207YjNP80OGem0P21PH4208F5
Q@80RXZ:0P28R8P208f=S@80UIFE0P2LW9`Y0<SPf080=CDe0P0_;bl202d];@8071`L0P0/;2`2034a
<@80@D510P20P80207AdM080@D510P0m?Cd2038b<P80:2PX0P0[:b/202`/;0809RHV0`0/;2`202XZ
:P80:BTY0P0b<S8203De=@80=3@d0P0V9RH402LW9`80;Rh^0P0];Bd202PX:0809RHV0P0R8R8202@T
90809bLW0P0S8b<203De=@80C4a<0P1XJ6P208Z:RP80MGEe0P1FEUH206e]K@80RHV90P32`/820;Jf
]P80Zj^[0P2KVi/209VIV@80UIFE0P2KVi/30:JVYP80[jn_0P2c/k<20;fm_@80bLW90P33`l<20<k>
cP80cLg=0P35aLD20<K6aP80aLG50P37alL20<;2`P80WIfM0P1PH60205iNGP80KFe]0P1/K6`207Ad
M080IFEU0P1RHV82059BDP80De=C0P19BDT204Q8B080=CDe0P0`<30202TY:@80<C4a0P10@40204M7
A`80IVIV0`1fMWH2079bLP80GemO0P19BDT203Xj>P80B4Q80P1WIfL205]KF`80DU9B0P1IFET205aL
G080ADE5100m?Cd208>3P`80`/;20P3@d=020=OGe`80d=3@0P3?cll40=3@d080bLW90P2g]kL209NG
U`80KFe]0P1:BTX2059BDP80HF5Q0P20P802065QH@80Hf=S0`1QHF4206e]K@80LG5a0P1_Kfl206e]
K@@0LW9b0P1iNGT207]kN`80QXJ61025QHD208V9R@80TI6A0P2FUYH209FEUAl0b>3H000M0<SPf080
<30`0P0_;bl202d];@80:2PX0P0Y:BT2030`<080DU9B0P2=SHd205mOG`80=3@d0P12@T8203<c<`80
:BTY0P0V9RH202LW9`80:BTY1`0/;2`203<c<`80=cLg0P0a<C4202XZ:P@09bLW0P0];Bd2034a<@80
;Rh^0P0Z:RX402LW9`80;Rh^0P0h>3P203`l?080@d=30P1CDe<208B4Q080T92@0P1`L70206UYJ@80
KVi^0P2][Jd20<G5a@80^k^k0P2VYZH40::RXP80Z:RX0`2_[jl20;>c/`80]kNg0P2j^[X20;jn_P80
a/K60P3=cLd20<_;b`80b<S81037alL20<g=c@80bl_;0P2a/K42096AT@80K6a/0P1GEeL205mOG`80
JFUY0P1RHV8205IFEP80Bd];0P11@D4203`l?080=cLg0P0a<C4202d];@80;Rh^0P0b<S8203dm?@80
Bd];0P1SHf<307AdM080HV9R0P1>CTh203`l?080DU9B0P1GEeL205YJFP80BTY:0P0l?3`204U9B@80
DE5A0P1KFe/204M7A`80:b/[0P1LG5`20;Fe]@80bl_;0P3Bd]820<[:bP80cLg=0P3>c/h20<[:bP80
`l?30P2UYJD20861P@80Fe]K0P13@d<205aLG080MgMg0P1kNg/205UIF@80H61P0`1ZJVX2071`L080
Lg=c0P1aLG4206m_K`80MGEe0P1lO7`207moO`80P8200P24Q8@208N7Q`80RHV90P2;Rh/208n?S`80
Ti>C0P2DU9@Y0<SPf080=CDe0P0Z:RX2030`<0809RHV0P0W9bL202h^;P80DU9B0P28R8P205ADE080
=SHf0P14A4@4030`<0808b<S0P0T92@202HV9P<0;bl_0P0V9RH202h^;P80=cLg0P0h>3P202l_;`80
:b/[0P0Y:BT202LW9`80=3@d0P0i>CT2038b<P80:b/[0P0U9BD202PX:080;Bd]0P0e=CD204Q8B080
BTY:0P1RHV8208V9R@80WIfM0P1eMGD2061PH080M7Ad0P2YZJT20<g=c@80_kno0P2ZZZX20:BTY080
[Jf]0P2ZZZX30;:b/P80^k^k0P2f][H20;fm_@80_;bl0P38b<P20<W9b@80bl_;1036a/H20<g=c@80
bLW90P38b<P20<;2`P80SHf=0P1MGEd2065QH@80Jf][0P1UIFD2065QH@80EUIF0P1CDe<20410@080
=CDe0P0c<c<2030`<080<C4a0P0];Bd202l_;`80@T920P17AdL205mOG`<0Lg=c0P1[Jf/204M7A`80
=3@d0P1LG5`2069RHP80FUYJ0P18B4P40492@P80FUYJ0P1/K6`204Y:BP80=CDe0P1GEeL20;6a/@80
clo?103<c<`20<k>cP80bl_;0P38b<P20;no_`80Zj^[0P20P80205QHF080ATI60P1HF5P207alO080
N7Qh0P1NGUh205YJFP<0K6a/0P1gMgL2079bLP80L71`0P1aLG4207=cL`80N7Qh0P1kNg/20861P@80
QXJ60P27QhL208R8R080Rh^;0P2=SHd2096AT@80VIVI:@38h=P202d];@@0;bl_0P0];Bd202TY:@80
;2`/0P1@D50208j>SP80HF5Q0P0b<S8204I6AP80=3@d0P0W9bL202PX:0808R8R0P0X:2P302h^;P80
<C4a0P0];Bd203Xj>P80=SHf0P0b<S8602XZ:P80:b/[0P0c<c<2030`<080:BTY0P0X:2P202TY:@80
;Rh^0P0j>SX203`l?080@D510P1BDU8208F5Q@80T92@0P1_Kfl206QXJ080K6a/0P2e]KD20<?3``80
_;bl0P2UYJD209nOW`80YJFU0P2[Zj/30;6a/@80];Bd0P2k^k/20;Ng]`80_[jn0P3:b/X20<o?c`80
c<c<1038b<P20<O7a`80c<c<0P3?cll20;Bd]080TI6A0P1[Jf/205iNGP80H61P0P1ZJVX205mOG`80
GEeM0P14A4@204Q8B080>SXj0P0k>c/202`/;0@0<C4a0P0e=CD20410@080CDe=0P1RHV83071`L080
HV9R0P1>CTh20451@@80EEEE0P1GEeL205]KF`80B4Q80P0j>SX204E5A@80De=C0P1IFET204M7A`80
;Rh^0P1QHF420;Jf]P80c/k>0P3=cLd20<c<c080cLg=0P3?cll20<[:bP80`/;20P2RXZ8207inOP80
FEUI0P12@T8205QHF080NGUi0P1mOGd205eMG@80H61P0`1UIFD2079bLP80MGEe0P1bLW82071`L080
NGUi0P23Ph<208B4Q080OWin0P26QXH208N7Q`80R8R80P2;Rh/208f=S@80TY:B0P2EUIDO0<SPf000
7@38h=P2030`<080;bl_0P0];Bd202PX:080:BTY0P0`<302059BDP80SHf=0P1OGel203@d=080@T92
0P0c<c<202TY:@809RHV0P0W9bL202TY:@L0;2`/0P0c<c<203Lg=`80<C4a0P0Z:RX402LW9`80;Bd]
0P0a<C4202h^;P80:RXZ100W9bL202h^;P80>3Ph0P0l?3`204=3@`80De=C0P24Q8@2092@T080L71`
0P1YJFT206i^KP80[Jf]0P35aLD20;^k^`80YZJV102RXZ820:RXZ0<0[jn_0P2c/k<20;Ng]`80^[Zj
0P2n_[h20<K6aP80cLg=0P3;bl/20<S8b0@0alO70P3=cLd20<_;b`80/K6a0P2ATI4206a/K080EeMG
0P1OGel206UYJ@80HV9R0P1FEUH204];B`80@D510P0l?3`203Lg=`80<C4a0P0];Bd202h^;P80<S8b
0P0m?Cd204];B`80Hf=S0`1dM7@2069RHP80CTi>0P0l?3`2059BDP80EeMG0P1JFUX204Y:BP80?3`l
0P19BDT2055AD@80Fe]K0P17AdL202/[:`80G5aL0P2e]KD20<_;b`80d];B0P3:b/X20<g=c@80c/k>
0P3:b/X20<?3``80YJFU0P21PH4205]KF`80@d=30P1LG5`207MgM`80Ng]k0P1IFET2061PH0<0JVYZ
0P1`L70207=cL`80LG5a0P1_Kfl207EeM@80O7al0P1oOgl20820P080Q8B40P27QhL208V9R@80Rh^;
0P2?Shl209>CT`80U9BD:@38h=P203De=@80:RXZ0P0`<30202HV9P809bLW0P0^;Rh2059BDP80R8R8
0P1DE5@203Hf=P80A4A4100`<30202<S8`8092@T0P0V9RH302l_;`809RHV0P0^;Rh203Lg=`80>3Ph
0P0_;bl202/[:`80:BTY0P0W9bL203@d=080>CTi0P0b<S8202/[:`809BDU0P0X:2P202d];@80=CDe
0P18B4P204Y:BP80HV9R0P29RHT209fMW@80MGEe0P1PH60207AdM080ZJVY0P3=cLd20;no_`80ZZZZ
0P2TY:@20:f][@80ZZZZ0`2b/[820;^k^`80][Jf0P2m_Kd20;bl_080b<S80P39bLT20<_;b`@0a/K6
0P3=cLd20<W9b@80b<S80P32`/8208f=S@80GEeM0P1QHF4206][J`80IFEU0P1QHF4205IFEP80De=C
0P10@40203De=@80<c<c0P0`<302034a<@80;Bd]0P0_;bl20492@P80AdM70P1OGel307=cL`80Jf][
0P17AdL203@d=080G5aL0P1RHV8205YJFP80B4Q81012@T8205YJFP80K6a/0P1:BTX203De=@80EeMG
0P2a/K420<o?c`@0c<c<0P3>c/h20<_;b`80b<S80P2o_kl20:^[Z`80P8200P1HF5P204I6AP80F5QH
0P1lO7`207QhN080GUiN0P1JFUX306a/K080MgMg0P1bLW82071`L080LG5a0P1cLg<207QhN080Ng]k
0P21PH4208J6QP80QhN70P28R8P208^;R`80SHf=0P2ATI4209VIVBT0b>3H0P0];Bd402l_;`80;Bd]
0P0Y:BT202`/;080D51@0P2>SXh2065QH@80<S8b0P16ATH203@d=0809bLW0P0X:2P2028R8P80:2PX
0`0^;Rh2034a<@80;Bd]0P0j>SX203Hf=P80<S8b1P0Z:RX202/[:`80<c<c0P0`<30202TY:@80:2PX
0P0Y:BT202h^;P80>SXj0P0l?3`20451@@80DU9B0P25QHD2092@T080Kfm_0P1XJ6P206a/K080]KFe
0P33`l<20;bl_080YJFU0P2OWil20:FUY@80Zj^[0`2a/K420;Bd]080^k^k0P2g]kL20;jn_P80b/[:
0P3?cll20<c<c0@0b<S80P37alL20<c<c080clo?0P2d];@2096AT@80Jf][0P1NGUh2061PH080JVYZ
0P1OGel205eMG@80A4A40P18B4P203Xj>P80>c/k0P0/;2`4034a<@80=CDe0P10@40204e=C@80HV9R
0`1`L702069RHP80CTi>0P11@D4205EEE@80EeMG0P1KFe/204Q8B080>SXj0P15ADD205=CD`80FEUI
0P17AdL202h^;P80HF5Q0P2f][H20<k>cP80cLg=0P3<c<`20<g=c@80clo?0P3:b/X20<;2`P80XZ:R
0P1nOWh205UIF@80@T920P1HF5P207UiN@80OGem0P1MGEd2061PH0<0IFEU0P1bLW8207EeM@80LW9b
0P1`L70207UiN@80Ph>30P24Q8@207inOP80QXJ60P27QhL208R8R080Rh^;0P2=SHd209:BTP80UIFE
7`38h=P001d0b>3H0P0^;Rh202l_;`80<C4a0P0Z:RX202`/;080;bl_0P1UIFD209FEU@80ATI60P0X
:2P20451@@80<c<c0P0Y:BT202HV9P809BDU0P0X:2P302`/;080;Bd]0P0^;Rh2038b<P80=SHf0P0c
<c<202h^;P80:RXZ0P0X:2P202h^;P@0=CDe0P0c<c<202`/;080:BTY0P0k>c/204e=C@80A4A40P0o
?cl203Xj>P80MGEe0P2TY:@208Z:RP80K6a/0P1HF5P208b<S080alO70P33`l<20;>c/`@0/;2`0P2d
];@30;Rh^080^KVi0P2j^[X40;Ng]`80`/;20P3<c<`20<g=c@@0b/[:0P39bLT20<S8b080a/K60P39
bLT20<71`@80NGUi0P1BDU8205ADE080HF5Q0P1KFe/2055AD@80ADE50P0i>CT203@d=080<S8b0P0_
;bl402h^;P80<C4a0P0i>CT204E5A@80GEeM0`1]KFd2059BDP80>c/k0P0a<C4206UYJ@80Fe]K0P18
B4P2038b<P808b<S0P0g=cL204Y:BP80L71`0P1DE5@202`/;080B4Q80P2TY:@20<S8b080c/k>0P34
a<@20<S8b080bLW90P30`<020;:b/P80S8b<0P1UIFD204];B`80@T920P1TI6@208F5Q@80K6a/0P1B
DU82061PH0<0M7Ad0P1hN7P207MgM`80Lg=c0P1aLG4207UiN@80PH610P23Ph<208B4Q080QhN70P2:
RXX208b<S080SXj>0P2@T904096ATBT0b>3H0P0X:2P203De=@80:b/[100/;2`203@d=080IVIV0P2=
SHd204U9B@80<C4a0P0m?Cd203De=@80:BTY0P0W9bL202TY:@80:2PX1@0^;Rh202l_;`80;2`/0P0j
>SX4038b<P80:RXZ0P0[:b/202XZ:P80=3@d0P0j>SX203@d=080:RXZ0P0Y:BT202l_;`80BDU90P1;
Bd/203Ti>@80>c/k0P1dM7@209RHV080SXj>0P1WIfL205aLG080S8b<0P32`/820<W9b@80];Bd0P2T
Y:@20:n_[`80][Jf0`2c/k<40;Vi^@80^;Rh0P2g]kL20<30`080c<c<0P3?cll20<_;b`80alO71039
bLT20<C4a080bLW90P2m_Kd207YjNP80D51@0P1KFe/205iNGP80EUIF0P1ADE4204A4A0@0>3Ph0P0e
=CD203<c<`80:RXZ0P0^;Rh203@d=080>3Ph0P16ATH205aLG0<0IfMW0P1JFUX2038b<P80>CTi0P1N
GUh205eMG@80C4a<0P0`<30202TY:@80:b/[0P15ADD2071`L080CDe=0P0h>3P20492@P80WIfM103<
c<`60<K6aP80`L710P2/[:`2092@T080HV9R0P16ATH204A4A080GEeM0P23Ph<206i^KP80E5AD0P1K
Fe/307AdM080NWYj0P1eMGD207AdM080LG5a0P1cLg<208R8R080PX:20P24Q8@208V9R@80Rh^;0P29
RHT2092@T080S8b<0P2?Shl209VIVBT0b>3H0P0];Bd202h^;P80;bl_0P0/;2`202XZ:P80;Rh^0P1X
J6P209JFUP80B4Q80P0T92@20410@080=CDe0P0Z:RX202HV9P8092@T0P0];Bd302TY:@@0:RXZ0P0d
=3@203De=@80<30`0P0/;2`2034a<@80:BTY0P0`<30203<c<`80=3@d0P0_;bl203<c<`809BDU0P0m
?Cd2051@D080@d=30P11@D4203Ti>@80MWIf0P2SXj<208Z:RP80Kfm_0P1GEeL208b<S080b<S80P2o
_kl20;Ng]`80Zj^[0P2a/K420;Jf]P<0^;Rh0P2d];@20;Zj^P80/[:b0P2i^KT20<G5a@80c<c<0P3:
b/X20<_;b`80c/k>0P38b<P20<W9b@80a<C40P37alL20<?3``80NWYj0P1<C4`205UIF@80GemO0P1I
FET2055AD@80@4100P0j>SX203Ti>@80=3@d0P0[:b/2038b<P80;bl_0P0b<S8203<c<`80AdM70P1N
GUh306i^KP80DU9B0P0k>c/202l_;`80JFUY0P1GEeL204M7A`80>3Ph0P0U9BD203De=@80B4Q80P1_
Kfl205ADE080;Bd]0P15ADD20::RXP80alO70P3=cLd20<C4a080bLW90P38b<P20;fm_@80/k>c0P2=
SHd206EUI@80CDe=0P15ADD2061PH080QXJ60P1]KFd204i>CP80GemO0`1hN7P207IfMP80MgMg0P1b
LW82075aL@80MGEe0P1nOWh208>3P`80QHF50P24Q8@208V9R@80SXj>0P2?Shl208^;R`80Shn?0P2G
UiLO0<SPf0007@38h=P202h^;P80;bl_0P0a<C4202XZ:P80;2`/0P0_;bl206EUI@80UIFE0P16ATH2
02PX:080@D510P0c<c<202TY:@809RHV0P0U9BD202PX:0<0;2`/0P0];Bd202h^;P80<S8b0P0f=SH2
03<c<`80;Rh^0P0Z:RX202PX:080;Rh^100e=CD203<c<`80;2`/0P0Y:BT203/k>`80CDe=0P14A4@2
03lo?`80>SXj0P1eMGD20:BTY080RXZ:0P1/K6`205QHF080S8b<0P37alL20<?3``80/k>c102`/;02
0;Bd]0<0^;Rh0P2i^KT20;Zj^P@0]kNg0P32`/820<c<c080cLg=103:b/X20<W9b@80b<S80P36a/H2
0<W9b@80`L710P1iNGT2059BDP80E5AD0P1QHF4205]KF`80DE5A0P15ADD203Ti>@80=3@d0P0b<S82
02l_;`@0;Rh^0P0a<C4203Ti>@80ADE50P1MGEd306e]K@80DU9B0P0k>c/2034a<@80JFUY0P1KFe/2
04Q8B080<S8b0P0S8b<203Lg=`80BTY:0P1`L70205ADE080;2`/0P18B4P20:BTY080b<S80P3>c/h2
0<C4a080b<S80P39bLT20<30`080/[:b0P2<S8`206EUI@80Bd];0P12@T8206ATI080QHF50P1/K6`2
059BDP80H61P0`1dM7@207QhN080MgMg0P1cLg<2075aL@80NGUi0P21PH4208>3P`80Q8B40P27QhL2
08Z:RP80S8b<0P2>SXh2092@T0@0TI6A:@38h=P202PX:080=CDe0P0[:b/402`/;080=3@d0P1VIVH2
08f=S@80BDU90P0a<C4203dm?@80=CDe0P0Y:BT202LW9`80:BTY0P0X:2P502h^;P80;bl_0P0/;2`2
03Xj>P@0<S8b0P0Z:RX202/[:`80:RXZ0P0d=3@203Xj>P80=3@d0P0Z:RX202TY:@80;bl_0P19BDT2
04];B`80>CTi0P0k>c/207AdM080V9RH0P2>SXh206MWI`80G5aL0P2<S8`20<;2`P80bLW90P2d];@2
0:BTY080[jn_0P2f][H30;>c/`@0^KVi0P2h^;P20;Ng]`80`<300P3<c<`20<o?c`80bl_;0P37alL4
0<W9b@80a<C40P39bLT20;fm_@80NWYj0P1@D50205]KF`80GUiN0P1FEUH2055AD@80A4A4100h>3P2
03De=@80<c<c0P0Z:RX202h^;P80=3@d0P0h>3P204I6AP80G5aL0`1WIfL205YJFP80<S8b0P0i>CT2
05iNGP80GEeM0P1<C4`2030`<080:BTY0P0[:b/204E5A@80L71`0P1=CDd203Ph>080@T920P2MWId4
0<c<c0H0a/K60P31`L420:b/[080T92@0P1RHV8204I6AP80A4A40P1MGEd208>3P`80KVi^0P1DE5@2
05]KF`<0M7Ad0P1jNWX207EeM@80M7Ad0P1aLG4207=cL`80R8R80P22PX8208B4Q080RHV90P2;Rh/2
08V9R@80T92@0P2<S8`208n?S`80VIVI:@38h=P202d];@80;Rh^0P0_;bl202`/;080:RXZ0P0^;Rh2
06QXJ080UYJF0P18B4P202@T9080@4100P0e=CD202XZ:P809RHV0P0T92@202d];@<0:BTY100Z:RX2
03@d=080=CDe0P0`<30202`/;080<C4a0P0Y:BT2030`<080<c<c0P0d=3@202l_;`80<c<c0P0U9BD2
03dm?@80D51@0P13@d<20451@@80>CTi0P1fMWH20:>SX`80RXZ:0P1_Kfl205MGE`80S8b<0P38b<P2
0;no_`80]kNg0P2[Zj/20;6a/@80][Jf0`2h^;P20;Bd]080^[Zj0P2b/[820;Vi^@80aLG50P3<c<`2
0<[:bP80bl_;0P3>c/h20<S8b080bLW90P34a<@20<O7a`80`l?30P1jNWX204a<C080FEUI0P1OGel2
05UIF@80DE5A0P10@40203Xj>P80>CTi0P0d=3@202/[:`80<S8b0P0_;bl2038b<P80<c<c0P17AdL2
05iNGP<0KVi^0P1BDU8203/k>`80;bl_0P1YJFT205MGE`80AdM70P0h>3P202DU9@80=CDe0P18B4P2
06m_K`80E5AD0P0];Bd204E5A@80XZ:R0P37alL20<g=c@80a<C40P39bLT20<S8b080_Kfm0P2c/k<2
08f=S@80IFEU0P1=CDd204E5A@80H61P0P26QXH206e]K@80CTi>0P1OGel307QhN080MWIf0P1gMgL2
079bLP80LG5a0P1eMGD207inOP80Ph>30P25QHD208B4Q080RHV90P2>SXh208n?S`80Rh^;0P2?Shl2
09NGUal0b>3H000M0<SPf080;bl_100^;Rh202LW9`80<30`0P0g=cL207QhN080OGem0P0i>CT202PX
:080=SHf0P0a<C4202d];@80:RXZ0P0X:2P202XZ:PD0;Bd]0P0^;Rh202l_;`80<30`0P0a<C42038b
<P80;2`/0P0Y:BT203Lg=`80ATI60P18B4P204A4A080>3Ph0P0[:b/2028R8P807AdM0P0Q8B4402h^
;P80De=C0P2?Shl209RHV080RHV90P1FEUH207IfMP80XZ:R0P2g]kL20<;2`P80];Bd0P2YZJT20:f]
[@<0];Bd0P2f][H20;Ng]`@0]KFe0P2k^k/20<?3``80bLW90P3=cLd20<_;b`@0alO70P36a/H20<S8
b080_Kfm0P2k^k/2075aL@80F5QH0P1=CDd205ADE080EEEE0P1<C4`20492@P80>c/k0P0f=SH2030`
<0@0:b/[0P0^;Rh203@d=080?Cdm0P1@D50305eMG@80ATI6100b<S8205IFEP80BTY:0P0i>CT202/[
:`809BDU0P0L71`203Ph>080E5AD0P1?Cdl203Hf=P80A4A40P2GUiL20<o?c`80dm?C0P34a<@20<;2
`P80^KVi0P2e]KD208V9R@80IFEU0P15ADD203`l?080?clo0P1EEED206YZJP80F5QH0P1<C4`2065Q
H@<0Ng]k0P1mOGd207YjNP80MWIf0P1dM7@207YjNP80PH610P24Q8@208J6QP80R8R80P2;Rh/208j>
SP80T92@0P2BTY8409>CTbT0b>3H0P0W9bL203Ph>080;Rh^0P0W9bL202`/;080?Shn0P1jNWX207em
O@80?clo0P0[:b/203De=@80:b/[0P0/;2`202PX:080:RXZ0P0[:b/302TY:@80<c<c0P0`<30202l_
;`80<C4a0P0^;Rh202l_;`@0:b/[0P0];Bd20410@080B4Q80P11@D4203Ph>080>SXj0P0U9BD202HV
9P809bLW0P0Q8B4202DU9@80DU9B0P2=SHd20:6QX@80OWin0P1PH60206a/K080W9bL0P36a/H20;fm
_@80Y:BT0P2][Jd20:n_[`<0/K6a0P2g]kL20;:b/P80/K6a0P2g]kL20;Vi^@80`l?30P3>c/h20<_;
b`80b/[:0P37alL20<71`@80b<S80P35aLD20<_;b`80]kNg0P1[Jf/2055AD@80DU9B0P1HF5P205EE
E@80CTi>0P14A4@203Ph>080<C4a0P0e=CD202`/;080:RXZ0P0/;2`203<c<`80@D510P1BDU8305YJ
FP80DE5A0P0b<S8203`l?080D51@0P1?Cdl2030`<0809RHV0P0T92@202LW9`80>3Ph0P1JFUX20451
@@80<S8b0P18B4P20:>SX`@0c<c<0P37alL40<30`080^KVi0P2;Rh/206][J`80B4Q80P0l?3`203hn
?P80J6QX0P1/K6`205ADE080Bd];0P1TI6@307]kN`80O7al0P1hN7P207YjNP80MgMg0P1iNGT20820
P080QhN70P22PX8208N7Q`@0Rh^;0P2FUYH208f=S@80TI6A0P2JVYXY0<SPf080=CDe0P0_;bl202/[
:`809BDU0P0c<c<203Ph>080MgMg0P1lO7`203Ph>080;2`/0P0d=3@2030`<080;2`/0P0W9bL402`/
;0<0;Bd]0P0/;2`2034a<@80<30`0P0e=CD202TY:@80=SHf0P0Y:BT2024Q8@80<S8b0P16ATH204i>
CP80@d=30P0i>CT202XZ:P@071`L0P0K6a/2038b<P80<C4a0P1DE5@208Z:RP80V9RH0P2:RXX205MG
E`80Kfm_0P2UYJD20;Vi^@80`l?30P2d];@20:RXZ080[:b/1@2d];@20;fm_@80^KVi0P2d];@20;^k
^`80`L710P38b<P20<W9b@80c<c<0P33`l<20<[:bP80a/K60P35aLD40;^k^`80Kfm_0P1IFET204e=
C@80DU9B0P1KFe/204];B`80@4100P0j>SX2038b<P80:b/[0P0W9bL202PX:0@0;bl_0P0l?3`2051@
D0<0GEeM0P17AdL2034a<@80=CDe0P1GEeL204E5A@80?3`l0P0];Bd201dM7@808b<S0P0g=cL205eM
G@80C4a<0P0`<30204E5A@80UiNG0P3AdM420=?Cd`80a<C40P32`/820;bl_080][Jf0P2:RXX206IV
IP80AdM70P0k>c/203lo?`80EEEE0P1XJ6P205eMG@80Bd];0P1SHf<307alO080NGUi0P1kNg/207If
MP80MgMg0P1hN7P207moO`80QXJ60P23Ph<208N7Q`80RXZ:0P2BTY8208j>SP80TI6A0P2EUID209RH
V1l0b>3H000M0<SPf080;bl_100^;Rh202LW9`80<30`0P0g=cL207QhN080OGem0P0i>CT202PX:080
=SHf0P0a<C4202d];@80:RXZ0P0X:2P202XZ:PD0;Bd]0P0^;Rh202l_;`80<30`0P0a<C42038b<P80
;2`/0P0Y:BT203Lg=`80ATI60P18B4P204A4A080>3Ph0P0[:b/2028R8P807AdM0P0Q8B4402h^;P80
De=C0P2?Shl209RHV080RHV90P1FEUH207IfMP80XZ:R0P2g]kL20<;2`P80];Bd0P2YZJT20:f][@<0
];Bd0P2f][H20;Ng]`@0]KFe0P2k^k/20<?3``80bLW90P3=cLd20<_;b`@0alO70P36a/H20<S8b080
_Kfm0P2k^k/2075aL@80F5QH0P1=CDd205ADE080EEEE0P1<C4`20492@P80>c/k0P0f=SH2030`<0@0
:b/[0P0^;Rh203@d=080?Cdm0P1@D50305eMG@80ATI6100b<S8205IFEP80BTY:0P0i>CT202/[:`80
9BDU0P0L71`203Ph>080E5AD0P1?Cdl203Hf=P80A4A40P2GUiL20<o?c`80dm?C0P34a<@20<;2`P80
^KVi0P2e]KD208V9R@80IFEU0P15ADD203`l?080?clo0P1EEED206YZJP80F5QH0P1<C4`2065QH@<0
Ng]k0P1mOGd207YjNP80MWIf0P1dM7@207YjNP80PH610P24Q8@208J6QP80R8R80P2;Rh/208j>SP80
T92@0P2BTY8409>CTbT0b>3H0P0W9bL203Ph>080;Rh^0P0W9bL202`/;080?Shn0P1jNWX207emO@80
?clo0P0[:b/203De=@80:b/[0P0/;2`202PX:080:RXZ0P0[:b/302TY:@80<c<c0P0`<30202l_;`80
<C4a0P0^;Rh202l_;`@0:b/[0P0];Bd20410@080B4Q80P11@D4203Ph>080>SXj0P0U9BD202HV9P80
9bLW0P0Q8B4202DU9@80DU9B0P2=SHd20:6QX@80OWin0P1PH60206a/K080W9bL0P36a/H20;fm_@80
Y:BT0P2][Jd20:n_[`<0/K6a0P2g]kL20;:b/P80/K6a0P2g]kL20;Vi^@80`l?30P3>c/h20<_;b`80
b/[:0P37alL20<71`@80b<S80P35aLD20<_;b`80]kNg0P1[Jf/2055AD@80DU9B0P1HF5P205EEE@80
CTi>0P14A4@203Ph>080<C4a0P0e=CD202`/;080:RXZ0P0/;2`203<c<`80@D510P1BDU8305YJFP80
DE5A0P0b<S8203`l?080D51@0P1?Cdl2030`<0809RHV0P0T92@202LW9`80>3Ph0P1JFUX20451@@80
<S8b0P18B4P20:>SX`@0c<c<0P37alL40<30`080^KVi0P2;Rh/206][J`80B4Q80P0l?3`203hn?P80
J6QX0P1/K6`205ADE080Bd];0P1TI6@307]kN`80O7al0P1hN7P207YjNP80MgMg0P1iNGT20820P080
QhN70P22PX8208N7Q`@0Rh^;0P2FUYH208f=S@80TI6A0P2JVYXY0<SPf080=CDe0P0_;bl202/[:`80
9BDU0P0c<c<203Ph>080MgMg0P1lO7`203Ph>080;2`/0P0d=3@2030`<080;2`/0P0W9bL402`/;0<0
;Bd]0P0/;2`2034a<@80<30`0P0e=CD202TY:@80=SHf0P0Y:BT2024Q8@80<S8b0P16ATH204i>CP80
@d=30P0i>CT202XZ:P@071`L0P0K6a/2038b<P80<C4a0P1DE5@208Z:RP80V9RH0P2:RXX205MGE`80
Kfm_0P2UYJD20;Vi^@80`l?30P2d];@20:RXZ080[:b/1@2d];@20;fm_@80^KVi0P2d];@20;^k^`80
`L710P38b<P20<W9b@80c<c<0P33`l<20<[:bP80a/K60P35aLD40;^k^`80Kfm_0P1IFET204e=C@80
DU9B0P1KFe/204];B`80@4100P0j>SX2038b<P80:b/[0P0W9bL202PX:0@0;bl_0P0l?3`2051@D0<0
GEeM0P17AdL2034a<@80=CDe0P1GEeL204E5A@80?3`l0P0];Bd201dM7@808b<S0P0g=cL205eMG@80
C4a<0P0`<30204E5A@80UiNG0P3AdM420=?Cd`80a<C40P32`/820;bl_080][Jf0P2:RXX206IVIP80
AdM70P0k>c/203lo?`80EEEE0P1XJ6P205eMG@80Bd];0P1SHf<307alO080NGUi0P1kNg/207IfMP80
MgMg0P1hN7P207moO`80QXJ60P23Ph<208N7Q`80RXZ:0P2BTY8208j>SP80TI6A0P2EUID209RHV1l0
b>3H000M0<SPf080;bl_100^;Rh202PX:080<c<c0P14A4@208R8R080GUiN0P0a<C4202/[:`80;2`/
0P0^;Rh202l_;`80;Rh^100/;2`502d];@80;Rh^0P0_;bl2038b<P80=cLg0P0k>c/203@d=080;bl_
0P0o?cl2051@D080De=C0P1>CTh203`l?080:RXZ0P0X:2P202TY:@80820P0P0K6a/2028R8P80<S8b
0P1]KFd209^KV`80Xj>S0P1RHV8206MWI`80N7Qh0P2UYJD20<_;b`80^;Rh0P2RXZ820:FUY@<0[Zj^
0P2a/K440;>c/`80];Bd0P2e]KD20;Vi^@80aLG50P3?cll20<_;b`80a<C41033`l<20<S8b080c<c<
0P2g]kL20;Jf]P80K6a/0P17AdL204a<C080FEUI0P1DE5@204e=C@80ATI60P0m?Cd2038b<P80:RXZ
0P0Y:BT202`/;080;bl_0P0e=CD20492@P<0Bd];0P0l?3`202d];@80=SHf0P0m?Cd203Hf=P80;Bd]
0P0U9BD202TY:@809bLW0P1SHf<204i>CP80@D510P1MGEd208>3P`80[:b/0P3?cll20<k>cP80`<30
0P2e]KD40:2PX080GEeM0P11@D4202/[:`80;bl_0P0k>c/20492@P@0AdM70P1:BTX206EUI@<0Ogmo
0P21PH4207alO080NWYj0P1hN7P207]kN`80PH610P24Q8@208N7Q`80RXZ:0P2<S8`208n?S`80TI6A
0P2DU9@409JFURT0b>3H0P0/;2`2030`<080;Bd]0P0^;Rh2030`<080AdM70P20P80206EUI@80:RXZ
0P0_;bl202d];@@0<C4a0P0^;Rh202/[:`80<S8b0`0_;bl202/[:`80;Bd]0P0`<302038b<P@0>c/k
0P0];Bd203<c<`80?clo0P1@D50205YJFP80EEEE0P0b<S8202XZ:P809bLW0P0R8R82024Q8@807alO
0P0Q8B42038b<P80LW9b0P2HV9P209bLW080Jf][0P1OGel207UiN@80/K6a0P38b<P20;2`/080Y:BT
0P2XZ:P30:b/[080/k>c0P2e]KD20:n_[`80]KFe0P2h^;P20;Jf]P80b/[:0P3>c/h20<W9b@80alO7
0P31`L460<G5a@80a<C40P2_[jl206UYJ@80C4a<0P1@D50205MGE`80EEEE0P1<C4`204A4A080?3`l
0P0b<S8202XZ:P80:BTY0P0Z:RX203<c<`80=CDe0P0m?Cd304e=C@80@d=30P0[:b/202l_;`80?Shn
0P0l?3`202d];@809bLW0P0T92@202PX:080F5QH0P1GEeL20451@@80EUIF0P1iNGT20:j^[P80b/[:
0P3<c<`20;no_`80/;2`0P2SXj<209ZJVP80HF5Q0P15ADD402/[:`80>c/k0P1<C4`204Y:BP80?clo
0P1?Cdl206e]K@<0Ng]k0P22PX8207alO080NGUi0P1fMWH207UiN@80P8200P2:RXX208J6QP80S8b<
0P2;Rh/209:BTP80T92@0P2ATI4209BDU080VIVI:@38h=P203@d=0809RHV0P0d=3@202TY:@80=3@d
0P0o?cl208Z:RP80GemO0P0^;Rh202/[:`80:2PX0P0b<S82034a<@80:BTY0P0`<30202LW9`<0<30`
100];Bd203<c<`80<C4a0P0b<S8203/k>`80=SHf0P0d=3@203Xj>P80D51@0P1CDe<204e=C@80?3`l
0P0[:b/402TY:@808B4Q0P0K6a/2020P8080<c<c0P1YJFT209fMW@80Xj>S0P1QHF4206UYJ@80N7Qh
0P2ZZZX20<S8b080^k^k0P2PX:020:FUY@<0[:b/0P2b/[820;6a/@80];Bd0P2e]KD20;>c/`80^;Rh
0P37alL20<c<c080clo?0P35aLD20<71`@80aLG50P37alL20<g=c@80_;bl0P2e]KD206][J`80BTY:
0P17AdL205QHF080De=C0P1>CTh204M7A`80@T920P0`<30202d];@80:BTY100];Bd203De=@80@D51
0`17AdL20410@080:2PX0P0f=SH203`l?080<c<c0P0a<C4402HV9P80:b/[0P1MGEd204m?C`80A4A4
0P1JFUX208J6QP80[Jf]0P3>c/h20=3@d080`L710P2a/K420:>SX`80XJ6Q0P1OGel203hn?P80;Bd]
0P0/;2`203dm?@80A4A40P18B4P204E5A@80B4Q80P1VIVH50820P0@0O7al0P1gMgL207UiN@80PX:2
0P26QXH208F5Q@80RXZ:0P29RHT408n?S`80U9BD0P2EUID209:BTQl0b>3H000M0<SPf080;bl_100^
;Rh202PX:080<c<c0P14A4@208R8R080GUiN0P0a<C4202/[:`80;2`/0P0^;Rh202l_;`80;Rh^100/
;2`502d];@80;Rh^0P0_;bl2038b<P80=cLg0P0k>c/203@d=080;bl_0P0o?cl2051@D080De=C0P1>
CTh203`l?080:RXZ0P0X:2P202TY:@80820P0P0K6a/2028R8P80<S8b0P1]KFd209^KV`80Xj>S0P1R
HV8206MWI`80N7Qh0P2UYJD20<_;b`80^;Rh0P2RXZ820:FUY@<0[Zj^0P2a/K440;>c/`80];Bd0P2e
]KD20;Vi^@80aLG50P3?cll20<_;b`80a<C41033`l<20<S8b080c<c<0P2g]kL20;Jf]P80K6a/0P17
AdL204a<C080FEUI0P1DE5@204e=C@80ATI60P0m?Cd2038b<P80:RXZ0P0Y:BT202`/;080;bl_0P0e
=CD20492@P<0Bd];0P0l?3`202d];@80=SHf0P0m?Cd203Hf=P80;Bd]0P0U9BD202TY:@809bLW0P1S
Hf<204i>CP80@D510P1MGEd208>3P`80[:b/0P3?cll20<k>cP80`<300P2e]KD40:2PX080GEeM0P11
@D4202/[:`80;bl_0P0k>c/20492@P@0AdM70P1:BTX206EUI@<0Ogmo0P21PH4207alO080NWYj0P1h
N7P207]kN`80PH610P24Q8@208N7Q`80RXZ:0P2<S8`208n?S`80TI6A0P2DU9@409JFURT0b>3H0P0/
;2`2030`<080;Bd]0P0^;Rh2030`<080AdM70P20P80206EUI@80:RXZ0P0_;bl202d];@@0<C4a0P0^
;Rh202/[:`80<S8b0`0_;bl202/[:`80;Bd]0P0`<302038b<P@0>c/k0P0];Bd203<c<`80?clo0P1@
D50205YJFP80EEEE0P0b<S8202XZ:P809bLW0P0R8R82024Q8@807alO0P0Q8B42038b<P80LW9b0P2H
V9P209bLW080Jf][0P1OGel207UiN@80/K6a0P38b<P20;2`/080Y:BT0P2XZ:P30:b/[080/k>c0P2e
]KD20:n_[`80]KFe0P2h^;P20;Jf]P80b/[:0P3>c/h20<W9b@80alO70P31`L460<G5a@80a<C40P2_
[jl206UYJ@80C4a<0P1@D50205MGE`80EEEE0P1<C4`204A4A080?3`l0P0b<S8202XZ:P80:BTY0P0Z
:RX203<c<`80=CDe0P0m?Cd304e=C@80@d=30P0[:b/202l_;`80?Shn0P0l?3`202d];@809bLW0P0T
92@202PX:080F5QH0P1GEeL20451@@80EUIF0P1iNGT20:j^[P80b/[:0P3<c<`20;no_`80/;2`0P2S
Xj<209ZJVP80HF5Q0P15ADD402/[:`80>c/k0P1<C4`204Y:BP80?clo0P1?Cdl206e]K@<0Ng]k0P22
PX8207alO080NGUi0P1fMWH207UiN@80P8200P2:RXX208J6QP80S8b<0P2;Rh/209:BTP80T92@0P2A
TI4209BDU080VIVI:@38h=P203@d=0809RHV0P0d=3@202TY:@80=3@d0P0o?cl208Z:RP80GemO0P0^
;Rh202/[:`80:2PX0P0b<S82034a<@80:BTY0P0`<30202LW9`<0<30`100];Bd203<c<`80<C4a0P0b
<S8203/k>`80=SHf0P0d=3@203Xj>P80D51@0P1CDe<204e=C@80?3`l0P0[:b/402TY:@808B4Q0P0K
6a/2020P8080<c<c0P1YJFT209fMW@80Xj>S0P1QHF4206UYJ@80N7Qh0P2ZZZX20<S8b080^k^k0P2P
X:020:FUY@<0[:b/0P2b/[820;6a/@80];Bd0P2e]KD20;>c/`80^;Rh0P37alL20<c<c080clo?0P35
aLD20<71`@80aLG50P37alL20<g=c@80_;bl0P2e]KD206][J`80BTY:0P17AdL205QHF080De=C0P1>
CTh204M7A`80@T920P0`<30202d];@80:BTY100];Bd203De=@80@D510`17AdL20410@080:2PX0P0f
=SH203`l?080<c<c0P0a<C4402HV9P80:b/[0P1MGEd204m?C`80A4A40P1JFUX208J6QP80[Jf]0P3>
c/h20=3@d080`L710P2a/K420:>SX`80XJ6Q0P1OGel203hn?P80;Bd]0P0/;2`203dm?@80A4A40P18
B4P204E5A@80B4Q80P1VIVH50820P0@0O7al0P1gMgL207UiN@80PX:20P26QXH208F5Q@80RXZ:0P29
RHT408n?S`80U9BD0P2EUID209:BTQl0b>3H000M0<SPf080;2`/0P0b<S8203hn?P80@d=30P0`<302
05ADE080S8b<0P1=CDd202d];@80:b/[0P0_;bl202h^;P80;Bd]0P0/;2`402XZ:P<0:b/[0P0Y:BT2
02LW9`80>CTi0P1>CTh205MGE`80Fe]K0P1CDe<204a<C080G5aL0P1WIfL2059BDP80>3Ph0P0_;bl2
02/[:`809RHV0P0R8R8401lO7`80820P0P0Y:BT204U9B@80S8b<0P2PX:0208B4Q080K6a/0P1RHV82
092@T080_Kfm0P3:b/X20:ZZZPD0ZJVY0P2/[:`20:n_[`80/[:b0P2d];@20;Jf]P80^KVi0P34a<@2
0<g=c@80bl_;0P36a/H20<C4a080`l?31034a<@20;no_`80]kNg0P2d];@206a/K080@T921P1<C4`2
04M7A`80?clo0P0f=SH202h^;P80;Bd]0P0^;Rh202l_;`80<C4a0P0f=SH303Xj>P80=CDe0P0_;bl4
03@d=080<C4a0P0/;2`202TY:@80:b/[0P0Y:BT204U9B@@0?Shn0P1HF5P207IfMP80W9bL0P2n_[h2
0;^k^`80ZJVY0P2CTi<207IfMP80JFUY0P0n?Sh2030`<0809bLW0P0Z:RX402l_;`80<S8b0P10@402
05=CD`80KFe]0`23Ph<208F5Q@80PX:20P1nOWh207alO080OWin0P22PX8208F5Q@80RHV90P2:RXX2
08b<S080Shn?0P2BTY8209FEU@80UYJF0P2GUiLY0<SPf080<C4a0P0`<30203Ph>080@4100P0c<c<2
04m?C`80SHf=0P1CDe<202PX:080;Rh^100/;2`202l_;`80:b/[0P0X:2P202TY:@<0:2PX0P0U9BD2
02/[:`80=3@d0P18B4P206MWI`80H61P0P1:BTX205YJFP80De=C0P1]KFd205iNGP80;bl_0P0Y:BT2
02XZ:P80:2PX0P0S8b<202DU9@808R8R0P0P820202HV9P80De=C0P2<S8`209nOW`80QHF5101UIFD2
09:BTP80`l?30P36a/H20:^[Z`80[:b/0`2VYZH20:n_[`80/[:b0P2^[Zh40;Fe]@80];Bd0P34a<@2
0<W9b@80b/[:0P34a<@20<O7a`80aLG50P30`<020;jn_P80`<300P38b<P20:j^[P80HF5Q0P14A4@2
04Q8B080D51@101;Bd/204I6AP80>SXj0P0Y:BT202l_;`80<C4a0P0`<302034a<@80<30`1@0e=CD2
02l_;`80:b/[0P0f=SH2034a<@80<S8b0P0X:2P202h^;P80<30`0P1<C4`203hn?P80ADE50P1NGUh2
0820P080XZ:R0P31`L420<30`080[jn_0P2EUID207MgM`80HV9R0P0k>c/202XZ:P809bLW0P0V9RH2
02LW9`80:RXZ0P0/;2`203<c<`80DE5A0P1^KVh30861P@80QhN70P21PH4207inOP80OGem0P20P802
07inOP80QhN70P28R8P208F5Q@80SXj>0P2<S8`209>CT`80UIFE0P2HV9P209VIVBT0b>3H0P0/;2`2
038b<P80@4100P0o?cl2030`<080EEEE0P2>SXh204a<C080<30`0P0_;bl4034a<@80;Bd]0P0X:2P2
02XZ:P80:b/[0`0Z:RX202@T90808b<S0P0g=cL2055AD@80EeMG0P1LG5`205YJFP80Cdm?0P1KFe/2
06a/K080DU9B0P0i>CT2030`<080:RXZ0P0Y:BT202DU9@808B4Q0P0N7Qh201XJ6P80;2`/0P1;Bd/2
08f=S@80WYjN0P26QXH206e]K@80GEeM0P2@T9020;Vi^@80bLW90P2VYZH20;6a/@<0ZZZZ0P2YZJT2
0:b/[080/[:b0P2`/;020;bl_080^[Zj0P32`/820<o?c`80d=3@0P31`L420<C4a080`/;20P36a/H2
0<30`080`/;20P2c/k<20;Ng]`80K6a/0P13@d<404i>CP80Cdm?0P11@D420492@P80<C4a0P0b<S82
034a<@80;Rh^0P0];Bd203Hf=P80>c/k0`0i>CT203Ph>080<C4a0P0f=SH203Lg=`80<C4a0P0V9RH2
02TY:@80;2`/0P0_;bl204Q8B080?Cdm0P0l?3`205EEE@80M7Ad0P2KVi/20;Zj^P80_[jn0P2VYZH2
09>CT`80LW9b0P1ZJVX203hn?P80;bl_0P0Y:BT202PX:080;2`/0P0b<S8202l_;`80?Cdm0P1EEED2
06m_K`<0PH610P26QXH20861P@H0OGem0P20P80208Z:RP80Rh^;0P2=SHd208j>SP80T92@0P2DU9@4
09JFUP80VYZJ7`38h=P001d0b>3H0P0/;2`2038b<P80?Shn0P13@d<2030`<080E5AD0P2<S8`204e=
C@80;Bd]0P0[:b/202l_;`80;Rh^0P0];Bd202`/;0@0:RXZ0`0[:b/202TY:@809bLW0P0i>CT204i>
CP80EeMG0P1KFe/205=CD`80C4a<0P1LG5`206MWI`80DU9B0P0h>3P202l_;`80:b/[0P0V9RH2028R
8P@07alO0P0P820202TY:@80BDU90P2<S8`20:2PX080Q8B40P1/K6`2069RHP80T92@0P2m_Kd20<[:
bP80ZZZZ1@2YZJT20:b/[080[jn_0P2b/[820;Bd]080][Jf0P2i^KT20<C4a080cLg=0P3;bl/20<K6
aP80a<C40P33`l<40<C4a080_kno0P2g]kL20;Bd]080K6a/0P12@T8604a<C080AdM70P0o?cl203Hf
=P80;Rh^0P0];Bd202h^;P80;bl_0P0a<C4203Hf=P<0>SXj0P0e=CD202l_;`@0=3@d0P0a<C4202`/
;080:BTY0P0[:b/202TY:@80BDU9100n?Sh205QHF080MWIf0P2LW9`20;jn_P80^k^k0P2YZJT209>C
T`80MWIf0P1YJFT203hn?P80<30`0P0W9bL202XZ:P@0;bl_0P0b<S820410@080De=C0P1]KFd308>3
P`80QHF50P22PX8207inOP80O7al0P1nOWh208:2PP80QHF50P29RHT208Z:RP80S8b<0P2?Shl209:B
TP80UIFE0P2FUYH209NGUbT0b>3H0P0a<C42030`<080>3Ph0P10@40203<c<`80Cdm?0P2=SHd205=C
D`80:2PX0P0^;Rh402`/;080;bl_0P0[:b/202PX:080:BTY0`0X:2P202DU9@80:b/[0P0d=3@204Q8
B080IfMW0P1PH60204Y:BP80FUYJ0P1CDe<206e]K@80GUiN0P0_;bl202TY:@80:RXZ0P0X:2P202<S
8`809BDU0P0R8R82020P80809RHV0P1CDe<208b<S080WinO0P25QHD406EUI@80TY:B0P33`l<20<K6
aP80Zj^[0P2/[:`30:JVYP80[jn_0P2b/[820:j^[P@0]KFe0P2d];@20<C4a080bLW90P3:b/X20<C4
a080alO70P35aLD20<30`080_[jn0P30`<020<S8b080[Zj^0P1QHF4204A4A080B4Q80P1@D50404];
B`80ATI60P0j>SX202TY:@80;bl_0P0a<C42030`<080<C4a0P0`<30503De=@80;bl_0P0[:b/203Hf
=P80<C4a0P0b<S8202PX:080;Rh^0P0`<30204a<C080?Shn0P15ADD205iNGP80P8200P2RXZ820<71
`@80`<300P2_[jl209FEU@80MgMg0P1RHV8203/k>`80:RXZ0P0W9bL202HV9P809bLW0P0Z:RX202`/
;080<c<c0P1ADE4206i^KP<0PH610P27QhL20861P@80OWin0P1mOGd20820P080OWin0P27QhL208R8
R080QHF50P2>SXh208b<S080Ti>C0P2EUID209RHV080VIVI:@38h=P202`/;080<S8b0P10@40203lo
?`80<30`0P1EEED208j>SP80C4a<0P0`<30202l_;`@0<C4a0P0];Bd202PX:080:RXZ0P0[:b/302XZ
:P8092@T0P0S8b<203Lg=`80DE5A0P1GEeL205aLG080FUYJ0P1?Cdl205]KF`80K6a/0P1BDU8203Ti
>@80<30`0P0Z:RX202TY:@809BDU0P0Q8B4201hN7P806QXJ0P0/;2`204];B`80SHf=0P2NWYh208J6
QP80KFe]0P1MGEd2092@T080^KVi0P39bLT20:JVYP80/K6a0`2ZZZX20:VYZ@80[:b/0P2b/[820;2`
/080_;bl0P2j^[X20<;2`P80clo?0P3@d=020<71`@80a<C40P32`/820<K6aP80`<300P32`/820;>c
/`80]kNg0P1/K6`204=3@`@0CTi>0P1?Cdl20451@@80@T920P0a<C42038b<P80<C4a0P0^;Rh202d]
;@80=SHf0P0k>c/303Ti>@80>3Ph0P0a<C4203Hf=P80=cLg0P0a<C4202HV9P80:BTY0P0/;2`202l_
;`80B4Q80P0m?Cd203`l?080EEEE0P1dM7@209^KV`80^[Zj0P2n_[h20:JVYP80Ti>C0P1bLW8206YZ
JP80?Shn0P0_;bl202TY:@80:2PX0P0/;2`2038b<P80;bl_0P0m?Cd205EEE@80Kfm_0`21PH4208J6
QP80PH611P1mOGd20820P080RXZ:0P2;Rh/208f=S@80SXj>0P2@T90209BDU0@0UYJF0P2JVYXO0<SP
f0007@38h=P202`/;080<S8b0P0n?Sh204=3@`80<30`0P1DE5@208b<S080CDe=0P0];Bd202/[:`80
;bl_0P0^;Rh202d];@80;2`/100Z:RX302/[:`80:BTY0P0W9bL203Ti>@80CTi>0P1GEeL205]KF`80
De=C0P1<C4`205aLG080IfMW0P1BDU8203Ph>080;bl_0P0[:b/202HV9P808R8R100O7al2020P8080
:BTY0P19BDT208b<S080X:2P0P24Q8@206a/K080HV9R0P2@T9020;fm_@80b/[:0P2ZZZX50:VYZ@80
[:b/0P2_[jl20;:b/P80];Bd0P2f][H20;Vi^@80a<C40P3=cLd20<_;b`80a/K60P34a<@20<?3``@0
a<C40P2o_kl20;Ng]`80];Bd0P1/K6`20492@PH0C4a<0P17AdL203lo?`80=SHf0P0^;Rh202d];@80
;Rh^0P0_;bl2034a<@80=SHf0`0j>SX203De=@80;bl_100d=3@2034a<@80;2`/0P0Y:BT202/[:`80
:BTY0P19BDT403hn?P80F5QH0P1fMWH209bLW080_[jn0P2k^k/20:VYZ@80Ti>C0P1fMWH206UYJ@80
?Shn0P0`<30202LW9`80:RXZ100_;bl2038b<P80@4100P1CDe<206e]K@<0Ph>30P25QHD208:2PP80
OWin0P1lO7`207inOP80PX:20P25QHD208V9R@80RXZ:0P2<S8`208n?S`80TY:B0P2EUID209JFUP80
UiNG:@38h=P2034a<@80<30`0P0h>3P20410@080<c<c0P1?Cdl208f=S@80De=C0P0X:2P202h^;P@0
;2`/0P0_;bl202/[:`80:2PX0P0Y:BT302PX:0809BDU0P0[:b/203@d=080B4Q80P1WIfL2061PH080
BTY:0P1JFUX205=CD`80KFe]0P1NGUh202l_;`80:BTY0P0Z:RX202PX:0808b<S0P0U9BD2028R8P80
820P0P0V9RH205=CD`80S8b<0P2OWil208F5Q@@0IFEU0P2BTY820<?3``80a/K60P2[Zj/20:b/[0<0
YZJV0P2_[jl20;:b/P80[Zj^102e]KD20;Bd]080a<C40P39bLT20<[:bP80a<C40P37alL20<G5a@80
`<300P2n_[h20<30`080b<S80P2^[Zh2065QH@80A4A40P18B4P2051@D0@0Bd];0P16ATH203Xj>P80
:BTY0P0_;bl2034a<@80<30`0P0a<C42030`<0D0=CDe0P0_;bl202/[:`80=SHf0P0a<C42038b<P80
:2PX0P0^;Rh2030`<080C4a<0P0n?Sh204E5A@80GUiN0P20P8020::RXP80`L710P30`<020:n_[`80
UIFE0P1gMgL2069RHP80>c/k0P0Z:RX202LW9`809RHV0P0W9bL202XZ:P80;2`/0P0c<c<2055AD@80
KVi^0`21PH4208N7Q`80PH610P1nOWh207emO@80P8200P1nOWh208N7Q`80R8R80P25QHD208j>SP80
S8b<0P2CTi<209FEU@80V9RH0P2IVITY0<SPf080;2`/0P0b<S820410@080?clo0P0`<30205EEE@80
SXj>0P1<C4`2030`<080;bl_100a<C4202d];@80:2PX0P0Z:RX202/[:`<0:RXZ0P0T92@202<S8`80
=cLg0P1ADE4205MGE`80G5aL0P1JFUX204m?C`80Fe]K0P1/K6`2059BDP80>CTi0P0`<30202XZ:P80
:BTY0P0U9BD2024Q8@807QhN0P0J6QX202`/;080Bd];0P2=SHd209jNWP80QXJ60P1]KFd205eMG@80
T92@0P2i^KT20<W9b@80YZJV0P2a/K430:ZZZP80ZJVY0P2/[:`20;:b/P80/;2`0P2l_;`20;Zj^P80
`/;20P3?cll20=3@d080`L710P34a<@20<;2`P80a/K60P30`<020<;2`P80/k>c0P2g]kL206a/K080
@d=3101>CTh204m?C`80@D510P12@T82034a<@80<S8b0P0a<C4202h^;P80;Bd]0P0f=SH203/k>`<0
>CTi0P0h>3P2034a<@80=SHf0P0g=cL2034a<@809RHV0P0Y:BT202`/;080;bl_0P18B4P203dm?@80
?3`l0P1EEED207AdM080Vi^K0P2j^[X20;jn_P80YZJV0P2CTi<2079bLP80JVYZ0P0n?Sh202l_;`80
:BTY0P0X:2P202`/;080<S8b0P0_;bl203dm?@80EEEE0P1_Kfl30861P@80QXJ60P21PH4607emO@80
P8200P2:RXX208^;R`80SHf=0P2>SXh2092@T080U9BD102FUYH209ZJVQl0b>3H000M0<SPf080:BTY
0P0j>SX204a<C080FUYJ0P0/;2`2061PH080RXZ:0P11@D4202/[:`80:BTY0P0c<c<202l_;`80:RXZ
1P0X:2P302TY:@809RHV0P0X:2P204U9B@80Jf][101fMWH2075aL@80IFEU0P1?Cdl203Ph>080:b/[
0P0T92@202LW9`80:b/[0P0X:2P402@T90809bLW0P0Q8B4202HV9P80:RXZ0P1cLg<2092@T080Xj>S
0P1jNWX205QHF080O7al0P2WYjL20=?Cd`80]KFe0P2_[jl30:FUY@80Z:RX0P2][Jd20;2`/080];Bd
0P2g]kL20;Zj^P80`l?30P3:b/X20<_;b`80bLW90P36a/H20<?3``80_[jn0P2k^k/20<G5a@80c<c<
102f][H204a<C080BDU90P13@d<204Y:BP80ATI60P11@D4203Xj>P80=CDe0P0b<S82034a<@@0<30`
0P0_;bl302h^;P80<C4a100c<c<2034a<@80<30`0P0^;Rh402d];@@0;bl_0P0c<c<203/k>`80Bd];
0P1QHF4208J6QP80Xj>S0P2NWYh208Z:RP80K6a/0P1<C4`203De=@80:BTY0P0X:2P202/[:`80:2PX
0P0U9BD202@T9080:BTY0P12@T82061PH080MWIf0`25QHD208R8R080QXJ60P22PX8207moO`80P820
0P22PX8208J6QP80RXZ:0P2;Rh/208b<S080Shn?0P2CTi<209JFUP80UiNG0P2HV9PY0<SPf080;bl_
0P0j>SX2059BDP80EUIF0P0e=CD205aLG080QhN70P17AdL202DU9@80;Bd]0P0d=3@2038b<P80;2`/
0P0U9BD202/[:`80:BTY0`0[:b/202XZ:P80<30`0P0n?Sh206i^KP80NWYj0P1`L70206e]K@80IVIV
0P1BDU8203/k>`80:b/[100W9bL202d];@80:BTY100R8R8202HV9P@08B4Q0P0c<c<206YZJP80Ti>C
0P2VYZH2075aL@80GemO0P1nOWh20:b/[080bLW90P2m_Kd20:NWY`<0ZJVY0P2ZZZX20:^[Z`80[jn_
0P2c/k<40;Vi^@80a<C40P39bLT20<g=c@80b/[:0P32`/820<C4a0@0_[jn0P33`l<20<71`@80aLG5
0P2VYZH205UIF@80@d=30P1;Bd/204U9B@80?Shn0P0k>c/20492@P80<c<c100`<30203@d=080;bl_
1@0`<30202l_;`80=cLg0P0_;bl203<c<`80<30`0P0^;Rh202`/;080;Rh^0P0_;bl202`/;080<S8b
0P0h>3P204I6AP80FUYJ0P2:RXX20::RXP80UYJF0P2>SXh206QXJ080CTi>0P0h>3P202XZ:P@0:BTY
0P0[:b/202HV9P80:RXZ0P0^;Rh204=3@`80I6AT0P1eMGD308B4Q080R8R80P24Q8@20861P@80OWin
0P20P80208:2PP80R8R80P2:RXX208^;R`80RXZ:0P2?Shl209:BTP80UYJF0P2DU9@209VIVBT0b>3H
0P0];Bd203Ph>080Cdm?0P1GEeL202d];@80HV9R0P29RHT203lo?`80;2`/0P0Z:RX2034a<@80;Rh^
0P0[:b/202HV9P809bLW0P0Y:BT302PX:0809bLW0P0Y:BT204];B`80KVi^0P1`L70207IfMP80M7Ad
0P1TI6@204i>CP80=3@d0P0^;Rh202@T90809BDU0P0X:2P202`/;0806a/K0P0X:2P202LW9`8071`L
0P0X:2P202XZ:P80Lg=c0P2BTY820:6QX@80Ng]k0P1HF5P20820P080YjNW0P3Hf=P20;>c/`80ZZZZ
0`2UYJD40:^[Z`80/k>c0P2b/[820;Fe]@80^[Zj0P33`l<20<c<c080a<C40P39bLT20<c<c080`<30
0P2j^[X20;bl_080c<c<0P3;bl/20;Jf]P80/K6a0P1ADE4204A4A080@4100P1:BTX204Q8B080A4A4
100f=SH203<c<`80<30`2@0^;Rh2030`<080<c<c1P0b<S8202h^;P80<30`0P0Z:RX202h^;P80;bl_
0P0h>3P203/k>`80C4a<0P1RHV8208V9R@80WinO0P2PX:0208J6QP80KFe]0P1;Bd/203Ti>@80:2PX
0P0W9bL202XZ:P80:2PX0P0S8b<202DU9@809RHV0P15ADD205eMG@80MgMg0`22PX8208b<S080Q8B4
101oOgl408>3P`80PX:20P27QhL2092@T080RXZ:0P2=SHd2096AT@H0UYJF7`38h=P001d0b>3H0P0Y
:BT203Xj>P80C4a<0P1JFUX202`/;080H61P0P2:RXX20451@@80:b/[0P0Y:BT203<c<`80;bl_0P0Z
:RX602PX:0<0:BTY0P0V9RH202PX:080BDU90P1[Jf/407IfMP80LG5a0P1UIFD204m?C`80>3Ph0P0[
:b/202@T90809bLW0P0[:b/202PX:0@092@T0P0W9bL2024Q8@809RHV0P0Z:RX207=cL`80T92@0P2S
Xj<207YjNP80F5QH0P1lO7`20:NWY`80dm?C0P2e]KD20:n_[`<0YJFU0P2XZ:P20:f][@80/;2`0P2d
];@20;Ng]`80^[Zj0P33`l<20<[:bP80bl_;0P39bLT20<K6aP80`l?30P2n_[h20;^k^`80aLG50P3<
c<`40;Jf]P80C4a<0P19BDT204=3@`80BTY:0P16ATH20451@@80>SXj0P0e=CD2038b<P80<C4a100`
<30202l_;`<0;Rh^0P0a<C4403<c<`80<C4a0P0`<30202h^;P@0;Bd]100_;bl203<c<`80>c/k0P1;
Bd/2065QH@80QXJ60P2SXj<209jNWP80RXZ:0P1/K6`204a<C080=CDe0P0Y:BT202PX:080:b/[0P0X
:2P202DU9@8092@T0P0Y:BT20492@P80H61P0P1fMWH308F5Q@80R8R80P26QXH208:2PP80Ogmo0P20
P80208:2PP80QXJ60P2:RXX208^;R`80S8b<0P2?Shl209>CT`80UYJF0P2GUiL209RHV2T0b>3H0P0_
;bl203Xj>P80DU9B0P1FEUH203De=@80G5aL0P27QhL204M7A`809BDU0P0];Bd203@d=080<S8b0P0/
;2`202DU9@80:b/[0P0Y:BT302/[:`80:RXZ0P0`<30203hn?P80KVi^0P1jNWX2071`L080KFe]0P1V
IVH2059BDP80>c/k0P0[:b/402LW9`80;Bd]0P0Y:BT4028R8P809RHV100Q8B4203<c<`80JVYZ0P2C
Ti<20:JVYP80LG5a0P1OGel207inOP80[:b/0P39bLT20;fm_@80YjNW0`2YZJT20:ZZZP80Zj^[0P2_
[jl20;>c/`@0^KVi0P34a<@20<W9b@80cLg=0P3:b/X20<;2`P80a<C4102n_[h20<?3``80`L710P35
aLD20:JVYP80FEUI0P13@d<204];B`80BDU90P0n?Sh203/k>`80@T920P0c<c<4030`<080=3@d0P0_
;bl5030`<080;bl_0P0g=cL202l_;`80<c<c0P0`<30202h^;P80;2`/0P0^;Rh202l_;`80;2`/0P0b
<S8203Ph>080ATI60P1JFUX208Z:RP80XZ:R0P2FUYH208j>SP80J6QX0P1>CTh203Ph>080:RXZ100Y
:BT202/[:`809RHV0P0Z:RX202h^;P80@d=30P1TI6@207EeM@<0Q8B40P28R8P208B4Q080PH610P1n
OWh20820P080PX:20P28R8P208Z:RP80Rh^;0P2:RXX208n?S`80TY:B0P2FUYH209BDU080VIVI:@38
h=P202d];@80>3Ph0P1?Cdl205MGE`80;Bd]0P1RHV8208V9R@80?clo0P0/;2`202XZ:P80<C4a0P0^
;Rh202/[:`809RHV0P0W9bL202TY:@<0:2PX0P0W9bL202TY:@80Bd];0P1^KVh2071`L080MWIf0P1d
M7@206ATI080CTi>0P0d=3@202h^;P8092@T0P0U9BD202PX:080;2`/0P0K6a/202PX:0809bLW0P0L
71`202PX:080:RXZ0P1cLg<209:BTP80XJ6Q0P1kNg/205QHF080P8200P2WYjL20=SHf080/k>c0P2Z
ZZX30:FUY@@0Zj^[0P2c/k<20;:b/P80]KFe0P2j^[X20<?3``80c<c<0P34a<@20<W9b@80c<c<0P30
`<020;Zj^P80_;bl0P3<c<`20<_;b`80][Jf0P2a/K42055AD@80A4A40P10@40204Y:BP80B4Q80P14
A4@403Hf=P80<c<c0P0`<30902h^;P80<30`0P0c<c<6038b<P80;Rh^0P0`<30202XZ:P80;Rh^0P0_
;bl203Ph>080>c/k0P1<C4`2069RHP80RHV90P2OWil20:2PX080QXJ60P1]KFd204];B`80>CTi0P0X
:2P202LW9`80:RXZ0P0X:2P202<S8`809BDU0P0V9RH204E5A@80GEeM0P1gMgL308:2PP80S8b<0P24
Q8@407moO`@0Ph>30P22PX8208N7Q`80T92@0P2:RXX208f=S@80TI6A1P2FUYHO0<SPf0007@38h=P2
02XZ:P80C4a<0P15ADD204U9B@80;bl_0P1KFe/20820P080>SXj0P0Z:RX202HV9P80;bl_0P0[:b/2
02LW9`@09BDU0P0T92@302XZ:P809BDU0P1=CDd206EUI@80NGUi0P1jNWX2071`L080GUiN0P19BDT2
03Ti>@80;2`/0P0V9RH202@T9080:RXZ0P0_;bl202/[:`809BDU0P0W9bL202PX:0@08R8R0P0O7al2
04U9B@80NGUi0P2SXj<209BDU080HV9R0P1bLW8208b<S080_[jn0P31`L420;Bd]0<0YJFU0P2YZJT2
0:b/[080[jn_0P2b/[820;Fe]@80^;Rh0P30`<020<O7a`@0b/[:0P36a/H20<71`@80_Kfm0P2k^k/2
0<;2`P80a<C40P2m_Kd20;:b/P80[Zj^0P1VIVH20410@080ATI60P12@T8204=3@`80?Shn0P0h>3P2
03De=@80<c<c100a<C45030`<080<S8b100c<c<2038b<P80<C4a0P0_;bl202h^;P80;Bd]0P0_;bl2
02`/;080;bl_0P0e=CD203hn?P80BTY:0P1TI6@207UiN@80LG5a0P1OGel204];B`80>3Ph0P0[:b/4
02LW9`80:BTY0P0V9RH202<S8`80;Bd]0P0m?Cd205QHF080Lg=c0P20P80508N7Q`80Q8B40P21PH42
07moO`80P8200P22PX8208N7Q`80Rh^;0P2<S8`208f=S@80T92@0P2CTi<209JFUP80VIVI0P2JVYXY
0<SPf080:RXZ0P0o?cl205EEE@80?Cdm0P0];Bd205iNGP80PX:20P0h>3P402`/;080:RXZ0P0X:2P2
02HV9P@092@T0P0Y:BT302DU9@80:RXZ0P11@D4206UYJ@@0NGUi0P1bLW8206MWI`80B4Q80P0X:2P2
02@T9080:BTY0P0V9RH202LW9`80;Bd]0P0_;bl202DU9@80:BTY0P0W9bL2028R8P808B4Q0P0S8b<2
04E5A@80P8200P2QXJ4209FEU@@0I6AT0P2@T9020;Vi^@80a/K60P2_[jl30:NWY`80Y:BT0P2/[:`2
0;6a/@80/;2`102h^;P20<;2`P80aLG50P3=cLd20<[:bP80`l?30P32`/820<30`080_Kfm102o_kl2
0;fm_@80aLG50P2WYjL205iNGP80BTY:1011@D4404=3@`80>CTi0P0e=CD2038b<P80;bl_0P0`<305
03De=@80<c<c0P0e=CD203Lg=`80<c<c0P0e=CD202d];@80;2`/0P0Z:RX202l_;`80;Rh^0P0_;bl2
030`<080Cdm?0P12@T82069RHP80MgMg0P1_Kfl205aLG080ATI60P0i>CT202h^;P80:RXZ0P0W9bL2
02h^;P80:BTY0P0V9RH202h^;P80?3`l0P1FEUH207=cL`80PH610`2;Rh/408N7Q`80Ph>30P1mOGd4
08:2PP80QHF5102=SHd2092@T080UiNG0P2CTi<209BDU080VIVI0P2MWIdY0<SPf08092@T0P1?Cdl2
04A4A080BDU90P0`<30205aLG080Ogmo0P0j>SX402HV9P80;bl_0P0Y:BT202HV9P809bLW0P0Y:BT2
02@T90<0:RXZ0P0/;2`204i>CP80I6AT0P1hN7P207MgM`80M7Ad0P1JFUX204Q8B080=CDe0P0/;2`2
02LW9`808b<S0P0V9RH2038b<P80;2`/0P0W9bL202TY:@80;Bd]0P0L71`202@T90807AdM0P19BDT2
07IfMP80YZJV0P2DU9@2061PH080MgMg0P24Q8@20<?3``80aLG50P2^[Zh30:BTY080Zj^[0P2][Jd2
0:b/[080]kNg0P2d];@20;Ng]`80`L710P36a/H20<_;b`80c<c<0P3:b/X20<C4a080_[jn0P2j^[X2
0<30`080`/;20P2k^k/20;:b/P80][Jf0P1WIfL20410@080ADE50P14A4@20410@080?3`l0P0f=SH2
03Ph>080<c<c0P0e=CD202h^;PD0<30`0P0_;bl2034a<@80=3@d0P0Z:RX2038b<P80;Rh^0P0d=3@4
02d];@80:2PX0P0`<30203De=@80?Cdm0P1:BTX206EUI@80NWYj0P1iNGT205mOG`80CDe=0P0f=SH2
02d];@809BDU0P0X:2P202TY:@@09bLW0P0_;bl203lo?`80FEUI0P1_Kfl208:2PPD0QhN70P28R8P2
0861P@80OWin1021PH4208J6QP80RXZ:0P2?Shl208V9R@80TY:B0P2EUID209RHV080Vi^K0P2IVITO
0<SPf0007@38h=P202XZ:P80C4a<0P15ADD204U9B@80;bl_0P1KFe/20820P080>SXj0P0Z:RX202HV
9P80;bl_0P0[:b/202LW9`@09BDU0P0T92@302XZ:P809BDU0P1=CDd206EUI@80NGUi0P1jNWX2071`
L080GUiN0P19BDT203Ti>@80;2`/0P0V9RH202@T9080:RXZ0P0_;bl202/[:`809BDU0P0W9bL202PX
:0@08R8R0P0O7al204U9B@80NGUi0P2SXj<209BDU080HV9R0P1bLW8208b<S080_[jn0P31`L420;Bd
]0<0YJFU0P2YZJT20:b/[080[jn_0P2b/[820;Fe]@80^;Rh0P30`<020<O7a`@0b/[:0P36a/H20<71
`@80_Kfm0P2k^k/20<;2`P80a<C40P2m_Kd20;:b/P80[Zj^0P1VIVH20410@080ATI60P12@T8204=3
@`80?Shn0P0h>3P203De=@80<c<c100a<C45030`<080<S8b100c<c<2038b<P80<C4a0P0_;bl202h^
;P80;Bd]0P0_;bl202`/;080;bl_0P0e=CD203hn?P80BTY:0P1TI6@207UiN@80LG5a0P1OGel204];
B`80>3Ph0P0[:b/402LW9`80:BTY0P0V9RH202<S8`80;Bd]0P0m?Cd205QHF080Lg=c0P20P80508N7
Q`80Q8B40P21PH4207moO`80P8200P22PX8208N7Q`80Rh^;0P2<S8`208f=S@80T92@0P2CTi<209JF
UP80VIVI0P2JVYXY0<SPf080:RXZ0P0o?cl205EEE@80?Cdm0P0];Bd205iNGP80PX:20P0h>3P402`/
;080:RXZ0P0X:2P202HV9P@092@T0P0Y:BT302DU9@80:RXZ0P11@D4206UYJ@@0NGUi0P1bLW8206MW
I`80B4Q80P0X:2P202@T9080:BTY0P0V9RH202LW9`80;Bd]0P0_;bl202DU9@80:BTY0P0W9bL2028R
8P808B4Q0P0S8b<204E5A@80P8200P2QXJ4209FEU@@0I6AT0P2@T9020;Vi^@80a/K60P2_[jl30:NW
Y`80Y:BT0P2/[:`20;6a/@80/;2`102h^;P20<;2`P80aLG50P3=cLd20<[:bP80`l?30P32`/820<30
`080_Kfm102o_kl20;fm_@80aLG50P2WYjL205iNGP80BTY:1011@D4404=3@`80>CTi0P0e=CD2038b
<P80;bl_0P0`<30503De=@80<c<c0P0e=CD203Lg=`80<c<c0P0e=CD202d];@80;2`/0P0Z:RX202l_
;`80;Rh^0P0_;bl2030`<080Cdm?0P12@T82069RHP80MgMg0P1_Kfl205aLG080ATI60P0i>CT202h^
;P80:RXZ0P0W9bL202h^;P80:BTY0P0V9RH202h^;P80?3`l0P1FEUH207=cL`80PH610`2;Rh/408N7
Q`80Ph>30P1mOGd408:2PP80QHF5102=SHd2092@T080UiNG0P2CTi<209BDU080VIVI0P2MWIdY0<SP
f08092@T0P1?Cdl204A4A080BDU90P0`<30205aLG080Ogmo0P0j>SX402HV9P80;bl_0P0Y:BT202HV
9P809bLW0P0Y:BT202@T90<0:RXZ0P0/;2`204i>CP80I6AT0P1hN7P207MgM`80M7Ad0P1JFUX204Q8
B080=CDe0P0/;2`202LW9`808b<S0P0V9RH2038b<P80;2`/0P0W9bL202TY:@80;Bd]0P0L71`202@T
90807AdM0P19BDT207IfMP80YZJV0P2DU9@2061PH080MgMg0P24Q8@20<?3``80aLG50P2^[Zh30:BT
Y080Zj^[0P2][Jd20:b/[080]kNg0P2d];@20;Ng]`80`L710P36a/H20<_;b`80c<c<0P3:b/X20<C4
a080_[jn0P2j^[X20<30`080`/;20P2k^k/20;:b/P80][Jf0P1WIfL20410@080ADE50P14A4@20410
@080?3`l0P0f=SH203Ph>080<c<c0P0e=CD202h^;PD0<30`0P0_;bl2034a<@80=3@d0P0Z:RX2038b
<P80;Rh^0P0d=3@402d];@80:2PX0P0`<30203De=@80?Cdm0P1:BTX206EUI@80NWYj0P1iNGT205mO
G`80CDe=0P0f=SH202d];@809BDU0P0X:2P202TY:@@09bLW0P0_;bl203lo?`80FEUI0P1_Kfl208:2
PPD0QhN70P28R8P20861P@80OWin1021PH4208J6QP80RXZ:0P2?Shl208V9R@80TY:B0P2EUID209RH
V080Vi^K0P2IVITO0<SPf0007@38h=P2030`<080F5QH0P0h>3P4038b<P80E5AD0P1dM7@203De=@80
:BTY0P0S8b<202TY:@809RHV0P0U9BD602<S8`D0;Rh^0P1bLW8207YjNP80Ng]k0P1_Kfl205eMG@80
@D510P0W9bL2024Q8@808R8R0P0U9BD202XZ:P80;bl_0P0b<S8202h^;P@0:2PX0P0Y:BT202@T9080
8B4Q0P0M7Ad202<S8`80GUiN0P2BTY820:RXZ080MGEe0P1`L70207AdM080WYjN0P35aLD20;Zj^P<0
ZJVY0P2[Zj/20:f][@80[jn_0P2a/K420;>c/`80][Jf0P2m_Kd20<C4a080b<S80P3:b/X20<K6aP80
`L710P2n_[h20;fm_@80^[Zj0P2h^;P20<30`080`L710P3:b/X20:JVYP80EeMG0P1<C4`20492@P80
ATI60P11@D4203dm?@80>CTi0P0f=SH203De=@80=3@d0P0e=CD303Hf=P80=CDe1P0d=3@203<c<`80
<C4a0P0_;bl402h^;P@0;bl_0P0`<302038b<P80=cLg0P15ADD2051@D080B4Q80P0j>SX203<c<`80
;Bd]100/;2`202XZ:P80:BTY0P0W9bL202TY:@80?clo0P1JFUX2075aL@80Q8B40P28R8P308N7Q`80
QHF50P21PH4207moO`80OWin0P1oOgl208:2PP80QhN70P2<S8`208j>SP80Shn?0P2ATI4209>CT`80
V9RH0P2KVi/209bLW2T0b>3H0P0g=cL205IFEP80>SXj0P0_;bl2038b<P80FEUI0P1cLg<202h^;P80
9RHV0P0Y:BT202LW9`8092@T0P0W9bL402DU9@80820P0`0`<30203De=@80L71`0P1iNGT2075aL@80
LW9b0P1PH6020410@0@09RHV0P0T92@202LW9`80:b/[0P0_;bl203<c<`80=3@d0P0Z:RX2020P8080
9RHV0P0Z:RX201/K6`807alO0P0V9RH205YJFP80T92@0P2][Jd207IfMP80IfMW0P1kNg/209ZJVP80
`L710P33`l<50:JVYP80[:b/0P2`/;020:f][@80][Jf0P2d];@20;Vi^@80a<C40P38b<P20<_;b`80
`l?30P31`L420<;2`P80^[Zj0P2l_;`20;jn_P80^KVi0P32`/820<K6aP80XZ:R0P1HF5P204I6AP80
@4100P0o?cl204];B`80>c/k0P0f=SH203Lg=`80>CTi0P0e=CD2038b<P<0=CDe100d=3@203Xj>P80
<c<c0P0_;bl2038b<P80=3@d0P0^;Rh2030`<080;Rh^0P0_;bl202`/;080<c<c0P0g=cL203lo?`80
E5AD0P17AdL203Lg=`80<c<c0P0^;Rh202PX:080;Rh^100W9bL2030`<080:2PX0P0g=cL205QHF080
Kfm_0P23Ph<208R8R0<0RHV90P21PH420820P080Ph>30P1kNg/207inOP80Ph>30P22PX8208b<S080
Shn?0P2;Rh/209:BTP@0U9BD0P2LW9`209fMWBT0b>3H0P0d=3@205EEE@80=cLg0P0c<c<2034a<@80
EEEE0P1eMGD203Lg=`80;Bd]0P0S8b<202/[:`80:2PX0P0O7al202PX:0807AdM0P0W9bL302/[:`80
;Rh^0P1`L70207moO`80NWYj0P1^KVh2061PH080?clo0P0[:b/2028R8P8092@T0P0P820202/[:`@0
<C4a0P0[:b/402LW9`80;2`/0P0R8R8202<S8`806QXJ0P0T92@205mOG`80Shn?0P2^[Zh2079bLP80
Kfm_0P1dM7@209fMW@80b<S80P2f][H30:ZZZP80[:b/102^[Zh20;Bd]080[Jf]0P2i^KT40<;2`P80
bLW90P37alL20<C4a080_Kfm0P30`<020;no_`80^k^k0P2i^KT20;fm_@80`/;20P36a/H20:NWY`80
EeMG0P19BDT204Q8B080ADE50P17AdL203`l?080>SXj0P0f=SH2034a<@80;bl_0P0n?Sh303@d=080
<S8b100g=cL203De=@80=cLg100b<S82034a<@80:b/[0P0c<c<203@d=0@0;bl_0P0d=3@204U9B@80
Bd];0P17AdL203Ph>080=3@d0P0^;Rh202`/;080;Bd]0P0/;2`202TY:@809RHV0P0W9bL203hn?P80
F5QH0P1aLG4208F5Q@D0QhN70P25QHD208:2PP@0OGem0P1kNg/208>3P`80R8R80P29RHT208n?S`80
SXj>0P2@T90209:BTP80VYZJ0P2KVi/209ZJVQl0b>3H000M0<SPf080<30`0P1HF5P203Ph>0@0<S8b
0P1DE5@207AdM080=CDe0P0Y:BT202<S8`80:BTY0P0V9RH202DU9@H08b<S1@0^;Rh2079bLP80NWYj
0P1kNg/206m_K`80GEeM0P11@D4202LW9`808B4Q0P0R8R8202DU9@80:RXZ0P0_;bl2038b<P80;Rh^
100X:2P202TY:@8092@T0P0Q8B4201dM7@808b<S0P1NGUh209:BTP80Z:RX0P1eMGD2071`L080M7Ad
0P2NWYh20<G5a@80^[Zj0`2YZJT20:^[Z`80[Jf]0P2_[jl20;6a/@80/k>c0P2f][H20;fm_@80a<C4
0P38b<P20<[:bP80a/K60P31`L420;jn_P80_Kfm0P2j^[X20;Rh^080`<300P31`L420<[:bP80YZJV
0P1GEeL204a<C080@T920P16ATH20451@@80?Cdm0P0i>CT203Hf=P80=CDe0P0d=3@203De=@<0=SHf
0P0e=CD603@d=080<c<c0P0a<C4202l_;`@0;Rh^100_;bl2030`<080<S8b0P0g=cL204E5A@80D51@
0P18B4P203Xj>P80<c<c0P0];Bd402`/;080:RXZ0P0Y:BT202LW9`80:BTY0P0o?cl205YJFP80LG5a
0P24Q8@208R8R0<0QhN70P25QHD20861P@80Ogmo0P1nOWh207moO`80PX:20P27QhL208b<S080SXj>
0P2?Shl2096AT@80Ti>C0P2HV9P209^KV`80W9bL:@38h=P203Lg=`80EUIF0P0j>SX202l_;`80<S8b
0P1IFET207=cL`80;Rh^0P0V9RH202TY:@809bLW0P0T92@202LW9`@09BDU0P0P8203030`<080=CDe
0P1`L70207UiN@80LG5a0P1bLW82061PH080@410100V9RH202@T90809bLW0P0[:b/202l_;`80<c<c
0P0d=3@202XZ:P80820P0P0V9RH202XZ:P806a/K0P0O7al202HV9P80FUYJ0P2@T9020:f][@80MWIf
0P1WIfL207]kN`80VYZJ0P31`L420<?3``D0YZJV0P2/[:`20;2`/080[Jf]0P2f][H20;Bd]080^KVi
0P34a<@20<S8b080bl_;0P33`l<20<71`@80`/;20P2j^[X20;bl_080_[jn0P2i^KT20<;2`P80a/K6
0P2RXZ8205QHF080ATI60P10@40203lo?`80Bd];0P0k>c/203Hf=P80=cLg0P0i>CT203De=@80<S8b
0`0e=CD403@d=080>SXj0P0c<c<202l_;`80<S8b0P0d=3@202h^;P80<30`0P0^;Rh202l_;`80;2`/
0P0c<c<203Lg=`80?clo0P1DE5@204M7A`80=cLg0P0c<c<202h^;P80:2PX0P0^;Rh402LW9`80<30`
0P0X:2P203Lg=`80F5QH0P1_Kfl208>3P`80R8R80`29RHT20861P@80P8200P23Ph<207]kN`80OWin
0P23Ph<208:2PP80S8b<0P2?Shl208^;R`80TY:B102DU9@209bLW080WIfM:@38h=P203@d=080EEEE
0P0g=cL203<c<`80<C4a0P1EEED207EeM@80=cLg0P0];Bd202<S8`80:b/[0P0X:2P201lO7`80:2PX
0P0M7Ad202LW9`<0:b/[0P0^;Rh2071`L080Ogmo0P1jNWX206i^KP80H61P0P0o?cl202/[:`808R8R
0P0T92@2020P8080:b/[100a<C4202/[:`@09bLW0P0/;2`2028R8P808b<S0P0J6QX202@T9080GemO
0P2?Shl20:j^[P80LW9b0P1_Kfl207AdM080WIfM0P38b<P20;Jf]P<0ZZZZ0P2/[:`40:j^[P80];Bd
0P2][Jd20;Vi^@@0`/;20P39bLT20<O7a`80a<C40P2m_Kd20<30`080_kno0P2k^k/20;Vi^@80_Kfm
0P32`/820<K6aP80YjNW0P1GEeL204U9B@80B4Q80P15ADD204M7A`80?3`l0P0j>SX203Hf=P80<C4a
0P0_;bl203hn?P<0=3@d0P0b<S8403Lg=`80=CDe0P0g=cL4038b<P80<C4a0P0[:b/203<c<`80=3@d
100_;bl203@d=080BDU90P1;Bd/204M7A`80>3Ph0P0d=3@202h^;P80;2`/0P0];Bd202`/;080:BTY
0P0V9RH202LW9`80?Shn0P1HF5P2075aL@80QHF51@27QhL208F5Q@80PX:2101mOGd207]kN`80Ph>3
0P28R8P208V9R@80Shn?0P2>SXh2092@T080TY:B0P2JVYX209^KV`80VYZJ7`38h=P001d0b>3H0P1;
Bd/20410@080<c<c0P0[:b/202l_;`80GUiN0P1XJ6P202l_;`80:2PX0P0R8R8802HV9P809bLW0P0/
;2`303Lg=`80FUYJ0P1iNGT207=cL`80HV9R0P1@D50203hn?P80<C4a0P0W9bL202DU9@809RHV0P0Z
:RX202d];@80<30`0P0a<C4202`/;0809RHV100W9bL202DU9@807QhN0P0L71`201hN7P80ATI60P1]
KFd20:JVYP80SXj>0P1kNg/206i^KP80NWYj0P2/[:`20<G5a@<0^;Rh0P2QXJ420:j^[P80[Jf]0P2`
/;020;:b/P80]KFe0P2l_;`20<?3``80b<S80P3;bl/20<S8b080a<C40P2o_kl20;^k^`80^KVi0P2h
^;P20;bl_080^k^k0P3AdM420;bl_080QhN70P1>CTh40492@P80AdM70P19BDT204I6AP80@D510P0n
?Sh203Xj>P80=CDe0`0b<S8203De=@80>CTi0P0g=cL203@d=080<c<c0P0b<S82030`<0H0;bl_0P0a
<C42038b<P80<C4a0P0`<30203@d=080=cLg0P0e=CD2034a<@80;2`/0P0X:2P402LW9`80:RXZ0P0^
;Rh202`/;080>SXj0P1KFe/207QhN080PX:20P29RHT208J6QPD0PX:20P23Ph<207moO`80OGem0P20
P80208F5Q@80RHV90P2<S8`208j>SP80T92@0P2DU9@209RHV080VYZJ0P2LW9`209fMWBT0b>3H0P1:
BTX204M7A`80;Bd]0P0`<302034a<@80Hf=S0P1WIfL202h^;P80:b/[0P0V9RH202/[:`8092@T0P0X
:2P202HV9P809bLW0P0[:b/3030`<080G5aL0P1kNg/207alO080KVi^0P1?Cdl2038b<P80;Bd]0P0Z
:RX202h^;P80:2PX0P0[:b/202TY:@80;bl_0P0^;Rh202`/;0809BDU0P0T92@202`/;080<c<c0P0M
7Ad401lO7`80>CTi0P1hN7P20:2PX080V9RH0P20P80206e]K@80OGem0P2ZZZX20<_;b`<0];Bd0P2W
YjL20:f][@80/k>c0P2_[jl20;6a/@80]kNg0P2k^k/20<C4a080b<S80P3;bl/20<G5a@80`/;20P2n
_[h20;Vi^@80]kNg0P2j^[X20;Bd]080^k^k0P36a/H20<S8b080WIfM0P1@D5020451@@80AdM70P16
ATH204M7A`80A4A40P13@d<203lo?`80>SXj0P0e=CD303<c<`80=SHf0P0d=3@203<c<`@0=3@d0P0a
<C42038b<P80;bl_0P0a<C42030`<080;Rh^0P0b<S8203/k>`80<30`0P0h>3P203Ti>@80=SHf0P11
@D4202`/;080;Rh^0P0X:2P202HV9P80;2`/0P0Y:BT202XZ:P80>3Ph0P1NGUh208>3P`80RXZ:0P2=
SHd508:2PP80Ogmo0P24Q8@207emO@80OWin0P23Ph<208:2PP80Shn?0P2<S8`208j>SP80T92@0P2A
TI4209NGU`80VIVI0P2LW9`209jNWRT0b>3H0P1;Bd/20410@080=SHf0P0];Bd202h^;P80Fe]K0P1U
IFD202XZ:P809RHV0P0O7al2028R8P809bLW0P0X:2P202XZ:P809BDU0P0W9bL303Hf=P80Fe]K101d
M7@206EUI@80Bd];0P0j>SX2038b<P@09RHV0P0X:2P202HV9P@0<C4a0P0d=3@202PX:080<30`0P0M
7Ad202<S8`80;2`/100L71`2024Q8@80A4A40P1/K6`20:JVYP80SHf=0P1oOgl2071`L080Ng]k0P2/
[:`20;fm_@<0_kno0P2QXJ420;6a/@80Xj>S0P2d];@20:n_[`80]KFe0P2h^;P20<71`@@0b/[:0P38
b<P20<G5a@80`L710P2e]KD40;Zj^P80_;bl0P2m_Kd20<k>cP80_;bl0P26QXH204m?C`80@4100P0o
?cl204E5A@80B4Q80P15ADD203lo?`80@4100P0o?cl203<c<`<0<S8b0P0g=cL203De=@80>CTi0P0c
<c<2034a<@809bLW0P0b<S8202XZ:P80:BTY0P0];Bd203<c<`80<C4a0P0`<30203<c<`80>CTi0P0f
=SH203<c<`80<C4a0P0[:b/202TY:@8092@T0P0S8b<202`/;080:b/[0P0^;Rh203Ti>@80GEeM0P1f
MWH208J6QP80RXZ:0P25QHD308:2PP80Q8B40P1oOgl20820P080PH610P24Q8@208:2PP80RHV9102@
T902096AT@80Ti>C0P2GUiL209FEU@80WinO0P2JVYXO0<SPf0007@38h=P204];B`80@4100P0c<c<2
02/[:`80;bl_0P1NGUh206QXJ080;bl_0P0X:2P2028R8PP09RHV0P0W9bL202`/;0<0=cLg0P1JFUX2
07UiN@80Lg=c0P1RHV82051@D080?Shn0P0a<C4202LW9`809BDU0P0V9RH202XZ:P80;Bd]0P0`<302
034a<@80;2`/0P0V9RH402LW9`809BDU0P0N7Qh201`L70807QhN0P16ATH206e]K@80YZJV0P2>SXh2
07]kN`80KVi^0P1jNWX20:b/[080aLG50`2h^;P20:6QX@80[Zj^0P2][Jd20;2`/080/[:b0P2e]KD2
0;bl_080`l?30P38b<P20<_;b`80b<S80P34a<@20;no_`80^k^k0P2i^KT20;Rh^080_;bl0P2k^k/2
0=7Ad@80_;bl0P27QhL204i>CP@0@T920P17AdL204U9B@80ATI60P11@D4203hn?P80>SXj0P0e=CD3
038b<P80=CDe0P0i>CT203Lg=`80=3@d0P0c<c<2038b<P80<30`1P0_;bl2034a<@80<S8b0P0a<C42
030`<080=3@d0P0g=cL203De=@80<C4a0P0/;2`202PX:0@09bLW0P0Z:RX202h^;P80;2`/0P0j>SX2
05]KF`80N7Qh0P22PX8208V9R@80QXJ61@22PX8208>3P`80Ogmo0P1mOGd20820P080QHF50P29RHT2
08b<S080SXj>0P2@T90209BDU080V9RH0P2JVYX209bLW080WIfM:@38h=P204Y:BP80AdM70P0];Bd2
030`<080<C4a0P1SHf<206MWI`80;Rh^0P0[:b/202HV9P80:b/[0P0T92@202PX:0809RHV0P0W9bL2
02/[:`<0<30`0P1LG5`207]kN`80O7al0P1^KVh204m?C`80<S8b0P0];Bd202XZ:P80;Rh^0P0X:2P2
02/[:`80:BTY0P0_;bl202h^;P80;2`/0P0U9BD202@T9080;2`/0P0c<c<201dM7@@07alO0P0i>CT2
07QhN080X:2P0P2HV9P20820P080KFe]0P1mOGd20:ZZZP80bl_;0`2d];@20:NWY`80[Jf]0P2c/k<2
0:n_[`80/K6a0P2g]kL20;^k^`80a<C40P38b<P20<_;b`80aLG50P32`/820;jn_P80^KVi0P2g]kL2
0;Zj^P80];Bd0P2k^k/20<K6aP80b<S80P2MWId2051@D080@D510P17AdL204I6AP80AdM70P14A4@2
04=3@`80?clo0P0j>SX203De=@<0<c<c0P0f=SH203@d=080<c<c100d=3@2034a<@80<S8b0P0_;bl2
034a<@80<30`0P0^;Rh2038b<P80>c/k0P0`<30203Ph>080>CTi0P0f=SH20451@@80;2`/0P0^;Rh2
02PX:0809RHV0P0/;2`202TY:@80:RXZ0P0h>3P205iNGP80Ph>30P2:RXX208f=S@D0PX:20P1oOgl2
08B4Q080OGem0P1nOWh208>3P`80PX:20P2?Shl208b<S080SXj>0P2@T902096AT@80UiNG0P2IVIT2
09bLW080WYjN:@38h=P204];B`80@4100P0f=SH202d];@80;Rh^0P1KFe/206EUI@80:RXZ0P0V9RH2
01lO7`808R8R0P0W9bL202PX:080:RXZ0P0U9BD202LW9`<0=SHf0P1KFe/407AdM080IFEU0P1;Bd/2
03Xj>P80<S8b100V9RH202PX:0809RHV100a<C4203@d=080:2PX0P0`<30201dM7@808b<S0P0/;2`4
01`L70808B4Q0P14A4@206a/K080YZJV0P2=SHd207moO`80L71`0P1kNg/20:b/[080_Kfm0`2o_kl2
0:6QX@80/K6a0P2SXj<20;Bd]080[jn_0P2e]KD20;Rh^080`L71103:b/X20<S8b080aLG50P31`L42
0;Fe]@@0^[Zj0P2l_;`20;fm_@80c/k>0P2l_;`208J6QP80Cdm?0P10@40203lo?`80ADE50P18B4P2
04E5A@80?clo0P10@40203lo?`80<c<c0`0b<S8203Lg=`80=CDe0P0i>CT203<c<`80<C4a0P0W9bL2
038b<P80:RXZ0P0Y:BT202d];@80<c<c0P0a<C42030`<080<c<c0P0i>CT203Hf=P80<c<c0P0a<C42
02/[:`80:BTY0P0T92@202<S8`80;2`/0P0[:b/202h^;P80>CTi0P1MGEd207IfMP80QXJ60P2:RXX2
08F5Q@<0PX:20P24Q8@207moO`80P8200P21PH4208B4Q080PX:20P29RHT4092@T080TI6A0P2CTi<2
09NGU`80UIFE0P2OWil209ZJVQl0b>3H000M0<SPf080GemO0P0V9RH202l_;`80:BTY0P0];Bd206QX
J080GemO0P0[:b/202TY:@808R8R0P0U9BD202HV9P80:2PX0P0Z:RX202h^;P80>CTi0`14A4@208:2
PP80Lg=c0P1QHF4204=3@`80<30`0P0S8b<202HV9PH0;Rh^0P0_;bl4030`<080;Rh^0P0Y:BT202DU
9@809RHV0P0W9bL202HV9P808R8R0P0O7al2028R8P80<30`0P15ADD209FEU@80WinO0P2:RXX2079b
LP80GEeM0P2=SHd20<O7a`<0`l?30P2LW9`20;2`/080[:b/0P2^[Zh20;2`/080];Bd0P2k^k/20<?3
``80alO7103:b/X20<S8b080`L710P2j^[X40;Vi^@80]KFe0P2c/k<20;no_`80a<C40P3Bd]8209>C
T`80K6a/0P19BDT204a<C080E5AD0P1BDU8204i>CP80BDU90P13@d<203Xj>P<0<c<c0P0i>CT20410
@080?3`l0P0f=SH403De=@80=3@d0P0c<c<4038b<P80<c<c0P0d=3@203<c<`80<S8b0P0_;bl202d]
;@80;bl_0P0a<C4202h^;P80:RXZ0P0V9RH202DU9@80;Rh^0P0l?3`203De=@80DE5A0P1aLG4208b<
S080SHf=0P28R8P20861P@<0Ng]k0P1oOgl208>3P`80Ogmo0P1kNg/20820P080QhN70P2:RXX208b<
S080Shn?0P2BTY8209NGU`80W9bL1P2MWIdY0<SPf080F5QH0P0_;bl202`/;080:RXZ0P0_;bl205eM
G@80IFEU0P0_;bl202PX:0809RHV0P0R8R8202<S8`809RHV0P0a<C42030`<080>SXj0`19BDT207em
O@80N7Qh0P1UIFD20451@@80;bl_0P0X:2P202DU9@@0:b/[0P0/;2`203Ti>@@0;bl_0P0`<30202PX
:0809RHV100T92@202LW9`807alO0P0U9BD202<S8`80:2PX0P1?Cdl2096AT@80X:2P0P28R8P206i^
KP80IVIV0P2=SHd20;bl_0<0`<300P2VYZH20:b/[080ZZZZ0P2][Jd20;2`/080/k>c0P2k^k/20<?3
``80a/K60P3;bl/20<O7a`80bLW90P32`/820;^k^`80^KVi0P2k^k/40;Jf]P80_kno0P35aLD20<W9
b@80WinO0P1JFUX204Q8B080CTi>0P1FEUH204e=C@80D51@0P18B4P204M7A`80?3`l0`0d=3@203/k
>`80@4100P0h>3P203Hf=P80>CTi0P0e=CD2038b<P80>3Ph0P0a<C42038b<P80=CDe0P0c<c<403De
=@80<S8b0P0a<C4202d];@80:b/[0P0];Bd202/[:`80:BTY0P0X:2P202`/;080=CDe0P14A4@204];
B`80JVYZ0P2:RXX208b<S080R8R81@20P80207YjNP80QHF50P23Ph<207emO@80NWYj1P29RHT409:B
TP80UiNG0P2KVi/209jNWP80W9bL0P2OWilY0<SPf080GemO0P0T92@202d];@80:BTY0P0Z:RX206YZ
JP80H61P0P0Z:RX202d];@808B4Q0P0X:2P202DU9@8092@T0P0];Bd202XZ:P80>c/k0`14A4@20861
P@80MGEe0P1OGel20492@P80;bl_0P0R8R8202`/;080:BTY0P0^;Rh202l_;`80:b/[0P0c<c<2030`
<080<S8b0P0U9BD202PX:0808b<S0P0X:2P202XZ:P808R8R0P0M7Ad2024Q8@80<C4a0P17AdL209JF
UP80X:2P0P2:RXX206i^KP80G5aL0P2?Shl20<K6aP<0a<C40P2JVYX20;2`/080[Jf]0P2^[Zh20;:b
/P80]kNg0P2e]KD20<G5a@80c<c<0P39bLT20<G5a@80b<S80P31`L420;fm_@80^k^k0P2j^[X20;Bd
]080]KFe0P2l_;`20<O7a`80d];B0P2ATI4206UYJ@80B4Q80P1@D504055AD@80BTY:0P1<C4`20410
@080>3Ph0`0c<c<20492@P80?clo0P0i>CT203Hf=P80=CDe100g=cL203De=@80<30`0P0c<c<403De
=@80;bl_0P0b<S8202h^;P@0;Bd]0P0c<c<402/[:`@09RHV0P0^;Rh203/k>`80=SHf0P1>CTh207If
MP80SHf=102:RXX208>3P`<0OWin0P1mOGd208N7Q`80O7al0P1iNGT208>3P`80QHF50P2:RXX208^;
R`80SXj>0P2DU9@209JFUP80WinO0P2LW9`209jNWP80WIfM7`38h=P001d0b>3H0P1OGel202HV9P80
;bl_0P0Y:BT202d];@80J6QX0P1OGel202/[:`80:BTY0P0R8R8202DU9@809RHV0P0X:2P202XZ:P80
;Rh^0P0i>CT304A4A080PX:20P1cLg<2065QH@80@d=30P0`<30202<S8`809RHV1P0^;Rh202l_;`@0
<30`0P0^;Rh202TY:@809BDU0P0V9RH202LW9`809RHV0P0R8R8201lO7`808R8R0P0`<30204E5A@80
UIFE0P2OWil208Z:RP80LW9b0P1MGEd208f=S@80alO70`33`l<209bLW080/;2`0P2/[:`20:j^[P80
/;2`0P2d];@20;^k^`80`l?30P37alL40<[:bP80b<S80P31`L420;Zj^P@0^KVi0P2e]KD20;>c/`80
_kno0P34a<@20=;BdP80Ti>C0P1/K6`204U9B@80C4a<0P1DE5@2059BDP80CTi>0P19BDT204=3@`80
>SXj0`0c<c<203Ti>@80@4100P0l?3`203Hf=P@0=CDe0P0d=3@203<c<`@0<S8b0P0c<c<203@d=080
<c<c0P0b<S8202l_;`80;Bd]0P0_;bl2034a<@80;Rh^0P0Z:RX202HV9P809BDU0P0^;Rh203`l?080
=CDe0P1ADE42075aL@80S8b<0P2=SHd208R8R080PH610`1kNg/207moO`80Ph>30P1oOgl207]kN`80
P8200P27QhL208Z:RP80S8b<0P2?Shl209:BTP80UiNG0P2LW9`609fMWBT0b>3H0P1HF5P202l_;`80
;2`/0P0Z:RX202l_;`80GEeM0P1UIFD202l_;`80:2PX0P0V9RH2028R8P808b<S0P0V9RH2034a<@80
<30`0P0j>SX304U9B@80OGem0P1hN7P206EUI@80@D510P0_;bl202PX:0809BDU100[:b/202`/;080
>CTi100_;bl2030`<080:2PX0P0V9RH402@T90809bLW0P0O7al202DU9@808b<S0P0X:2P204m?C`80
TI6A0P2PX:0208R8R080KVi^0P1VIVH208f=S@80_;bl0`30`<020:JVYP80[:b/0P2ZZZX20:f][@80
/;2`0P2c/k<20;^k^`80`l?30P36a/H20<_;b`80alO70P39bLT20<;2`P80^k^k0P2i^KT20;^k^`@0
][Jf0P2o_kl20<G5a@80bLW90P2OWil205YJFP80B4Q80P1>CTh205IFEP80CDe=0P1@D50204Q8B080
AdM70P0l?3`303@d=080>c/k0P10@40203Ph>080=SHf0P0i>CT203De=@80<S8b0P0h>3P2034a<@80
<S8b0P0e=CD203<c<`@0=CDe0P0b<S82034a<@80;Bd]0P0[:b/202d];@80:b/[0P0Y:BT202PX:080
;2`/0P0e=CD204A4A080Bd];0P1ZJVX208Z:RP80S8b<0P28R8P50820P080NWYj0P25QHD208>3P`80
OGem0P1jNWX608V9R@@0TY:B0P2GUiL209^KV`80WYjN0P2LW9`209nOWbT0b>3H0P1OGel202@T9080
;Bd]0P0Y:BT202XZ:P80JVYZ0P1PH60202XZ:P80;Bd]0P0Q8B4202PX:0809BDU0P0T92@202d];@80
:RXZ0P0k>c/304A4A080PH610P1eMGD205mOG`80@T920P0_;bl2028R8P80;2`/0P0Y:BT202h^;P80
;bl_0P0[:b/203<c<`80<30`0P0b<S8202DU9@80:2PX0P0S8b<202PX:080:RXZ0P0R8R8201dM7@80
8B4Q0P0a<C4204M7A`80UYJF0P2PX:0208Z:RP80KVi^0P1LG5`208n?S`80a/K60`34a<@209ZJVP80
/;2`0P2][Jd20:j^[P80/[:b0P2g]kL20;Fe]@80aLG50P3<c<`20<W9b@80aLG50P38b<P20<71`@80
_Kfm0P2k^k/20;Zj^P80];Bd0P2e]KD20;bl_080alO70P3Bd]82096AT@80JFUY0P18B4P2051@D0@0
DE5A0P1:BTX204a<C080@4100P0h>3P303<c<`80@T920P0o?cl203Ti>@80=SHf0P0e=CD403Lg=`80
=CDe0P0`<30203<c<`@0=CDe0P0_;bl2038b<P80;Rh^100];Bd203<c<`@0:b/[100V9RH202h^;P80
>c/k0P0f=SH204i>CP80MWIf0P2=SHd408Z:RP80Ph>30`1nOWh207emO@80QhN70P1lO7`207UiN@80
Ph>30P25QHD208Z:RP80Rh^;0P2>SXh209BDU080UYJF0P2OWil209bLW080WYjN0P2MWIdO0<SPf000
7@38h=P204U9B@809bLW0P0];Bd202`/;080=3@d0P1KFe/2065QH@80;2`/0P0^;Rh602DU9@809bLW
0P0];Bd203Hf=P80BDU90`1HF5P207MgM`80I6AT0P1<C4`202l_;`809bLW0P0V9RH202TY:@@0;Rh^
200_;bl202h^;P80:b/[0P0X:2P202HV9P80:2PX0P0P820203Ph>080;2`/0P0S8b<2024Q8@80;2`/
0P1`L70209:BTP80WinO0P20P80205IFEP80MWIf0P2XZ:P30;Zj^P80^;Rh0P2][Jd20:^[Z`80ZZZZ
0P2/[:`20;2`/080^;Rh0P30`<020<G5a@80b<S8103;bl/20<C4a080_Kfm0P2i^KT20;Fe]@80/K6a
0P2_[jl20;Fe]@80_Kfm0P3Rh^820=3@d080UiNG0P1IFET204M7A`80CDe=0P1BDU8205UIF@80EUIF
0P1ADE4204e=C@<0Bd];0P1<C4`204e=C@80ADE50P0m?Cd203`l?080?Cdm100o?cl203/k>`80=CDe
0P0a<C4202l_;`80=SHf0P0n?Sh20451@@80@4100P0f=SH202/[:`80<30`0P0c<c<202l_;`80<S8b
0P0o?cl204Y:BP80MgMg101PH60207YjNP80Shn?0P1oOgl207emO@<0NGUi0P1kNg/207alO080NWYj
0P1hN7P207emO@80Ph>30P27QhL208^;R`80TI6A0P2FUYH209ZJVP80WIfM1P2NWYhY0<SPf080@410
0P0W9bL202TY:@80;Bd]0P0f=SH205UIF@80GEeM0P0[:b/202LW9`@09RHV0P0T92@202TY:@80;Rh^
0P0`<30204=3@`<0G5aL0P1fMWH2061PH080>SXj0P0Z:RX202TY:@80;2`/0P0_;bl2038b<P80;Bd]
0P0X:2P202l_;`80;Bd]0P0^;Rh203<c<`80:BTY0P0`<30202HV9P8092@T0P0S8b<202PX:080?Cdm
0P0Q8B42028R8P809bLW0P1^KVh208n?S`80WinO0P1gMgL206EUI@80Kfm_0P2RXZ830;no_`80^KVi
0P2XZ:P40:ZZZP80/;2`0P2^[Zh20;Jf]P80_kno0P34a<@20<_;b`80c<c<0P3;bl/20<O7a`80_;bl
0P2i^KT20;Fe]@80[:b/0P2a/K420;Ng]`80_kno0P36a/H20<g=c@80YZJV0P1NGUh204m?C`80DE5A
0P1?Cdl205iNGP80EeMG0P1=CDd204E5A@<0ATI60P1GEeL205ADE0@0@4100P13@d<203hn?P80>CTi
0P0k>c/203Ti>@80=SHf0P0b<S8202`/;080<S8b0P0e=CD203`l?080=cLg0P0h>3P202l_;`80:b/[
0P0_;bl4030`<080>3Ph0P1CDe<207]kN`80I6AT0P1QHF4207QhN080R8R80P21PH4207alO0<0NGUi
0P1jNWX207]kN`80O7al0P1gMgL207YjNP80Q8B40P29RHT208b<S080Shn?0P2FUYH209ZJVP80WinO
0P2QXJ4209ZJVP80WIfM:@38h=P204a<C080:2PX0P0Z:RX203<c<`80=3@d0P1OGel206=SH`80:b/[
0P0^;Rh202XZ:P809BDU0P0R8R8202PX:080;bl_0P0g=cL204m?C`<0EeMG0P1hN7P206ATI080De=C
0P0];Bd202h^;P@09RHV0P0`<30203@d=080;Rh^0P0_;bl202XZ:P80;2`/0P0Z:RX202d];@80:BTY
0P0P820202l_;`807AdM0P0g=cL202d];@808b<S0P0R8R8202XZ:P80KVi^0P2CTi<209bLW080Ph>3
0P1KFe/207AdM080ZZZZ0`2j^[X20;>c/`80[jn_0P2d];@20:NWY`80[:b/0P2d];@20;>c/`80_[jn
0P3<c<`20<O7a`@0c<c<0P34a<@20;no_`80/k>c0P2d];@20:n_[`80/k>c0P2`/;020;jn_P80iNGU
0P3Cdm<209fMW@80FUYJ0P1:BTX2055AD@80De=C101MGEd204m?C`80BTY:0`19BDT204Q8B080D51@
0P0o?cl20451@@80A4A40P11@D4203/k>`80@D510P0n?Sh203De=@80<30`0P0^;Rh203De=@80?Shn
0P14A4@203lo?`80=CDe0P0^;Rh2034a<@80=SHf0P0^;Rh203De=@80@4100P1;Bd/207MgM`80H61P
0P1LG5`207QhN080SHf=0P1mOGd207YjNP<0MGEe0P1iNGT207alO080Ng]k0P1gMgL207emO@80QhN7
0P24Q8@208^;R`80TI6A0P2DU9@209^KV`80WinO0P2LW9`209fMW@80WinO7`38h=P001d0b>3H0P19
BDT202LW9`80;Bd]0P0/;2`203@d=080Fe]K0P1QHF4202`/;080;Rh^1P0U9BD202LW9`80;Bd]0P0f
=SH204U9B@<0F5QH0P1gMgL206ATI080C4a<0P0_;bl202LW9`809RHV0P0Y:BT402h^;PP0;bl_0P0^
;Rh202/[:`80:2PX0P0V9RH202PX:080820P0P0h>3P202`/;0808b<S0P0Q8B4202`/;080L71`0P2B
TY8209nOW`80P8200P1FEUH207IfMP80Z:RX0`2j^[X20;Rh^080[Jf]0P2[Zj/20:ZZZP80[:b/0P2`
/;020;Rh^080`<300P35aLD20<S8b0@0bl_;0P34a<@20;fm_@80^KVi0P2e]KD20;6a/@80[jn_0P2e
]KD20;fm_@80h^;R0P3@d=0209NGU`80FEUI0P17AdL204e=C@80DU9B0P1IFET205IFEP80DE5A0P1=
CDd304];B`80C4a<0P1=CDd204E5A@80?Cdm0P0l?3`203dm?@@0?clo0P0k>c/203De=@80<C4a0P0_
;bl203Hf=P80?Shn0P11@D420410@080=SHf0P0[:b/2030`<080<c<c0P0_;bl2038b<P80?clo0P1:
BTX207MgM`@0H61P0P1jNWX208n?S`80Ogmo0P1mOGd307UiN@80Ng]k0P1lO7`207YjNP80N7Qh0P1m
OGd208>3P`80QhN70P2;Rh/2096AT@80UYJF0P2JVYX209fMW@H0WYjN:@38h=P20410@0809bLW0P0Y
:BT202d];@80=SHf0P1IFET205eMG@80:b/[0P0W9bL402HV9P8092@T0P0Y:BT202h^;P80<30`0P13
@d<305aLG080MWIf0P1PH60203Xj>P80:RXZ0P0Y:BT202`/;080;bl_0P0b<S8202d];@80:2PX0P0_
;bl202d];@80;Rh^0P0c<c<202TY:@80<30`0P0V9RH202@T90808b<S0P0X:2P203dm?@808B4Q0P0R
8R8202LW9`80KVi^0P2?Shl209nOW`80MgMg0P1UIFD206m_K`80XZ:R0`2o_kl20;Vi^@80Z:RX102Z
ZZX20;2`/080[Zj^0P2f][H20;no_`80a<C40P3;bl/20<c<c080bl_;0P37alL20;bl_080^KVi0P2e
]KD20:b/[080/K6a0P2g]kL20;no_`80a/K60P3=cLd20:JVYP80GUiN0P1?Cdl2055AD@80Cdm?0P1N
GUh205MGE`80CDe=0P15ADD304I6AP80EeMG0P1DE5@40410@080@d=30P0n?Sh203Ti>@80>c/k0P0i
>CT203Hf=P80<S8b0P0/;2`2038b<P80=CDe0P0l?3`203Lg=`80>3Ph0P0_;bl202/[:`80;bl_100`
<30203Ph>080De=C0P1kNg/206ATI080HF5Q0P1hN7P208R8R080PH610P1lO7`307UiN@80NWYj0P1k
Ng/207alO080MgMg0P1jNWX208B4Q080RHV90P2<S8`208n?S`80UYJF0P2JVYX209nOW`80XJ6Q0P2J
VYX209fMWBT0b>3H0P1<C4`202PX:080:RXZ0P0c<c<203@d=080GemO0P1SHf<202/[:`80;Rh^0P0Z
:RX202DU9@808R8R0P0X:2P202l_;`80=cLg0P1?Cdl305MGE`80N7Qh0P1TI6@205=CD`80;Bd]0P0^
;Rh402HV9P80<30`0P0d=3@202h^;P80;bl_0P0Z:RX202`/;080:RXZ0P0];Bd202TY:@80820P0P0_
;bl201dM7@80=cLg0P0];Bd202<S8`808R8R0P0Z:RX206i^KP80Ti>C0P2LW9`208>3P`80Fe]K0P1d
M7@20:ZZZP<0^[Zj0P2c/k<20:n_[`80];Bd0P2WYjL20:b/[080];Bd0P2c/k<20;jn_P80c<c<0P37
alL40<c<c080a<C40P2o_kl20;>c/`80];Bd0P2_[jl20;>c/`80/;2`0P2n_[h20>GUi@80dm?C0P2M
WId205YJFP80BTY:0P1ADE4205=CD`@0GEeM0P1?Cdl204Y:BP<0BDU90P18B4P2051@D080?clo0P11
@D4204A4A080@D510P0k>c/20451@@80?Shn0P0e=CD2030`<080;Rh^0P0e=CD203hn?P80A4A40P0o
?cl203De=@80;Rh^0P0a<C4203Hf=P80;Rh^0P0e=CD20410@080Bd];0P1gMgL2061PH080G5aL0P1h
N7P208f=S@80OGem0P1jNWX307EeM@80NGUi0P1lO7`207]kN`80MgMg0P1mOGd208N7Q`80Q8B40P2;
Rh/2096AT@80U9BD0P2KVi/209nOW`80W9bL0P2MWId209nOWal0b>3H000M0<SPf0@0;Bd]0P0/;2`2
034a<@80>c/k0P1=CDd2069RHP80;Rh^0P0b<S8202PX:0809bLW0P0T92@202HV9P80<C4a0P10@402
05QHF0<0Jf][0P1QHF42051@D080=cLg0P0S8b<202HV9P80;bl_0P0^;Rh202d];@H0;Rh^1P0];Bd4
02`/;080:b/[0P0a<C42024Q8@80C4a<0P0h>3P202@T908061PH0P0L71`204Q8B080NGUi0P2ZZZX2
092@T080GEeM0P1XJ6P208B4Q0<0Z:RX0P3?cll20:b/[080Zj^[0P2WYjL20:RXZ080[:b/0P2d];@2
0;bl_080`L710P36a/H20<[:bP80c<c<0P37alL20<71`@80^;Rh0P2a/K420:f][@80Zj^[0P2_[jl2
0;Bd]080_;bl0P33`l<20;jn_P80[Zj^0P1/K6`204i>CP80DU9B0P1RHV82065QH@80GemO0P1RHV83
06EUI@80HF5Q0P1KFe/2055AD@80BDU90P18B4P204Y:BP80CTi>0P1@D50204U9B@80?clo0P0b<S82
02/[:`80?Cdm0P1BDU8405]KF`80ADE50P0`<30203Ph>080@T920P0n?Sh20451@@80FEUI0P1dM7@2
079bLP80QhN70P1DE5@2061PH080QhN70P1dM7@207QhN0<0MWIf0P1eMGD207AdM080Lg=c0P1dM7@2
07UiN@80P8200P26QXH208f=S@80U9BD0P2JVYX209fMW@80WYjN0P2OWil40:2PX2T0b>3H0P0a<C42
030`<0@0;Bd]0P0l?3`205ADE080GUiN0P0a<C4202l_;`80;Bd]0P0V9RH202@T9080:BTY0P0c<c<2
03hn?P80GemO0`1PH60206a/K080EeMG0P0d=3@202DU9@80<30`100[:b/202`/;080;Rh^0P0];Bd2
03@d=080:RXZ0P0^;Rh402/[:`80:RXZ0P0^;Rh402LW9`80A4A40P0o?cl201hN7P807AdM0P0R8R82
03hn?P80PH610P2RXZ8208f=S@80JVYZ0P1YJFT207alO0<0/;2`0P36a/H20;Fe]@80Y:BT0P2ZZZX2
0:RXZ080[Jf]0P2a/K420;^k^`80`L710P35aLD40<S8b080b/[:0P30`<020;Fe]@80/k>c0P2YZJT2
0:j^[P80[Jf]0P2g]kL20;fm_@80a/K60P3:b/X20:f][@80I6AT0P1DE5@205EEE@80GemO0P1RHV82
061PH080I6AT0`1WIfL206ATI080H61P0P1:BTX204];B`80BDU90P13@d<2059BDP80BDU90P1ADE42
03/k>`80=SHf0P0_;bl203Ph>080DE5A0P1YJFT205iNGP80Bd];0P0`<30202h^;P80@d=30P15ADD2
0410@080E5AD0P1_Kfl207UiN@80P8200P1GEeL206EUI@80P8200P1gMgL207YjNP<0MGEe0P1cLg<4
07AdM080MgMg0P1jNWX20820P080QXJ60P2=SHd209>CT`80VIVI0P2LW9`209fMW@80XZ:R0P2PX:02
09fMWBT0b>3H0P0[:b/202d];@80:RXZ0P0c<c<203Ti>@80B4Q80P1NGUh202d];@80<C4a0P0V9RH2
02LW9`809RHV0P0X:2P202l_;`80@4100P1JFUX306UYJ@80H61P0P1=CDd203Ph>0807AdM0P0[:b/2
02d];@80:RXZ0P0];Bd202l_;`80;2`/0P0b<S8202l_;`80:b/[0P0];Bd402`/;080:RXZ0P0f=SH2
01/K6`80DE5A0P0i>CT202HV9P8061PH0P0K6a/204Y:BP80MWIf0P2`/;0208V9R@80HV9R0P1SHf<2
08N7Q`<0YJFU0P3Bd]820:RXZ080[:b/0P2TY:@20;6a/@80YZJV0P2c/k<20;Zj^P80`L710P33`l<2
0<_;b`80alO70P35aLD20<C4a080^;Rh0P2g]kL20:NWY`80Zj^[0P2`/;020;>c/`80^k^k0P32`/82
0;Vi^@80[jn_0P1SHf<404a<C080GemO0P1VIVH205]KF`80HV9R0`1WIfL2061PH080FEUI0P1DE5@2
04M7A`80BTY:0P19BDT204a<C080DE5A0P1=CDd20451@@@0;bl_0P0e=CD2059BDP80H61P0P1KFe/2
0492@P80<30`0P0i>CT20492@P80?3`l0P11@D4205MGE`80LW9b0P1dM7@208N7Q`80E5AD0P1TI6@2
08>3P`80M7Ad0P1kNg/307MgM`H0M7Ad0P1gMgL207QhN080P8200P28R8P208b<S080UiNG0P2MWId2
09jNWP80XJ6Q102OWil20:BTY1l0b>3H000M0<SPf0@0;Bd]0P0/;2`2034a<@80>c/k0P1=CDd2069R
HP80;Rh^0P0b<S8202PX:0809bLW0P0T92@202HV9P80<C4a0P10@40205QHF0<0Jf][0P1QHF42051@
D080=cLg0P0S8b<202HV9P80;bl_0P0^;Rh202d];@H0;Rh^1P0];Bd402`/;080:b/[0P0a<C42024Q
8@80C4a<0P0h>3P202@T908061PH0P0L71`204Q8B080NGUi0P2ZZZX2092@T080GEeM0P1XJ6P208B4
Q0<0Z:RX0P3?cll20:b/[080Zj^[0P2WYjL20:RXZ080[:b/0P2d];@20;bl_080`L710P36a/H20<[:
bP80c<c<0P37alL20<71`@80^;Rh0P2a/K420:f][@80Zj^[0P2_[jl20;Bd]080_;bl0P33`l<20;jn
_P80[Zj^0P1/K6`204i>CP80DU9B0P1RHV82065QH@80GemO0P1RHV8306EUI@80HF5Q0P1KFe/2055A
D@80BDU90P18B4P204Y:BP80CTi>0P1@D50204U9B@80?clo0P0b<S8202/[:`80?Cdm0P1BDU8405]K
F`80ADE50P0`<30203Ph>080@T920P0n?Sh20451@@80FEUI0P1dM7@2079bLP80QhN70P1DE5@2061P
H080QhN70P1dM7@207QhN0<0MWIf0P1eMGD207AdM080Lg=c0P1dM7@207UiN@80P8200P26QXH208f=
S@80U9BD0P2JVYX209fMW@80WYjN0P2OWil40:2PX2T0b>3H0P0a<C42030`<0@0;Bd]0P0l?3`205AD
E080GUiN0P0a<C4202l_;`80;Bd]0P0V9RH202@T9080:BTY0P0c<c<203hn?P80GemO0`1PH60206a/
K080EeMG0P0d=3@202DU9@80<30`100[:b/202`/;080;Rh^0P0];Bd203@d=080:RXZ0P0^;Rh402/[
:`80:RXZ0P0^;Rh402LW9`80A4A40P0o?cl201hN7P807AdM0P0R8R8203hn?P80PH610P2RXZ8208f=
S@80JVYZ0P1YJFT207alO0<0/;2`0P36a/H20;Fe]@80Y:BT0P2ZZZX20:RXZ080[Jf]0P2a/K420;^k
^`80`L710P35aLD40<S8b080b/[:0P30`<020;Fe]@80/k>c0P2YZJT20:j^[P80[Jf]0P2g]kL20;fm
_@80a/K60P3:b/X20:f][@80I6AT0P1DE5@205EEE@80GemO0P1RHV82061PH080I6AT0`1WIfL206AT
I080H61P0P1:BTX204];B`80BDU90P13@d<2059BDP80BDU90P1ADE4203/k>`80=SHf0P0_;bl203Ph
>080DE5A0P1YJFT205iNGP80Bd];0P0`<30202h^;P80@d=30P15ADD20410@080E5AD0P1_Kfl207Ui
N@80P8200P1GEeL206EUI@80P8200P1gMgL207YjNP<0MGEe0P1cLg<407AdM080MgMg0P1jNWX20820
P080QXJ60P2=SHd209>CT`80VIVI0P2LW9`209fMW@80XZ:R0P2PX:0209fMWBT0b>3H0P0[:b/202d]
;@80:RXZ0P0c<c<203Ti>@80B4Q80P1NGUh202d];@80<C4a0P0V9RH202LW9`809RHV0P0X:2P202l_
;`80@4100P1JFUX306UYJ@80H61P0P1=CDd203Ph>0807AdM0P0[:b/202d];@80:RXZ0P0];Bd202l_
;`80;2`/0P0b<S8202l_;`80:b/[0P0];Bd402`/;080:RXZ0P0f=SH201/K6`80DE5A0P0i>CT202HV
9P8061PH0P0K6a/204Y:BP80MWIf0P2`/;0208V9R@80HV9R0P1SHf<208N7Q`<0YJFU0P3Bd]820:RX
Z080[:b/0P2TY:@20;6a/@80YZJV0P2c/k<20;Zj^P80`L710P33`l<20<_;b`80alO70P35aLD20<C4
a080^;Rh0P2g]kL20:NWY`80Zj^[0P2`/;020;>c/`80^k^k0P32`/820;Vi^@80[jn_0P1SHf<404a<
C080GemO0P1VIVH205]KF`80HV9R0`1WIfL2061PH080FEUI0P1DE5@204M7A`80BTY:0P19BDT204a<
C080DE5A0P1=CDd20451@@@0;bl_0P0e=CD2059BDP80H61P0P1KFe/20492@P80<30`0P0i>CT20492
@P80?3`l0P11@D4205MGE`80LW9b0P1dM7@208N7Q`80E5AD0P1TI6@208>3P`80M7Ad0P1kNg/307Mg
M`H0M7Ad0P1gMgL207QhN080P8200P28R8P208b<S080UiNG0P2MWId209jNWP80XJ6Q102OWil20:BT
Y1l0b>3H000M0<SPf080;2`/0P0];Bd202XZ:P80;bl_0P0g=cL205EEE@80EUIF0P0d=3@202XZ:P80
9RHV0P0X:2P202DU9@809RHV0P0f=SH204U9B@80HF5Q0`1_Kfl205YJFP80?Cdm0P0];Bd202<S8`80
9BDU0P0Z:RX202/[:`80;2`/0P0_;bl2030`<080;Bd]0P0Y:BT202XZ:P809bLW0P0Y:BT202XZ:P80
8b<S0P0V9RH202`/;080Bd];0P0d=3@201`L708061PH0P0L71`203De=@80F5QH0P2ATI4209fMW@80
MgMg0P1XJ6P2079bLP<0Rh^;0P2j^[X20;bl_080];Bd0P2VYZH20:NWY`80Zj^[0P2`/;020;Jf]P80
_Kfm0P32`/820<K6aP80b<S80P37alL20<?3``80^KVi0P2^[Zh20:RXZ080YZJV0P2YZJT20:n_[`80
][Jf0P33`l<20=7Ad@80d=3@0P35aLD2075aL@80I6AT0P1NGUh2061PH080IVIV0P1ZJVX306e]K@80
Jf][0P1WIfL206ATI0@0HF5Q0P1RHV8206EUI@80IfMW0P1TI6@205]KF`80?clo0P0];Bd204M7A`80
Jf][0P28R8P209RHV080MWIf0P1CDe<204I6AP80GemO0P1SHf<204];B`80H61P0P1bLW8207UiN@80
Ph>3101RHV8207QhN080LG5a0P1`L70506a/K080KVi^0P1]KFd206m_K`80MgMg0P22PX8208b<S080
U9BD0P2IVIT209^KV`80WYjN0P2PX:020:6QX@@0XZ:R:@38h=P402`/;080<C4a0P0Z:RX2030`<080
Fe]K0P1GEeL203@d=080;Rh^0P0Y:BT202DU9@808b<S0P0T92@2030`<080CDe=0P1WIfL306a/K080
HV9R0P0d=3@202PX:080:b/[0P0U9BD202PX:0809RHV0P0[:b/203@d=080<S8b0P0^;Rh202d];@80
9RHV0P0/;2`202XZ:P809BDU0P0X:2P202d];@80>c/k0P1EEED202HV9P8071`L0P0N7Qh2024Q8@80
;2`/0P1QHF4209BDU080XJ6Q0P1cLg<206QXJ080Jf][0`2<S8`20;Vi^@80`L710P2`/;020:BTY080
[:b/0P2WYjL20;:b/P80^k^k0P2m_Kd20<;2`P80a<C40P3;bl/20<S8b080`l?30P2i^KT20;6a/@@0
Z:RX0P2VYZH20;:b/P80^[Zj0P2l_;`20<C4a080c<c<0P2b/[8207EeM@80EEEE0P1TI6@2061PH080
J6QX0P1/K6`306][J`80IFEU0P1NGUh205mOG`80HV9R101VIVH206UYJ@80KFe]0P1[Jf/205MGE`80
?Shn0P0_;bl204E5A@80Kfm_0P2ATI4208B4Q080O7al0P1CDe<204A4A080IFEU0P1`L70204U9B@80
IfMW0P1^KVh207]kN`80O7al0P1[Jf/205mOG`80MGEe0P1dM7@206m_K`<0KFe]0P1aLG42071`L080
IVIV0P1]KFd207UiN@80PH610P2:RXX209>CT`80Vi^K0P2OWil209ZJVP80WYjN102SXj<20::RXRT0
b>3H0P0X:2P2034a<@809BDU0P0d=3@203De=@80EeMG0P1OGel203@d=080:BTY0P0X:2P202LW9`80
8R8R0P0U9BD203<c<`80@d=30P1RHV8306e]K@80GemO0P0n?Sh202/[:`808R8R0P0Z:RX202PX:080
;Bd]0P0Z:RX202d];@80;Rh^0P0[:b/202TY:@80:RXZ0P0/;2`202XZ:P80;Rh^100R8R8202d];@80
BTY:0P0_;bl201TI6@805ADE0P0M7Ad203/k>`80EEEE0P2@T90209jNWP80MGEe0P1ZJVX207=cL`<0
S8b<0P2i^KT20;^k^`80][Jf0P2SXj<20:BTY080Zj^[0P2d];@20;Vi^@80_[jn0P32`/820<O7a`@0
c<c<0P31`L420;Fe]@80[jn_0P2YZJT20:^[Z`80ZZZZ0P2_[jl20;Zj^P80aLG50P3:b/X20=KFeP80
b/[:0P1lO7`2069RHP80GUiN0P1PH60406YZJP<0K6a/0P1^KVh206UYJ@80I6AT0P1NGUh205aLG0@0
HV9R0P1VIVH2065QH@80F5QH0P10@402030`<080BDU90P1^KVh208F5Q@80UiNG0P1hN7P2059BDP80
ATI60P1NGUh206IVIP80CDe=0P1MGEd207EeM@80Ng]k0P24Q8@205iNGP80IFEU0P1jNWX407AdM0<0
K6a/0P1^KVh206m_K`80Jf][0P1_Kfl207EeM@80PX:20P29RHT409FEU@80UYJF0P2JVYX209bLW080
XJ6Q0P2RXZ8209nOWal0b>3H000M0<SPf080;2`/0P0];Bd202XZ:P80;bl_0P0g=cL205EEE@80EUIF
0P0d=3@202XZ:P809RHV0P0X:2P202DU9@809RHV0P0f=SH204U9B@80HF5Q0`1_Kfl205YJFP80?Cdm
0P0];Bd202<S8`809BDU0P0Z:RX202/[:`80;2`/0P0_;bl2030`<080;Bd]0P0Y:BT202XZ:P809bLW
0P0Y:BT202XZ:P808b<S0P0V9RH202`/;080Bd];0P0d=3@201`L708061PH0P0L71`203De=@80F5QH
0P2ATI4209fMW@80MgMg0P1XJ6P2079bLP<0Rh^;0P2j^[X20;bl_080];Bd0P2VYZH20:NWY`80Zj^[
0P2`/;020;Jf]P80_Kfm0P32`/820<K6aP80b<S80P37alL20<?3``80^KVi0P2^[Zh20:RXZ080YZJV
0P2YZJT20:n_[`80][Jf0P33`l<20=7Ad@80d=3@0P35aLD2075aL@80I6AT0P1NGUh2061PH080IVIV
0P1ZJVX306e]K@80Jf][0P1WIfL206ATI0@0HF5Q0P1RHV8206EUI@80IfMW0P1TI6@205]KF`80?clo
0P0];Bd204M7A`80Jf][0P28R8P209RHV080MWIf0P1CDe<204I6AP80GemO0P1SHf<204];B`80H61P
0P1bLW8207UiN@80Ph>3101RHV8207QhN080LG5a0P1`L70506a/K080KVi^0P1]KFd206m_K`80MgMg
0P22PX8208b<S080U9BD0P2IVIT209^KV`80WYjN0P2PX:020:6QX@@0XZ:R:@38h=P402`/;080<C4a
0P0Z:RX2030`<080Fe]K0P1GEeL203@d=080;Rh^0P0Y:BT202DU9@808b<S0P0T92@2030`<080CDe=
0P1WIfL306a/K080HV9R0P0d=3@202PX:080:b/[0P0U9BD202PX:0809RHV0P0[:b/203@d=080<S8b
0P0^;Rh202d];@809RHV0P0/;2`202XZ:P809BDU0P0X:2P202d];@80>c/k0P1EEED202HV9P8071`L
0P0N7Qh2024Q8@80;2`/0P1QHF4209BDU080XJ6Q0P1cLg<206QXJ080Jf][0`2<S8`20;Vi^@80`L71
0P2`/;020:BTY080[:b/0P2WYjL20;:b/P80^k^k0P2m_Kd20<;2`P80a<C40P3;bl/20<S8b080`l?3
0P2i^KT20;6a/@@0Z:RX0P2VYZH20;:b/P80^[Zj0P2l_;`20<C4a080c<c<0P2b/[8207EeM@80EEEE
0P1TI6@2061PH080J6QX0P1/K6`306][J`80IFEU0P1NGUh205mOG`80HV9R101VIVH206UYJ@80KFe]
0P1[Jf/205MGE`80?Shn0P0_;bl204E5A@80Kfm_0P2ATI4208B4Q080O7al0P1CDe<204A4A080IFEU
0P1`L70204U9B@80IfMW0P1^KVh207]kN`80O7al0P1[Jf/205mOG`80MGEe0P1dM7@206m_K`<0KFe]
0P1aLG42071`L080IVIV0P1]KFd207UiN@80PH610P2:RXX209>CT`80Vi^K0P2OWil209ZJVP80WYjN
102SXj<20::RXRT0b>3H0P0X:2P2034a<@809BDU0P0d=3@203De=@80EeMG0P1OGel203@d=080:BTY
0P0X:2P202LW9`808R8R0P0U9BD203<c<`80@d=30P1RHV8306e]K@80GemO0P0n?Sh202/[:`808R8R
0P0Z:RX202PX:080;Bd]0P0Z:RX202d];@80;Rh^0P0[:b/202TY:@80:RXZ0P0/;2`202XZ:P80;Rh^
100R8R8202d];@80BTY:0P0_;bl201TI6@805ADE0P0M7Ad203/k>`80EEEE0P2@T90209jNWP80MGEe
0P1ZJVX207=cL`<0S8b<0P2i^KT20;^k^`80][Jf0P2SXj<20:BTY080Zj^[0P2d];@20;Vi^@80_[jn
0P32`/820<O7a`@0c<c<0P31`L420;Fe]@80[jn_0P2YZJT20:^[Z`80ZZZZ0P2_[jl20;Zj^P80aLG5
0P3:b/X20=KFeP80b/[:0P1lO7`2069RHP80GUiN0P1PH60406YZJP<0K6a/0P1^KVh206UYJ@80I6AT
0P1NGUh205aLG0@0HV9R0P1VIVH2065QH@80F5QH0P10@402030`<080BDU90P1^KVh208F5Q@80UiNG
0P1hN7P2059BDP80ATI60P1NGUh206IVIP80CDe=0P1MGEd207EeM@80Ng]k0P24Q8@205iNGP80IFEU
0P1jNWX407AdM0<0K6a/0P1^KVh206m_K`80Jf][0P1_Kfl207EeM@80PX:20P29RHT409FEU@80UYJF
0P2JVYX209bLW080XJ6Q0P2RXZ8209nOWal0b>3H000M0<SPf080;bl_0P0/;2`202TY:@80;Bd]0P0a
<C4205eMG@80AdM70P0i>CT202<S8`8092@T0P0Y:BT202HV9P809bLW0P0k>c/2055AD@80IFEU0`1^
KVh2059BDP80;bl_100X:2P402HV9P80:2PX0P0[:b/202l_;`80<30`0P0/;2`202HV9P@0:2PX0P0V
9RH202XZ:P80@4100P1FEUH205=CD`80@4100P0/;2`201/K6`8071`L0P0R8R8202PX:080>3Ph0P1^
KVh20:2PX080T92@0P1cLg<206a/K0<0Lg=c0P2KVi/20<C4a080^[Zj0P2YZJT20:RXZ080ZZZZ0P2]
[Jd20;6a/@80^;Rh0P2o_kl20<;2`P80a<C40P36a/H20<G5a@80^k^k0P2^[Zh20:JVYP80XJ6Q0P2S
Xj<20:VYZ@80/K6a0P2i^KT20<;2`P80alO70P2f][H20;Vi^@80Rh^;101QHF4206a/K080Kfm_1`1b
LW8207EeM@80N7Qh0P1iNGT207YjNP80O7al101mOGd207IfMP80DE5A0P0f=SH205]KF`80QhN70P2A
TI42092@T080QHF50P1kNg/205aLG080NGUi0P25QHD205MGE`80HF5Q0P1ZJVX207AdM080N7Qh0P1a
LG4206IVIP80IfMW0P1/K6`206IVIP<0H61P0P1RHV8206MWI`80J6QX0P1[Jf/207QhN080QhN70P2D
U9@409jNWP80WIfM0P2OWil20::RXP80Xj>S0P2TY:@20:FUYBT0b>3H0P0`<30202l_;`80:BTY0P0Z
:RX203`l?080De=C0P1ADE42038b<P@09RHV0P0X:2P202XZ:P80<30`0P0a<C4205EEE@80IFEU0`1X
J6P205]KF`80;Bd]0P0W9bL402PX:08092@T100Z:RX2030`<080;bl_100X:2P202XZ:P80:2PX0P0a
<C4202d];@80>3Ph0P1BDU82069RHP80?Cdm0P0Y:BT2028R8P809RHV100Q8B4203De=@80Ng]k0P2F
UYH209VIV@80LG5a0P1]KFd307MgM`80WYjN0P2l_;`20<;2`P80YjNW0P2SXj<20:b/[080[Zj^0P2_
[jl20;Rh^0@0`<300P33`l<20<O7a`80aLG50P2k^k/20:b/[080Xj>S0P2QXJ420::RXP80YZJV0P2g
]kL20;Zj^P80`/;21038b<P20;Jf]P80PX:20P1TI6@2069RHP80K6a/1@1aLG42079bLP80N7Qh0P1e
MGD207IfMP80OGem0P1hN7P207EeM@80O7al0P21PH4206i^KP80F5QH0P0c<c<205YJFP80PH610P2E
UID209:BTP80Rh^;0P1dM7@2061PH080MgMg0P1mOGd205]KF`80FEUI0P1aLG4207=cL`80O7al0P1a
LG4206UYJ@80I6AT0P1^KVh206=SH`<0GEeM0P1TI6@2065QH@80J6QX0P1]KFd207YjNP80QHF50P2H
V9P209bLW080WIfM0P2LW9`209fMW@80XJ6Q0P2VYZH20:BTY080YJFU:@38h=P202XZ:P80;Rh^0P0X
:2P202/[:`80<c<c0P1HF5P204I6AP80>3Ph0P0W9bL2020P8080;2`/0P0T92@202`/;080=cLg0P1E
EED206MWI`<0JVYZ0P1FEUH202d];@8092@T0P0Z:RX2028R8P809bLW0P0Y:BT202d];@80:b/[0P0c
<c<202l_;`80:2PX0P0R8R8202/[:`8092@T0P0V9RH204=3@`80DE5A0P1DE5@203lo?`80:RXZ0P0M
7Ad201lO7`808b<S0P0V9RH203Ti>@80Jf][0P2SXj<208n?S`80M7Ad0P1/K6`3079bLP80V9RH0P35
aLD20;^k^`80[:b/0P2VYZH40:b/[080/;2`0P2k^k/20;jn_P80`<300P32`/820<W9b@80a/K60P2k
^k/20;Bd]080Xj>S0P2RXZ820:FUY@80ZJVY0P2_[jl20;^k^`80`<300P3:b/X20;Fe]@80^;Rh0P29
RHT206ATI080IFEU0P1/K6`206e]K@<0M7Ad0P1_Kfl207EeM@80LG5a0P1lO7`2079bLP80Ogmo0P1m
OGd20820P080NGUi0P1jNWX204m?C`80=3@d0P1KFe/208B4Q080Ti>C0P2>SXh208R8R080O7al0P1H
F5P207]kN`80QhN70P1GEeL205mOG`80K6a/0P1cLg<207YjNP80L71`0P1UIFD206UYJ@80K6a/0P1O
Gel3069RHP80I6AT101WIfL206a/K080NGUi0P28R8P209>CT`80WinO0P2KVi/209nOW`80X:2P0P2R
XZ840:FUY@80XJ6Q7`38h=P001d0b>3H0P0_;bl202`/;080:BTY0P0];Bd2034a<@80GEeM0P17AdL2
03Ti>@808b<S0P0T92@202TY:@809RHV0P0W9bL203/k>`80DE5A0P1UIFD306i^KP80DU9B0P0_;bl4
02PX:0@09RHV0P0X:2P202/[:`80;bl_0P0`<30202`/;0809RHV100X:2P202HV9P80:RXZ0P10@402
05IFEP80De=C0P10@40202`/;0806a/K0P0L71`2028R8P80:2PX0P0h>3P206i^KP80X:2P0P2@T902
07=cL`80K6a/0`1cLg<209^KV`80a<C40P2j^[X20:VYZ@80Z:RX0P2ZZZX20:f][@80/K6a0P2h^;P2
0;no_`80`/;20P34a<@20<K6aP80aLG50P2k^k/20:j^[P80YZJV0P2QXJ420:>SX`80ZJVY0P2a/K42
0;Vi^@80`/;20P37alL20;Jf]P80^KVi0P2;Rh/4065QH@80K6a/0P1_Kfl7079bLP80MGEe0P1hN7P2
07UiN@80NWYj0P1lO7`407emO@80MWIf0P1ADE4203Hf=P80Fe]K0P27QhL2096AT@80T92@0P25QHD2
07]kN`80G5aL0P1iNGT208F5Q@80EeMG0P1QHF4206YZJP80M7Ad0P1hN7P2075aL@80IVIV0P1WIfL2
06a/K080IVIV0`1PH602069RHP80IfMW0P1XJ6P206][J`80N7Qh0P27QhL209BDU0@0WYjN0P2MWId2
09nOW`80XZ:R0P2SXj<20:BTY080YJFU:@38h=P2030`<080;bl_0P0Y:BT202XZ:P80?3`l0P1CDe<2
055AD@80<S8b100V9RH202PX:080:RXZ0P0`<302034a<@80EEEE0P1UIFD306QXJ080Fe]K0P0];Bd2
02LW9`@0:2PX0P0T92@402XZ:P80<30`0P0_;bl402PX:080:RXZ0P0X:2P2034a<@80;Bd]0P0h>3P2
059BDP80HV9R0P0m?Cd202TY:@808R8R0P0V9RH4024Q8@80=CDe0P1kNg/209JFUP80VIVI0P1aLG42
06e]K@<0MgMg0P2NWYh20;bl_080`/;20P2WYjL20:>SX`80[:b/0P2^[Zh20:n_[`80^;Rh1030`<02
0<?3``80alO70P35aLD20;^k^`80[:b/0P2SXj<20:6QX@80XZ:R0P2VYZH20;Ng]`80^[Zj0P32`/84
0<S8b080][Jf0P22PX8206ATI080HV9R0P1/K6`5075aL@80LW9b0P1hN7P207EeM@80MWIf0P1mOGd2
07QhN080MGEe0P1lO7`20861P@80KVi^0P1HF5P203<c<`80FUYJ0P21PH4209FEU@80TY:B0P2;Rh/2
07AdM080H61P0P1gMgL207emO@80Fe]K0P1IFET2075aL@80Lg=c0P1lO7`2075aL@80JFUY0P1TI6@2
06i^KP80Hf=S0`1MGEd206ATI080HF5Q0P1XJ6P206e]K@80NWYj0P25QHD209RHV080W9bL0P2MWId2
09bLW080WIfM0P2QXJ420:JVYP80Y:BT0P2UYJDY0<SPf080:RXZ0P0^;Rh202PX:080:b/[0P0c<c<2
05QHF080ATI60P0h>3P202LW9`80820P0P0/;2`202@T9080;2`/0P0g=cL205EEE@80IfMW0`1ZJVX2
05IFEP80;Bd]0P0T92@202XZ:P808R8R0P0W9bL202TY:@80;Bd]0P0[:b/203<c<`80;bl_0P0X:2P2
028R8P80:b/[0P0T92@202HV9P80@d=30P1ADE4205ADE080?clo0P0Z:RX201dM7@807alO0P0S8b<2
02HV9P80>CTi0P1[Jf/20:>SX`80Shn?0P1dM7@206a/K0<0LW9b0P2HV9P20<G5a@80^k^k0P2/[:`2
0:JVYP@0[:b/0P2`/;020;^k^`80_[jn0P30`<020<;2`P80bLW90P36a/H20;^k^`80];Bd0P2SXj<2
0::RXP80YJFU0P2YZJT20:n_[`80^k^k0P30`<020<[:bP80]KFe0P2h^;P208V9R@80I6AT0P1UIFD2
06a/K080KFe]0`1dM7@206m_K`80MGEe0P1aLG4207alO080LW9b0P1oOgl207emO@80P8200P1iNGT2
07YjNP80Cdm?0P0d=3@205]KF`80Q8B40P2CTi<208j>SP80R8R80P1lO7`205QHF080Ng]k0P27QhL2
05MGE`80GemO0P1/K6`207=cL`80NWYj0P1`L70206EUI@80JFUY0P1/K6`205mOG`<0HV9R0P1TI6@4
06MWI`80K6a/0P1iNGT208R8R080Ti>C0P2OWil209^KV`80WinO0P2PX:020::RXP@0YJFU0P2QXJ4O
0<SPf0007@38h=P202TY:@80:RXZ0P0[:b/402d];@80EUIF0P0l?3`203Xj>P80;2`/0P0Y:BT202PX
:0809BDU0P0/;2`20410@080EUIF0P1SHf<306][J`80@D510P0f=SH202PX:0809bLW0P0U9BD202HV
9P80:2PX0P0Z:RX202`/;080;Bd]0P0Z:RX202`/;08092@T0P0o?cl203hn?P80@d=30P1]KFd207Ad
M080Bd];0P0d=3@203<c<`80?Shn100Q8B4201/K6`809BDU0P1ADE4208:2PP80TY:B0P2@T9020820
P0<0M7Ad0P27QhL20:FUY@80/k>c0P2j^[X20;2`/080Y:BT0P2XZ:P20;2`/080];Bd0P2i^KT20;fm
_@80`L710P36a/H20<O7a`80_kno0P2d];@20:JVYP80W9bL0P2MWId20::RXP80Zj^[0P2e]KD20;no
_`80a/K61035aLD20:j^[P80TY:B0P1lO7`206a/K080Kfm_0`1gMgL207YjNP80OGem0P1nOWh207mo
O`80Q8B40P29RHT208Z:RP80RHV90P27QhL208:2PP80J6QX0P1FEUH207EeM@80VYZJ0P2QXJ4209jN
WP80U9BD0P29RHT207EeM@80Ph>30P2:RXX207=cL`80GUiN101/K6`206YZJP80IVIV0P1NGUh205YJ
FP80G5aL0P1FEUH3059BDP80De=C0P1GEeL2061PH080KFe]0P1mOGd208j>SP80Vi^K102UYJD20::R
XP80Xj>S0P2UYJD40:NWY`80Z:RX:@38h=P202PX:0809BDU0P0/;2`202TY:@80=3@d0P1<C4`20410
@080=cLg0P0[:b/202LW9`809RHV0P0`<30202PX:080>3Ph0P1GEeL506IVIP80C4a<0P0e=CD202XZ
:P808b<S0P0R8R8202`/;080;Bd]0P0/;2`202XZ:P80<C4a0P0X:2P202LW9`80:RXZ0P0c<c<203De
=@80@d=30P1/K6`206i^KP80@D510P0[:b/2034a<@80;bl_0P0R8R8201hN7P80820P0P0Q8B4204Y:
BP80Ng]k0P2NWYh208j>SP80Ng]k0`1bLW820861P@80Xj>S0P2o_kl20;Vi^@@0Z:RX0P2YZJT20:^[
Z`80/[:b0P2h^;P20;fm_@80`L710P36a/H20<G5a@80_kno0P2e]KD20:VYZ@80VYZJ0P2QXJ4209bL
W080/K6a0P2e]KD20;jn_P80a<C41037alL20;fm_@80UIFE0P1/K6`206m_K`80LG5a0`1hN7P207in
OP80OGem0P1kNg/207alO080RXZ:0P27QhL208J6QP80Q8B40P2:RXX208>3P`80Lg=c0P1?Cdl207]k
N`80Vi^K0P2MWId209^KV`80WIfM0P29RHT2075aL@80Q8B40P29RHT207IfMP80Fe]K0P1/K6`206EU
I@80JVYZ0P1TI6@205iNGP80EeMG0P1MGEd205YJFP<0DE5A0P1JFUX205aLG080HV9R0P1_Kfl207Mg
M`80Shn?0P2NWYh20:FUY@80Y:BT102SXj<20:NWY`80ZZZZ0P2RXZ820:FUYBT0b>3H0P0_;bl202XZ
:P80;bl_0P0V9RH202l_;`80FEUI0P0i>CT203Xj>P80:b/[0P0U9BD202/[:`809bLW0P0];Bd20410
@080EEEE0P1SHf<306e]K@80@d=30P0f=SH202LW9`80:BTY100U9BD402`/;0809bLW0P0[:b/202l_
;`80:b/[0P0R8R8203`l?080?clo0P12@T8207AdM080MWIf0P1IFET203De=@80;Bd]0P14A4@2028R
8P807alO0P0H61P202PX:080E5AD0P21PH44092@T080PH610`1iNGT208^;R`80YJFU0P2a/K420;Zj
^P80/;2`0P2TY:@20:RXZ080ZJVY0P2g]kL20;Rh^080^[Zj0P30`<020<W9b@80a/K60P2l_;`20;>c
/`80W9bL0P2MWId209ZJVP80XZ:R0P2[Zj/20;Ng]`80^[Zj0P34a<@20<30`080`l?30P2ZZZX208b<
S080Ng]k0P1ZJVX206][J`<0Ng]k0P1eMGD207emO@80P8200P26QXH208:2PP80R8R80P2<S8`208Z:
RP80QXJ60P23Ph<206UYJ@80F5QH0P1gMgL209^KV`80X:2P0P2NWYh209JFUP80R8R80P1dM7@20861
P@80Rh^;0P1aLG4205]KF`80JFUY0P1]KFd206YZJP80HF5Q0P1MGEd405aLG080De=C0`1ADE42051@
D080EeMG0P1OGel206m_K`80NWYj0P2@T90209ZJVP80YjNW0P2XZ:P20:FUY@80ZJVY0P2VYZH20:NW
Y`@0Z:RX7`38h=P001d0b>3H0P0Y:BT202XZ:P80:b/[100];Bd205IFEP80?3`l0P0j>SX202`/;080
:BTY0P0X:2P202DU9@80;2`/0P10@40205IFEP80Hf=S0`1[Jf/20451@@80=SHf0P0X:2P202LW9`80
9BDU0P0V9RH202PX:080:RXZ0P0/;2`202d];@80:RXZ0P0/;2`202@T9080?clo0P0n?Sh204=3@`80
KFe]0P1dM7@204];B`80=3@d0P0c<c<203hn?P@08B4Q0P0K6a/202DU9@80DE5A0P22PX8209:BTP80
T92@0P20P80307AdM080QhN70P2UYJD20;>c/`80^[Zj0P2`/;020:BTY080Z:RX0P2`/;020;Bd]080
^KVi0P2m_Kd20<71`@80a/K60P37alL20;no_`80];Bd0P2VYZH209bLW080WIfM0P2RXZ820:^[Z`80
]KFe0P2o_kl20<K6aP@0aLG50P2^[Zh209:BTP80O7al0P1/K6`206m_K`<0MgMg0P1jNWX207emO@80
OWin0P1oOgl208B4Q080RHV90P2:RXX208V9R@80QhN70P22PX8206QXJ080EUIF0P1eMGD209ZJVP80
XJ6Q0P2NWYh209BDU080RHV90P1eMGD208>3P`80RXZ:0P1cLg<205iNGP@0K6a/0P1ZJVX206IVIP80
GUiN0P1JFUX205aLG080EUIF0`1BDU8205=CD`80EeMG0P1PH60206e]K@80OGem0P2>SXh209^KV`@0
YJFU0P2RXZ820:>SX`80YJFU102WYjL20:RXZ2T0b>3H0P0X:2P202DU9@80;2`/0P0Y:BT203@d=080
C4a<0P10@40203Lg=`80:b/[0P0W9bL202HV9P80<30`0P0X:2P203Ph>080EeMG1@1VIVH204a<C080
=CDe0P0Z:RX202<S8`808R8R0P0/;2`202d];@80;2`/0P0Z:RX2034a<@80:2PX0P0W9bL202XZ:P80
<c<c0P0e=CD204=3@`80K6a/0P1^KVh20451@@80:b/[0P0a<C4202l_;`808R8R0P0N7Qh2020P8080
8B4Q0P1:BTX207]kN`80WYjN0P2>SXh207]kN`<0LW9b0P21PH420:>SX`80_kno0P2i^KT40:RXZ080
ZJVY0P2[Zj/20;:b/P80^;Rh0P2m_Kd20<71`@80a/K60P35aLD20;no_`80]KFe0P2YZJT209ZJVP80
XJ6Q0P2LW9`20;6a/@80]KFe0P2n_[h20<C4a0@0alO70P2m_Kd209FEU@80K6a/0P1_Kfl2075aL@<0
N7Qh0P1nOWh207emO@80Ng]k0P1lO7`208Z:RP80QhN70P26QXH208B4Q080RXZ:0P23Ph<207=cL`80
Cdm?0P1kNg/209^KV`80WIfM0P2KVi/209fMW@80RHV90P1aLG4208B4Q080RHV90P1fMWH205]KF`80
K6a/0P1UIFD206YZJP80I6AT0P1NGUh205MGE`80GEeM0P1JFUX3055AD@80FUYJ0P1LG5`2069RHP80
Kfm_0P1gMgL208n?S`80WYjN0P2UYJD20:BTY0@0Xj>S0P2WYjL20:ZZZP80XZ:R0P2UYJDY0<SPf080
;bl_0P0Z:RX202l_;`809RHV0P0_;bl205UIF@80>CTi0P0j>SX202/[:`809BDU0P0[:b/202LW9`80
;Bd]0P10@40205EEE@80Hf=S0`1]KFd204=3@`80=SHf0P0W9bL202TY:@@09BDU100/;2`202LW9`80
:b/[0P0_;bl202/[:`808R8R0P0l?3`203lo?`80@T920P1dM7@207IfMP80FEUI0P0e=CD202d];@80
A4A40P0R8R8201lO7`8061PH0P0X:2P205ADE080PH61102@T9020861P@<0NGUi0P2;Rh/20:FUY@80
/K6a0P2j^[X20;2`/080Y:BT0P2XZ:P20:VYZ@80]kNg0P2h^;P20;Zj^P80`<300P39bLT20<K6aP80
_;bl0P2c/k<209bLW080WIfM0P2JVYX20::RXP80Zj^[0P2g]kL20;Zj^P80a<C40P30`<020<?3``80
ZZZZ0P2<S8`207]kN`80JVYZ0P1[Jf/307]kN`80MGEe0P1mOGd20820P080QXJ60P22PX8208R8R080
S8b<0P2:RXX208J6QP80Ph>30P1YJFT205QHF080MgMg0P2KVi/20:2PX080WYjN0P2FUYH208R8R080
M7Ad0P21PH4208^;R`80LG5a0P1KFe/206UYJ@80KFe]0P1ZJVX2065QH@80GEeM101LG5`205=CD`<0
DE5A0P1@D50205MGE`80GemO0P1_Kfl207YjNP80T92@0P2JVYX20:NWY`80Z:RX0P2UYJD20:VYZ@80
YZJV0P2WYjL40:RXZ1l0b>3H000M0<SPf0808b<S0P0X:2P202d];@80;2`/0P0X:2P204U9B@80<S8b
100h>3P202l_;`809RHV0P0U9BD202d];@80@T920P1HF5P205iNGP<0HV9R0P0b<S8203lo?`80;Bd]
100U9BD402PX:080:BTY100X:2P202TY:@80<S8b0P0W9bL405]KF`80FEUI0P1dM7@2059BDP807alO
0P0];Bd20492@P80GUiN0P0U9BD202<S8`805QHF0P0K6a/203Lg=`80G5aL0P29RHT20:VYZ@80UiNG
0`1lO7`207QhN080Ogmo0P2UYJD20<O7a`80^;Rh0P2RXZ820:JVYP80[Zj^0P2a/K420;>c/`80^KVi
0P2n_[h20<C4a080b<S80P34a<@20;^k^`80ZJVY0P2IVIT209NGU`80W9bL0P2UYJD20;2`/080^;Rh
0P2o_kl20<G5a@80alO70P3:b/X20<?3``80VYZJ0P1dM7@207IfMP<0PH611023Ph<208:2PP80Ph>3
0P2;Rh/409:BTP80T92@0P2=SHd208R8R080OGem0P1hN7P208f=S@80YJFU0P2VYZH20:6QX@80V9RH
0P2>SXh208V9R@@0Ph>30P27QhL205UIF@80JVYZ0P1PH60205]KF`80EUIF0P1CDe<204m?C`80Bd];
0P19BDT304Q8B080BDU90P1?Cdl2061PH080MGEe0P26QXH209JFUP80Xj>S0P2[Zj/20:ZZZP80YZJV
0P2WYjL40:VYZ@@0ZZZZ:@38h=P202@T9080:BTY0P0a<C4202HV9P80=3@d0P17AdL203/k>`80?Shn
0P0g=cL202h^;P80:RXZ0P0/;2`203<c<`80>CTi0P1KFe/205eMG@<0HF5Q0P0l?3`203Ph>080<30`
1P0T92@202TY:@80:2PX0P0Y:BT202LW9`80:RXZ0P0`<302034a<@80FEUI0P1CDe<2061PH080QHF5
0P1BDU8202DU9@80:b/[0P19BDT205aLG0809bLW0P0P820201dM7@807alO0P0b<S82069RHP80SXj>
0P2WYjL209JFUP<0PX:20P1aLG4208:2PP80Z:RX0P33`l<20;Ng]`80XJ6Q0P2XZ:P20:b/[080/K6a
0P2c/k<20;Rh^080^k^k0P37alL20<K6aP80a<C40P2k^k/20:NWY`80UYJF0P2JVYX209VIV@80Z:RX
0P2[Zj/20;Zj^P80_kno0P31`L420<G5a@80alO70P30`<0209jNWP80Kfm_0P1^KVh307]kN`@0PX:2
0P23Ph<208F5Q@80RHV90P2BTY8209>CT`80SXj>0P2BTY8208Z:RP80MGEe0P1jNWX2092@T080YJFU
0P2SXj<20:2PX080Vi^K0P2?Shl207moO`80PH610P2:RXX207inOP80Fe]K0P1XJ6P205YJFP80GUiN
0P1EEED205ADE080Cdm?0P1;Bd/204i>CP<0B4Q8101>CTh2061PH080MWIf0P27QhL209JFUP80YZJV
0P2ZZZX20:VYZ@80YZJV0P2XZ:P20:NWY`80Zj^[0P2ZZZX20:f][BT0b>3H0P0O7al202HV9P80;Rh^
0P0X:2P202XZ:P80Bd];0P0_;bl203/k>`80=CDe0P0a<C4202<S8`80:2PX0P0_;bl20451@@80EeMG
1@1SHf<202d];@80@d=3100W9bL202<S8`809RHV0P0Z:RX202/[:`809BDU0P0/;2`202LW9`80<C4a
0P0V9RH205]KF`80GemO0P1EEED2079bLP80CDe=0P0S8b<202d];@80?Shn0P1OGel202PX:0809BDU
0P0C4a<201dM7@80=CDe0P1NGUh208R8R080Z:RX0P2GUiL307QhN080NGUi0P1nOWh20:FUY@80alO7
0P2k^k/20:2PX080YjNW0P2^[Zh20;:b/P80]KFe0P2g]kL20;fm_@80cLg=0P31`L420<O7a`80_;bl
0P2YZJT209ZJVP80U9BD0P2LW9`20:>SX`80/[:b0P2e]KD20<71`@80b<S80P36a/H20<[:bP80a/K6
0P2MWId207IfMP80Lg=c0`21PH4208B4Q080PX:20P24Q8@208:2PP80QXJ60P2EUID209:BTP80S8b<
0P2@T90208B4Q080Ogmo0P1eMGD208n?S`80XJ6Q0P2ZZZX20:>SX`80UYJF0P2?Shl208Z:RP80PH61
0P23Ph<208V9R@80FEUI0P1]KFd2061PH080FUYJ0P1EEED2059BDP80E5AD0P1:BTX204Q8B0<0BDU9
0P16ATH204m?C`80Hf=S0P1dM7@208R8R080UiNG0P2SXj<20:ZZZP80YJFU0P2SXj<20:^[Z`80YZJV
0P2XZ:P20:^[Z`80[Zj^7`38h=P001d0b>3H0P0S8b<202PX:080;Bd]0P0/;2`202PX:080BDU90P0b
<S8403Ph>080;bl_0P0V9RH202DU9@80;Bd]0P12@T8205QHF080GUiN0`1RHV82038b<P80?clo0P0]
;Bd402DU9@@0:2PX0P0Y:BT402PX:080:BTY0P0b<S8202LW9`@0Fe]K0P1IFET207AdM080DU9B0P0O
7al202d];@80@T920P1NGUh202DU9@808b<S0P0F5QH201/K6`80=cLg0P1LG5`208V9R@80ZJVY0P2G
UiL307alO080N7Qh0P1oOgl20:FUY@80alO70P2h^;P20::RXP80YZJV0P2^[Zh20;6a/@80/k>c0P2i
^KT20;jn_P80a<C40P38b<P20<C4a080^k^k0P2YZJT209VIV@80UiNG0P2LW9`20:FUY@80/;2`0P2h
^;P20;no_`80aLG50P37alL20<[:bP80`l?30P2JVYX207AdM080MWIf0`21PH4408>3P`80PX:20P23
Ph<208^;R`@0TY:B0P2@T90208f=S@80R8R80P1mOGd207QhN080SHf=0P2UYJD20:JVYP80XJ6Q0P2H
V9P208j>SP80RHV91023Ph<208N7Q`80FEUI0P1ZJVX2061PH080Fe]K0P1FEUH205=CD`80Cdm?0P1;
Bd/204U9B@<0B4Q80P19BDT204m?C`80H61P0P1eMGD208J6QP80UYJF0P2SXj<20:^[Z`80ZZZZ0P2V
YZH20:NWY`@0ZJVY102ZZZXY0<SPf08092@T0P0Y:BT2034a<@809RHV0P0d=3@204M7A`80>c/k0P0n
?Sh203Lg=`80;Rh^0P0Z:RX202`/;080<c<c0P0i>CT205]KF`80GEeM0`1QHF4203`l?080>3Ph0P0`
<30602@T9080:BTY0P0X:2P202TY:@809bLW0P0Z:RX2030`<080<C4a0P1IFET205=CD`80H61P0P25
QHD2059BDP809BDU0P0[:b/204U9B@80G5aL0P0W9bL2020P80807AdM0P0O7al2038b<P80HV9R0P2>
SXh20:NWY`80UYJF0`22PX82075aL@80PX:20P2XZ:P20<?3``80]kNg0P2QXJ420:RXZ080[:b/0P2a
/K420;>c/`80^;Rh0P2k^k/20<O7a`80a/K60P34a<@20;^k^`80YjNW0P2FUYH209ZJVP80VIVI0P2X
Z:P20:^[Z`80^[Zj0P2o_kl20<71`@80aLG50P37alL20<30`080WYjN0P1_Kfl206i^KP<0Ng]k1022
PX8208>3P`80QHF50P29RHT209:BTP80Ti>C0P2>SXh209:BTP80RXZ:0P1eMGD207YjNP80T92@0P2U
YJD20:>SX`80X:2P0P2KVi/208n?S`80Ogmo0P21PH4208Z:RP80OWin0P1KFe/206QXJ080FUYJ0P1N
GUh205EEE@80E5AD0P1?Cdl204];B`80CTi>0`18B4P404i>CP80H61P0P1fMWH208N7Q`80UYJF0P2V
YZH20:ZZZP80ZJVY0P2VYZH20:RXZ080YjNW0P2[Zj/20:ZZZP80[Jf]:@38h=P201lO7`809RHV0P0^
;Rh202PX:080:RXZ0P1;Bd/202l_;`80>c/k0P0e=CD2034a<@808b<S0P0X:2P202l_;`80@D510P1G
EeL506=SH`80;Bd]0P13@d<402LW9`808b<S0P0V9RH202XZ:P80:b/[0P0U9BD202`/;0809bLW0P0a
<C4202HV9P80Fe]K0P1OGel205EEE@80LW9b0P1=CDd202<S8`80;Bd]0P0n?Sh205mOG`80:2PX0P0U
9BD201<C4`807AdM0P0e=CD205iNGP80R8R80P2XZ:P209NGU`<0N7Qh0P1iNGT207inOP80YJFU0P37
alL20;^k^`80X:2P0P2WYjL20:j^[P80/[:b0P2e]KD20;Ng]`80_Kfm0P3=cLd20<71`@80alO70P2l
_;`20:VYZ@80VYZJ0P2DU9@209bLW080Xj>S0P2b/[820;Fe]@80`L710P38b<P20<K6aP80b/[:0P36
a/H209fMW@80MWIf0P1cLg<30861P@80Q8B40P22PX8208B4Q080PX:20P26QXH209FEU@80TY:B0P2<
S8`2092@T080Q8B40P1oOgl207EeM@80Shn?0P2QXJ420:ZZZP80Xj>S0P2FUYH208n?S`80RXZ:0P21
PH4208>3P`80RHV90P1IFET206e]K@80H61P0P1JFUX205EEE@80DU9B0P1DE5@204Y:BP80B4Q80`19
BDT204I6AP80Cdm?0P1SHf<207AdM080R8R80P2GUiL20:>SX`80ZZZZ0P2UYJD20:>SX`80Zj^[0P2V
YZH20:RXZ080Zj^[0P2^[ZhO0<SPf0007@38h=P402@T9080:2PX0P0h>3P204I6AP80L71`0P1EEED2
04M7A`80=SHf0P10@40204];B`80FUYJ0P16ATH204a<C080CTi>0P1LG5`304I6AP80;bl_0P0e=CD2
03`l?08092@T0P0U9BD402LW9`80:2PX0P0V9RH202DU9@80:BTY0P0b<S8202LW9`80ADE50P1PH602
06a/K080QXJ60P1FEUH202@T9080;Bd]0P1>CTh205MGE`809bLW0P0^;Rh2020P80807AdM0P0W9bL2
03lo?`80Lg=c0P2QXJ4209bLW0<0RHV90P1aLG4206YZJP80Shn?0P2h^;P20;Vi^@80/K6a0P2ZZZX2
0:BTY080ZZZZ0P2c/k<20;Ng]`80^k^k0P31`L440<G5a@80`<300P2_[jl209jNWP@0UiNG0P2OWil2
0:ZZZP80/[:b0P2i^KT20<30`080`l?31039bLT20;Ng]`80WYjN0P1oOgl306QXJ080KVi^0P1mOGd2
08B4Q080Rh^;0P2ATI4209FEU@@0V9RH0P2DU9@208n?S`80SHf=0P2?Shl209ZJVP80YJFU0P2TY:@2
09nOW`80UYJF0P2<S8`208F5Q@80Ng]k0P1eMGD207AdM080EUIF0P1JFUX2059BDP80CDe=0P18B4P2
04A4A0@0@T920P15ADD304Y:BP80EEEE0P1TI6@207MgM`80RXZ:0P2HV9P20::RXP80Z:RX102[Zj/6
0:VYZ@80ZZZZ0P2/[:`20:f][BT0b>3H0P0V9RH202@T9080;bl_0P0c<c<204E5A@80HF5Q0P1<C4`2
04I6AP80?3`l0P0g=cL203dm?@80Hf=S0P16ATH203lo?`80Fe]K0P1LG5`304=3@`809bLW0P0e=CD2
03/k>`@0:BTY0P0X:2P202/[:`809bLW0P0U9BD202TY:@808b<S0P0];Bd203<c<`80Cdm?0P1OGel2
06IVIP80MWIf0P1DE5@202HV9P80;Bd]0P1KFe/205UIF@80;Rh^0P0Z:RX201lO7`807AdM0P0T92@2
03Ti>@80MGEe0P2JVYX20:NWY`<0R8R80P1^KVh206QXJ080Shn?0P2g]kL20<?3``80[:b/0P2WYjL2
0:ZZZP80[Jf]102d];@20;jn_P80`/;20P36a/H20<O7a`80_kno0P2/[:`20:>SX`@0UYJF0P2QXJ42
0:VYZ@80/k>c0P2l_;`20;jn_P80a<C40P35aLD20<O7a`80`L710P2[Zj/207alO0<0M7Ad0P1hN7P2
07YjNP80QXJ60P29RHT208j>SP80UiNG0P2IVIT209ZJVP80UIFE0P2>SXh207]kN`80UYJF0P2MWId2
09nOW`80Xj>S0P2PX:0209ZJVP80Rh^;0P25QHD407inOP80Lg=c101QHF4205IFEP80De=C1018B4P2
04A4A0@0?clo0`11@D4204m?C`80Fe]K0P1iNGT208R8R080UIFE0P2QXJ420:NWY`80Zj^[0P2WYjL2
0:^[Z`80Y:BT0P2WYjL40:^[Z`80[Jf]:@38h=P202HV9P809bLW0P0[:b/203Ph>080A4A40P1dM7@2
05EEE@80BDU90P0i>CT20492@P80Bd];0P1EEED20451@@80C4a<0P1=CDd205eMG@<0?clo0P0a<C42
03@d=080?Shn0P0T92@202/[:`80:BTY0P0W9bL202PX:0808R8R0P0Y:BT202PX:080=3@d0P0Z:RX2
0451@@80HF5Q0P1_Kfl208B4Q080E5AD0P0Q8B4202XZ:P80D51@0P1?Cdl402/[:`808b<S0P0K6a/2
02LW9`80?Shn0P1gMgL20:BTY080Vi^K0`29RHT2071`L080Jf][0P2=SHd20;Ng]`80^KVi0P2_[jl2
0:b/[080Z:RX0P2UYJD20;>c/`80][Jf0P2h^;P20<30`080bLW90P36a/H20;no_`80/[:b0P2SXj<2
09VIV@80WYjN0P2PX:020:ZZZP80]KFe0P2j^[X20<30`080a<C40P3<c<`20<_;b`80/k>c0P2QXJ42
07inOP<0JVYZ0P1aLG4207emO@80Q8B40P2<S8`208R8R080VIVI0P2JVYX209VIV@80UIFE102>SXh2
08b<S080VIVI0P2UYJD20:BTY080VYZJ0P2DU9@208V9R@80RXZ:0P1nOWh207AdM080Lg=c0P1EEED2
05QHF080EEEE0P1ADE4204Q8B080ADE50P14A4@20451@@80A4A40`1>CTh205QHF080IFEU0P1gMgL2
08^;R`80TY:B0P2RXZ820:NWY`80[Zj^0P2[Zj/20:RXZ080ZJVY0P2VYZH20:ZZZP80Z:RX0P2/[:`O
0<SPf0007@38h=P402@T9080:2PX0P0h>3P204I6AP80L71`0P1EEED204M7A`80=SHf0P10@40204];
B`80FUYJ0P16ATH204a<C080CTi>0P1LG5`304I6AP80;bl_0P0e=CD203`l?08092@T0P0U9BD402LW
9`80:2PX0P0V9RH202DU9@80:BTY0P0b<S8202LW9`80ADE50P1PH60206a/K080QXJ60P1FEUH202@T
9080;Bd]0P1>CTh205MGE`809bLW0P0^;Rh2020P80807AdM0P0W9bL203lo?`80Lg=c0P2QXJ4209bL
W0<0RHV90P1aLG4206YZJP80Shn?0P2h^;P20;Vi^@80/K6a0P2ZZZX20:BTY080ZZZZ0P2c/k<20;Ng
]`80^k^k0P31`L440<G5a@80`<300P2_[jl209jNWP@0UiNG0P2OWil20:ZZZP80/[:b0P2i^KT20<30
`080`l?31039bLT20;Ng]`80WYjN0P1oOgl306QXJ080KVi^0P1mOGd208B4Q080Rh^;0P2ATI4209FE
U@@0V9RH0P2DU9@208n?S`80SHf=0P2?Shl209ZJVP80YJFU0P2TY:@209nOW`80UYJF0P2<S8`208F5
Q@80Ng]k0P1eMGD207AdM080EUIF0P1JFUX2059BDP80CDe=0P18B4P204A4A0@0@T920P15ADD304Y:
BP80EEEE0P1TI6@207MgM`80RXZ:0P2HV9P20::RXP80Z:RX102[Zj/60:VYZ@80ZZZZ0P2/[:`20:f]
[BT0b>3H0P0V9RH202@T9080;bl_0P0c<c<204E5A@80HF5Q0P1<C4`204I6AP80?3`l0P0g=cL203dm
?@80Hf=S0P16ATH203lo?`80Fe]K0P1LG5`304=3@`809bLW0P0e=CD203/k>`@0:BTY0P0X:2P202/[
:`809bLW0P0U9BD202TY:@808b<S0P0];Bd203<c<`80Cdm?0P1OGel206IVIP80MWIf0P1DE5@202HV
9P80;Bd]0P1KFe/205UIF@80;Rh^0P0Z:RX201lO7`807AdM0P0T92@203Ti>@80MGEe0P2JVYX20:NW
Y`<0R8R80P1^KVh206QXJ080Shn?0P2g]kL20<?3``80[:b/0P2WYjL20:ZZZP80[Jf]102d];@20;jn
_P80`/;20P36a/H20<O7a`80_kno0P2/[:`20:>SX`@0UYJF0P2QXJ420:VYZ@80/k>c0P2l_;`20;jn
_P80a<C40P35aLD20<O7a`80`L710P2[Zj/207alO0<0M7Ad0P1hN7P207YjNP80QXJ60P29RHT208j>
SP80UiNG0P2IVIT209ZJVP80UIFE0P2>SXh207]kN`80UYJF0P2MWId209nOW`80Xj>S0P2PX:0209ZJ
VP80Rh^;0P25QHD407inOP80Lg=c101QHF4205IFEP80De=C1018B4P204A4A0@0?clo0`11@D4204m?
C`80Fe]K0P1iNGT208R8R080UIFE0P2QXJ420:NWY`80Zj^[0P2WYjL20:^[Z`80Y:BT0P2WYjL40:^[
Z`80[Jf]:@38h=P202HV9P809bLW0P0[:b/203Ph>080A4A40P1dM7@205EEE@80BDU90P0i>CT20492
@P80Bd];0P1EEED20451@@80C4a<0P1=CDd205eMG@<0?clo0P0a<C4203@d=080?Shn0P0T92@202/[
:`80:BTY0P0W9bL202PX:0808R8R0P0Y:BT202PX:080=3@d0P0Z:RX20451@@80HF5Q0P1_Kfl208B4
Q080E5AD0P0Q8B4202XZ:P80D51@0P1?Cdl402/[:`808b<S0P0K6a/202LW9`80?Shn0P1gMgL20:BT
Y080Vi^K0`29RHT2071`L080Jf][0P2=SHd20;Ng]`80^KVi0P2_[jl20:b/[080Z:RX0P2UYJD20;>c
/`80][Jf0P2h^;P20<30`080bLW90P36a/H20;no_`80/[:b0P2SXj<209VIV@80WYjN0P2PX:020:ZZ
ZP80]KFe0P2j^[X20<30`080a<C40P3<c<`20<_;b`80/k>c0P2QXJ4207inOP<0JVYZ0P1aLG4207em
O@80Q8B40P2<S8`208R8R080VIVI0P2JVYX209VIV@80UIFE102>SXh208b<S080VIVI0P2UYJD20:BT
Y080VYZJ0P2DU9@208V9R@80RXZ:0P1nOWh207AdM080Lg=c0P1EEED205QHF080EEEE0P1ADE4204Q8
B080ADE50P14A4@20451@@80A4A40`1>CTh205QHF080IFEU0P1gMgL208^;R`80TY:B0P2RXZ820:NW
Y`80[Zj^0P2[Zj/20:RXZ080ZJVY0P2VYZH20:ZZZP80Z:RX0P2/[:`O0<SPf0007@38h=P402HV9P80
9bLW100X:2P2055AD@80?3`l0P0n?Sh403Xj>P80=3@d0P19BDT202<S8`80>CTi0P17AdL205aLG0<0
;2`/0P0_;bl202XZ:P80B4Q80P0U9BD202LW9`809RHV0P0W9bL202PX:0809BDU0P0T92@202PX:080
<S8b0P1ADE4206QXJ080HV9R0P0g=cL206IVIP80FUYJ0P0`<30203@d=080EeMG0P15ADD202PX:080
?Cdm0P0];Bd2028R8P807QhN0P0X:2P205UIF@80RXZ:0P2HV9P309FEU@80MGEe0P1MGEd207QhN080
WIfM0P2d];@20;no_`80[jn_0P2MWId20:JVYP80/[:b0P2f][H20;Rh^080_Kfm0P31`L420<G5a@80
a<C40P2f][H20:JVYP80VYZJ0P2DU9@209^KV`80YJFU0P2][Jd20;Bd]080^KVi0P2m_Kd20<71`@80
a<C40P37alL20<C4a080[Jf]0`2DU9@20820P080M7Ad0P1oOgl208n?S`80TY:B0P2CTi<209RHV080
W9bL0P2GUiL209>CT`80UiNG0P2MWId209jNWP80WIfM0P2KVi/209NGU`80SXj>0P24Q8@207UiN@80
KVi^0P1SHf<205UIF@80De=C0P1;Bd/204M7A`80A4A40P10@40203dm?@80?clo0P14A4@204a<C0<0
EeMG0P1[Jf/20820P080TY:B0P2QXJ420:VYZ@@0[Jf]0P2ZZZX20:^[Z`80[:b/0P2ZZZX20:VYZ@80
Zj^[0P2][Jd20:j^[RT0b>3H0P0U9BD202PX:0@09bLW0P0c<c<204e=C@80?clo0P12@T8203Xj>P80
:b/[0P0m?Cd205=CD`80:RXZ0P0c<c<204Y:BP80E5AD0`0d=3@202TY:@80=SHf0P0n?Sh202XZ:P80
:2PX0P0S8b<202`/;080:BTY0P0P820202PX:080:BTY0P0d=3@2051@D080IVIV0P1IFET203dm?@80
JFUY0P1QHF4202DU9@80<c<c0P1MGEd203Xj>P80;Bd]0P0n?Sh2028R8P80:2PX0P0W9bL202XZ:P80
D51@0P25QHD20::RXP<0T92@0P1bLW8206ATI080Lg=c0P2JVYX20;no_`80_Kfm0P2VYZH209jNWP80
ZZZZ0P2`/;020;:b/P80^;Rh0P2k^k/20<71`@80a/K60P34a<@20;>c/`80YZJV0P2KVi/209BDU080
W9bL0P2UYJD20:RXZ080/[:b0P2k^k/20;fm_@80`<300P35aLD20<?3``80_Kfm0P2a/K4308R8R080
MWIf0P1iNGT208>3P`80Rh^;102ATI4209RHV0@0VIVI0P2HV9P209:BTP80WIfM0P2RXZ8209^KV`80
UYJF0P2EUID208n?S`80PH610P1jNWX206e]K@80H61P0P1MGEd2059BDP80ATI60P1=CDd204=3@`80
@D510P0o?cl203Ti>@80ATI60P1?Cdl305UIF@80IfMW0P21PH4209JFUP80X:2P0P2YZJT20:n_[`80
Zj^[0P2ZZZX20:f][@80Zj^[0P2XZ:P20:^[Z`80ZZZZ0P2[Zj/20;2`/2T0b>3H0P0P820202TY:@80
8B4Q0P0/;2`202TY:@80CDe=0P0k>c/20410@080>CTi0P0j>SX203De=@80CDe=0P0R8R8203Hf=P80
ATI60P1NGUh302XZ:P80;Rh^0P0X:2P204Q8B0809RHV0P0Q8B4202HV9P809BDU0P0Z:RX202HV9P80
92@T0P0X:2P202h^;P80De=C0P1WIfL205iNGP80>CTi0P1TI6@205iNGP80;2`/0P0g=cL205aLG080
A4A40P0V9RH203hn?P80;Bd]0P0O7al2028R8P80:BTY0P1CDe<208b<S080Ti>C0`2HV9P2075aL@80
GUiN0P1jNWX209ZJVP80/k>c0P2m_Kd20:f][@80WYjN0P2TY:@20;>c/`80^KVi0P2h^;P20<30`080
_;bl0P37alL20<30`080^k^k0P2TY:@209JFUP80T92@0P2MWId20:>SX`80[:b/0P2b/[820;bl_080
^k^k0P30`<040<S8b080`L710P2][Jd309>CT`80P8200P1dM7@207emO@80TI6A0P2@T90209BDU080
V9RH0P2IVIT209^KV`80TY:B0P2GUiL209bLW0@0WIfM0P2LW9`209BDU080T92@0P25QHD207MgM`80
KFe]0P1WIfL205MGE`80EUIF0P1:BTX204I6AP80@d=30P0m?Cd203`l?080?clo0P14A4@204];B`<0
EUIF0P1YJFT207emO@80UIFE0P2RXZ820:RXZ080/;2`0P2^[Zh40:ZZZP80[Jf]0P2WYjL20:RXZ080
[jn_0P2[Zj/20:n_[al0b>3H000M0<SPf0@09RHV0P0W9bL402PX:080DE5A0P0l?3`203hn?P@0>SXj
0P0d=3@204U9B@808b<S0P0i>CT204M7A`80G5aL0`0/;2`202l_;`80:RXZ0P18B4P202DU9@809bLW
0P0V9RH202LW9`80:2PX0P0U9BD202@T9080:2PX0P0b<S82055AD@80J6QX0P1RHV8203Lg=`80IVIV
0P1JFUX2030`<080=3@d0P1GEeL204E5A@80:2PX0P0m?Cd202d];@808R8R0P0N7Qh202PX:080FEUI
0P2:RXX209RHV0<0UIFE0P1eMGD205eMG@80N7Qh0P2MWId20;Bd]080_kno0P2_[jl209fMW@80YZJV
0P2b/[820;Jf]P80^;Rh0P2m_Kd20<71`@80aLG50P34a<@20;Jf]P80YZJV0P2JVYX209BDU080Vi^K
0P2UYJD20:f][@80];Bd0P2i^KT20;fm_@80`L710P34a<@20<O7a`80a<C40P2][Jd309BDU080P820
0P1dM7@207moO`80Shn?0P2BTY8209>CT`80V9RH0P2LW9`209NGU`80Ti>C0P2GUiL209fMW@80WYjN
0P2MWId209^KV`80UiNG0P2>SXh208B4Q080NGUi0P1^KVh206=SH`80FEUI0P1CDe<204];B`80AdM7
0P14A4@20410@080?Cdm0P0o?cl204A4A080C4a<0`1GEeL206][J`80P8200P2BTY820:6QX@80ZJVY
102][Jd20:ZZZP80Zj^[0P2/[:`20:ZZZP80ZJVY0P2[Zj/20:f][@80[Zj^:@38h=P202DU9@80:2PX
100W9bL203<c<`80CDe=0P0o?cl20492@P80>SXj0P0[:b/203dm?@80De=C0P0Z:RX203<c<`80BTY:
0P1DE5@303@d=080:BTY0P0f=SH203hn?P80:RXZ0P0X:2P202<S8`80;2`/0P0Y:BT2020P8080:2PX
0P0Y:BT203@d=080D51@0P1VIVH205UIF@80?Cdm0P1YJFT2065QH@809BDU0P0c<c<205eMG@80>SXj
0P0];Bd203hn?P808R8R0P0X:2P202LW9`80:RXZ0P1@D50208F5Q@80XZ:R0`2@T902079bLP80I6AT
0P1cLg<209ZJVP80_kno0P2m_Kd20:JVYP80WYjN0P2ZZZX20;2`/080/[:b0P2h^;P20;^k^`80`L71
0P36a/H20<C4a080/k>c0P2VYZH209^KV`80U9BD0P2LW9`20:FUY@80Z:RX0P2b/[820;^k^`80_Kfm
0P30`<020<G5a@80`l?30P2m_Kd20;6a/@<0R8R80P1fMWH207UiN@80Ph>30P2;Rh/4096AT@80V9RH
102IVIT209RHV080TY:B0P2MWId20::RXP80Vi^K0P2FUYH209FEU@80Shn?0P21PH4207YjNP80KFe]
0P1PH60205eMG@80DU9B0P16ATH204e=C@80@d=30P11@D4203lo?`80>CTi0P16ATH204m?C`<0FEUI
0P1WIfL20861P@80UYJF0P2PX:020:VYZ@80[jn_0P2[Zj/20:ZZZP80[Jf]0P2[Zj/20:RXZ080Zj^[
0P2ZZZX20:^[Z`80/;2`:@38h=P2020P8080:BTY0P0Q8B4202`/;080:BTY0P1=CDd203/k>`80@410
0P0i>CT203Xj>P80=CDe0P1=CDd2028R8P80=SHf0P16ATH205iNGP<0:RXZ0P0^;Rh202PX:080B4Q8
0P0V9RH2024Q8@809RHV0P0U9BD202XZ:P809RHV0P0T92@202PX:080;Rh^0P1CDe<206MWI`80GUiN
0P0i>CT206ATI080GUiN0P0/;2`203Lg=`80G5aL0P14A4@202HV9P80?Shn0P0];Bd201lO7`808R8R
0P0Y:BT205=CD`80S8b<0P2CTi<309RHV080LG5a0P1NGUh207YjNP80VYZJ0P2c/k<20;fm_@80[Jf]
0P2NWYh20:BTY080/k>c0P2i^KT20;Rh^080`<300P2l_;`20<O7a`80`<300P2k^k/20:BTY080UYJF
0P2@T90209fMW@80Xj>S0P2/[:`20;:b/P80_;bl0P2k^k/20<30`0@0b<S80P31`L420:f][@<0Ti>C
0P20P80207AdM080OGem0P2ATI42092@T080U9BD0P2HV9P209VIV@80Vi^K0P2BTY8209NGU`80W9bL
102MWId209bLW080U9BD0P2@T90208F5Q@80MgMg0P1]KFd206MWI`80EeMG0P1FEUH204Y:BP80ATI6
0P13@d<203dm?@80?3`l0P0o?cl204A4A080Bd];0`1FEUH206UYJ@80OGem0P2EUID20::RXP80Z:RX
0P2`/;020:j^[P@0ZZZZ0P2][Jd20:NWY`80Z:RX0P2_[jl20:^[Z`80[jn_7`38h=P001d0b>3H0P0U
9BD202LW9`H0:BTY0P10@40203/k>`80A4A40P16ATH20451@@80>3Ph0P12@T8202l_;`80?Shn0P18
B4P204a<C0<0:b/[0P0^;Rh202`/;080?Shn0P0^;Rh202`/;080:2PX0P0Y:BT202/[:`@09bLW0P0h
>3P204I6AP80KVi^0P1WIfL202@T90809BDU0P1;Bd/205aLG080:b/[0P19BDT205]KF`80=3@d0P0U
9BD204];B`80=3@d0P0N7Qh201`L70809RHV0P12@T8206ATI080RHV90`2JVYX208n?S`80GUiN0P1V
IVH207UiN@80W9bL0P2k^k/20;>c/`80YJFU0P2XZ:P20:f][@80/K6a0P2e]KD20;Vi^@80_;bl0P33
`l<20<G5a@80_;bl0P2_[jl20:6QX@80UYJF0P2HV9P209nOW`80YZJV0P2_[jl20;Ng]`80_Kfm0P30
`<020<71`@80a/K60P37alL20;fm_@<0[Jf]0P2EUID20861P@80OGem0P1oOgl208J6QP80SXj>0P2D
U9@209^KV`80V9RH0P2CTi<209JFUP80UiNG0P2BTY8208^;R`80R8R80P24Q8@207alO080LW9b0P1W
IfL205aLG080Cdm?0P15ADD204M7A`80ADE50P14A4@204=3@`80B4Q80P1?Cdl205EEE@80GEeM0P1[
Jf/307alO080RXZ:0P2GUiL20:>SX`80[:b/202_[jl20;2`/080/K6a0P2^[Zh40:b/[080[Jf]0P2^
[ZhY0<SPf0808B4Q0P0X:2P202LW9`809RHV0P0Z:RX203`l?080C4a<0P12@T8204i>CP80C4a<0P0k
>c/203De=@80:BTY0P0k>c/204m?C`80B4Q80`0e=CD2030`<080:b/[0P0l?3`202d];@@09bLW0P0X
:2P202XZ:P809bLW0P0Z:RX202h^;P80BTY:0P1]KFd2061PH080<c<c0P0X:2P204i>CP80Hf=S0P0X
:2P204];B`80G5aL0P0[:b/203Hf=P80CTi>0P0X:2P2028R8P807AdM0P0_;bl203Xj>P80KVi^0P2=
SHd309jNWP80PH610P1UIFD2069RHP80NGUi0P2KVi/20;no_`80/K6a0P2QXJ420:^[Z`80[jn_0P2`
/;020;Ng]`80^KVi0P2j^[X20<?3``80alO70P2m_Kd20:n_[`80Vi^K0P2GUiL209ZJVP80W9bL0P2[
Zj/20:b/[080_;bl0P2m_Kd20;Zj^P80a/K61033`l<20<30`0<0^KVi0P2BTY8207]kN`80OGem0P24
Q8@208V9R@80Shn?0P2FUYH209bLW0@0UYJF102GUiL209BDU080TI6A0P2<S8`208B4Q080OGem0P1d
M7@206QXJ080G5aL0P1;Bd/204=3@`80>c/k0P16ATH403dm?@80A4A40P1<C4`205QHF080GUiN0P1a
LG4308B4Q080SHf=0P2KVi/20:NWY`80ZJVY0P2_[jl20;2`/080[Jf]0P2_[jl20;Fe]@80/K6a0P2^
[Zh20:b/[0@0[Zj^0P2a/K4Y0<SPf0809bLW0P0U9BD202PX:080;Rh^0P0U9BD20451@@80?3`l0P15
ADD204A4A080?Cdm0P0c<c<204Q8B080=3@d0P0n?Sh204Y:BP80CTi>0`0a<C44030`<080?3`l0P0`
<30202h^;P80:b/[0P0V9RH202TY:@80:2PX0P0T92@203De=@80@d=30P1eMGD206YZJP808b<S0P0W
9bL204M7A`80Hf=S0P0X:2P204Y:BP80EUIF0P0g=cL202LW9`80BDU90P0d=3@202<S8`806a/K0P0U
9BD204E5A@80IVIV0P26QXH309jNWP80SHf=0P1PH60206EUI@80Ogmo0P2PX:020<;2`P80/[:b0P2U
YJD40:b/[080/;2`0P2e]KD20;Ng]`80_kno0P30`<040<?3``80Z:RX0P2PX:0209RHV080UiNG0P2N
WYh20:VYZ@80[jn_0P2e]KD20;no_`80_Kfm0P2l_;`20<C4a080d=3@0P2h^;P30:f][@80UYJF0P22
PX8207alO080PX:20P26QXH208f=S@80U9BD0P2KVi/209JFUP80TI6A0P2IVIT209^KV`80UYJF0P29
RHT208N7Q`80RHV90P22PX8206m_K`80Hf=S0P1GEeL2055AD@80A4A40P17AdL204A4A080ATI60P10
@40204e=C@80CTi>0P1EEED205eMG@80KFe]0`1jNWX208b<S080UiNG0P2TY:@20:^[Z`80[:b/0P2`
/;040:b/[080/k>c0P2`/;020;6a/@80ZZZZ0P2`/;020:f][@80/K6a7`38h=P001d0b>3H0P0U9BD2
02LW9`H0:BTY0P10@40203/k>`80A4A40P16ATH20451@@80>3Ph0P12@T8202l_;`80?Shn0P18B4P2
04a<C0<0:b/[0P0^;Rh202`/;080?Shn0P0^;Rh202`/;080:2PX0P0Y:BT202/[:`@09bLW0P0h>3P2
04I6AP80KVi^0P1WIfL202@T90809BDU0P1;Bd/205aLG080:b/[0P19BDT205]KF`80=3@d0P0U9BD2
04];B`80=3@d0P0N7Qh201`L70809RHV0P12@T8206ATI080RHV90`2JVYX208n?S`80GUiN0P1VIVH2
07UiN@80W9bL0P2k^k/20;>c/`80YJFU0P2XZ:P20:f][@80/K6a0P2e]KD20;Vi^@80_;bl0P33`l<2
0<G5a@80_;bl0P2_[jl20:6QX@80UYJF0P2HV9P209nOW`80YZJV0P2_[jl20;Ng]`80_Kfm0P30`<02
0<71`@80a/K60P37alL20;fm_@<0[Jf]0P2EUID20861P@80OGem0P1oOgl208J6QP80SXj>0P2DU9@2
09^KV`80V9RH0P2CTi<209JFUP80UiNG0P2BTY8208^;R`80R8R80P24Q8@207alO080LW9b0P1WIfL2
05aLG080Cdm?0P15ADD204M7A`80ADE50P14A4@204=3@`80B4Q80P1?Cdl205EEE@80GEeM0P1[Jf/3
07alO080RXZ:0P2GUiL20:>SX`80[:b/202_[jl20;2`/080/K6a0P2^[Zh40:b/[080[Jf]0P2^[ZhY
0<SPf0808B4Q0P0X:2P202LW9`809RHV0P0Z:RX203`l?080C4a<0P12@T8204i>CP80C4a<0P0k>c/2
03De=@80:BTY0P0k>c/204m?C`80B4Q80`0e=CD2030`<080:b/[0P0l?3`202d];@@09bLW0P0X:2P2
02XZ:P809bLW0P0Z:RX202h^;P80BTY:0P1]KFd2061PH080<c<c0P0X:2P204i>CP80Hf=S0P0X:2P2
04];B`80G5aL0P0[:b/203Hf=P80CTi>0P0X:2P2028R8P807AdM0P0_;bl203Xj>P80KVi^0P2=SHd3
09jNWP80PH610P1UIFD2069RHP80NGUi0P2KVi/20;no_`80/K6a0P2QXJ420:^[Z`80[jn_0P2`/;02
0;Ng]`80^KVi0P2j^[X20<?3``80alO70P2m_Kd20:n_[`80Vi^K0P2GUiL209ZJVP80W9bL0P2[Zj/2
0:b/[080_;bl0P2m_Kd20;Zj^P80a/K61033`l<20<30`0<0^KVi0P2BTY8207]kN`80OGem0P24Q8@2
08V9R@80Shn?0P2FUYH209bLW0@0UYJF102GUiL209BDU080TI6A0P2<S8`208B4Q080OGem0P1dM7@2
06QXJ080G5aL0P1;Bd/204=3@`80>c/k0P16ATH403dm?@80A4A40P1<C4`205QHF080GUiN0P1aLG43
08B4Q080SHf=0P2KVi/20:NWY`80ZJVY0P2_[jl20;2`/080[Jf]0P2_[jl20;Fe]@80/K6a0P2^[Zh2
0:b/[0@0[Zj^0P2a/K4Y0<SPf0809bLW0P0U9BD202PX:080;Rh^0P0U9BD20451@@80?3`l0P15ADD2
04A4A080?Cdm0P0c<c<204Q8B080=3@d0P0n?Sh204Y:BP80CTi>0`0a<C44030`<080?3`l0P0`<302
02h^;P80:b/[0P0V9RH202TY:@80:2PX0P0T92@203De=@80@d=30P1eMGD206YZJP808b<S0P0W9bL2
04M7A`80Hf=S0P0X:2P204Y:BP80EUIF0P0g=cL202LW9`80BDU90P0d=3@202<S8`806a/K0P0U9BD2
04E5A@80IVIV0P26QXH309jNWP80SHf=0P1PH60206EUI@80Ogmo0P2PX:020<;2`P80/[:b0P2UYJD4
0:b/[080/;2`0P2e]KD20;Ng]`80_kno0P30`<040<?3``80Z:RX0P2PX:0209RHV080UiNG0P2NWYh2
0:VYZ@80[jn_0P2e]KD20;no_`80_Kfm0P2l_;`20<C4a080d=3@0P2h^;P30:f][@80UYJF0P22PX82
07alO080PX:20P26QXH208f=S@80U9BD0P2KVi/209JFUP80TI6A0P2IVIT209^KV`80UYJF0P29RHT2
08N7Q`80RHV90P22PX8206m_K`80Hf=S0P1GEeL2055AD@80A4A40P17AdL204A4A080ATI60P10@402
04e=C@80CTi>0P1EEED205eMG@80KFe]0`1jNWX208b<S080UiNG0P2TY:@20:^[Z`80[:b/0P2`/;04
0:b/[080/k>c0P2`/;020;6a/@80ZZZZ0P2`/;020:f][@80/K6a7`38h=P001d0b>3H0P0T92@202TY
:@80;Rh^0P0Z:RX202PX:080;2`/0P0f=SH204E5A@80Cdm?0P14A4@203Lg=`80=3@d0P0h>3P20492
@P80BDU90P0k>c/302l_;`80;Bd]0P0_;bl2038b<P80=SHf0P0`<30202/[:`80;2`/0P0_;bl202XZ
:P80:BTY0P16ATH205YJFP80Lg=c0P13@d<204Y:BP80=CDe0P16ATH205aLG0809RHV0P1MGEd205UI
F@809RHV0P0S8b<205IFEP80>CTi0P0L71`201hN7P80:BTY0P0_;bl203dm?@80LG5a0`2GUiL20:JV
YP80JFUY0P1MGEd205YJFP80PX:20P2[Zj/20;>c/`80/;2`0P2][Jd20:VYZ@80[Jf]0P2b/[820;Bd
]080]kNg0P2o_kl20<G5a@80`<300P2f][H20:NWY`80VYZJ0P2GUiL209ZJVP80XJ6Q0P2ZZZX20;Bd
]080_Kfm102n_[h20;no_`80`L711@37alL20:f][@80TI6A0P21PH4207QhN080Ng]k0P23Ph<208Z:
RP80TY:B0P2ATI4208j>SP80S8b<0P29RHT20861P@80N7Qh0P1dM7@2071`L080JVYZ0P1SHf<205QH
F080CTi>0P13@d<203`l?080@D511019BDT204a<C080FUYJ0P1YJFT2079bLP80O7al0P2?Shl30:2P
X080YjNW0P2[Zj/20;2`/080/k>c0P2a/K420:n_[`80/;2`0P2c/k<20;Bd]080]KFe0P2b/[820;2`
/080[Zj^102][JdY0<SPf08092@T0P0[:b/203@d=0808b<S0P0Z:RX203@d=080=CDe0P0l?3`205IF
EP80@T920P0b<S8203/k>`80=3@d0P17AdL204I6AP80>CTi0`0_;bl202XZ:P80;2`/0P0j>SX203Lg
=`80;bl_0P0b<S8202/[:`@0<30`0P0/;2`20492@P80H61P0P1XJ6P204i>CP80ATI60P0b<S8203`l
?080H61P0P0^;Rh205]KF`80De=C0P0U9BD202d];@80EEEE0P0a<C4201lO7`809bLW0P0U9BD202<S
8`80?Shn0P1eMGD309NGU`80WinO0P1^KVh205]KF`80H61P0P1kNg/20:ZZZP80^KVi0P2^[Zh20:JV
YP80[Jf]0P2/[:`20;Bd]080/[:b0P2h^;P20<30`080`/;20P34a<@20;Fe]@80YJFU0P2JVYX209bL
W080V9RH0P2OWil20:RXZ080][Jf0P2l_;`20;^k^`80_Kfm0P32`/820<?3``80`/;20`31`L420;Zj
^P80VIVI0P1iNGT207IfMP80NWYj0P22PX8208V9R@80T92@0P2<S8`208j>SP80SHf=0P29RHT207mo
O`80NGUi0P1eMGD206i^KP80Jf][0P1TI6@205]KF`80D51@100o?cl204A4A080AdM70P19BDT204];
B`80FEUI0P1ZJVX206m_K`80NWYj0P2=SHd309jNWP80YJFU0P2XZ:P20;2`/080/k>c0P2`/;020:n_
[`80/K6a0P2c/k<20;Bd]080/k>c0P2d];@20;2`/0H0[:b/:@38h=P202<S8`80:BTY0P0_;bl202h^
;P80:b/[0P0Z:RX203Lg=`80BDU90P1?Cdl204A4A080>CTi0P0f=SH403Ph>080CDe=0P0i>CT302h^
;P80:2PX0P0^;Rh203<c<`80>3Ph0P0/;2`202/[:`809BDU0P0`<30202`/;080:BTY0P14A4@205YJ
FP80MGEe0P14A4@204Q8B080=CDe0P18B4P205]KF`809RHV0P1PH60205QHF0809bLW0P0O7al205UI
F@80?3`l0P0K6a/201PH6080:RXZ0P0d=3@203Ph>080Lg=c0`2GUiL20::RXP80KVi^0P1IFET205eM
G@80Ogmo0P2[Zj/20;6a/@80[Zj^0P2_[jl20:VYZ@80[Zj^0P2b/[820;Jf]P80]KFe1033`l<20;jn
_P80^;Rh0P2WYjL209JFUP80UiNG0P2JVYX20::RXP80ZZZZ0P2e]KD20;no_`80_Kfm0P33`l<20;Vi
^@80`l?30P35aLD30<_;b`80[:b/0P2?Shl208>3P`80M7Ad0P21PH4208>3P`80R8R80P2ATI4209JF
UP80Shn?1028R8P208>3P`80NWYj0P1aLG4206i^KP80K6a/0P1VIVH205IFEP80CDe=0P17AdL203Xj
>P80@4100P18B4P204a<C080Bd];0P1HF5P206MWI`80M7Ad0P1mOGd2096AT@<0X:2P0P2UYJD20:b/
[080[jn_0P2e]KD20:n_[`80/K6a0P2b/[840;>c/`80]KFe0P2a/K420;2`/080[Jf]0P2[Zj/20:f]
[Al0b>3H000M0<SPf08092@T0P0Y:BT202h^;P80:RXZ0P0X:2P202`/;080=SHf0P15ADD204m?C`80
A4A40P0g=cL203@d=080>3Ph0P12@T8204U9B@80>c/k0`0_;bl202d];@80;bl_0P0b<S8203Hf=P80
<30`0P0[:b/202`/;080;bl_0P0Z:RX202TY:@80ATI60P1JFUX207=cL`80@d=30P1:BTX203De=@80
ATI60P1LG5`202HV9P80GEeM0P1IFET202HV9P808b<S0P1FEUH203Ti>@8071`L0P0N7Qh202TY:@80
;bl_0P0m?Cd2075aL@<0UiNG0P2VYZH206UYJ@80GEeM0P1JFUX208:2PP80Zj^[0P2c/k<20;2`/080
[Jf]0P2YZJT20:f][@80/[:b0P2d];@20;Ng]`80_kno0P35aLD20<30`080][Jf0P2WYjL209ZJVP80
UiNG0P2JVYX20:6QX@80ZZZZ0P2d];@20;fm_@@0_[jn0P2o_kl20<71`@D0alO70P2][Jd2096AT@80
PH610P1hN7P207]kN`80Ph>30P2:RXX209:BTP80TI6A0P2>SXh208b<S080RHV90P21PH4207QhN080
M7Ad0P1`L70206YZJP80Hf=S0P1HF5P204i>CP80@d=30P0l?3`20451@@@0BDU90P1<C4`205YJFP80
JFUY0P1bLW8207alO080Shn?0`2PX:020:NWY`80Zj^[0P2`/;020;>c/`80/K6a0P2_[jl20;2`/080
/k>c0P2d];@20;Fe]@80/[:b0P2`/;020:j^[P@0[Jf]:@38h=P202@T9080:b/[0P0d=3@202<S8`80
:RXZ0P0d=3@203De=@80?3`l0P1FEUH20492@P80<S8b0P0k>c/203@d=080AdM70P16ATH203Ti>@<0
;bl_0P0Z:RX202`/;080>SXj0P0g=cL202l_;`80<S8b0P0[:b/4030`<080;2`/0P12@T82061PH080
J6QX0P1>CTh204I6AP80<S8b0P0l?3`2061PH080;Rh^0P1KFe/205=CD`809BDU0P0];Bd205EEE@80
<C4a0P0O7al202LW9`809BDU0P0S8b<203hn?P80MGEe0`2GUiL209nOW`80KVi^0P1KFe/2061PH080
Ng]k0P2ZZZX20;Vi^@80[Zj^0P2VYZH20:f][@80[:b/0P2d];@20;:b/P80^;Rh0P30`<020<;2`P80
a<C40P2e]KD20:FUY@80VYZJ0P2LW9`209RHV080WinO0P2XZ:P20;Jf]P80_;bl0P2k^k/20;fm_@80
`/;20P33`l<20<;2`P<0`L710P2j^[X209VIV@80NGUi0P1fMWH207YjNP80PX:20P29RHT2092@T080
S8b<0P2>SXh208f=S@80RHV90P1oOgl207UiN@80MGEe0P1^KVh206][J`80I6AT0P1KFe/2051@D0@0
?clo0P14A4@204M7A`80BDU90P1;Bd/205UIF@80JVYZ0P1_Kfl207YjNP80SHf=0`2NWYh20:FUY@80
Z:RX0P2`/;020;>c/`80/;2`0P2_[jl20;6a/@80/k>c0P2d];@20;>c/`80];Bd0P2`/;060:b/[2T0
b>3H0P0S8b<202TY:@80;bl_0P0^;Rh202/[:`80:RXZ0P0g=cL204U9B@80Cdm?0P14A4@203Ti>@80
=SHf100h>3P204e=C@80>CTi0`0^;Rh202PX:080;Rh^0P0c<c<203Ph>080;2`/0P0[:b/202DU9@80
<30`0P0/;2`202TY:@80A4A40P1JFUX207EeM@80A4A40P18B4P203De=@80B4Q80P1KFe/202HV9P80
H61P0P1HF5P202LW9`807alO0P1IFET203`l?0806a/K0P0H61P202XZ:P80=3@d0P0h>3P207=cL`<0
UiNG0P2RXZ8206i^KP80FEUI0P1MGEd207moO`80Zj^[0P2a/K420:j^[P80[jn_0P2YZJT20:j^[P80
/[:b0P2f][H20;Fe]@@0`l?30P2n_[h20;Rh^080YjNW0P2FUYH209NGU`80VYZJ0P2RXZ820:ZZZP80
]KFe0P2o_kl20;fm_@80`l?30P2i^KT20<?3``80aLG50`3;bl/20:b/[080Shn?0P23Ph<207AdM080
PH610P23Ph<208R8R080TI6A0P2FUYH208n?S`@0R8R80P23Ph<207YjNP80LG5a0P1^KVh206a/K080
IVIV0P1FEUH204e=C@80AdM70P0j>SX20410@080B4Q80P1<C4`204];B`80F5QH0P1WIfL207AdM080
OGem0P2ATI430:2PX080YJFU0P2/[:`20:n_[`80]KFe0P2_[jl20;6a/@80/[:b102c/k<20;Fe]@80
/K6a0P2`/;020:f][@80Zj^[0P2][JdO0<SPf0007@38h=P2028R8P80;2`/0P0f=SH202l_;`80:2PX
0P0[:b/203De=@80>c/k0P0o?cl203Ph>080<S8b0P0c<c<403/k>`80?clo0P0c<c<302h^;P80;2`/
0P0^;Rh2038b<P80>SXj0P0c<c<202/[:`80;2`/0P0b<S820451@@80D51@0P18B4P205EEE@80EeMG
0P0h>3P203Lg=`80=CDe0P0g=cL2061PH080=cLg0P1UIFD204m?C`80:BTY0P0X:2P205mOG`80?Shn
0P0P820201dM7@808b<S0P0Q8B4202/[:`80BTY:0`27QhL209jNWP80QXJ60P1/K6`205MGE`80Jf][
0P2:RXX20:JVYP80^[Zj0P2d];@20:VYZ@80ZZZZ0P2^[Zh20;2`/080/k>c0P2k^k/20<71`@80`<30
0P2j^[X20:ZZZP80Vi^K0P2HV9P209ZJVP80WIfM0P2SXj<20:n_[`80^k^k0P2n_[h20;no_`80`L71
0P33`l<50<G5a@80cLg=0P39bLT209jNWP80L71`0P1UIFD206IVIP80KVi^0P1aLG4207IfMP80NGUi
0P1hN7P207AdM080Kfm_0P1ZJVX206MWI`80I6AT0P1SHf<2065QH@80F5QH0P1@D50204m?C`80DU9B
0P1HF5P2061PH080I6AT0P1YJFT207IfMP80Q8B40P2=SHd209FEU@80XJ6Q0`2[Zj/20;2`/080/[:b
0P2e]KD20;Jf]P80];Bd102a/K460;>c/`80/[:b0P2a/K420:n_[`@0[:b/:@38h=P402PX:080=SHf
0P0^;Rh202LW9`@0<30`0P0_;bl203Ph>080=cLg0P0h>3P203@d=080?clo0P1:BTX203Ti>@80<c<c
0`0Y:BT2030`<080;bl_0P0f=SH203Ti>@80;Bd]0P0[:b/202LW9`80;bl_0P18B4P204I6AP80Cdm?
0P1JFUX2059BDP80<S8b100m?Cd203@d=080EeMG0P0c<c<206UYJ@80CTi>0P0V9RH202l_;`80G5aL
0P0d=3@201dM7@@09bLW0P0P820202XZ:P80C4a<0`24Q8@20:JVYP80Ph>30P1/K6`205aLG080I6AT
0P28R8P20;2`/080_kno0P2^[Zh20:VYZ@80ZZZZ0P2/[:`20:n_[`80]KFe0P2h^;P20;jn_P80`/;2
0P2k^k/20:VYZ@80UiNG0P2JVYX209RHV0@0WYjN0P2f][H20;Zj^P@0_[jn0P32`/820<C4a080`/;2
0`31`L420<;2`P80`L710P2NWYh207IfMP80IVIV0P1XJ6P206i^KP80MWIf0P1hN7P207UiN@80MgMg
0P1eMGD206a/K080IVIV0P1PH60206MWI`80IFEU0P1KFe/205=CD`80CDe=0P1GEeL205EEE@80GEeM
0P1UIFD206][J`80LW9b0P1mOGd208F5Q@80TY:B0P2HV9P209nOW`<0YjNW0P2^[Zh20;2`/080^KVi
102e]KD20;2`/080[Jf]0P2a/K420;>c/`80/[:b0P2a/K440:n_[`80[Jf]0P2ZZZXY0<SPf0809BDU
0P0Y:BT2038b<P80;2`/0P0S8b<202TY:@80;bl_0P0o?cl203dm?@80>3Ph0P0];Bd203Lg=`@0>SXj
0P13@d<2034a<@<0;Bd]0P0^;Rh203<c<`80;2`/0P0j>SX203Lg=`80;bl_0P0`<30203Hf=P80@T92
0P1CDe<204M7A`80EeMG0P1EEED2038b<P@0=CDe0P0h>3P205aLG080>SXj0P1TI6@204a<C080;2`/
0P0W9bL205]KF`80?clo0P0R8R8201LG5`808b<S0P0O7al2030`<080A4A40`29RHT209^KV`80RHV9
0P1VIVH205EEE@80JVYZ0P27QhL20:RXZ080^KVi0P2e]KD20:JVYP80ZJVY0P2`/;020:f][@80/k>c
0P2m_Kd20<?3``80_Kfm0P2l_;`20:n_[`80WYjN0P2GUiL209RHV080WinO0P2PX:020:^[Z`80^KVi
0P2n_[h40<?3``80aLG50P2m_Kd30<G5a@80clo?0P39bLT209nOW`80KVi^0P1UIFD206ATI080LG5a
0P1_Kfl207AdM080NGUi101cLg<206i^KP80JFUY0P1VIVH406=SH`80GUiN0P1HF5P205=CD`80D51@
0P1DE5@205MGE`80GemO0P1VIVH206YZJP80NGUi0P26QXH208^;R`80T92@0P2PX:030:^[Z`80/;2`
0P2a/K420;Fe]@80^;Rh0P2c/k<40;2`/080]KFe0P2d];@40;>c/`80/K6a0P2][Jd20:b/[080[jn_
7`38h=P001d0b>3H0P0R8R8202`/;080=SHf0P0_;bl202PX:080:b/[0P0e=CD203/k>`80?clo0P0h
>3P2038b<P80<c<c100k>c/203lo?`80<c<c0`0^;Rh202`/;080;Rh^0P0b<S8203Xj>P80<c<c0P0[
:b/202`/;080<S8b0P11@D42051@D080B4Q80P1EEED205MGE`80>3Ph0P0g=cL203De=@80=cLg0P1P
H60203Lg=`80IFEU0P1?Cdl202TY:@80:2PX0P1OGel203hn?P80820P0P0M7Ad202<S8`808B4Q0P0[
:b/204Y:BP<0QhN70P2NWYh208J6QP80K6a/0P1GEeL206][J`80RXZ:0P2VYZH20;Zj^P80];Bd0P2Y
ZJT20:ZZZP80[Zj^0P2`/;020;>c/`80^k^k0P31`L420<30`080^[Zj0P2ZZZX209^KV`80V9RH0P2J
VYX209fMW@80Xj>S0P2_[jl20;^k^`80_[jn0P2o_kl20<71`@80`l?31@35aLD20<g=c@80bLW90P2N
WYh2071`L080IFEU0P1VIVH206i^KP80LG5a0P1fMWH207UiN@80N7Qh0P1dM7@206m_K`80JVYZ0P1W
IfL206ATI080Hf=S0P1QHF4205QHF080D51@0P1?Cdl2059BDP80F5QH0P1PH60206ATI080JFUY0P1f
MWH208B4Q080SHf=0P2EUID20:6QX@<0Zj^[0P2`/;020;:b/P80]KFe0P2f][H20;Bd]0@0/K6a1P2c
/k<20;:b/P80/K6a0P2_[jl40:b/[2T0b>3H100X:2P203Hf=P80;Rh^0P0W9bL4030`<080;bl_0P0h
>3P203Lg=`80>3Ph0P0d=3@203lo?`80BTY:0P0i>CT203<c<`<0:BTY0P0`<30202l_;`80=SHf0P0i
>CT202d];@80:b/[0P0W9bL202l_;`80B4Q80P16ATH204m?C`80FUYJ0P1BDU82038b<P@0?Cdm0P0d
=3@205MGE`80<c<c0P1YJFT204i>CP809RHV0P0_;bl205aLG080=3@d0P0M7Ad402LW9`80820P0P0Z
:RX204a<C0<0Q8B40P2VYZH208>3P`80K6a/0P1LG5`206ATI080R8R80P2`/;020;no_`80[Zj^0P2Y
ZJT20:ZZZP80[:b/0P2_[jl20;Fe]@80^;Rh0P2n_[h20<;2`P80^k^k0P2YZJT209NGU`80VYZJ0P2H
V9P409jNWP80][Jf0P2j^[X40;jn_P80`/;20P34a<@20<;2`P<0`L710P32`/820<71`@80WYjN0P1f
MWH206IVIP80J6QX0P1^KVh207IfMP80N7Qh0P1iNGT207MgM`80MGEe0P1/K6`206IVIP80H61P0P1W
IfL206EUI@80Fe]K0P1CDe<204e=C@80EeMG0P1EEED205eMG@80IFEU0P1[Jf/2079bLP80OGem0P25
QHD209:BTP80V9RH0P2OWil30:NWY`80[Zj^0P2`/;020;Vi^@@0]KFe0P2`/;020:f][@80/K6a0P2c
/k<20;:b/P80/K6a102_[jl20:f][@80ZZZZ:@38h=P202DU9@80:BTY0P0b<S8202`/;0808b<S0P0Y
:BT202l_;`80?clo0P0m?Cd203Ph>080;Bd]0P0g=cL403Xj>P80@d=30P0a<C4302d];@80;Rh^0P0c
<c<202`/;080>SXj0P0g=cL202l_;`80<30`0P0f=SH20492@P80De=C0P17AdL205MGE`80EEEE0P0b
<S8403De=@80>3Ph0P1LG5`203Xj>P80I6AT0P1<C4`202`/;0809bLW0P1KFe/203lo?`808R8R0P0G
5aL202<S8`807alO0P0`<30204A4A0<0RHV90P2KVi/208V9R@80IVIV0P1EEED206YZJP80QhN70P2X
Z:P20;Vi^@80]KFe0P2VYZH20:VYZ@80/;2`0P2][Jd20;>c/`80_Kfm0P33`l<20;fm_@80_;bl0P2_
[jl209jNWP80UiNG0P2HV9P209nOW`80X:2P0P2[Zj/20;Vi^@80_[jn1033`l<20<G5a@80_Kfm0`35
aLD20<o?c`80bLW90P2OWil206i^KP80IFEU0P1TI6@2075aL@80Kfm_0P1dM7@207UiN@@0Lg=c0P1^
KVh206UYJ@80IVIV101SHf<205iNGP80F5QH0P1CDe<2051@D080E5AD0P1GEeL205mOG`80IVIV0P1Z
JVX207UiN@80QXJ60P2;Rh/2092@T080X:2P0`2[Zj/20;2`/080/K6a0P2e]KD20;Rh^080/k>c102`
/;020;Fe]@80];Bd102c/k<20;6a/@80[Jf]0P2/[:`20:n_[al0b>3H000M0<SPf0808B4Q0P0^;Rh2
03/k>`80<c<c0P0Z:RX202l_;`80=CDe0P0b<S8202h^;P80;Bd]0P0^;Rh203De=@80>SXj0P0f=SH2
03<c<`80;bl_0`0/;2`202/[:`80;Bd]0P0d=3@203Xj>P80<c<c0P0/;2`2034a<@80>3Ph0P0e=CD2
03Hf=P809RHV0P1?Cdl203dm?@80<30`0P0/;2`203Hf=P80;2`/0P1RHV8204];B`80IfMW0P14A4@2
02l_;`80:b/[0P1RHV8204E5A@80:BTY100Q8B4201/K6`808b<S0P0V9RH306m_K`80RXZ:0P2MWId2
0861P@80HF5Q0P1NGUh206YZJP80Ti>C0P2j^[X20;Rh^080[Jf]102ZZZX20:b/[080[jn_0P2f][H2
0;fm_@80_kno0P2l_;`20:b/[080W9bL0P2JVYX409^KV`80WIfM0P2[Zj/20;Vi^@80_[jn0P31`L42
0<?3``@0a<C40`32`/820;no_`80^k^k0P2j^[X20;2`/080P8200P1@D50205aLG080EEEE0P1MGEd4
06=SH`H0HF5Q101PH60206ATI080IfMW0P1PH60205aLG080IFEU0P1`L70207EeM@80NWYj0P21PH42
08V9R@80Ti>C0P2LW9`20:>SX`80Z:RX0P2/[:`30:n_[`80/[:b0P2d];@20;Jf]P80]kNg0P2e]KD2
0;>c/`@0/[:b0P2a/K420;2`/080/K6a0P2b/[820:n_[`80[Jf]0P2/[:`Y0<SPf0809RHV0P0[:b/2
0451@@@0;2`/0P0^;Rh203Ph>080=3@d0P0c<c<203Ti>@80:RXZ0P0d=3@203De=@80>SXj0P0`<302
02/[:`<0;bl_0P0Z:RX202`/;080=CDe0P0j>SX203Lg=`80;Rh^0P0b<S8203Ph>080>CTi0P0e=CD2
02h^;P80BTY:0P16ATH202l_;`80:b/[0P0/;2`203Ph>080H61P0P19BDT206a/K080?Shn0P0`<302
038b<P80GemO0P12@T8202XZ:P809BDU0P0P820201dM7@808b<S0P0[:b/306e]K@80Rh^;0P2IVIT2
08:2PP80Hf=S0P1MGEd206a/K080Shn?0P2e]KD20<71`@80[:b/0P2UYJD20:b/[080[Zj^0P2c/k<2
0;:b/P80_kno0P30`<020;^k^`80[Jf]0P2JVYX209fMW@80VIVI0P2LW9`209fMW@80[Jf]0P2h^;P2
0;fm_@80`<300P33`l<20<C4a080a/K60`35aLD40<30`080_kno0P2ZZZX207QhN0@0EEEE0P1GEeL2
05QHF0@0HF5Q0P1PH60206IVIP80Hf=S0P1KFe/2061PH080J6QX101TI6@205IFEP80IVIV0P1^KVh2
07=cL`80NWYj0P1lO7`208J6QP80T92@0P2LW9`20:>SX`80YZJV0P2][Jd30:n_[`@0/k>c102f][H2
0;Fe]@80/K6a0P2b/[820;>c/`@0/;2`0P2_[jl20;Fe]@80[Jf]0P2ZZZX20:n_[bT0b>3H0P0Y:BT2
02XZ:P80?Cdm0P0f=SH202TY:@@0<C4a0P0g=cL202d];@80<30`0P0_;bl203Hf=P80>c/k0P0d=3@2
03De=@80:b/[1@0];Bd202`/;080;bl_0P0j>SX2030`<080:RXZ0P0b<S8203Ph>080=CDe0P0d=3@2
02HV9P80DE5A0P0l?3`203Hf=P80;Rh^0P0f=SH202/[:`80GemO0P1?Cdl206MWI`80@T920P0c<c<2
02HV9P80JFUY0P16ATH202LW9`809BDU0P0N7Qh201TI6@809bLW0P0R8R83075aL@80RXZ:0P2RXZ82
07emO@@0HV9R0P1^KVh208N7Q`80_kno0P2i^KT20:VYZ@80/k>c0P2WYjL20:f][@80/k>c0P2a/K42
0;jn_P80a<C40P2j^[X20:ZZZP80V9RH102LW9`209^KV`80XJ6Q0P2YZJT20;^k^`80_kno0P2m_Kd2
0<K6aP80`/;21@33`l<20<71`@80^;Rh0P2j^[X20:n_[`80Ph>30P1@D50205UIF@80EUIF0P1PH602
06ATI080HF5Q0P1RHV82065QH@80H61P0P1SHf<205iNGP@0IVIV0P1SHf<205]KF`80HV9R0P1aLG42
07IfMP80NGUi0P23Ph<208V9R@80TI6A0P2JVYX20:FUY@80ZJVY0P2[Zj/30:j^[P80/[:b0P2f][H2
0;Bd]080]kNg0P2e]KD40;>c/`80/[:b0P2/[:`20;2`/080/k>c0P2a/K420:n_[`80Zj^[0P2][JdO
0<SPf0007@38h=P2024Q8@80;Rh^0P0k>c/203<c<`80:RXZ0P0_;bl203De=@80<S8b0P0^;Rh202d]
;@80;Rh^0P0e=CD203Xj>P80=SHf0P0c<c<202l_;`<0;2`/0P0[:b/202d];@80=3@d0P0j>SX203<c
<`80;2`/0P0a<C4203Ph>080=CDe0P0f=SH202HV9P80Cdm?0P0m?Cd2030`<080;2`/0P0f=SH202`/
;080HV9R0P1;Bd/206MWI`80A4A40P0_;bl202/[:`80HV9R0P15ADD202TY:@@08B4Q0P0K6a/202<S
8`809RHV0`1_Kfl208Z:RP80WIfM0P21PH42065QH@80GUiN0P1ZJVX209>CT`80^[Zj0P2h^;P20:f]
[@@0ZZZZ0P2/[:`20:n_[`80][Jf0P2m_Kd20;no_`80_;bl0P2/[:`209bLW080VYZJ102KVi/209fM
W@80Zj^[0P2i^KT20;jn_P80`L710P33`l<40<C4a0<0`/;20P2o_kl20;^k^`80^[Zj0P2`/;020820
P080D51@0P1LG5`205EEE@80GEeM101SHf<6065QH@@0H61P0P1TI6@206MWI`80H61P0P1LG5`206EU
I@80L71`0P1eMGD207YjNP80PH610P29RHT209>CT`80W9bL0P2SXj<20:RXZ080[:b/0`2_[jl20;:b
/P80];Bd0P2f][H20;Ng]`80]KFe0P2c/k<40;:b/P80/K6a0P2`/;020;6a/@80/[:b0P2_[jl20:f]
[@80[:b/:@38h=P202HV9P80:b/[0P11@D4402`/;080;Rh^0P0h>3P203@d=080<c<c0P0i>CT202XZ
:P80=3@d0P0e=CD203Xj>P80<30`0P0[:b/302l_;`80:RXZ0P0/;2`203De=@80>SXj0P0g=cL202h^
;P80<S8b0P0h>3P203Ti>@80=CDe0P0^;Rh204Y:BP80ATI60P0_;bl202/[:`80;2`/0P0h>3P2061P
H080BDU90P1/K6`203hn?P80<30`0P0b<S8205mOG`80@T920P0Z:RX202DU9@80820P0P0M7Ad202<S
8`80:b/[0`1]KFd208^;R`80VIVI0P22PX8206=SH`80GEeM0P1/K6`208n?S`80]KFe0P31`L420:b/
[080YJFU0P2/[:`20:j^[P80/k>c0P2b/[820;no_`80`<300P2k^k/20:f][@80VYZJ0P2MWId209VI
V@80W9bL0P2MWId20:f][@80^;Rh0P2m_Kd20<30`080`l?30P34a<@20<K6aP<0aLG51030`<020;no
_`80ZZZZ0P1hN7P405EEE@80EeMG0P1HF5P4065QH@80H61P0P1VIVH206=SH`80Fe]K0P1PH60206QX
J0@0I6AT0P1FEUH206IVIP80KVi^0P1cLg<207YjNP80O7al0P26QXH2092@T080W9bL0P2SXj<20:JV
YP80[Jf]0`2_[jl40;>c/`@0][Jf0P2e]KD20;6a/@80/[:b0P2c/k<40;2`/080[jn_0P2e]KD20:f]
[@80ZZZZ0P2_[jlY0<SPf080:BTY0P0Z:RX203dm?@80=SHf0P0Y:BT4034a<@80=cLg0P0];Bd2030`
<080;bl_0P0f=SH203/k>`80=3@d0P0e=CD202/[:`D0;Bd]0P0/;2`202l_;`80>SXj0P0`<30202XZ
:P80<S8b0P0h>3P203De=@80=3@d0P0V9RH2055AD@80?3`l0P0f=SH202h^;P80=SHf0P0[:b/205mO
G`80Cdm?0P1WIfL20492@P80<c<c0P0V9RH206UYJ@80ATI60P0W9bL202DU9@807QhN0P0I6AT202LW
9`808R8R0`1aLG4208Z:RP80XZ:R0P1mOGd4069RHP80KVi^0P27QhL20;no_`80^KVi0P2YZJT20;>c
/`80YjNW0P2][Jd20;>c/`80/K6a0P2n_[h20<C4a080^[Zj0P2ZZZX209RHV0@0W9bL0P2KVi/20:6Q
X@80ZJVY0P2k^k/20;no_`80_Kfm0P36a/H20<;2`PD0`l?30P31`L420;Rh^080^[Zj0P2_[jl208>3
P`80D51@0P1IFET205IFEP80H61P0P1TI6@2065QH@80HV9R0P1QHF42061PH080Hf=S0P1NGUh406IV
IP80Hf=S0P1KFe/2069RHP80LG5a0P1fMWH207UiN@80Ph>30P29RHT2096AT@80VYZJ0P2UYJD20:VY
Z@80Zj^[0`2^[Zh20;:b/P80][Jf0P2d];@20;Ng]`80]KFe102c/k<20;:b/P80[:b/0P2`/;020;>c
/`80/K6a0P2_[jl20:^[Z`80[Jf]7`38h=P001d0b>3H0P0Q8B4202/[:`80=cLg0P0c<c<202h^;P80
=SHf0P0m?Cd203/k>`80=cLg0P0d=3@2034a<@@0=3@d0P10@40702XZ:P@0:BTY0P0];Bd2034a<@80
;bl_0P0];Bd2034a<@80=SHf0P0e=CD203Ph>080:BTY0P1EEED203Lg=`80:b/[0P0U9BD2030`<080
9BDU0P1OGel205YJFP80IFEU0P13@d<202TY:@808b<S0P1MGEd205UIF@80=CDe100f=SH202XZ:P80
8b<S0P0O7al304M7A`80KVi^0P2EUID2092@T080Ogmo0P1XJ6P205]KF`80NGUi0P2NWYh20;Bd]080
_kno0P2d];@20:JVYP80YjNW0P2/[:`20;:b/P80]kNg0P2j^[X20;Vi^@80[Jf]0P2PX:0209^KV`80
VYZJ0P2IVIT209^KV`80YjNW0P2e]KD20;bl_080`L711032`/850<?3``80`/;20P2o_kl20;fm_@80
]kNg0P2UYJD2092@T080AdM70P18B4P204A4A080CTi>0P1FEUH205mOG`80I6AT0P1XJ6P206UYJ@80
Jf][0P1aLG4207QhN0@0MgMg0P1nOWh208F5Q@80R8R80P2<S8`209>CT`80VYZJ0P2PX:020:JVYP80
ZZZZ0P2][Jd20:n_[`<0/K6a0P2b/[820;Bd]080][Jf0P2g]kL20;Fe]@80/k>c0P2a/K460;2`/0@0
/K6a102`/;020:n_[bT0b>3H0P0S8b<202HV9P80?Cdm0P0b<S8203<c<`80>CTi0P0o?cl203Ti>@80
=3@d1P0_;bl203<c<`80@4100P0b<S8202PX:0<0<C4a0P0Y:BT202XZ:P80:b/[0P0d=3@202`/;080
;Rh^0P0e=CD203<c<`80=CDe0P0a<C4202`/;080AdM70P0g=cL202XZ:P@0:BTY0P0`<30206EUI@80
EEEE0P1/K6`203Ti>@80:BTY0P0b<S8405]KF`80=cLg0P0b<S8202h^;P80:BTY0P0N7Qh202<S8`<0
>c/k0P1iNGT208b<S080X:2P0P1hN7P205mOG`80I6AT0P1bLW8209NGU`80a/K60P2j^[X20:VYZ@80
Zj^[0P2VYZH20:NWY`80/;2`102i^KT20;Ng]`80Zj^[0P2SXj<209ZJVP80Vi^K0P2FUYH209^KV`80
Y:BT0P2c/k<20;fm_@80`l?30P31`L420<30`080`/;20`35aLD20<30`080_[jn0P2k^k/20;Vi^@80
/;2`0P29RHT204m?C`80ADE50P17AdL205EEE@80FEUI0P1MGEd206EUI@80JVYZ0P1^KVh206QXJ080
M7Ad0P1iNGT207emO@80OWin0P1mOGd208B4Q080QhN70P29RHT209BDU080V9RH0P2NWYh40:JVYP80
[:b/0P2a/K430:n_[`80]KFe102d];@20;Ng]`@0]KFe0P2d];@20:j^[P@0/k>c102_[jl20;:b/P80
[jn_0P2d];@Y0<SPf0805aLG0P0];Bd203Ti>@80=SHf0P0a<C4203<c<`80A4A40P0k>c/203<c<`80
<S8b0P0`<30203<c<`80=3@d0P0i>CT202d];@80:RXZ0`0^;Rh202@T90@0;Rh^0P0g=cL203@d=080
;Bd]0P0/;2`202l_;`80=CDe0P0g=cL202d];@80De=C0P0^;Rh202/[:`809BDU0P0_;bl202PX:0@0
GemO0P1UIFD203hn?P80;bl_0P0K6a/205eMG@80EeMG0P0b<S8203Xj>P80>3Ph0P0[:b/2028R8P80
7AdM0`1=CDd206YZJP80UYJF0P2<S8`208:2PP80K6a/0P1LG5`207QhN080WinO0P2g]kL20<30`080
/;2`102UYJD20:b/[080[Zj^0P2g]kL20;Rh^080]kNg0P2^[Zh209nOW`80WYjN0P2IVIT209BDU080
W9bL0P2VYZH20;Ng]`80^k^k1P32`/820<K6aP<0`<300P33`l<20;no_`80`L710P2e]KD20:FUY@80
TI6A0P16ATH204U9B@80@T920P1>CTh205IFEP80GemO0P1VIVH206EUI@80KVi^0P1YJFT2075aL@@0
MgMg0P1fMWH207inOP80Q8B40P29RHT208Z:RP80Ti>C0P2GUiL209jNWP80YjNW0P2_[jl20:j^[P80
/k>c0`2b/[840;Bd]080][Jf0P2g]kL20;Fe]@80/[:b0P2c/k<20;2`/0@0/[:b1P2`/;020;6a/@80
[jn_7`38h=P001d0b>3H0P0Q8B4202/[:`80=cLg0P0c<c<202h^;P80=SHf0P0m?Cd203/k>`80=cLg
0P0d=3@2034a<@@0=3@d0P10@40702XZ:P@0:BTY0P0];Bd2034a<@80;bl_0P0];Bd2034a<@80=SHf
0P0e=CD203Ph>080:BTY0P1EEED203Lg=`80:b/[0P0U9BD2030`<0809BDU0P1OGel205YJFP80IFEU
0P13@d<202TY:@808b<S0P1MGEd205UIF@80=CDe100f=SH202XZ:P808b<S0P0O7al304M7A`80KVi^
0P2EUID2092@T080Ogmo0P1XJ6P205]KF`80NGUi0P2NWYh20;Bd]080_kno0P2d];@20:JVYP80YjNW
0P2/[:`20;:b/P80]kNg0P2j^[X20;Vi^@80[Jf]0P2PX:0209^KV`80VYZJ0P2IVIT209^KV`80YjNW
0P2e]KD20;bl_080`L711032`/850<?3``80`/;20P2o_kl20;fm_@80]kNg0P2UYJD2092@T080AdM7
0P18B4P204A4A080CTi>0P1FEUH205mOG`80I6AT0P1XJ6P206UYJ@80Jf][0P1aLG4207QhN0@0MgMg
0P1nOWh208F5Q@80R8R80P2<S8`209>CT`80VYZJ0P2PX:020:JVYP80ZZZZ0P2][Jd20:n_[`<0/K6a
0P2b/[820;Bd]080][Jf0P2g]kL20;Fe]@80/k>c0P2a/K460;2`/0@0/K6a102`/;020:n_[bT0b>3H
0P0S8b<202HV9P80?Cdm0P0b<S8203<c<`80>CTi0P0o?cl203Ti>@80=3@d1P0_;bl203<c<`80@410
0P0b<S8202PX:0<0<C4a0P0Y:BT202XZ:P80:b/[0P0d=3@202`/;080;Rh^0P0e=CD203<c<`80=CDe
0P0a<C4202`/;080AdM70P0g=cL202XZ:P@0:BTY0P0`<30206EUI@80EEEE0P1/K6`203Ti>@80:BTY
0P0b<S8405]KF`80=cLg0P0b<S8202h^;P80:BTY0P0N7Qh202<S8`<0>c/k0P1iNGT208b<S080X:2P
0P1hN7P205mOG`80I6AT0P1bLW8209NGU`80a/K60P2j^[X20:VYZ@80Zj^[0P2VYZH20:NWY`80/;2`
102i^KT20;Ng]`80Zj^[0P2SXj<209ZJVP80Vi^K0P2FUYH209^KV`80Y:BT0P2c/k<20;fm_@80`l?3
0P31`L420<30`080`/;20`35aLD20<30`080_[jn0P2k^k/20;Vi^@80/;2`0P29RHT204m?C`80ADE5
0P17AdL205EEE@80FEUI0P1MGEd206EUI@80JVYZ0P1^KVh206QXJ080M7Ad0P1iNGT207emO@80OWin
0P1mOGd208B4Q080QhN70P29RHT209BDU080V9RH0P2NWYh40:JVYP80[:b/0P2a/K430:n_[`80]KFe
102d];@20;Ng]`@0]KFe0P2d];@20:j^[P@0/k>c102_[jl20;:b/P80[jn_0P2d];@Y0<SPf0805aLG
0P0];Bd203Ti>@80=SHf0P0a<C4203<c<`80A4A40P0k>c/203<c<`80<S8b0P0`<30203<c<`80=3@d
0P0i>CT202d];@80:RXZ0`0^;Rh202@T90@0;Rh^0P0g=cL203@d=080;Bd]0P0/;2`202l_;`80=CDe
0P0g=cL202d];@80De=C0P0^;Rh202/[:`809BDU0P0_;bl202PX:0@0GemO0P1UIFD203hn?P80;bl_
0P0K6a/205eMG@80EeMG0P0b<S8203Xj>P80>3Ph0P0[:b/2028R8P807AdM0`1=CDd206YZJP80UYJF
0P2<S8`208:2PP80K6a/0P1LG5`207QhN080WinO0P2g]kL20<30`080/;2`102UYJD20:b/[080[Zj^
0P2g]kL20;Rh^080]kNg0P2^[Zh209nOW`80WYjN0P2IVIT209BDU080W9bL0P2VYZH20;Ng]`80^k^k
1P32`/820<K6aP<0`<300P33`l<20;no_`80`L710P2e]KD20:FUY@80TI6A0P16ATH204U9B@80@T92
0P1>CTh205IFEP80GemO0P1VIVH206EUI@80KVi^0P1YJFT2075aL@@0MgMg0P1fMWH207inOP80Q8B4
0P29RHT208Z:RP80Ti>C0P2GUiL209jNWP80YjNW0P2_[jl20:j^[P80/k>c0`2b/[840;Bd]080][Jf
0P2g]kL20;Fe]@80/[:b0P2c/k<20;2`/0@0/[:b1P2`/;020;6a/@80[jn_7`38h=P001d0b>3H0P0P
820202PX:080<S8b0P0a<C42038b<P80>c/k0P14A4@204=3@`80@4100P0n?Sh203/k>`80>3Ph0P0b
<S8204a<C0809bLW0P0Z:RX302/[:`80:2PX0P0V9RH202LW9`80:BTY0P0/;2`202l_;`80<S8b0P0e
=CD2038b<P80=CDe0P0];Bd205YJFP80?clo0P0Z:RX202<S8`80:RXZ0P0R8R8205QHF0@0I6AT0P12
@T8202@T90806a/K0P1BDU8206a/K080ATI60P1;Bd/204Q8B080>CTi0P0Y:BT2028R8P<09BDU0P1@
D50207inOP80UIFE0P2KVi/207UiN@80F5QH0P1RHV8207emO@80YjNW0P39bLT20;^k^`80YJFU0P2T
Y:@20:RXZ080[Jf]0P2b/[840;Fe]@80[Jf]0P2TY:@209fMW@80VIVI0P2HV9P209^KV`80YJFU0P2a
/K420;Zj^P@0`<300P2n_[h20<71`@<0a<C40P30`<020;^k^`@0_;bl0P2m_Kd20;Bd]080WinO0P1X
J6P2059BDP80AdM70P1CDe<206EUI@80KVi^0P1dM7@207QhN080O7al0P23Ph<208Z:RP80Shn?0P2C
Ti<209BDU080UIFE0P2GUiL209VIV@80WinO0P2UYJD20:RXZ080ZZZZ0P2/[:`20:f][@80[jn_1`2a
/K420;Bd]080][Jf0P2e]KD20;:b/P80/K6a0P2_[jl20;2`/0H0/K6a0P2b/[840;>c/bT0b>3H0P0V
9RH2028R8P80<30`0P0g=cL2038b<P80=CDe0P18B4P204e=C@80ATI60P0n?Sh203`l?080<S8b0P0n
?Sh204=3@`80;Bd]0P0X:2P302`/;080:2PX0P0U9BD202XZ:P80:2PX0P0];Bd2034a<@80<S8b0P0c
<c<203Xj>P80<c<c0P0_;bl205MGE`80AdM7100T92@202HV9P80;2`/0P1DE5@206EUI@80K6a/0P0l
?3`402<S8`80BTY:0P1]KFd20451@@80ADE50P1@D50203/k>`809bLW0P0Q8B4302XZ:P80ADE50P1m
OGd209fMW@80UiNG0P1dM7@205]KF`80IFEU0P1mOGd20:ZZZP80a/K60P2i^KT20:BTY080Z:RX0P2W
YjL20:^[Z`@0/k>c0P2g]kL20:^[Z`80YZJV0P2JVYX209bLW080UYJF0P2MWId20:JVYP80/[:b0P2h
^;P60<30`080_[jn0`36a/H20;no_`80_[jn0P2o_kl20;^k^`80][Jf0P2h^;P20:>SX`80KFe]0P1>
CTh204Y:BP80DU9B0P1VIVH207EeM@80KVi^101iNGT208J6QP80RHV90P2>SXh209>CT`80TI6A0P2D
U9@409RHV080WYjN0P2TY:@20:^[Z`80ZZZZ102^[Zh20:ZZZP<0/K6a0P2d];@20;2`/080];Bd0P2f
][H20;Bd]080/;2`0P2d];@40:j^[P80/K6a0P2`/;020;6a/@80/[:b0P2_[jl20;Fe]BT0b>3H0P0T
92@202DU9@80;bl_100a<C4203Xj>P80?clo0P16ATH20492@P80?Shn0P0k>c/203Xj>P80<c<c0P1=
CDd202XZ:P809RHV0`0_;bl202PX:0809bLW0P0U9BD202HV9P80:b/[0P0_;bl203Lg=`80>SXj0P0e
=CD203Lg=`80:b/[0P1JFUX204A4A080;2`/0P0Q8B4202d];@80820P0P1EEED206EUI@80GemO0P1:
BTX202<S8`806ATI0P1GEeL206YZJP80ATI60P1>CTh20451@@80?Cdm0P0U9BD2024Q8@<09BDU0P1@
D50207moO`80TI6A0P2GUiL207alO080F5QH0P1NGUh207emO@80[:b/0P37alL20;Fe]@80Zj^[0P2W
YjL20:b/[080YJFU0P2h^;P20;Bd]080^;Rh0P2[Zj/40:6QX@80VYZJ0P2HV9P209VIV@80[:b/0P2_
[jl20;Ng]`80_kno0P34a<@20;Zj^P80`l?30`35aLD20;fm_@80_;bl0P2m_Kd20;^k^`80_;bl0P2g
]kL209jNWP80Jf][0P1ADE4204Q8B080E5AD0P1SHf<206a/K080LG5a101kNg/208>3P`80Rh^;0P2C
Ti<209BDU080Ti>C0P2FUYH409RHV080XJ6Q0P2VYZH20:VYZ@80ZZZZ0P2[Zj/20:ZZZP80/K6a0`2`
/;020:n_[`80/K6a102f][H20;Fe]@@0/K6a0P2_[jl20:j^[P80/;2`0P2a/K420;2`/080];Bd0P2f
][H20;6a/Al0b>3H000M0<SPf080820P0P0X:2P2038b<P80<C4a0P0b<S8203/k>`80A4A40P13@d<2
0410@080?Shn0P0k>c/203Ph>080<S8b0P1<C4`202LW9`80:RXZ0`0[:b/202PX:0809RHV0P0W9bL2
02TY:@80;2`/0P0_;bl2038b<P80=CDe0P0b<S8203De=@80;Bd]0P1JFUX203lo?`80:RXZ0P0S8b<2
02XZ:P808R8R0P1HF5P406ATI080@T920P0T92@201/K6`80DU9B0P1/K6`204I6AP80Bd];0P18B4P2
03Ti>@80:BTY0P0R8R8302DU9@80D51@0P1nOWh209FEU@80Vi^K0P1iNGT205QHF080HV9R0P1mOGd2
0:NWY`80bLW90P2k^k/20:FUY@80Y:BT0P2XZ:P20:f][@80/[:b102e]KD20:f][@80Y:BT0P2MWId2
09VIV@80V9RH0P2KVi/20:FUY@80/K6a0P2j^[X40<30`080_[jn0P31`L430<C4a080`<300P2k^k/4
0;bl_080_Kfm0P2d];@209nOW`80J6QX0P1BDU8204M7A`80De=C0P1UIFD206i^KP80M7Ad0P1hN7P2
07alO080Ph>30P2:RXX208n?S`80Ti>C0P2DU9@209FEU@80UiNG0P2IVIT209nOW`80YJFU0P2XZ:P2
0:ZZZP80[:b/0P2][Jd20:n_[`L0/K6a0P2d];@20;Jf]P80]KFe0P2b/[820;6a/@80[jn_0P2`/;06
0;6a/@80/[:b102c/k<Y0<SPf0809RHV0P0R8R82030`<080=cLg0P0b<S8203De=@80B4Q80P1=CDd2
04I6AP80?Shn0P0l?3`2038b<P80?Shn0P13@d<202d];@80:2PX0`0/;2`202PX:0809BDU0P0Z:RX2
02PX:080;Bd]0P0a<C42038b<P80<c<c0P0j>SX203<c<`80;bl_0P1GEeL204M7A`@092@T0P0V9RH2
02`/;080E5AD0P1UIFD206a/K080?3`l100S8b<204Y:BP80KFe]0P11@D4204E5A@80D51@0P0k>c/2
02LW9`808B4Q0`0Z:RX204E5A@80OGem0P2MWId209NGU`80M7Ad0P1KFe/206EUI@80OGem0P2ZZZX2
0<K6aP80^KVi0P2TY:@20:RXZ080YjNW0P2[Zj/40;>c/`80]kNg0P2[Zj/20:JVYP80VYZJ0P2LW9`2
09JFUP80WIfM0P2VYZH20;:b/P80^;Rh1P30`<020;jn_P<0a/K60P2o_kl20;jn_P80_kno0P2k^k/2
0;Jf]P80^;Rh0P2SXj<206e]K@80CTi>0P1:BTX2059BDP80IVIV0P1eMGD206i^KP@0NGUi0P26QXH2
08V9R@80SXj>0P2CTi<2096AT@80U9BD102HV9P209jNWP80Y:BT0P2[Zj/20:ZZZP@0[Zj^0P2ZZZX3
0;6a/@80];Bd0P2`/;020;Bd]080][Jf0P2d];@20;2`/080];Bd102^[Zh20;6a/@80/;2`0P2a/K42
0;:b/P80[jn_0P2e]KDY0<SPf08092@T0P0U9BD202l_;`@0<C4a0P0j>SX203lo?`80ATI60P12@T82
03hn?P80>c/k0P0j>SX203<c<`80CDe=0P0Z:RX202HV9P<0;bl_0P0X:2P202LW9`809BDU0P0V9RH2
02/[:`80;bl_0P0g=cL203Xj>P80=CDe0P0g=cL202/[:`80FUYJ0P14A4@202`/;0808B4Q0P0];Bd2
020P8080EEEE0P1UIFD205mOG`80BTY:0P0S8b<201TI6@80EeMG0P1ZJVX204I6AP80CTi>0P11@D42
03dm?@809BDU0P0Q8B4302DU9@80D51@0P1oOgl2096AT@80UiNG0P1lO7`205QHF080GUiN0P1mOGd2
0:b/[080alO70P2e]KD20:^[Z`80YjNW0P2/[:`20:FUY@80^;Rh0P2d];@20;Rh^080Zj^[102QXJ42
09ZJVP80V9RH0P2IVIT20:b/[080[jn_0P2g]kL20;no_`80a<C40P2j^[X20<?3``<0aLG50P2m_Kd2
0;bl_080_Kfm0P2k^k/20;bl_080]kNg0P2NWYh206][J`80DE5A0P18B4P205ADE080Hf=S0P1/K6`2
075aL@@0Ng]k0P23Ph<208^;R`80Ti>C0P2DU9@209>CT`80UYJF102HV9P20:6QX@80YZJV0P2YZJT2
0:ZZZP80Zj^[0P2ZZZX20;6a/@<0/;2`0P2_[jl20;6a/@@0][Jf0P2e]KD40;6a/@80[jn_0P2^[Zh2
0;2`/080/K6a0P2`/;020;Bd]080][Jf0P2a/K4O0<SPf0007@38h=P201lO7`809RHV0P0_;bl202h^
;P80;Bd]0P0a<C4203De=@80CDe=0P1SHf<205mOG`80EEEE0P1>CTh204E5A@80CTi>0P0l?3`203Ti
>@<0=3@d0P0];Bd402PX:080:RXZ0P0/;2`202l_;`80=3@d0P0i>CT403<c<`80:2PX0P1DE5@205eM
G@809RHV0P0U9BD402HV9P80AdM70P1RHV8206m_K`80?Cdm0P0V9RH2020P8080?Cdm0P1OGel203Ti
>@80:b/[100g=cL2038b<P80:b/[0`0T92@203Lg=`80De=C0P20P8020:6QX@80R8R80P1WIfL205iN
GP80Hf=S0P2;Rh/20;>c/`80^;Rh0P2c/k<20:RXZ080Xj>S0P2XZ:P20:n_[`@0/K6a0P2^[Zh20:RX
Z080XZ:R0P2MWId209^KV`80WYjN0P2WYjL20;6a/@80^[Zj0P30`<020;no_`80_;bl0P2n_[h30;no
_`80_[jn0P2l_;`20;Zj^P80^;Rh0P2i^KT20;Rh^080^KVi0P2[Zj/208f=S@80LG5a0P1/K6`206m_
K`80MgMg0P20P80208J6QP80Rh^;0P2@T90209BDU080VIVI0P2LW9`209jNWP80WinO0P2PX:020::R
XP80YJFU0P2XZ:P20:VYZ@80ZZZZ0P2/[:`20:n_[`D0/;2`102a/K420;>c/`H0];Bd0P2b/[860;6a
/@80/[:b0P2c/k<20;Fe]@@0][Jf:@38h=P2028R8P80:BTY0P0_;bl203<c<`80:BTY0P0Z:RX2038b
<P80@4100P1JFUX2065QH@80GemO0P1@D50204=3@`80ATI6100j>SX3034a<@80:b/[0P0W9bL202`/
;080:BTY0P0Z:RX202`/;080=3@d0P0e=CD203Ph>080:b/[0P0a<C4205YJFP80F5QH0P0];Bd202<S
8`@09RHV0P0l?3`206UYJ@80Hf=S0P0m?Cd202DU9@8092@T0P0j>SX206YZJP80@D510P0/;2`203@d
=080@4100P0f=SH202h^;P<0;bl_0P0[:b/205QHF080Ph>30P2VYZH208V9R@80H61P0P1MGEd2065Q
H@80QhN70P2d];@20<;2`P80[jn_0P2SXj<20:JVYP80/;2`0P2/[:`20;>c/`80/[:b0P2^[Zh20:FU
Y@80YZJV0P2KVi/209bLW080WYjN0P2WYjL20;>c/`80]kNg0P2o_kl40;jn_P80^[Zj0`2o_kl20;fm
_@80^KVi0P2d];@20;Vi^@80];Bd0P2f][H20;Fe]@80YJFU0P29RHT206a/K080I6AT0P1XJ6P207al
O080Ng]k102:RXX208j>SP80Ti>C0P2DU9@209VIV@80X:2P102SXj<40:FUY@80Z:RX0P2YZJT20:JV
YP80[Zj^0P2a/K420:n_[`<0/[:b0P2_[jl20;2`/0@0/k>c0P2d];@20;:b/P80/;2`0P2b/[820;2`
/080/K6a0P2_[jl20;Bd]080]kNg0P2e]KD20;Rh^2T0b>3H0P0P820202/[:`80<S8b0P0];Bd202`/
;080<30`0P0g=cL204a<C0@0GemO0P1EEED204a<C080@d=30P1=CDd203/k>`80>3Ph0`0a<C4202XZ
:P809BDU0P0W9bL402/[:`80;2`/0P0`<30203<c<`@0;Rh^0P0U9BD205ADE080GemO0P0R8R8202DU
9@809RHV0P0T92@204a<C080H61P0P1aLG4203/k>`8092@T0P0P820203dm?@80HF5Q0P0f=SH2034a
<@80=CDe0P0i>CT203<c<`80<30`0`0N7Qh203Ph>080DU9B0P27QhL209nOW`80Shn?0P1WIfL205EE
E@80IFEU0P2;Rh/20;Ng]`80^[Zj0P2`/;020:2PX080Xj>S0P2ZZZX20;6a/@80/;2`0P2b/[840:b/
[080X:2P0P2KVi/209VIV@80WIfM0P2YZJT20:j^[P@0_Kfm0P32`/820;^k^`80_Kfm0`2o_kl40;^k
^`80^KVi0P2j^[X20;Vi^@80^;Rh0P2g]kL20:b/[080Rh^;0P1`L70206e]K@80Kfm_0P1jNWX208:2
PP@0RXZ:0P2<S8`209>CT`80V9RH0P2IVIT20:2PX080WinO0P2NWYh20:BTY080Xj>S0P2YZJT20:NW
Y`80ZJVY0P2[Zj/20:n_[`80/K6a0`2^[Zh20:n_[`H0/[:b0P2c/k<20;Fe]@80/[:b102a/K420;:b
/P80/k>c0P2e]KD20;:b/P@0/k>c7`38h=P001d0b>3H0P0O7al202HV9P80;bl_0P0^;Rh202d];@80
<C4a0P0e=CD204e=C@80Hf=S0P1OGel205EEE@80CTi>0P15ADD204i>CP80?3`l0P0i>CT303@d=080
;Bd]100X:2P202XZ:P80;2`/0P0_;bl203@d=080>CTi100c<c<202PX:080E5AD0P1MGEd202HV9P80
9BDU100V9RH204M7A`80HV9R0P1_Kfl203dm?@809RHV0P0P820203dm?@80GemO0P0i>CT202/[:`@0
=cLg0P0b<S8202/[:`<092@T0P0g=cL205=CD`80P8200P2QXJ4208R8R080IfMW0P1NGUh206=SH`80
Rh^;0P2c/k<20;Rh^080/k>c0P2XZ:P20:>SX`80Z:RX0P2_[jl40;6a/@80[Zj^0P2XZ:P20::RXP80
WIfM0P2KVi/209jNWP80YjNW0P2a/K420;Zj^P80`<300P2o_kl20;bl_080_[jn0`2o_kl20;jn_P80
_;bl0P2j^[X20;Rh^080^KVi0P2h^;P20;Vi^@80Zj^[0P2=SHd2075aL@80K6a/0P1_Kfl207MgM`80
P8200P26QXH208^;R`80T92@0P2DU9@209VIV@80W9bL0P2NWYh209nOW`80X:2P0P2RXZ820:FUY@80
Z:RX0P2YZJT20:ZZZP80[:b/0P2_[jl50;2`/0@0/K6a0P2c/k<60;Bd]080/[:b1P2a/K420;:b/P80
/k>c0P2e]KD40;Jf]RT0b>3H0P0R8R8202TY:@80;bl_0P0c<c<202TY:@80:RXZ0P0b<S820410@080
FUYJ0P1QHF4205mOG`80D51@0P13@d<204I6AP@0>SXj0`0a<C4202/[:`809bLW0P0/;2`202TY:@80
:RXZ0P0/;2`203@d=080=CDe0P0h>3P202/[:`80<C4a0P1JFUX205QHF080;Bd]0P0S8b<402HV9P80
?3`l0P1YJFT206=SH`80?Cdm0P0U9BD202@T9080>SXj0P1ZJVX20451@@80;2`/0P0d=3@20410@080
=SHf0P0^;Rh302l_;`80:b/[0P1HF5P208>3P`80YZJV0P29RHT2061PH080GEeM0P1QHF4208N7Q`80
];Bd0P32`/820:n_[`80Xj>S0P2VYZH20;2`/080[:b/0P2c/k<20;:b/P80[Zj^0P2UYJD20:JVYP80
Vi^K0P2LW9`209jNWP80YjNW0P2c/k<20;Ng]`80_kno102n_[h20;Zj^P<0_kno0P2m_Kd20;Vi^@80
];Bd0P2i^KT20;Bd]080][Jf0P2e]KD20:FUY@80RHV90P1/K6`206ATI080J6QX0P1lO7`207]kN`@0
RXZ:0P2>SXh209>CT`80U9BD0P2IVIT20:2PX0@0Xj>S102UYJD20:RXZ080ZJVY0P2VYZH20:j^[P80
/K6a0P2_[jl30;:b/P80[jn_0P2`/;040;>c/`80];Bd0P2b/[820;2`/080/[:b0P2`/;020;6a/@80
[jn_0P2d];@20;Ng]`80]KFe0P2h^;PY0<SPf080820P0P0[:b/2038b<P80;Bd]0P0/;2`2030`<080
=cLg0P1<C4`405mOG`80EEEE0P1<C4`204=3@`80CDe=0P0k>c/203Ph>0<0<C4a0P0Z:RX202DU9@80
9bLW100[:b/202`/;080<30`0P0c<c<402h^;P809BDU0P1DE5@205mOG`808R8R0P0U9BD202HV9P80
92@T0P1<C4`2061PH080LG5a0P0k>c/202@T9080820P0P0m?Cd2065QH@80=SHf0P0a<C4203De=@80
>CTi0P0c<c<2030`<0<07QhN0P0h>3P2059BDP80QhN70P2OWil208n?S`80IfMW0P1EEED206EUI@80
Rh^;0P2g]kL20;Zj^P80/;2`0P2PX:020:>SX`80ZZZZ0P2a/K420;2`/080/[:b102/[:`20:2PX080
Vi^K0P2IVIT209fMW@80ZJVY0P2^[Zh40;fm_@80`/;20P2k^k/20;fm_@<0_kno102k^k/20;Vi^@80
^[Zj0P2i^KT20;Rh^080]kNg0P2/[:`208^;R`80L71`0P1]KFd206m_K`80NWYj0P22PX8408Z:RP80
S8b<0P2CTi<209RHV080VIVI0P2PX:0209nOW`80WYjN0P2TY:@20:>SX`80ZJVY0P2WYjL20:VYZ@80
Zj^[0P2_[jl20;6a/@<0[Zj^0P2_[jl60;:b/P80/k>c0P2e]KD20;:b/P@0/K6a0P2b/[820;>c/`80
]KFe0P2b/[840;>c/al0b>3H000M0<SPf0808B4Q0P0V9RH202`/;080:b/[0P0Y:BT402XZ:P80=3@d
0P13@d<205UIF@80Jf][0P1VIVH205]KF`80DU9B0P1@D50204M7A`<0?Shn0P0d=3@202/[:`80:RXZ
0P0/;2`202d];@80;bl_0P0g=cL203`l?080=3@d0P0_;bl202<S8`80Bd];0P1iNGT202PX:0809bLW
0P0T92@202`/;080=cLg0P1LG5`207UiN@80>3Ph0P0/;2`202<S8`809bLW0P1XJ6P206EUI@80=3@d
0P0Q8B4202`/;080>SXj0P0d=3@302/[:`8092@T0P0[:b/206=SH`80V9RH0P2ATI4207YjNP80HF5Q
0P1BDU8206i^KP80Ti>C0P2][Jd20;jn_P80[jn_0P2PX:020:BTY080[:b/1P2][Jd20:^[Z`80YZJV
0P2PX:0209nOW`80X:2P0P2XZ:P20;:b/P80^[Zj0P30`<020;jn_P80^k^k0P2j^[X30;^k^`@0_;bl
0P2g]kL20;:b/P80/K6a0P2b/[820:n_[`80[Jf]0P2YZJT20::RXP80Shn?0P1nOWh208>3P`80S8b<
0P2CTi<209RHV080VYZJ0P2KVi/209jNWP80X:2P0P2SXj<20:FUY@80YZJV102WYjL40:RXZ080ZJVY
0P2/[:`20:j^[PD0[jn_0P2`/;040;:b/P80/K6a0P2c/k<20;Fe]@80];Bd0P2c/k<40;6a/@80/k>c
0P2e]KD20;Ng]`@0^;Rh:@38h=P202HV9P808B4Q0P0U9BD203Lg=`809BDU0P0X:2P202l_;`80>3Ph
0P18B4P205=CD`80IVIV0P1^KVh205IFEP80D51@0P1FEUH204=3@`<0?Shn0P0a<C4402`/;0@0;Bd]
0P0a<C4203hn?P80>3Ph0P0c<c<202d];@80:b/[0P17AdL206m_K`80;bl_0P0W9bL202PX:0809RHV
0P0h>3P206ATI080MGEe0P0m?Cd202TY:@809BDU0P0/;2`205aLG080IVIV0P0Z:RX202/[:`80<30`
0P0h>3P2038b<P<09RHV0P0T92@202h^;P80I6AT0P2>SXh209ZJVP80Lg=c0P1OGel205UIF@80JFUY
0P2DU9@20;Bd]080^KVi0P2/[:`20:2PX080ZJVY0P2VYZH20;2`/080Zj^[0P2^[Zh20:VYZ@80YJFU
0P2OWil20:6QX@80WYjN0P2WYjL20;2`/080_Kfm0P2o_kl20;jn_P@0^[Zj0`2i^KT20;no_`80_;bl
0P2g]kL20;:b/P80][Jf0P2b/[820;2`/080];Bd0P2/[:`20::RXP80S8b<0P1lO7`208F5Q@80Rh^;
0P2CTi<209NGU`80UYJF0P2NWYh209nOW`80XZ:R0P2QXJ420:>SX`80Y:BT0P2WYjL20:BTY080YZJV
0P2_[jl20:VYZ@80Z:RX0P2^[Zh20;2`/0<0[Zj^102a/K420;:b/P80/K6a0P2c/k<20;Jf]P80]kNg
0P2_[jl20;Fe]@80/[:b0P2_[jl40;Jf]P@0]kNg:@38h=P201lO7`8092@T0P0^;Rh602/[:`809RHV
0P0e=CD20451@@80G5aL0P1/K6`206MWI`80Fe]K0P1BDU8204e=C@80BTY:0`0n?Sh203@d=0@0:b/[
0P0/;2`202h^;P80;bl_0P0i>CT203hn?P80=CDe0P0`<30202<S8`80BTY:0P1hN7P202HV9P80:2PX
0P0T92@202TY:@80>c/k0P1EEED207inOP80<C4a0P0^;Rh202LW9`8092@T0P1YJFT206EUI@80<30`
0P0O7al202/[:`80>CTi0P0h>3P302XZ:P80:BTY0P0U9BD206EUI@80UIFE0P2CTi<207emO@80GUiN
0P1DE5@2071`L080Ti>C0P2[Zj/20<30`080/;2`0P2NWYh20:RXZ080YjNW0P2`/;020;6a/@80YJFU
0P2[Zj/20:RXZ080XJ6Q0P2KVi/20:>SX`80YZJV0P2e]KD20;Zj^P80`<300P32`/820;Ng]`80_[jn
0`2l_;`20;Ng]`80_kno0P2i^KT20;6a/@80[jn_0P2c/k<20:j^[P80[:b/0P2YZJT20::RXP80Shn?
0P1nOWh208F5Q@80QXJ60P2BTY8209VIV@80VYZJ102NWYh20:2PX080XZ:R0P2SXj<20:NWY`@0YZJV
0P2YZJT20:NWY`80ZZZZ0P2/[:`20:f][@D0[Zj^0P2a/K420;>c/`80/K6a0P2b/[840;Fe]@80/[:b
0P2f][H20:j^[P80/[:b0P2e]KD20;>c/`80^KVi102h^;PO0<SPf0007@38h=P2024Q8@809RHV0P0/
;2`202/[:`80:BTY100Z:RX203@d=080@d=30P1IFET206][J`80IVIV0P1KFe/2059BDP80D51@0P17
AdL303hn?P80=3@d0P0[:b/202XZ:P80;2`/0P0];Bd202l_;`80=cLg0P0l?3`203@d=080;bl_0P0S
8b<204];B`80NGUi0P0X:2P202LW9`8092@T0P0/;2`203Lg=`80G5aL0P1iNGT203Ph>080;2`/0P0S
8b<202LW9`80J6QX0P1UIFD203@d=0808B4Q0P0/;2`203Xj>P80=3@d0`0[:b/202@T9080:b/[0P1S
Hf<209RHV080TI6A0P1jNWX2065QH@80DU9B0P1^KVh209>CT`80[Jf]0P2n_[h20:n_[`80X:2P0P2T
Y:@20:b/[0H0[Jf]0P2[Zj/20:JVYP80X:2P0P2OWil20:2PX080Z:RX0P2b/[820;Zj^P80`<300P2n
_[h20;^k^`80^[Zj0`2k^k/40;bl_080]kNg0P2b/[820;6a/@80/[:b0P2_[jl20:f][@80ZJVY0P2R
XZ8208n?S`80OWin0P23Ph<208b<S080Ti>C0P2HV9P209ZJVP80Vi^K0P2NWYh20:2PX080Xj>S0P2U
YJD20:JVYP@0YjNW102XZ:P20:VYZ@80[:b/0P2^[Zh50:n_[`80/;2`102b/[820;6a/@80/k>c0P2e
]KD20;Bd]080/k>c102a/K420;>c/`80]KFe0P2g]kL40;Rh^2T0b>3H0P0V9RH2024Q8@809BDU0P0g
=cL202DU9@80:2PX0P0_;bl203Ph>080B4Q80P1CDe<206IVIP80KVi^0P1FEUH2051@D080EUIF0P13
@d<303hn?P80<C4a100/;2`402d];@80<C4a0P0n?Sh203Ph>080<c<c0P0];Bd202/[:`80AdM70P1_
Kfl202l_;`809bLW0P0X:2P202HV9P80>3Ph0P1TI6@207EeM@80?Cdm0P0Y:BT202DU9@80;2`/0P1L
G5`206IVIP80:RXZ0P0[:b/2030`<080>3Ph0P0b<S8302HV9P8092@T0P0^;Rh206ATI080SXj>0P2J
VYX207=cL`80GemO0P1IFET206UYJ@80U9BD0P2d];@20;Vi^@80[:b/0P2PX:020:VYZ@80YZJV0P2`
/;020:^[Z`80[Zj^0P2YZJT20:FUY@80WinO0P2QXJ4209jNWP80YjNW0P2`/;020;fm_@80_kno0P2n
_[h40;Zj^P<0^KVi0P2o_kl20;bl_080]kNg0P2b/[820;Jf]P80/[:b0P2`/;020;Bd]080[:b/0P2R
XZ8208b<S080O7al0P25QHD208^;R`80Ti>C0P2GUiL209JFUP80WYjN0P2OWil20::RXP80XJ6Q0P2S
Xj<20:BTY080YjNW0P2TY:@20:JVYP80[jn_0P2YZJT20:RXZ080[Zj^0P2`/;030:j^[P@0/K6a0P2b
/[820;6a/@80/k>c0P2f][H20;Ng]`80[jn_0P2e]KD20;:b/P80[jn_102f][H40;Ng]bT0b>3H0P0O
7al202@T9080;Rh^1P0[:b/202HV9P80=CDe0P11@D4205aLG080K6a/0P1WIfL205]KF`80DU9B0P1=
CDd204Y:BP<0?Shn0P0d=3@402/[:`80;2`/0P0^;Rh202l_;`80>CTi0P0n?Sh203De=@80<30`0P0S
8b<204Y:BP80N7Qh0P0V9RH202PX:08092@T0P0Y:BT203/k>`80EEEE0P1nOWh2034a<@80;Rh^0P0W
9bL202@T9080JFUY0P1UIFD2030`<0807alO0P0[:b/203Ti>@80>3Ph0`0Z:RX202TY:@809BDU0P1U
IFD209FEU@80Ti>C0P1mOGd205iNGP80E5AD0P1`L70209>CT`80Zj^[0P30`<020;2`/080WYjN0P2X
Z:P20:NWY`80/;2`0P2a/K420:FUY@80Zj^[0P2XZ:P20:6QX@80Vi^K0P2SXj<20:JVYP80]KFe0P2j
^[X20<30`080`/;20P2g]kL20;jn_P<0_;bl0P2g]kL20;no_`80^KVi0P2a/K420:n_[`80/k>c0P2^
[Zh20:b/[080ZJVY0P2RXZ8208n?S`80OWin0P25QHD208J6QP80TY:B0P2IVIT209ZJVP@0WYjN0P2P
X:020::RXP80Xj>S0P2WYjL40:JVYP80ZJVY0P2WYjL20:ZZZP80[:b/0P2][Jd50:j^[P80/K6a0P2c
/k<20;6a/@80/[:b102e]KD20;:b/P80][Jf0P2^[Zh20;:b/P80]KFe0P2c/k<20;Vi^@@0^;Rh7`38
h=P001d0b>3H0P0^;Rh402LW9`80;Bd]0P0f=SH2028R8P80=cLg0P0l?3`204E5A@80BTY:0P1ADE42
061PH0@0J6QX0P16ATH204=3@`<0?clo0P0f=SH202h^;P80:RXZ0P0Y:BT202/[:`80;bl_0P0f=SH2
03/k>`80<30`0P0W9bL202PX:080@T920P1cLg<203`l?08092@T0P0W9bL202l_;`80>c/k0P1JFUX2
07=cL`80>CTi0P0j>SX202XZ:P809bLW0P1:BTX2079bLP80=SHf0P0i>CT2028R8P80=SHf0P0^;Rh3
02TY:@80820P0P0R8R8204U9B@80Lg=c0P23Ph<208F5Q@80Jf][0P1CDe<205iNGP80M7Ad0P2DU9@2
0:j^[P80_Kfm0P2SXj<40:BTY080YZJV102YZJT20:NWY`80Xj>S0P2OWil209jNWP80XJ6Q0P2XZ:P2
0;6a/@80^[Zj0P30`<020;no_`80_;bl0P2i^KT30;Ng]`80^[Zj0P2k^k/20;Jf]P@0/;2`0P2c/k<2
0;Bd]080]kNg0P2a/K420:ZZZP80WinO0P2FUYH209BDU080UIFE0P2HV9P209^KV`80WYjN0P2QXJ42
0:>SX`80Y:BT0P2UYJD:0:JVYP80YjNW0P2YZJT20:ZZZP80Zj^[0P2][Jd30:j^[P80/;2`0P2b/[82
0;6a/@80/;2`0P2a/K440;>c/`@0/[:b1P2a/K420;Bd]0@0^;Rh:@38h=P202LW9`80:BTY0P0Z:RX2
03@d=080=cLg0P0S8b<203@d=080AdM70P1;Bd/204A4A080CTi>0P1XJ6P207QhN080EeMG0P19BDT2
04m?C`<0B4Q80P0e=CD2034a<@809bLW0P0X:2P202l_;`80:2PX0P0h>3P203dm?@80<C4a0P0U9BD2
02/[:`80A4A40P1bLW8203<c<`80:RXZ0P0X:2P202/[:`80?clo0P1NGUh2079bLP80?Shn0P0f=SH2
02TY:@80:b/[0P11@D4207emO@80>SXj0P0Y:BT202@T9080;Bd]0P0d=3@302h^;P808B4Q0P0R8R82
03hn?P80MWIf0P2<S8`2092@T080JFUY0P1FEUH205UIF@80LW9b0P2@T9020;Vi^@80^;Rh0P2OWil2
0:2PX0@0YjNW0P2UYJD20:RXZ080ZZZZ0P2UYJD209fMW@80WinO0P2QXJ420:VYZ@80[jn_1P2n_[h2
0;fm_@80^[Zj0`2e]KD20<30`080^[Zj0P2g]kL20:f][@80[jn_0P2b/[820;Rh^080[jn_0P2^[Zh2
0;:b/P80Z:RX0P2NWYh409FEU@80V9RH102PX:020:6QX@@0Xj>S0P2WYjL40:FUY@80YjNW0P2SXj<2
0:NWY`80ZJVY0P2WYjL20:VYZ@@0Zj^[0`2^[Zh20:n_[`80];Bd102a/K420:n_[`80/K6a102b/[82
0;6a/@@0/;2`0P2d];@20;:b/P@0^;Rh:@38h=P203<c<`8092@T0P0U9BD202PX:080=SHf0P0S8b<2
03Ti>@80?clo0P18B4P204];B`80C4a<0P1PH60206YZJP80Jf][0P17AdL204I6AP<0@T920P0b<S82
03<c<`80:b/[0P0Y:BT202PX:080<C4a0P0j>SX203dm?@80;Rh^0P0/;2`202TY:@80@4100P1iNGT2
03`l?0809bLW0P0X:2P202l_;`80?3`l0P1GEeL207UiN@@0>CTi0P0];Bd202<S8`80C4a<0P1cLg<2
03Ph>080?Cdm0P0W9bL203<c<`D0:BTY0P0K6a/202@T9080BTY:0P1`L70207inOP80Ph>30P1]KFd2
05EEE@80Fe]K0P1`L70209RHV080[:b/0P32`/8209nOW`80Z:RX0P2QXJ420:ZZZP80YZJV0P2XZ:P2
0:ZZZP80Z:RX0P2PX:0209fMW@80Xj>S0P2VYZH20;:b/P80]KFe0P2l_;`20<;2`P80]kNg0P2o_kl3
0;Jf]P80]KFe0P2m_Kd20;Rh^0@0[jn_0P2f][H20;:b/P80_;bl0P2g]kL20:^[Z`80W9bL0P2ATI44
09RHV0@0Vi^K0P2MWId40:6QX@80YZJV0P2[Zj/20:FUY@@0YjNW0P2YZJT20:NWY`80Z:RX0P2ZZZX2
0:^[Z`80ZZZZ0P2b/[830:n_[`@0/;2`102b/[820:j^[P80];Bd0P2c/k<40;6a/@80[jn_0P2b/[82
0:n_[`80^;Rh0P2i^KT20;Rh^1l0b>3H000M0<SPf080;Rh^100W9bL202d];@80=SHf0P0R8R8203Lg
=`80?3`l0P15ADD204Y:BP80DE5A0P1PH60406QXJ080ATI60P13@d<303lo?`80=SHf0P0^;Rh202XZ
:P80:BTY0P0[:b/202l_;`80=SHf0P0k>c/2030`<0809bLW0P0X:2P20492@P80Lg=c0P0l?3`202@T
90809bLW0P0_;bl203/k>`80FUYJ0P1cLg<203Ti>@80>SXj0P0Z:RX202LW9`80BTY:0P1bLW8203Hf
=P80>CTi0P0R8R8203Hf=P80;Rh^0`0Y:BT2020P80808R8R0P19BDT207=cL`80Ph>30P25QHD206][
J`80De=C0P1NGUh207AdM080U9BD0P2^[Zh20;fm_@80Xj>S102TY:@20:JVYP@0ZJVY0P2WYjL20:>S
X`80WinO0P2NWYh20:6QX@80Z:RX0P2a/K420;Zj^P80`<300P2o_kl20;bl_080^KVi0`2g]kL20;Zj
^P80^k^k0P2f][H40;2`/080/k>c0P2d];@20;Ng]`80/K6a0P2ZZZX209nOW`80UYJF0P2DU9@209FE
U@80V9RH0P2KVi/209jNWP80XJ6Q0P2SXj<20:BTY080YJFU2P2VYZH20:NWY`80ZJVY0P2ZZZX20:^[
Z`80[Jf]0`2^[Zh20;2`/080/[:b0P2a/K420;2`/080/K6a102c/k<40;:b/PH0/K6a0P2d];@40;Rh
^2T0b>3H0P0W9bL202TY:@80:RXZ0P0d=3@203Lg=`808b<S0P0d=3@204M7A`80Bd];0P14A4@204i>
CP80J6QX0P1hN7P205MGE`80BDU90P1?Cdl304Q8B080=CDe0P0a<C4202LW9`80:2PX0P0_;bl202PX
:080>3Ph0P0m?Cd2034a<@809BDU0P0[:b/204A4A080LW9b0P0c<c<202XZ:P80:2PX0P0[:b/203lo
?`80GUiN0P1bLW8203hn?P80=SHf0P0Y:BT202/[:`80@D510P1mOGd203Xj>P80:BTY0P0T92@202d]
;@80=3@d0`0^;Rh2024Q8@808R8R0P0n?Sh207IfMP80S8b<0P2@T90206UYJ@80EUIF0P1IFET2079b
LP80T92@0P2i^KT20;Rh^080WinO0P2PX:040:NWY`80YJFU0P2XZ:P20:ZZZP80YJFU0P2MWId209nO
W`80XJ6Q0P2YZJT20:n_[`H0_[jn0P2m_Kd20;Zj^P<0]KFe0P30`<020;Zj^P80]kNg0P2][Jd20:n_
[`80/[:b0P2h^;P20:n_[`80[Zj^0P2b/[820:RXZ080WYjN102EUID209RHV0@0X:2P0P2QXJ440:>S
X`80YjNW102UYJD20:NWY`80Xj>S0P2WYjL20:VYZ@80YjNW0P2YZJT40:^[Z`<0[Zj^0P2_[jl20;Bd
]0@0/K6a0P2_[jl20;6a/@@0/[:b0P2a/K440;2`/080];Bd0P2b/[840;Rh^2T0b>3H0P0c<c<202@T
90809BDU0P0X:2P203Hf=P808b<S0P0i>CT203lo?`80B4Q80P1;Bd/204a<C080H61P0P1ZJVX206][
J`80AdM70P16ATH30492@P80<S8b0P0c<c<202/[:`80:BTY0P0X:2P2034a<@80>SXj0P0m?Cd202h^
;P80;2`/0P0Y:BT20410@080NGUi0P0l?3`202LW9`80:2PX0P0_;bl203`l?080EeMG0P1iNGT403Ti
>@80;Bd]0P0S8b<204a<C080Lg=c0P0h>3P203dm?@809bLW0P0c<c<502TY:@806a/K0P0T92@204Y:
BP80L71`0P1nOWh208>3P`80KFe]0P1EEED205]KF`80L71`0P2HV9P20:b/[080`/;20P2OWil20:RX
Z080XJ6Q0P2ZZZX20:JVYP80Z:RX0P2ZZZX20:RXZ080X:2P0P2MWId20:>SX`80YZJV0P2b/[820;Fe
]@80_;bl0P32`/820;Ng]`80_kno0`2f][H20;Fe]@80_Kfm0P2h^;P40:n_[`80][Jf0P2b/[820;bl
_080]kNg0P2[Zj/209bLW080TI6A102HV9P409^KV`80WIfM102QXJ420:JVYP80Zj^[0P2UYJD40:NW
Y`80ZJVY0P2WYjL20:RXZ080ZZZZ0P2[Zj/20:ZZZP80/[:b0`2_[jl40;2`/0@0/[:b0P2^[Zh20;Bd
]080/k>c102a/K420:n_[`80/[:b0P2_[jl20;Rh^080^KVi0P2h^;PO0<SPf0007@38h=P203/k>`80
;Rh^0P0U9BD202l_;`80@4100P0Q8B4204=3@`80@D510P10@40203De=@80<C4a0P1DE5@206m_K`80
MgMg0P0i>CT203dm?@<0@T920P0j>SX2034a<@80:BTY0P0U9BD202PX:080;Rh^0P0e=CD203Ti>@80
;Bd]0P0Q8B4202h^;P80>CTi0P1UIFD2059BDP808B4Q0P0Z:RX2034a<@80@d=30P1FEUH206IVIP80
>SXj0P15ADD2038b<P80;bl_0P0V9RH205aLG080OWin0P0n?Sh201TI6@80<C4a0P0Y:BT302DU9@80
820P0P0Q8B42038b<P80BTY:0P1^KVh208Z:RP80N7Qh0P1OGel205UIF@80GemO0P1kNg/209JFUP80
`l?30P2XZ:P20:FUY@80WYjN0P2QXJ440:BTY080Xj>S0P2PX:0209fMW@80WYjN0P2QXJ420:RXZ080
/;2`0P2i^KT40<30`080_Kfm0P2i^KT30;Fe]@80^;Rh0P2j^[X20;Bd]0@0[Zj^0P2`/;020;>c/`80
]KFe0P2_[jl40:VYZ@80ZZZZ0P2SXj<209bLW080VYZJ0P2KVi/209nOW`80Y:BT202UYJD20:BTY0H0
Xj>S0P2VYZH40:RXZ080YjNW0P2ZZZX30:f][@80/;2`0P2b/[820;2`/0@0[jn_0P2`/;040;6a/@@0
/[:b0P2`/;020:j^[P80/[:b0P2h^;P20;Vi^BT0b>3H0P0f=SH203@d=08092@T0P0X:2P203dm?@80
;2`/0P0j>SX203lo?`@0>c/k0P0c<c<204M7A`80KFe]0P1aLG420492@P80>CTi0`16ATH203Hf=P80
=3@d0P0U9BD202LW9`80;Rh^0P0/;2`203`l?080=cLg0P0Y:BT202PX:0809bLW0P0g=cL206][J`80
CDe=0P0W9bL202XZ:P80;2`/0P0o?cl405eMG@80>SXj100k>c/202PX:080:RXZ0P1MGEd207EeM@80
?Shn0P0X:2P202`/;080:2PX0`0U9BD2020P8080:BTY0P0[:b/204U9B@80N7Qh0P27QhL207EeM@80
Hf=S0P1LG5`206IVIP80NGUi0P2JVYX20;^k^`80/;2`0P2QXJ420:2PX080Y:BT0P2SXj<20:FUY@80
XZ:R0P2LW9`409jNWP80Xj>S0P2VYZH20:n_[`80_;bl0P2n_[h20<;2`P80_;bl0P2g]kL30;Bd]080
_;bl0P2g]kL20;Rh^080/[:b0P2ZZZX20:j^[P80^KVi0P2e]KD20:b/[080ZJVY102VYZH20:NWY`80
Vi^K0P2HV9P209ZJVP80XJ6Q0P2TY:@20:RXZ080XZ:R0P2TY:@20:JVYP@0Y:BT0P2QXJ420:JVYP80
Xj>S0P2YZJT40:NWY`80[:b/0`2[Zj/20;Bd]080/[:b0P2][Jd60;2`/080/[:b0P2`/;020;:b/P80
];Bd102^[Zh20;6a/@80][Jf0P2l_;`Y0<SPf080>SXj0P0[:b/202HV9P80<C4a0P0o?cl2020P8080
A4A4100k>c/203Ti>@80<30`0P1EEED2071`L080MgMg0P0k>c/203hn?P<0@T920P0o?cl2038b<P80
:2PX0P0W9bL202@T9080<c<c0P0b<S8203Ti>@80;Rh^0P0M7Ad202l_;`80>3Ph0P1SHf<204e=C@80
7AdM0P0[:b/202h^;P80@D510P1MGEd206ATI080>CTi0P17AdL2030`<080;bl_0P0U9BD205YJFP80
Ogmo0P0o?cl201LG5`80=3@d0P0Z:RX302LW9`8092@T0P0S8b<2034a<@80BDU90P1bLW8208^;R`80
M7Ad0P1NGUh205QHF080GUiN0P22PX8209:BTP80alO70P2TY:@20:RXZ080VYZJ0P2SXj<20:FUY@80
Xj>S0P2OWil20:2PX0@0WIfM0P2SXj<20:VYZ@80/;2`0P2l_;`20<30`080`L710P2j^[X20;^k^`<0
]KFe0P2h^;P20;Vi^@80];Bd0P2^[Zh40;6a/@80/[:b0P2c/k<20:f][@80ZJVY0P2WYjL20:n_[`80
YJFU0P2MWId409^KV`80WinO0P2VYZH40:FUY@80Xj>S102TY:@20:2PX0@0Xj>S102VYZH20:RXZ080
YjNW0P2XZ:P30:b/[080/k>c0P2a/K420;Bd]080[jn_0P2][Jd20;6a/@80[jn_0P2a/K420;Bd]080
/[:b0P2`/;020:j^[P80/[:b0P2h^;P20;Zj^Ql0b>3H000M0<SPf080>c/k0P0^;Rh202DU9@80;bl_
0P10@402024Q8@80@d=30P11@D420410@080=CDe0P0a<C4205ADE080Kfm_0P1gMgL203Ti>@80?Cdm
0`12@T8203Xj>P80<C4a0P0Y:BT202DU9@80:2PX0P0^;Rh203De=@80>CTi0P0];Bd2024Q8@80;Rh^
0P0i>CT206EUI@80DU9B0P0Q8B4202XZ:P80<C4a0P13@d<205IFEP80IVIV0P0j>SX204E5A@80<S8b
0P0_;bl202HV9P80G5aL0P1nOWh203hn?P806ATI0P0a<C4202TY:@<09BDU0P0P8202024Q8@80<S8b
0P1:BTX206i^KP80RXZ:0P1hN7P205mOG`80FEUI0P1OGel207]kN`80UYJF0P33`l<20:RXZ080YJFU
0P2NWYh20:6QX@@0Y:BT0P2SXj<20:2PX080WIfM0P2NWYh20:6QX@80Z:RX0P2`/;020;Vi^@@0`<30
0P2m_Kd20;Vi^@<0]KFe0P2h^;P20;Zj^P80];Bd102^[Zh20;2`/080/k>c0P2e]KD20:n_[`@0ZJVY
0P2ZZZX20:>SX`80W9bL0P2JVYX209^KV`80WinO0P2TY:@80:FUY@80Y:BT1P2SXj<20:JVYP@0Z:RX
0P2WYjL20:ZZZP<0[Jf]0P2`/;020;:b/P80/;2`102_[jl20;2`/0@0/K6a102b/[820;2`/080[Zj^
0P2b/[820;Rh^080^KVi:@38h=P203Hf=P80=3@d0P0T92@202PX:080?Cdm0P0/;2`203Xj>P80?clo
100k>c/203<c<`80AdM70P1]KFd2075aL@80@T920P0i>CT304I6AP80=SHf0P0d=3@202DU9@809bLW
0P0^;Rh202`/;080?3`l0P0g=cL202TY:@80:2PX0P0W9bL203Lg=`80Jf][0P1=CDd202LW9`80:RXZ
0P0/;2`203lo?`@0GEeM0P0j>SX403/k>`80:2PX0P0Z:RX205eMG@80MGEe0P0n?Sh202PX:080;2`/
0P0X:2P302DU9@80820P0P0Y:BT202/[:`80BDU90P1hN7P208N7Q`80MGEe0P1SHf<205aLG080IVIV
0P1iNGT209ZJVP80^k^k0P2`/;020:6QX@80X:2P0P2TY:@20:>SX`80YJFU0P2RXZ8209bLW0@0WYjN
0P2SXj<20:JVYP80[jn_0P2l_;`20;jn_P80`/;20P2l_;`20;Ng]`<0];Bd0P2l_;`20;Ng]`80^;Rh
0P2b/[820:ZZZP80[Zj^0P2i^KT20;Fe]@80[:b/0P2YZJT40:JVYP80YjNW0P2KVi/209RHV080VYZJ
0P2QXJ420:BTY080Z:RX0P2RXZ820:BTY080YZJV102TY:@20:6QX@80YZJV0P2SXj<20:VYZ@@0YjNW
0P2/[:`30:^[Z`80];Bd0P2b/[820:f][@H0/;2`0P2b/[820;2`/080/[:b0P2d];@40:j^[P80/K6a
0P2f][H20;bl_2T0b>3H0P0j>SX202/[:`809RHV0P0a<C4203lo?`80820P0P14A4@403/k>`80>CTi
0P0`<30205EEE@80L71`0P1gMgL203/k>`80?Shn0`12@T8203lo?`80<S8b0P0X:2P202LW9`8092@T
0P0c<c<2038b<P80>CTi0P0^;Rh201dM7@80;bl_0P0h>3P206=SH`80CDe=0P0M7Ad202/[:`80;Rh^
0P11@D4205eMG@80I6AT0P0i>CT204M7A`80<30`0P0_;bl202DU9@80FUYJ0P1oOgl203lo?`805aLG
0P0d=3@202XZ:P<09bLW0P0T92@202<S8`80<C4a0P19BDT2079bLP80Rh^;0P1dM7@205iNGP80F5QH
0P1NGUh208:2PP80TY:B0P37alL20:BTY080Z:RX0P2JVYX20:>SX`80YJFU0P2SXj<209nOW`80X:2P
102MWId20:>SX`80ZJVY0P2`/;020;bl_080`<300P31`L420;Zj^P80^k^k0`2e]KD20;Rh^080^KVi
0P2d];@20:j^[P@0/K6a0P2b/[820;>c/`80[Jf]0P2YZJT20:NWY`80[jn_0P2UYJD209fMW@@0Vi^K
0P2OWil20:JVYP@0YJFU0P2SXj<40:BTY080X:2P102SXj<40:JVYP80Z:RX0P2WYjL20:RXZ0<0[:b/
0P2c/k<20;6a/@80];Bd0P2_[jl20:f][@80/K6a0P2_[jl20;6a/@80];Bd0P2b/[820;2`/080[Zj^
0P2b/[820;Rh^080^[Zj7`38h=P001d0b>3H0P0o?cl204U9B@80;Bd]0P0_;bl2034a<@80=3@d0P0e
=CD203@d=080<S8b0P0];Bd202/[:`80;Rh^0P0k>c/206UYJ@80Kfm_0P1TI6@304m?C`80@4100P0c
<c<202XZ:P809RHV0P0X:2P202d];@80=CDe0P0j>SX202l_;`8092@T0P0/;2`203@d=080FEUI0P1Q
HF4202@T90809bLW0P0_;bl204=3@`80CTi>0P1ADE4203Lg=`80>c/k100c<c<202HV9P80A4A40P1c
Lg<206][J`80?clo0P0];Bd202<S8`<08B4Q0P0N7Qh201lO7`808b<S0P0a<C4205ADE080Ng]k0P23
Ph<207moO`80Kfm_0P1VIVH206m_K`80Ogmo0P2YZJT20:b/[080[Jf]0P2VYZH20::RXP80WinO0P2P
X:020:6QX@80X:2P0P2OWil20:2PX080XZ:R0P2YZJT20;2`/080^;Rh102o_kl20;bl_080^KVi0`2g
]kL20;Zj^P80^k^k0P2d];@20:b/[080YjNW0P2QXJ420:^[Z`80^[Zj0P2f][H20:n_[`80[:b/0P2Y
ZJT20:JVYP80XZ:R0P2NWYh209^KV`80WIfM0P2PX:020::RXP80Xj>S0P2UYJD20:JVYP80Y:BT102Q
XJ420::RXP80Y:BT0P2WYjL40:JVYP80ZZZZ0`2][Jd20:n_[`80/;2`0P2_[jl40:j^[P80[jn_0P2a
/K420;:b/P80/k>c0P2d];@20;:b/P80/K6a0P2e]KD20;Vi^@80^[Zj:@38h=P20410@080Cdm?0P0[
:b/202@T9080<c<c0P0g=cL203dm?@80;bl_0P0b<S8202d];@80;Rh^0P0g=cL20492@P80Jf][0P1X
J6P206EUI@<0AdM70P0f=SH203/k>`80:RXZ0P0U9BD2028R8P80:b/[0P0k>c/203Lg=`80;Rh^0P0V
9RH202TY:@80=cLg0P1IFET206ATI080:RXZ0P0U9BD202XZ:P80AdM70P1ADE4205QHF080>CTi0P10
@40204=3@`80;bl_0P0W9bL203`l?080N7Qh0P1aLG420451@@80<30`0P0S8b<301dM7@807QhN100P
8202038b<P80De=C0P1bLW8207IfMP80OWin0P1/K6`206=SH`80JVYZ0P23Ph<209jNWP80];Bd0P2^
[Zh20::RXP80WIfM102QXJ420:2PX080WinO102QXJ420:2PX080YZJV0P2][Jd20;bl_080^k^k102n
_[h20;Fe]@<0]kNg0P2i^KT20;Ng]`80];Bd0P2/[:`209bLW080XZ:R0P2f][H20;Vi^@80][Jf0P2/
[:`20:>SX`80YjNW0P2VYZH20:BTY080Vi^K102JVYX209bLW080XJ6Q0P2VYZH20:VYZ@80Y:BT0P2Q
XJ420:>SX`80XZ:R0P2NWYh20:BTY080ZJVY0P2WYjL20:JVYP80Z:RX0`2][Jd20;2`/080[Jf]0P2^
[Zh20:f][@80[Zj^0P2_[jl20;6a/@80/[:b102d];@20;6a/@80/[:b0P2d];@20;Rh^080_[jn:@38
h=P204I6AP80AdM70P0a<C4403<c<`80<S8b0P0d=3@203Hf=P80=CDe0P0`<30202/[:`80;bl_0P0h
>3P2069RHP80JVYZ0P1UIFD304M7A`80?3`l0P0/;2`402TY:@809bLW100];Bd203hn?P80;Rh^0P0X
:2P202TY:@80<c<c0P1OGel206QXJ0808b<S0P0X:2P2034a<@80@4100P1CDe<204Y:BP80=cLg0P0j
>SX2038b<P80=3@d0P0Z:RX204M7A`80K6a/0P1WIfL203hn?P80;Rh^0P0R8R8301lO7`807AdM0P0J
6QX2024Q8@80=CDe0P1DE5@207inOP80PH610P25QHD206m_K`80I6AT0P1_Kfl207alO080YZJV102/
[:`20:NWY`80Y:BT0P2LW9`20::RXP80XJ6Q0P2RXZ8209fMW@80WinO0P2QXJ420:VYZ@80[Jf]0P2j
^[X20<30`080^k^k0P31`L420;Zj^P<0]KFe0P2n_[h20;no_`@0[Zj^0P2VYZH209bLW080[Jf]0P2h
^;P20;Zj^P80[Jf]0P2/[:`20:RXZ080X:2P0P2NWYh209fMW@@0Vi^K0P2PX:020::RXP80Y:BT0P2S
Xj<20:RXZ080YjNW0P2TY:@209jNWP80X:2P0P2UYJD20:JVYP80ZZZZ0P2TY:@20:VYZ@<0[Jf]0P2^
[Zh20;2`/080[Zj^102][Jd20;2`/0@0/k>c0P2d];@20;Jf]P80/K6a0P2b/[820;Bd]080]kNg0P2e
]KDO0<SPf0007@38h=P203lo?`80BDU90P0];Bd202l_;`80<C4a0P0d=3@203De=@80=3@d0P0b<S82
02d];@80:b/[0P0^;Rh203/k>`80JFUY0P1_Kfl206ATI0<0Cdm?0P10@40203<c<`80:RXZ0P0V9RH2
02PX:080;Bd]0P0e=CD203Xj>P80;bl_0P0T92@202`/;080=3@d0P1IFET2065QH@8092@T0P0W9bL2
02l_;`80@d=30P1>CTh2055AD@80=cLg0P0k>c/403<c<`809RHV0P14A4@207=cL`80Jf][0P0o?cl2
02d];@808b<S0`0Q8B4201hN7P807alO0P0S8b<2034a<@80E5AD0P1kNg/208>3P`80Ogmo0P1_Kfl2
06IVIP80Kfm_0P1oOgl20:VYZ@80[:b/0P2][Jd20:JVYP80XZ:R0P2OWil20:2PX080XJ6Q0P2PX:02
09nOW`80X:2P0P2RXZ820:VYZ@80/;2`0P2h^;P40;no_`80_;bl0P2i^KT30;Ng]`80^[Zj0P2k^k/2
0;Bd]080[:b/0P2WYjL20:6QX@80Zj^[0P2j^[X20;Jf]P80[jn_0P2/[:`20:VYZ@80YZJV0P2RXZ82
09jNWP80Vi^K0P2MWId20:2PX080XZ:R0P2SXj<20:FUY@80YZJV0P2TY:@40:6QX@80XZ:R0P2TY:@2
0:NWY`@0YZJV0P2ZZZX30:f][@80[jn_0P2`/;020:n_[`@0[Zj^0P2_[jl20;6a/@80/[:b0P2c/k<2
0;Bd]080/[:b0P2a/K420;Fe]@80^KVi0P2j^[XY0<SPf080@4100P1?Cdl202/[:`8092@T0P0c<c<2
03Lg=`80?Cdm0P0_;bl2038b<P80;Bd]0P0^;Rh203Lg=`80@T920P1[Jf/206QXJ080IFEU0`17AdL2
03Hf=P80>c/k0P0Z:RX202DU9@808R8R0P0[:b/203/k>`80=cLg0P0^;Rh202HV9P80:BTY0P0g=cL2
05UIF@80I6AT0P0Z:RX202DU9@80:RXZ0P17AdL2055AD@80F5QH0P0i>CT20410@080@d=30P0_;bl2
02LW9`80?3`l0P1hN7P2075aL@80@D510P0`<30202<S8`<07AdM0P0N7Qh4020P8080<S8b0P1CDe<2
079bLP80MWIf0P1nOWh206a/K080Hf=S0P1ZJVX208>3P`80WYjN0P2d];@20:j^[P80XZ:R0P2MWId4
0:6QX@80X:2P0P2OWil40:6QX@80X:2P0P2VYZH20:f][@80_;bl0P2k^k/40;jn_P80]KFe0`2g]kL2
0;Vi^@80]kNg0P2d];@20:b/[080W9bL0P2RXZ820;Jf]P80^KVi0P2f][H20:b/[080Xj>S0P2WYjL2
0:JVYP80Y:BT0P2KVi/409ZJVP80W9bL0P2QXJ420:JVYP80ZJVY0P2TY:@20:6QX@80Xj>S0P2RXZ82
09jNWP80Y:BT0P2YZJT20:NWY`80YZJV0P2XZ:P30:f][@80/;2`0P2][Jd20:j^[P80[Jf]0P2^[Zh2
0:n_[`80/K6a0P2b/[840;Bd]080/K6a0P2b/[820;Bd]080^;Rh0P2n_[hY0<SPf080ATI60P17AdL2
034a<@@0<c<c0P0b<S8203@d=080=SHf0P0e=CD2030`<080:b/[0P0_;bl203Ph>080HV9R0P1ZJVX2
06EUI@<0AdM70P0l?3`202`/;0@0:BTY0P0W9bL402d];@80?Shn0P0^;Rh202PX:080:BTY0P0c<c<2
05mOG`80J6QX0P0S8b<202PX:080<C4a0P10@40205=CD`80BTY:0P0g=cL203Xj>P80<S8b0P0d=3@2
02XZ:P80AdM70P1/K6`206MWI`80?Shn0P0^;Rh2028R8P<07alO0P0M7Ad201XJ6P808B4Q0P0e=CD2
05ADE080OWin0P21PH4208F5Q@80Kfm_0P1TI6@206m_K`80O7al0P2VYZH40:b/[080YjNW0P2TY:@2
09bLW080XZ:R0P2QXJ420::RXP80WIfM0P2OWil20:6QX@80ZJVY0P2][Jd20;Zj^P80`<300P2k^k/2
0<71`@80^[Zj0`2e]KD20;jn_P80_kno102^[Zh20:JVYP80W9bL0P2][Jd20;Rh^080^[Zj0P2][Jd2
0:b/[080Z:RX0P2PX:0209jNWP80WIfM102KVi/20:2PX080XZ:R0P2TY:@20:>SX`80Z:RX0P2WYjL2
0:BTY080WYjN0P2PX:020:FUY@80YZJV0P2ZZZX20:BTY080ZJVY0`2][Jd20:j^[P80/;2`0P2^[Zh4
0:f][@80/;2`102c/k<20;Bd]080][Jf0P2a/K420;:b/P80];Bd0P2g]kL20;Fe]Al0b>3H000M0<SP
f080?3`l0P1NGUh203Ph>080<30`0P0R8R8204E5A@809BDU0P0V9RH202@T90809RHV0P0/;2`203Lg
=`80AdM70P1BDU8205eMG@80HF5Q0`1NGUh204];B`80=SHf0P0/;2`202PX:080:BTY0P0/;2`203De
=@80>c/k0P0c<c<202XZ:P80:2PX0P0_;bl204e=C@80JVYZ0P0Z:RX202DU9@80<30`1015ADD203dm
?@80=3@d0P0^;Rh2034a<@80=SHf0P0_;bl202h^;P80HF5Q0P2>SXh2069RHP80:2PX1@0N7Qh201dM
7@807QhN0P0M7Ad202DU9@80@d=30P1ZJVX208N7Q`80VYZJ0P2:RXX207MgM`@0KFe]0P29RHT20:ZZ
ZP80/;2`0P2^[Zh20:FUY@80WIfM0P2NWYh60:6QX@80XZ:R0P2TY:@20:ZZZP80/K6a0P2h^;P40;fm
_@80^k^k1@2j^[X40;^k^`80/k>c0P2YZJT209^KV`80TI6A0P2SXj<40;^k^`80]KFe0P2][Jd40:FU
Y@80YZJV0P2QXJ4209bLW080VYZJ0P2KVi/209fMW@80X:2P0P2TY:@20:JVYP80Xj>S102OWil20:6Q
X@80Xj>S102UYJD20:JVYP80ZZZZ0`2][Jd60:j^[P80[Jf]0P2^[Zh20:n_[`80/K6a0P2b/[820;Bd
]0H0]KFe0P2h^;P40;^k^bT0b>3H0P0j>SX2069RHP80=3@d0P0Y:BT202PX:080>CTi0P0X:2P202DU
9@8092@T0P0W9bL202`/;080=SHf0P0n?Sh204e=C@80Hf=S0P1YJFT3069RHP80?clo0P0f=SH203Lg
=`80:2PX0P0Y:BT2030`<080>CTi0P0l?3`202h^;P80:b/[0P0/;2`202d];@80DU9B0P1TI6@202d]
;@809RHV0P0];Bd204Y:BP80?3`l0P0n?Sh203Ti>@80:BTY0P0a<C42038b<P80;Bd]0P0^;Rh206=S
H`80S8b<0P1QHF4202TY:@D07alO0P0M7Ad201lO7`808B4Q0P0X:2P203hn?P80K6a/0P2>SXh209NG
U`80Q8B40P1lO7`2075aL@80KVi^0P26QXH20:NWY`80_;bl0P2][Jd209fMW@80WYjN0P2SXj<20:2P
X080WinO0P2RXZ820:6QX@80YZJV0P2/[:`20:n_[`80^k^k0P2l_;`20;Zj^P80^k^k0P2l_;`70;^k
^`80/[:b0P2^[Zh2092@T080Shn?0P2[Zj/20;Fe]@80_;bl0P2h^;P20:NWY`80ZJVY0P2WYjL20:JV
YP80XJ6Q0P2NWYh209ZJVP80Vi^K0P2LW9`20:2PX080YJFU0P2VYZH20:>SX`80WYjN0P2MWId20:>S
X`80XJ6Q0P2VYZH20:6QX@@0Z:RX0`2`/;020:^[Z`80/;2`102][Jd40;2`/080[Zj^0P2d];@20;Fe
]@80][Jf0P2b/[820;Jf]P80^;Rh0P2i^KT20;jn_RT0b>3H0P0m?Cd205YJFP80=CDe0P0f=SH2020P
8080AdM70P0T92@202HV9P80820P0P0X:2P202XZ:P80?Shn0P18B4P204m?C`80Hf=S0P1RHV83065Q
H@80BDU90P0f=SH2030`<080:BTY0P0T92@202/[:`80=cLg0P0i>CT203Hf=P80;Bd]0P0U9BD203<c
<`80B4Q80P1XJ6P202TY:@8092@T0P0_;bl204M7A`80A4A40P11@D4203Lg=`80;bl_0P0];Bd203Xj
>P80;Bd]0P0_;bl2065QH@80S8b<0P1WIfL202LW9`807AdM1@0N7Qh201lO7`807QhN0P0S8b<204=3
@`80Jf][0P25QHD209^KV`80R8R80P1iNGT206e]K@80Kfm_0P28R8P20:^[Z`80/K6a0P2[Zj/20:NW
Y`80WIfM0P2IVIT209jNWP80XJ6Q0P2OWil20:BTY080YJFU0P2YZJT20;>c/`80^k^k0P2l_;`20;Rh
^0@0^KVi1@2l_;`20;Vi^@80[Jf]0P2[Zj/209nOW`80TY:B0P2SXj<20;Vi^@80_;bl0P2b/[820:j^
[P80YJFU0P2SXj<20:ZZZP80YJFU0P2LW9`209^KV`@0W9bL0P2QXJ420::RXP80YZJV0P2PX:0209nO
W`80X:2P102RXZ820:FUY@80YZJV0P2UYJD20:ZZZP<0[Zj^102_[jl20:b/[080/;2`0P2/[:`20:n_
[`80/[:b0P2_[jl20;Fe]@80];Bd102e]KD20;Rh^080_;bl0P2k^k/O0<SPf0007@38h=P203`l?080
GUiN0P0h>3P2030`<0808R8R0P15ADD202DU9@809RHV0P0T92@202HV9P80;2`/0P0g=cL204M7A`80
DU9B0P1MGEd2065QH@<0GUiN0P1;Bd/203Hf=P80;2`/0P0X:2P202TY:@80;2`/0P0e=CD203/k>`80
<c<c0P0Z:RX202PX:080;bl_0P1=CDd206YZJP80:RXZ0P0U9BD2030`<0@0ADE50P0m?Cd203@d=080
;Rh^0P0a<C4203Hf=P80;bl_0P0^;Rh2065QH@80SXj>0P1RHV8202PX:0D07QhN0P0M7Ad201hN7P80
7AdM0P0U9BD204=3@`80JVYZ0P27QhL209ZJVP80RXZ:0P1gMgL406e]K@80RHV90P2ZZZX20;2`/080
[Zj^0P2UYJD209fMW@80WYjN1P2QXJ420::RXP80Y:BT0P2ZZZX20;6a/@80^;Rh102m_Kd20;^k^`D0
^[Zj102k^k/20;>c/`80ZJVY0P2KVi/2096AT@80Xj>S102k^k/20;Fe]@80[Jf]102UYJD20:JVYP80
XJ6Q0P2LW9`209ZJVP80Vi^K0P2MWId20:2PX080Y:BT0P2VYZH20:>SX`@0WinO0P2QXJ420:>SX`@0
YJFU0P2VYZH20:ZZZP<0[Jf]1P2^[Zh20:f][@80[Zj^0P2_[jl20;6a/@80/[:b0P2d];@60;Fe]@80
^;Rh102k^k/Y0<SPf080>SXj0P1RHV8203@d=080:BTY0P0X:2P203Ti>@80:2PX0P0U9BD202@T9080
9bLW0P0/;2`203Hf=P80?Shn0P1=CDd206=SH`80JFUY0`1RHV8203lo?`80=SHf0P0g=cL202PX:080
:BTY0P0`<30203Ti>@80?3`l0P0^;Rh202/[:`80;2`/0P0];Bd2059BDP80I6AT0P0];Bd202HV9P80
;Bd]0P1:BTX203`l?080?Shn0P0i>CT202TY:@80<C4a0P0b<S8202d];@80;Rh^0P1SHf<208b<S080
HF5Q0P0Y:BT501lO7`807AdM0P0O7al2024Q8@80:2PX0P0n?Sh206a/K080SXj>0P2GUiL208B4Q080
O7al0P1aLG4206i^KP80QXJ60P2WYjL20;bl_080[Jf]0P2MWId209jNWP80Xj>S0P2PX:0209nOW`80
XZ:R0P2QXJ420:JVYP80[:b/0P2_[jl20;^k^`80_;bl0P2j^[X20;^k^`80_;bl1`2k^k/20;:b/P80
[Zj^0P2@T90208n?S`80Zj^[0P2e]KD20;bl_080^;Rh0P2WYjL20:VYZ@80YjNW0P2VYZH20:6QX@80
WYjN0P2JVYX209^KV`80W9bL0P2PX:020:FUY@80YZJV0P2SXj<209jNWP80WIfM0P2SXj<20:6QX@80
YZJV0P2QXJ440:RXZ0<0/;2`0P2[Zj/20;2`/0@0[Jf]102`/;020:j^[P80];Bd0P2e]KD20;Jf]P80
/[:b0P2f][H20;Rh^080^KVi0P2n_[hY0<SPf080?Cdm0P1JFUX203De=@80=SHf0P0P820204M7A`80
92@T0P0V9RH2020P8080:2PX0P0Z:RX203hn?P80B4Q80P1?Cdl206=SH`80HV9R0`1QHF4204U9B@80
=SHf0P0`<30202TY:@8092@T0P0[:b/203Lg=`80>CTi0P0f=SH202d];@809BDU0P0c<c<204Q8B080
J6QX0P0Y:BT202@T9080;bl_0P17AdL204A4A080@D510P0g=cL202l_;`80;Bd]0P0j>SX202d];@80
;bl_0P1QHF4208b<S080IfMW0P0W9bL201dM7@D07QhN0P0O7al201hN7P808b<S0P13@d<206][J`80
QHF50P2KVi/208R8R080NGUi0P1]KFd206m_K`80R8R80P2[Zj/20;6a/@80Zj^[0P2WYjL209fMW@80
VIVI0P2NWYh20:6QX@80WinO0P2TY:@20:FUY@80ZJVY0P2c/k<20;^k^`80_;bl0P2h^;P40;Vi^@D0
_;bl0P2i^KT20:f][@80Zj^[0P2OWil209:BTP80Xj>S0P2i^KT20;bl_080/[:b0P2^[Zh20:FUY@80
Xj>S0P2ZZZX20:FUY@80W9bL0P2KVi/409bLW080XJ6Q0P2RXZ820:JVYP80X:2P0P2OWil20:2PX0@0
XZ:R0P2UYJD20:JVYP80YJFU0P2ZZZX30:j^[P@0[jn_0P2/[:`20;2`/080[:b/0P2_[jl20;:b/P80
[jn_0P2e]KD20;Bd]0@0]KFe0P2h^;P20;bl_080^k^k7`38h=P001d0b>3H0P0_;bl204];B`80@T92
0P0f=SH202DU9@80>CTi0P0Y:BT202DU9@808B4Q0P0Z:RX203Lg=`80Cdm?100n?Sh204A4A080De=C
0`1MGEd2051@D080?Shn0P0b<S8202TY:@80:RXZ0P0_;bl203@d=080>3Ph0P0c<c<202d];@80:2PX
0P0Z:RX204M7A`80IFEU0P0f=SH202LW9`80?3`l0P1FEUH203Lg=`80<S8b0P0k>c/202@T9080:b/[
0P0a<C4203@d=080<S8b0P1HF5P207]kN`80EUIF0P0T92@201hN7P<0820P0P0M7Ad201`L70809bLW
0P0a<C4205eMG@80IfMW0P1oOgl208V9R@80WinO0P2;Rh/207UiN@80JVYZ0P1fMWH208n?S`80XJ6Q
0P2_[jl20:VYZ@@0X:2P102QXJ420::RXP80Y:BT0P2WYjL20:j^[P80]KFe0P2j^[X20;bl_080^k^k
0P2i^KT50;^k^`80^[Zj0P2f][H20:n_[`80XZ:R0P22PX8208J6QP80Z:RX0P2c/k<20;fm_@80_[jn
0P2g]kL20:f][@80ZJVY0P2VYZH20:6QX@80WIfM0P2JVYX209VIV@80VYZJ0P2MWId209nOW`80X:2P
0P2NWYh209bLW080WYjN0P2QXJ420::RXP80Xj>S0P2TY:@20:JVYP80ZJVY0`2/[:`40:f][@@0[:b/
0P2^[Zh20;2`/080/K6a0P2b/[820;>c/`H0]KFe0P2h^;P20;bl_080_Kfm:@38h=P202LW9`80BTY:
0P1DE5@2038b<P80<C4a0P0l?3`202XZ:P@09BDU0P0X:2P203@d=080DU9B0P18B4P203hn?P80>CTi
0P1JFUX3069RHP80De=C0P0m?Cd2038b<P809RHV0P0X:2P202TY:@80<S8b0P0i>CT203Lg=`80;2`/
100Y:BT20410@080IVIV0P0k>c/202LW9`80>c/k0P1JFUX2034a<@80=3@d0P0b<S8202DU9@809RHV
0P0b<S8204E5A@80=3@d0P1?Cdl207YjNP80De=C0P0Q8B42020P80<08b<S100N7Qh2020P8080<C4a
0P1RHV8206MWI`@0SXj>0P2QXJ4208R8R080OGem0P1ZJVX207AdM080R8R80P2SXj<20;:b/P80YJFU
0P2PX:020:BTY080XJ6Q0P2LW9`40::RXP80YJFU0P2_[jl20;>c/`80`<300P2l_;`20;Zj^P80^KVi
0P2k^k/30;Rh^080^k^k0P2i^KT20:n_[`80Y:BT0P2:RXX208B4Q080Zj^[0P2`/;020;Vi^@80`l?3
0P2h^;P20:j^[P80Z:RX0P2VYZH209nOW`80W9bL0P2NWYh209bLW080Vi^K0P2HV9P209jNWP80X:2P
1P2NWYh20:>SX`80X:2P0P2RXZ820:JVYP80YJFU0P2/[:`30:ZZZP80[Zj^0P2_[jl20:^[Z`@0[:b/
0P2`/;040:n_[`@0];Bd0P2c/k<20;Ng]`80][Jf0P2l_;`20;fm_BT0b>3H0P0^;Rh204e=C@80?clo
0P0h>3P201dM7@80=CDe0P0Z:RX202PX:08092@T0P0P820203Lg=`80DE5A0P0n?Sh203`l?080ADE5
0P1ADE4305mOG`80EEEE0P13@d<2030`<0809RHV0P0[:b/203<c<`80?3`l0P0d=3@202h^;P@0:2PX
0P0Z:RX204I6AP80IVIV0P0h>3P202TY:@80>SXj0P1FEUH203De=@80;bl_0P0h>3P202DU9@80<30`
0P0Z:RX203De=@80;Rh^0P1IFET207moO`80EeMG0P0Q8B4201lO7`<08R8R0P0P820201hN7P80:2PX
0P0c<c<205UIF@80IfMW0P21PH4208F5Q@80WinO0P2:RXX207alO080Jf][0P1fMWH208n?S`80X:2P
0P2_[jl20:b/[080Xj>S0P2NWYh20:NWY`80YZJV0P2RXZ840:JVYP80ZZZZ0P2e]KD20;^k^`80`<30
0P2l_;`20;jn_P80_Kfm0`2h^;P20;^k^`80^;Rh0P2b/[820:2PX080P8200P26QXH20:JVYP80]KFe
0P2o_kl20;jn_P80_;bl0P2_[jl20:VYZ@80YjNW0P2PX:0209bLW080VIVI0P2FUYH209bLW080WinO
0P2NWYh20:>SX`80WIfM0P2KVi/40:2PX080WinO0P2SXj<20:6QX@80Z:RX0P2ZZZX50:b/[080/;2`
0P2[Zj/20:f][@80[:b/0P2^[Zh20;Fe]@80/[:b0P2d];@20;>c/`@0]KFe0P2k^k/20;jn_P80_Kfm
7`38h=P001d0b>3H0P0_;bl204];B`80@T920P0f=SH202DU9@80>CTi0P0Y:BT202DU9@808B4Q0P0Z
:RX203Lg=`80Cdm?100n?Sh204A4A080De=C0`1MGEd2051@D080?Shn0P0b<S8202TY:@80:RXZ0P0_
;bl203@d=080>3Ph0P0c<c<202d];@80:2PX0P0Z:RX204M7A`80IFEU0P0f=SH202LW9`80?3`l0P1F
EUH203Lg=`80<S8b0P0k>c/202@T9080:b/[0P0a<C4203@d=080<S8b0P1HF5P207]kN`80EUIF0P0T
92@201hN7P<0820P0P0M7Ad201`L70809bLW0P0a<C4205eMG@80IfMW0P1oOgl208V9R@80WinO0P2;
Rh/207UiN@80JVYZ0P1fMWH208n?S`80XJ6Q0P2_[jl20:VYZ@@0X:2P102QXJ420::RXP80Y:BT0P2W
YjL20:j^[P80]KFe0P2j^[X20;bl_080^k^k0P2i^KT50;^k^`80^[Zj0P2f][H20:n_[`80XZ:R0P22
PX8208J6QP80Z:RX0P2c/k<20;fm_@80_[jn0P2g]kL20:f][@80ZJVY0P2VYZH20:6QX@80WIfM0P2J
VYX209VIV@80VYZJ0P2MWId209nOW`80X:2P0P2NWYh209bLW080WYjN0P2QXJ420::RXP80Xj>S0P2T
Y:@20:JVYP80ZJVY0`2/[:`40:f][@@0[:b/0P2^[Zh20;2`/080/K6a0P2b/[820;>c/`H0]KFe0P2h
^;P20;bl_080_Kfm:@38h=P202LW9`80BTY:0P1DE5@2038b<P80<C4a0P0l?3`202XZ:P@09BDU0P0X
:2P203@d=080DU9B0P18B4P203hn?P80>CTi0P1JFUX3069RHP80De=C0P0m?Cd2038b<P809RHV0P0X
:2P202TY:@80<S8b0P0i>CT203Lg=`80;2`/100Y:BT20410@080IVIV0P0k>c/202LW9`80>c/k0P1J
FUX2034a<@80=3@d0P0b<S8202DU9@809RHV0P0b<S8204E5A@80=3@d0P1?Cdl207YjNP80De=C0P0Q
8B42020P80<08b<S100N7Qh2020P8080<C4a0P1RHV8206MWI`@0SXj>0P2QXJ4208R8R080OGem0P1Z
JVX207AdM080R8R80P2SXj<20;:b/P80YJFU0P2PX:020:BTY080XJ6Q0P2LW9`40::RXP80YJFU0P2_
[jl20;>c/`80`<300P2l_;`20;Zj^P80^KVi0P2k^k/30;Rh^080^k^k0P2i^KT20:n_[`80Y:BT0P2:
RXX208B4Q080Zj^[0P2`/;020;Vi^@80`l?30P2h^;P20:j^[P80Z:RX0P2VYZH209nOW`80W9bL0P2N
WYh209bLW080Vi^K0P2HV9P209jNWP80X:2P1P2NWYh20:>SX`80X:2P0P2RXZ820:JVYP80YJFU0P2/
[:`30:ZZZP80[Zj^0P2_[jl20:^[Z`@0[:b/0P2`/;040:n_[`@0];Bd0P2c/k<20;Ng]`80][Jf0P2l
_;`20;fm_BT0b>3H0P0^;Rh204e=C@80?clo0P0h>3P201dM7@80=CDe0P0Z:RX202PX:08092@T0P0P
820203Lg=`80DE5A0P0n?Sh203`l?080ADE50P1ADE4305mOG`80EEEE0P13@d<2030`<0809RHV0P0[
:b/203<c<`80?3`l0P0d=3@202h^;P@0:2PX0P0Z:RX204I6AP80IVIV0P0h>3P202TY:@80>SXj0P1F
EUH203De=@80;bl_0P0h>3P202DU9@80<30`0P0Z:RX203De=@80;Rh^0P1IFET207moO`80EeMG0P0Q
8B4201lO7`<08R8R0P0P820201hN7P80:2PX0P0c<c<205UIF@80IfMW0P21PH4208F5Q@80WinO0P2:
RXX207alO080Jf][0P1fMWH208n?S`80X:2P0P2_[jl20:b/[080Xj>S0P2NWYh20:NWY`80YZJV0P2R
XZ840:JVYP80ZZZZ0P2e]KD20;^k^`80`<300P2l_;`20;jn_P80_Kfm0`2h^;P20;^k^`80^;Rh0P2b
/[820:2PX080P8200P26QXH20:JVYP80]KFe0P2o_kl20;jn_P80_;bl0P2_[jl20:VYZ@80YjNW0P2P
X:0209bLW080VIVI0P2FUYH209bLW080WinO0P2NWYh20:>SX`80WIfM0P2KVi/40:2PX080WinO0P2S
Xj<20:6QX@80Z:RX0P2ZZZX50:b/[080/;2`0P2[Zj/20:f][@80[:b/0P2^[Zh20;Fe]@80/[:b0P2d
];@20;>c/`@0]KFe0P2k^k/20;jn_P80_Kfm7`38h=P001d0b>3H0P0R8R82038b<P80ATI60P0j>SX2
02/[:`80:RXZ0P0^;Rh202PX:0809BDU0P0f=SH204I6AP80IVIV0P0l?3`202l_;`809BDU0P0m?Cd3
05IFEP80De=C0P18B4P203Ph>080:RXZ0P0/;2`2034a<@80=3@d0P0e=CD203<c<`80;bl_0P0X:2P2
02LW9`80@d=30P1KFe/204=3@`80:b/[0P15ADD2065QH@@0:b/[0P10@402020P8080:BTY0P0a<C42
03Hf=P80>SXj0P1@D50205iNGP80@D510P0Q8B4201lO7`<08b<S100M7Ad203De=@80Bd];0P1jNWX2
06ATI080K6a/0P1[Jf/20:JVYP80Vi^K0P29RHT2071`L080KFe]0P1cLg<208n?S`80ZJVY0P2[Zj/2
0:JVYP80Xj>S102QXJ420:>SX`80YZJV0P2[Zj/20;:b/P80^;Rh0P2k^k/20;bl_080^[Zj0P2h^;P2
0;^k^`<0_;bl0P2h^;P20;2`/080YjNW0P2KVi/206e]K@80Ogmo0P2_[jl20:^[Z`80_;bl0P34a<@2
0<30`080]kNg0P2^[Zh20:JVYP80XZ:R0P2OWil209^KV`@0VIVI102JVYX209^KV`@0VYZJ0P2MWId6
0:6QX@80Xj>S0P2VYZH20:VYZ@<0Zj^[102/[:`40:^[Z`80[Zj^1P2a/K420;>c/`H0];Bd0P2i^KT2
0;bl_080_Kfm:@38h=P202TY:@80<C4a0P15ADD203<c<`809bLW0P0`<30202`/;0809RHV0P0Y:BT2
03@d=080BDU90P1QHF4203/k>`80;Rh^0P0Y:BT203/k>`<0EEEE0P1HF5P204Y:BP80>CTi0P0^;Rh2
02/[:`80;bl_0P0h>3P2034a<@80>CTi0P0Z:RX202`/;080:RXZ0P0l?3`205mOG`80@D510P0[:b/2
04E5A@80GEeM0P0c<c<202d];@80=cLg0P0W9bL202/[:`80;Rh^0P0m?Cd203Hf=P80Cdm?0P1UIFD2
03lo?`8092@T0P0O7al3024Q8@@0820P0P0/;2`204m?C`80OGem0P1WIfL205mOG`80LW9b0P2KVi/2
0:6QX@80QhN70P1dM7@206m_K`80NWYj0P24Q8@20:^[Z`80[jn_0P2SXj<20:BTY080XZ:R0P2MWId4
0:JVYP80ZZZZ0P2d];@20;Fe]@80_Kfm0P2k^k/20;Zj^P80][Jf0P2o_kl30;^k^`80^;Rh0P2a/K42
0:2PX080V9RH0P1dM7@207emO@80ZJVY0P2`/;020;bl_080`l?30P30`<020;Jf]P80[jn_0P2VYZH2
0::RXP80XJ6Q0P2IVIT209NGU`80Vi^K0P2FUYH209^KV`80VYZJ0P2KVi/209VIV@80Vi^K0P2PX:02
0:BTY080XJ6Q0P2SXj<20:FUY@80ZJVY0`2ZZZX20:f][@80ZZZZ0P2YZJT20:b/[080[jn_102a/K42
0;Bd]080/;2`0P2g]kL20;Fe]@80]kNg0P2e]KD20;fm_@80`L71:@38h=P202LW9`80<C4a0P18B4P2
03/k>`80;Rh^0P0X:2P2030`<080:2PX0P0S8b<203Lg=`80BTY:0P1VIVH203Lg=`80=CDe0P0R8R82
03Xj>P<0E5AD0P1CDe<204Q8B080=cLg0P0/;2`202TY:@80;Bd]100d=3@203Ti>@80<C4a100X:2P2
03hn?P80G5aL0P18B4P202XZ:P80@d=30P1PH60202d];@80;bl_0P10@40201/K6`80;Bd]0P0`<302
03<c<`80?clo0P1@D50205eMG@80@D510P0R8R8201hN7P<09RHV0P0J6QX201/K6`80>3Ph0P1=CDd2
07AdM080I6AT0P1aLG4206][J`80YJFU0P2JVYX208V9R@80K6a/0P1^KVh207AdM080SXj>0P2ZZZX2
0:f][@80Y:BT0P2MWId209jNWP80Y:BT0P2RXZ820:RXZ080ZZZZ0P2b/[820;Zj^P80^k^k0P2m_Kd2
0;Zj^P80][Jf0P2l_;`30;Vi^@80^;Rh0P2/[:`20:NWY`80VYZJ0P1ZJVX208>3P`80ZJVY0P2][Jd2
0;^k^`80aLG50P30`<020;Rh^080[Jf]0P2UYJD20:6QX@80X:2P0P2KVi/209VIV@80Vi^K0P2IVIT2
09ZJVP80Vi^K0P2GUiL209bLW080WIfM0P2QXJ4209nOW`80XZ:R0P2SXj<20:JVYP80ZJVY0`2/[:`2
0:ZZZP80[:b/0P2[Zj/20:f][@80[:b/102b/[820;2`/080/K6a0P2e]KD20;Jf]P80]KFe0P2j^[X2
0;bl_080^[Zj7`38h=P001d0b>3H0P0R8R82038b<P80ATI60P0j>SX202/[:`80:RXZ0P0^;Rh202PX
:0809BDU0P0f=SH204I6AP80IVIV0P0l?3`202l_;`809BDU0P0m?Cd305IFEP80De=C0P18B4P203Ph
>080:RXZ0P0/;2`2034a<@80=3@d0P0e=CD203<c<`80;bl_0P0X:2P202LW9`80@d=30P1KFe/204=3
@`80:b/[0P15ADD2065QH@@0:b/[0P10@402020P8080:BTY0P0a<C4203Hf=P80>SXj0P1@D50205iN
GP80@D510P0Q8B4201lO7`<08b<S100M7Ad203De=@80Bd];0P1jNWX206ATI080K6a/0P1[Jf/20:JV
YP80Vi^K0P29RHT2071`L080KFe]0P1cLg<208n?S`80ZJVY0P2[Zj/20:JVYP80Xj>S102QXJ420:>S
X`80YZJV0P2[Zj/20;:b/P80^;Rh0P2k^k/20;bl_080^[Zj0P2h^;P20;^k^`<0_;bl0P2h^;P20;2`
/080YjNW0P2KVi/206e]K@80Ogmo0P2_[jl20:^[Z`80_;bl0P34a<@20<30`080]kNg0P2^[Zh20:JV
YP80XZ:R0P2OWil209^KV`@0VIVI102JVYX209^KV`@0VYZJ0P2MWId60:6QX@80Xj>S0P2VYZH20:VY
Z@<0Zj^[102/[:`40:^[Z`80[Zj^1P2a/K420;>c/`H0];Bd0P2i^KT20;bl_080_Kfm:@38h=P202TY
:@80<C4a0P15ADD203<c<`809bLW0P0`<30202`/;0809RHV0P0Y:BT203@d=080BDU90P1QHF4203/k
>`80;Rh^0P0Y:BT203/k>`<0EEEE0P1HF5P204Y:BP80>CTi0P0^;Rh202/[:`80;bl_0P0h>3P2034a
<@80>CTi0P0Z:RX202`/;080:RXZ0P0l?3`205mOG`80@D510P0[:b/204E5A@80GEeM0P0c<c<202d]
;@80=cLg0P0W9bL202/[:`80;Rh^0P0m?Cd203Hf=P80Cdm?0P1UIFD203lo?`8092@T0P0O7al3024Q
8@@0820P0P0/;2`204m?C`80OGem0P1WIfL205mOG`80LW9b0P2KVi/20:6QX@80QhN70P1dM7@206m_
K`80NWYj0P24Q8@20:^[Z`80[jn_0P2SXj<20:BTY080XZ:R0P2MWId40:JVYP80ZZZZ0P2d];@20;Fe
]@80_Kfm0P2k^k/20;Zj^P80][Jf0P2o_kl30;^k^`80^;Rh0P2a/K420:2PX080V9RH0P1dM7@207em
O@80ZJVY0P2`/;020;bl_080`l?30P30`<020;Jf]P80[jn_0P2VYZH20::RXP80XJ6Q0P2IVIT209NG
U`80Vi^K0P2FUYH209^KV`80VYZJ0P2KVi/209VIV@80Vi^K0P2PX:020:BTY080XJ6Q0P2SXj<20:FU
Y@80ZJVY0`2ZZZX20:f][@80ZZZZ0P2YZJT20:b/[080[jn_102a/K420;Bd]080/;2`0P2g]kL20;Fe
]@80]kNg0P2e]KD20;fm_@80`L71:@38h=P202LW9`80<C4a0P18B4P203/k>`80;Rh^0P0X:2P2030`
<080:2PX0P0S8b<203Lg=`80BTY:0P1VIVH203Lg=`80=CDe0P0R8R8203Xj>P<0E5AD0P1CDe<204Q8
B080=cLg0P0/;2`202TY:@80;Bd]100d=3@203Ti>@80<C4a100X:2P203hn?P80G5aL0P18B4P202XZ
:P80@d=30P1PH60202d];@80;bl_0P10@40201/K6`80;Bd]0P0`<30203<c<`80?clo0P1@D50205eM
G@80@D510P0R8R8201hN7P<09RHV0P0J6QX201/K6`80>3Ph0P1=CDd207AdM080I6AT0P1aLG4206][
J`80YJFU0P2JVYX208V9R@80K6a/0P1^KVh207AdM080SXj>0P2ZZZX20:f][@80Y:BT0P2MWId209jN
WP80Y:BT0P2RXZ820:RXZ080ZZZZ0P2b/[820;Zj^P80^k^k0P2m_Kd20;Zj^P80][Jf0P2l_;`30;Vi
^@80^;Rh0P2/[:`20:NWY`80VYZJ0P1ZJVX208>3P`80ZJVY0P2][Jd20;^k^`80aLG50P30`<020;Rh
^080[Jf]0P2UYJD20:6QX@80X:2P0P2KVi/209VIV@80Vi^K0P2IVIT209ZJVP80Vi^K0P2GUiL209bL
W080WIfM0P2QXJ4209nOW`80XZ:R0P2SXj<20:JVYP80ZJVY0`2/[:`20:ZZZP80[:b/0P2[Zj/20:f]
[@80[:b/102b/[820;2`/080/K6a0P2e]KD20;Jf]P80]KFe0P2j^[X20;bl_080^[Zj7`38h=P001d0
b>3H0P0S8b<202/[:`80>CTi0P0c<c<202/[:`80:2PX0P0[:b/202`/;080<30`0P1HF5P205UIF@80
Bd];0P0f=SH202/[:`809bLW0P0e=CD304M7A`80DE5A0P1CDe<20451@@80;Rh^0P0];Bd2030`<080
=3@d0P0g=cL203De=@80<30`0P0Y:BT202LW9`80?Cdm0P1?Cdl2055AD@80:b/[0P0m?Cd204i>CP80
;Rh^0P0[:b/203Ph>080:b/[0P0f=SH204E5A@80;bl_0P0f=SH204U9B@80FEUI0P0o?cl2028R8P80
7alO0`0R8R8201`L7080820P0P0i>CT207EeM@80O7al0P1KFe/20410@080CTi>0P26QXH209bLW080
U9BD0P21PH4207=cL`80L71`0P20P80209FEU@80Y:BT0P2^[Zh20:NWY`80WinO0P2QXJ420:JVYP80
ZZZZ0P2_[jl20;6a/@80];Bd0P2k^k/20<30`080_;bl0P2h^;P20;^k^`<0_Kfm0P2g]kL20:n_[`80
UiNG0P2MWId206a/K080Ph>30P2b/[820:ZZZP80^KVi0P30`<020<;2`P80_kno0P2g]kL20:f][@80
Z:RX0P2TY:@209nOW`@0Vi^K0P2MWId409jNWP80Vi^K0P2HV9P209^KV`80X:2P0P2RXZ860:>SX`80
YjNW0`2[Zj/60:b/[080[Jf]0P2^[Zh20;2`/0H0/K6a0P2b/[820;Bd]080]kNg0P2j^[X20;bl_080
_Kfm:@38h=P202TY:@809RHV0P0f=SH203Lg=`80:2PX0P0Y:BT202/[:`80;2`/0P0c<c<204Q8B080
J6QX0P1;Bd/203Hf=P809BDU0P0b<S8202h^;P<0?Shn0P1GEeL204i>CP80=CDe0P0d=3@202d];@80
?3`l0P0f=SH202l_;`80>c/k0P0Z:RX2030`<080:RXZ0P0f=SH205UIF@80Bd];0P0b<S8203dm?@80
CTi>0P0_;bl2034a<@80=cLg0P0a<C4202h^;P80@T920P0];Bd203@d=080CTi>0P1CDe<203lo?`@0
8b<S0`0O7al2020P808092@T0P0c<c<207=cL`80QXJ60P1JFUX2034a<@80EUIF0P21PH4209nOW`80
U9BD0P1mOGd206m_K`80MgMg0P1jNWX2092@T080]kNg0P2YZJT209fMW@80XZ:R102UYJD20:^[Z`80
[Zj^102c/k<20;Zj^P80_[jn0P2j^[X20;Vi^@D0^k^k0P2j^[X20:j^[P80TY:B0P2JVYX207IfMP80
PH610P2/[:`20:^[Z`80^;Rh0P30`<020<;2`P80_[jn0P2h^;P20:ZZZP80Zj^[0P2QXJ4209fMW@80
VIVI0P2LW9`20::RXP80YJFU0P2JVYX209RHV080Vi^K0P2HV9P40:6QX@80X:2P0P2SXj<20::RXP80
Z:RX0`2ZZZX20:j^[P80[Jf]0P2/[:`20:j^[P80[Jf]0P2c/k<20:j^[P80/k>c102`/;020;:b/P80
]KFe0P2g]kL20;^k^`80_Kfm:@38h=P2024Q8@8092@T0P0g=cL203Ph>080;2`/0P0V9RH202LW9`80
;Rh^0P0a<C4205]KF`80EeMG0P15ADD203Xj>P80;bl_0P0T92@203dm?@<0ATI60P1@D50204m?C`80
@4100P0e=CD202XZ:P80=CDe100c<c<203Ti>@80;2`/0P0[:b/202PX:080?clo0P1;Bd/2055AD@80
:BTY0P10@402055AD@80;2`/0P0W9bL203Xj>P80:b/[0P0l?3`204M7A`80;2`/0P0f=SH204I6AP80
F5QH0P0n?Sh202LW9`806a/K0`0O7al201`L70808b<S0P0e=CD2075aL@80PH610P1JFUX20410@080
CDe=0P28R8P209fMW@80U9BD0P27QhL207MgM`80Lg=c0P1fMWH209RHV080YZJV0P2`/;020:RXZ0@0
WinO0P2RXZ820:RXZ080/K6a0P2^[Zh20;:b/P80_Kfm0P2k^k/20;Rh^080]KFe0P2n_[h30;no_`80
^[Zj0P2^[Zh209RHV080XZ:R0P1_Kfl208J6QP80/;2`0P2/[:`20;^k^`80_;bl0P31`L420;bl_080
]KFe0P2c/k<20:NWY`80YZJV0P2NWYh609^KV`80XJ6Q0P2MWId209VIV@80V9RH0P2NWYh20::RXP80
Xj>S0P2TY:@20::RXP80Y:BT0P2WYjL30:^[Z`80[Jf]0P2/[:`20:ZZZP80[Jf]0P2/[:`20;:b/P80
/K6a0P2b/[820;6a/@80/k>c102d];@20;Rh^080^k^k0P2m_KdO0<SPf0007@38h=P202<S8`80:b/[
0P0i>CT203<c<`80:b/[0P0X:2P202/[:`80;2`/0P0`<30205QHF080FEUI0P1;Bd/203Hf=P80:b/[
0P0W9bL203De=@<0AdM70P1ADE4205=CD`80@D510P0^;Rh202d];@80<30`0P0d=3@203Lg=`80=CDe
0P0`<30202TY:@809bLW0P0m?Cd204m?C`80DE5A0P0[:b/203dm?@80CTi>0P0^;Rh202/[:`80>3Ph
0P0[:b/203Hf=P80ADE50P0_;bl203Hf=P80BDU90P1IFET203lo?`808R8R0P0O7al3028R8P8071`L
0P0P820203Ti>@80MGEe0P1lO7`205]KF`80@4100P1>CTh208J6QP80W9bL0P2DU9@20861P@80Lg=c
0P1`L7020820P080UIFE0P2TY:@20:j^[P80YjNW0P2OWil20:6QX@80YZJV0P2ZZZX20:n_[`80/K6a
0P2d];@20;^k^`80`<300P2l_;`20;Rh^080^k^k0`2m_Kd20;Ng]`80[jn_0P2GUiL209fMW@80K6a/
0P23Ph<20;:b/P80ZZZZ0P2i^KT20<30`080`/;20P2o_kl20;Ng]`80[Jf]0P2XZ:P20:BTY080WinO
102KVi/209fMW@@0WYjN0P2KVi/209RHV080Vi^K0P2PX:020::RXPH0Xj>S0P2WYjL30:^[Z`H0[:b/
0P2][Jd20:j^[P80/;2`1P2a/K420;:b/P80];Bd0P2g]kL20;Zj^P80_;bl0P2m_KdY0<SPf080:BTY
0P0V9RH203Hf=P80=cLg0P0X:2P202TY:@80:b/[0P0/;2`203<c<`80B4Q80P1XJ6P204];B`80=SHf
0P0U9BD2038b<P80;Rh^0`0n?Sh205MGE`80CTi>0P0e=CD203@d=080;Bd]0P0l?3`203Hf=P80;bl_
0P0k>c/202XZ:P80<30`0P0Z:RX203Hf=P80FEUI0P1;Bd/2038b<P80?Cdm0P1>CTh202l_;`80<C4a
0P0g=cL2034a<@80;Rh^0P12@T8202d];@80=3@d0P1>CTh205=CD`80?clo100S8b<301lO7`80820P
0P0T92@203<c<`80Lg=c0P26QXH205YJFP80<C4a0P1FEUH20861P@80WinO0P2DU9@207emO@80Kfm_
0P1gMgL207YjNP80T92@0P2g]kL20:VYZ@80WIfM0P2RXZ840:FUY@80Zj^[0P2^[Zh40;>c/`80^[Zj
0P2n_[h20;Zj^P80^KVi1@2k^k/20;Zj^P80[Zj^0P2BTY8209ZJVP80MWIf0P21PH420:b/[080Zj^[
0P2h^;P20<30`080`/;20P2n_[h20;Rh^080ZZZZ0P2[Zj/20:6QX@80WIfM0P2IVIT209bLW080XZ:R
0P2UYJD209ZJVP80V9RH0P2KVi/209RHV0@0XJ6Q0P2PX:020:>SX`80XZ:R0P2XZ:P30:ZZZP80[Zj^
0P2][Jd20:b/[080[Zj^0P2][Jd20;>c/`80[Zj^0P2c/k<40;2`/080/[:b0P2e]KD20;Ng]`80^k^k
0P2m_KdY0<SPf0808B4Q0P0T92@203Lg=`80>3Ph0P0/;2`202HV9P809bLW0P0^;Rh2034a<@80Fe]K
0P1GEeL204E5A@80>SXj0P0_;bl202@T9080?Cdm0`16ATH2051@D080Cdm?0P10@40203De=@80:RXZ
0P0e=CD403<c<`80>CTi0P0/;2`202/[:`80:2PX0P0o?cl204];B`80DE5A0P0Y:BT20410@080DE5A
0P0/;2`202LW9`80>SXj0P0[:b/203`l?080AdM70P0/;2`203Hf=P80ATI60P1HF5P203hn?P809bLW
0P0K6a/301lO7`8071`L0P0S8b<203De=@80LG5a0P21PH4205YJFP80@4100P1=CDd208R8R080WIfM
0P2DU9@208N7Q`80MgMg0P1cLg<207IfMP80V9RH0P2VYZH20;2`/080Z:RX102OWil20::RXP80Z:RX
0P2a/K420:j^[P80/[:b0P2m_Kd20;^k^`80^;Rh0P2e]KD20;jn_P<0_kno0P2j^[X20:j^[P80V9RH
0P2RXZ8206m_K`80QXJ60P2`/;020:b/[080^k^k0P2l_;`20<71`@80_;bl0P2e]KD20;>c/`80YjNW
0P2VYZH209jNWPH0Vi^K0P2QXJ4209fMW@80VIVI0P2HV9P209jNWP80XZ:R0P2SXj<20:BTY080XZ:R
0P2TY:@20:NWY`<0Zj^[0P2][Jd20:b/[080ZZZZ0P2][Jd20:b/[080/[:b0P2a/K420;:b/P80/K6a
0P2c/k<40;Bd]080^;Rh0P2k^k/20;fm_Al0b>3H000M0<SPf0809RHV0P0X:2P202XZ:P@0:b/[100X
:2P203<c<`80@4100P1eMGD206ATI080;Rh^0P0d=3@202d];@80<30`0P0a<C4303Lg=`80BTY:0P1I
FET204Q8B080<c<c100^;Rh203@d=080>SXj0P0g=cL2034a<@80:b/[0P0Y:BT203Ti>@80@d=30P1J
FUX202h^;P80=3@d0P0g=cL203<c<`80;2`/0P0^;Rh203Ti>@80B4Q80P1IFET202TY:@80=SHf0P15
ADD205IFEP80@T920P0Y:BT5028R8P807AdM0P0X:2P204=3@`80V9RH0P1fMWH204i>CP805aLG0P0c
<c<205aLG080Shn?0P2GUiL2096AT@80PH610P1eMGD207IfMP80P8200P2IVIT20:n_[`80ZZZZ0P2P
X:020:>SX`80ZJVY0P2][Jd20;6a/@@0/;2`0P2j^[X20<?3``80_[jn0P2h^;P20;Zj^P<0_;bl0P2e
]KD20;2`/080R8R80P2PX:0207AdM080RXZ:0P2c/k<20:ZZZP80];Bd0P2i^KT20<71`@80a/K60P30
`<020;Ng]`80/;2`0P2YZJT20:>SX`@0WinO0P2PX:020::RXP80Xj>S0P2MWId209RHV080VYZJ0P2N
WYh20:6QX@80Y:BT0P2RXZ820:2PX080YJFU0`2ZZZX20:^[Z`80[:b/0P2][Jd40:j^[P80[Jf]0P2_
[jl20;6a/@@0/;2`0P2e]KD20;Vi^@80^k^k102l_;`Y0<SPf0808b<S0P0X:2P202TY:@80;Rh^0P0Y
:BT402XZ:P80=3@d0P17AdL206][J`80GemO0P0k>c/2034a<@80:b/[0P0_;bl2030`<0<0<c<c0P1=
CDd205aLG080ATI60P0f=SH202d];@80;2`/0P0e=CD203Ph>080>SXj0P0];Bd202`/;080;Rh^0P0c
<c<204Y:BP80E5AD0P0_;bl203@d=080>c/k0P0X:2P202l_;`80;Rh^0P0d=3@2055AD@80EUIF0P0Z
:RX2038b<P80CDe=0P1ADE420451@@80:b/[0P0X:2P302<S8`80820P0P0[:b/204E5A@80U9BD0P1k
Ng/204];B`80820P0P0/;2`206IVIP80QhN70P2PX:02092@T080NWYj0P1gMgL207moO`80P8200P2E
UID20;6a/@80ZZZZ0P2MWId40:NWY`80[Zj^0P2a/K420:j^[P80/;2`0P2l_;`20<?3``80^k^k0P2h
^;P20;^k^`D0^KVi0P2/[:`208b<S080Vi^K0P1mOGd208R8R080/;2`0P2][Jd20;6a/@80^[Zj0P30
`<020<G5a@80`L710P2f][H20:n_[`80ZJVY0P2TY:@20:2PX080W9bL0P2KVi/20:VYZ@80XZ:R0P2C
Ti<209bLW080WIfM0P2OWil209fMW@80ZJVY0P2MWId20:6QX@80Z:RX1@2YZJT20:^[Z`@0[Zj^0P2]
[Jd40:j^[P80/k>c102`/;020;Vi^@@0^;Rh0P2j^[X20<?3`bT0b>3H0P0U9BD402/[:`80;2`/0P0Z
:RX202<S8`80:b/[0P0e=CD203hn?P80MgMg0P1VIVH2038b<P80=SHf0P0S8b<2030`<080<c<c0`0e
=CD204e=C@80FEUI0P1:BTX202l_;`80:2PX0P0^;Rh203Hf=P80=cLg0P0m?Cd202`/;080:BTY0P0X
:2P203dm?@80@T920P1JFUX2030`<080<S8b0P0k>c/202h^;P80<c<c0P0`<30203Xj>P80ADE50P1K
Fe/202LW9`80?3`l0P12@T8205UIF@80?clo0P0Z:RX201/K6`<08R8R0P0O7al202PX:080@4100P2F
UYH207moO`80BDU90P0A4A4203De=@80H61P0P2@T90209:BTP80Shn?0P26QXH207IfMP80KVi^0P23
Ph<209^KV`80[Jf]0P2YZJT209jNWP80YJFU0P2XZ:P20:j^[P80/[:b0P2a/K420:n_[`80_;bl0P32
`/820<K6aP@0^KVi0`2j^[X20;Rh^080[Zj^0P2:RXX20:6QX@80LG5a0P29RHT20;Bd]080ZJVY0P2e
]KD20;Ng]`80`l?30P37alL20<71`@80]kNg102ZZZX20:FUY@80WYjN102PX:020:>SX`80XJ6Q0P2M
WId209RHV080VIVI0P2NWYh20:6QX@80Y:BT0P2PX:020:6QX@80Xj>S0`2ZZZX20:f][@@0[:b/0P2`
/;020:b/[080[jn_0P2a/K420;:b/P80[Jf]0P2b/[820;Ng]`80^k^k0P2j^[X40;bl_1l0b>3H000M
0<SPf0809RHV0P0X:2P202XZ:P@0:b/[100X:2P203<c<`80@4100P1eMGD206ATI080;Rh^0P0d=3@2
02d];@80<30`0P0a<C4303Lg=`80BTY:0P1IFET204Q8B080<c<c100^;Rh203@d=080>SXj0P0g=cL2
034a<@80:b/[0P0Y:BT203Ti>@80@d=30P1JFUX202h^;P80=3@d0P0g=cL203<c<`80;2`/0P0^;Rh2
03Ti>@80B4Q80P1IFET202TY:@80=SHf0P15ADD205IFEP80@T920P0Y:BT5028R8P807AdM0P0X:2P2
04=3@`80V9RH0P1fMWH204i>CP805aLG0P0c<c<205aLG080Shn?0P2GUiL2096AT@80PH610P1eMGD2
07IfMP80P8200P2IVIT20:n_[`80ZZZZ0P2PX:020:>SX`80ZJVY0P2][Jd20;6a/@@0/;2`0P2j^[X2
0<?3``80_[jn0P2h^;P20;Zj^P<0_;bl0P2e]KD20;2`/080R8R80P2PX:0207AdM080RXZ:0P2c/k<2
0:ZZZP80];Bd0P2i^KT20<71`@80a/K60P30`<020;Ng]`80/;2`0P2YZJT20:>SX`@0WinO0P2PX:02
0::RXP80Xj>S0P2MWId209RHV080VYZJ0P2NWYh20:6QX@80Y:BT0P2RXZ820:2PX080YJFU0`2ZZZX2
0:^[Z`80[:b/0P2][Jd40:j^[P80[Jf]0P2_[jl20;6a/@@0/;2`0P2e]KD20;Vi^@80^k^k102l_;`Y
0<SPf0808b<S0P0X:2P202TY:@80;Rh^0P0Y:BT402XZ:P80=3@d0P17AdL206][J`80GemO0P0k>c/2
034a<@80:b/[0P0_;bl2030`<0<0<c<c0P1=CDd205aLG080ATI60P0f=SH202d];@80;2`/0P0e=CD2
03Ph>080>SXj0P0];Bd202`/;080;Rh^0P0c<c<204Y:BP80E5AD0P0_;bl203@d=080>c/k0P0X:2P2
02l_;`80;Rh^0P0d=3@2055AD@80EUIF0P0Z:RX2038b<P80CDe=0P1ADE420451@@80:b/[0P0X:2P3
02<S8`80820P0P0[:b/204E5A@80U9BD0P1kNg/204];B`80820P0P0/;2`206IVIP80QhN70P2PX:02
092@T080NWYj0P1gMgL207moO`80P8200P2EUID20;6a/@80ZZZZ0P2MWId40:NWY`80[Zj^0P2a/K42
0:j^[P80/;2`0P2l_;`20<?3``80^k^k0P2h^;P20;^k^`D0^KVi0P2/[:`208b<S080Vi^K0P1mOGd2
08R8R080/;2`0P2][Jd20;6a/@80^[Zj0P30`<020<G5a@80`L710P2f][H20:n_[`80ZJVY0P2TY:@2
0:2PX080W9bL0P2KVi/20:VYZ@80XZ:R0P2CTi<209bLW080WIfM0P2OWil209fMW@80ZJVY0P2MWId2
0:6QX@80Z:RX1@2YZJT20:^[Z`@0[Zj^0P2][Jd40:j^[P80/k>c102`/;020;Vi^@@0^;Rh0P2j^[X2
0<?3`bT0b>3H0P0U9BD402/[:`80;2`/0P0Z:RX202<S8`80:b/[0P0e=CD203hn?P80MgMg0P1VIVH2
038b<P80=SHf0P0S8b<2030`<080<c<c0`0e=CD204e=C@80FEUI0P1:BTX202l_;`80:2PX0P0^;Rh2
03Hf=P80=cLg0P0m?Cd202`/;080:BTY0P0X:2P203dm?@80@T920P1JFUX2030`<080<S8b0P0k>c/2
02h^;P80<c<c0P0`<30203Xj>P80ADE50P1KFe/202LW9`80?3`l0P12@T8205UIF@80?clo0P0Z:RX2
01/K6`<08R8R0P0O7al202PX:080@4100P2FUYH207moO`80BDU90P0A4A4203De=@80H61P0P2@T902
09:BTP80Shn?0P26QXH207IfMP80KVi^0P23Ph<209^KV`80[Jf]0P2YZJT209jNWP80YJFU0P2XZ:P2
0:j^[P80/[:b0P2a/K420:n_[`80_;bl0P32`/820<K6aP@0^KVi0`2j^[X20;Rh^080[Zj^0P2:RXX2
0:6QX@80LG5a0P29RHT20;Bd]080ZJVY0P2e]KD20;Ng]`80`l?30P37alL20<71`@80]kNg102ZZZX2
0:FUY@80WYjN102PX:020:>SX`80XJ6Q0P2MWId209RHV080VIVI0P2NWYh20:6QX@80Y:BT0P2PX:02
0:6QX@80Xj>S0`2ZZZX20:f][@@0[:b/0P2`/;020:b/[080[jn_0P2a/K420;:b/P80[Jf]0P2b/[82
0;Ng]`80^k^k0P2j^[X40;bl_1l0b>3H000M0<SPf0809RHV0P0W9bL202PX:080:BTY0P0Z:RX202LW
9`80:BTY0P10@40205ADE080J6QX0P1@D50203Lg=`80@T920P0j>SX203@d=080;bl_0`0^;Rh203hn
?P80C4a<0P12@T8203De=@80;bl_0P0^;Rh203@d=080>SXj0P0h>3P203@d=080<30`0P0^;Rh203Hf
=P80?Shn0P1@D50203dm?@80>SXj0P0d=3@202h^;P809RHV0P0/;2`203Xj>P80GEeM0P1NGUh203@d
=080BDU90P1:BTX204U9B@80@T920P0i>CT202d];@<09BDU0P0[:b/203Ti>@80JVYZ0P2DU9@206MW
I`80=SHf0P0C4a<202DU9@80@4100P1YJFT208J6QP80UYJF0P2LW9`207UiN@@0M7Ad0P26QXH209ZJ
VP80YjNW0P2_[jl20:b/[080Z:RX0P2ZZZX20:j^[P80/;2`0P2c/k<20;Zj^P80`<300P2m_Kd20;Vi
^@80]kNg0`2f][H40;Bd]080QhN70P2NWYh208>3P`80Rh^;0P2c/k<20::RXP80[:b/0P2c/k<20;jn
_P80a/K60P35aLD20;no_`80][Jf0P2[Zj/20:JVYP80XZ:R0P2QXJ420::RXP80Xj>S0P2TY:@20:6Q
X@80WYjN0P2IVIT209NGU`80W9bL0P2QXJ420:2PX080WinO0P2SXj<30:NWY`@0ZJVY0P2[Zj/60:f]
[@80[Zj^0P2_[jl20;6a/@80/k>c0P2f][H20;Vi^@80_;bl0P2m_Kd20;jn_RT0b>3H0P0[:b/202PX
:0@0:b/[0P0Y:BT202XZ:P80:b/[0P0c<c<205YJFP80K6a/0P1=CDd203lo?`80?Shn0P0m?Cd203@d
=080;bl_0`0o?cl20451@@80B4Q80P1;Bd/2034a<@80;bl_0P0Z:RX2038b<P80>CTi0P17AdL2038b
<P80<C4a0P0/;2`2030`<080?Cdm0P1BDU8203lo?`@0>3Ph0P0_;bl202PX:080;2`/0P0h>3P206QX
J080HF5Q0P0^;Rh204Y:BP80DE5A0P1<C4`204Q8B080;bl_0P0W9bL3028R8P8092@T0P0^;Rh206i^
KP80TI6A0P1YJFT202h^;P807AdM0P0S8b<203Hf=P80JFUY0P2:RXX20::RXP80RXZ:0P1hN7P207Yj
NP80LW9b0P1kNg/209JFUP80^[Zj0P2[Zj/40:JVYP80[:b/0P2][Jd20:b/[080/k>c0P2o_kl20<;2
`P80_;bl102j^[X30;Bd]080^KVi0P2_[jl208V9R@80V9RH0P27QhL208^;R`80ZZZZ0P2VYZH20:f]
[@80];Bd0P2l_;`20<G5a@80bLW90P30`<020;:b/P80[:b/0P2WYjL20::RXP80XJ6Q0P2OWil20:6Q
X@80ZZZZ0P2RXZ8209bLW080UYJF0P2IVIT209^KV`80XJ6Q0P2PX:0209bLW080Xj>S0`2VYZH20:VY
Z@80ZZZZ0P2[Zj/20:j^[P80ZZZZ0P2^[Zh20:b/[080/;2`0P2[Zj/20;:b/P80_Kfm0P2k^k/20;Rh
^080_kno0P31`L4Y0<SPf080;2`/0P0U9BD202LW9`80:RXZ0P0[:b/202`/;080:RXZ0P0l?3`204m?
C`80KVi^0P18B4P203Xj>P80@410100g=cL2038b<P<0:RXZ0P0j>SX204U9B@80ADE50P0i>CT203@d
=080;Bd]0P0a<C4203Lg=`80@T920P0h>3P202`/;080:b/[0P0h>3P20410@080C4a<0P0m?Cd203Xj
>P80<c<c0P0U9BD402LW9`80>3Ph0P1MGEd205aLG080=3@d0P19BDT204I6AP80CDe=0P13@d<20410
@080:RXZ0`0];Bd203<c<`80>CTi0P1OGel209JFUP80Kfm_0P0j>SX2018B4P809BDU0P0n?Sh206][
J`80OWin102HV9P207YjNP80NGUi0P1eMGD208J6QP80W9bL0P2VYZH20;:b/P80[Zj^0P2ZZZX40:^[
Z`80[:b/0P2g]kL20;Zj^P80`L710P2j^[X20;Fe]@80^KVi0`2b/[820;Jf]P80/K6a0P26QXH209RH
V080PX:20P2>SXh20;2`/080WinO0P2][Jd20;Jf]P80_kno0P38b<P20<;2`P80_kno0P2i^KT20:ZZ
ZP80YJFU0P2RXZ820:BTY080X:2P0P2SXj<20:FUY@80Xj>S0P2NWYh209VIV@80UIFE0P2KVi/209nO
W`80XZ:R0P2MWId20::RXP<0YjNW0P2XZ:P20:ZZZP80Zj^[0P2_[jl20:b/[080ZZZZ0P2][Jd20;:b
/P80[:b/0P2d];@20;Jf]P80^[Zj0P2l_;`40;no_al0b>3H000M0<SPf0809RHV0P0W9bL202PX:080
:BTY0P0Z:RX202LW9`80:BTY0P10@40205ADE080J6QX0P1@D50203Lg=`80@T920P0j>SX203@d=080
;bl_0`0^;Rh203hn?P80C4a<0P12@T8203De=@80;bl_0P0^;Rh203@d=080>SXj0P0h>3P203@d=080
<30`0P0^;Rh203Hf=P80?Shn0P1@D50203dm?@80>SXj0P0d=3@202h^;P809RHV0P0/;2`203Xj>P80
GEeM0P1NGUh203@d=080BDU90P1:BTX204U9B@80@T920P0i>CT202d];@<09BDU0P0[:b/203Ti>@80
JVYZ0P2DU9@206MWI`80=SHf0P0C4a<202DU9@80@4100P1YJFT208J6QP80UYJF0P2LW9`207UiN@@0
M7Ad0P26QXH209ZJVP80YjNW0P2_[jl20:b/[080Z:RX0P2ZZZX20:j^[P80/;2`0P2c/k<20;Zj^P80
`<300P2m_Kd20;Vi^@80]kNg0`2f][H40;Bd]080QhN70P2NWYh208>3P`80Rh^;0P2c/k<20::RXP80
[:b/0P2c/k<20;jn_P80a/K60P35aLD20;no_`80][Jf0P2[Zj/20:JVYP80XZ:R0P2QXJ420::RXP80
Xj>S0P2TY:@20:6QX@80WYjN0P2IVIT209NGU`80W9bL0P2QXJ420:2PX080WinO0P2SXj<30:NWY`@0
ZJVY0P2[Zj/60:f][@80[Zj^0P2_[jl20;6a/@80/k>c0P2f][H20;Vi^@80_;bl0P2m_Kd20;jn_RT0
b>3H0P0[:b/202PX:0@0:b/[0P0Y:BT202XZ:P80:b/[0P0c<c<205YJFP80K6a/0P1=CDd203lo?`80
?Shn0P0m?Cd203@d=080;bl_0`0o?cl20451@@80B4Q80P1;Bd/2034a<@80;bl_0P0Z:RX2038b<P80
>CTi0P17AdL2038b<P80<C4a0P0/;2`2030`<080?Cdm0P1BDU8203lo?`@0>3Ph0P0_;bl202PX:080
;2`/0P0h>3P206QXJ080HF5Q0P0^;Rh204Y:BP80DE5A0P1<C4`204Q8B080;bl_0P0W9bL3028R8P80
92@T0P0^;Rh206i^KP80TI6A0P1YJFT202h^;P807AdM0P0S8b<203Hf=P80JFUY0P2:RXX20::RXP80
RXZ:0P1hN7P207YjNP80LW9b0P1kNg/209JFUP80^[Zj0P2[Zj/40:JVYP80[:b/0P2][Jd20:b/[080
/k>c0P2o_kl20<;2`P80_;bl102j^[X30;Bd]080^KVi0P2_[jl208V9R@80V9RH0P27QhL208^;R`80
ZZZZ0P2VYZH20:f][@80];Bd0P2l_;`20<G5a@80bLW90P30`<020;:b/P80[:b/0P2WYjL20::RXP80
XJ6Q0P2OWil20:6QX@80ZZZZ0P2RXZ8209bLW080UYJF0P2IVIT209^KV`80XJ6Q0P2PX:0209bLW080
Xj>S0`2VYZH20:VYZ@80ZZZZ0P2[Zj/20:j^[P80ZZZZ0P2^[Zh20:b/[080/;2`0P2[Zj/20;:b/P80
_Kfm0P2k^k/20;Rh^080_kno0P31`L4Y0<SPf080;2`/0P0U9BD202LW9`80:RXZ0P0[:b/202`/;080
:RXZ0P0l?3`204m?C`80KVi^0P18B4P203Xj>P80@410100g=cL2038b<P<0:RXZ0P0j>SX204U9B@80
ADE50P0i>CT203@d=080;Bd]0P0a<C4203Lg=`80@T920P0h>3P202`/;080:b/[0P0h>3P20410@080
C4a<0P0m?Cd203Xj>P80<c<c0P0U9BD402LW9`80>3Ph0P1MGEd205aLG080=3@d0P19BDT204I6AP80
CDe=0P13@d<20410@080:RXZ0`0];Bd203<c<`80>CTi0P1OGel209JFUP80Kfm_0P0j>SX2018B4P80
9BDU0P0n?Sh206][J`80OWin102HV9P207YjNP80NGUi0P1eMGD208J6QP80W9bL0P2VYZH20;:b/P80
[Zj^0P2ZZZX40:^[Z`80[:b/0P2g]kL20;Zj^P80`L710P2j^[X20;Fe]@80^KVi0`2b/[820;Jf]P80
/K6a0P26QXH209RHV080PX:20P2>SXh20;2`/080WinO0P2][Jd20;Jf]P80_kno0P38b<P20<;2`P80
_kno0P2i^KT20:ZZZP80YJFU0P2RXZ820:BTY080X:2P0P2SXj<20:FUY@80Xj>S0P2NWYh209VIV@80
UIFE0P2KVi/209nOW`80XZ:R0P2MWId20::RXP<0YjNW0P2XZ:P20:ZZZP80Zj^[0P2_[jl20:b/[080
ZZZZ0P2][Jd20;:b/P80[:b/0P2d];@20;Jf]P80^[Zj0P2l_;`40;no_al0b>3H000M0<SPf0@09bLW
0P0X:2P202TY:@80:RXZ0P0W9bL202/[:`80C4a<0P1WIfL2059BDP80>3Ph0P13@d<204e=C@80A4A4
0P0h>3P2030`<0<0:b/[0P0c<c<203`l?080>c/k0P0g=cL2034a<@80;Bd]0P0b<S8403Ti>@80>3Ph
0P0d=3@2038b<P80=CDe0P0j>SX20492@P80BTY:0P11@D4203De=@80:BTY0P0R8R8202`/;080>SXj
0P1[Jf/205eMG@80A4A40P1MGEd204m?C`80@D510P17AdL204a<C080>CTi0`0Y:BT203Lg=`80BDU9
0P2?Shl208N7Q`80FUYJ0P0S8b<201XJ6P807AdM0P0Y:BT203lo?`80K6a/0P2@T9020:n_[`80PH61
0P1hN7P2071`L080MGEe0P23Ph<20:2PX080^KVi0P2d];@20:VYZ@80YjNW0P2YZJT20;2`/080]kNg
0P2k^k/20;bl_080^k^k0P2i^KT20;Bd]0<0/;2`0P2c/k<20;Ng]`80Rh^;0P2JVYX209:BTP80SHf=
0P2`/;0209^KV`80YZJV0P2_[jl20;^k^`80aLG50P38b<P20<K6aP80^k^k0P2_[jl20:RXZ0X0Y:BT
0P2UYJD20:BTY080VYZJ0P2BTY8209JFUP@0WIfM0P2NWYh20:6QX@<0Y:BT0P2UYJD20:JVYP80ZJVY
0P2[Zj/40:b/[080[Jf]0P2^[Zh20;:b/P80]kNg0P2h^;P20;Vi^@80_;bl0P2o_kl20<30`2T0b>3H
0P0U9BD202LW9`80:BTY0P0S8b<202d];@80:2PX0P0_;bl204E5A@80J6QX0P1GEeL203<c<`80AdM7
0P1;Bd/204i>CP80=CDe0P0[:b/302`/;080;bl_0P0j>SX20492@PH0<C4a0P0`<30203Ti>@80>3Ph
0P0e=CD203Hf=P80<c<c0P0b<S8203Ti>@80B4Q80P1;Bd/203Xj>P80>CTi0P0V9RH202LW9`80;2`/
0P0h>3P206YZJP80Fe]K0P0l?3`206MWI`80@d=30P12@T82055AD@80AdM70P0g=cL303<c<`80=3@d
0P1?Cdl209ZJVP80R8R80P1ADE4202XZ:P807alO0P0Q8B42020P8080@D510P1hN7P208^;R`80ZZZZ
0P25QHD207UiN@80L71`0P1gMgL20861P@80XZ:R0P2f][H20;>c/`H0ZZZZ0P2][Jd20;^k^`80^;Rh
0P2k^k/20;jn_P@0];Bd0`2][Jd20;Jf]P80/[:b0P2CTi<209ZJVP80Shn?0P2EUID20:NWY`80XJ6Q
0P2TY:@20;:b/P80^KVi1036a/H20<G5a@80_;bl0P2^[Zh20:ZZZP80XZ:R0P2UYJD20:JVYP80XJ6Q
0P2TY:@20:JVYP80YjNW0P2GUiL209>CT`@0VYZJ0P2NWYh209^KV`80YJFU0`2RXZ820:VYZ@80YJFU
0P2XZ:P20:^[Z`80[Jf]0P2_[jl20:^[Z`80[Jf]0P2d];@20;Fe]@80^;Rh0P2g]kL20;bl_080_[jn
0P33`l<Y0<SPf0@09RHV0P0/;2`202<S8`80:RXZ0P0V9RH202d];@80Bd];0P1VIVH205EEE@80=cLg
0P1:BTX204e=C@80@T920P0g=cL2038b<P<0;Rh^0P0c<c<203/k>`80?Cdm0P0b<S8402h^;P80=3@d
0P0h>3P203Xj>P80=CDe0P0^;Rh203@d=080<S8b0P0g=cL20492@P80BTY:0P16ATH203Ph>080:RXZ
0P0V9RH203<c<`80>c/k0P1YJFT205eMG@80@d=30P1NGUh205=CD`80?clo0P11@D4204a<C080=cLg
0`0W9bL203Ti>@80Bd];0P2BTY8208N7Q`80EEEE0P0R8R8201`L70807QhN0P0];Bd20451@@80IfMW
0P2CTi<20;:b/P@0Ng]k0P1`L70206i^KP80QHF50P2SXj<20;Vi^@80/;2`0P2ZZZX20:RXZ080[Jf]
0P2`/;020;Rh^080][Jf0P2n_[h20;fm_@80^[Zj0P2f][H30:n_[`80/[:b0P2h^;P208j>SP80Vi^K
0P2CTi<208Z:RP80[jn_0P2LW9`20:JVYP80[:b/0P2l_;`20<;2`P80alO70P35aLD20;bl_080[jn_
0P2WYjL20:>SX`80YJFU0P2VYZH20:6QX@H0Y:BT0P2JVYX209>CT`80UiNG102MWId209jNWP80XJ6Q
0`2TY:@20:NWY`80YZJV0P2WYjL20:f][@80[:b/0P2^[Zh20:b/[080[jn_0P2c/k<20;Vi^@80][Jf
0P2j^[X20;^k^`80_[jn0P2o_klO0<SPf0007@38h=P402LW9`80:2PX0P0Y:BT202XZ:P809bLW0P0[
:b/204a<C080IfMW0P1BDU8203Ph>080@d=30P1=CDd204A4A080>3Ph0P0`<30302/[:`80<c<c0P0l
?3`203/k>`80=cLg0P0a<C4202d];@80<S8b100i>CT203Ph>080=3@d0P0b<S8203De=@80>SXj0P12
@T8204Y:BP80@D510P0e=CD202TY:@808R8R0P0/;2`203Xj>P80Jf][0P1MGEd204A4A080GEeM0P1?
Cdl20451@@80AdM70P1<C4`203Ti>@<0:BTY0P0g=cL204U9B@80Shn?0P27QhL205YJFP808b<S0P0J
6QX201dM7@80:BTY0P0o?cl206a/K080T92@0P2_[jl20861P@80N7Qh0P1`L70207EeM@80Ph>30P2P
X:020;Vi^@80];Bd0P2YZJT20:NWY`80ZJVY0P2`/;020;Ng]`80^k^k0P2l_;`20;^k^`80^KVi0P2d
];@30;2`/080/k>c0P2g]kL208^;R`80VYZJ0P2BTY8208f=S@80/;2`0P2KVi/20:JVYP80[jn_0P2k
^k/20<G5a@80b<S80P36a/H20;^k^`80[jn_0P2XZ:P:0:BTY080YJFU0P2TY:@209ZJVP80TY:B0P2F
UYH409fMW@80WYjN0P2QXJ430:BTY080YJFU0P2VYZH20:VYZ@80Zj^[102/[:`20:f][@80[Zj^0P2b
/[820;Ng]`80^;Rh0P2i^KT20;bl_080_kno0P30`<0Y0<SPf0809BDU0P0W9bL202TY:@808b<S0P0]
;Bd202PX:080;bl_0P15ADD206QXJ080EeMG0P0c<c<204M7A`80Bd];0P1>CTh203De=@80:b/[0`0/
;2`202l_;`80>SXj0P12@T86034a<@80<30`0P0i>CT203Ph>080=CDe0P0f=SH203<c<`80<S8b0P0i
>CT204Q8B080Bd];0P0j>SX203Ti>@809RHV0P0W9bL202`/;080>3Ph0P1ZJVX205]KF`80?3`l0P1W
IfL204=3@`80@T920P1ADE4204M7A`80=cLg0`0c<c<203@d=080Cdm?0P2JVYX208R8R080DE5A0P0Z
:RX201lO7`808B4Q0P0P82020451@@80N7Qh0P2;Rh/20:ZZZP80QHF50P1iNGT2071`L080MgMg0P21
PH420::RXP80][Jf0P2c/k<60:ZZZP80[Jf]0P2k^k/20;Rh^080^k^k0P2n_[h40;Bd]0<0[Jf]0P2f
][H20;:b/P80Ti>C0P2JVYX208n?S`80UIFE0P2WYjL20:6QX@80Y:BT0P2b/[820;Vi^@@0a/K60P35
aLD20;bl_080[Zj^0P2ZZZX20::RXP80YJFU0P2VYZH20:6QX@80Y:BT0P2VYZH20:NWY`80UiNG0P2C
Ti<409ZJVP80WYjN0P2KVi/20:FUY@<0XZ:R0P2YZJT20:FUY@80Z:RX0P2[Zj/20:f][@80[jn_0P2[
Zj/20:f][@80];Bd0P2e]KD20;Rh^080]kNg0P2l_;`20;jn_P80`l?3:@38h=P402HV9P80;2`/0P0S
8b<202XZ:P809RHV0P0];Bd204];B`80IVIV0P1EEED203Lg=`80BTY:0P1=CDd20492@P80=cLg0P0b
<S8302h^;P80<c<c0P0k>c/203dm?@80<S8b100^;Rh203@d=080>3Ph0P0j>SX203De=@80;Rh^0P0d
=3@2038b<P80=cLg0P12@T8204Y:BP80ATI60P0h>3P202XZ:P809RHV0P0c<c<203/k>`80JFUY0P1M
GEd204=3@`80GUiN0P1CDe<203lo?`80@D510P1<C4`203Lg=`<09bLW0P0i>CT204];B`80TY:B0P27
QhL205EEE@808R8R0P0L71`201hN7P80;Bd]0P11@D4206MWI`80Ti>C0P2b/[8407]kN`80L71`0P1^
KVh208F5Q@80Xj>S0P2i^KT20;2`/080ZZZZ0P2XZ:P20:f][@80/;2`0P2h^;P20;Jf]P80_[jn0P2m
_Kd20;Zj^P80][Jf0`2_[jl20;:b/P80^;Rh0P2>SXh209^KV`80Ti>C0P2:RXX20:n_[`80W9bL0P2V
YZH20:b/[080_;bl0P32`/820<O7a`80aLG50P2l_;`20:n_[`80YjNW0P2SXj<20:FUY@80YZJV0P2Q
XJ460:BTY080VYZJ0P2CTi<209NGU`@0WIfM0P2NWYh20:6QX@<0Y:BT0P2WYjL20:JVYP80YjNW0P2]
[Jd20:b/[080[Zj^0P2/[:`20:n_[`80/k>c0P2i^KT20;Jf]P80^[Zj0P2k^k/20;jn_P80_kno7`38
h=P001d0b>3H0P0[:b/202PX:0809RHV0P0X:2P202/[:`80:2PX0P0];Bd204m?C`80LG5a0P10@402
030`<080=CDe0P0l?3`203/k>`80>CTi0P0f=SH303<c<`80<S8b0P0c<c<203Xj>P80?clo0P0e=CD2
02/[:`80;bl_0P0e=CD203Ti>@80>SXj0P0f=SH2038b<P80<C4a0P0c<c<203`l?080AdM70P0o?cl2
03<c<`80:RXZ0P0W9bL203De=@80ADE50P1NGUh205EEE@80CDe=0P1PH60204M7A`80DE5A0P1EEED2
05QHF080EeMG0`1KFe/205aLG080N7Qh0P2ZZZX208^;R`80H61P0P0Y:BT201lO7`8071`L0P0M7Ad2
02TY:@80CDe=0P1bLW8209^KV`80UYJF0P29RHT207IfMP80LW9b0P1gMgL208j>SP80YZJV0P2c/k<2
0;Vi^@80[jn_0P2UYJD20:f][@80^;Rh0P2j^[X20;Vi^@80^;Rh0P2f][H20;:b/P<0/;2`0P2d];@2
0;Jf]P80UYJF0P2BTY8209FEU@80UiNG0P2YZJT209jNWP80YjNW0P2_[jl20;Zj^P80`l?31038b<P2
0<71`@80^;Rh0P2^[Zh20:FUY@80YZJV102XZ:P20:JVYP80YJFU0P2SXj<209jNWP80VIVI0P2GUiL2
09JFUP80V9RH0P2LW9`209nOW`L0Xj>S0P2WYjL:0:^[Z`80/K6a0P2f][H20;Rh^080^[Zj0P2m_Kd4
0<30`2T0b>3H0P0[:b/202LW9`809BDU0P0/;2`402TY:@80<C4a0P1=CDd206i^KP80BDU90P0/;2`2
03<c<`80=SHf0P0h>3P203hn?P80<c<c0`0^;Rh202d];@80=CDe0P0m?Cd204M7A`80<30`0P0];Bd2
03<c<`80=cLg0P0c<c<203Xj>P80@T92100a<C4203Lg=`80>c/k0P18B4P203dm?@80=CDe0P0V9RH2
02@T9080;Rh^0P17AdL206UYJ@80FEUI0P1>CTh206ATI080?3`l0P1;Bd/205UIF@80HF5Q0P1MGEd5
05IFEP80MgMg0P2VYZH208Z:RP80GUiN0P0W9bL201dM7@807QhN0P0P820202XZ:P80ATI60P1fMWH2
09ZJVP80Vi^K0P23Ph<207QhN080Ng]k0P1hN7P20861P@80ZZZZ0P2n_[h20;Jf]P80YJFU0P2ZZZX2
0:b/[080^KVi0P2c/k<20;Rh^080^k^k0P2f][H20;Fe]@<0[:b/0P2e]KD20;>c/`80VIVI0P2ATI42
09:BTP80V9RH0P2WYjL20:2PX080Xj>S0P2^[Zh20;Jf]P80`l?30P39bLT20<O7a`80`l?30P2f][H2
0:f][@80YJFU0P2WYjL20:RXZ080ZJVY0P2TY:@209nOW`80X:2P0P2VYZH209BDU080Ti>C0P2HV9P2
09^KV`80W9bL0P2PX:0309nOW`80Xj>S0P2RXZ820:JVYP80[Jf]0P2ZZZX20:VYZ@80Z:RX0P2^[Zh2
0;>c/`80]kNg0P2d];@20;Zj^P80^k^k0P2m_Kd20;no_bT0b>3H0P0[:b/202PX:08092@T0P0Y:BT2
02/[:`80:2PX0P0V9RH205ADE080LG5a0P12@T8202/[:`80<S8b0P0i>CT20451@@80=SHf0P0g=cL3
03<c<`80:b/[0P0g=cL203hn?P80@T920P0e=CD202XZ:P80<30`0P0c<c<203/k>`80?Cdm0P0h>3P2
03Lg=`80=SHf0P0e=CD20410@080ADE50P0j>SX2034a<@809BDU0P0R8R82034a<@80ATI60P1OGel2
05ADE080De=C0P1IFET204Y:BP80DU9B0P1CDe<205]KF`D0E5AD0P1NGUh2071`L080Z:RX0P2>SXh2
05mOG`809bLW0P0Q8B4201PH608071`L0P0Y:BT2051@D080LW9b102JVYX208Z:RP80MGEe0P1cLg<2
07EeM@80T92@0P2WYjL20:j^[P80]kNg0P2a/K420:6QX@80[Jf]0P2h^;P20;bl_080^KVi0P2h^;P2
0;Bd]080/k>c0`2a/K420;Bd]080/k>c0P2IVIT209:BTP80UYJF0P2IVIT20:^[Z`80XJ6Q0P2UYJD2
0;2`/080^k^k0P37alL20<W9b@80aLG50P38b<P20;Ng]`80Zj^[102WYjL20:RXZ0@0YjNW0P2UYJD2
0:>SX`80Vi^K0P2JVYX609NGU`80W9bL0P2PX:030:BTY080Xj>S102UYJD20:^[Z`80ZJVY0P2/[:`2
0:^[Z`80ZZZZ0P2`/;020;Jf]P80]kNg0P2j^[X20;bl_080`/;20P31`L4O0<SPf0007@38h=P202/[
:`80:2PX0P0V9RH202PX:080:b/[0P0X:2P202d];@80Cdm?0P1aLG420410@080<30`0P0e=CD203`l
?080>c/k0P0i>CT203Hf=P<0<c<c0P0b<S8203<c<`80>SXj0P0o?cl203De=@80:b/[0P0_;bl203De
=@80>CTi0P0j>SX203Hf=P80<S8b0P0a<C4203<c<`80?3`l0P17AdL203lo?`80<c<c0P0Z:RX202LW
9`80=CDe0P15ADD205iNGP80EEEE0P1=CDd2061PH080AdM70P1ADE4205EEE@80F5QH0P1GEeL305]K
F`80G5aL0P1hN7P20:ZZZP80Rh^;0P1PH60202TY:@807alO0P0L71`201dM7@80:BTY0P1=CDd2079b
LP80Vi^K0P2FUYH208V9R@80MWIf0P1bLW8207MgM`80SXj>0P2VYZH20;>c/`80^KVi0P2_[jl20:FU
Y@80[Jf]0P2h^;P20;Zj^P80^KVi0P2h^;P20;Jf]P80/[:b0`2`/;020;Bd]080][Jf0P2FUYH209:B
TP80UIFE0P2GUiL20:VYZ@80WYjN0P2WYjL20:n_[`80^[Zj0P33`l<40<S8b080`L710P2h^;P20:j^
[P80YJFU0P2VYZH40:RXZ080YZJV0P2UYJD20:>SX`80WYjN0P2IVIT209NGU`80UYJF0P2HV9P209bL
W080WinO1`2SXj<20:NWY`X0Zj^[0P2a/K420;Jf]P80^;Rh0P2j^[X20;fm_@@0`<30:@38h=P202/[
:`809bLW0P0U9BD202`/;0@0:BTY0P0a<C4204e=C@80KVi^0P19BDT202`/;080<c<c0P0f=SH203Ph
>080?Shn0P0c<c<302h^;P80;Bd]0P0e=CD203dm?@80AdM70P0`<30202d];@80<c<c0P0g=cL203<c
<`80>SXj0P12@T84034a<@80=cLg0P0k>c/204Q8B080?Cdm0P0e=CD202HV9P8092@T0P0^;Rh204M7
A`80JFUY0P1IFET204i>CP80I6AT0P0l?3`204];B`80FEUI0P1QHF4205eMG@D0EUIF0P1gMgL20:JV
YP80RXZ:0P1NGUh202LW9`807AdM0P0N7Qh2020P8080:RXZ0P16ATH207IfMP80VYZJ0P2KVi/208>3
P`80N7Qh0P1kNg/207QhN080PH610P2ZZZX20;jn_P80][Jf0P2UYJD20:ZZZP80[:b/0P2i^KT20;>c
/`80^;Rh0P2k^k/20;Jf]P80]KFe0`2/[:`20;Fe]@80/k>c0P2IVIT2096AT@80TY:B0P2HV9P20:NW
Y`80X:2P0P2SXj<20:j^[P80][Jf0P33`l<20<W9b@80alO70P33`l<20;Jf]P80[Jf]0P2UYJD20:NW
Y`80Z:RX0P2YZJT20:BTY080WinO0P2PX:020:JVYP80U9BD0P2CTi<209RHV080Vi^K0P2LW9`20:2P
X0<0WinO0P2SXj<20::RXP80YZJV0P2][Jd20:ZZZP80ZJVY0P2XZ:P20:j^[P80/k>c0P2g]kL20;Bd
]080^[Zj0P2k^k/20;fm_@80_kno:@38h=P202/[:`80:2PX0P0T92@202TY:@80:b/[0P0X:2P202HV
9P80E5AD0P1aLG420492@P80:b/[0P0b<S8203Ti>@80@D510P0f=SH203Lg=`<0<c<c0P0[:b/203Lg
=`80?Shn0P12@T8203De=@80:RXZ0P0`<30203<c<`80>c/k0P0m?Cd203Ph>080=cLg0P0f=SH203De
=@80@4100P15ADD203Xj>P80<C4a0P0U9BD2028R8P80<C4a0P16ATH205mOG`80E5AD0P1CDe<205UI
F@80BTY:0P1BDU8205=CD`80Fe]K1@1DE5@205iNGP80L71`0P2XZ:P208j>SP80GemO0P0W9bL2024Q
8@8061PH0P0L71`202TY:@80D51@0P1bLW8409ZJVP80RXZ:0P1eMGD207=cL`80MGEe0P2@T9020:NW
Y`80[Zj^0P2g]kL20;6a/@80XJ6Q0P2][Jd20;Rh^080_;bl0P2i^KT20;Rh^080];Bd0P2c/k<30;6a
/@80];Bd0P2c/k<209VIV@80TY:B0P2FUYH209VIV@80Zj^[0P2QXJ420:FUY@80/;2`0P2k^k/20<O7
a`80bLW90P35aLD20<S8b080]kNg0P2[Zj/40:NWY`80Z:RX102WYjL20:FUY@80Xj>S0P2KVi/209ZJ
VPH0UiNG0P2LW9`20:2PX0<0Y:BT0P2SXj<40:FUY@80Zj^[0P2YZJT20:b/[080Zj^[0P2ZZZX20;2`
/080][Jf0P2g]kL20;Zj^P80_;bl0P32`/820<71`Al0b>3H000M0<SPf080:b/[0P0X:2P202HV9P80
:2PX0P0[:b/202PX:080;Bd]0P1?Cdl2075aL@80@4100P0`<30203De=@80?3`l0P0k>c/203Ti>@80
=SHf0`0c<c<2038b<P80<c<c0P0j>SX203lo?`80=CDe0P0[:b/202l_;`80=CDe0P0i>CT203Xj>P80
=SHf0P0b<S82034a<@80<c<c0P0l?3`204M7A`80?clo0P0c<c<202XZ:P809bLW0P0e=CD204E5A@80
GUiN0P1EEED204e=C@80H61P0P17AdL2055AD@80EEEE0P1HF5P205MGE`<0Fe]K0P1LG5`207QhN080
ZZZZ0P2;Rh/2061PH080:BTY0P0O7al201`L70807AdM0P0Y:BT204e=C@80LW9b0P2KVi/209JFUP80
RHV90P1fMWH2079bLP80MgMg0P2>SXh20:JVYP80/k>c0P2i^KT20:n_[`80YJFU0P2][Jd20;Rh^080
^[Zj0P2i^KT20;Rh^080][Jf0P2b/[830;2`/080];Bd0P2f][H209JFUP80TY:B0P2EUID209NGU`80
ZJVY0P2NWYh20:NWY`80[jn_0P2j^[X20<?3``@0b<S80P31`L420;Rh^080[Zj^0P2UYJD20:JVYP@0
Z:RX0P2VYZH20:FUY@80Xj>S0P2NWYh209VIV@80UiNG0P2FUYH209RHV080W9bL0P2OWil70:>SX`80
YjNW2P2[Zj/20;6a/@80][Jf0P2h^;P20;Zj^P80_Kfm1030`<0Y0<SPf080:b/[0P0W9bL202DU9@80
;2`/100Y:BT2034a<@80CDe=0P1^KVh204U9B@80;2`/0P0c<c<203Hf=P80>3Ph0P0n?Sh203<c<`<0
;Rh^0P0];Bd203De=@80?Cdm0P17AdL2030`<080;Bd]0P0c<c<203Lg=`80<c<c0P0j>SX20492@P@0
<C4a0P0g=cL203/k>`80B4Q80P0m?Cd203De=@809RHV0P0T92@202h^;P80AdM70P1YJFT205UIF@80
CTi>0P1TI6@203`l?080Bd];0P1IFET2065QH@80GEeM1@1FEUH207MgM`80YZJV0P2:RXX205iNGP80
9bLW0P0M7Ad201hN7P80820P0P0Z:RX204I6AP80MWIf0P2JVYX209^KV`80Ph>30P1hN7P207]kN`80
N7Qh0P21PH420:ZZZP80_[jn0P2f][H20:FUY@80ZZZZ0P2/[:`20;Vi^@80/k>c0P2h^;P20;^k^`80
][Jf0P2e]KD30:b/[080]KFe0P2c/k<209VIV@80TI6A0P2BTY8209RHV080YjNW0P2PX:020:>SX`80
[Zj^0P2f][H20<?3``80bLW90P37alL20<?3``80][Jf0P2][Jd20:FUY@80YjNW0P2XZ:P20:VYZ@80
Y:BT0P2OWil20:2PX080YZJV0P2DU9@209>CT`80V9RH0P2KVi/209bLW080X:2P0`2OWil20:>SX`80
XZ:R0P2VYZH20:f][@80ZZZZ0P2YZJT20:RXZ080[Zj^0P2c/k<20;Ng]`80];Bd0P2j^[X20;^k^`80
_Kfm0P2o_klY0<SPf080:b/[0P0X:2P202@T9080:BTY0P0[:b/202PX:0809RHV0P1DE5@2075aL@80
@T920P0[:b/2038b<P80>CTi0P11@D4203Hf=P80=cLg0`0c<c<202/[:`80=cLg0P0n?Sh20492@P80
=CDe0P0Z:RX2030`<080<c<c0P0k>c/203dm?@80>3Ph0P0g=cL203Hf=P80=CDe0P10@40204E5A@80
>SXj0P0a<C4202DU9@808R8R0P0a<C4204I6AP80GemO0P1DE5@205=CD`80FEUI0P1:BTX2059BDP80
De=C0P1KFe/505ADE080GUiN0P1`L7020:RXZ080SXj>0P1OGel202LW9`808B4Q0P0H61P201`L7080
:BTY0P1@D502079bLP@0VYZJ0P2:RXX207EeM@80Lg=c0P1eMGD2092@T080YjNW0P2^[Zh20;Ng]`80
/K6a0P2QXJ420:f][@80^;Rh0P2l_;`20;Vi^@80^;Rh0P2d];@20;>c/`<0/K6a0P2d];@20;>c/`80
VIVI0P2BTY8209JFUP80VIVI0P2[Zj/20:6QX@80YJFU0P2`/;020;^k^`80alO70P39bLT20<G5a@80
b<S80P2g]kL20:^[Z`@0YjNW0P2XZ:P40:NWY`80YJFU0P2SXj<209^KV`80VYZJ1P2GUiL209bLW080
X:2P0`2TY:@20:>SX`@0YJFU0P2[Zj/20:VYZ@80[:b/0P2[Zj/20:ZZZP80/;2`0P2f][H20;Ng]`80
^[Zj0P2l_;`20<;2`P80`L717`38h=P001d0b>3H0P0_;bl202XZ:P809BDU0P0X:2P202d];@80:RXZ
0P0_;bl2059BDP80Lg=c0P0d=3@202d];@809BDU0P0Y:BT202l_;`80=cLg0P0l?3`303hn?P80=SHf
0P0_;bl203/k>`80ADE50P0i>CT202XZ:P80;2`/0P0b<S8203Lg=`80>c/k0P0g=cL2038b<P80;Rh^
0P0];Bd203Lg=`80@4100P0k>c/203<c<`@0;Rh^0P0l?3`404a<C080CTi>0P1FEUH2061PH080A4A4
0P1WIfL206EUI@80H61P0P1BDU8304];B`80>CTi0P1VIVH209bLW080SHf=0P1WIfL203<c<`808b<S
0P0M7Ad201PH60807AdM0P0a<C4204m?C`80Ng]k0P2QXJ4209RHV080Ph>30P1gMgL2079bLP80O7al
0P2>SXh20:b/[080`l?30P2f][H20:BTY080[:b/0P2g]kL20;Rh^080]kNg0P2d];@20;6a/@D0/;2`
0P2c/k<20;:b/P80WinO0P2;Rh/209BDU0@0XZ:R0P2UYJD20:ZZZP80/;2`0P2i^KT20<71`@80aLG5
0P37alL20<G5a@80`<300P2b/[820:JVYP80Z:RX0P2/[:`20:^[Z`80ZJVY0P2UYJD20::RXP@0Xj>S
0P2KVi/209>CT`80UIFE0P2IVIT209fMW@L0XJ6Q0P2VYZH40:ZZZP@0ZJVY0P2ZZZX20:n_[`80]KFe
0P2h^;P20;^k^`80_[jn0P30`<020<71`BT0b>3H0P0];Bd202TY:@809RHV0P0W9bL202h^;P80:2PX
0P0[:b/205MGE`80KVi^0P0n?Sh202LW9`80:b/[0P0^;Rh202XZ:P80>3Ph0P10@40303lo?`80;bl_
0P0e=CD203Lg=`80A4A40P0d=3@202`/;080;bl_0P0d=3@203Ph>080?Cdm0P0g=cL2034a<@80<S8b
0P0a<C4202h^;P80A4A40P0l?3`2034a<@80;Rh^0P0a<C4203`l?080Bd];0P1EEED204Q8B080FEUI
0P1KFe/204E5A@80J6QX0P1UIFD205mOG`80DU9B0`1CDe<203hn?P80J6QX0P2TY:@208b<S080Kfm_
0P0f=SH202<S8`@07AdM0P0P820202TY:@80DU9B0P25QHD209NGU`80Vi^K0P20P80207UiN@80LW9b
0P1kNg/208j>SP80[jn_0P30`<020;Ng]`80YZJV0P2/[:`20;Rh^080]KFe0P2j^[X20;2`/080/[:b
0P2`/;050;>c/`80/K6a0P2QXJ4208f=S@80T92@0P2TY:@40:JVYP80ZZZZ0P2a/K420;Ng]`80`<30
0P37alL20<G5a@80b/[:0P2n_[h20;2`/080Z:RX0P2VYZH40:f][@80Zj^[0P2TY:@20::RXP80Xj>S
0P2TY:@209fMW@80UIFE0P2BTY8209^KV`80W9bL0`2QXJ420:2PX080XZ:R0P2VYZH20:ZZZP@0Zj^[
0P2ZZZX20:RXZ080[:b/0P2d];@20;Rh^080^k^k0P2m_Kd20<30`080`L71:@38h=P202h^;P80:2PX
0P0Q8B4202XZ:P80;2`/0P0W9bL2038b<P80E5AD0P1eMGD203<c<`80;bl_0P0S8b<202TY:@80=CDe
0P0i>CT203Ph>0<0@410100a<C4203Xj>P80ATI60P0f=SH202/[:`80;Rh^0P0_;bl203dm?@80>3Ph
0P0f=SH203De=@80:RXZ0P0];Bd2038b<P80A4A41P0e=CD2030`<080?clo0P1>CTh204Q8B080Cdm?
0P1CDe<2065QH@80Bd];0P1VIVH2065QH@80HV9R0P1CDe<304e=C@80?3`l0P1]KFd209JFUP80SXj>
0P1[Jf/2034a<@809RHV0P0Q8B4201PH60806QXJ0P0a<C4204i>CP80O7al0P2OWil209NGU`80PX:2
0P1iNGT207AdM080NGUi0P2>SXh20:b/[080`l?30P2g]kL20:FUY@80ZZZZ0P2e]KD20;fm_@80/k>c
0P2e]KD20:j^[P80];Bd0`2_[jl40;>c/`80WinO0P28R8P209FEU@80X:2P102SXj<20:b/[080[jn_
0P2m_Kd20<30`080`L710P36a/H20<c<c080_Kfm0P2a/K420:JVYP80ZJVY0P2[Zj/20:RXZ080ZJVY
0P2WYjL20:>SX`@0XZ:R0P2LW9`209BDU080Ti>C0P2HV9P209jNWP<0XZ:R0P2NWYh20:>SX`80YjNW
0P2][Jd20:RXZ080ZJVY0P2/[:`20:^[Z`80[Jf]102g]kL20;bl_080_[jn0P32`/820;jn_Ql0b>3H
000M0<SPf080;bl_0P0Z:RX202DU9@80:2PX0P0];Bd202XZ:P80;bl_0P1BDU8207=cL`80=3@d0P0]
;Bd202DU9@80:BTY0P0_;bl203Lg=`80?3`l0`0n?Sh203Hf=P80;bl_0P0k>c/204E5A@80>CTi0P0Z
:RX202`/;080<S8b0P0g=cL203/k>`80=cLg0P0b<S8202h^;P80;Bd]0P0g=cL20410@080>c/k0P0c
<c<402h^;P80?3`l101<C4`204i>CP80EUIF0P1PH60204A4A080IfMW0P1UIFD2061PH080DU9B0`1;
Bd/203Ti>@80IVIV0P2LW9`208f=S@80IfMW0P0c<c<202<S8`807AdM0P0H61P201dM7@80<C4a0P1?
Cdl207]kN`80XJ6Q0P2HV9P208>3P`80MgMg0P1bLW8207alO080SXj>0P2/[:`20<?3``80][Jf0P2T
Y:@20:b/[080]kNg0P2h^;P20;Ng]`80];Bd0P2a/K450;2`/080/k>c0P2b/[8209nOW`80Rh^;0P2D
U9@40::RXP80YJFU0P2ZZZX20;2`/080^KVi0P31`L420<G5a@80alO70P35aLD20<30`080/[:b0P2V
YZH20:RXZ080[:b/0P2[Zj/20:VYZ@80YJFU0P2RXZ840:>SX`80Vi^K0P2CTi<209FEU@80VIVI0P2M
WId70:6QX@80YZJV102ZZZX40:VYZ@80ZZZZ0P2_[jl20;Fe]@80^;Rh0P2k^k/20;jn_P80`<300P31
`L4Y0<SPf080;Bd]0P0Y:BT202HV9P809bLW0P0^;Rh202PX:080:b/[0P1GEeL206i^KP80?Shn0P0W
9bL202/[:`80;Rh^0P0Z:RX203Ph>080@4100`0o?cl202l_;`80=CDe0P0g=cL204A4A080=3@d0P0/
;2`202l_;`80=3@d0P0h>3P203dm?@80=cLg0P0a<C42038b<P80<C4a0P0^;Rh204A4A080?3`l0P0a
<C4202h^;P80<C4a0P0l?3`204];B`80EEEE0P18B4P205UIF@80Fe]K0P15ADD206QXJ080IFEU0P1O
Gel2059BDP<0De=C0P0n?Sh206QXJ080Y:BT0P2<S8`206m_K`80=SHf0P0S8b<401dM7@80820P0P0Y
:BT2059BDP80QHF50P2GUiL209^KV`80P8200P1iNGT2079bLP80Ng]k0P2>SXh20:n_[`80`<300P2g
]kL20:JVYP80[:b/0P2h^;P20;Fe]@80^[Zj0P2`/;020;:b/P80/;2`1@2c/k<20;6a/@80XJ6Q0P2=
SHd2092@T080Y:BT102VYZH20:ZZZP80/K6a0P2g]kL20<30`080alO70P35aLD20<[:bP80_[jn0P2`
/;020:RXZ080YZJV102][Jd20:^[Z`80Y:BT0P2RXZ820:>SX`80Y:BT0P2MWId209FEU@80TY:B0P2K
Vi/209bLW0<0XJ6Q0P2PX:020::RXP80YZJV0P2ZZZX40:^[Z`80ZZZZ0P2XZ:P20:b/[080];Bd0P2h
^;P20;^k^`80_Kfm0P30`<020<71`BT0b>3H0P0^;Rh202PX:0808B4Q0P0Z:RX202`/;0809bLW0P0b
<S8205ADE080MGEe0P0c<c<202l_;`808b<S0P0Y:BT203De=@80>CTi0P0h>3P30410@0@0<C4a0P0j
>SX204I6AP80=SHf0P0[:b/202h^;P80;bl_0P0m?Cd203Ph>080=SHf0P0e=CD202XZ:P80;Bd]0P0b
<S8204A4A0H0=CDe0P0`<30203lo?`80CTi>0P18B4P204m?C`80De=C0P1QHF4204];B`80IVIV0P1Q
HF42069RHP80De=C0`1=CDd203`l?080KFe]0P2FUYH208j>SP80Jf][0P0a<C4202HV9P808B4Q0P0H
61P201XJ6P80<C4a0P1>CTh207alO080WinO0P2GUiL208:2PP80NGUi0P1dM7@207UiN@80SXj>0P2/
[:`20<?3``80]kNg0P2UYJD20:ZZZP80]KFe0P2m_Kd20;>c/`80]KFe0P2^[Zh20;Bd]0<0[jn_102c
/k<209nOW`80R8R80P2EUID20:2PX0@0Xj>S0P2/[:`20:n_[`80_Kfm0P30`<020<71`@80a/K60P3<
c<`20;fm_@80/K6a0P2VYZH20:VYZ@80Zj^[0P2XZ:P20:VYZ@80YjNW0P2SXj<40::RXP80W9bL0P2D
U9@209>CT`80V9RH0P2NWYh30::RXP80WYjN0P2SXj<20:NWY`80[Jf]0P2XZ:P20:VYZ@80[:b/0P2[
Zj/20:f][@@0]kNg0P2l_;`20;jn_P80`/;20P2n_[hO0<SPf0007@38h=P202h^;P80:RXZ0P0U9BD2
02PX:080;Bd]0P0^;Rh203<c<`80Hf=S0P1[Jf/203dm?@80:2PX0P0T92@202TY:@80;Bd]0P0c<c<2
0410@0<0BDU90P0m?Cd2030`<080=cLg0P0o?cl203Lg=`80;Rh^0P0_;bl2038b<P80=SHf100i>CT2
03Lg=`80;bl_0P0Z:RX2038b<P@0>c/k0P0h>3P203De=@80<c<c0P0f=SH203dm?@80ATI60P1EEED2
065QH@80K6a/0P1VIVH207MgM`80EeMG0P1BDU8204=3@`<0@D510P0e=CD206UYJ@80TI6A0P1gMgL2
04=3@`80;2`/0P0P820201lO7`8071`L0P0N7Qh202@T9080=3@d0P1IFET208>3P`80UYJF0P2MWId2
08V9R@80N7Qh0P1fMWH207inOP80V9RH0P2b/[820;Fe]@80/K6a0P2_[jl20:j^[P80/k>c0P2g]kL2
0;:b/P80[Jf]1@2[Zj/20:j^[P80[Jf]0P2LW9`208R8R080UIFE102WYjL20:ZZZP80[Jf]0P2a/K42
0;Jf]P80_;bl0P31`L420<G5a@80a<C40P2o_kl20;Bd]0@0ZJVY0P2/[:`20:ZZZP80ZJVY0P2XZ:P4
0:NWY`80YZJV0P2QXJ4209bLW080V9RH0P2FUYH209NGU`<0VIVI0P2MWId20:2PX080YJFU202YZJT2
0:^[Z`80[jn_0P2d];@20;Rh^080^k^k0P2n_[h20<30`080`L71:@38h=P203Xj>P809bLW0P0Y:BT2
02DU9@80;Rh^0P0i>CT203@d=080Fe]K0P1YJFT203lo?`809BDU100W9bL202l_;`80<30`0P17AdL3
055AD@80?Shn0P0`<30203Ph>080@4100P12@T8202/[:`80:BTY0P0];Bd203Ph>080=3@d0P0h>3P2
03Hf=P80:RXZ0P0[:b/202h^;P80>SXj0P18B4P203/k>`80;Bd]0P0i>CT203Ph>080<c<c0P16ATH2
04U9B@80IVIV0P1/K6`206m_K`80NGUi0P1IFET204a<C0D0>c/k0P0];Bd205iNGP80V9RH0P1ZJVX2
0451@@809BDU0P0O7al201`L7080820P0P0M7Ad202DU9@80;Rh^0P1IFET208>3P`80XJ6Q0P2FUYH2
08F5Q@80O7al0P1cLg<207]kN`80Ti>C0P2d];@20;fm_@80ZJVY0P2ZZZX20;2`/080^;Rh0P2i^KT4
0:j^[P80ZJVY0`2XZ:P20:^[Z`80[Zj^0P2IVIT208Z:RP80T92@0P2WYjL20:RXZ080YjNW0P2VYZH2
0;Jf]P80^[Zj0P2m_Kd40;no_`80a<C40P2o_kl20;>c/`80Zj^[0P2UYJD20:VYZ@80[:b/102WYjL2
0:VYZ@80YjNW0P2RXZ820:FUY@80VIVI0P2ATI4209JFUP80Vi^K0`2MWId209bLW080WinO102VYZH2
0:RXZ080YjNW0P2YZJT20:f][@80[jn_0P2g]kL20;Rh^080^[Zj0P31`L420<;2`P80_[jn:@38h=P2
02l_;`80;Rh^0P0Y:BT202`/;080;Bd]0P0^;Rh203<c<`80HF5Q0P1TI6@203lo?`80;Rh^0P0O7al2
02`/;080:b/[0P0_;bl20410@0<0Cdm?0P0n?Sh4038b<P80@4100P0e=CD202/[:`80=3@d0P0];Bd2
03/k>`80>CTi0P0`<30203<c<`80;Rh^0P0];Bd203@d=080@T920P0g=cL203`l?080<c<c0P0^;Rh2
03Xj>P80?3`l0P11@D4205MGE`80IVIV0P1[Jf/2065QH@80Ng]k0P1>CTh205ADE080AdM70`0m?Cd2
03Lg=`80IVIV0P2<S8`207AdM080B4Q80P0Y:BT201hN7P8061PH0P0S8b<201lO7`80:2PX0P0d=3@2
05]KF`80PX:20P2HV9P209jNWP80QHF50P1iNGT207EeM@80P8200P2JVYX20;>c/`80^[Zj0P2b/[82
0:f][@80[Zj^0P2d];@20;:b/P80^[Zj0P2[Zj/20:j^[P<0ZJVY102/[:`209bLW080Rh^;0P2EUID4
0:NWY`80ZJVY0P2ZZZX20;2`/080/k>c0P2i^KT40<;2`P80`l?30P2o_kl20;:b/P80Z:RX102][Jd2
0:RXZ080Zj^[0P2XZ:P20:JVYP80Z:RX0P2WYjL20:>SX`80Vi^K0P2HV9P209ZJVP80UiNG0`2JVYX2
09VIV@80X:2P0P2UYJD40:NWY`80Zj^[0P2WYjL20:b/[080[Jf]0P2e]KD20;Rh^080^[Zj102o_kl2
0;fm_Al0b>3H000M0<SPf080;Rh^0P0Z:RX202DU9@80:2PX0P0];Bd202h^;P80<c<c0P1SHf<206][
J`80?Cdm0P0X:2P202@T9080:BTY0P0];Bd203<c<`80@4100`19BDT203dm?@80<30`0P0g=cL203lo
?`80=cLg0P0^;Rh202l_;`80<S8b0P0f=SH403Ti>@80=cLg0P0_;bl202XZ:P80<S8b100k>c/203Ph
>080=CDe0P0c<c<203Hf=P80?Cdm0P16ATH205EEE@80HF5Q0P1/K6`206IVIP80MgMg0P1GEeL2059B
DP80@d=30`11@D4203De=@80JFUY0P2ATI4207MgM`80@d=30P0/;2`2020P80807alO0P0L71`201hN
7P8092@T0P0d=3@205UIF@80Ph>30P2FUYH209fMW@80RHV90P1hN7P207IfMP80OWin0P2HV9P20;:b
/P80]KFe0P2a/K420:n_[`80[Zj^0P2c/k<20;Ng]`80/[:b0P2][Jd50:^[Z`80[Zj^0P2][Jd209bL
W080R8R80P2EUID40:NWY`80ZZZZ0P2][Jd20;6a/@80][Jf0P2l_;`20<71`@80aLG50P34a<@20;no
_`80];Bd102YZJT20:b/[080ZZZZ0P2YZJT20:RXZ0@0YjNW0P2VYZH20:6QX@80W9bL0P2HV9P209JF
UP80UiNG0`2IVIT209fMW@80X:2P0P2UYJD80:VYZ@80Zj^[0P2_[jl20;Bd]080^;Rh0P2k^k/20;jn
_P80`<300P31`L4Y0<SPf080>SXj0P0W9bL202TY:@809BDU0P0^;Rh203Ti>@80=3@d0P1KFe/206UY
J@80?clo0P0U9BD402LW9`80;bl_0P0`<30204M7A`<0DE5A0P0n?Sh2030`<080>3Ph0P10@4020492
@P80:b/[0P0Y:BT202d];@80>3Ph0P0d=3@203Ph>080=SHf0P0Z:RX202/[:`80;Rh^0P0j>SX204Q8
B080>c/k0P0];Bd203Ti>@80>3Ph0P0c<c<204I6AP80BDU90P1VIVH206a/K080Kfm_0P1iNGT205UI
F@80C4a<1@0k>c/202d];@80GUiN0P2HV9P206YZJP80@D510P0U9BD201lO7`8071`L0P0P820201dM
7@809BDU0P0^;Rh205UIF@80Ph>30P2QXJ4209JFUP80QHF50P1lO7`207=cL`80Ng]k0P2CTi<20;Bd
]080_Kfm0P2YZJT20:ZZZP80/;2`0P2h^;P20;Vi^@@0[Zj^0P2YZJT30:RXZ080Zj^[0P2^[Zh209VI
V@80RXZ:0P2@T9020:NWY`80Z:RX0P2WYjL20:JVYP80][Jf0P2j^[X20;fm_@@0_kno0P34a<@20;no
_`80/k>c0P2[Zj/20:FUY@80ZJVY0P2/[:`40:NWY`80ZJVY0P2WYjL20::RXP80YJFU0P2IVIT2096A
T@80UYJF0P2KVi/309fMW@80W9bL0P2OWil40:JVYP80Z:RX0P2WYjL20:VYZ@80[Jf]0P2_[jl20;Ng
]`80^;Rh0P2j^[X20<71`@80`/;20P2n_[hY0<SPf080;bl_0P0^;Rh202TY:@80;2`/0P0];Bd202h^
;P80<c<c0P1QHF4206ATI080?clo0P0^;Rh201lO7`80;2`/0P0[:b/202l_;`80@4100`1?Cdl203hn
?P@0<S8b0P10@40203De=@80:b/[0P0d=3@202d];@80>c/k0P0i>CT2030`<080<c<c0P0^;Rh202d]
;@80=3@d0P12@T8203Lg=`80?3`l0P0c<c<202h^;P80>SXj0P0l?3`20451@@80EeMG0P1VIVH206][
J`80HF5Q0P1kNg/204i>CP80E5AD0P17AdL303dm?@80=cLg0P1VIVH208b<S080M7Ad0P18B4P202TY
:@807QhN0P0H61P202<S8`807alO0P0X:2P203@d=080Fe]K0P22PX8209RHV080WYjN0P25QHD207Ui
N@80MGEe0P20P80209ZJVP80/k>c0P2j^[X20;:b/P80[Jf]0P2^[Zh20;Bd]080/[:b0P2j^[X20:^[
Z`80[Zj^0`2YZJT40:b/[080W9bL0P2;Rh/209FEU@@0YjNW0P2YZJT20:ZZZP80/;2`0P2c/k<20;Vi
^@@0`/;20P33`l<20;no_`80/[:b0P2XZ:P40:f][@80Z:RX0P2[Zj/20:RXZ080YZJV0P2XZ:P20:NW
Y`80Xj>S0P2KVi/209RHV080VYZJ0P2GUiL309ZJVP80VIVI0P2PX:020:FUY@@0YjNW0P2[Zj/20:NW
Y`80[:b/0P2][Jd20;Fe]@80^;Rh0P2j^[X40;no_`80_Kfm7`38h=P001d0b>3H0P0`<30202`/;080
:2PX0P0Z:RX202h^;P80<S8b0P0f=SH2075aL@80Hf=S0P1:BTX402HV9P80;Bd]0P0/;2`202h^;P80
@4100`1?Cdl204=3@`@0=3@d0P0f=SH203@d=0H0<S8b0P0d=3@203Hf=P80>SXj0P0l?3`2034a<@80
:2PX0P0_;bl203Ph>080?3`l0P0n?Sh203/k>`80=cLg0P0_;bl202d];@80A4A40P1OGel206UYJ@80
LW9b0P20P80208:2PP80A4A40P10@40202h^;P<0<30`0P0a<C4206UYJ@80Ph>30P1LG5`2020P8080
8b<S0P0N7Qh4028R8P808b<S0P0O7al2024Q8@80>SXj0P1KFe/208V9R@80Zj^[0P2KVi/208>3P`80
MgMg0P1cLg<208>3P`80VIVI0P2][Jd20;bl_080/[:b0P2VYZH20:j^[P80][Jf0P2`/;020:VYZ@80
YZJV0`2UYJD40:RXZ080UYJF0P27QhL209JFUP80ZJVY0P2^[Zh60:n_[`80/k>c0P2g]kL20;fm_@80
`/;20P31`L420;bl_080];Bd0P2/[:`40:ZZZP80ZJVY0P2XZ:P20:^[Z`80[Jf]0P2ZZZX40:RXZ080
YjNW0P2NWYh209JFUP80Ti>C0`2DU9@209VIV@80WinO0P2TY:@20:NWY`80Z:RX0P2YZJT20:ZZZP80
[:b/0P2_[jl20;>c/`80]kNg0P2k^k/20;jn_P@0`<30:@38h=P2038b<P80:b/[0P0b<S8202HV9P80
;bl_0P0e=CD203Ph>080JFUY0P1]KFd20451@@809bLW0P0Z:RX202TY:@80;bl_0P0^;Rh20451@@<0
C4a<0P17AdL203Ph>080;2`/0P0f=SH203dm?@80<30`0P0];Bd203<c<`80=cLg0P0b<S820492@P80
=CDe0P0g=cL202TY:@80;Rh^0P0f=SH20451@@80?3`l0P0h>3P203Lg=`80=3@d0P0b<S8203lo?`80
H61P0P1bLW8206UYJ@80N7Qh0P1nOWh2051@D080@4100P0Z:RX303De=@80=SHf0P1XJ6P208V9R@80
F5QH0P0Y:BT2020P80809RHV0P0P820202@T90808R8R0P0N7Qh202@T9080=SHf0P1MGEd2096AT@80
ZJVY0P2DU9@208B4Q080Ng]k0P1gMgL207emO@80UIFE0P2f][H20;Vi^@80ZJVY0P2XZ:P20;Jf]P80
/k>c0P2^[Zh20:ZZZP80YZJV0`2SXj<20;2`/080Xj>S0P2DU9@208^;R`80Shn?0P2YZJT20;Fe]@80
[Jf]0P2/[:`20:n_[`80[Zj^0P2i^KT20;jn_P80`l?30P2o_kl20;Zj^P80][Jf0P2/[:`20:NWY`80
[:b/0P2[Zj/20:NWY`80Zj^[0P2][Jd20:RXZ080YjNW0P2[Zj/20:FUY@80X:2P0P2EUID209>CT`<0
U9BD0P2GUiL209fMW@80YJFU0P2VYZH20:VYZ@80Zj^[0P2XZ:P40:f][@80/k>c0P2g]kL20;Vi^@80
_[jn0P2o_kl20;jn_RT0b>3H100^;Rh202HV9P80:b/[0P0/;2`2038b<P80>3Ph0P1`L70206MWI`80
B4Q80P0W9bL202DU9@@0;Rh^0P0];Bd20451@@<0Bd];0P12@T8203<c<`H0=CDe0P0^;Rh203De=@80
<C4a0P0c<c<203Lg=`80=SHf0P0m?Cd203@d=080:RXZ0P0U9BD203Xj>P80?Cdm0P11@D4203De=@80
?3`l0P0c<c<202`/;080B4Q80P1OGel206=SH`80LW9b0P25QHD20820P080@d=30P10@40203<c<`<0
;bl_0P0`<30206m_K`80PX:20P1LG5`402@T90807alO0P0R8R8202LW9`808B4Q0P0F5QH2028R8P80
?Shn0P1JFUX208Z:RP80[:b/0P2HV9P208>3P`80MgMg0P1^KVh208R8R080V9RH0P2YZJT20;bl_080
[jn_0P2[Zj/20;2`/080^;Rh0P2^[Zh40:JVYP<0YjNW0P2ZZZX20:RXZ080UiNG0P27QhL209:BTP80
ZJVY0P2a/K420:j^[P80[Jf]0P2_[jl20;Fe]@80]kNg0P2l_;`20<G5a@@0_[jn0P2d];@20:ZZZP80
[Zj^0P2XZ:P40:VYZ@80ZZZZ0P2/[:`20:ZZZP80YZJV0P2XZ:P20:NWY`80WIfM0P2FUYH509>CT`80
VIVI0P2NWYh20:RXZ080YZJV0P2XZ:P20:VYZ@80Z:RX0P2^[Zh20:b/[080/k>c0P2i^KT20;^k^`80
_[jn0P31`L420<30`1l0b>3H000M0<SPf080<30`0P0/;2`202PX:080:RXZ0P0^;Rh2038b<P80=SHf
0P1aLG4206=SH`80BTY:100V9RH202d];@80;2`/0P0^;Rh20410@0<0Cdm?0P13@d<403@d=080=SHf
0P0d=3@6038b<P80=3@d0P0f=SH203Xj>P80?3`l0P0a<C4202PX:080;bl_0P0h>3P203`l?080?Shn
0P0k>c/203Lg=`80;bl_0P0];Bd204A4A080GemO0P1YJFT2079bLP80P8200P22PX8204A4A080@410
0P0^;Rh3030`<080<C4a0P1YJFT208>3P`80G5aL0P0P820202<S8`807QhN100R8R8202<S8`807alO
0P0Q8B4203Xj>P80Fe]K0P29RHT20:^[Z`80Vi^K0P23Ph<207MgM`80Lg=c0P23Ph<209VIV@80[Jf]
0P2l_;`20;:b/P80YZJV0P2^[Zh20;Jf]P80/;2`0P2YZJT20:JVYP<0YJFU102XZ:P209JFUP80QhN7
0P2FUYH20:VYZ@80[Zj^1P2_[jl20;>c/`80]kNg0P2m_Kd20<;2`P80`L710P2l_;`20;Bd]080[:b/
102ZZZX20:VYZ@80Z:RX0P2[Zj/20:f][@80ZZZZ102XZ:P20:NWY`80WYjN0P2FUYH209>CT`<0U9BD
0P2IVIT209nOW`80Y:BT0P2WYjL20:RXZ080ZJVY0P2ZZZX20:b/[080[jn_0P2c/k<20;Ng]`80^k^k
0P2n_[h40<30`2T0b>3H0P0b<S8202/[:`80<S8b0P0V9RH202l_;`80=CDe0P0h>3P206UYJ@80KFe]
0P11@D4202LW9`80:RXZ0P0Y:BT202l_;`80;Rh^0P11@D4304a<C080AdM70P0h>3P202`/;080=SHf
0P0m?Cd2030`<080;Bd]0P0c<c<203Lg=`80<S8b0P12@T8203De=@80=cLg0P0Y:BT202h^;P80=SHf
0P11@D4203`l?080>3Ph0P0g=cL203@d=080<S8b0P0o?cl2061PH080LW9b0P1YJFT207QhN080OWin
0P1@D5020410@080:RXZ0`0e=CD203Hf=P80J6QX0P29RHT205QHF080:BTY0P0P820202HV9P80820P
0P0T92@2028R8P807QhN0P0T92@203Hf=P80GEeM0P2ATI420:VYZ@80U9BD0P24Q8@207]kN`80MgMg
0P1mOGd209FEU@80][Jf0P2i^KT20:VYZ@80Z:RX0P2f][H20;>c/`80[Zj^0P2ZZZX20:JVYP<0Xj>S
0P2`/;020:>SX`80U9BD0P2;Rh/208n?S`80ZJVY0P2e]KD20:f][@80[:b/0P2_[jl20:j^[P80^KVi
0P2n_[h20<?3``80_kno0P2j^[X20;Jf]P80[:b/0P2WYjL20:b/[080Zj^[0P2WYjL20:^[Z`80[Jf]
0P2XZ:P20:NWY`80Zj^[0P2UYJD20:2PX080UIFE0P2CTi<309BDU080UiNG0P2MWId20:FUY@80YZJV
0P2YZJT20:^[Z`80Z:RX102][Jd20;>c/`80]kNg0P2i^KT20;jn_P80_kno0P2n_[hY0<SPf0@0;Rh^
0P0V9RH202/[:`80;2`/0P0b<S8203Ph>080L71`0P1WIfL204Q8B0809bLW0P0U9BD402h^;P80;Bd]
0P11@D4304];B`80@T920P0c<c<603De=@80;Rh^0P0e=CD2034a<@80<c<c0P0g=cL203Hf=P80?Cdm
0P0d=3@202XZ:P809BDU0P0j>SX203dm?@80@D510P0e=CD203`l?080<c<c0P0/;2`204Q8B080GemO
0P1SHf<2079bLP80QHF50P20P80204=3@`80@4100P0c<c<302l_;`80<30`0P1_Kfl208:2PP80G5aL
100T92@201lO7`808R8R0P0W9bL2024Q8@805QHF0P0R8R8203hn?P80FUYJ0P2:RXX20:b/[080V9RH
0P23Ph<207MgM`80KVi^0P28R8P209RHV080ZJVY0P2l_;`20:n_[`80Zj^[0P2`/;020;Rh^080[Zj^
102VYZH30:NWY`80ZZZZ0P2XZ:P209NGU`80QhN70P2BTY820:VYZ@80/K6a0P2^[Zh20:f][@80[jn_
0P2e]KD20;Ng]`80_;bl0P35aLD40;jn_P80];Bd0P2ZZZX20:j^[P80Z:RX102YZJT20:ZZZP80[:b/
0P2ZZZX20:JVYP80Z:RX0P2WYjL209fMW@80UYJF1@2CTi<209VIV@80WYjN0P2XZ:P20:JVYP80Z:RX
0P2YZJT20:RXZ080[Zj^0P2/[:`20;>c/`80^KVi0P2k^k/20;jn_P80`L710P30`<0O0<SPf0007@38
h=P20451@@80?Cdm0P0f=SH202l_;`80;2`/0P0`<30203Ti>@80IfMW0P1YJFT204m?C`80:RXZ0P0X
:2P202d];@@0:b/[0P0h>3P504=3@`80?clo0P0j>SX403Hf=P80=CDe0P0a<C4202h^;P80;bl_0P0b
<S8203Ph>080>c/k0P0b<S8202TY:@80<30`0P0k>c/203hn?P80?clo0P0j>SX203@d=080<S8b0P0e
=CD204i>CP80GemO0P1/K6`205]KF`80HF5Q0P1nOWh203Ti>@80=SHf0P0Z:RX3030`<080>SXj0P1n
OWh208F5Q@80ATI60P0T92@202LW9`808b<S100T92@202<S8`@0820P0P0W9bL203Ph>080Hf=S0P2;
Rh/20:NWY`80UIFE0P21PH42075aL@80Lg=c0P1nOWh209VIV@80/[:b0P2c/k<40:n_[`80[Zj^0P2Z
ZZX20:JVYPD0YJFU0P2WYjL20:JVYP80Ti>C0P25QHD209FEU@80ZJVY102_[jl20:ZZZP80YZJV0P2_
[jl20;Zj^P80_[jn0P30`<020;no_`80^k^k0P2e]KD20:j^[P80Zj^[0P2YZJT20:RXZ080ZJVY0P2[
Zj/20:f][@80Zj^[0P2ZZZX20:^[Z`80[:b/0P2XZ:P20::RXP80Vi^K1@2EUID209RHV080WinO0P2V
YZH20:NWY`80Z:RX0P2ZZZX20:b/[080[Zj^0P2a/K420;Bd]080^;Rh0P2k^k/20;jn_P80_kno:@38
h=P203lo?`80=cLg0P0^;Rh202XZ:P@0;2`/0P0l?3`206QXJ080KFe]0P1=CDd202h^;P80<C4a0P0/
;2`402/[:`80<30`0`0n?Sh204M7A`80?clo0P0b<S8203<c<`80>c/k0P0e=CD2038b<P80=CDe0P0a
<C4203Lg=`80=SHf0P14A4@202h^;P80:b/[0P0^;Rh203/k>`80?Shn0P10@40203Ti>@@0<S8b0P0g
=cL204i>CP80Hf=S0P1^KVh206MWI`80G5aL0P1jNWX203lo?`80=cLg0P0];Bd303<c<`80>c/k0P20
P80208V9R@80AdM70P0U9BD202@T9080:2PX0P0O7al202@T90808b<S0P0X:2P202<S8`80:BTY0P0[
:b/2069RHP80TI6A0P2UYJD209FEU@80PH610P1dM7@2079bLP80Ng]k0P2PX:020;Fe]@80^KVi0P2U
YJD20:j^[P80[Jf]0P2XZ:P20:VYZ@80XJ6Q1@2XZ:P20:ZZZP80UYJF0P27QhL208j>SP80ZJVY0P2f
][H20;6a/@80ZJVY0P2XZ:P20:n_[`80^KVi0P2l_;`20<30`080a/K60P2i^KT20;Rh^080[jn_0P2W
YjL20:ZZZP80Zj^[0P2YZJT20:ZZZP80[:b/0P2YZJT20:^[Z`80[Zj^0P2ZZZX20:n_[`80XJ6Q0P2F
UYH309>CT`80UIFE0P2LW9`20:>SX`80YZJV0P2UYJD20:VYZ@80YjNW0P2^[Zh20:b/[080/[:b0P2`
/;020;Zj^P80_Kfm0P2o_kl20;Vi^BT0b>3H0P0o?cl203Xj>P80<S8b0P0^;Rh202`/;0@0=SHf0P1U
IFD206YZJP80De=C0P0X:2P202DU9@80:BTY0P0a<C4202h^;P80=3@d0`14A4@204I6AP80@4100P0l
?3`203Ph>080=SHf0P0i>CT203<c<`80;Rh^0P0];Bd203@d=0@0?Shn0P0f=SH202PX:080:b/[0P0i
>CT204E5A@80?Shn0P0d=3@203<c<`80;Rh^0P0c<c<204i>CP80GemO0P1]KFd405mOG`80PH610P0i
>CT9034a<@80O7al0P27QhL204M7A`808R8R0P0T92@2028R8P8092@T0P0Q8B4202PX:0@0820P0P0X
:2P203De=@80HV9R0P2<S8`20:BTY080V9RH0P24Q8@407=cL`80Ng]k0P2IVIT20;Bd]080][Jf0P2Z
ZZX20:NWY`80[Zj^102YZJT20:RXZ0<0XJ6Q102UYJD209JFUP80PX:20P2EUID20:RXZ080/;2`0P2b
/[820:ZZZP80YjNW0P2a/K420;^k^`80`L710P2o_kl20;jn_P80_Kfm0P2e]KD40:j^[P80Z:RX0P2V
YZH20:VYZ@80Zj^[0P2^[Zh20:f][@80ZJVY102][Jd20:NWY`80X:2P0P2JVYX309RHV080UIFE0P2G
UiL20::RXP80YJFU0P2VYZH20:VYZ@80Zj^[0P2/[:`20;:b/P80/;2`0P2e]KD20;Ng]`80^[Zj0P2o
_kl20<30`1l0b>3H000M0<SPf080@D510P0m?Cd203Hf=P80;bl_0P0/;2`2030`<080>CTi0P1WIfL2
06UYJ@80Cdm?0P0Z:RX202PX:080;Bd]100[:b/203Ph>0D0@d=30P0o?cl203Xj>P@0=SHf0P0e=CD2
034a<@80;Rh^0P0_;bl2038b<P80>3Ph0P0k>c/2038b<P80:BTY0P0`<30203/k>`80?Shn0P0o?cl2
03Xj>P80=3@d0P0b<S8203De=@80CTi>0P1OGel206a/K080Fe]K0P1QHF4207inOP80>CTi0P0f=SH2
02XZ:P<0<30`0P0j>SX207inOP80QHF50P16ATH202@T90809bLW0P0S8b<402@T90808b<S100P8202
02LW9`80>3Ph0P1SHf<208^;R`80YjNW0P2EUID20861P@80LG5a0P1cLg<207inOP80VIVI0P2b/[82
0;>c/`@0[jn_0P2^[Zh20:ZZZP80YZJV1@2UYJD20:NWY`80YZJV0P2CTi<208F5Q@80UIFE0P2YZJT4
0:n_[`80ZZZZ0P2VYZH20:n_[`80^[Zj0P2n_[h20<30`080_kno0P2k^k/20;Fe]@80[Zj^0P2[Zj/2
0:VYZ@80Z:RX0P2YZJT20:^[Z`80[Jf]0P2[Zj/20:ZZZP80Zj^[0P2/[:`20:RXZ080XZ:R0P2KVi/5
09FEU@80V9RH0P2OWil20:JVYP80YjNW0P2XZ:P20:ZZZP80[:b/0P2^[Zh20;6a/@80];Bd0P2h^;P2
0;^k^`80_[jn0P2o_klY0<SPf080?clo0P0g=cL202h^;P80:RXZ100/;2`203`l?080J6QX0P1]KFd2
04e=C@80;Rh^0P0a<C4202`/;0@0:b/[0P0`<30303hn?P80AdM70P0o?cl2038b<P80<c<c0P0k>c/2
03De=@80<S8b0P0e=CD2034a<@80=cLg0P0f=SH204A4A080;Rh^0P0[:b/202h^;P80>c/k0P0n?Sh2
0410@080>CTi100b<S8203Lg=`80CTi>0P1SHf<206i^KP80IfMW0P1LG5`207YjNP80?clo0P0g=cL2
02d];@<0<c<c0P0k>c/20820P080RHV90P17AdL202DU9@8092@T0P0X:2P201lO7`8092@T0P0S8b<2
02PX:0808b<S0P0Y:BT202/[:`80HV9R0P2ATI420:FUY@80UIFE0P21PH4207AdM080LW9b0P1kNg/2
0:2PX080]KFe0P2i^KT20:FUY@80[Zj^0P2][Jd20:RXZ080ZJVY0P2QXJ450:RXZ080ZZZZ0P2FUYH2
08N7Q`80SXj>0P2YZJT20;Jf]P80/K6a0P2YZJT20:RXZ080[jn_0P2i^KT20;bl_080`<300P36a/H2
0;Vi^@80^;Rh0P2_[jl20:NWY`80ZZZZ0P2[Zj/20:VYZ@80ZZZZ0P2/[:`20:VYZ@80Zj^[0P2^[Zh2
0:ZZZP80[jn_0P2QXJ4209JFUP<0Ti>C0P2EUID209bLW080Xj>S0P2VYZH20:FUY@80ZJVY0P2WYjL2
0:j^[P80[:b/0P2b/[820;2`/080^[Zj0P2m_Kd20;no_`80^KVi:@38h=P203lo?`80>SXj0P0b<S82
02h^;P80;2`/100f=SH206EUI@80JVYZ0P1CDe<202PX:0809BDU0P0Y:BT2034a<@80;Rh^0P0d=3@3
04A4A080ATI60P10@40203`l?080>3Ph0P0f=SH203Ti>@80<c<c0P0^;Rh202d];@80=3@d100n?Sh2
03Hf=P80:2PX0P0[:b/203Ti>@80ADE50P0n?Sh203@d=080<c<c0P0^;Rh203<c<`80CTi>0P1OGel2
06e]K@@0GemO0P21PH4203Ti>@T0<C4a0P1lO7`208N7Q`80AdM70P0R8R8202@T90808R8R0P0T92@2
024Q8@80:2PX100P820202PX:080=CDe0P1RHV8208b<S080Y:BT0P2HV9P208B4Q0@0Lg=c0P1kNg/2
09VIV@80];Bd0P2f][H20:ZZZP80YjNW0P2^[Zh40:VYZ@80Z:RX0`2QXJ440:FUY@80UYJF0P22PX82
09FEU@80Z:RX0P2`/;020;:b/P80ZZZZ0P2WYjL20;6a/@80^k^k0P31`L420;no_`80_[jn0P2m_Kd2
0;Fe]@@0[Zj^0P2XZ:P20:JVYP80ZJVY0P2[Zj/20:j^[P80[Jf]0P2YZJT40:f][@80YjNW0P2PX:02
09ZJVP<0V9RH0P2EUID209NGU`80XZ:R0P2UYJD20:JVYP80ZJVY0P2[Zj/20:b/[080/[:b0P2`/;02
0;Fe]@80]kNg0P2j^[X20;no_`80`<307`38h=P001d0b>3H0P1>CTh204U9B@80?clo0P0c<c<202/[
:`80;bl_0P0k>c/205QHF080Kfm_0P1CDe<2034a<@@0:b/[100Z:RX202h^;P<0=3@d0P0o?cl204M7
A`80@410100g=cL203Ph>080<C4a100[:b/202l_;`80=3@d0P0i>CT203<c<`80;Rh^0P0f=SH20410
@080@D510P0o?cl203Lg=`80<S8b0P0h>3P20492@P80EUIF0P1NGUh206YZJP80?clo0P0j>SX2079b
LP80<c<c0P0`<30202XZ:P<0=cLg0P1;Bd/2096AT@80QHF50P0d=3@202h^;P80;2`/0P0X:2P202HV
9P8092@T0P0S8b<402@T90@07AdM0P0l?3`205mOG`80YJFU0P2OWil208n?S`80MgMg0P1ZJVX206QX
J080PX:20P2PX:020:n_[`80]kNg0P2a/K420:RXZ080YZJV0P2UYJD50:JVYP80YjNW0P2UYJD2096A
T@80Ph>30P2CTi<20:RXZ0@0[Jf]0P2UYJD209jNWP80[Jf]0P2m_Kd20<30`080_kno0P2m_Kd20;Vi
^@80]KFe0P2`/;020:^[Z`@0Z:RX0P2YZJT20:ZZZP@0Zj^[0P2ZZZX20:b/[080[Jf]0P2_[jl20:j^
[P80YZJV0`2LW9`209JFUP80Ti>C0P2JVYX20:>SX`80YJFU0P2WYjL20:VYZ@80[:b/0P2][Jd20:j^
[P80/K6a0P2e]KD20;Vi^@80_;bl0P2m_KdY0<SPf080Cdm?0P1BDU8204M7A`80<c<c0P0[:b/202`/
;080=CDe0P1VIVH206e]K@80BDU90P0d=3@202d];@@0:RXZ0P0/;2`202h^;P<0=SHf1016ATH203Xj
>P80>c/k0P0l?3`203Ti>@80:RXZ0P0[:b/202h^;P@0;bl_0P0k>c/203De=@80<C4a0P0d=3@204=3
@`80?Shn0P12@T8203Ti>@80=SHf0P0d=3@204A4A080FUYJ0P1PH60206=SH`80>c/k0P13@d<206YZ
JP80=cLg0P0/;2`202l_;`<0=3@d0P1@D502092@T080PH610P0g=cL202TY:@80;Bd]0P0Z:RX202LW
9`8092@T0P0Q8B4202<S8`80820P0P0Q8B4202@T9080=3@d0P1[Jf/209^KV`80X:2P0P2?Shl207Qh
N080Jf][0P1ZJVX207emO@80Vi^K102e]KD20:b/[080Zj^[102UYJD50:JVYP80YjNW0P2SXj<209BD
U080Q8B40P2=SHd20:NWY`80/K6a0P2][Jd20:>SX`80WinO0P2a/K420;Zj^P80`L710P2n_[h20;fm
_@80^;Rh0P2g]kL20;6a/@H0YjNW0P2XZ:P20:ZZZP@0Zj^[0P2ZZZX20:^[Z`80[Jf]0P2^[Zh20:b/
[080YjNW0`2LW9`209>CT`80UIFE0P2RXZ820:2PX080XZ:R0P2YZJT20:ZZZP80[Jf]0P2_[jl20;2`
/080[Zj^0P2f][H20;Zj^P80_;bl0P2k^k/Y0<SPf080CTi>0P1;Bd/204E5A@80;bl_0P0Z:RX202d]
;@80>SXj0P1GEeL206m_K`80De=C0P0`<302034a<@809bLW0P0Y:BT202LW9`80:b/[0`0h>3P203lo
?`80B4Q80P0l?3`203Ti>@80=CDe0P0h>3P203De=@80:RXZ0P0W9bL202h^;PH0<c<c0P0`<30203Hf
=P80?clo0P0l?3`203hn?P@0>CTi0P0^;Rh204U9B@80FUYJ0P1LG5`206][J`80?3`l0P0b<S8206i^
KP80?Shn0P0];Bd202PX:0<0?3`l0P1<C4`209RHV080PH610P0f=SH402d];@80;2`/0P0U9BD202<S
8`8092@T0P0S8b<202TY:@8071`L0P0T92@203Xj>P80H61P0P2SXj<209nOW`80Shn?0P1hN7P206i^
KP80IfMW0P22PX8209^KV`80][Jf0P2i^KT20;:b/P80Zj^[0P2TY:@20:>SX`D0YJFU0P2[Zj/20:BT
Y080T92@0P1oOgl209BDU080ZJVY102/[:`20:RXZ080WIfM0P2/[:`20;^k^`80_kno0P2n_[h20<30
`080^;Rh0P2c/k<20;2`/080[Jf]0P2WYjL40:ZZZP80Z:RX0P2YZJT20:ZZZP80Z:RX0P2_[jl20:f]
[@80[:b/0P2_[jl20:NWY`<0WIfM0P2BTY8209FEU@80Vi^K0P2RXZ820:FUY@80YZJV0P2WYjL20:b/
[080[Jf]0P2^[Zh20;2`/080][Jf0P2i^KT20;bl_080`L717`38h=P001d0b>3H0P1>CTh204U9B@80
?clo0P0c<c<202/[:`80;bl_0P0k>c/205QHF080Kfm_0P1CDe<2034a<@@0:b/[100Z:RX202h^;P<0
=3@d0P0o?cl204M7A`80@410100g=cL203Ph>080<C4a100[:b/202l_;`80=3@d0P0i>CT203<c<`80
;Rh^0P0f=SH20410@080@D510P0o?cl203Lg=`80<S8b0P0h>3P20492@P80EUIF0P1NGUh206YZJP80
?clo0P0j>SX2079bLP80<c<c0P0`<30202XZ:P<0=cLg0P1;Bd/2096AT@80QHF50P0d=3@202h^;P80
;2`/0P0X:2P202HV9P8092@T0P0S8b<402@T90@07AdM0P0l?3`205mOG`80YJFU0P2OWil208n?S`80
MgMg0P1ZJVX206QXJ080PX:20P2PX:020:n_[`80]kNg0P2a/K420:RXZ080YZJV0P2UYJD50:JVYP80
YjNW0P2UYJD2096AT@80Ph>30P2CTi<20:RXZ0@0[Jf]0P2UYJD209jNWP80[Jf]0P2m_Kd20<30`080
_kno0P2m_Kd20;Vi^@80]KFe0P2`/;020:^[Z`@0Z:RX0P2YZJT20:ZZZP@0Zj^[0P2ZZZX20:b/[080
[Jf]0P2_[jl20:j^[P80YZJV0`2LW9`209JFUP80Ti>C0P2JVYX20:>SX`80YJFU0P2WYjL20:VYZ@80
[:b/0P2][Jd20:j^[P80/K6a0P2e]KD20;Vi^@80_;bl0P2m_KdY0<SPf080Cdm?0P1BDU8204M7A`80
<c<c0P0[:b/202`/;080=CDe0P1VIVH206e]K@80BDU90P0d=3@202d];@@0:RXZ0P0/;2`202h^;P<0
=SHf1016ATH203Xj>P80>c/k0P0l?3`203Ti>@80:RXZ0P0[:b/202h^;P@0;bl_0P0k>c/203De=@80
<C4a0P0d=3@204=3@`80?Shn0P12@T8203Ti>@80=SHf0P0d=3@204A4A080FUYJ0P1PH60206=SH`80
>c/k0P13@d<206YZJP80=cLg0P0/;2`202l_;`<0=3@d0P1@D502092@T080PH610P0g=cL202TY:@80
;Bd]0P0Z:RX202LW9`8092@T0P0Q8B4202<S8`80820P0P0Q8B4202@T9080=3@d0P1[Jf/209^KV`80
X:2P0P2?Shl207QhN080Jf][0P1ZJVX207emO@80Vi^K102e]KD20:b/[080Zj^[102UYJD50:JVYP80
YjNW0P2SXj<209BDU080Q8B40P2=SHd20:NWY`80/K6a0P2][Jd20:>SX`80WinO0P2a/K420;Zj^P80
`L710P2n_[h20;fm_@80^;Rh0P2g]kL20;6a/@H0YjNW0P2XZ:P20:ZZZP@0Zj^[0P2ZZZX20:^[Z`80
[Jf]0P2^[Zh20:b/[080YjNW0`2LW9`209>CT`80UIFE0P2RXZ820:2PX080XZ:R0P2YZJT20:ZZZP80
[Jf]0P2_[jl20;2`/080[Zj^0P2f][H20;Zj^P80_;bl0P2k^k/Y0<SPf080CTi>0P1;Bd/204E5A@80
;bl_0P0Z:RX202d];@80>SXj0P1GEeL206m_K`80De=C0P0`<302034a<@809bLW0P0Y:BT202LW9`80
:b/[0`0h>3P203lo?`80B4Q80P0l?3`203Ti>@80=CDe0P0h>3P203De=@80:RXZ0P0W9bL202h^;PH0
<c<c0P0`<30203Hf=P80?clo0P0l?3`203hn?P@0>CTi0P0^;Rh204U9B@80FUYJ0P1LG5`206][J`80
?3`l0P0b<S8206i^KP80?Shn0P0];Bd202PX:0<0?3`l0P1<C4`209RHV080PH610P0f=SH402d];@80
;2`/0P0U9BD202<S8`8092@T0P0S8b<202TY:@8071`L0P0T92@203Xj>P80H61P0P2SXj<209nOW`80
Shn?0P1hN7P206i^KP80IfMW0P22PX8209^KV`80][Jf0P2i^KT20;:b/P80Zj^[0P2TY:@20:>SX`D0
YJFU0P2[Zj/20:BTY080T92@0P1oOgl209BDU080ZJVY102/[:`20:RXZ080WIfM0P2/[:`20;^k^`80
_kno0P2n_[h20<30`080^;Rh0P2c/k<20;2`/080[Jf]0P2WYjL40:ZZZP80Z:RX0P2YZJT20:ZZZP80
Z:RX0P2_[jl20:f][@80[:b/0P2_[jl20:NWY`<0WIfM0P2BTY8209FEU@80Vi^K0P2RXZ820:FUY@80
YZJV0P2WYjL20:b/[080[Jf]0P2^[Zh20;2`/080][Jf0P2i^KT20;bl_080`L717`38h=P001d0b>3H
0P1QHF42069RHP80GUiN0P15ADD202l_;`80;Bd]0P0g=cL205=CD`80KVi^0P1FEUH203Lg=`80<30`
0P0Y:BT202PX:080:RXZ0P0[:b/302h^;P80>CTi0P12@T8203Xj>P80<S8b0P0g=cL203`l?080=CDe
0P0/;2`202d];@@0<C4a0P0c<c<203Ph>080?Shn0P13@d<204I6AP80@d=30P0n?Sh203Ph>080=SHf
0P0n?Sh204];B`80B4Q80P1LG5`2065QH@80;Bd]0P0d=3@205aLG080>CTi0P0d=3@202HV9P<0B4Q8
0P1bLW8208n?S`80LG5a0P0/;2`202LW9`809RHV100U9BD202<S8`808B4Q0P0R8R8202<S8`8071`L
0P0J6QX202LW9`80?3`l0P1gMgL208^;R`80YjNW0P2@T90207YjNP80I6AT0P1aLG4208J6QP80WIfM
0P2a/K420;Ng]`80]KFe0P2/[:`20::RXP80Y:BT1@2WYjL20:>SX`80T92@0P21PH4208j>SP80WinO
0P2WYjL20:ZZZP80YJFU0P2RXZ820:^[Z`80][Jf0P2m_Kd20<30`080^KVi0P2a/K420;>c/`80]KFe
0P2^[Zh40:RXZ0H0ZZZZ0P2XZ:P20:NWY`80Z:RX0P2YZJT20:f][@@0[jn_0`2/[:`20:2PX0@0UYJF
0P2KVi/20:2PX080YZJV0P2YZJT20:b/[080[Jf]0P2_[jl20;:b/P80]KFe0P2h^;P40;Zj^RT0b>3H
101LG5`205YJFP80@d=30P0i>CT202h^;P80=cLg0P1DE5@206QXJ080FUYJ0P0b<S8202d];@80:BTY
0P0Z:RX202d];@809RHV0`0];Bd20410@080@d=30P0g=cL202h^;P80@D510P0j>SX2038b<P80;2`/
0P0^;Rh203@d=080:b/[0P0`<30203Xj>P80?3`l0P11@D4204a<C080>SXj0P0k>c/20451@@80=CDe
0P0d=3@204Q8B080E5AD0P1LG5`204m?C`80<C4a0P0g=cL2065QH@80>SXj0P0/;2`202h^;P<0@410
0P1_Kfl208n?S`80LG5a0P0/;2`202h^;P80:BTY0P0S8b<202LW9`809RHV0P0S8b<2028R8P808B4Q
0P0O7al2020P80809BDU0P0f=SH2071`L080UiNG0P2XZ:P208j>SP80M7Ad0P1WIfL2079bLP80Ph>3
0P2PX:020;>c/`80_kno0P2a/K420:VYZ@80Y:BT0P2UYJD30:BTY080YJFU0P2PX:0208j>SP80Q8B4
0P29RHT20:BTY080ZJVY0P2UYJD209jNWP80WinO0P2YZJT20;Jf]P80`L710P2k^k/20;Fe]@80[Jf]
0P2f][H20;Bd]080Zj^[102/[:`40:VYZ@80[:b/0P2VYZH20:RXZ080Y:BT0P2ZZZX20:RXZ080/[:b
0P2c/k<30:n_[`80WIfM0P2:RXX209>CT`80WIfM0P2OWil20:JVYP80YjNW0P2YZJT20:b/[0@0[jn_
0P2d];@20;Vi^@80^k^k0P2g]kLY0<SPf080I6AT0P1QHF4205iNGP80@T920P0c<c<203@d=080>3Ph
0P1BDU8206e]K@80DU9B0P0e=CD2034a<@80:b/[0P0^;Rh2034a<@8092@T0`0_;bl203De=@80@d=3
0P0j>SX203<c<`80<30`0P0k>c/203Hf=P80<C4a0P0Y:BT403@d=080=CDe100k>c/20492@P80CDe=
0P15ADD20492@P80>c/k0P0f=SH203Xj>P80Bd];0P18B4P205]KF`80IfMW0P0a<C4203Ti>@80FUYJ
0P0k>c/203De=@808R8R0`13@d<206i^KP80SHf=0P1dM7@202l_;`808b<S0P0Y:BT202HV9P809bLW
0P0P8202024Q8@8071`L0P0R8R8201PH60805QHF0P0W9bL203`l?080NGUi0P2;Rh/20::RXP80S8b<
0P1gMgL206IVIP80M7Ad0P22PX8209jNWP80[:b/0P2i^KT20;:b/P80Zj^[0P2TY:@50:RXZ080YZJV
0P2SXj<209>CT`80QhN70P2CTi<209nOW`80XZ:R0P2YZJT20:JVYP80XZ:R0P2XZ:P20;Zj^P80^k^k
0P31`L420;^k^`80/K6a0P2b/[820;Bd]080/;2`0P2UYJD20:RXZ0@0ZZZZ0P2][Jd20:ZZZP80YjNW
0P2[Zj/20:JVYP80[Jf]0P2c/k<20:f][@<0[:b/0P2KVi/209RHV080UiNG0P2LW9`209jNWP80YjNW
0P2][Jd20:ZZZP80[jn_0P2`/;020:n_[`80^KVi0P2e]KD20;Ng]`80^k^k7`38h=P001d0b>3H0P1Q
HF42069RHP80GUiN0P15ADD202l_;`80;Bd]0P0g=cL205=CD`80KVi^0P1FEUH203Lg=`80<30`0P0Y
:BT202PX:080:RXZ0P0[:b/302h^;P80>CTi0P12@T8203Xj>P80<S8b0P0g=cL203`l?080=CDe0P0/
;2`202d];@@0<C4a0P0c<c<203Ph>080?Shn0P13@d<204I6AP80@d=30P0n?Sh203Ph>080=SHf0P0n
?Sh204];B`80B4Q80P1LG5`2065QH@80;Bd]0P0d=3@205aLG080>CTi0P0d=3@202HV9P<0B4Q80P1b
LW8208n?S`80LG5a0P0/;2`202LW9`809RHV100U9BD202<S8`808B4Q0P0R8R8202<S8`8071`L0P0J
6QX202LW9`80?3`l0P1gMgL208^;R`80YjNW0P2@T90207YjNP80I6AT0P1aLG4208J6QP80WIfM0P2a
/K420;Ng]`80]KFe0P2/[:`20::RXP80Y:BT1@2WYjL20:>SX`80T92@0P21PH4208j>SP80WinO0P2W
YjL20:ZZZP80YJFU0P2RXZ820:^[Z`80][Jf0P2m_Kd20<30`080^KVi0P2a/K420;>c/`80]KFe0P2^
[Zh40:RXZ0H0ZZZZ0P2XZ:P20:NWY`80Z:RX0P2YZJT20:f][@@0[jn_0`2/[:`20:2PX0@0UYJF0P2K
Vi/20:2PX080YZJV0P2YZJT20:b/[080[Jf]0P2_[jl20;:b/P80]KFe0P2h^;P40;Zj^RT0b>3H101L
G5`205YJFP80@d=30P0i>CT202h^;P80=cLg0P1DE5@206QXJ080FUYJ0P0b<S8202d];@80:BTY0P0Z
:RX202d];@809RHV0`0];Bd20410@080@d=30P0g=cL202h^;P80@D510P0j>SX2038b<P80;2`/0P0^
;Rh203@d=080:b/[0P0`<30203Xj>P80?3`l0P11@D4204a<C080>SXj0P0k>c/20451@@80=CDe0P0d
=3@204Q8B080E5AD0P1LG5`204m?C`80<C4a0P0g=cL2065QH@80>SXj0P0/;2`202h^;P<0@4100P1_
Kfl208n?S`80LG5a0P0/;2`202h^;P80:BTY0P0S8b<202LW9`809RHV0P0S8b<2028R8P808B4Q0P0O
7al2020P80809BDU0P0f=SH2071`L080UiNG0P2XZ:P208j>SP80M7Ad0P1WIfL2079bLP80Ph>30P2P
X:020;>c/`80_kno0P2a/K420:VYZ@80Y:BT0P2UYJD30:BTY080YJFU0P2PX:0208j>SP80Q8B40P29
RHT20:BTY080ZJVY0P2UYJD209jNWP80WinO0P2YZJT20;Jf]P80`L710P2k^k/20;Fe]@80[Jf]0P2f
][H20;Bd]080Zj^[102/[:`40:VYZ@80[:b/0P2VYZH20:RXZ080Y:BT0P2ZZZX20:RXZ080/[:b0P2c
/k<30:n_[`80WIfM0P2:RXX209>CT`80WIfM0P2OWil20:JVYP80YjNW0P2YZJT20:b/[0@0[jn_0P2d
];@20;Vi^@80^k^k0P2g]kLY0<SPf080I6AT0P1QHF4205iNGP80@T920P0c<c<203@d=080>3Ph0P1B
DU8206e]K@80DU9B0P0e=CD2034a<@80:b/[0P0^;Rh2034a<@8092@T0`0_;bl203De=@80@d=30P0j
>SX203<c<`80<30`0P0k>c/203Hf=P80<C4a0P0Y:BT403@d=080=CDe100k>c/20492@P80CDe=0P15
ADD20492@P80>c/k0P0f=SH203Xj>P80Bd];0P18B4P205]KF`80IfMW0P0a<C4203Ti>@80FUYJ0P0k
>c/203De=@808R8R0`13@d<206i^KP80SHf=0P1dM7@202l_;`808b<S0P0Y:BT202HV9P809bLW0P0P
8202024Q8@8071`L0P0R8R8201PH60805QHF0P0W9bL203`l?080NGUi0P2;Rh/20::RXP80S8b<0P1g
MgL206IVIP80M7Ad0P22PX8209jNWP80[:b/0P2i^KT20;:b/P80Zj^[0P2TY:@50:RXZ080YZJV0P2S
Xj<209>CT`80QhN70P2CTi<209nOW`80XZ:R0P2YZJT20:JVYP80XZ:R0P2XZ:P20;Zj^P80^k^k0P31
`L420;^k^`80/K6a0P2b/[820;Bd]080/;2`0P2UYJD20:RXZ0@0ZZZZ0P2][Jd20:ZZZP80YjNW0P2[
Zj/20:JVYP80[Jf]0P2c/k<20:f][@<0[:b/0P2KVi/209RHV080UiNG0P2LW9`209jNWP80YjNW0P2]
[Jd20:ZZZP80[jn_0P2`/;020:n_[`80^KVi0P2e]KD20;Ng]`80^k^k7`38h=P001d0b>3H1P0m?Cd2
03Ph>080=3@d0P0`<30203<c<`80D51@0P1XJ6P205QHF080?clo0P0c<c<402PX:0@0:RXZ0`0[:b/2
03<c<`80>SXj0P0c<c<202d];@80=SHf0P0n?Sh203Lg=`80;bl_0P0`<30203<c<`@0<30`0P10@404
04m?C`80BTY:0P14A4@203hn?P@0>c/k0P13@d<204m?C`80>SXj0P1JFUX205QHF0808B4Q0P0d=3@2
04I6AP80@4100P0i>CT202HV9P<0EeMG0P2EUID208R8R080G5aL0P0Z:RX2028R8P8092@T0P0U9BD2
02LW9`8092@T100Q8B42028R8P80820P0P0O7al201/K6`808B4Q0P14A4@206e]K@80/K6a0P2UYJD2
08f=S@80K6a/0P1XJ6P2071`L080R8R80P2SXj<20;Jf]P80`<300P2c/k<20::RXP80Xj>S1@2VYZH2
0:6QX@80Shn?0P20P80208Z:RP80VIVI0P2RXZ840:VYZ@80Z:RX0P2[Zj/20;2`/080^[Zj0P31`L42
0;Jf]P80Zj^[0P2a/K420;Vi^@80/[:b102YZJT20:ZZZP80ZJVY0P2XZ:P20:FUY@@0Xj>S0P2TY:@2
0:RXZ080[:b/0P2e]KD30;Zj^P80[Jf]0P2MWId209JFUP80UIFE0P2LW9`20:FUY@80Z:RX0P2[Zj/2
0:f][@80[jn_0P2b/[820;Jf]P80]kNg102h^;PY0<SPf080@d=30P12@T8204A4A080=CDe0P0d=3@4
02h^;P80EEEE0P1QHF42069RHP80?Shn0P0];Bd202XZ:P809bLW0P0];Bd202TY:@<0;Bd]0P0d=3@2
03/k>`@0;Rh^0P0h>3P203hn?P80<c<c0P0a<C4202l_;`80=SHf0P0a<C4203<c<`80@4100P1ADE42
04a<C080BTY:0P11@D4203dm?@80A4A40P0i>CT20451@@80CDe=0P16ATH205UIF@80D51@0P0Y:BT2
02/[:`80Bd];0P0k>c/203De=@80;Bd]0`1IFET208R8R080RXZ:0P1NGUh202LW9`80:BTY0P0V9RH2
02@T9080;Rh^0P0X:2P402<S8`808B4Q0P0M7Ad201hN7P807alO0P0V9RH20451@@80Lg=c0P2TY:@2
0:b/[080R8R80P1aLG4206MWI`80M7Ad0P27QhL209nOW`80][Jf0P2o_kl20:f][@80YZJV0P2TY:@3
0:JVYP80YJFU0P2SXj<208f=S@80QXJ60P20P80209^KV`80YjNW0P2TY:@40:b/[080XZ:R0P2`/;02
0<30`080_kno0P2f][H20:f][@80[:b/0P2m_Kd20:j^[P80YjNW0P2][Jd20:ZZZP80ZJVY0P2ZZZX2
0:6QX@80YjNW0P2PX:020:RXZ080Xj>S0P2^[Zh20;2`/0<0]kNg0P2e]KD209jNWP80Shn?0P2IVIT2
09nOW`80YZJV0P2UYJD20:ZZZP80/[:b0P2][Jd20:n_[`80];Bd0P2k^k/20;Bd]080^KVi:@38h=P2
03Ph>080@d=30P0l?3`203De=@80=3@d0P0^;Rh2030`<080E5AD0P1ZJVX205UIF@80@d=30P0b<S82
02HV9P@0:BTY0P0[:b/302l_;`80<C4a0P0j>SX203@d=080;Rh^0P0b<S8203hn?P80>3Ph0P0/;2`2
02d];@80=3@d0P0[:b/2034a<@80A4A40P1>CTh2055AD@80BDU90P11@D4203lo?`80>CTi0P0m?Cd2
04E5A@80CDe=0P0k>c/205UIF@80EeMG0P0L71`203Hf=P80ADE5100i>CT202TY:@<0EeMG0P2HV9P2
08J6QP80GEeM0P0Z:RX201`L70809BDU0P0Z:RX602DU9@8071`L0P0U9BD202LW9`807alO0P0H61P2
028R8P80ADE50P1]KFd20;Bd]080YjNW0P2;Rh/206e]K@80K6a/0P1aLG4208B4Q080Xj>S0P2l_;`2
0;no_`80];Bd0P2PX:020:>SX`<0YjNW0P2VYZH20:6QX@80Ti>C0P1nOWh208B4Q080VYZJ0P2TY:@2
0:ZZZP80Z:RX0P2YZJT20:ZZZP80/[:b0P2j^[X20<71`@80][Jf0P2ZZZX20;>c/`80][Jf0P2d];@4
0:RXZ080ZZZZ0P2YZJT20:JVYP80YJFU0P2SXj<20:BTY080Xj>S0P2YZJT20:^[Z`80/k>c0`2l_;`2
0:^[Z`80W9bL0P2EUID209BDU080VYZJ0P2UYJD20:NWY`@0[:b/0P2`/;020;>c/`80][Jf0P2e]KD2
0;Vi^@80^[Zj7`38h=P001d0b>3H1P0m?Cd203Ph>080=3@d0P0`<30203<c<`80D51@0P1XJ6P205QH
F080?clo0P0c<c<402PX:0@0:RXZ0`0[:b/203<c<`80>SXj0P0c<c<202d];@80=SHf0P0n?Sh203Lg
=`80;bl_0P0`<30203<c<`@0<30`0P10@40404m?C`80BTY:0P14A4@203hn?P@0>c/k0P13@d<204m?
C`80>SXj0P1JFUX205QHF0808B4Q0P0d=3@204I6AP80@4100P0i>CT202HV9P<0EeMG0P2EUID208R8
R080G5aL0P0Z:RX2028R8P8092@T0P0U9BD202LW9`8092@T100Q8B42028R8P80820P0P0O7al201/K
6`808B4Q0P14A4@206e]K@80/K6a0P2UYJD208f=S@80K6a/0P1XJ6P2071`L080R8R80P2SXj<20;Jf
]P80`<300P2c/k<20::RXP80Xj>S1@2VYZH20:6QX@80Shn?0P20P80208Z:RP80VIVI0P2RXZ840:VY
Z@80Z:RX0P2[Zj/20;2`/080^[Zj0P31`L420;Jf]P80Zj^[0P2a/K420;Vi^@80/[:b102YZJT20:ZZ
ZP80ZJVY0P2XZ:P20:FUY@@0Xj>S0P2TY:@20:RXZ080[:b/0P2e]KD30;Zj^P80[Jf]0P2MWId209JF
UP80UIFE0P2LW9`20:FUY@80Z:RX0P2[Zj/20:f][@80[jn_0P2b/[820;Jf]P80]kNg102h^;PY0<SP
f080@d=30P12@T8204A4A080=CDe0P0d=3@402h^;P80EEEE0P1QHF42069RHP80?Shn0P0];Bd202XZ
:P809bLW0P0];Bd202TY:@<0;Bd]0P0d=3@203/k>`@0;Rh^0P0h>3P203hn?P80<c<c0P0a<C4202l_
;`80=SHf0P0a<C4203<c<`80@4100P1ADE4204a<C080BTY:0P11@D4203dm?@80A4A40P0i>CT20451
@@80CDe=0P16ATH205UIF@80D51@0P0Y:BT202/[:`80Bd];0P0k>c/203De=@80;Bd]0`1IFET208R8
R080RXZ:0P1NGUh202LW9`80:BTY0P0V9RH202@T9080;Rh^0P0X:2P402<S8`808B4Q0P0M7Ad201hN
7P807alO0P0V9RH20451@@80Lg=c0P2TY:@20:b/[080R8R80P1aLG4206MWI`80M7Ad0P27QhL209nO
W`80][Jf0P2o_kl20:f][@80YZJV0P2TY:@30:JVYP80YJFU0P2SXj<208f=S@80QXJ60P20P80209^K
V`80YjNW0P2TY:@40:b/[080XZ:R0P2`/;020<30`080_kno0P2f][H20:f][@80[:b/0P2m_Kd20:j^
[P80YjNW0P2][Jd20:ZZZP80ZJVY0P2ZZZX20:6QX@80YjNW0P2PX:020:RXZ080Xj>S0P2^[Zh20;2`
/0<0]kNg0P2e]KD209jNWP80Shn?0P2IVIT209nOW`80YZJV0P2UYJD20:ZZZP80/[:b0P2][Jd20:n_
[`80];Bd0P2k^k/20;Bd]080^KVi:@38h=P203Ph>080@d=30P0l?3`203De=@80=3@d0P0^;Rh2030`
<080E5AD0P1ZJVX205UIF@80@d=30P0b<S8202HV9P@0:BTY0P0[:b/302l_;`80<C4a0P0j>SX203@d
=080;Rh^0P0b<S8203hn?P80>3Ph0P0/;2`202d];@80=3@d0P0[:b/2034a<@80A4A40P1>CTh2055A
D@80BDU90P11@D4203lo?`80>CTi0P0m?Cd204E5A@80CDe=0P0k>c/205UIF@80EeMG0P0L71`203Hf
=P80ADE5100i>CT202TY:@<0EeMG0P2HV9P208J6QP80GEeM0P0Z:RX201`L70809BDU0P0Z:RX602DU
9@8071`L0P0U9BD202LW9`807alO0P0H61P2028R8P80ADE50P1]KFd20;Bd]080YjNW0P2;Rh/206e]
K@80K6a/0P1aLG4208B4Q080Xj>S0P2l_;`20;no_`80];Bd0P2PX:020:>SX`<0YjNW0P2VYZH20:6Q
X@80Ti>C0P1nOWh208B4Q080VYZJ0P2TY:@20:ZZZP80Z:RX0P2YZJT20:ZZZP80/[:b0P2j^[X20<71
`@80][Jf0P2ZZZX20;>c/`80][Jf0P2d];@40:RXZ080ZZZZ0P2YZJT20:JVYP80YJFU0P2SXj<20:BT
Y080Xj>S0P2YZJT20:^[Z`80/k>c0`2l_;`20:^[Z`80W9bL0P2EUID209BDU080VYZJ0P2UYJD20:NW
Y`@0[:b/0P2`/;020;>c/`80][Jf0P2e]KD20;Vi^@80^[Zj7`38h=P001d0b>3H0P1KFe/2059BDP80
@d=30P0g=cL202h^;P80:b/[0P0`<30204U9B@80HF5Q0P1LG5`204m?C`80:b/[0P0Z:RX202LW9`@0
:RXZ0`0[:b/2034a<@80=SHf0P0a<C4202`/;080<C4a0P0h>3P203@d=080;bl_0P0`<302038b<P80
=SHf0P0k>c/204U9B@80E5AD0P1<C4`40451@@80@d=31014A4@203lo?`80?Shn0P12@T8205]KF`80
FUYJ0P0Q8B42038b<P80?clo0P0k>c/203<c<`80<30`0`1BDU8209JFUP80QHF50P1JFUX402XZ:P80
<c<c100e=CD2030`<080:RXZ0P0V9RH202@T90808R8R0P0Q8B4201`L70807AdM0P0/;2`204U9B@80
QhN70P2LW9`209ZJVP80RHV90P1hN7P206][J`80Lg=c0P24Q8@209nOW`80][Jf0P2e]KD20:j^[P80
Z:RX1@2QXJ4209fMW@80S8b<0P1iNGT208R8R080WIfM0P2ZZZX20;>c/`80/;2`0P2[Zj/20:b/[080
/K6a0P2k^k/20<;2`P80^k^k0P2c/k<20;Jf]P80^[Zj0P2b/[820:ZZZP@0Z:RX0P2WYjL20:FUY@80
Xj>S0P2RXZ820:2PX080XJ6Q0P2UYJD20:ZZZP80/[:b0`2h^;P20;Fe]@80[Zj^0P2VYZH209nOW`@0
WIfM0P2RXZ820:RXZ080ZZZZ0P2/[:`20:n_[`80/[:b0P2d];@20;Jf]P80]kNg:@38h=P2051@D080
EUIF0P0o?cl202l_;`80;Rh^0P0b<S8203<c<`80DE5A0P1NGUh2061PH080CDe=0P0b<S8202/[:`80
:RXZ0P0Y:BT202LW9`<0;Bd]0P0b<S8203Lg=`80<c<c0P0_;bl2034a<@80>c/k0P0c<c<2038b<P80
=CDe0P0^;Rh203<c<`80>3Ph0P1CDe<205ADE0@0B4Q80P15ADD20492@P80ADE50P11@D4204=3@`80
>SXj0P10@402065QH@80EUIF0P0[:b/202h^;P80?Shn0P10@40203Lg=`80?3`l0`1GEeL209:BTP80
SXj>0P1KFe/202PX:0809bLW0P0/;2`202d];@80:b/[0P0Z:RX202DU9@8092@T0P0Z:RX2024Q8@@0
7QhN0P0Q8B4202DU9@80BTY:0P25QHD20:BTY080W9bL0P29RHT2071`L080JVYZ0P1bLW8208B4Q080
X:2P0P2j^[X20;fm_@80YjNW0P2TY:@30:FUY@80Y:BT0P2SXj<208J6QP80P8200P23Ph<209VIV@80
[jn_0P2e]KD20;Jf]P80[Zj^0P2TY:@20;:b/P80`L710P30`<020;Rh^080^KVi0P2c/k<20;^k^`80
/k>c0P2YZJT20:NWY`80YZJV0P2PX:020:RXZ080X:2P0P2TY:@20:6QX@80YJFU0P2TY:@20:j^[P80
[jn_0`2d];@20;^k^`80]KFe0P2UYJD209^KV`80W9bL0P2KVi/20:BTY080YjNW0P2^[Zh20:b/[080
[Jf]0P2e]KD20;Jf]P80/k>c0P2m_KdY0<SPf080FEUI0P1CDe<204A4A080=cLg0P0[:b/2038b<P80
;2`/0P1?Cdl205UIF@80FUYJ0P1>CTh402TY:@80:RXZ0P0W9bL202@T90<0;Rh^0P0a<C4203Ph>080
=CDe0P0Z:RX203De=@80>CTi0P0h>3P202h^;P80>3Ph0P0e=CD2034a<@80>3Ph0P18B4P2059BDP80
C4a<0P0m?Cd203hn?P@0@T920P11@D4204A4A080@4100P11@D4205]KF`80EeMG0P0P8202034a<@80
A4A40P0n?Sh203Lg=`80<C4a0`1EEED209JFUP80QHF50P1NGUh202`/;080:RXZ0P0f=SH202`/;080
<c<c0P0j>SX202TY:@8092@T0P0R8R8202@T90808B4Q0P0P820201TI6@809bLW0P18B4P208f=S@80
WYjN0P2FUYH208J6QP80NGUi0P1[Jf/2079bLP80QXJ60P2MWId20;Ng]`80];Bd0P2`/;020:NWY`<0
WIfM0P2SXj<209VIV@80Rh^;0P1hN7P208B4Q080WYjN0P2^[Zh40;6a/@80Zj^[0P2YZJT20:j^[P80
^k^k0P32`/820;Jf]P80/[:b0P2g]kL20;^k^`80/K6a0P2][Jd20:ZZZP80YjNW0P2XZ:P20:JVYPH0
X:2P0P2SXj<20:FUY@80Zj^[0P2a/K430;Vi^@80]KFe0P2_[jl20:VYZ@80XJ6Q102NWYh20:6QX@80
YZJV0P2/[:`40:ZZZP@0];Bd0P2h^;P20;Fe]Al0b>3H000M0<SPf080Fe]K0P1BDU8204=3@`80=cLg
0P0^;Rh202/[:`80<30`0P19BDT2065QH@80G5aL0P1?Cdl202/[:`80:RXZ0P0W9bL402XZ:P<0:b/[
0P0a<C4203Hf=P80<C4a0P0/;2`2034a<@80>3Ph0P0d=3@202l_;`80<30`0P0b<S8203Hf=P80>c/k
0P19BDT205ADE080C4a<1011@D4204=3@`@0A4A40P0o?cl203hn?P80@T920P1KFe/205YJFP808B4Q
0P0b<S8203lo?`80>c/k0P0c<c<2030`<0<0DU9B0P2FUYH208F5Q@80FUYJ100Z:RX203<c<`@0=CDe
0P0`<30202XZ:P809RHV0P0T92@2028R8P808B4Q0P0L71`201dM7@80;2`/0P19BDT208N7Q`80W9bL
0P2JVYX208V9R@80N7Qh0P1[Jf/207=cL`80Q8B40P2OWil20;Jf]P80]KFe0P2^[Zh20:RXZ0D0XJ6Q
0P2MWId208b<S080NGUi0P28R8P209fMW@80ZZZZ0P2c/k<20;2`/080Zj^[0P2/[:`20;6a/@80^k^k
0P32`/820;^k^`80/k>c0P2f][H20;Zj^P80/[:b0P2ZZZX40:RXZ080YjNW0P2UYJD20:>SX`80XZ:R
0P2PX:020:6QX@80YJFU0P2ZZZX20;:b/P<0^;Rh0P2e]KD20:j^[P80YZJV0P2OWil409fMW@80XZ:R
0P2XZ:P20:ZZZP80[:b/0P2_[jl20;:b/P80];Bd0P2f][H20;Ng]bT0b>3H0P1@D50205IFEP80?clo
0P0_;bl202h^;P80<S8b0P0c<c<2055AD@80GUiN0P1PH60204e=C@80<S8b0P0[:b/202XZ:P80:BTY
0P0W9bL302d];@80<S8b0P0g=cL203<c<`80;bl_0P0a<C4203/k>`80<c<c0P0b<S8203De=@80;Rh^
0P0c<c<203Ph>080De=C0P1DE5@404Q8B080ADE50P12@T8204E5A@80@D510P13@d<203Xj>P80@410
0P1QHF4205IFEP80:b/[0P0^;Rh203hn?P80@4100P0g=cL203`l?0<0EeMG0P2BTY8208j>SP80Fe]K
0P0X:2P202LW9`80;2`/0P0];Bd202/[:`80:RXZ0P0U9BD202@T9080:RXZ0P0Q8B4401hN7P808B4Q
0P0U9BD204Y:BP80QHF50P2TY:@209bLW080RHV90P1`L70206YZJP80LW9b0P24Q8@20:2PX080^[Zj
0P2m_Kd20:NWY`80Y:BT0`2UYJD20:BTY080Xj>S0P26QXH20820P080Ph>30P2IVIT20:n_[`80]KFe
0P2f][H20:j^[P80Y:BT0P2b/[820<71`@80`<300P2h^;P20;Vi^@80/k>c0P2k^k/20;>c/`80ZJVY
0P2WYjL20:JVYP80X:2P0P2XZ:P20:2PX080Y:BT0P2QXJ420:FUY@80Y:BT0P2^[Zh20:n_[`<0];Bd
0P2k^k/20;Fe]@80YJFU0P2KVi/209bLW080Vi^K0P2TY:@20:NWY`80[Zj^0P2/[:`20:f][@80]KFe
0P2f][H20;>c/`80_Kfm:@38h=P205UIF@80De=C0P14A4@203Lg=`80:b/[0P0b<S8202`/;080Cdm?
0P1IFET205YJFP80CTi>100Y:BT202XZ:P809bLW0P0T92@302h^;P80<C4a0P0h>3P203De=@80:RXZ
0P0e=CD203Ti>@80>3Ph0P0^;Rh203Ph>080=CDe0P0a<C4203Ph>080B4Q80P1BDU8204a<C080?Cdm
0P0n?Sh40492@P80@D510P14A4@20410@080@D510P1KFe/205MGE`80820P0P0a<C4204A4A080?Shn
0P0g=cL2034a<@<0EEEE0P2FUYH208F5Q@80GUiN0P0/;2`202XZ:P80=SHf0P0/;2`203<c<`80>SXj
0P0Y:BT202@T90808R8R0P0T92@2024Q8@80820P0P0I6AT202LW9`80B4Q80P2=SHd209jNWP80UYJF
0P26QXH207UiN@80Jf][0P1bLW8208J6QP80WIfM0P2g]kL20;Bd]080/;2`0P2WYjL309fMW@80Xj>S
0P2IVIT208^;R`80N7Qh0P24Q8@209jNWP80[Zj^102a/K420:^[Z`80ZJVY0P2^[Zh20;^k^`80`/;2
0P2f][H20;:b/P80]kNg0P2k^k/20;6a/@80[Jf]0P2ZZZX20:NWY`80Z:RX0P2VYZH60:2PX080Xj>S
0P2UYJD20:^[Z`80/K6a0`2i^KT20;Fe]@80[jn_0P2YZJT20:6QX@@0WYjN0P2QXJ420:JVYP80[:b/
102ZZZX40;Bd]080^;Rh0P2e]KDO0<SPf0007@38h=P207QhN080HF5Q0P11@D42034a<@@09bLW0P0^
;Rh20492@P80EUIF101MGEd202HV9P80;bl_0P0X:2P202/[:`80:RXZ0`0[:b/2030`<080<c<c0P0`
<30202`/;080;Rh^0P0a<C42030`<080;bl_0P0`<30203<c<`80?Shn0P19BDT2055AD@80De=C0P16
ATH203Ti>@80@4100P1:BTX204e=C@80BTY:0P0i>CT202d];@80Bd];0P1LG5`205mOG`809BDU0P0_
;bl203`l?080=3@d0P0^;Rh203hn?P<0CTi>0P2>SXh208B4Q080GUiN0P0a<C4203Ph>080AdM70P16
ATH20451@@80>SXj0P0a<C4202/[:`809RHV0P0T92@202<S8`808B4Q0P0P820201lO7`80:BTY0P1D
E5@208>3P`80Vi^K0P2SXj<208^;R`80Kfm_0P1UIFD206IVIP80PX:20P2QXJ420;2`/080][Jf0P2/
[:`309nOW`80WIfM0P2HV9P208J6QP80MWIf0P2:RXX20:FUY@80];Bd0P2m_Kd20;Jf]P80[Jf]0P2_
[jl20;Bd]080_;bl0P33`l<20<71`@80_Kfm0P2l_;`20;^k^`80/k>c0P2/[:`20:VYZ@80YjNW0P2U
YJD20:>SX`80XJ6Q0P2PX:0409nOW`80XZ:R0P2XZ:P20:f][@<0/[:b0P2i^KT20;fm_@80][Jf0P2/
[:`20:2PX080V9RH0P2MWId20:BTY080YjNW0P2XZ:P20:^[Z`80[Zj^0P2b/[820;Fe]@80][Jf:@38
h=P207EeM@80JFUY0P17AdL202d];@809bLW0P0[:b/202d];@80?Shn0P1GEeL205mOG`80EUIF0P0/
;2`202d];@80:BTY0P0_;bl202HV9P<0:b/[0P0_;bl203Hf=P80=3@d0P0];Bd202/[:`80<S8b0P0`
<30202d];@80<C4a0P0d=3@203Ph>080BTY:0P1FEUH204m?C`80ADE50P0j>SX203lo?`80BDU90P1;
Bd/204E5A@80@4100P0a<C4204E5A@80HV9R0P1HF5P202/[:`80;Bd]100l?3`202`/;080<S8b0`1A
DE4208j>SP80QHF50P1HF5P2034a<@80?Shn0P10@40204];B`80@d=30P0n?Sh202h^;P80:BTY0P0V
9RH202@T90@08b<S0P0O7al2024Q8@80:BTY0P1FEUH208:2PP80VYZJ0P2PX:0208R8R080LG5a0P1/
K6`206QXJ080N7Qh0P2OWil20;Rh^080]KFe0P2PX:030:NWY`80XZ:R0P2HV9P20820P080Ng]k0P2>
SXh20:2PX080^k^k0P2j^[X20;6a/@80];Bd0P2VYZH20;Ng]`80_;bl0P33`l<40;bl_080_[jn0P2h
^;P20;Fe]@80[Jf]0P2ZZZX20:b/[080XZ:R0P2TY:@20:>SX`80WinO0P2QXJ4209jNWP80WinO0P2W
YjL20;6a/@<0];Bd0P2f][H20;bl_080/K6a0P2`/;0209nOW`80V9RH0P2LW9`20:BTY0@0Z:RX0P2W
YjL20:n_[`80/;2`0P2d];@20;Zj^RT0b>3H0P1jNWX2061PH080@D510P0`<30202HV9P80:RXZ0P0W
9bL204Q8B080F5QH0P1KFe/2069RHP8092@T0P0_;bl202LW9`80;Rh^0P0Z:RX302`/;080<C4a0P0`
<30203@d=080:2PX0P0_;bl202/[:`80<S8b0P0/;2`2030`<080<C4a0P11@D4204Q8B080DE5A0P1E
EED204I6AP80?Cdm0P10@40404];B`80BDU90P0k>c/202/[:`80C4a<0P1JFUX205aLG0809bLW0P0]
;Bd203Ti>@80=cLg0P0/;2`203`l?0<0CTi>0P2<S8`208F5Q@80Fe]K0P0`<30203<c<`80B4Q80P1:
BTX403hn?P80<c<c0P0W9bL202/[:`807QhN0P0T92@2024Q8@807alO0P0Q8B4202TY:@80De=C0P21
PH4209ZJVP80XZ:R0P2>SXh206i^KP80I6AT0P1YJFT207inOP80Y:BT0P2b/[820;Bd]080[:b/1@2N
WYh209^KV`80QHF50P1hN7P208N7Q`80YJFU0P2c/k<20;jn_P80^KVi0P2ZZZX20;6a/@80/k>c0P2n
_[h20<71`@80_kno0P2n_[h20;fm_@80^k^k0P2a/K420:f][@80YjNW0P2XZ:P20:FUY@80Xj>S0P2P
X:020:6QX@80XZ:R0P2MWId20:2PX080Z:RX0P2[Zj/30;Bd]080^KVi0P2k^k/20;Bd]080ZZZZ0P2R
XZ8209NGU`80W9bL0P2RXZ820:ZZZP80Z:RX0P2ZZZX20:j^[P80/K6a0P2e]KD20;>c/al0b>3H000M
0<SPf080N7Qh0P1QHF420451@@80<C4a100W9bL202h^;P80@T920P1FEUH405eMG@809RHV0P0_;bl2
02PX:080:b/[0P0Z:RX302/[:`80<30`0P0c<c<2030`<080;2`/0P0^;Rh2034a<@80<30`0P0_;bl2
030`<080<c<c0P0n?Sh204U9B@80DE5A0P1CDe<204I6AP80>CTi0P10@40204Y:BP80CDe=0P1:BTX2
03Ti>@80;Bd]0P1;Bd/205aLG080GemO0P0U9BD202l_;`80?3`l0P0d=3@202h^;P80?Shn0`1>CTh2
08j>SP80Q8B40P1NGUh2034a<@80>3Ph0P17AdL204I6AP80@D510P0j>SX2034a<@80:b/[0P0V9RH2
02@T90808b<S0P0Q8B42020P80807alO0P0Y:BT205ADE080Ph>30P2KVi/20:>SX`80Rh^;0P1_Kfl2
06EUI@80IVIV0P22PX820:6QX@80/;2`0P2f][H20:b/[0<0WinO0P2MWId209RHV080QXJ60P1fMWH2
08Z:RP80YJFU0P2d];@20;fm_@80][Jf0P2][Jd20:n_[`80];Bd0P2l_;`20<?3``80`L710P2m_Kd2
0;bl_080^k^k0P2c/k<20:b/[080ZJVY0P2WYjL20:FUY@80Xj>S0P2QXJ420:2PX0@0WinO0P2RXZ82
0:RXZ080[Jf]0`2b/[820;Vi^@80_Kfm0P2f][H20:b/[080X:2P0P2HV9P209fMW@80Y:BT0P2WYjL2
0:RXZ080Zj^[0P2^[Zh20;:b/P80]KFe0P2f][HY0<SPf080MGEe0P1YJFT204M7A`80;Bd]0P0W9bL2
02/[:`80;Bd]0P0n?Sh205MGE`80GemO0P1FEUH202`/;080;Bd]0P0Y:BT202l_;`809RHV0`0[:b/2
02l_;`80=SHf0P0d=3@202d];@80:b/[0P0b<S82030`<080;Bd]0P0a<C4203@d=080>3Ph0P1:BTX2
05IFEP80Cdm?0P15ADD203Xj>P80?clo0P19BDT204];B`80ADE50P10@402034a<@80ADE50P1RHV82
05QHF080:b/[0P0];Bd403`l?080;2`/0P0b<S83055AD@80SXj>0P25QHD205QHF080<C4a0P0n?Sh2
0410@080Bd];0P13@d<203hn?P80;Rh^0P0Y:BT202HV9P8092@T100S8b<201lO7`808B4Q0P0Y:BT2
05IFEP80PX:20P2JVYX20:2PX080R8R80P1aLG4206a/K080J6QX0P1hN7P209nOW`80^;Rh0P2e]KD2
0:2PX0<0YjNW0P2RXZ8209RHV080P8200P1kNg/208j>SP80X:2P0P2k^k/20;Zj^P80/K6a0P2d];@2
0:JVYP80]kNg0P2l_;`20<?3``@0_;bl0P2n_[h20;Rh^080]KFe0P2][Jd20:ZZZP80[:b/0P2RXZ82
0:BTY080Xj>S0P2OWil20:6QX@80WYjN0P2OWil20:NWY`80/K6a0`2d];@20;Jf]P80_;bl0P2a/K42
0;2`/080WinO0P2HV9P209bLW080Y:BT102XZ:P20:NWY`80[jn_0P2`/;020;Bd]080^[Zj:@38h=P2
07YjNP80H61P0P11@D42030`<0809RHV0P0Z:RX202LW9`80B4Q80P1HF5P205]KF`80HV9R0P0T92@2
02l_;`809bLW0P0^;Rh202XZ:P<0;2`/0P0a<C42030`<080=3@d0P0X:2P202l_;`80:b/[0P0b<S82
02`/;080<30`0P0a<C420451@@80B4Q80P1ADE4205EEE@80ATI60P0m?Cd20410@0@0Bd];0P19BDT2
03/k>`80:b/[0P1<C4`205YJFP80G5aL0P0W9bL202d];@80>CTi0P0g=cL202`/;080?3`l0`1>CTh2
08b<S080QHF50P1KFe/2030`<080<c<c0P18B4P204Y:BP@0?Shn0P0c<c<202LW9`80:b/[0P0N7Qh2
02@T90808B4Q0P0O7al2024Q8@80:BTY0P1CDe<20861P@80VYZJ0P2RXZ8208j>SP80KVi^0P1TI6@2
06UYJ@80OWin0P2TY:@20;:b/P80];Bd0P2/[:`509jNWP80Vi^K0P25QHD207QhN080QhN70P2UYJD2
0;>c/`80_[jn0P2i^KT20:ZZZP80/K6a0P2c/k<20;jn_P80`L710P2o_kl20;jn_P80_Kfm0P2k^k/2
0;6a/@80[Jf]0P2WYjL20:RXZ080YJFU0P2SXj<20:2PX080XJ6Q0P2RXZ8209fMW@80X:2P0P2XZ:P2
0:^[Z`<0];Bd0P2i^KT20;^k^`80];Bd0P2ZZZX20::RXP80UiNG0P2LW9`20::RXP80ZZZZ0P2XZ:P2
0:ZZZP80[Zj^0P2a/K420;Fe]@80/k>c7`38h=P001d0b>3H0P1fMWH206a/K080F5QH0P0k>c/202@T
90809BDU0P0`<30203Xj>P80ADE50P1CDe<205aLG080=SHf0P0c<c<402d];@D0;2`/0P0^;Rh202l_
;`@0;Rh^0P0`<302034a<@80;Rh^0P0];Bd203@d=080?Cdm0P1;Bd/205ADE080D51@0P18B4P20492
@P80?clo0P19BDT205=CD`80CTi>0P15ADD203@d=080;2`/0P0k>c/205mOG`80HF5Q0P0Q8B4202TY
:@80<c<c0P0_;bl202h^;P80B4Q80`1PH60208V9R@80R8R80P1]KFd204e=C@80Cdm?0P1IFET206EU
I@80JFUY0P1<C4`202`/;0@09BDU100T92@2028R8P808B4Q0P0O7al202<S8`80=cLg0P1GEeL207in
OP80WIfM0P2GUiL208B4Q080K6a/0P1KFe/206IVIP80PH610P2HV9P20:b/[080/K6a0`2_[jl209nO
W`80Ti>C0P1gMgL20820P080Ti>C0P2/[:`20;Jf]P80_[jn0P2g]kL20:n_[`80/[:b0P2g]kL20;bl
_080`<300P31`L440<30`080_[jn0P2h^;P20;6a/@80[:b/0P2WYjL20:FUY@80Y:BT0P2RXZ820:2P
X080WinO0P2PX:020:>SX`80YjNW0P2[Zj/30;2`/080][Jf0P2j^[X20;Rh^080/[:b0P2ZZZX20::R
XP80XJ6Q0P2RXZ820:BTY080YjNW0P2[Zj/20:j^[P80/[:b0P2d];@20;Fe]BT0b>3H0P1hN7P206QX
J080EeMG0P0`<30202`/;0809RHV0P0[:b/203Hf=P80?clo0P1KFe/205eMG@80=SHf0P0];Bd202l_
;`80;2`/0P0[:b/303De=@H0:RXZ0P0[:b/202h^;P80<30`0P0a<C4202/[:`80=cLg0P13@d<204a<
C080E5AD0P1@D50204i>CP80>c/k0P0o?cl204Q8B080EUIF0P1EEED204E5A@80>3Ph0P0X:2P203Ph
>080IfMW0P1CDe<202@T90808b<S0P0];Bd203Ti>@80:b/[0P0k>c/3069RHP80TI6A0P27QhL206=S
H`80EUIF0P1ADE4206ATI080Kfm_0P1SHf<205UIF@80<c<c0P0U9BD2024Q8@80:RXZ0P0R8R8202@T
90807alO0P0R8R8202PX:080;Rh^0P1@D50208J6QP80WinO0P2RXZ820861P@80IVIV0P1MGEd206=S
H`80O7al0P2NWYh20;Fe]@80Zj^[0`2QXJ420:BTY080SXj>0P1jNWX207]kN`80QXJ60P2`/;020;jn
_P80^[Zj0P2^[Zh20:n_[`80];Bd0P2e]KD20<30`080`L71102o_kl20<71`@80_kno0P2e]KD20:j^
[P80ZZZZ0P2VYZH20::RXP80YJFU0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`80YZJV0P2ZZZX30:f]
[@80]KFe0P2i^KT20;Jf]P80/[:b0P2`/;020::RXP80WYjN0P2PX:020:BTY080YjNW1P2][Jd20;2`
/080^k^k:@38h=P207YjNP80JFUY0P1KFe/203Ti>@809BDU0P0T92@203@d=080=SHf0P14A4@2059B
DP80G5aL0P0e=CD203Hf=P80<C4a0P0];Bd202PX:0<0;2`/0P0`<30402`/;080;Bd]0P0b<S8203<c
<`@0:b/[0P0d=3@203/k>`80Bd];0P1IFET2055AD@80AdM70P11@D4203dm?@80C4a<0P1DE5@204i>
CP80B4Q80P0a<C4202/[:`80?Shn0P1TI6@2069RHP8092@T0P0V9RH2034a<@80<S8b0P0W9bL204Y:
BP<0HF5Q0P27QhL208V9R@80Kfm_0P1DE5@204e=C@80F5QH0P1XJ6P206e]K@80@d=30P0[:b/201dM
7@80:BTY0P0R8R8202LW9`807QhN0P0V9RH2024Q8@808R8R0P0j>SX205EEE@80QHF50P2LW9`209RH
V080QXJ60P1/K6`205aLG080I6AT0P1oOgl209JFUP80[Jf]0P2c/k<30;6a/@80XZ:R0P2ATI4207If
MP80PX:20P2HV9P20:f][@80]KFe0P2k^k/20;Rh^080[Jf]102g]kL20;Zj^P80`/;20P36a/H20;no
_`80`<300P2m_Kd20;Rh^080/K6a0P2XZ:P20:VYZ@@0YJFU0P2OWil20:6QX@80X:2P0P2OWil20:>S
X`80ZZZZ0P2YZJT30;2`/080]KFe0P2m_Kd20;Fe]@80/[:b0P2/[:`20:2PX0@0XZ:R102XZ:P20:ZZ
ZP80/;2`0P2a/K420;Rh^080/k>c7`38h=P001d0b>3H0P1fMWH206a/K080F5QH0P0k>c/202@T9080
9BDU0P0`<30203Xj>P80ADE50P1CDe<205aLG080=SHf0P0c<c<402d];@D0;2`/0P0^;Rh202l_;`@0
;Rh^0P0`<302034a<@80;Rh^0P0];Bd203@d=080?Cdm0P1;Bd/205ADE080D51@0P18B4P20492@P80
?clo0P19BDT205=CD`80CTi>0P15ADD203@d=080;2`/0P0k>c/205mOG`80HF5Q0P0Q8B4202TY:@80
<c<c0P0_;bl202h^;P80B4Q80`1PH60208V9R@80R8R80P1]KFd204e=C@80Cdm?0P1IFET206EUI@80
JFUY0P1<C4`202`/;0@09BDU100T92@2028R8P808B4Q0P0O7al202<S8`80=cLg0P1GEeL207inOP80
WIfM0P2GUiL208B4Q080K6a/0P1KFe/206IVIP80PH610P2HV9P20:b/[080/K6a0`2_[jl209nOW`80
Ti>C0P1gMgL20820P080Ti>C0P2/[:`20;Jf]P80_[jn0P2g]kL20:n_[`80/[:b0P2g]kL20;bl_080
`<300P31`L440<30`080_[jn0P2h^;P20;6a/@80[:b/0P2WYjL20:FUY@80Y:BT0P2RXZ820:2PX080
WinO0P2PX:020:>SX`80YjNW0P2[Zj/30;2`/080][Jf0P2j^[X20;Rh^080/[:b0P2ZZZX20::RXP80
XJ6Q0P2RXZ820:BTY080YjNW0P2[Zj/20:j^[P80/[:b0P2d];@20;Fe]BT0b>3H0P1hN7P206QXJ080
EeMG0P0`<30202`/;0809RHV0P0[:b/203Hf=P80?clo0P1KFe/205eMG@80=SHf0P0];Bd202l_;`80
;2`/0P0[:b/303De=@H0:RXZ0P0[:b/202h^;P80<30`0P0a<C4202/[:`80=cLg0P13@d<204a<C080
E5AD0P1@D50204i>CP80>c/k0P0o?cl204Q8B080EUIF0P1EEED204E5A@80>3Ph0P0X:2P203Ph>080
IfMW0P1CDe<202@T90808b<S0P0];Bd203Ti>@80:b/[0P0k>c/3069RHP80TI6A0P27QhL206=SH`80
EUIF0P1ADE4206ATI080Kfm_0P1SHf<205UIF@80<c<c0P0U9BD2024Q8@80:RXZ0P0R8R8202@T9080
7alO0P0R8R8202PX:080;Rh^0P1@D50208J6QP80WinO0P2RXZ820861P@80IVIV0P1MGEd206=SH`80
O7al0P2NWYh20;Fe]@80Zj^[0`2QXJ420:BTY080SXj>0P1jNWX207]kN`80QXJ60P2`/;020;jn_P80
^[Zj0P2^[Zh20:n_[`80];Bd0P2e]KD20<30`080`L71102o_kl20<71`@80_kno0P2e]KD20:j^[P80
ZZZZ0P2VYZH20::RXP80YJFU0P2RXZ8209nOW`80W9bL0P2QXJ4209nOW`80YZJV0P2ZZZX30:f][@80
]KFe0P2i^KT20;Jf]P80/[:b0P2`/;020::RXP80WYjN0P2PX:020:BTY080YjNW1P2][Jd20;2`/080
^k^k:@38h=P207YjNP80JFUY0P1KFe/203Ti>@809BDU0P0T92@203@d=080=SHf0P14A4@2059BDP80
G5aL0P0e=CD203Hf=P80<C4a0P0];Bd202PX:0<0;2`/0P0`<30402`/;080;Bd]0P0b<S8203<c<`@0
:b/[0P0d=3@203/k>`80Bd];0P1IFET2055AD@80AdM70P11@D4203dm?@80C4a<0P1DE5@204i>CP80
B4Q80P0a<C4202/[:`80?Shn0P1TI6@2069RHP8092@T0P0V9RH2034a<@80<S8b0P0W9bL204Y:BP<0
HF5Q0P27QhL208V9R@80Kfm_0P1DE5@204e=C@80F5QH0P1XJ6P206e]K@80@d=30P0[:b/201dM7@80
:BTY0P0R8R8202LW9`807QhN0P0V9RH2024Q8@808R8R0P0j>SX205EEE@80QHF50P2LW9`209RHV080
QXJ60P1/K6`205aLG080I6AT0P1oOgl209JFUP80[Jf]0P2c/k<30;6a/@80XZ:R0P2ATI4207IfMP80
PX:20P2HV9P20:f][@80]KFe0P2k^k/20;Rh^080[Jf]102g]kL20;Zj^P80`/;20P36a/H20;no_`80
`<300P2m_Kd20;Rh^080/K6a0P2XZ:P20:VYZ@@0YJFU0P2OWil20:6QX@80X:2P0P2OWil20:>SX`80
ZZZZ0P2YZJT30;2`/080]KFe0P2m_Kd20;Fe]@80/[:b0P2/[:`20:2PX0@0XZ:R102XZ:P20:ZZZP80
/;2`0P2a/K420;Rh^080/k>c7`38h=P001d0b>3H0P1eMGD205IFEP80;bl_0P0V9RH202LW9`80;2`/
100c<c<203@d=080AdM70P1FEUH204Y:BP80>CTi0P0c<c<2030`<080;Rh^0`0];Bd402`/;080;Bd]
0P0_;bl2038b<P80<c<c0P0^;Rh202`/;080>SXj0P1:BTX205IFEP80Fe]K0P1<C4`203`l?080@410
0P18B4P205=CD`80FUYJ0P1<C4`203/k>`@0;bl_0P0/;2`2065QH@80GemO0P0N7Qh202<S8`80;Bd]
0P0^;Rh203Hf=P80EEEE0`1eMGD208>3P`80RHV90P1fMWH2065QH@80I6AT0P1XJ6P205iNGP80CTi>
0P0j>SX202TY:@H09BDU0P0T92@602<S8`809BDU0P0T92@202d];@80FUYJ0P28R8P209RHV080UYJF
0P1hN7P205UIF@80EEEE0P1RHV8207alO080V9RH0P2_[jl30;Zj^P80Xj>S0P2>SXh206a/K080Shn?
0P2LW9`20:n_[`80][Jf0P2l_;`20;Jf]P80/;2`0P2d];@20;Zj^P80^k^k0P2m_Kd20;no_`@0`/;2
0P31`L420;fm_@80]kNg0P2`/;020:ZZZP80YjNW0P2VYZH20::RXP80WinO0P2PX:020::RXP80Y:BT
0P2VYZH20:VYZ@<0[Jf]0P2`/;020;>c/`@0][Jf0P2c/k<20:j^[P80YjNW0P2QXJ420::RXP80YZJV
0P2ZZZX20:j^[P80/K6a0P2c/k<20;Bd]2T0b>3H0P1bLW8205eMG@80=3@d0P0];Bd202HV9P80:BTY
0P0_;bl203`l?080<c<c0P13@d<205QHF080AdM70P11@D4203<c<`@0<30`0`0[:b/202d];@80<C4a
0P0];Bd2034a<@80<S8b0P0h>3P202l_;`80<C4a0P0d=3@204I6AP80G5aL0P1@D50205=CD`80>c/k
0P0o?cl204];B`80CTi>0P1IFET204];B`80?Cdm0P0/;2`202h^;P80>SXj0P1RHV8205=CD`809BDU
0P0S8b<202XZ:P80=cLg0P0a<C4205=CD`<0LW9b0P28R8P208N7Q`80Jf][0P1XJ6P205iNGP80GemO
0P1MGEd204Q8B080=CDe0P0U9BD202<S8`809RHV0P0Z:RX202@T90808B4Q0P0U9BD202@T90809BDU
0P0Q8B42038b<P80Fe]K0P23Ph<209ZJVP80U9BD0P1eMGD205YJFP80De=C0P1VIVH207IfMP80UYJF
0P2d];@30;Jf]P80YJFU0P29RHT207QhN080SHf=0P2EUID20:b/[080^k^k0P2l_;`20;Jf]P80/;2`
0P2e]KD20;^k^`80^[Zj0P2l_;`20<30`080`/;21031`L420;fm_@80][Jf0P2c/k<20:NWY`80ZJVY
102UYJD60:6QX@80YZJV0P2UYJD20:ZZZP<0[jn_0P2/[:`20;Bd]080]kNg0P2f][H20;:b/P80[Jf]
0P2WYjL20:BTY080XJ6Q0P2VYZH20:^[Z`80[Jf]0P2/[:`20;6a/@80^;Rh:@38h=P207=cL`80F5QH
0P0^;Rh202PX:0809RHV0P0^;Rh2034a<@80<S8b0P0d=3@204Y:BP80EEEE0P15ADD203Ti>@80<c<c
0P0^;Rh202l_;`<0;2`/0P0a<C4202h^;P80:BTY0P0c<c<2030`<080<c<c0P0a<C4202l_;`80?3`l
0P1<C4`205=CD`80FEUI0P19BDT203dm?@80A4A40P16ATH2055AD@80EUIF0P1>CTh203Xj>P80;2`/
0P0a<C4202h^;P80GUiN0P1QHF4201dM7@8071`L0P0[:b/2038b<P80=3@d0P1EEED307EeM@80Ph>3
0P2<S8`2075aL@80Hf=S0P1RHV8206a/K080GemO0P1=CDd203De=@80;bl_0P0V9RH202DU9@80:BTY
0P0R8R82020P80808b<S0P0Q8B4202HV9P808R8R0P0[:b/205]KF`80QhN7102EUID207YjNP@0EeMG
0P1RHV8207moO`80UiNG0P2[Zj/30;^k^`80XJ6Q0P2BTY8206][J`80SHf=0P2LW9`20:f][@80^k^k
0P2m_Kd20;Fe]@80[Jf]0P2d];@20;Vi^@80^[Zj0P2m_Kd20<C4a080`<300P33`l<20<30`080_Kfm
0P2h^;P20;2`/080[:b/0P2VYZH20:NWY`80XZ:R0P2QXJ4209bLW0@0Xj>S102WYjL30:n_[`80/;2`
0P2b/[820;Ng]`80][Jf0P2b/[820:j^[P80YjNW0P2OWil20:2PX080YZJV0P2XZ:P20:j^[P80/;2`
0P2a/K420;Bd]1l0b>3H000M0<SPf080MGEe0P1FEUH202l_;`809RHV0P0W9bL202`/;0@0<c<c0P0d
=3@204M7A`80EUIF0P1:BTX203Ti>@80<c<c0P0`<30202h^;P<0;Bd]100/;2`202d];@80;bl_0P0b
<S8203<c<`80;Rh^0P0/;2`203Xj>P80BTY:0P1FEUH205]KF`80C4a<0P0l?3`20410@080B4Q80P1C
De<205YJFP80C4a<0P0k>c/402l_;`80;2`/0P1QHF4205mOG`807QhN0P0S8b<202d];@80;Rh^0P0f
=SH205EEE@<0MGEe0P23Ph<208V9R@80MWIf0P1QHF4206ATI080J6QX0P1NGUh204i>CP80>SXj0P0Y
:BT602DU9@8092@T1P0S8b<202DU9@8092@T0P0];Bd205YJFP80R8R80P2HV9P209JFUP80N7Qh0P1I
FET205EEE@80HV9R0P1lO7`209RHV080[jn_0`2j^[X20:>SX`80SXj>0P1/K6`208n?S`80W9bL0P2_
[jl20;Jf]P80_;bl0P2f][H20;2`/080];Bd0P2j^[X20;^k^`80_Kfm0P2o_kl40<;2`P80`L710P2m
_Kd20;Ng]`80/;2`0P2ZZZX20:NWY`80YZJV0P2RXZ8209nOW`80X:2P0P2RXZ820:BTY080YZJV0P2Y
ZJT30:f][@80/;2`0P2c/k<40;Jf]P80/k>c0P2^[Zh20:NWY`80XJ6Q0P2RXZ820:JVYP80ZZZZ0P2^
[Zh20;6a/@80/k>c0P2d];@Y0<SPf080LW9b0P1MGEd203@d=080;Bd]0P0V9RH202TY:@80;bl_0P0l
?3`203<c<`80@d=30P1HF5P204M7A`80@D510P0c<c<4030`<0<0:b/[0P0];Bd2034a<@80;Bd]0P0a
<C42038b<P80>3Ph0P0_;bl2034a<@80=3@d0P16ATH205aLG080D51@0P1CDe<203/k>`80?clo0P1;
Bd/204i>CP80FEUI0P1;Bd/203dm?@80;2`/0P0^;Rh203Xj>P80HV9R0P1CDe<202DU9@808b<S0P0Z
:RX203Lg=`80<C4a0P1CDe<3079bLP80R8R80P27QhL206][J`80J6QX0P1NGUh205mOG`80GEeM0P18
B4P203De=@809BDU0P0S8b<202HV9P80:RXZ0P0T92@2024Q8@809BDU0P0T92@202DU9@808B4Q0P0b
<S8205]KF`80Ph>30P2JVYX209BDU080MGEe0P1JFUX205=CD`80IVIV0P1fMWH209JFUP80];Bd0`2f
][H20:FUY@80RHV90P1hN7P208f=S@80UIFE0P2/[:`20;^k^`80_;bl0P2f][H20;2`/080]KFe0P2k
^k/20;Zj^P80_;bl0P30`<020<;2`P@0`L710P2m_Kd20;Jf]P80/k>c0P2WYjL20:VYZ@@0YJFU1P2Q
XJ420:JVYP80YJFU0P2ZZZX30:n_[`80[:b/0P2d];@20;Ng]`80][Jf0P2b/[820:f][@80YjNW0P2T
Y:@20:6QX@80YZJV0P2[Zj/20:f][@80[:b/0P2a/K420;Rh^2T0b>3H0P1cLg<205QHF080;Rh^0P0X
:2P202HV9P80;Rh^0P0a<C42038b<P80=3@d0P1:BTX205EEE@80ADE50P0i>CT203<c<`80;Rh^0P0_
;bl302`/;080<C4a0P0^;Rh202TY:@80<c<c0P0`<30203<c<`80<C4a0P0_;bl203`l?080C4a<0P1C
De<205UIF@80BDU90P0m?Cd204A4A080ATI60P1ADE4205IFEP80CTi>0P0j>SX202`/;080<C4a0P0^
;Rh205iNGP80HF5Q0P0M7Ad201`L7080:b/[0P0b<S8203@d=080EEEE0`1eMGD208>3P`80S8b<0P1a
LG4206=SH`80HV9R0P1/K6`205mOG`80CDe=0P0e=CD202l_;`809RHV0P0U9BD202TY:@808R8R0P0P
820202<S8`808B4Q0P0V9RH2028R8P80:b/[0P1KFe/208N7Q`@0UIFE0P1jNWX405MGE`80HV9R0P1o
Ogl209NGU`80Zj^[0`2k^k/20:6QX@80TY:B0P1[Jf/208f=S@80W9bL0P2][Jd20;^k^`80_Kfm0P2e
]KD20:f][@80];Bd0P2i^KT20;Zj^P80_Kfm0P34a<@20<30`080`l?30P30`<020;fm_@80^;Rh0P2`
/;020:b/[080YZJV0P2WYjL20::RXP80XJ6Q0P2LW9`40:>SX`@0YjNW0`2_[jl20;2`/080/[:b0P2g
]kL20;Jf]P80/[:b0P2^[Zh20:NWY`80WinO0P2PX:020:JVYP80Z:RX0P2^[Zh20;2`/080/K6a0P2d
];@O0<SPf0007@38h=P207=cL`80F5QH0P0e=CD202h^;P80:RXZ0P0_;bl203De=@80;Rh^0P0Z:RX2
03hn?P80Cdm?0P1MGEd203hn?P80=cLg0P0`<30202h^;P<0;Bd]0P0/;2`202d];@80;Rh^0P0`<304
034a<@80;Rh^0P0_;bl204A4A0@0F5QH0P1BDU8204I6AP80?Cdm0P13@d<204i>CP80FEUI0P1NGUh2
04M7A`80<30`0P0/;2`203<c<`80>SXj0P1KFe/204m?C`8092@T0P0Q8B4202PX:080?Shn0P1CDe<2
06][J`<0Ogmo0P20P80207]kN`80HV9R0P17AdL203Xj>P80<C4a0P0Y:BT202DU9@80:BTY0P0_;bl2
02`/;0H0:2PX0P0U9BD2028R8P808b<S0P0T92@2020P80808b<S0P0n?Sh205eMG@80O7al0P2?Shl2
07alO080H61P0P1WIfL205MGE`80I6AT0P1gMgL209FEU@<0Zj^[0P2ZZZX208b<S080MGEe102OWil2
0:2PX080_;bl102f][H20;>c/`80]KFe0P2h^;P20;Vi^@80^[Zj0P2m_Kd20;no_`@0`<300P2l_;`2
0;Ng]`80/k>c0P2^[Zh20:VYZ@80YJFU0P2RXZ8209nOW`80X:2P0P2QXJ420:>SX`80YJFU0P2WYjL3
0:VYZ@80[:b/0P2_[jl20;Bd]080^;Rh0P2e]KD20;2`/080Z:RX0P2RXZ840:2PX080Xj>S0P2WYjL2
0:f][@80/K6a0P2c/k<Y0<SPf080MWIf0P1BDU8202h^;P809bLW0P0[:b/2034a<@80>c/k0P0d=3@2
02/[:`80?3`l0P1DE5@2051@D080?Cdm0P0i>CT2034a<@80;2`/0`0[:b/202d];@@0;bl_0P0e=CD2
02l_;`80;Rh^0P0[:b/202l_;`80?Shn0P1HF5P205mOG`80F5QH0P12@T8203Xj>P80@D510P1EEED2
05MGE`80H61P0P1=CDd202/[:`809bLW0P0_;bl20410@080EeMG0P1@D50202DU9@80:RXZ0P0/;2`2
03Xj>P80G5aL0P1XJ6P307emO@80SHf=0P26QXH205aLG080ATI60P0o?cl203Hf=P80;bl_0P0^;Rh2
02XZ:P80<C4a0P0Y:BT202XZ:P809RHV0P0Y:BT202<S8`@08R8R0P0T92@202PX:0809RHV0P0_;bl2
05mOG`80OWin0P2CTi<207YjNP80IVIV0P1YJFT2061PH080G5aL0P1gMgL209FEU@<0]KFe0P2^[Zh2
08J6QP80MgMg0P2VYZH209jNWP80YjNW0P2l_;`20;Jf]P@0];Bd0P2e]KD20;Jf]P80]KFe0P2j^[X2
0;bl_080`L710P2n_[h20;no_`80_[jn0P2i^KT20;Bd]080/K6a0P2YZJT20::RXP80Y:BT0P2KVi/2
09bLW080XZ:R0P2TY:@20:FUY@80Z:RX0`2[Zj/20:b/[080/;2`0P2e]KD20;Jf]P80/k>c0P2a/K42
0:JVYP80XZ:R0P2KVi/20:2PX080YJFU0P2/[:`20:j^[P@0][Jf:@38h=P2079bLP80FUYJ0P0a<C42
02h^;P809bLW0P0d=3@203Lg=`80:2PX0P0`<30203dm?@80DE5A0P1PH60203lo?`80=3@d0P0e=CD2
02d];@<0:BTY100_;bl202DU9@80<S8b0P0e=CD2034a<@80:RXZ0P0/;2`203dm?@80Fe]K0P1IFET2
05EEE@80ADE50P0k>c/204E5A@80Cdm?0P1JFUX205mOG`80CTi>0P0];Bd202l_;`80<S8b0P0c<c<2
05QHF080EEEE0P0R8R8202PX:080;2`/0P13@d<205MGE`80Hf=S0`21PH4207inOP80O7al0P1QHF42
04A4A080=cLg100/;2`202HV9P80;2`/0P0`<30202LW9`809RHV100Z:RX202@T90808R8R100T92@2
020P80808R8R0P0n?Sh205aLG080OGem0P2=SHd207alO080GUiN0P1/K6`205ADE080IFEU0P1hN7P2
09NGU`<0ZZZZ0P2XZ:P208R8R080N7Qh0P2OWil209ZJVP80W9bL0P31`L420;:b/P80][Jf102h^;P4
0;Vi^@80]KFe0P2i^KT20;fm_@80`l?30P32`/820;^k^`80][Jf0P2d];@20:^[Z`80ZJVY0P2TY:@2
0:JVYP80X:2P0P2MWId60:BTY080YJFU0`2[Zj/20:ZZZP80/;2`0P2e]KD20;Rh^080][Jf0P2`/;02
0:NWY`80YZJV102PX:020:JVYP80Z:RX0P2/[:`20;>c/`80/K6a7`38h=P001d0b>3H0P1cLg<205QH
F080=CDe0P0^;Rh202XZ:P80;bl_0P0e=CD202h^;P80:RXZ0P0n?Sh204m?C`80GEeM0P0n?Sh203Lg
=`80<30`0P0^;Rh302d];@80;2`/0P0];Bd202h^;P80<30`100a<C4202h^;P80;bl_0P14A4@405QH
F080DU9B0P16ATH203dm?@80@d=30P1>CTh205UIF@80GUiN0P17AdL2030`<080;2`/0P0c<c<203Xj
>P80Fe]K0P1?Cdl202@T90808B4Q0P0X:2P203hn?P80De=C0P1[Jf/307moO`80P8200P1kNg/2069R
HP80AdM70P0j>SX2034a<@80:BTY0P0U9BD202TY:@80;bl_0P0/;2`602PX:0809BDU0P0R8R8202<S
8`8092@T0P0P820202<S8`80?Shn0P1MGEd207alO080Shn?0P1lO7`2061PH080IfMW0P1GEeL206AT
I080MgMg0P2EUID30:^[Z`80ZZZZ0P2<S8`207EeM@@0WinO0P2PX:020;bl_0@0][Jf0P2c/k<20;Fe
]@80^;Rh0P2i^KT20;Zj^P80_Kfm0P2o_kl40<30`080_;bl0P2g]kL20;>c/`80[Zj^0P2YZJT20:FU
Y@80XZ:R0P2OWil20:2PX080XJ6Q0P2SXj<20:FUY@80YjNW0`2YZJT20:b/[080[jn_0P2d];@20;Rh
^080]KFe0P2`/;020:RXZ080XZ:R102PX:020:>SX`80YjNW0P2][Jd20;6a/@80/k>c:@38h=P207If
MP80DU9B0P0^;Rh202LW9`80:b/[0P0a<C4203/k>`80=3@d0P0[:b/203`l?080E5AD0P1@D50203dm
?@80>CTi0P0a<C4202`/;0<0:b/[0P0];Bd402l_;`80=CDe0P0_;bl202h^;P80:b/[0P0_;bl203hn
?P80F5QH0P1OGel205QHF080@T920P0j>SX20451@@80EEEE0P1GEeL2061PH080CDe=0P0[:b/202LW
9`80;bl_0P10@40205MGE`80D51@0P0U9BD202XZ:P80;2`/0P0j>SX205aLG080J6QX0`1mOGd208f=
S@80QXJ60P1LG5`204I6AP80?clo0P0f=SH202l_;`80;Rh^0P0Z:RX2034a<@80:BTY0P0Z:RX202HV
9P80:BTY0P0S8b<4028R8P8092@T0P0X:2P202HV9P80;bl_0P1OGel207inOP80Ti>C0P1jNWX206IV
IP80JFUY0P1PH60205aLG080MgMg0P2EUID30;Fe]@80[Zj^0P26QXH207MgM`80YZJV0P2NWYh20:NW
Y`80_;bl0P2f][H40;Bd]080]KFe0P2f][H20;Fe]@80^[Zj0P2l_;`20<71`@80_[jn0P2o_kl20;jn
_P80^KVi0P2d];@20;6a/@80ZJVY0P2RXZ820:BTY080Vi^K0P2LW9`20::RXP80Y:BT0P2UYJD20:RX
Z0<0Zj^[0P2/[:`20;2`/080]KFe0P2f][H20;>c/`80/K6a0P2VYZH20::RXP80Vi^K0P2PX:020:FU
Y@80[:b/0P2^[Zh40;Jf]RT0b>3H0P1bLW8205YJFP80<C4a0P0^;Rh202LW9`80=3@d0P0g=cL202PX
:080<30`0P0m?Cd2055AD@80H61P0P0o?cl203@d=080=CDe0P0];Bd302TY:@@0;bl_0P0U9BD2038b
<P80=CDe0P0a<C4202XZ:P80;2`/0P0m?Cd205]KF`80FEUI0P1EEED204E5A@80>c/k0P15ADD204m?
C`80FUYJ0P1OGel204i>CP80;Bd]0P0_;bl2038b<P80<c<c0P1HF5P205EEE@808R8R0P0X:2P202`/
;080@d=30P1GEeL206=SH`<0PH610P1nOWh207alO080HF5Q0P14A4@203Lg=`@0;2`/0P0V9RH202`/
;080<30`0P0W9bL202HV9P@0:RXZ0P0T92@2028R8P@092@T0P0P8202028R8P80?Shn0P1LG5`207em
O@80SHf=0P1lO7`205iNGP80K6a/0P1DE5@206EUI@80N7Qh0P2GUiL30:ZZZP80Z:RX0P28R8P207Qh
N080WinO0P2JVYX209bLW080`L710P2b/[820;Jf]P@0^;Rh102i^KT20;Fe]@80^KVi0P2m_Kd20<?3
``80`/;20P2k^k/20;Jf]P80];Bd0P2[Zj/20:VYZ@80Y:BT0P2VYZH20:2PX080WIfM1P2TY:@20:FU
Y@<0Zj^[0P2ZZZX20;2`/080]KFe0P2h^;P20;Jf]P80/;2`0P2WYjL20:JVYP@0X:2P0P2VYZH20:RX
Z080[:b/0P2c/k<20;6a/Al0b>3H000M0<SPf080LW9b0P1KFe/203hn?P80=cLg0P0c<c<203Lg=`80
>SXj0P0_;bl202HV9P80>3Ph0P18B4P206UYJ@80A4A40P0l?3`2034a<@80;Rh^1@0];Bd<02l_;`80
<c<c0P1<C4`2065QH@80EeMG0P16ATH20492@P80@D510P19BDT2059BDP80G5aL0P1NGUh20492@P80
9bLW0P0Z:RX203Hf=P80BDU90P1DE5@203hn?P80:BTY0P0T92@202/[:`80Cdm?0P1aLG4207moO`<0
PX:20P1iNGT206IVIP80A4A40P0U9BD202PX:080<S8b100d=3@203<c<`80<S8b0P0^;Rh202XZ:P80
:b/[0P0/;2`202PX:08092@T0P0S8b<202@T90808b<S0P0T92@202PX:080=3@d0P1JFUX207]kN`80
NWYj0P1ZJVX207inOP80EUIF0P1CDe<205IFEP80MWIf0`2BTY820:^[Z`80QhN70P20P8020:f][@80
WYjN0P2?Shl20;jn_P80/K6a0P2f][H40;Fe]@@0][Jf0P2h^;P20;Zj^P80_;bl102m_Kd20;Zj^P80
]kNg0P2e]KD20;>c/`80[:b/0P2UYJD20::RXP@0X:2P0P2QXJ420:>SX`@0YJFU0`2VYZH20:RXZ080
[:b/0P2c/k<20;Rh^080]KFe0P2_[jl20:ZZZP80Y:BT0P2NWYh209^KV`80WIfM0P2RXZ820:VYZ@80
[jn_0P2a/K4Y0<SPf080MWIf0P1MGEd204=3@`@0=CDe0P0m?Cd203Ti>@80;Rh^0P0[:b/203Ph>080
CTi>0P1OGel204Y:BP80=SHf0P0d=3@202/[:`<0;Bd]0P0c<c<2034a<@80:BTY0P0a<C4202l_;`80
<S8b0P0c<c<203Ti>@80BTY:0P1RHV8205UIF@80BTY:0P0n?Sh204E5A@80AdM70P1BDU8205ADE080
HF5Q0P0k>c/202/[:`80;bl_0P0f=SH204Q8B080EUIF0P11@D4202LW9`80:2PX0P0^;Rh204M7A`80
MWIf0P1eMGD307inOP80PH610P1RHV8203Ti>@@0:RXZ0P0];Bd202l_;`80;Rh^0P0`<302034a<@80
=3@d0P0[:b/202l_;`80;2`/0P0^;Rh202<S8`@08R8R0P0T92@202HV9P80:BTY0P0g=cL205mOG`80
MWIf0P1lO7`206a/K080MGEe0P1LG5`204i>CP80Fe]K0P1gMgL309>CT`80Xj>S0P2;Rh/207YjNP80
/K6a0P2HV9P209>CT`80^KVi0P2e]KD20;>c/`80][Jf0P2d];@20;Rh^080][Jf0P2h^;P20;Zj^P80
_;bl0P2k^k/20;fm_@80^k^k0P2f][H20;Fe]@80/k>c0P2ZZZX40:FUY@80XJ6Q0P2PX:020:6QX@80
X:2P0P2VYZH20:BTY0<0YZJV0P2[Zj/20:b/[080/k>c0P2i^KT20;Bd]080[jn_0P2/[:`20:NWY`80
VIVI0P2LW9`20:>SX`80WYjN0P2UYJD20:j^[P80]KFe:@38h=P206m_K`80GemO0P0l?3`203Hf=P80
=3@d0P0f=SH203/k>`80:b/[0P0Y:BT2034a<@80AdM70P1/K6`204A4A080>c/k0P0c<c<202l_;`<0
;2`/0P0a<C4202l_;`80:b/[0P0_;bl202h^;P80;bl_0P0b<S8203Hf=P80BDU90P1PH60205MGE`80
ATI60P0n?Sh204=3@`80BDU90P1DE5@205QHF080GUiN0P0n?Sh202DU9@80;2`/0P0f=SH204Y:BP80
EEEE0P0l?3`202HV9P809BDU0P0T92@204m?C`80KFe]0P22PX8308J6QP80MgMg0P1WIfL204E5A@80
9RHV0P0[:b/203De=@80<C4a0P0b<S8203Hf=P80;bl_0P0d=3@202/[:`809RHV0P0];Bd202PX:080
8R8R0P0U9BD202@T9080820P100V9RH203<c<`80G5aL0P1iNGT207YjNP80J6QX0P22PX8605EEE@80
M7Ad0`2DU9@20:ZZZP80QhN70P22PX820:j^[P80WYjN0P2ATI420<71`@80/k>c0P2d];@20;>c/`@0
];Bd0P2h^;P20;Zj^PH0_;bl102k^k/20;Jf]P80]kNg0P2c/k<20:j^[P80YJFU0P2RXZ820:2PX0@0
WinO0P2SXj<20:FUY@80Xj>S0`2XZ:P20:NWY`80[Jf]0P2e]KD20;Ng]`80/k>c0P2`/;020:ZZZP80
XZ:R0P2MWId209RHV080X:2P0P2QXJ420:JVYP80[jn_0P2c/k<O0<SPf0007@38h=P2079bLP80Fe]K
0P0n?Sh203Lg=`80<c<c0P0g=cL203Xj>P80;bl_0P0V9RH203Ph>080B4Q80P1YJFT204A4A080?3`l
0P0a<C4202h^;PD0;Bd]300_;bl203<c<`80C4a<0P1QHF4205MGE`80ATI60P12@T820451@@80BDU9
0P1BDU8205aLG080GUiN0P12@T8202LW9`80:RXZ0P0f=SH204U9B@80E5AD0P0n?Sh202TY:@8092@T
0P0[:b/204m?C`80LG5a0P1oOgl308:2PP80NGUi0P1VIVH204A4A0809BDU0P0X:2P2038b<P@0=3@d
0P0c<c<2038b<P80;Rh^0P0Z:RX202/[:`80;2`/0P0X:2P202@T90808b<S0P0T92@202<S8`8092@T
0P0X:2P203@d=080FUYJ0P1kNg/207YjNP80JVYZ0P1nOWh205IFEP80De=C0P1FEUH207IfMP<0TY:B
0P2[Zj/208N7Q`80P8200P2][Jd209jNWP80Shn?0P2n_[h20;6a/@80][Jf102e]KD40;Jf]P80^;Rh
0P2j^[X20;bl_0@0_Kfm0P2j^[X20;Ng]`80]KFe0P2c/k<20:b/[080YJFU0P2RXZ840:2PX080XJ6Q
0P2SXj<40:FUY@<0YZJV0P2XZ:P20:b/[080/k>c0P2h^;P20;Fe]@80[jn_0P2ZZZX20:BTY080WYjN
0P2KVi/209fMW@80XZ:R0P2YZJT20:n_[`80/K6a:@38h=P207IfMP80GEeM0P13@d<403De=@80?Cdm
0P0i>CT202h^;P80:b/[0P0h>3P204i>CP80GemO0P1:BTX203Hf=P80=3@d0P0[:b/302d];@80<c<c
0P0a<C4202TY:@80<C4a0P0_;bl2038b<P80<c<c0P0i>CT204Y:BP80HV9R0P1IFET204Y:BP80?Shn
0P15ADD204M7A`80DU9B0P1DE5@2065QH@80>c/k0P0[:b/202l_;`80=SHf0P18B4P205IFEP80@D51
0P0W9bL202PX:080;Rh^0P17AdL207IfMP80MGEe0`1nOWh20861P@80HV9R0P0i>CT402XZ:P80;Bd]
0P0_;bl202h^;P80<30`0P0a<C4203@d=080:b/[0P0_;bl202`/;080;Rh^0P0S8b<4028R8P8092@T
0P0V9RH202TY:@80=cLg0P1OGel207IfMP80O7al0P1/K6`207EeM@80G5aL0P1>CTh205]KF`80MgMg
0`2CTi<20:>SX`80Rh^;0P1jNWX20;6a/@80V9RH0P2CTi<20;Vi^@80]KFe0P2c/k<20;Jf]P80];Bd
0P2h^;P20;Jf]P80^;Rh0P2j^[X20;bl_080^k^k0P2m_Kd20;^k^`80][Jf0P2e]KD20;>c/`80ZZZZ
102UYJD20:6QX@80X:2P0P2QXJ420:2PX080YZJV0P2TY:@30:JVYP80Zj^[0P2/[:`20;>c/`80^KVi
0P2d];@20:n_[`80[:b/0P2WYjL209VIV@80W9bL0P2SXj<209jNWP80YJFU0P2^[Zh20;Fe]BT0b>3H
0P1_Kfl205mOG`80?3`l0P0f=SH203@d=080=SHf0P0k>c/202/[:`80:BTY0P0a<C4204M7A`80K6a/
0P14A4@203/k>`80<c<c0P0_;bl302`/;080<C4a0P0_;bl202/[:`80;bl_0P0^;Rh202l_;`80<S8b
0P0f=SH204U9B@80H61P0P1GEeL204I6AP80?Shn0P13@d<204U9B@80E5AD0P1HF5P205iNGP80?Shn
0P0U9BD202`/;080=SHf0P1:BTX205EEE@80?3`l0P0V9RH202DU9@8092@T0P1?Cdl206e]K@80PX:2
0`26QXH207MgM`80IfMW0P15ADD202HV9P80:b/[0P0e=CD2034a<@80<S8b0P0f=SH202l_;`80=3@d
0P0[:b/202HV9P80;Bd]0P0X:2P2028R8P809BDU0P0T92@2020P80@09RHV0P0c<c<205aLG080NGUi
0P1jNWX206QXJ080PX:21P1EEED207AdM0<0U9BD0P2ZZZX208N7Q`80PX:20P2^[Zh209jNWP80TI6A
0P31`L420;>c/`80];Bd0P2c/k<40;Bd]080^;Rh0P2j^[X60;bl_0@0^k^k0P2f][H20;Ng]`80/k>c
0P2^[Zh20:FUY@80XZ:R0P2PX:0409nOW`80Xj>S0P2UYJD20:>SX`<0Z:RX0P2WYjL20:f][@80]KFe
0P2g]kL20;>c/`80/;2`0P2ZZZX20::RXP80WIfM0P2HV9P20:2PX080XJ6Q0P2VYZH20:n_[`80/k>c
7`38h=P001d0b>3H0P1`L702065QH@80D51@0P11@D42059BDP80Cdm?0P1<C4`203dm?@80<C4a0P0k
>c/204M7A`80GemO0P1@D50204M7A`80>SXj0P0d=3@3034a<@@0;bl_0P0^;Rh202d];@80;Rh^0P0`
<30203<c<`80>CTi0P1<C4`205]KF`80DU9B0P15ADD204=3@`80A4A40P1<C4`205EEE@80FEUI0P1F
EUH20410@080:b/[0P0];Bd203Hf=P80BDU90P1BDU8203Ti>@809RHV0P0_;bl204A4A080De=C0P1k
Ng/20820P0<0NWYj0P1VIVH204e=C@80=SHf0P0U9BD202LW9`80;Bd]0P0_;bl2030`<080<C4a0P0b
<S82030`<080;Bd]200/;2`202TY:@809RHV100U9BD202@T9080:BTY0P10@40205UIF@80IfMW0P1^
KVh208:2PP80IVIV0P1GEeL204Y:BP80GUiN0`1cLg<209:BTP80MgMg0P1kNg/20;6a/@80WIfM0P29
RHT20:n_[`80][Jf0P2h^;P40;>c/`80];Bd0P2e]KD20;Jf]P80]kNg0P2h^;P20;^k^`80_;bl0P2k
^k/20;Vi^@80^;Rh0P2e]KD20;2`/080ZZZZ0P2VYZH20:BTY0@0XZ:R0P2TY:@20:NWY`D0Z:RX0P2[
Zj/20:f][@80/[:b0P2f][H20;Bd]080/K6a0P2^[Zh20:^[Z`80XZ:R0P2LW9`209nOW`80YJFU0P2Y
ZJT20:b/[080[Jf]:@38h=P206e]K@80GUiN0P1FEUH204=3@`80BTY:0P1CDe<204A4A080<c<c0P0a
<C42038b<P80BDU90P1VIVH205UIF@80BDU90P11@D4202h^;P<0<c<c0P0d=3@402XZ:P80<30`0P0[
:b/202l_;`80=3@d0P0c<c<204I6AP80HF5Q0P1;Bd/203/k>`80ADE50P14A4@205QHF080EEEE0P1K
Fe/205UIF@80ADE50P0Y:BT202d];@80=cLg0P18B4P2051@D080=SHf0P0R8R8202l_;`80>c/k0P1J
FUX207IfMP80QHF50`1lO7`206m_K`80Bd];0P0Z:RX202/[:`80;2`/0P0`<30202h^;P80<c<c0P0j
>SX2034a<@80:b/[1P0Y:BT202`/;080;Bd]0P0X:2P202XZ:P808b<S100T92@202LW9`80=SHf0P1L
G5`206UYJ@80KVi^0P1jNWX206][J`@0Cdm?0P1OGel306m_K`80RHV90P22PX8207emO@80/K6a0P2G
UiL208F5Q@80/k>c0P2g]kL20;Bd]080]kNg0P2a/K420;Jf]P80/[:b0P2f][H20;^k^`80][Jf0P2k
^k/20;fm_@80^k^k0P2h^;P40;Bd]080[jn_0P2YZJT20:NWY`80XJ6Q0P2RXZ820:>SX`80YJFU0P2W
YjL50:JVYP80YJFU0P2[Zj/20;6a/@@0][Jf0P2`/;020:b/[080Zj^[0P2SXj<209ZJVP80WIfM0P2U
YJD20:NWY`80ZJVY0P2WYjLY0<SPf080KFe]0P1SHf<205=CD`80@d=30P1FEUH204a<C080Cdm?0P11
@D42038b<P80>3Ph0P19BDT2065QH@80D51@0P0o?cl203Ph>0D0<c<c1P0_;bl2038b<P80;Bd]0P0_
;bl203<c<`80>SXj0P1?Cdl205iNGP80EUIF0P12@T8204E5A@80A4A40P1>CTh205=CD`80E5AD0P1J
FUX20410@080<30`0P0/;2`203Hf=P80AdM70P1CDe<20410@0809BDU0P0a<C4204=3@`80F5QH0P1j
NWX207inOP<0MgMg0P1SHf<204m?C`80<c<c0P0T92@202`/;0@0:b/[0P0^;Rh203@d=080;bl_100`
<30202LW9`80;Bd]0P0d=3@202XZ:P809bLW0P0X:2P2024Q8@809RHV0P0Z:RX202PX:080@D510P1J
FUX206UYJ@80KFe]0P22PX8206=SH`80De=C0P1<C4`205mOG`<0Lg=c0P2ATI4207QhN080P8200P2^
[Zh209ZJVP80RHV90P2^[Zh20;Bd]080^KVi0P2c/k<20;6a/@80];Bd0P2g]kL20;Fe]@80]kNg102j
^[X20;jn_P80_Kfm0P2j^[X20;Rh^080];Bd0P2^[Zh20:RXZ0@0Xj>S0P2RXZ820:6QX@80ZJVY102X
Z:P50:VYZ@80Zj^[0P2a/K420;Vi^@80][Jf0P2`/;020:b/[080[Jf]0P2VYZH209bLW080WinO0P2U
YJD20:NWY`@0[Jf]7`38h=P001d0b>3H0P1`L702065QH@80D51@0P11@D42059BDP80Cdm?0P1<C4`2
03dm?@80<C4a0P0k>c/204M7A`80GemO0P1@D50204M7A`80>SXj0P0d=3@3034a<@@0;bl_0P0^;Rh2
02d];@80;Rh^0P0`<30203<c<`80>CTi0P1<C4`205]KF`80DU9B0P15ADD204=3@`80A4A40P1<C4`2
05EEE@80FEUI0P1FEUH20410@080:b/[0P0];Bd203Hf=P80BDU90P1BDU8203Ti>@809RHV0P0_;bl2
04A4A080De=C0P1kNg/20820P0<0NWYj0P1VIVH204e=C@80=SHf0P0U9BD202LW9`80;Bd]0P0_;bl2
030`<080<C4a0P0b<S82030`<080;Bd]200/;2`202TY:@809RHV100U9BD202@T9080:BTY0P10@402
05UIF@80IfMW0P1^KVh208:2PP80IVIV0P1GEeL204Y:BP80GUiN0`1cLg<209:BTP80MgMg0P1kNg/2
0;6a/@80WIfM0P29RHT20:n_[`80][Jf0P2h^;P40;>c/`80];Bd0P2e]KD20;Jf]P80]kNg0P2h^;P2
0;^k^`80_;bl0P2k^k/20;Vi^@80^;Rh0P2e]KD20;2`/080ZZZZ0P2VYZH20:BTY0@0XZ:R0P2TY:@2
0:NWY`D0Z:RX0P2[Zj/20:f][@80/[:b0P2f][H20;Bd]080/K6a0P2^[Zh20:^[Z`80XZ:R0P2LW9`2
09nOW`80YJFU0P2YZJT20:b/[080[Jf]:@38h=P206e]K@80GUiN0P1FEUH204=3@`80BTY:0P1CDe<2
04A4A080<c<c0P0a<C42038b<P80BDU90P1VIVH205UIF@80BDU90P11@D4202h^;P<0<c<c0P0d=3@4
02XZ:P80<30`0P0[:b/202l_;`80=3@d0P0c<c<204I6AP80HF5Q0P1;Bd/203/k>`80ADE50P14A4@2
05QHF080EEEE0P1KFe/205UIF@80ADE50P0Y:BT202d];@80=cLg0P18B4P2051@D080=SHf0P0R8R82
02l_;`80>c/k0P1JFUX207IfMP80QHF50`1lO7`206m_K`80Bd];0P0Z:RX202/[:`80;2`/0P0`<302
02h^;P80<c<c0P0j>SX2034a<@80:b/[1P0Y:BT202`/;080;Bd]0P0X:2P202XZ:P808b<S100T92@2
02LW9`80=SHf0P1LG5`206UYJ@80KVi^0P1jNWX206][J`@0Cdm?0P1OGel306m_K`80RHV90P22PX82
07emO@80/K6a0P2GUiL208F5Q@80/k>c0P2g]kL20;Bd]080]kNg0P2a/K420;Jf]P80/[:b0P2f][H2
0;^k^`80][Jf0P2k^k/20;fm_@80^k^k0P2h^;P40;Bd]080[jn_0P2YZJT20:NWY`80XJ6Q0P2RXZ82
0:>SX`80YJFU0P2WYjL50:JVYP80YJFU0P2[Zj/20;6a/@@0][Jf0P2`/;020:b/[080Zj^[0P2SXj<2
09ZJVP80WIfM0P2UYJD20:NWY`80ZJVY0P2WYjLY0<SPf080KFe]0P1SHf<205=CD`80@d=30P1FEUH2
04a<C080Cdm?0P11@D42038b<P80>3Ph0P19BDT2065QH@80D51@0P0o?cl203Ph>0D0<c<c1P0_;bl2
038b<P80;Bd]0P0_;bl203<c<`80>SXj0P1?Cdl205iNGP80EUIF0P12@T8204E5A@80A4A40P1>CTh2
05=CD`80E5AD0P1JFUX20410@080<30`0P0/;2`203Hf=P80AdM70P1CDe<20410@0809BDU0P0a<C42
04=3@`80F5QH0P1jNWX207inOP<0MgMg0P1SHf<204m?C`80<c<c0P0T92@202`/;0@0:b/[0P0^;Rh2
03@d=080;bl_100`<30202LW9`80;Bd]0P0d=3@202XZ:P809bLW0P0X:2P2024Q8@809RHV0P0Z:RX2
02PX:080@D510P1JFUX206UYJ@80KFe]0P22PX8206=SH`80De=C0P1<C4`205mOG`<0Lg=c0P2ATI42
07QhN080P8200P2^[Zh209ZJVP80RHV90P2^[Zh20;Bd]080^KVi0P2c/k<20;6a/@80];Bd0P2g]kL2
0;Fe]@80]kNg102j^[X20;jn_P80_Kfm0P2j^[X20;Rh^080];Bd0P2^[Zh20:RXZ0@0Xj>S0P2RXZ82
0:6QX@80ZJVY102XZ:P50:VYZ@80Zj^[0P2a/K420;Vi^@80][Jf0P2`/;020:b/[080[Jf]0P2VYZH2
09bLW080WinO0P2UYJD20:NWY`@0[Jf]7`38h=P001d0b>3H0P1_Kfl206IVIP80H61P0P19BDT206i^
KP80IfMW0P1MGEd204Y:BP80>c/k0P0n?Sh204M7A`80DE5A0P1KFe/2051@D080@T920P0k>c/303De
=@80<C4a0P0_;bl202`/;080:b/[0P0];Bd2034a<@80=SHf0P0m?Cd204U9B@80De=C0P1=CDd204I6
AP80ADE50P17AdL204m?C`80EUIF0P1EEED204i>CP80?clo0P0b<S82030`<080=CDe0P16ATH2059B
DP80>3Ph0P0R8R8203Xj>P80GEeM0P1CDe<207inOP80Ng]k0`1aLG4205ADE080=cLg0P0];Bd202/[
:`80;Bd]0P0a<C44038b<P@0<C4a0P0`<30202l_;`80;Bd]0P0[:b/2030`<080<c<c0P0_;bl202TY
:@80:2PX100W9bL202PX:080;Bd]0P0i>CT205MGE`80LG5a0P27QhL207EeM@80G5aL0P13@d<204];
B`<0F5QH0P1kNg/206][J`80MWIf0P2a/K4209bLW080QhN70P2NWYh20;bl_080^KVi102a/K420;:b
/P80];Bd0P2f][H40;Fe]@80^KVi0P2l_;`20;fm_@80_;bl0P2j^[X20;Ng]`80/k>c0P2^[Zh20:ZZ
ZP80YjNW0P2TY:@20:>SX`80YZJV0P2ZZZX20:^[Z`<0[:b/0P2^[Zh20;2`/080/[:b102c/k<40;:b
/P80/K6a0P2WYjL209jNWP80Xj>S0P2ZZZX20:^[Z`@0ZJVY:@38h=P206YZJP80IVIV0P1HF5P204m?
C`80IfMW0P1RHV8205eMG@80CTi>0P16ATH203/k>`80A4A40P1GEeL205YJFP80Cdm?0P12@T8203<c
<`<0=3@d0P0^;Rh202l_;`80;Bd]0P0^;Rh202/[:`80<C4a0P0e=CD203dm?@80BTY:0P1EEED2055A
D@80ATI60P1EEED204A4A080B4Q80P1EEED2061PH080C4a<0P0m?Cd203Ph>0809BDU0P0h>3P204];
B`80Cdm?0P0o?cl202PX:080;2`/0P1NGUh205UIF@80Ng]k0P20P80306a/K080GUiN0P0e=CD202TY
:@80;Bd]0P0_;bl2038b<P80;Bd]0P0a<C44038b<P80=3@d0P0`<30202`/;080:RXZ0P0a<C4203<c
<`80:b/[0P0_;bl2024Q8@809bLW0P0/;2`202HV9P80=CDe0P0l?3`205=CD`80Kfm_0P2:RXX207If
MP80EUIF0P19BDT205ADE0<0GEeM0P1/K6`206EUI@80O7al0P2a/K4209ZJVP80QXJ60P2WYjL20;fm
_@@0]kNg0P2_[jl20;>c/`80]kNg102f][H20;Ng]`80^KVi0P2m_Kd20;no_`80_;bl0P2i^KT40;Jf
]P80[Jf]0P2/[:`20:BTY080XZ:R0P2PX:020:VYZ@80Z:RX0P2YZJT50:j^[P80/;2`0P2c/k<20;6a
/@80^;Rh0P2`/;020:j^[P80/K6a0P2[Zj/409fMW@80ZZZZ0P2][Jd20:RXZ080YZJV:@38h=P206e]
K@80IfMW0P1LG5`204Y:BP80L71`0P1PH60205aLG080CTi>0P0i>CT203dm?@80ADE50P1ADE4205UI
F@80CTi>0P15ADD203`l?0<0=cLg0P0^;Rh202l_;`80;2`/0P0[:b/202XZ:P80;Rh^0P0l?3`203dm
?@80ADE50P1EEED204a<C080ATI60P11@D4204I6AP80CTi>0P1HF5P205]KF`80CTi>0P0n?Sh2034a
<@80;2`/0P0g=cL204A4A080DU9B0P0g=cL2024Q8@80=SHf0P1LG5`2055AD@80Ng]k0P1nOWh3079b
LP80De=C0P0h>3P202LW9`80;Rh^0P0_;bl203<c<`@0<C4a0P0g=cL202h^;P80<C4a0P0];Bd202TY
:@80:RXZ0P0b<S82034a<@80;Rh^0P0X:2P202/[:`80:2PX0P0U9BD202LW9`80<30`0P0e=CD205UI
F@80LG5a0P25QHD207UiN@80FEUI0P12@T8204Y:BP<0EUIF0P1jNWX206a/K080M7Ad0P2d];@209fM
W@80RHV90P2MWId20;jn_P80^[Zj0P2a/K420;2`/080];Bd0P2e]KD20;Ng]`80][Jf0P2e]KD20;Vi
^@80^k^k0P2n_[h20;Zj^P80^KVi0P2e]KD20;Jf]P80[Jf]0P2ZZZX40:JVYP80Xj>S0P2UYJD20:VY
Z@D0[:b/0P2_[jl20;2`/0@0/k>c0P2`/;020;>c/`@0/K6a0P2VYZH209fMW@80Y:BT0P2[Zj/20:b/
[080ZJVY0P2ZZZXO0<SPf0007@38h=P206m_K`80IVIV0P1PH60204U9B@80KVi^0P1WIfL205eMG@80
BTY:0P0k>c/203hn?P80AdM70P1ADE4205]KF`80D51@0P12@T8203/k>`<0=CDe0P0a<C4202l_;`80
;2`/0P0[:b/202d];@80<C4a0P0f=SH203dm?@80BDU90P1CDe<204e=C@80ATI60P15ADD204M7A`80
Cdm?0P1FEUH205EEE@80CTi>0P0o?cl2038b<P80<30`0P0e=CD204I6AP80DU9B0P0h>3P2028R8P80
>SXj0P1MGEd205=CD`80OWin0P1kNg/3075aL@80E5AD0P0g=cL202d];@80:b/[0P0];Bd2034a<@@0
<S8b100a<C42030`<080;bl_0P0];Bd202/[:`80<30`0P0c<c<202l_;`80:BTY0P0X:2P402LW9`80
:2PX0P0];Bd203Ti>@80EeMG0P1aLG4208N7Q`80MGEe0P1LG5`204=3@`80Bd];0`1HF5P207]kN`80
Jf][0P1fMWH20;6a/@80W9bL0P27QhL209jNWP80_;bl0P2i^KT40;6a/@80/[:b0P2d];@20;Jf]P@0
]KFe0P2i^KT20;bl_080_Kfm0P2l_;`20;Zj^P80]kNg0P2c/k<20:j^[P80ZZZZ0P2WYjL20:BTY080
Xj>S0P2VYZH20:ZZZP80Zj^[0`2/[:`20:j^[P80/;2`0P2b/[840;>c/`@0/[:b0P2a/K420:NWY`80
WYjN0P2SXj<20:ZZZP80Zj^[102YZJTY0<SPf080JVYZ0P1VIVH205QHF080Cdm?0P1WIfL2069RHP80
GEeM0P1>CTh204I6AP80>c/k0P14A4@205MGE`80FUYJ0P1?Cdl20492@P80<c<c0`0d=3@202h^;P80
;bl_0P0];Bd202h^;P80:b/[0P0a<C4203De=@80?Cdm0P1:BTX205EEE@80DE5A0P16ATH205EEE@80
A4A40P18B4P205EEE@80H61P0P1<C4`203dm?@80>3Ph0P0U9BD203Ph>080Bd];0P1?Cdl203lo?`80
:2PX0P0/;2`205iNGP80FEUI0P1kNg/20820P0<0K6a/0P1NGUh203De=@80:BTY0P0];Bd202l_;`80
<S8b0P0];Bd2034a<@@0<S8b0P0d=3@2030`<080;2`/0P0Z:RX2034a<@80<c<c0P0[:b/202l_;`80
8B4Q0P0W9bL202`/;0809RHV0P0e=CD203`l?080De=C0P1_Kfl208Z:RP80MWIf0P1FEUH204U9B@80
E5AD0`1MGEd206a/K080IFEU0P1lO7`20;6a/@80VYZJ0P26QXH20:NWY`80_Kfm102g]kL20:n_[`80
/k>c0P2g]kL40;Jf]P80]kNg0P2i^KT20;fm_@80_kno0P2l_;`20;Vi^@@0][Jf0P2][Jd20:b/[080
Y:BT0P2RXZ820:2PX080ZJVY0P2XZ:P20:VYZ@D0[Zj^0P2`/;020;>c/`80/K6a0P2h^;P20;2`/080
[Zj^0P2a/K420:^[Z`@0WIfM0P2ZZZX20:f][@80Z:RX0P2VYZHY0<SPf080KFe]0P1WIfL205aLG080
BTY:0P1`L702061PH080G5aL0P1>CTh203Ti>@80?Cdm0P15ADD2055AD@80FEUI0P1>CTh204E5A@80
?3`l0`0g=cL202h^;P80;bl_0P0/;2`202/[:`80:RXZ0P0^;Rh203`l?080?Cdm0P15ADD205EEE@80
C4a<0P16ATH20451@@80ATI60P1>CTh205QHF080Fe]K0P1>CTh203hn?P80<C4a0P0/;2`203Lg=`80
A4A40P1BDU8203Lg=`808B4Q0P0f=SH205aLG080DE5A0P1kNg/207inOP<0LW9b0P1CDe<203Ph>080
9bLW0P0^;Rh202l_;`80<c<c100a<C4203Lg=`80;Rh^0P0a<C4202d];@80:BTY0P0Z:RX2038b<P80
<C4a0P0^;Rh202PX:080:b/[0P0X:2P202DU9@809bLW0P0`<30203De=@80FEUI0P1aLG4208F5Q@80
NGUi0P1IFET20492@P80BTY:0`1FEUH207YjNP80K6a/0P1dM7@20;Bd]080WIfM0P29RHT209fMW@80
_[jn0P2j^[X20;6a/@80/;2`0P2d];@20;Fe]@80]kNg0P2f][H20;Fe]@80^KVi0P2k^k/20;jn_P80
^[Zj0P2i^KT20;Fe]@80][Jf0P2][Jd20:ZZZP@0YZJV0P2SXj<20:FUY@80ZJVY1@2/[:`20:n_[`80
/;2`102c/k<20;2`/080/k>c102a/K420:JVYP80WIfM0P2TY:@20:^[Z`80[:b/0P2YZJT20:ZZZQl0
b>3H000M0<SPf080Kfm_0P1WIfL206ATI080Bd];0P1eMGD206UYJ@80GemO101NGUh2051@D080ADE5
0P1<C4`205eMG@80De=C0P14A4@203`l?0<0=SHf0P0b<S8202l_;`80;2`/0P0[:b/202d];@80<C4a
0P0g=cL203lo?`80BDU90P1ADE4204a<C080ATI60P15ADD204M7A`80D51@0P1GEeL205ADE080C4a<
0P0o?cl203<c<`80<C4a0P0d=3@204I6AP80DU9B0P0g=cL2024Q8@80?3`l0P1SHf<205ADE080P820
0P1kNg/306m_K`80D51@0P0a<C4202XZ:P80:b/[0P0];Bd8034a<@H0<30`0P0];Bd202/[:`80<30`
0P0e=CD2030`<080:RXZ100X:2P402HV9P80:BTY0P0b<S8204I6AP80HF5Q0P1ADE4208R8R080MGEe
0P1PH60205QHF0<0DU9B0P1QHF4204Q8B080I6AT0P2c/k<209jNWP80QXJ60P2KVi/20;fm_@80^KVi
102`/;020;:b/P80];Bd0P2f][H40;Fe]@80^;Rh0P2l_;`20;fm_@80_;bl0P2j^[X20;Ng]`80/k>c
0P2_[jl20:^[Z`80Z:RX0P2TY:@20:>SX`80YZJV0P2ZZZX20:^[Z`<0[:b/0P2^[Zh20;2`/080/[:b
102c/k<20;:b/P80/k>c0P2b/[820:RXZ080WinO0P2TY:@40:^[Z`@0ZJVY:@38h=P207IfMP80Kfm_
0P1LG5`205]KF`80O7al0P1aLG4206YZJP80FEUI0P1EEED205=CD`80BDU90P1:BTX2055AD@80CDe=
0P1<C4`203dm?@<0?Shn0P0k>c/2038b<P80<30`0P0Y:BT202XZ:P80>3Ph0P0j>SX204Q8B080CDe=
0P18B4P204i>CP80@d=30P11@D4404E5A@80EEEE0P1ADE4204M7A`80?Shn0P0k>c/202LW9`80=SHf
0P1<C4`2055AD@80>3Ph0P0V9RH203Hf=P80LG5a0P1KFe/207UiN@80N7Qh0`1OGel205QHF080<S8b
0P0X:2P202`/;080:b/[0P0_;bl203Xj>P80;bl_0P0/;2`202d];@@0<30`0P0f=SH2034a<@80<30`
0P0j>SX202l_;`80:BTY0P0Z:RX202`/;080:BTY0P0W9bL202TY:@80;2`/0P11@D4205mOG`80K6a/
0P24Q8@206][J`80F5QH0P1EEED305UIF@80HF5Q0P1?Cdl2079bLP80YjNW0P2QXJ4208>3P`80WIfM
0P2f][H20;2`/080[Zj^0P2YZJT20;6a/@80]kNg0P2a/K420;2`/080/k>c0P2e]KD20;Ng]`80^k^k
102l_;`20;Ng]`80/[:b0P2[Zj/40:f][@80YJFU0P2SXj<20:JVYP80Zj^[0P2/[:`30:n_[`80[:b/
102c/k<20:n_[`80/[:b0P2d];@20;>c/`80/;2`0P2YZJT20:NWY`80X:2P0P2_[jl20;>c/`80[:b/
0P2][JdY0<SPf080Kfm_0P1YJFT2069RHP80CTi>0P1dM7@206=SH`80GemO0P1VIVH205YJFP80De=C
0P18B4P204];B`80I6AT0P1EEED204E5A@80>CTi0`0d=3@202l_;`@0<C4a100Y:BT203De=@80>SXj
0P0o?cl20451@@80D51@0P1=CDd204U9B@80AdM70P18B4P2055AD@80De=C0P1BDU8204Q8B080?Shn
0P0e=CD2038b<P80=3@d0P18B4P2055AD@80=cLg0P0U9BD203Xj>P80J6QX0P1IFET207moO`80Ph>3
0`1[Jf/205IFEP80=CDe0P0[:b/202`/;080:RXZ0P0b<S8202/[:`80;bl_0P0f=SH202/[:`80=3@d
0P0b<S8202h^;P80;Bd]100c<c<2034a<@80:b/[0P0U9BD202LW9`808R8R0P0W9bL202XZ:P80;Rh^
0P1:BTX2061PH080D51@0P2<S8`207AdM080Hf=S0P1MGEd305IFEP80GemO0P19BDT2065QH@80/[:b
0P2NWYh208R8R080UiNG0P2k^k/20;fm_@80/;2`0P2^[Zh20;6a/@80[jn_0P2d];@20;Rh^080/[:b
0P2g]kL20;Rh^080_kno102k^k/20;Ng]`80]KFe0P2_[jl20;6a/@80ZJVY0P2SXj<20:2PX080YZJV
0P2WYjL20:b/[0<0ZZZZ0P2^[Zh20;2`/080]KFe0P2d];@20:j^[P80][Jf0P2d];@20;2`/080YZJV
0P2QXJ420::RXP@0ZZZZ0P2WYjL20:VYZAl0b>3H000M0<SPf080Kfm_0P1WIfL206ATI080Bd];0P1e
MGD206UYJ@80GemO101NGUh2051@D080ADE50P1<C4`205eMG@80De=C0P14A4@203`l?0<0=SHf0P0b
<S8202l_;`80;2`/0P0[:b/202d];@80<C4a0P0g=cL203lo?`80BDU90P1ADE4204a<C080ATI60P15
ADD204M7A`80D51@0P1GEeL205ADE080C4a<0P0o?cl203<c<`80<C4a0P0d=3@204I6AP80DU9B0P0g
=cL2024Q8@80?3`l0P1SHf<205ADE080P8200P1kNg/306m_K`80D51@0P0a<C4202XZ:P80:b/[0P0]
;Bd8034a<@H0<30`0P0];Bd202/[:`80<30`0P0e=CD2030`<080:RXZ100X:2P402HV9P80:BTY0P0b
<S8204I6AP80HF5Q0P1ADE4208R8R080MGEe0P1PH60205QHF0<0DU9B0P1QHF4204Q8B080I6AT0P2c
/k<209jNWP80QXJ60P2KVi/20;fm_@80^KVi102`/;020;:b/P80];Bd0P2f][H40;Fe]@80^;Rh0P2l
_;`20;fm_@80_;bl0P2j^[X20;Ng]`80/k>c0P2_[jl20:^[Z`80Z:RX0P2TY:@20:>SX`80YZJV0P2Z
ZZX20:^[Z`<0[:b/0P2^[Zh20;2`/080/[:b102c/k<20;:b/P80/k>c0P2b/[820:RXZ080WinO0P2T
Y:@40:^[Z`@0ZJVY:@38h=P207IfMP80Kfm_0P1LG5`205]KF`80O7al0P1aLG4206YZJP80FEUI0P1E
EED205=CD`80BDU90P1:BTX2055AD@80CDe=0P1<C4`203dm?@<0?Shn0P0k>c/2038b<P80<30`0P0Y
:BT202XZ:P80>3Ph0P0j>SX204Q8B080CDe=0P18B4P204i>CP80@d=30P11@D4404E5A@80EEEE0P1A
DE4204M7A`80?Shn0P0k>c/202LW9`80=SHf0P1<C4`2055AD@80>3Ph0P0V9RH203Hf=P80LG5a0P1K
Fe/207UiN@80N7Qh0`1OGel205QHF080<S8b0P0X:2P202`/;080:b/[0P0_;bl203Xj>P80;bl_0P0/
;2`202d];@@0<30`0P0f=SH2034a<@80<30`0P0j>SX202l_;`80:BTY0P0Z:RX202`/;080:BTY0P0W
9bL202TY:@80;2`/0P11@D4205mOG`80K6a/0P24Q8@206][J`80F5QH0P1EEED305UIF@80HF5Q0P1?
Cdl2079bLP80YjNW0P2QXJ4208>3P`80WIfM0P2f][H20;2`/080[Zj^0P2YZJT20;6a/@80]kNg0P2a
/K420;2`/080/k>c0P2e]KD20;Ng]`80^k^k102l_;`20;Ng]`80/[:b0P2[Zj/40:f][@80YJFU0P2S
Xj<20:JVYP80Zj^[0P2/[:`30:n_[`80[:b/102c/k<20:n_[`80/[:b0P2d];@20;>c/`80/;2`0P2Y
ZJT20:NWY`80X:2P0P2_[jl20;>c/`80[:b/0P2][JdY0<SPf080Kfm_0P1YJFT2069RHP80CTi>0P1d
M7@206=SH`80GemO0P1VIVH205YJFP80De=C0P18B4P204];B`80I6AT0P1EEED204E5A@80>CTi0`0d
=3@202l_;`@0<C4a100Y:BT203De=@80>SXj0P0o?cl20451@@80D51@0P1=CDd204U9B@80AdM70P18
B4P2055AD@80De=C0P1BDU8204Q8B080?Shn0P0e=CD2038b<P80=3@d0P18B4P2055AD@80=cLg0P0U
9BD203Xj>P80J6QX0P1IFET207moO`80Ph>30`1[Jf/205IFEP80=CDe0P0[:b/202`/;080:RXZ0P0b
<S8202/[:`80;bl_0P0f=SH202/[:`80=3@d0P0b<S8202h^;P80;Bd]100c<c<2034a<@80:b/[0P0U
9BD202LW9`808R8R0P0W9bL202XZ:P80;Rh^0P1:BTX2061PH080D51@0P2<S8`207AdM080Hf=S0P1M
GEd305IFEP80GemO0P19BDT2065QH@80/[:b0P2NWYh208R8R080UiNG0P2k^k/20;fm_@80/;2`0P2^
[Zh20;6a/@80[jn_0P2d];@20;Rh^080/[:b0P2g]kL20;Rh^080_kno102k^k/20;Ng]`80]KFe0P2_
[jl20;6a/@80ZJVY0P2SXj<20:2PX080YZJV0P2WYjL20:b/[0<0ZZZZ0P2^[Zh20;2`/080]KFe0P2d
];@20:j^[P80][Jf0P2d];@20;2`/080YZJV0P2QXJ420::RXP@0ZZZZ0P2WYjL20:VYZAl0b>3H003o
0<SPf?l0b>3Ho`38h=RM0<SPf000o`38h=So0<SPf?l0b>3HW@38h=P00?l0b>3Ho`38h=So0<SPf9d0
b>3H003o0<SPf?l0b>3Ho`38h=RM0<SPf000o`38h=So0<SPf?l0b>3HW@38h=P00?l0b>3Ho`38h=So
0<SPf9d0b>3H003o0<SPf?l0b>3Ho`38h=RM0<SPf000o`38h=So0<SPf?l0b>3HW@38h=P00?l0b>3H
o`38h=So0<SPf9d0b>3H003o0<SPf?l0b>3Ho`38h=RM0<SPf000o`38h=So0<SPf?l0b>3HW@38h=P0
0?l0b>3Ho`38h=So0<SPf9d0b>3H003o0<SPf?l0b>3Ho`38h=RM0<SPf000\
\>"],
  ImageRangeCache->{{{0, 921}, {287.125, 0}} -> {-0.078787, -0.0234425, \
0.00342842, 0.00342842}, {{22.9375, 296.375}, {280.25, 6.8125}} -> {-14.475, \
-6.5799, 0.491525, 0.491525}, {{323.75, 597.188}, {280.25, 6.8125}} -> \
{-162.332, -6.5799, 0.491525, 0.491525}, {{624.563, 898}, {280.25, 6.8125}} -> \
{-310.189, -6.5799, 0.491525, 0.491525}}]
}, Open  ]],

Cell["\<\
Although the noise levels on the skin and in the feathers are now more \
correct, there are still visible transitions between different noise levels. \
More troubling, there is too much noise in the areas around sharp edges. \
Further work should address proper computation of noise levels around sharp \
edges.\
\>", "Text"],

Cell[CellGroupData[{

Cell["SPACL decomposition of  residuals:", "Subsection"],

Cell["\<\
We notice that we do not need to compute the standard deviations in such an \
expensive way: it is merely an issue of averaging absolute residuals. We \
might wonder if we could describe the noise better with Spacl decomposition -\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(abstrecomp = 
        Map[DeInterleave2[ImgDWT[#]] &, 
          Abs[mcomp], {2}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GfxMat[abstrecomp, 64]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A59F9C99929FAC9C91AD8CAA8B9388898885888C89848F848A8B8A8C87839B96
8FA999878B899A9F8CA39096838A87888C8A8E8A8B8A88828B87888A888A9793
A59C9E9A8C8C978992ADA29A848C8787858E8781878C86848C8387858781899D
AB959E9B92869195919EA790828981878A8B8987888C8D858A87898C878F8892
8E9F8B919B85898C9596908E8C8C848889868887898E8A898586828987878987
8AAFA08B979085908CA7A58A878B878586888A8E8A8789848487909590928B91
9C8A899E8B99A38A9DB1958F8A8A8C89868A8E868B8A86888587869286858F86
9A9597A4A2A6A4918BA3B7888B89878790878E85888A878E838889858690898D
979B93B4A4A09E9283ABAA91878C8C8884998A8C87878A84898A8686858C8487
96A48998A29497988CA4938B8D8E8C828784878C878E88848A8B8386868B8489
8A91898FA79BA09893A29B8B87858985888B8D878F868784888389848C898B8E
A087938E9FA99196979096868C86968288868488838B8490878D838B8E848986
979186868FA79C9D928F9C8389848A8D88888986858989868885888C88928888
9F858F888B9CA3A1928D958F89898A84888A868E8F84878B898C84878A888D99
8A8E8B9B8695AFA1AD8398A08D898991858D88898A89878A878B9B8D8789828F
8D888E888E839897B48F8D98AA848987888790898B8688888B8B858D878A8C90
8C8F88898C8C8FA5AAAB8E8A8B9A898F9488898C8C9A99A9AD998B8A84898687
898D8B8E8D9A8696AB99968B8782958C8E8D8C92A1848D8C878C898F918A8A8F
8F94939984928A91A0A49F878D878A948D8D9593909A8693898891AC8E89858B
9392998786919196A19BACA98E8B8C959D82898CB39DA3A99494949D948F8997
A3A29987919C9A8F88A2A5AD8D908D8AB1A393858D8A8B9A918D899885868688
9B9E9088A08B8A8C9AAAA3A9AB89878990ADA08891958E948F8B9F898F8D878C
8AB48DA1A48A87959EA6A1A79C928189869AA3968B92A197A9A294918C85868B
8EA892A8AB96969E96ACAFA19EA695878E8C90899C828C9287908F858F888B86
9C918C9F85889E9FA6A0A390AB96A4868B8E8E83918B8C8E918E818487838589
9E9A95AA898E9CA59BA3A69992A5979C8D8D89878F8B88928C858E8888838B89
9EAD8B93AA9094959D9E9490889D999DA7878C8D84A9958A858786878C84888A
918FB097958A9EA5949AA29E91A6A6A58F8C8C8D97A98E8782988C9189898C8F
8F8DAD999895898C9D93A4948C9F99A290968F938C9692898D8B8B8E85818783
9498A986979F8F8E9B92ACA39E998595AB8C9D8885A19190938A8A8A938E8B8D
9B929F8F8B8B8F9A8D9FB8A09E9C93898B958CA69CA19C95898E8D8F8F868A90
94969A9A938B8F96969498A1B19484898B9293A3A2A1948884868B868686908D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
509C9F878D927A857B7A87857B6279857A82876A8A877F7A8388858D7F867E82
81AF726687888B747E7A7A8679708C757F7A7F8673807C7B7F8C85878B8A7E79
85915A9E8E836B8481809583857A777C83847C7B79858D7F787C7D7D8B7C7181
6797643580916C847770857A866B897A83807584747A7B897C778A92947B7781
6A8292ABB28C817A79867D898279887C7D857B867C84847A86787D71767D857A
958A78717F948C5F7E78768683808979777C6C76898A8589796F6F8D8E75818A
975F8C85785E816E50757B7881798986807C6C89817986898A89848180916F74
9546637C755E7586998E78767E83896D79817A8480727A858884738481777E7A
7F857F829E7B2F877468807D6874859C8A84718F83837A86758A7C7B7A757978
8A67798C836993358F877A848579807B7C877C87807B8183717E7A7A878A838E
85786783738081B18C838E847A948E847F928E7E7F8687827B96928475806C77
7E998A877B8B857D457F6284757C7D8278788980927B7F7B8781828570907481
7F78777B7A606C85AE576E6E749394857F867C786F7A837C7D78848282808D8B
8467817784B0B37E79AA9E7A7F8084708A858476837588757B797986718A7C7B
8F7E7C86677D75779B7D5F3E79888C808C708F887B81798C867E727C8A897A65
626B787E768867957D79848EAC7D807F6E83917E777E8F8E857D907F6E8B8279
66767F8D9B877B6CA480697E768F7D877D79878E6C6E8B83896D8087886E7B68
73767A6F709AB28B7B7C82829B729975777E848AAC7B678387846E7F6F78757F
7D6482A86A7E7C75A79F8F8083884F9A7881888572747D7F827C697991898379
836C6E9996748A73887672708E8B984E99778D8168A48B5F7D7C4B86867C7782
7F7882746A8C7E94717E7A58877B719C61AB90828982869B7582837D808A737A
889B8459727C767D94B0928469967E6E93767D867A6D8B7D7670A280707D8177
948460858C94999958A3889D86957C8B6290718984874C7E89756F7D7B8A7582
769D4C7A7F846E4A8B6A637FA2938F866D687B67818369777E75A18F78868A7E
688D75677A88859D668A8DA78181836F8A937A828A7D9473889A83777982917F
8D66B860867FA46D4F945D8E8783668F80857A7C76729A8984867D888C718187
5A85815F8A7D867E807A84959455938A8C7873748791837E81747F7C80838975
77778879709A8674686F7C857D887E9A447E73857B858F6C86879182808A8282
808F988E6A977A9F6A6D64825E885C757E818F868E7C7C77858F817E767B747A
8E6B85718B83869B769077759F837C7574727081837C888594788E7E6D80866B
738BA68A857790816778926A9DA68F81798C807B9B976D8A71827B8A92826C69
97947384826C867C6293929E776D82717C6255727E6C8B758685828389847F6A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7B80518B5F928A846D7CA19E8B7A63877F787998717D807F8067868585617186
663F89AC998B84967C8F86816AB086AA7E7986796E9278708B936C8A87676E7C
42798C906B4647805D668DB49468A97176849F86849A878D956772656E728486
859B6166576A13937A5893707382687182845A67767E8C7D9787967669AC967D
6C6A627E548679CA8E76964C6382846B5C69966A6E7B8D749785608457798087
87619A9168BF76CA2A756C636F4169755D6F8571888C79687A8B72756E748A72
7B80608B70F687B8435C88728D808F9390858E8676A384868787898B8F799780
84806F8B9F905BBAABB07D7875947C80957E937D7E818D8C9991B8788B858BA3
8866445B90BD516A6B57878970757B746A79B97A948B876A6F8B956A75886C8D
7AA09BA3475585807B7D8972966E7A717F788D87837A7D806E6B7C7AB979476F
8F95AF7078386AA133767B8D6F736E779E93919A6F637FA4976C84787251546A
6A6186A76932788D4B4C78829890827F87817B7382927C7095837270746D7682
75766C97729B836AB3546AAA627897828D8990966C7B87708B69696D678C6381
7B698D8A66576EAF837551306754679E78819374839863828179918E6C7A96AE
796C846D6875868654764DAC7A9A8DAE61A48D865E8F6D6D877B85866E77A772
FF826D848B93A75A6E7A7563B668867A76838D7E446C88A69A66857F9E757185
7C6B9DCEA68AA37350B6788D3CB7997989788C7C7F876C95917284898766917E
786982878695C3967067A39C7436BE937A6E8678A78D796E687B7D9572686B6A
5AB2A57DAD678861777A8990688A2B9A7175785EE5896768777C577B8D7D7178
71737E7F5E7592677B3F73A39B78C28702C1995966B5FFD289A37288885F819F
8251715C63966587BC867C8C68707F9481348D7E9F74B3BFC48695908EA98570
484878785E7B73695B6A7E3E696779649C757C99AC73887960CFD878B08A9171
6A9789669690B9475B6C477E967F9085866D59FF62A18E9F8D709081A3717D94
AB9E936E785783735B4A8760708F9A73725F6B60916886918560B08D8C978896
94909A86937A60759C4466668CB5707874739F8A9D3B8180759D985E74A07C80
59B6B785AD6244402D75653C84B2437F9F8F869E8A787F988B6C89709E808B77
7549884D668EAD9543D14E8B8BA5675546847B989292839BA0786C677F978B85
DD868D6B549BD98539544891A3614CB796B979936A9D89788B50717B7F94AA7A
B53F7E9A82928B7D7453C14660A23F677A476A9C69857DBC968360818C7E9583
50839F7A976A869B8193B1988D96B75A4D7F47A8B4A15F8C7D7F7499AC9C747C
5DAA775FA06A924CB97959627BA68F6F842F6CB88E8B7293696B72959D948E98
AE7664628C8E58002490639048D8457EA700D87B55458A6F8291786A616D7A85
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A3CDA497A58C9F89949189978A90909986848E888D8D888385908B918C928E8B
AE9CBB8FA1868E8C8D8C8D8B898F8B938E938B8E89898892898C8885908E8885
8F89ADB68E8EA689948A97978E8A8A8A8C868D8E918991818B848A8A878D8B86
AFADA1A4B08CABA7929B8D8E8E8B89978D87938E8789848C8D918D89968A8585
9897908DBE809388938C9192948E8B848590918B928B8A8689978A8A88918D8E
85AA959095B78A9C8A8C9BA28990898C8A8E8C908C8B8C888A90958E8E9F8C9A
8EA7A38993899489AEA295998A98938990888C94838E8B8A8987938286809689
98AE9F9285999A93928F9F908C8A888B8D93878A8B8B8B868B8C8D89828F8B8F
9A88879493919DA39C9B8F8A8C8F888F8E898A9093848A8B8885948A88878989
8F8F9A93A3938AB99B97868B8A8D8E888D8D87929691868E8F8B8A8985978B8F
958F909295999682BEA2919089889481908F928D8E8B8A888A8496808C8D9395
8B96859A8C9E9A8F9EAA928D8A8D878886858B878C958B8E89988D9186928F8B
87998D898AA0939385C9A48B918497868D8D898A8B898F8A8C81878F88828E89
89958994909BA3A5987DB4A1998A8B8582928D90878989878B928E8C8F938A90
848D8D828C8F969BAE879BC69F898E8989978F8D84908F8E8E9188868A819091
9C939297919C95A7998C8A8ECF9B9A8D8C8D9882908B8A99928A8D8E84928F84
9D968C8AABA08FA8A89A8A8B99DB8E8B8985848F899D95928E9B89898C8D8B88
96938C8B95A389B69E9288927FA9D38B87878F8BA88C9091838E938C8D938E95
9D988A95A294938E8EB7958C8A8B96E387958B92A098A6988588908B878A8C85
9890A28B9895A4998E959DA0919089C6AC8C988E8D9BA6999D8A9D92888D9091
AAA78C96ADB4C3959790A99995878E82CAAC9796849985B89E939E858C91988A
8A938B8F9991869B99B1BCB094A2838E86CDC7849C8D99959F9ACB8697959286
92978FAC87979597A1BE8AAD8AA1878A9386ADCA8D9A9CA799A28E968B998A8A
98A9C9A5A3828FB2B98998A9A78B9F8B8B8E978DB2838B8D869A9D9788898D8A
9B989A95949798979B9B918BD698BD98888F8E878FC39A988B9689988A8F8C8A
8BA0A2C895978EA696A2B9B18CAD909A8B91888D8A858994808E898B92878C89
A8949B9D9D9F8BA0899FA9A389A7BC8AA68489858B969186908591978B8C8E87
9596A693A99CA5888F8F968D95A2B5B4C7B88894849087908A9A988C86899494
949F8D988B9EA0AA979B9B999B9691A4939D93859C8A9489858795988B88848A
8B99A88A8C9C91A19294A290958F86949E8A989890828F869C83828A8C8E8D8D
B292949E8A8F91B18E98919793A1979B8DAF9C8E9D999097858A8E8E8C968A8F
87989A91948C94ADA3999BB88F93A0948FA7A09E8C96878E8B8988898988948C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
736D70708D84666E908182726F80747586877C797580827B90877B8A877B7E6D
8A856782789187706D9E836D8E658481838696836E7E8D8482788185737E897E
769E94AD715F578778657A87739478748493787F7B8D81758A76746A64767680
2E8F6259545F7E7682877E7E957C7C808081887DAC9885767D8175827187748D
5B98816A997A948A928C7C80717A787A777F72856A738B86888684877885827C
828DA09BB095388D647B9F7E6E81827E878C768A928180878A8583749BA37082
767C7381A3709C7C768F877C8A84868180927470817E6C7E876E7B8C63717876
7373627F717C927887797896856D828289807E7B7982897D747F8A8B79828089
8564798063857A7E8F807C7E757A6D7282847088848381798D7F7E7686898279
6A68778680818178968C84737C8F74777773818A857E6E72837F918174726D7B
A585817D5A778B8865797D798E777F728B7374847B808477826D7D7D70767883
95896A9A809B887A739B776F837D7C917E806F81867C768A7A8A7F8A887E8F7A
6E9265849376757B81786D9871867E8F80827C8B849D7687738286808374707B
8998887F7D6F8C80886A837392877C88767B7C7F7E85847C769A8782876E6E8B
78896C7491697F826C8891A1677B887166668396797E89898B77838379858E72
BE908E767464826E6F6C8B8593816B7A8D7F81887983787A9B7D66818E827A83
7B7B817C97748F8E9C7D877580965F8387778E7D56697FA6558374899C9C8567
80797983816E7883966C6F848474818D8F7E7A6E997D7F697B606778776E837A
6D5C619C7A70A674897794A3767E85657B688B706F6DC156827A7F7A79A87D7C
AA88948D5C9D53537A906F817D817A758E766C76697579A98EAE92857E7C7098
84729865399F4E7EA486AB838881748B647B9C80918E8F85C273556A80806C7E
7B717F58898C8E67B16E8698847B74757A878F6EAC8C6971548887816C749179
7B90D79F717D6A937696706E887473848A7E6DB15F8B967467545D7877917869
977679739290859991908F6C7D7A7A6C737D93779C696486A180968B79736A74
849C9A8F8C9086777074C6B25C64837A80897D718F9666808A967285847C7A8B
64B47F788568908A77A06E85839A986373867B7E7B7F83898181837B86797B81
7E678992A68F7C866D627E776E897E5F8B757D81877777816B6F8070858A8D7B
8989638A8482808167615C9370808C7A89828D8F83889272888A92838787758D
B9839086787F7A806E6DAD898F747CA67A72758C937C7271888B7F8070848476
6BB26A8E69737379698A7EA68E58498882605173A48B667185A3727F81718574
A09488875E95688C797C7F95C46E56828E63846C74927C75827D8E857D76706F
455F95677682BC987E8C66706F86CB8F6E387CCE9A44988C976E9299747F8A7B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
95A7A0949185868880868E878D868C8687858183858A82898984898388888787
868E9A948C8DA29B969B8C938C87888A8986868285838784848A878883888885
AD9685A19798A38D8E908C88848B878B898889858A858287888384878A848582
A89A94A69E8C98A184918D8C8B898A8C8888868985888A858787868789898E8D
9F9590929B8D8B8D879885848588898585838B84888985858388838187909092
8F8A8D9191A88C8E8A86998C84858484828886838A86868388838890849BA096
8B869C979EABB197919C85918986868482878A878586868587878D8485858582
898E9390859DA6908A88898F8D84888683878388868586868A82848486888683
7FA582898D8889998C8C868B868889858287898989878E84848A848986888483
998F878C888883908B8F868A8985868A8B8986888283868884858C8787828887
8F888C8B838D86819A918D8F88898A898486868D85868D858A87888786888588
8498888E8698898B839F89838685898788848886878A8D848684858886878583
8C8A8A888B928D878395938A86878184888482848588888C868688868B828B85
9783898A8C88928486809A94898C86878886848585838486888C848B84888A85
858C8B898A888887898789AC9E868C82888785838487898C8E8A878686868489
989193908D888B88878788849F8D83878A878789858D8B8E8A8887898B838186
918A898C8D8C8989898A848885958C8387868684898C9296A09C948789868E8B
9B8D918C9D8F918B9E86998982888E9C858785898A949B9087A9928C838B8A8B
968791878686898C8AA593A694828688868C8F988E9C9DA38B888083858A8586
898C918C8C8A8F98A6998B898987868FA883998B8E9891B08D91909D848C8986
9F928B878A9A979388878A8D85848684A2A18E868E86898F908A8C9689858987
918C8F8D98AB968A909592869289868A839BAE89978F908CAA96909384878588
8D9790908A928692A5AB909091858C858B869B8B9684968A928C8F86928E838A
869CA29F93908C8AAB898E96868B8F8788858683B4988C89908AA38EA0858685
8C89A5918788889D8F948C9C8D8C8B848A858688899A8F918794888D83868889
938D99A298878C908A9290A59795989B8E898483878B9B998A88868784848484
A6978AAB99958B878591958E85879D868A808984878E8B838892838684858683
888289889C89908B878B8C989F9087928888818984858482838F8B8386848888
96898B8A93908C8C888E9B97A19B8C96898E95858B838E8A8685878989858A84
AA9787878987888C888688938C85908CA18C8F8C848592878888848797928684
9A948B9290908C8992928A908D9AAA92829C8F93A1938E85848C888789878988
9E9A9C9A9089969D968A8A91988B958F8B8B918B9D948C87868789868987868D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf0002`38h=P205QHF080IVIV0P29RHT209ZJVP80MWIf
0P2BTY8209NGU`0307UiN@2VYZH0YZJV0080LG5a0P21PH4209bLW080NGUi0P2CTi<207inOP80LW9b
0P1kNg/208V9R@80N7Qh0P24Q8@208>3P`80RHV90P25QHD00`21PH40MgMg07MgM`0206a/K080Ng]k
0P2;Rh/207YjNP80Ti>C0P23Ph<205MGE`<0b>3H0P38b<P206ATI080Ogmo0P1jNWX207]kN`80QXJ6
0P2MWId00`2[Zj/0Ogmo07moO`020;Vi^@80BDU90P1ZJVX208^;R`80PX:20P1cLg<207MgM`80SHf=
0P1bLW8206m_K`80N7Qh0P27QhL407moO`030820P021PH40PH610080UiNG0P1lO7`207YjNP80S8b<
0P23Ph<208B4Q080GemO2P38h=P2051@D080W9bL0P2OWil208N7Q`80SHf=0P2BTY8207YjNP0308F5
Q@1kNg/0Ng]k0080NWYj0P27QhL208F5Q@80Ng]k0P1RHV8207UiN@80QHF50P1jNWX208:2PP80QhN7
0P1ZJVX208Z:RP80QhN70P1oOgl00`1jNWX0Ph>308>3P`0208R8R080QHF50P2=SHd207moO`80QXJ6
0P1nOWh208:2PP<0b>3H0P1kNg/20820P080DE5A0P2;Rh/205mOG`80TY:B0P2:RXX00`24Q8@0KFe]
06e]K@0207alO080XJ6Q0P2NWYh208^;R`80NWYj0P1SHf<208N7Q`80Ogmo0P1hN7P207UiN@80V9RH
0P1aLG4207emO@80P82000<0Ogmo0820P020P8000P1WIfL208J6QP@0QHF50P1QHF42075aL@80QXJ6
3@38h=P000/0b>3H0P1HF5P206IVIP80RHV90P2JVYX207IfMP80TY:B0P2GUiL00`1iNGT0YZJV0:JV
YP02075aL@80PH610P2LW9`207UiN@80Ti>C0P1nOWh2079bLP80Ng]k0P29RHT207QhN080Q8B40P23
Ph<208V9R@80QHF500<0PH6107MgM`1gMgL00P1/K6`207]kN`80Rh^;0P1jNWX209>CT`80Ph>30P1G
EeL30<SPf080b<S80P1TI6@207moO`80NWYj0P1kNg/208J6QP80WIfM00<0Zj^[07moO`1oOgl00P2i
^KT204U9B@80JVYZ0P2;Rh/208:2PP80Lg=c0P1gMgL208f=S@80LW9b0P1_Kfl207QhN080QhN7101o
Ogl00`20P800PH610861P@0209NGU`80O7al0P1jNWX208b<S080Ph>30P24Q8@205mOG`X0b>3H0P1@
D50209bLW080WinO0P27QhL208f=S@80TY:B0P1jNWX00`25QHD0Ng]k07]kN`0207YjNP80QhN70P25
QHD207]kN`80HV9R0P1iNGT208F5Q@80NWYj0P22PX8208N7Q`80JVYZ0P2:RXX208N7Q`80Ogmo00<0
NWYj08>3P`23Ph<00P28R8P208F5Q@80SHf=0P1oOgl208J6QP80OWin0P22PX830<SPf080Ng]k0P20
P802055AD@80Rh^;0P1OGel209:BTP80RXZ:00<0Q8B406e]K@1]KFd00P1lO7`20:6QX@80WYjN0P2;
Rh/207YjNP80Hf=S0P27QhL207moO`80N7Qh0P1iNGT209RHV080LG5a0P1mOGd20820P00307moO`20
P800P8200080IfMW0P26QXH408F5Q@80HF5Q0P1aLG4208J6QPd0b>3H000;0<SPf0@0UYJF0P24Q8@2
07EeM@80QHF50P2=SHd2059BDP0307inOP2JVYX0VYZJ0080Q8B40P1SHf<208N7Q`80O7al0P1`L702
07QhN080RHV90P1jNWX207IfMP80Ng]k0P20P80207inOP80NGUi0P1nOWh00`26QXH0SXj>08j>SP02
07YjNP80MgMg1028R8P207YjNP80MWIf0P1ADE430<SPf080BDU90P2MWId208R8R080Ng]k0P1nOWh2
07YjNP80RXZ:00<0VYZJ09>CT`2CTi<00P2YZJT209NGU`80UIFE0P24Q8@208R8R080Lg=c0P1iNGT2
07IfMP80UIFE0P1hN7P2079bLP80Shn?0P1eMGD207moO`0308N7Q`1hN7P0N7Qh0080QhN70P2DU9@2
07inOP80QhN70P26QXH208V9R@80PX:22P38h=P20861P@80[jn_0P1bLW8206IVIP80QhN70P28R8P2
08^;R`0307AdM01nOWh0OWin00@0NWYj0P26QXH207UiN@80L71`0P2<S8`207EeM@80Ogmo0P1jNWX2
07moO`80QXJ60P1cLg<20820P080O7al00<0Ng]k07moO`1oOgl00P2<S8`208F5Q@80QhN70P2;Rh/2
08Z:RP80OWin0P1iNGT30<SPf080IVIV0P0o?cl208V9R@80[:b/0P2IVIT208^;R`80Q8B400<0UYJF
07alO01lO7`00P2?Shl208J6QP80PH610P1ZJVX20;2`/080QXJ60P2ZZZX207inOP80NGUi0P26QXH2
07UiN@80KVi^0P2BTY8207QhN003071`L02;Rh/0Rh^;0080Ti>C0P1/K6`208Z:RP80QhN70P1WIfL2
06i^KP80O7al3@38h=P000/0b>3H102FUYH208B4Q080MGEe0P25QHD208f=S@80DU9B00<0OWin09ZJ
VP2JVYX00P24Q8@206=SH`80QhN70P1lO7`2071`L080N7Qh0P29RHT207YjNP80MWIf0P1kNg/20820
P080OWin0P1iNGT207inOP0308J6QP2>SXh0SXj>0080NWYj0P1gMgL408R8R080NWYj0P1fMWH2055A
D@<0b>3H0P19BDT209fMW@80R8R80P1kNg/207inOP80NWYj0P2:RXX00`2JVYX0Ti>C09>CT`020:VY
Z@80UiNG0P2EUID208B4Q080R8R80P1cLg<207UiN@80MWIf0P2EUID207QhN080LW9b0P2?Shl207Ee
M@80Ogmo00<0QhN707QhN01hN7P00P27QhL209BDU080OWin0P27QhL208J6QP80RHV90P22PX8:0<SP
f080PH610P2_[jl2079bLP80IVIV0P27QhL208R8R080Rh^;00<0M7Ad07inOP1nOWh0101jNWX208J6
QP80NGUi0P1`L70208b<S080MGEe0P1oOgl207YjNP80Ogmo0P26QXH207=cL`80P8200P1lO7`00`1k
Ng/0Ogmo07moO`0208b<S080QHF50P27QhL208^;R`80RXZ:0P1nOWh207UiN@<0b>3H0P1VIVH203lo
?`80RHV90P2/[:`209VIV@80Rh^;0P24Q8@00`2FUYH0O7al07alO00208n?S`80QXJ60P21PH4206YZ
JP80/;2`0P26QXH20:ZZZP80OWin0P1iNGT208J6QP80NGUi0P1^KVh209:BTP80N7Qh00<0L71`08^;
R`2;Rh/00P2CTi<206a/K080RXZ:0P27QhL206MWI`80KVi^0P1lO7`=0<SPf0002`38h=P20861P@80
GEeM0P2GUiL208Z:RP80Q8B40P2:RXX208>3P`0307=cL`2@T900T92@0080PX:20P1cLg<20861P@80
P8200P1hN7P208N7Q`80PX:20P25QHD207alO080OGem0P20P80207YjNP80OGem0P1oOgl00`21PH40
R8R808R8R0020861P@80OGem0P21PH4208>3P`80Ogmo0P2=SHd206YZJP<0b>3H0P2JVYX203dm?@80
KFe]0P2PX:0207IfMP80Lg=c0P1[Jf/00`23Ph<0Kfm_06m_K`0207MgM`80NWYj0P2<S8`208R8R080
OGem0P25QHD2092@T080MgMg0P1^KVh208N7Q`80M7Ad0P2;Rh/207UiN@80Q8B400<0MWIf071`L01`
L7000P21PH4208Z:RP80KFe]0P1iNGT208f=S@80Ng]k0P1`L70:0<SPf080QHF50P2ATI4205YJFP80
WYjN0P2>SXh208>3P`80Jf][00<0Q8B40861P@21PH400P20P80209FEU@80Ph>30P25QHD207YjNP80
MgMg0P1lO7`208>3P`80Q8B40P1lO7`207]kN`80NGUi0P25QHD208f=S@0307moO`1hN7P0N7Qh0080
O7al101mOGd208^;R`80O7al0P1aLG420861P@<0b>3H0P12@T8207UiN@80S8b<0P2@T90206][J`80
ATI60P17AdL00`20P800GEeM05eMG@0206IVIP80SHf=0P2d];@209BDU080J6QX0P2YZJT2075aL@80
MWIf0P24Q8@209nOW`80QXJ60P24Q8@209ZJVP80QhN700<0SHf=09FEU@2EUID00P1WIfL2079bLP80
IFEU0P1^KVh2079bLP80Q8B40P26QXH=0<SPf0002`38h=P20861P@80GEeM0P2GUiL208Z:RP80Q8B4
0P2:RXX208>3P`0307=cL`2@T900T92@0080PX:20P1cLg<20861P@80P8200P1hN7P208N7Q`80PX:2
0P25QHD207alO080OGem0P20P80207YjNP80OGem0P1oOgl00`21PH40R8R808R8R0020861P@80OGem
0P21PH4208>3P`80Ogmo0P2=SHd206YZJP<0b>3H0P2JVYX203dm?@80KFe]0P2PX:0207IfMP80Lg=c
0P1[Jf/00`23Ph<0Kfm_06m_K`0207MgM`80NWYj0P2<S8`208R8R080OGem0P25QHD2092@T080MgMg
0P1^KVh208N7Q`80M7Ad0P2;Rh/207UiN@80Q8B400<0MWIf071`L01`L7000P21PH4208Z:RP80KFe]
0P1iNGT208f=S@80Ng]k0P1`L70:0<SPf080QHF50P2ATI4205YJFP80WYjN0P2>SXh208>3P`80Jf][
00<0Q8B40861P@21PH400P20P80209FEU@80Ph>30P25QHD207YjNP80MgMg0P1lO7`208>3P`80Q8B4
0P1lO7`207]kN`80NGUi0P25QHD208f=S@0307moO`1hN7P0N7Qh0080O7al101mOGd208^;R`80O7al
0P1aLG420861P@<0b>3H0P12@T8207UiN@80S8b<0P2@T90206][J`80ATI60P17AdL00`20P800GEeM
05eMG@0206IVIP80SHf=0P2d];@209BDU080J6QX0P2YZJT2075aL@80MWIf0P24Q8@209nOW`80QXJ6
0P24Q8@209ZJVP80QhN700<0SHf=09FEU@2EUID00P1WIfL2079bLP80IFEU0P1^KVh2079bLP80Q8B4
0P26QXH=0<SPf0002`38h=P205MGE`80TY:B0P26QXH206IVIP80OWin0P2;Rh/207]kN`0308N7Q`1i
NGT0NGUi0080Ph>30P1PH60207QhN080PH610P25QHD20820P080Ng]k0P1mOGd208b<S080RXZ:0P21
PH4208>3P`80MGEe0P1lO7`00`29RHT0QHF508F5Q@020861P@80LG5a0P1kNg/208V9R@80SXj>0P1i
NGT207YjNP<0b>3H0P2ZZZX2079bLP80ADE50P2UYJD208B4Q080VYZJ0P1kNg/00`1HF5P0QhN708N7
Q`020:>SX`80NGUi0P2CTi<207]kN`80QHF50P1eMGD207QhN080Jf][0P1hN7P208B4Q080Lg=c0P1`
L70206YZJP80OGem00<0LG5a07MgM`1gMgL00P1oOgl207IfMP80OWin0P1oOgl208J6QP80LG5a0P2?
Shl:0<SPf080IfMW0P2GUiL206ATI080=CDe0P20P802096AT@80K6a/00<0Q8B407MgM`1gMgL00P1`
L70208F5Q@80NWYj0P26QXH206][J`80RHV90P1jNWX208>3P`80P8200P1eMGD208B4Q080M7Ad0P1j
NWX207]kN`0308V9R@1lO7`0O7al0080MgMg0P2:RXX209:BTP80U9BD0P1kNg/207MgM`80PH610`38
h=P208F5Q@80Vi^K0P1QHF4206IVIP80EeMG0P1ZJVX201<C4`0309>CT`1jNWX0NWYj0080F5QH0P2C
Ti<2071`L080Lg=c0P22PX8206QXJ080LG5a0P22PX8208B4Q080FUYJ0P1WIfL207IfMP80OWin0P2<
S8`00`1mOGd0UiNG09NGU`0208N7Q`80UYJF0P1fMWH206UYJ@80[:b/0P2FUYH207emO@d0b>3H000;
0<SPf080EeMG0P2BTY8208J6QP80IVIV0P1nOWh208^;R`80Ng]k00<0QhN707UiN@1iNGT00P23Ph<2
061PH080N7Qh0P21PH4208F5Q@80P8200P1kNg/207emO@80S8b<0P2:RXX20861P@80Ph>30P1eMGD2
07alO00308V9R@25QHD0QHF50080PH610P1aLG4207]kN`80RHV90P2>SXh207UiN@80NWYj0`38h=P2
0:ZZZP80LW9b0P15ADD20:FUY@80Q8B40P2JVYX207]kN`0305QHF027QhL0QhN70080Xj>S0P1iNGT2
09>CT`80Ng]k0P25QHD207EeM@80N7Qh0P1[Jf/207QhN080Q8B40P1cLg<2071`L080JVYZ0P1mOGd0
0`1aLG40MgMg07MgM`0207moO`80MWIf0P1nOWh207moO`80QXJ60P1aLG4208n?S`X0b>3H0P1WIfL2
09NGU`80I6AT0P0e=CD20820P080TI6A0P1/K6`00`24Q8@0MgMg07MgM`02071`L080QHF50P1jNWX2
08J6QP80Jf][0P29RHT207YjNP80Ph>30P20P80207EeM@80Q8B40P1dM7@207YjNP80Ng]k00<0RHV9
07alO01lO7`00P1gMgL208Z:RP80TY:B0P2DU9@207]kN`80MgMg0P21PH430<SPf080QHF50P2KVi/2
065QH@80IVIV0P1GEeL206YZJP804a<C00<0Ti>C07YjNP1jNWX00P1HF5P209>CT`80L71`0P1cLg<2
08:2PP80J6QX0P1aLG4208:2PP80Q8B40P1JFUX206MWI`80MWIf0P1nOWh208b<S00307emO@2GUiL0
UiNG0080QhN70P2FUYH207IfMP80JFUY0P2/[:`209JFUP80OGem3@38h=P000/0b>3H0P2FUYH20:2P
X080OGem0P21PH4207inOP80OGem0P1^KVh00`2FUYH0T92@092@T00208^;R`80W9bL0P1oOgl207in
OP80Ogmo0P1mOGd208N7Q`80Rh^;0P21PH4207inOP80QXJ60P1fMWH207alO080Ogmo00<0OWin08F5
Q@25QHD0101mOGd208Z:RP80LG5a0P1oOgl208R8R080MGEe0`38h=P206IVIP80HV9R0P2b/[820:6Q
X@80[Jf]0P1bLW8206a/K00308>3P`26QXH0QXJ60080DU9B0P1gMgL209>CT`80Kfm_0P2=SHd20820
P080QhN70P1eMGD208^;R`80TY:B0P1VIVH205mOG`80PH610P25QHD00`1eMGD0NWYj07YjNP0208:2
PP80QhN70P1OGel207inOP80TY:B0P27QhL208n?S`X0b>3H0P1ZJVX208:2PP80TY:B0P2[Zj/20;:b
/P80S8b<0P21PH400`1jNWX0NGUi07UiN@0208J6QP80OGem0P29RHT208:2PP80NGUi0P28R8P207al
O080OGem0P25QHD207]kN`80QXJ60P1lO7`408B4Q00307YjNP26QXH0QXJ60080N7Qh0P1mOGd2075a
L@80MWIf0P1mOGd208F5Q@80NWYj0`38h=P206a/K080JVYZ0P1RHV8207inOP80E5AD0P26QXH207Ui
N@030<[:bP2>SXh0SXj>0080MWIf0P2FUYH204a<C080Hf=S0P22PX8208B4Q080Jf][0P1LG5`206UY
J@80UYJF0P1ZJVX206i^KP80Ng]k0P2=SHd00`1dM7@0UiNG09NGU`0208F5Q@80H61P0P24Q8@205MG
E`80NGUi0P20P80208N7Q`d0b>3H000;0<SPf080UYJF0P2PX:0207emO@80PH610P1nOWh207emO@80
KVi^00<0UYJF092@T02@T9000P2;Rh/209bLW080Ogmo0P1nOWh207moO`80OGem0P27QhL208^;R`80
PH610P1nOWh208J6QP80MWIf0P1lO7`207moO`0307inOP25QHD0QHF500@0OGem0P2:RXX2075aL@80
Ogmo0P28R8P207EeM@<0b>3H0P1VIVH2069RHP80/[:b0P2QXJ420:f][@80LW9b0P1/K6`00`23Ph<0
QXJ608J6QP02059BDP80MgMg0P2CTi<206m_K`80SHf=0P20P80208N7Q`80MGEe0P2;Rh/209:BTP80
IVIV0P1OGel20861P@80QHF500<0MGEe07YjNP1jNWX00P22PX8208N7Q`80GemO0P1nOWh209:BTP80
QhN70P2?Shl:0<SPf080JVYZ0P22PX8209:BTP80Zj^[0P2b/[8208b<S080PH6100<0NWYj07UiN@1i
NGT00P26QXH207emO@80RHV90P22PX8207UiN@80R8R80P1lO7`207emO@80QHF50P1kNg/208J6QP80
O7al1024Q8@00`1jNWX0QXJ608J6QP0207QhN080OGem0P1aLG4207IfMP80OGem0P25QHD207YjNP<0
b>3H0P1/K6`206YZJP80HV9R0P1nOWh205ADE080QXJ60P1iNGT00`3:b/X0SXj>08j>SP0207IfMP80
UYJF0P1<C4`206=SH`80PX:20P24Q8@206][J`80G5aL0P1YJFT209JFUP80JVYZ0P1^KVh207]kN`80
SHf=00<0M7Ad09NGU`2GUiL00P25QHD2061PH080Q8B40P1GEeL207UiN@80P8200P27QhL=0<SPf000
2`38h=P207]kN`80NWYj0P1`L70208f=S@80NWYj0P1YJFT208F5Q@0307MgM`2>SXh0SXj>0080PH61
0P2<S8`208R8R080Kfm_0P20P80208B4Q080OWin0P23Ph<20820P080Ng]k0P1cLg<207alO080Ng]k
0P24Q8@00`20P800O7al07alO0020820P080SXj>0P1]KFd206][J`80NGUi0P25QHD206QXJ0<0b>3H
102QXJ420861P@80L71`0P1jNWX20;Vi^@80Ti>C00<0XJ6Q04i>CP1>CTh00P1GEeL206EUI@80GUiN
0P29RHT206e]K@80MWIf0P1/K6`206i^KP80NWYj0P2;Rh/209RHV080KFe]0P23Ph<208b<S00308N7
Q`2<S8`0S8b<0080Lg=c0P1aLG4208V9R@80Lg=c0P2:RXX209RHV080S8b<2P38h=P209FEU@80RXZ:
0P1hN7P2075aL@80Ogmo0P2DU9@208b<S00305mOG`1nOWh0OWin0080N7Qh0P1fMWH208J6QP80Ph>3
0P20P80208V9R@80NGUi0P1gMgL207alO080K6a/0P1fMWH208V9R@80RXZ:0P25QHD00`29RHT0NGUi
07UiN@0406m_K`80SHf=0P2>SXh207EeM@80PH610P2:RXX30<SPf080QhN70P1QHF4209ZJVP80TI6A
0P1XJ6P20;no_`80MWIf00<0b/[:02XZ:P0Z:RX00P1eMGD206a/K080Hf=S0P1_Kfl20451@@80JFUY
0P1eMGD205eMG@80Kfm_0P25QHD2075aL@80R8R80P2<S8`207UiN@0306QXJ01jNWX0NWYj0080Rh^;
0P1bLW8207EeM@80KVi^0P1dM7@208Z:RP80LW9b3@38h=P000/0b>3H0P1kNg/207YjNP80L71`0P2=
SHd207YjNP80JFUY0P25QHD00`1gMgL0SXj>08j>SP020861P@80S8b<0P28R8P206m_K`80P8200P24
Q8@207inOP80Ph>30P20P80207]kN`80Lg=c0P1lO7`207]kN`80Q8B400<0P82007alO01lO7`00P20
P80208j>SP80KFe]0P1[Jf/207UiN@80QHF50P1XJ6P30<SPf0@0XJ6Q0P21PH42071`L080NWYj0P2i
^KT209>CT`030:6QX@1>CTh0CTi>0080EeMG0P1UIFD205iNGP80RHV90P1]KFd207IfMP80K6a/0P1^
KVh207YjNP80Rh^;0P2HV9P206e]K@80Ph>30P2<S8`00`27QhL0S8b<08b<S00207=cL`80LG5a0P29
RHT207=cL`80RXZ:0P2HV9P208b<S0X0b>3H0P2EUID208Z:RP80N7Qh0P1aLG4207moO`80U9BD0P2<
S8`00`1OGel0OWin07inOP0207QhN080MWIf0P26QXH208>3P`80P8200P29RHT207UiN@80MgMg0P1l
O7`206a/K080MWIf0P29RHT208Z:RP80QHF500<0RHV907UiN@1iNGT0101_Kfl208f=S@80SXj>0P1e
MGD20861P@80RXZ:0`38h=P208N7Q`80HF5Q0P2JVYX2096AT@80J6QX0P2o_kl207IfMP030<[:bP0Z
:RX0:RXZ0080MGEe0P1/K6`206=SH`80Kfm_0P11@D4206UYJ@80MGEe0P1MGEd206m_K`80QHF50P1a
LG4208R8R080S8b<0P1iNGT00`1XJ6P0NWYj07YjNP0208^;R`80LW9b0P1eMGD206i^KP80M7Ad0P2:
RXX2079bLPd0b>3H000;0<SPf080RHV90P1SHf<207YjNP80NGUi0P1_Kfl209VIV@80TY:B00<0Lg=c
07UiN@1iNGT00P1]KFd208B4Q080JVYZ0P21PH4207UiN@80Ph>30P27QhL20820P080QhN70P1eMGD2
07inOP80M7Ad0P1oOgl208F5Q@0308Z:RP23Ph<0Ph>30080OGem0P2<S8`2092@T080O7al0P2:RXX2
08R8R080MgMg0`38h=P208:2PP80R8R80P1YJFT2092@T080IFEU0P2JVYX204Q8B00307AdM028R8P0
R8R80080NGUi0P27QhL206MWI`80SHf=0P1kNg/208>3P`80RXZ:0P1bLW8207MgM`80Shn?0P1mOGd2
07inOP80Ng]k0P2=SHd00`2DU9@0QhN708N7Q`0206YZJP80VIVI0P1lO7`208Z:RP80QHF50P1eMGD2
07IfMPX0b>3H0P2GUiL205mOG`80S8b<0P25QHD207QhN080GUiN0P21PH400`1^KVh0D51@051@D002
07EeM@80Ng]k0P1hN7P20861P@80NGUi0P29RHT208J6QP80P8200P1lO7`206a/K080RHV90P21PH42
07UiN@80QXJ600<0RHV908Z:RP2:RXX00P29RHT208B4Q080PH610P20P802096AT@80Kfm_0P1dM7@3
0<SPf080Ng]k0P20P802061PH080Rh^;0P1`L7020?KfmP80QhN700<0^;Rh04=3@`13@d<00P1LG5`2
08R8R080LW9b0P2=SHd20820P080Shn?0P2CTi<2092@T080QHF50P2>SXh208J6QP80MWIf0P2SXj<2
08B4Q00308J6QP27QhL0QhN70080QhN70P29RHT208^;R`80Shn?0P1iNGT209NGU`80P8203@38h=P0
00/0b>3H0P29RHT206=SH`80NWYj0P1iNGT206m_K`80VIVI0P2BTY800`1cLg<0NGUi07UiN@0206e]
K@80Q8B40P1ZJVX20861P@80NGUi0P23Ph<208N7Q`80P8200P27QhL207EeM@80OWin0P1dM7@207mo
O`80QHF500<0RXZ:08>3P`23Ph<00P1mOGd208b<S080T92@0P1lO7`208Z:RP80R8R80P1gMgL30<SP
f080PX:20P28R8P206UYJ@80T92@0P1UIFD209ZJVP80B4Q800<0M7Ad08R8R028R8P00P1iNGT208N7
Q`80IfMW0P2=SHd207]kN`80Ph>30P2:RXX2079bLP80MgMg0P2?Shl207emO@80OWin0P1kNg/208f=
S@0309BDU027QhL0QhN70080JVYZ0P2IVIT207alO080RXZ:0P25QHD207EeM@80MWIf2P38h=P209NG
U`80GemO0P2<S8`208F5Q@80N7Qh0P1NGUh20861P@0306i^KP1@D500D51@0080MGEe0P1kNg/207Qh
N080PH610P1iNGT208V9R@80QXJ60P20P80207alO080K6a/0P29RHT20861P@80NGUi0P26QXH00`29
RHT0RXZ:08Z:RP0208V9R@80Q8B40P21PH420820P080TI6A0P1_Kfl207AdM0<0b>3H0P1kNg/20820
P080H61P0P2;Rh/2071`L080m_Kf0P27QhL00`2h^;P0@d=304=3@`0205aLG080R8R80P1bLW8208f=
S@80P8200P2?Shl209>CT`80T92@0P25QHD208j>SP80QXJ60P1fMWH20:>SX`80Q8B400<0QXJ608N7
Q`27QhL00P27QhL208V9R@80Rh^;0P2?Shl207UiN@80UiNG0P20P80=0<SPf0002`38h=P206QXJ080
WYjN0P2HV9P207YjNP80OGem0P1iNGT207=cL`0307MgM`2BTY80TY:B0080PH610P1lO7`2071`L080
MGEe0P22PX820820P080Ph>30P1bLW8207emO@80M7Ad0P23Ph<208:2PP80Ogmo0P28R8P00`23Ph<0
OWin07inOP0207moO`80PH610P1`L7020820P080PX:20P1gMgL2075aL@<0b>3H0P2TY:@20:j^[P80
YZJV0P20P80207QhN080alO70P1bLW800`1LG5`0TY:B09:BTP0208j>SP80VIVI0P1ZJVX207EeM@80
OWin0P1UIFD207EeM@80Y:BT0P1`L70207alO080QHF50P1kNg/207UiN@80Ph>300<0QHF509RHV02H
V9P00P1]KFd207MgM`80O7al0P2:RXX208F5Q@80Kfm_0P2@T90:0<SPf080UIFE0P16ATH206=SH`80
O7al0P1eMGD205iNGP80MGEe00<0QXJ609VIV@2IVIT00P2>SXh207QhN080MWIf0P1nOWh208>3P`80
RHV90P1]KFd207UiN@80PH610P1jNWX208B4Q080P8200P1bLW8207YjNP0308F5Q@28R8P0R8R80080
Q8B40P1cLg<208B4Q080PH610P1gMgL207inOP80NWYj0`38h=P208B4Q080P8200P1_Kfl208^;R`80
WinO0P2@T90205]KF`030;Zj^P2[Zj/0Zj^[0080/;2`0P1mOGd207QhN080MGEe0P2DU9@207alO080
P8200P2EUID207inOP80Ti>C0P1mOGd207inOP80PH610P2=SHd00`2<S8`0VIVI09VIV@02096AT@80
^;Rh0P1hN7P208^;R`80QHF50P2;Rh/20:>SX`d0b>3H000;0<SPf080J6QX0P2NWYh209RHV080NWYj
0P1mOGd207UiN@80Lg=c00<0MgMg09:BTP2BTY800P21PH4207alO080L71`0P1eMGD208:2PP80P820
0P23Ph<2079bLP80OGem0P1dM7@208>3P`80PX:20P1oOgl208R8R00308>3P`1nOWh0OWin0080Ogmo
0P21PH42071`L080P8200P22PX8207MgM`80LG5a0`38h=P20:BTY080[Zj^0P2VYZH20820P080N7Qh
0P37alL2079bLP0305aLG02BTY80TY:B0080SXj>0P2IVIT206YZJP80MGEe0P1nOWh206EUI@80MGEe
0P2TY:@2071`L080O7al0P25QHD207]kN`80NGUi0P23Ph<00`25QHD0V9RH09RHV00206e]K@80MgMg
0P1lO7`208Z:RP80QHF50P1_Kfl2092@T0X0b>3H0P2EUID204I6AP80Hf=S0P1lO7`207EeM@80GUiN
0P1eMGD00`26QXH0VIVI09VIV@0208j>SP80N7Qh0P1fMWH207inOP80Ph>30P29RHT206e]K@80NGUi
0P21PH4207YjNP80Q8B40P20P802079bLP80NWYj00<0QHF508R8R028R8P00P24Q8@207=cL`80Q8B4
0P21PH4207MgM`80OWin0P1jNWX30<SPf080Q8B40P20P80206m_K`80Rh^;0P2OWil2092@T080Fe]K
00<0^[Zj0:^[Z`2[Zj/00P2`/;0207emO@80N7Qh0P1eMGD209BDU080O7al0P20P80209FEU@80OWin
0P2CTi<207emO@80OWin0P21PH4208f=S@0308b<S02IVIT0VIVI0080TI6A0P2h^;P207QhN080Rh^;
0P25QHD208^;R`80Xj>S3@38h=P000/0b>3H0P25QHD208V9R@80GEeM0P21PH4208V9R@80V9RH0P1b
LW800`1hN7P0S8b<08b<S0020820P080Shn?0P1fMWH20861P@80MgMg0P1dM7@208>3P`80Ng]k0P24
Q8@208>3P`80RXZ:0P24Q8@207moO`80MWIf00<0Ng]k08N7Q`27QhL00P29RHT20820P080PH610P1l
O7`207moO`80PX:20P1iNGT30<SPf080^;Rh0P1oOgl206a/K080QXJ60P2MWId20861P@80VIVI00<0
YJFU08>3P`23Ph<00P2e]KD207AdM080VIVI0P1lO7`209FEU@80O7al0P1kNg/20820P080WIfM102B
TY8208>3P`80NGUi0P1mOGd00`2=SHd0V9RH09RHV00208J6QP80PX:20P1mOGd209FEU@80U9BD0P1o
Ogl208f=S@X0b>3H0P1oOgl208F5Q@80Ogmo0P22PX8209jNWP80Ng]k0P0_;bl00`27QhL0M7Ad07Ad
M00206QXJ080P8200P1mOGd206QXJ080M7Ad0P25QHD209bLW080RXZ:0P24Q8@2075aL@80Shn?1023
Ph<207YjNP0308J6QP1eMGD0MGEe0080RXZ:0P1lO7`207]kN`80NWYj0P1eMGD207UiN@80N7Qh0`38
h=P208R8R080IVIV0P14A4@205]KF`80T92@0P2m_Kd2055AD@0306YZJP1[Jf/0Jf][0080EeMG0P27
QhL208V9R@80L71`0P1eMGD207]kN`80M7Ad0P1ZJVX207UiN@80^KVi0P1jNWX209BDU080Rh^;0P27
QhL00`1ZJVX0Kfm_06m_K`0208^;R`80UIFE0P1ZJVX207EeM@80R8R80P1/K6`208f=S@d0b>3H000;
0<SPf080LG5a0P2@T90209:BTP80OGem0P2>SXh206IVIP80J6QX00<0Ogmo0:ZZZP2ZZZX00P1gMgL2
0820P080Lg=c0P27QhL208^;R`80QhN70P22PX8207UiN@80OGem0P26QXH207emO@80LG5a0P2ATI43
08>3P`80O7al0P24Q8@208:2PP80O7al0P24Q8@20861P@80OWin0P1lO7`30<SPf080?3`l0P2^[Zh2
0;Fe]@80C4a<0P2KVi/204i>CP80?Cdm00<0BDU907YjNP1jNWX00P2IVIT206i^KP80LW9b0P2?Shl2
07UiN@@0Q8B40P20P80208b<S080LW9b0P1eMGD208J6QP80Q8B40P26QXH00`1jNWX0OWin07inOP02
08V9R@80QHF50P27QhL208F5Q@80V9RH0P1`L70209RHV0X0b>3H0P2:RXX206MWI`80NGUi0P2<S8`2
08>3P`80JFUY0P2CTi<00`0e=CD0Shn?08n?S`0208N7Q`80NWYj0P24Q8@208F5Q@80NGUi0P20P802
07]kN`80O7al0P27QhL207alO080QhN70P20P80207]kN`80PH6100<0Ph>3075aL@1aLG400P1nOWh4
07YjNP80QhN70P2:RXX208>3P`80SXj>0`38h=P207YjNP80X:2P0P2KVi/20:>SX`80AdM70P1EEED2
08F5Q@030820P01kNg/0Ng]k0080OGem0P29RHT2079bLP80UYJF0P1^KVh207YjNP80LG5a0P1oOgl2
07QhN080SHf=0P27QhL208>3P`80NWYj0P1mOGd00`20P800KVi^06i^KP0206][J`80O7al0P1jNWX2
0;Vi^@80NGUi0P17AdL206m_K`d0b>3H000;0<SPf080LG5a0P2@T90209:BTP80OGem0P2>SXh206IV
IP80J6QX00<0Ogmo0:ZZZP2ZZZX00P1gMgL20820P080Lg=c0P27QhL208^;R`80QhN70P22PX8207Ui
N@80OGem0P26QXH207emO@80LG5a0P2ATI4308>3P`80O7al0P24Q8@208:2PP80O7al0P24Q8@20861
P@80OWin0P1lO7`30<SPf080?3`l0P2^[Zh20;Fe]@80C4a<0P2KVi/204i>CP80?Cdm00<0BDU907Yj
NP1jNWX00P2IVIT206i^KP80LW9b0P2?Shl207UiN@@0Q8B40P20P80208b<S080LW9b0P1eMGD208J6
QP80Q8B40P26QXH00`1jNWX0OWin07inOP0208V9R@80QHF50P27QhL208F5Q@80V9RH0P1`L70209RH
V0X0b>3H0P2:RXX206MWI`80NGUi0P2<S8`208>3P`80JFUY0P2CTi<00`0e=CD0Shn?08n?S`0208N7
Q`80NWYj0P24Q8@208F5Q@80NGUi0P20P80207]kN`80O7al0P27QhL207alO080QhN70P20P80207]k
N`80PH6100<0Ph>3075aL@1aLG400P1nOWh407YjNP80QhN70P2:RXX208>3P`80SXj>0`38h=P207Yj
NP80X:2P0P2KVi/20:>SX`80AdM70P1EEED208F5Q@030820P01kNg/0Ng]k0080OGem0P29RHT2079b
LP80UYJF0P1^KVh207YjNP80LG5a0P1oOgl207QhN080SHf=0P27QhL208>3P`80NWYj0P1mOGd00`20
P800KVi^06i^KP0206][J`80O7al0P1jNWX20;Vi^@80NGUi0P17AdL206m_K`d0b>3H000;0<SPf080
QhN70P1gMgL208>3P`80Shn?0P2JVYX2079bLP80W9bL00<0Hf=S07inOP1nOWh00P1<C4`208Z:RP80
Ti>C0P22PX8208J6QP80MGEe0P1gMgL207YjNP80S8b<0P21PH4208R8R080QhN70P26QXH307emO@80
PH610P25QHD207alO080NWYj0P1dM7@207inOP80NGUi0P28R8P30<SPf080PX:20P1oOgl207UiN@80
XZ:R0P1iNGT208J6QP80UiNG00<0R8R804Y:BP1:BTX00P2KVi/208V9R@80R8R80P1iNGT20861P@80
SXj>0P1]KFd208V9R@80UYJF0P26QXH2096AT@80OWin0P1^KVh208Z:RP0308^;R`20P800P8200080
O7al0P2GUiL208:2PP80MgMg0P22PX82079bLP80MgMg2P38h=P208F5Q@80N7Qh0P1WIfL208>3P`80
Lg=c0P20P8020861P@030;6a/@2<S8`0S8b<0080Ph>30P2>SXh208B4Q080NWYj0P2DU9@208j>SP80
Q8B40P1oOgl209:BTP80SXj>0P1nOWh207moO`80QXJ60P27QhL00`22PX80Ng]k07]kN`0209JFUP80
TY:B0P24Q8@207EeM@80P8200P1/K6`207MgM`<0b>3H0P2?Shl209FEU@80[jn_0P1`L70207QhN080
>3Ph0P1ZJVX00`2QXJ40<c<c03<c<`0207IfMP80Ng]k0P2=SHd206m_K`80Lg=c0P1^KVh207MgM`80
WYjN0P2CTi<2096AT@80VYZJ0P1_Kfl206=SH`80Ogmo00<0Y:BT09NGU`2GUiL00P1/K6`208B4Q080
N7Qh0P1bLW82055AD@80E5AD0P1ZJVX=0<SPf0002`38h=P208N7Q`80MgMg0P23Ph<208n?S`80VYZJ
0P1bLW8209bLW00306=SH`1nOWh0OWin0080C4a<0P2:RXX209>CT`80PX:20P26QXH207EeM@80MgMg
0P1jNWX208b<S080PH610P28R8P208N7Q`80QXJ60`1mOGd20861P@80QHF50P1lO7`207YjNP80M7Ad
0P1nOWh207UiN@80R8R80`38h=P208:2PP80Ogmo0P1iNGT20::RXP80NGUi0P26QXH209NGU`0308R8
R01:BTX0BTY:0080Vi^K0P29RHT208R8R080NGUi0P21PH4208j>SP80KFe]0P29RHT209JFUP80QXJ6
0P2ATI4207inOP80KVi^0P2:RXX00`2;Rh/0P8200820P00207alO080UiNG0P22PX8207MgM`80PX:2
0P1bLW8207MgM`X0b>3H0P25QHD207QhN080IfMW0P23Ph<207=cL`80P8200P21PH400`2a/K40S8b<
08b<S00208>3P`80SXj>0P24Q8@207YjNP80U9BD0P2>SXh208B4Q080Ogmo0P2BTY8208j>SP80OWin
0P1oOgl208J6QP80QhN700<0PX:207]kN`1kNg/00P2FUYH209:BTP80Q8B40P1eMGD20820P080K6a/
0P1gMgL30<SPf080Shn?0P2EUID20:n_[`80L71`0P1hN7P203Ph>080JVYZ00<0XJ6Q03<c<`0c<c<0
0P1fMWH207]kN`80SHf=0P1_Kfl207=cL`80KVi^0P1gMgL209jNWP80Ti>C0P2ATI4209ZJVP80Kfm_
0P1SHf<207moO`030:BTY02GUiL0UiNG0080K6a/0P24Q8@207QhN080LW9b0P1ADE4205ADE080JVYZ
3@38h=P000/0b>3H0P2>SXh208F5Q@80GemO0P2EUID208J6QP80I6AT0P1aLG400`2GUiL0N7Qh07Qh
N00206MWI`80MGEe101mOGd208N7Q`80Q8B40P1kNg/408:2PP80P8200P1lO7`208V9R@80PX:20P1b
LW800`1oOgl0M7Ad07AdM00208F5Q@80OGem0P1jNWX207QhN080Ng]k0P2;Rh/207alO0<0b>3H0P2:
RXX207inOP80Kfm_0P2HV9P208>3P`80NWYj0P1`L7000`1bLW80RXZ:08Z:RP0209fMW@80L71`0P1a
LG4208:2PP80N7Qh0P1]KFd207alO080Ogmo0P22PX8208V9R@80OGem0P1kNg/207MgM`80QXJ600<0
M7Ad08N7Q`27QhL00P2<S8`207emO@80RHV90P1mOGd2071`L080QhN70P21PH4:0<SPf080OWin0P2I
VIT208Z:RP80QhN70P1kNg/208^;R`80QHF500<0OGem04E5A@15ADD00P1oOgl2069RHP80Q8B40P1e
MGD207alO080OGem0P22PX8407QhN080RHV90P20P80209:BTP80Ng]k0P1oOgl00`1kNg/0QhN708N7
Q`020861P@80PX:20P25QHD2071`L080T92@0P1dM7@20861P@<0b>3H0P1ZJVX2065QH@80QXJ60P2W
YjL206UYJ@80<S8b0P1hN7P00`2=SHd0Bd];04];B`0204a<C080N7Qh0P22PX8209RHV080T92@0P22
PX8207moO`80QhN70P21PH4207]kN`80Lg=c0P22PX8209:BTP80O7al00<0L71`09FEU@2EUID00P23
Ph<2079bLP80L71`0P1dM7@206e]K@80MWIf0P22PX8=0<SPf0002`38h=P208j>SP80QHF50P1OGel2
09FEU@80QXJ60P1TI6@2075aL@0309NGU`1hN7P0N7Qh0080IfMW0P1eMGD407emO@80QhN70P24Q8@2
07]kN`@0PX:20P20P80207alO080RHV90P22PX82079bLP0307moO`1dM7@0M7Ad0080QHF50P1mOGd2
07YjNP80N7Qh0P1kNg/208^;R`80O7al0`38h=P208Z:RP80OWin0P1_Kfl209RHV080Ph>30P1jNWX2
071`L003079bLP2:RXX0RXZ:0080WIfM0P1`L702075aL@80PX:20P1hN7P206e]K@80O7al0P1oOgl2
08:2PP80RHV90P1mOGd207]kN`80MgMg0P26QXH00`1dM7@0QhN708N7Q`0208b<S080OGem0P29RHT2
07emO@80L71`0P27QhL20861P@X0b>3H0P1nOWh209VIV@80RXZ:0P27QhL207]kN`80Rh^;0P25QHD0
0`1mOGd0ADE504E5A@0207moO`80HV9R0P24Q8@207EeM@80O7al0P1mOGd208:2PP@0N7Qh0P29RHT2
0820P080TY:B0P1kNg/207moO`0307]kN`27QhL0QhN70080PH610P22PX8208F5Q@80L71`0P2@T902
07AdM080PH610`38h=P206YZJP80HF5Q0P26QXH20:NWY`80JFUY0P0b<S8207QhN00308f=S@1;Bd/0
Bd];0080C4a<0P1hN7P208:2PP80V9RH0P2@T90208:2PP80Ogmo0P27QhL20861P@80Ng]k0P1cLg<2
08:2PP80TY:B0P1lO7`00`1`L700UIFE09FEU@0208>3P`80LW9b0P1`L70207AdM080KFe]0P1fMWH2
08:2PPd0b>3H000;0<SPf080Rh^;0P21PH4207alO080LG5a0P1XJ6P209JFUP80Q8B400<0SXj>06EU
I@1UIFD00P2=SHd209NGU`80NGUi0P28R8P208>3P`80Lg=c0P1nOWh208^;R`80N7Qh0P1oOgl207Mg
M`80PH610P1mOGd207=cL`0308F5Q@1nOWh0OWin0080PH610P23Ph<208f=S@80LW9b0P1hN7P207em
O@80Lg=c0`38h=P207QhN080ZZZZ0P26QXH207moO`80LG5a0P2][Jd20;bl_003061PH01XJ6P0J6QX
0080P8200P1bLW8207MgM`80R8R80P1gMgL2075aL@80TI6A0P1]KFd207MgM`80Ph>30P1nOWh207Qh
N080S8b<0P2;Rh/00`20P800OWin07inOP0208B4Q080QhN70P22PX8206a/K080HV9R0P2>SXh207em
O@X0b>3H0P1oOgl207QhN080MgMg0P1kNg/207YjNP80H61P0P1/K6`00`25QHD0[Zj^0:j^[P0205MG
E`@0KVi^0P1dM7@209>CT`80U9BD0P25QHD207moO`80QXJ60P1lO7`207QhN080Kfm_0P1jNWX208>3
P`0307alO01mOGd0OGem0080N7Qh0P24Q8@408:2PP80P8200P2=SHd208^;R`<0b>3H0P1eMGD207If
MP80K6a/0P2GUiL2079bLP80Vi^K0P23Ph<00`1ZJVX0/k>c0;>c/`0205ADE080JVYZ0P2ZZZX2069R
HP80N7Qh0P2GUiL208:2PP80SHf=0P29RHT2092@T080UYJF0P1/K6`207]kN`80QhN700<0L71`08^;
R`2;Rh/0101YJFT206e]K@80IfMW0P2<S8`206=SH`80PH613@38h=P000/0b>3H0P2;Rh/20861P@80
O7al0P1aLG4206QXJ080UYJF0P24Q8@00`2>SXh0IFEU06EUI@0208f=S@80UiNG0P1iNGT208R8R080
Ph>30P1cLg<207inOP80Rh^;0P1hN7P207moO`80MgMg0P21PH4207emO@80Lg=c00<0QHF507inOP1n
OWh00P21PH4208>3P`80SHf=0P1bLW8207QhN080OGem0P1cLg<30<SPf080N7Qh0P2ZZZX208J6QP80
Ogmo0P1aLG420:f][@80_;bl00<0H61P06QXJ01XJ6P00P20P802079bLP80MgMg0P28R8P207MgM`80
LG5a0P2ATI4206e]K@80MgMg0P23Ph<207inOP80N7Qh0P2<S8`208^;R`030820P01nOWh0OWin0080
Q8B40P27QhL208:2PP80K6a/0P1RHV8208j>SP80OGem2P38h=P207moO`80N7Qh0P1gMgL207]kN`80
NWYj0P1PH60206a/K00308F5Q@2^[Zh0[Zj^0080EeMG101^KVh207AdM080Ti>C0P2DU9@208F5Q@80
Ogmo0P26QXH207alO080N7Qh0P1_Kfl207YjNP80Ph>300<0O7al07emO@1mOGd00P1hN7P208B4Q0@0
PX:20P20P80208f=S@80Rh^;0`38h=P207EeM@80MWIf0P1/K6`209NGU`80LW9b0P2KVi/208>3P`03
06YZJP2c/k<0/k>c0080E5AD0P1ZJVX20:ZZZP80HV9R0P1hN7P209NGU`80PX:20P2=SHd208V9R@80
T92@0P2FUYH206a/K080Ng]k0P27QhL00`1`L700Rh^;08^;R`0406UYJ@80KFe]0P1WIfL208b<S080
Hf=S0P21PH4=0<SPf0002`38h=P209:BTP80Lg=c0P28R8P207MgM`@0OWin0P2OWil00`1kNg/0PH61
0861P@0208N7Q`80R8R80P2:RXX207inOP80KVi^0P1mOGd207=cL`80KFe]0P1hN7P207emO@80Rh^;
0P2=SHd407moO`0307UiN@1nOWh0OWin0080OGem0P22PX8207]kN`80PH610P1kNg/206EUI@80OGem
0`38h=P208b<S080Kfm_0P2RXZ8207=cL`80[jn_0P1<C4`202/[:`0305eMG@2EUID0UIFE0080M7Ad
0P1/K6`205aLG080LG5a0P1cLg<209^KV`80NGUi0P2<S8`209FEU@80OWin0P1_Kfl2069RHP80NWYj
0P2;Rh/00`26QXH0MWIf07IfMP0209JFUP80Rh^;0P23Ph<208J6QP80O7al0P1gMgL207inOPX0b>3H
0P24Q8@206MWI`80PH610P1gMgL208B4Q080/;2`0P2c/k<00`1nOWh0NGUi07UiN@020:ZZZP80WYjN
0P1jNWX207moO`80P8200P24Q8@2071`L080RXZ:0P25QHD208B4Q080MWIf0P23Ph<207EeM@80R8R8
00<0MGEe07]kN`1kNg/0101iNGT208J6QP80LG5a0P2:RXX207alO080Ng]k0`38h=P207]kN`80JFUY
0P2=SHd208Z:RP80IVIV0P1GEeL206i^KP030:n_[`23Ph<0Ph>30080MGEe0P1ADE42030`<080IfMW
0P1DE5@206MWI`80WYjN0P1hN7P20861P@80Ti>C0P1dM7@208>3P`80V9RH0P1SHf<00`22PX80PH61
0861P@0207UiN@80TI6A0P2>SXh206a/K080NWYj0P2FUYH20:j^[Pd0b>3H000;0<SPf080TY:B0P1c
Lg<208R8R080MgMg101nOWh209nOW`0307]kN`21PH40PH610080QhN70P28R8P208Z:RP80OWin0P1^
KVh207emO@80Lg=c0P1]KFd207QhN080OGem0P2;Rh/208f=S@@0Ogmo00<0NGUi07inOP1nOWh00P1m
OGd208:2PP80Ng]k0P21PH4207]kN`80IFEU0P1mOGd30<SPf080S8b<0P1_Kfl20::RXP80Lg=c0P2_
[jl204a<C080:b/[00<0GEeM09FEU@2EUID00P1dM7@206a/K080G5aL0P1aLG4207=cL`80Vi^K0P1i
NGT208b<S080UIFE0P1nOWh206m_K`80HV9R0P1jNWX208^;R`0308J6QP1fMWH0MWIf0080UYJF0P2;
Rh/208>3P`80QXJ60P1lO7`207MgM`80OWin2P38h=P208B4Q080IfMW0P21PH4207MgM`80Q8B40P2`
/;020;>c/`0307inOP1iNGT0NGUi0080ZZZZ0P2NWYh207YjNP80Ogmo0P20P80208B4Q080L71`0P2:
RXX208F5Q@80Q8B40P1fMWH208>3P`80MGEe0P28R8P00`1eMGD0Ng]k07]kN`0407UiN@80QXJ60P1a
LG4208Z:RP80O7al0P1kNg/30<SPf080Ng]k0P1YJFT208f=S@80RXZ:0P1VIVH205MGE`80KVi^00<0
[jn_08>3P`23Ph<00P1eMGD2055AD@80<30`0P1WIfL205ADE080IfMW0P2NWYh207QhN080PH610P2C
Ti<207AdM080Ph>30P2HV9P206=SH`0308:2PP21PH40PH610080NGUi0P2ATI4208j>SP80K6a/0P1j
NWX209JFUP80[Zj^3@38h=P000/0b>3H0P25QHD208:2PP80UiNG0P2ATI4407moO`80KFe]00<0Kfm_
09bLW02LW9`00P1oOgl208R8R080PX:20P1nOWh207UiN@80MgMg0P1`L70208F5Q@80QhN70P1fMWH2
08R8R080OWin1026QXH00`1iNGT0O7al07alO00207UiN@@0Ph>30P27QhL208>3P`80PX:20P1ADE43
0<SPf080Ogmo0P1cLg<20820P080[Jf]0P27QhL207MgM`80WIfM00<0Jf][07MgM`1gMgL00P2>SXh2
0;no_`80Cdm?0P1eMGD207alO080I6AT0P1mOGd209:BTP80PH610P1iNGT207]kN`80PX:20P28R8P2
07inOP0306i^KP1nOWh0OWin0080I6AT0P2CTi<207QhN080O7al0P2;Rh/207IfMP80L71`2P38h=P2
08n?S`80OWin0P1lO7`208J6QP80IfMW0P1mOGd207EeM@0307MgM`2KVi/0Vi^K0080OGem0P1OGel2
03hn?P80NGUi0P28R8P208b<S080P8200P2<S8`2071`L080Shn?0P28R8P207]kN`80PH610P1iNGT0
0`2<S8`0QXJ608J6QP0207inOP80LW9b0P1lO7`208Z:RP80RHV90P1jNWX206EUI@<0b>3H0P1iNGT2
06a/K080Q8B40P1]KFd206QXJ080MGEe0`26QXH205ADE080MWIf0P1=CDd20:b/[080NWYj0P2JVYX2
08f=S@80[Zj^0P1QHF420:BTY080SHf=0P26QXH205iNGP80Shn?0`1]KFd208N7Q`80Ng]k0P25QHD2
08J6QP80KVi^0P1gMgL20:NWY`80LW9b3@38h=P000/0b>3H0P25QHD208:2PP80UiNG0P2ATI4407mo
O`80KFe]00<0Kfm_09bLW02LW9`00P1oOgl208R8R080PX:20P1nOWh207UiN@80MgMg0P1`L70208F5
Q@80QhN70P1fMWH208R8R080OWin1026QXH00`1iNGT0O7al07alO00207UiN@@0Ph>30P27QhL208>3
P`80PX:20P1ADE430<SPf080Ogmo0P1cLg<20820P080[Jf]0P27QhL207MgM`80WIfM00<0Jf][07Mg
M`1gMgL00P2>SXh20;no_`80Cdm?0P1eMGD207alO080I6AT0P1mOGd209:BTP80PH610P1iNGT207]k
N`80PX:20P28R8P207inOP0306i^KP1nOWh0OWin0080I6AT0P2CTi<207QhN080O7al0P2;Rh/207If
MP80L71`2P38h=P208n?S`80OWin0P1lO7`208J6QP80IfMW0P1mOGd207EeM@0307MgM`2KVi/0Vi^K
0080OGem0P1OGel203hn?P80NGUi0P28R8P208b<S080P8200P2<S8`2071`L080Shn?0P28R8P207]k
N`80PH610P1iNGT00`2<S8`0QXJ608J6QP0207inOP80LW9b0P1lO7`208Z:RP80RHV90P1jNWX206EU
I@<0b>3H0P1iNGT206a/K080Q8B40P1]KFd206QXJ080MGEe0`26QXH205ADE080MWIf0P1=CDd20:b/
[080NWYj0P2JVYX208f=S@80[Zj^0P1QHF420:BTY080SHf=0P26QXH205iNGP80Shn?0`1]KFd208N7
Q`80Ng]k0P25QHD208J6QP80KVi^0P1gMgL20:NWY`80LW9b3@38h=P000/0b>3H0P1gMgL208F5Q@80
Lg=c0P1mOGd208N7Q`80RHV90P24Q8@00`1hN7P0KFe]06e]K@0208F5Q@80Ph>30P27QhL209BDU080
N7Qh0P1iNGT208F5Q@80Q8B40P1kNg/207inOP80NWYj0P1fMWH207alO080QHF500<0Ng]k0861P@21
PH400P1nOWh208:2PP80Ph>30P1iNGT207]kN`80N7Qh0P1HF5P30<SPf080[Jf]0P2@T90205iNGP80
MGEe0P1dM7@209>CT`80E5AD00<0VIVI07moO`1oOgl00P2SXj<209NGU`80LW9b0P28R8P208^;R`80
JVYZ0P1kNg/207IfMP80KVi^0P21PH4206][J`80NWYj0P2IVIT209RHV00309jNWP22PX80PX:200@0
OGem0P1nOWh207emO@80SXj>0P1eMGD208j>SPX0b>3H0P1RHV8206][J`80N7Qh0P1nOWh207IfMP80
R8R80P1WIfL00`2EUID0OGem07emO@0207UiN@80Q8B40P2>SXh20:b/[080OGem0P20P80207moO`80
KVi^0P23Ph<2096AT@80OWin0P1gMgL207inOP80Shn?00<0SXj>08F5Q@25QHD00P1mOGd2092@T080
Ogmo0P1^KVh208^;R`80PX:20P1iNGT30<SPf080oooo0P22PX8206e]K@80Q8B40P2;Rh/209>CT`80
YjNW00<0FUYJ06i^KP1^KVh00P1jNWX207EeM@80Hf=S0P2f][H206QXJ080QXJ60P1jNWX207IfMP80
Ph>30P2=SHd207inOP80A4A40P1/K6`208R8R0030:JVYP2JVYX0VYZJ0080IVIV0P25QHD207moO`80
WYjN0P1eMGD2075aL@80QHF53@38h=P000/0b>3H0P1gMgL208F5Q@80Lg=c0P1mOGd208N7Q`80RHV9
0P24Q8@00`1hN7P0KFe]06e]K@0208F5Q@80Ph>30P27QhL209BDU080N7Qh0P1iNGT208F5Q@80Q8B4
0P1kNg/207inOP80NWYj0P1fMWH207alO080QHF500<0Ng]k0861P@21PH400P1nOWh208:2PP80Ph>3
0P1iNGT207]kN`80N7Qh0P1HF5P30<SPf080[Jf]0P2@T90205iNGP80MGEe0P1dM7@209>CT`80E5AD
00<0VIVI07moO`1oOgl00P2SXj<209NGU`80LW9b0P28R8P208^;R`80JVYZ0P1kNg/207IfMP80KVi^
0P21PH4206][J`80NWYj0P2IVIT209RHV00309jNWP22PX80PX:200@0OGem0P1nOWh207emO@80SXj>
0P1eMGD208j>SPX0b>3H0P1RHV8206][J`80N7Qh0P1nOWh207IfMP80R8R80P1WIfL00`2EUID0OGem
07emO@0207UiN@80Q8B40P2>SXh20:b/[080OGem0P20P80207moO`80KVi^0P23Ph<2096AT@80OWin
0P1gMgL207inOP80Shn?00<0SXj>08F5Q@25QHD00P1mOGd2092@T080Ogmo0P1^KVh208^;R`80PX:2
0P1iNGT30<SPf080oooo0P22PX8206e]K@80Q8B40P2;Rh/209>CT`80YjNW00<0FUYJ06i^KP1^KVh0
0P1jNWX207EeM@80Hf=S0P2f][H206QXJ080QXJ60P1jNWX207IfMP80Ph>30P2=SHd207inOP80A4A4
0P1/K6`208R8R0030:JVYP2JVYX0VYZJ0080IVIV0P25QHD207moO`80WYjN0P1eMGD2075aL@80QHF5
3@38h=P000/0b>3H0P1gMgL207alO080MgMg0P1jNWX207IfMP80QHF50P1bLW800`2JVYX0NGUi07Ui
N@0206a/K080QHF50P1gMgL208:2PP80Ti>C0P2<S8`208Z:RP80Q8B40P22PX8207IfMP80QHF50P1N
GUh20::RXP80YjNW00<0Jf][07AdM01dM7@00P2CTi<207IfMP80PX:20P20P80206m_K`80Ogmo0P1h
N7P30<SPf080QXJ60P2SXj<207QhN080MGEe0P2b/[8209VIV@80E5AD00<0Q8B405ADE01DE5@00P1k
Ng/209NGU`80Rh^;0P1kNg/208V9R@80Ng]k0P2HV9P208V9R@80OGem0P21PH4207]kN`80R8R80P1/
K6`209VIV@0308>3P`2DU9@0U9BD0080TI6A0P2CTi<206i^KP80SHf=0P1jNWX208b<S080Q8B42P38
h=P206IVIP80MWIf0P1oOgl208f=S@80Vi^K0P27QhL207]kN`0306a/K02TY:@0Y:BT0080P8200P1Y
JFT207inOP80MWIf0P2?Shl207emO@80QhN70P1mOGd207UiN@80QhN70P2>SXh206a/K080KVi^0P2;
Rh/00`23Ph<0RHV908V9R@0206e]K@80P8200P27QhL208R8R080KVi^0P1kNg/206QXJ0<0b>3H0P1l
O7`206][J`80WIfM0P3>c/h20:JVYP80RXZ:0P2SXj<00`1cLg<0D51@051@D0020;Jf]P80N7Qh0P2=
SHd203`l?080]kNg0P2IVIT207UiN@80RHV90P1hN7P208b<S080O7al0P1oOgl208N7Q`80K6a/00<0
UIFE096AT@2ATI400P1bLW8208B4Q080RHV90P27QhL206IVIP80TI6A0P1nOWh=0<SPf0002`38h=P2
07MgM`80O7al0P1gMgL207YjNP80MWIf0P25QHD2079bLP0309ZJVP1iNGT0NGUi0080K6a/0P25QHD2
07MgM`80PX:20P2CTi<208b<S080RXZ:0P24Q8@208:2PP80MWIf0P25QHD205iNGP80XZ:R0P2WYjL0
0`1[Jf/0M7Ad07AdM00209>CT`80MWIf0P22PX820820P080Kfm_0P1oOgl207QhN0<0b>3H0P26QXH2
0:>SX`80N7Qh0P1eMGD20;:b/P80VIVI0P1DE5@00`24Q8@0E5AD05ADE00207]kN`80UiNG0P2;Rh/2
07]kN`80RHV90P1kNg/209RHV080RHV90P1mOGd20861P@80Ng]k0P28R8P206a/K080VIVI00<0Ph>3
09BDU02DU9@00P2ATI4209>CT`80KVi^0P2=SHd207YjNP80S8b<0P24Q8@:0<SPf080IVIV0P1fMWH2
07moO`80SHf=0P2KVi/208N7Q`80Ng]k00<0K6a/0:BTY02TY:@00P20P80206UYJ@80OWin0P1fMWH2
08n?S`80OGem0P27QhL207emO@80NGUi0P27QhL208j>SP80K6a/0P1^KVh208^;R`0308>3P`29RHT0
RHV90080KFe]0P20P80208N7Q`80R8R80P1^KVh207]kN`80J6QX0`38h=P207alO080Jf][0P2MWId2
0<k>cP80YZJV0P2:RXX20:>SX`0307=cL`1@D500D51@0080][Jf0P1hN7P208f=S@80?3`l0P2g]kL2
09VIV@80NGUi0P29RHT207QhN080S8b<0P1lO7`207moO`80QhN70P1/K6`00`2EUID0TI6A096AT@02
079bLP80Q8B40P29RHT208N7Q`80IVIV0P2ATI4207inOPd0b>3H000;0<SPf080Ng]k0P1/K6`207in
OP80QhN70P1ZJVX208J6QP80Ng]k00<0V9RH08Z:RP2:RXX00P1oOgl20820P080OGem0P1lO7`208F5
Q@80S8b<0P1kNg/208b<S0@0R8R80P1aLG4209FEU@80N7Qh0P1cLg<00`1kNg/0RHV908V9R@020861
P@80M7Ad0P1lO7`2079bLP@0O7al0P1gMgL30<SPf080MGEe0P24Q8@2096AT@80Lg=c0P1WIfL206AT
I080Lg=c00<0WYjN096AT@2ATI400P1GEeL208:2PP80IfMW0P1oOgl209>CT`80/k>c0P24Q8@2055A
D@80GUiN0P23Ph<205MGE`80X:2P0P1oOgl20820P00307inOP1ZJVX0JVYZ0080MgMg0P2f][H209nO
W`80RHV90P1ZJVX207EeM@80N7Qh2P38h=P207=cL`80MWIf0P1jNWX206m_K`80L71`0P2JVYX20;:b
/P0308^;R`1kNg/0Ng]k0080O7al1022PX8209^KV`80LW9b0P2IVIT207EeM@80MgMg0P1nOWh208B4
Q080RXZ:0P2/[:`207]kN`80IfMW00<0Ph>308N7Q`27QhL00P24Q8@206i^KP80Ogmo0P1_Kfl207Qh
N080MGEe0P1oOgl30<SPf080N7Qh0P1YJFT208:2PP80QhN70P26QXH209FEU@80`l?300<0UYJF071`
L01`L7000P1WIfL20:>SX`80W9bL0P1dM7@203Hf=P80_[jn0P2CTi<207YjNP80KVi^0P26QXH207Qh
N080YjNW0P2=SHd207UiN@0306i^KP1XJ6P0J6QX0080Ng]k0P1mOGd209FEU@80LW9b0P1XJ6P206][
J`80JVYZ3@38h=P000/0b>3H0P1kNg/206a/K080OWin0P27QhL206YZJP80QXJ60P1kNg/00`2HV9P0
RXZ:08Z:RP0207moO`80P8200P1mOGd207alO080QHF50P2<S8`207]kN`80S8b<1028R8P2075aL@80
UIFE0P1hN7P207=cL`0307]kN`29RHT0RHV90080PH610P1dM7@207alO080LW9b101lO7`207MgM`<0
b>3H0P1eMGD208B4Q080TI6A0P1cLg<206MWI`80I6AT0P1cLg<00`2NWYh0TI6A096AT@0205MGE`80
PX:20P1WIfL207moO`80Ti>C0P2c/k<208B4Q080DE5A0P1NGUh208>3P`80EeMG0P2PX:0207moO`80
P82000<0OWin06YZJP1ZJVX00P1gMgL20;Jf]P80WinO0P29RHT206YZJP80MGEe0P1hN7P:0<SPf080
Lg=c0P1fMWH207YjNP80Kfm_0P1`L70209ZJVP80/[:b00<0Rh^;07]kN`1kNg/00P1lO7`408:2PP80
Vi^K0P1bLW8209VIV@80MGEe0P1gMgL207inOP80Q8B40P2:RXX20:b/[080Ng]k0P1WIfL00`23Ph<0
QhN708N7Q`0208B4Q080KVi^0P1oOgl206m_K`80N7Qh0P1eMGD207moO`<0b>3H0P1hN7P206UYJ@80
PX:20P27QhL208J6QP80UIFE0P33`l<00`2FUYH0L71`071`L00206MWI`80Xj>S0P2LW9`207AdM080
=SHf0P2n_[h209>CT`80NWYj0P1^KVh208J6QP80N7Qh0P2WYjL208f=S@80NGUi00<0KVi^06QXJ01X
J6P00P1kNg/207emO@80UIFE0P1bLW8206QXJ080Jf][0P1ZJVX=0<SPf0002`38h=P208n?S`80N7Qh
0P26QXH207emO@80R8R80P1gMgL208Z:RP0309JFUP23Ph<0Ph>30080VYZJ0P24Q8@2069RHP80O7al
0P24Q8@208b<S080PX:20P29RHT209>CT`80SXj>0P25QHD207]kN`80Ph>30P1jNWX00`2ATI40NWYj
07YjNP0207QhN080JVYZ0P2EUID208:2PP80OWin0P1oOgl206=SH`<0b>3H0P1hN7P206IVIP80VIVI
0P1nOWh207MgM`80JVYZ0P1mOGd00`2@T900PH610861P@0204Y:BP80SXj>0P2MWId208B4Q080Lg=c
0P24Q8@2092@T080O7al0P2HV9P206ATI080MWIf0P2?Shl20::RXP80TI6A00<0Ng]k07UiN@1iNGT0
0P28R8P20:b/[080NWYj0P2:RXX208N7Q`80P8200P1eMGD:0<SPf080OGem0P1TI6@208:2PP80Z:RX
0P1ZJVX207inOP80O7al00<0MGEe0:NWY`2WYjL00P2OWil208n?S`80P8200P23Ph<208R8R080Cdm?
0P2JVYX207QhN080PH610P28R8P208F5Q@80LW9b0P1dM7@207emO@0307moO`22PX80PX:20080O7al
0P1YJFT207UiN@80TI6A0P29RHT208>3P`80NGUi0`38h=P205YJFP80/[:b0P2UYJD207emO@80[Jf]
0P1WIfL208R8R003065QH@1gMgL0MgMg0080NWYj0P29RHT2092@T080J6QX0P2:RXX202/[:`80VYZJ
0P1aLG4207EeM@80N7Qh0P1NGUh20>GUi@80RHV90P1WIfL00`1XJ6P0MgMg07MgM`0207alO080EeMG
0P1kNg/208f=S@80OGem0P1aLG4207QhN0d0b>3H000;0<SPf080Shn?0P1hN7P208J6QP80OGem0P28
R8P207MgM`80RXZ:00<0UYJF08>3P`23Ph<00P2JVYX208B4Q080HV9R0P1lO7`208B4Q080S8b<0P22
PX8208V9R@80Ti>C0P2>SXh208F5Q@80Ng]k0P23Ph<207YjNP03096AT@1jNWX0NWYj0080N7Qh0P1Z
JVX209FEU@80PX:20P1nOWh207moO`80Hf=S0`38h=P207QhN080IVIV0P2IVIT207inOP80MgMg0P1Z
JVX207emO@03092@T021PH40PH610080BTY:0P2>SXh209fMW@80Q8B40P1cLg<208B4Q080T92@0P1l
O7`209RHV080I6AT0P1fMWH208n?S`80XZ:R0P2ATI400`1kNg/0NGUi07UiN@0208R8R080[:b/0P1j
NWX208Z:RP80QhN70P20P80207EeM@X0b>3H0P1mOGd206ATI080PX:20P2XZ:P206YZJP80OWin0P1l
O7`00`1eMGD0YjNW0:NWY`0209nOW`80Shn?0P20P80208>3P`80R8R80P1?Cdl209ZJVP80N7Qh0P21
PH4208R8R080QHF50P1bLW8207AdM080OGem00<0Ogmo08:2PP22PX800P1lO7`206UYJ@80NGUi0P2A
TI4208V9R@80Ph>30P1iNGT30<SPf080FUYJ0P2b/[820:FUY@80OGem0P2][Jd206MWI`80R8R800<0
HF5Q07MgM`1gMgL00P1jNWX208V9R@80T92@0P1XJ6P208Z:RP80:b/[0P2JVYX2075aL@80MGEe0P1h
N7P205iNGP80iNGU0P29RHT206MWI`0306QXJ01gMgL0MgMg0080O7al0P1GEeL207]kN`80SHf=0P1m
OGd2075aL@80N7Qh3@38h=P000/0b>3H0P2GUiL207IfMP80Rh^;0P1cLg<207moO`80Rh^;0P1mOGd0
0`21PH40UIFE09FEU@0206EUI@80LG5a0P2IVIT207alO080M7Ad0P28R8P207MgM`80Shn?0P20P802
08^;R`80VIVI0P1jNWX208b<S080QHF500<0UYJF08Z:RP2:RXX00P1dM7@207QhN080Lg=c0P2:RXX2
07alO080NGUi0P1[Jf/30<SPf080OGem0P2?Shl2092@T080Ti>C0P1>CTh20;>c/`80NWYj00<0DU9B
0:2PX02PX:000P1lO7`208Z:RP80N7Qh0P2LW9`209VIV@80Ph>30P2JVYX207]kN`80U9BD0P2?Shl2
09NGU`80I6AT0P1ADE4209^KV`030<30`029RHT0RHV90080EUIF0P2NWYh2075aL@80QXJ60P2a/K42
07=cL`80LG5a2P38h=P208>3P`80K6a/0P1^KVh209VIV@80UYJF0P1dM7@208Z:RP0307=cL`28R8P0
R8R80080MWIf0P1bLW82071`L080SXj>0P2;Rh/209RHV080CTi>0P2IVIT207MgM`80SHf=0P21PH42
06QXJ080Y:BT0P2;Rh/00`1OGel0OGem07emO@0207alO080Bd];1026QXH207alO080MgMg0P22PX83
0<SPf080LG5a0P1cLg<207inOP80Ogmo0P1NGUh207EeM@80TY:B00<0IfMW07]kN`1kNg/00P0o?cl2
07=cL`80Xj>S0P2KVi/207QhN080`/;20P27QhL200820P80`L710P2IVIT205UIF@80IVIV0P2e]KD2
0?ooo`030=;BdP29RHT0RHV90080Xj>S0P1bLW8408R8R080GemO0P21PH4209nOW`d0b>3H000;0<SP
f080UiNG0P1fMWH208^;R`80Lg=c0P1oOgl208^;R`80OGem00<0PH6109FEU@2EUID00P1UIFD2075a
L@80VIVI0P1lO7`207AdM080R8R80P1gMgL208n?S`80P8200P2;Rh/209VIV@80NWYj0P2<S8`208F5
Q@0309JFUP2:RXX0RXZ:0080M7Ad0P1hN7P207=cL`80RXZ:0P1lO7`207UiN@80Jf][0`38h=P207em
O@80Shn?0P2@T90209>CT`80CTi>0P2c/k<207YjNP03059BDP2PX:00X:2P0080O7al0P2:RXX207Qh
N080W9bL0P2IVIT208>3P`80VYZJ0P1kNg/209BDU080Shn?0P2GUiL206ATI080DE5A0P2KVi/00`30
`<00RHV908V9R@0205IFEP80WYjN0P1aLG4208J6QP80/K6a0P1cLg<2075aL@X0b>3H0P23Ph<206a/
K080KVi^0P2IVIT209JFUP80M7Ad0P2:RXX00`1cLg<0R8R808R8R00207IfMP80LW9b0P1`L70208j>
SP80Rh^;0P2HV9P204i>CP80VIVI0P1gMgL208f=S@80PH610P1XJ6P20:BTY080Rh^;00<0GemO07em
O@1mOGd00P1lO7`204];B`@0QXJ60P1lO7`207MgM`80PX:20`38h=P2075aL@80Lg=c0P1nOWh207mo
O`80GUiN0P1eMGD209:BTP0306MWI`1kNg/0Ng]k0080?clo0P1cLg<20:>SX`80Vi^K0P1hN7P20<;2
`P80QhN70P020P820<71`@80VIVI0P1IFET206IVIP80]KFe0P3oool00`3Bd]80RHV908V9R@020:>S
X`80LW9b1028R8P205mOG`80PH610P2OWil=0<SPf0002`38h=P207=cL`80NWYj0P2=SHd208>3P`80
Lg=c0P2:RXX208B4Q0030820P02<S8`0S8b<0080Rh^;0P1mOGd206QXJ080NWYj0P1iNGT207MgM`80
V9RH0P22PX8209jNWP80TI6A0P1kNg/207=cL`80OGem0P29RHT00`1jNWX0N7Qh07QhN00208V9R@80
NWYj0P28R8P20861P@80MWIf0P25QHD207emO@<0b>3H0P1kNg/208N7Q`80UIFE0P1ZJVX207UiN@80
TY:B0P1aLG400`23Ph<0Zj^[0:^[Z`0209JFUP80fMWI0P2SXj<208^;R`80Ogmo0P22PX8206ATI080
Ph>30P1EEED2075aL@80RHV90P28R8P208F5Q@80JFUY00<0LW9b07QhN01hN7P00P23Ph<209BDU080
NWYj0P28R8P208F5Q@80RHV90P1SHf<:0<SPf080Ogmo0P1hN7P208:2PP80M7Ad0P1ZJVX208b<S080
OWin00<0U9BD075aL@1aLG400P1nOWh207YjNP80F5QH0P27QhL207]kN`80LG5a0P2LW9`2065QH@80
Zj^[0P2@T90208:2PP80RHV90P22PX8208J6QP0309^KV`1eMGD0MGEe0080PX:20P23Ph<207emO@80
P8200P2:RXX207=cL`80NWYj0`38h=P208:2PP80DE5A0P1aLG4205aLG080Hf=S0P2FUYH206EUI@03
08N7Q`2l_;`0_;bl0080QXJ60P1lO7`208b<S080J6QX0P1`L70207moO`80U9BD0P21PH4203@d=080
SHf=0P1nOWh209nOW`80M7Ad0P2c/k<00`2o_kl0a<C40<C4a00208J6QP80UIFE0P2@T90208j>SP80
ZJVY0P25QHD2071`L0d0b>3H000;0<SPf080Lg=c0P1jNWX208f=S@80Ph>30P1cLg<208Z:RP80Q8B4
00<0P82008b<S02<S8`00P2;Rh/207emO@80J6QX0P1jNWX207UiN@80MgMg0P2HV9P208:2PP80WYjN
0P2ATI4207]kN`80Lg=c0P1mOGd208V9R@0307YjNP1hN7P0N7Qh0080RHV90P1jNWX208R8R080PH61
0P1fMWH208F5Q@80OGem0`38h=P207]kN`80QhN70P2EUID206YZJP80NGUi0P2BTY82075aL@0308>3
P`2[Zj/0Zj^[0080UYJF0P3IfMT20:>SX`80Rh^;0P1oOgl208:2PP80I6AT0P23Ph<205EEE@80LG5a
0P29RHT208R8R080QHF50P1YJFT00`1bLW80N7Qh07QhN00208>3P`80U9BD0P1jNWX208R8R080QHF5
0P29RHT206=SH`X0b>3H0P1oOgl207QhN080PX:20P1dM7@206YZJP80S8b<0P1nOWh00`2DU9@0LG5a
075aL@0207inOP80NWYj0P1HF5P208N7Q`80Ng]k0P1aLG4209bLW080HF5Q0P2[Zj/2092@T080PX:2
0P29RHT208:2PP80QXJ600<0Vi^K07EeM@1eMGD00P22PX8208>3P`80OGem0P20P80208Z:RP80Lg=c
0P1jNWX30<SPf080PX:20P1ADE42075aL@80G5aL0P1SHf<209JFUP80IFEU00<0QhN70;bl_02l_;`0
0P26QXH207alO080S8b<0P1XJ6P2071`L080Ogmo0P2DU9@20861P@80=3@d0P2=SHd207inOP80WinO
0P1dM7@20;>c/`030;no_`34a<@0a<C40080QXJ60P2EUID2092@T080SXj>0P2YZJT208F5Q@80L71`
3@38h=P000/0b>3H0P2NWYh209RHV080PH610P28R8P208F5Q@80Ph>30P1RHV800`1jNWX0LW9b079b
LP0207UiN@80Shn?0P2@T90208Z:RP80PH610P1jNWX208b<S080TY:B0P1hN7P207MgM`80R8R80P1]
KFd207YjNP80W9bL00<0P82007=cL`1cLg<00P2NWYh208Z:RP80OGem0P28R8P60861P@<0b>3H0P2F
UYH206i^KP80Ogmo0P2j^[X20:6QX@80KFe]0P1kNg/00`1ZJVX0Shn?08n?S`0205IFEP80I6AT0P2C
Ti<207MgM`80Ph>30P1ZJVX2071`L080RXZ:0P29RHT206QXJ080PX:20P2^[Zh207inOP80ATI600<0
[Zj^09VIV@2IVIT00P1EEED208:2PP80JFUY0P2OWil207IfMP80NWYj0P23Ph<:0<SPf080R8R80P2K
Vi/208B4Q080FEUI0P1bLW8207alO080MWIf00<0OGem09BDU02DU9@00P2`/;0209:BTP80Q8B40P1Y
JFT209JFUP80OWin0P1^KVh209>CT`80MWIf0P1mOGd208J6QP80NWYj0P1]KFd208^;R`0307emO@1f
MWH0MWIf0080L71`0P2RXZ820820P080L71`0P1mOGd20861P@80MgMg0`38h=P404Q8B0@0N7Qh0P1N
GUh207]kN`80Lg=c00<0JFUY05]KF`1KFe/00P1ZJVX207inOP80?Shn0P1YJFT206MWI`80NGUi0P1T
I6@209bLW080MGEe0P1lO7`209VIV@80[:b/0P1cLg<208R8R00307UiN@1PH600H61P0080clo?0P3H
f=P207QhN080/;2`0P2:RXX2096AT@80LG5a3@38h=P000/0b>3H0P2NWYh209RHV080PH610P28R8P2
08F5Q@80Ph>30P1RHV800`1jNWX0LW9b079bLP0207UiN@80Shn?0P2@T90208Z:RP80PH610P1jNWX2
08b<S080TY:B0P1hN7P207MgM`80R8R80P1]KFd207YjNP80W9bL00<0P82007=cL`1cLg<00P2NWYh2
08Z:RP80OGem0P28R8P60861P@<0b>3H0P2FUYH206i^KP80Ogmo0P2j^[X20:6QX@80KFe]0P1kNg/0
0`1ZJVX0Shn?08n?S`0205IFEP80I6AT0P2CTi<207MgM`80Ph>30P1ZJVX2071`L080RXZ:0P29RHT2
06QXJ080PX:20P2^[Zh207inOP80ATI600<0[Zj^09VIV@2IVIT00P1EEED208:2PP80JFUY0P2OWil2
07IfMP80NWYj0P23Ph<:0<SPf080R8R80P2KVi/208B4Q080FEUI0P1bLW8207alO080MWIf00<0OGem
09BDU02DU9@00P2`/;0209:BTP80Q8B40P1YJFT209JFUP80OWin0P1^KVh209>CT`80MWIf0P1mOGd2
08J6QP80NWYj0P1]KFd208^;R`0307emO@1fMWH0MWIf0080L71`0P2RXZ820820P080L71`0P1mOGd2
0861P@80MgMg0`38h=P404Q8B0@0N7Qh0P1NGUh207]kN`80Lg=c00<0JFUY05]KF`1KFe/00P1ZJVX2
07inOP80?Shn0P1YJFT206MWI`80NGUi0P1TI6@209bLW080MGEe0P1lO7`209VIV@80[:b/0P1cLg<2
08R8R00307UiN@1PH600H61P0080clo?0P3Hf=P207QhN080/;2`0P2:RXX2096AT@80LG5a3@38h=P0
00/0b>3H0P1gMgL207alO080Ng]k0P2`/;02092@T080OWin0P1kNg/307QhN080T92@0P1aLG4209bL
W080I6AT0P20P80207alO080P8200P2;Rh/208f=S@80R8R80P1lO7`208B4Q080QXJ60P1^KVh00`1m
OGd0Rh^;08^;R`0208:2PP80QXJ60P2<S8`208N7Q`80Lg=c0P21PH4208j>SP<0b>3H0P2KVi/207]k
N`80/[:b0P1HF5P207inOP80RXZ:0P1@D5000`24Q8@0E5AD05ADE00207=cL`80Ti>C0P0n?Sh207]k
N`80TY:B0P1_Kfl207]kN`80Shn?0P1oOgl20861P@80UYJF0P1aLG4207alO080KFe]00<0Q8B409NG
U`2GUiL00P1XJ6P209JFUP80XJ6Q0P1PH60207AdM080JVYZ0P1kNg/:0<SPf080U9BD0P24Q8@2061P
H080QHF50P2<S8`209BDU0<0VIVI0P1HF5P20:>SX`80R8R80P2MWId208J6QP80UIFE0P1lO7`208^;
R`80HV9R0P2@T902075aL@80RHV90P24Q8@208N7Q`80C4a<00<0OWin08V9R@29RHT00P1eMGD206m_
K`80OGem0P1kNg/208Z:RP80MGEe0P22PX830<SPf080JVYZ0P2GUiL208V9R@80IVIV0P2FUYH2092@
T080^KVi00<0AdM705]KF`1KFe/00P1/K6`204M7A`80OWin0P2FUYH207moO`80T92@0P25QHD208J6
QP80KFe]0P1IFET20?ooo`80HV9R0P2QXJ4208j>SP0309nOW`2=SHd0SHf=0080L71`0P2@T9020861
P@80Xj>S0P1aLG4207emO@80U9BD3@38h=P000/0b>3H0P1gMgL207alO080Ng]k0P2`/;02092@T080
OWin0P1kNg/307QhN080T92@0P1aLG4209bLW080I6AT0P20P80207alO080P8200P2;Rh/208f=S@80
R8R80P1lO7`208B4Q080QXJ60P1^KVh00`1mOGd0Rh^;08^;R`0208:2PP80QXJ60P2<S8`208N7Q`80
Lg=c0P21PH4208j>SP<0b>3H0P2KVi/207]kN`80/[:b0P1HF5P207inOP80RXZ:0P1@D5000`24Q8@0
E5AD05ADE00207=cL`80Ti>C0P0n?Sh207]kN`80TY:B0P1_Kfl207]kN`80Shn?0P1oOgl20861P@80
UYJF0P1aLG4207alO080KFe]00<0Q8B409NGU`2GUiL00P1XJ6P209JFUP80XJ6Q0P1PH60207AdM080
JVYZ0P1kNg/:0<SPf080U9BD0P24Q8@2061PH080QHF50P2<S8`209BDU0<0VIVI0P1HF5P20:>SX`80
R8R80P2MWId208J6QP80UIFE0P1lO7`208^;R`80HV9R0P2@T902075aL@80RHV90P24Q8@208N7Q`80
C4a<00<0OWin08V9R@29RHT00P1eMGD206m_K`80OGem0P1kNg/208Z:RP80MGEe0P22PX830<SPf080
JVYZ0P2GUiL208V9R@80IVIV0P2FUYH2092@T080^KVi00<0AdM705]KF`1KFe/00P1/K6`204M7A`80
OWin0P2FUYH207moO`80T92@0P25QHD208J6QP80KFe]0P1IFET20?ooo`80HV9R0P2QXJ4208j>SP03
09nOW`2=SHd0SHf=0080L71`0P2@T9020861P@80Xj>S0P1aLG4207emO@80U9BD3@38h=P000/0b>3H
0P1jNWX209bLW080Ti>C0P2EUID2061PH080MWIf0P2>SXh00`2DU9@0OWin07inOP0207emO@80X:2P
0P1nOWh209>CT`80O7al0P21PH4208R8R080P8200P2:RXX207=cL`80NGUi0P1mOGd208:2PP80IFEU
00<0SHf=07]kN`1kNg/00P28R8P208N7Q`80Q8B40P1fMWH207alO080Ng]k0P1eMGD30<SPf080Shn?
0P3IfMT209jNWP80Kfm_0P23Ph<207]kN`80FEUI00<0Kfm_08J6QP26QXH00P2JVYX207QhN080>c/k
0P22PX8209FEU@80LG5a0P1[Jf/207QhN0@0O7al0P1oOgl2092@T080Jf][0P1VIVH00`1jNWX0MWIf
07IfMP0408J6QP80OWin0P28R8P207emO@80N7Qh0P1[Jf/:0<SPf080MWIf0P2MWId204a<C080NWYj
0P1oOgl208B4Q080KVi^00<0BTY:08^;R`2;Rh/00P1ZJVX206=SH`80Ogmo0P2RXZ8209>CT`80Shn?
0P26QXH206e]K@80J6QX0P1kNg/206MWI`80PH610P23Ph<206UYJ@0307MgM`1nOWh0OWin0080MGEe
0P2QXJ4208n?S`80N7Qh0P26QXH208Z:RP80OWin0`38h=P20:^[Z`80WYjN0P2CTi<206i^KP80N7Qh
0P1GEeL208>3P`0307=cL`1KFe/0Fe]K0080BTY:0P27QhL2061PH080L71`0P2?Shl209ZJVP80Lg=c
0P1bLW8205mOG`80Jf][0P1PH602096AT@80J6QX0P26QXH00`2ATI40QHF508F5Q@02061PH080/;2`
0P2=SHd208b<S080UiNG0P28R8P209JFUPd0b>3H000;0<SPf080NWYj0P2LW9`209>CT`80UIFE0P1P
H60207IfMP80SXj>00<0U9BD07inOP1nOWh00P1mOGd20:2PX080OWin0P2CTi<207alO080PH610P28
R8P20820P080RXZ:0P1cLg<207UiN@80OGem0P22PX8206EUI@0308f=S@1kNg/0Ng]k0080R8R80P27
QhL208B4Q080MWIf0P1lO7`207]kN`80MGEe0`38h=P208n?S`80fMWI0P2NWYh206m_K`80Ph>30P1k
Ng/205UIF@0306m_K`26QXH0QXJ60080VYZJ0P1hN7P203/k>`80PX:20P2EUID2075aL@80Jf][0P1h
N7P407alO080Ogmo0P2@T90206][J`80IVIV00<0NWYj07IfMP1fMWH01026QXH207inOP80R8R80P1m
OGd207QhN080Jf][2P38h=P207IfMP80WIfM0P1<C4`207YjNP80Ogmo0P24Q8@206i^KP0304Y:BP2;
Rh/0Rh^;0080JVYZ0P1SHf<207moO`80XZ:R0P2CTi<208n?S`80QXJ60P1]KFd206QXJ080Ng]k0P1W
IfL20861P@80Ph>30P1YJFT00`1gMgL0OWin07inOP0207EeM@80XJ6Q0P2?Shl207QhN080QXJ60P2:
RXX207inOP<0b>3H0P2[Zj/209jNWP80Ti>C0P1^KVh207QhN080EeMG0P23Ph<00`1cLg<0Fe]K05]K
F`0204Y:BP80QhN70P1PH602071`L080Shn?0P2JVYX207=cL`80LW9b0P1OGel206][J`80H61P0P2A
TI4206QXJ080QXJ600<0TI6A08F5Q@25QHD00P1PH6020;2`/080SHf=0P2<S8`209NGU`80R8R80P2F
UYH=0<SPf0002`38h=P207QhN080KVi^0P2DU9@208R8R080MGEe0P2DU9@2079bLP0309nOW`2KVi/0
Vi^K0080GEeM0P1oOgl209FEU@80P8200P2IVIT208V9R@80LW9b0P23Ph<208N7Q`80PX:20P1lO7`2
07UiN@80MgMg0P2?Shl00`1hN7P0QHF508F5Q@0208F5Q@80OWin0P1iNGT20820P080O7al0P1iNGT2
07AdM0<0b>3H0P1;Bd/207YjNP80UIFE0P22PX82092@T080HF5Q0P1JFUX00`27QhL0Bd];04];B`02
0:NWY`80O7al0P1/K6`20;6a/@80PH610P1WIfL206UYJ@80RXZ:0P28R8P208:2PP80X:2P0P1iNGT2
08F5Q@80MWIf00<0Q8B407YjNP1jNWX00P26QXH207IfMP80RHV90P1gMgL209FEU@80LG5a0P29RHT:
0<SPf080J6QX0P2=SHd207EeM@80IfMW0P1jNWX208R8R080QHF500<0WIfM06IVIP1VIVH00P2:RXX2
08f=S@80YjNW1021PH4208>3P`80Kfm_0P2:RXX209>CT`80NWYj0P22PX8208Z:RP80OGem0P2DU9@0
0`1cLg<0R8R808R8R00209ZJVP80Ph>30P1gMgL207UiN@80PX:20P2ATI4207moO`<0b>3H0P2DU9@2
092@T080VYZJ0P26QXH209>CT`80NWYj0P1PH6000`1eMGD0W9bL09bLW00204A4A0@0IVIV0P2<S8`2
0;Fe]@80L71`0P1hN7P207AdM080Lg=c0P2OWil208Z:RP80WIfM0P0k>c/20861P@030820P01eMGD0
MGEe0080WIfM0P2HV9P205iNGP80M7Ad0P2PX:0207alO080P8203@38h=P000/0b>3H0P1WIfL209BD
U080Kfm_0P2TY:@207UiN@80LW9b0P1fMWH00`2ATI40OWin07inOP0208^;R`80SXj>0P2ATI420861
P@80WinO0P1nOWh207]kN`80QHF50P1kNg/2071`L080QXJ60P2<S8`207]kN`80Rh^;00<0QhN708>3
P`23Ph<00P21PH4207=cL`80Ph>30P1oOgl207]kN`80NWYj0P1mOGd30<SPf080BTY:0P25QHD206QX
J080GEeM0P28R8P208Z:RP80QHF500<0WinO06m_K`1_Kfl00P3Ti>@207=cL`80J6QX0P2d];@209FE
U@80PX:20P1YJFT208Z:RP80Lg=c0P22PX8207QhN080Ogmo0P27QhL2069RHP0308B4Q02<S8`0S8b<
0080PX:20P1lO7`208B4Q080QXJ60P25QHD207QhN080QhN72P38h=P208f=S@80IVIV0P2h^;P2061P
H080QXJ60P1oOgl20:BTY00306e]K@1?Cdl0Cdm?0080U9BD0P1MGEd208j>SP80QhN70P23Ph<206IV
IP80Shn?0P20P80208F5Q@80NWYj0P1lO7`207IfMP80LW9b0P2JVYX00`29RHT0Q8B408B4Q00208J6
QP80OGem0P28R8P208b<S080LG5a0P21PH4208N7Q`<0b>3H0P1IFET20;Jf]P80]kNg0P25QHD20:f]
[@80HV9R0P14A4@00`10@400;Bd]02d];@0207EeM@80IFEU0P0l?3`208B4Q080/[:b0P13@d<207mo
O`80WinO0P2?Shl208J6QP80WYjN0P2:RXX207QhN080Ogmo00<0V9RH08^;R`2;Rh/00P1/K6`208V9
R@80L71`0P2NWYh20820P080Rh^;0P1gMgL=0<SPf0002`38h=P206MWI`80U9BD0P1_Kfl20:BTY080
NGUi0P1bLW8207IfMP03096AT@1nOWh0OWin0080Rh^;0P2>SXh2096AT@80PH610P2OWil207inOP80
Ng]k0P25QHD207]kN`80L71`0P26QXH208b<S080Ng]k0P2;Rh/00`27QhL0Ph>308>3P`020861P@80
Lg=c0P23Ph<207moO`80Ng]k0P1jNWX207emO@<0b>3H0P1:BTX208F5Q@80J6QX0P1MGEd208R8R080
RXZ:0P25QHD00`2OWil0Kfm_06m_K`020>CTi080Lg=c0P1XJ6P20;Bd]080UIFE0P22PX8206UYJ@80
RXZ:0P1cLg<208:2PP80N7Qh0P1oOgl208N7Q`80HV9R00<0Q8B408b<S02<S8`00P22PX8207alO080
Q8B40P26QXH208F5Q@80N7Qh0P27QhL:0<SPf080SHf=0P1VIVH20;Rh^080H61P0P26QXH207moO`80
Y:BT00<0KFe]04m?C`1?Cdl00P2DU9@205eMG@80SXj>0P27QhL208>3P`80IVIV0P2?Shl20820P080
QHF50P1jNWX207alO080MWIf0P1bLW8209ZJVP0308V9R@24Q8@0Q8B40080QXJ60P1mOGd208R8R080
S8b<0P1aLG420861P@80QhN70`38h=P205UIF@80][Jf0P2g]kL208F5Q@80[Jf]0P1RHV8204A4A003
0410@00];Bd0;Bd]0080MGEe0P1UIFD203`l?080Q8B40P2b/[8204=3@`80Ogmo0P2OWil208n?S`80
QXJ60P2NWYh208Z:RP80N7Qh0P1oOgl00`2HV9P0Rh^;08^;R`0206a/K080RHV90P1`L70209jNWP80
P8200P2;Rh/207MgM`d0b>3H000;0<SPf080Ph>30P2FUYH206e]K@80RHV90P1oOgl207]kN`80Ph>3
00<0N7Qh06IVIP1VIVH00P1dM7@209JFUP80QhN70P1/K6`206EUI@80R8R80P1WIfL208n?S`80RHV9
0P1[Jf/207]kN`80SXj>0P1ZJVX206][J`<0NWYj0P27QhL20820P080QXJ60P22PX8207YjNP80OGem
0P1fMWH30<SPf080KFe]0P1SHf<406MWI`80NGUi0P21PH4207MgM`0306i^KP1:BTX0BTY:0080=CDe
0P1EEED207UiN@80`/;20P1nOWh2075aL@80WYjN0P1EEED206m_K`80OWin0P2QXJ4208b<S080I6AT
0P1[Jf/00`20P800TI6A096AT@0206][J`80M7Ad0P20P80208V9R@80Ng]k0P1[Jf/2065QH@X0b>3H
0P1JFUX208F5Q@80PH610P1OGel208Z:RP80OGem0P26QXH00`1nOWh0P8200820P00207YjNP80Q8B4
0P2EUID209BDU080EEEE0P2CTi<208Z:RP80S8b<0P1hN7P207=cL`80M7Ad0P27QhL2096AT@80Ph>3
00<0OWin0861P@21PH400P1dM7@207moO`80O7al0P20P80208>3P`80RHV90P1eMGD30<SPf080MGEe
0P19BDT208R8R080CDe=0P1VIVH208j>SP80[Jf]00<0UIFE04=3@`13@d<00P3AdM4204i>CP@0Rh^;
0P2UYJD206MWI`80EEEE0P16ATH208B4Q080Ng]k0P2HV9P409:BTP80Ph>300<0Vi^K0:2PX02PX:00
0P1hN7P206a/K080IfMW0P1oOgl209NGU`80Rh^;0P25QHD=0<SPf0002`38h=P208>3P`80UYJF0P1]
KFd208V9R@80Ogmo0P1kNg/208>3P`0307QhN01VIVH0IVIV0080M7Ad0P2FUYH208N7Q`80K6a/0P1U
IFD208R8R080IfMW0P2?Shl208V9R@80Jf][0P1kNg/208j>SP80JVYZ0P1[Jf/307YjNP80QhN70P20
P80208J6QP80PX:20P1jNWX207emO@80MWIf0`38h=P206e]K@80Hf=S101WIfL207UiN@80PH610P1g
MgL00`1^KVh0BTY:04Y:BP0203De=@80EEEE0P1iNGT20<;2`P80OWin0P1aLG4209jNWP80EEEE0P1_
Kfl207inOP80XJ6Q0P2<S8`206ATI080Jf][00<0P820096AT@2ATI400P1[Jf/207AdM080P8200P29
RHT207]kN`80Jf][0P1QHF4:0<SPf080FUYJ0P25QHD20861P@80GemO0P2:RXX207emO@80QXJ600<0
OWin0820P020P8000P1jNWX208B4Q080UIFE0P2DU9@205EEE@80Ti>C0P2:RXX208b<S080N7Qh0P1c
Lg<207AdM080QhN70P2ATI4208>3P`0307inOP21PH40PH610080M7Ad0P1oOgl207alO080P8200P23
Ph<208V9R@80MGEe0`38h=P207EeM@80BDU90P28R8P204e=C@80IVIV0P2>SXh20:f][@0309FEU@13
@d<0@d=30080dM7A0P1>CTh408^;R`80YJFU0P1WIfL205EEE@80ATI60P24Q8@207]kN`80V9RH102B
TY8208>3P`0309^KV`2PX:00X:2P0080N7Qh0P1/K6`206MWI`80Ogmo0P2GUiL208^;R`80QHF53@38
h=P000/0b>3H0P1/K6`208>3P`80MWIf0P25QHD2071`L080TI6A0P2NWYh00`1mOGd0Jf][06][J`02
0820P080G5aL0P27QhL208>3P`80RHV90P2EUID207MgM`80OGem0P28R8P208>3P`80QhN70P2;Rh/2
0861P@80QHF500<0QXJ608N7Q`27QhL00P1iNGT207MgM`80OWin0P24Q8@407]kN`80NWYj0`38h=P2
08:2PP80_[jn0P1dM7@208N7Q`80[jn_0P2EUID20:j^[P0305mOG`1QHF40HF5Q0080A4A40P1_Kfl2
04e=C@80LW9b0P1[Jf/2065QH@80JFUY0P2?Shl207moO`80K6a/0P28R8P20:>SX`80`L710P2CTi<0
0`1cLg<0PX:208:2PP0206UYJ@80Ph>30P2;Rh/207MgM`80Rh^;0P1lO7`208>3P`X0b>3H101gMgL2
08R8R080NGUi0P1`L70209ZJVP80QXJ600<0M7Ad06QXJ01XJ6P00P1_Kfl207alO080QHF50P1mOGd2
08R8R080OWin0P2JVYX204A4A080OWin0P1cLg<208F5Q@80Ng]k0P25QHD208n?S`0306a/K026QXH0
QXJ60080QhN70P2ATI4208:2PP80P8200P2:RXX408:2PP<0b>3H0P3MgMd208J6QP80SHf=0P1[Jf/2
05ADE080Vi^K0P3IfMT00`25QHD0>CTi03Ti>@0205ADE080B4Q80P2ATI420:>SX`80HF5Q0P1<C4`2
0;Ng]`80UYJF0P2i^KT207UiN@80Ti>C0P1ZJVX209fMW@80RHV900<0N7Qh08^;R`2;Rh/00P1@D502
075aL@80Ng]k0P1oOgl209BDU080ZZZZ0P1jNWX=0<SPf0002`38h=P206a/K080Ph>30P1fMWH208F5
Q@80L71`0P2ATI4209jNWP0307emO@1[Jf/0Jf][0080P8200P1LG5`208N7Q`80Ph>30P29RHT209FE
U@80MgMg0P1mOGd208R8R080Ph>30P27QhL208^;R`80PH610P25QHD00`26QXH0QhN708N7Q`0207Ui
N@80MgMg0P1nOWh208B4Q0@0Ng]k0P1jNWX30<SPf080PX:20P2n_[h207AdM080QhN70P2_[jl209FE
U@80[Zj^00<0GemO065QH@1QHF400P14A4@206m_K`80CDe=0P1bLW8206][J`80HF5Q0P1YJFT208n?
S`80Ogmo0P1/K6`208R8R080Xj>S0P31`L4209>CT`0307=cL`22PX80PX:20080JFUY0P23Ph<208^;
R`80MgMg0P2;Rh/207alO080Ph>32P38h=P407MgM`80R8R80P1iNGT2071`L080VYZJ0P26QXH00`1d
M7@0J6QX06QXJ00206m_K`80O7al0P25QHD207emO@80R8R80P1nOWh209ZJVP80A4A40P1nOWh207=c
L`80QHF50P1kNg/208F5Q@80Shn?00<0K6a/08J6QP26QXH00P27QhL2096AT@80PX:20P20P80208Z:
RP@0PX:20`38h=P20=gMg@80QXJ60P2=SHd206][J`80E5AD0P2KVi/20=WIf@0308F5Q@0i>CT0>CTi
0080E5AD0P18B4P2096AT@80Xj>S0P1QHF4204a<C080]kNg0P2FUYH20;Vi^@80NGUi0P2CTi<206YZ
JP80WIfM0P29RHT00`1hN7P0Rh^;08^;R`02051@D080LG5a0P1kNg/207moO`80U9BD0P2ZZZX207Yj
NPd0b>3H000;0<SPf080Ogmo0P1hN7P209FEU@80SHf=0P1gMgL208F5Q@80KVi^00<0Jf][08:2PP22
PX800P1[Jf/208n?S`80R8R80P1WIfL2096AT@80OWin0P1kNg/207MgM`80PH610P1dM7@208^;R`80
QHF50P1cLg<20820P00307EeM@1nOWh0OWin0080QXJ61028R8P207moO`80NWYj0P22PX8207YjNP<0
b>3H0P2=SHd2092@T080Shn?0P1jNWX20861P@80GemO0P1nOWh00`1CDe<0Rh^;08^;R`0206][J`80
I6AT0P1kNg/409jNWP80M7Ad0P2VYZH205mOG`80_;bl0P2QXJ4207QhN080J6QX0P2<S8`208V9R@03
07]kN`24Q8@0Q8B40080MWIf0P2KVi/408>3P`80Shn?0P1UIFD208>3P`X0b>3H0P20P80208n?S`80
V9RH0P2>SXh206YZJP80UiNG0P1jNWX00`2OWil0JVYZ06YZJP0206e]K@80I6AT0P22PX8205iNGP80
R8R80P1LG5`207EeM@80OWin0P21PH4208n?S`80QXJ60P2>SXh407alO00307MgM`25QHD0QHF50080
Shn?0P21PH4207inOP80MWIf0P1kNg/207AdM080NWYj0`38h=P20;Fe]@80?clo0P1nOWh209ZJVP80
PX:20P2BTY8208^;R`0307emO@1dM7@0M7Ad0080De=C0P31`L4204I6AP80H61P0P2RXZ8203lo?`80
IfMW0P1jNWX204M7A`80JVYZ0P2LW9`206UYJ@80QHF50P1mOGd00`2l_;`0UYJF09JFUP0208>3P`80
H61P0P21PH4208b<S080OWin0P2EUID208>3P`d0b>3H000;0<SPf080Ogmo0P1hN7P209FEU@80SHf=
0P1gMgL208F5Q@80KVi^00<0Jf][08:2PP22PX800P1[Jf/208n?S`80R8R80P1WIfL2096AT@80OWin
0P1kNg/207MgM`80PH610P1dM7@208^;R`80QHF50P1cLg<20820P00307EeM@1nOWh0OWin0080QXJ6
1028R8P207moO`80NWYj0P22PX8207YjNP<0b>3H0P2=SHd2092@T080Shn?0P1jNWX20861P@80GemO
0P1nOWh00`1CDe<0Rh^;08^;R`0206][J`80I6AT0P1kNg/409jNWP80M7Ad0P2VYZH205mOG`80_;bl
0P2QXJ4207QhN080J6QX0P2<S8`208V9R@0307]kN`24Q8@0Q8B40080MWIf0P2KVi/408>3P`80Shn?
0P1UIFD208>3P`X0b>3H0P20P80208n?S`80V9RH0P2>SXh206YZJP80UiNG0P1jNWX00`2OWil0JVYZ
06YZJP0206e]K@80I6AT0P22PX8205iNGP80R8R80P1LG5`207EeM@80OWin0P21PH4208n?S`80QXJ6
0P2>SXh407alO00307MgM`25QHD0QHF50080Shn?0P21PH4207inOP80MWIf0P1kNg/207AdM080NWYj
0`38h=P20;Fe]@80?clo0P1nOWh209ZJVP80PX:20P2BTY8208^;R`0307emO@1dM7@0M7Ad0080De=C
0P31`L4204I6AP80H61P0P2RXZ8203lo?`80IfMW0P1jNWX204M7A`80JVYZ0P2LW9`206UYJ@80QHF5
0P1mOGd00`2l_;`0UYJF09JFUP0208>3P`80H61P0P21PH4208b<S080OWin0P2EUID208>3P`d0b>3H
000;0<SPf080MWIf0P1NGUh208J6QP80OGem0P22PX8207inOP80HV9R00<0QXJ608:2PP22PX800P2;
Rh/208B4Q080LW9b0P2;Rh/207YjNP80Ogmo0P1fMWH209JFUP80PX:20P24Q8@20820P080Shn?0P27
QhL207=cL`0308f=S@1gMgL0MgMg0080RXZ:0P1lO7`208Z:RP80LW9b0P22PX8207QhN080MWIf0`38
h=P209BDU080MGEe0P1GEeL20861P@80SXj>0P2=SHd205IFEP0308>3P`34a<@0a<C40080ZJVY0P2m
_Kd208J6QP80?Shn0P2;Rh/208V9R@80H61P0P2b/[8208B4Q080Y:BT0P1]KFd207MgM`80H61P0P28
R8P00`1EEED0MGEe07EeM@0205eMG@80NWYj0P1[Jf/207YjNP80OWin0P1TI6@205iNGPX0b>3H0P2>
SXh206][J`80QHF50P1aLG4208^;R`80Ph>30P26QXH00`2KVi/0MWIf07IfMP02092@T080MgMg0P1e
MGD209nOW`80Ph>30P1lO7`207EeM@80M7Ad0P1bLW82071`L080PH610P23Ph<207alO080R8R800<0
QHF509BDU02DU9@00P1hN7P208j>SP80OWin0P1]KFd20820P080QXJ60P1[Jf/30<SPf080D51@0P23
Ph<209nOW`80NWYj0P2GUiL206YZJP80QXJ600<0Vi^K0861P@21PH400P2CTi<20;6a/@80V9RH0P2=
SHd209JFUP80]kNg0P1JFUX204e=C@80Ogmo0P17AdL20:RXZ080];Bd0P2QXJ4205mOG`0308b<S01m
OGd0OGem0080Ogmo0P1dM7@209VIV@80[:b/0P2LW9`207AdM080O7al3@38h=P000/0b>3H0P1fMWH2
05iNGP80QXJ60P1mOGd208:2PP80OWin0P1RHV800`26QXH0PX:208:2PP0208^;R`80Q8B40P1bLW82
08^;R`80NWYj0P1oOgl207IfMP80UYJF0P22PX8208B4Q080P8200P2?Shl208N7Q`80Lg=c00<0SHf=
07MgM`1gMgL00P2:RXX207alO080RXZ:0P1bLW8208:2PP80N7Qh0P1fMWH30<SPf080U9BD0P1eMGD2
05MGE`80PH610P2>SXh208f=S@80EUIF00<0Ph>30<C4a034a<@00P2YZJT20;fm_@80QXJ60P0n?Sh2
08^;R`80RHV90P1PH6020;:b/P80Q8B40P2TY:@206e]K@80MgMg0P1PH60208R8R00305EEE@1eMGD0
MGEe0080GEeM0P1jNWX206][J`80NWYj0P1nOWh206ATI080GUiN2P38h=P208j>SP80Jf][0P25QHD2
075aL@80Rh^;0P23Ph<208J6QP0309^KV`1fMWH0MWIf0080T92@0P1gMgL207EeM@80WinO0P23Ph<2
07alO080MGEe0P1dM7@2079bLP80L71`0P21PH4208>3P`80O7al0P28R8P00`25QHD0U9BD09BDU002
07QhN080SXj>0P1nOWh206e]K@80P8200P26QXH206][J`<0b>3H0P1@D50208>3P`80WinO0P1jNWX2
09NGU`80JVYZ0P26QXH00`2KVi/0PH610861P@0209>CT`80/K6a0P2HV9P208f=S@80UYJF0P2g]kL2
05YJFP80CDe=0P1oOgl204M7A`80Z:RX0P2d];@20:6QX@80GemO00<0S8b<07emO@1mOGd00P1oOgl2
07AdM080VIVI0P2/[:`209bLW080M7Ad0P1lO7`=0<SPf0002`38h=P206][J`80Ph>30P1]KFd2071`
L080Ogmo0P29RHT207inOP<0NGUi0P1aLG420:BTY0@0LG5a0P1fMWH208R8R080OGem0P1gMgL208:2
PP80Ogmo0P1hN7P206i^KP80LW9b0P1YJFT00`20P800QXJ608J6QP0207=cL`80QHF50P2:RXX207=c
L`80PX:20P25QHD206][J`<0b>3H0P1YJFT20<71`@80QXJ60P1aLG4208:2PP80Ph>30P2UYJD00`26
QXH0Rh^;08^;R`0209bLW080DU9B0P1GEeL208Z:RP80SXj>0P23Ph<206m_K`80Vi^K0P2UYJD205=C
D`80N7Qh0P2;Rh/206e]K@80OGem00<0NGUi07EeM@1eMGD00P1ZJVX208Z:RP80MWIf0P1^KVh208j>
SP80MgMg0P1lO7`:0<SPf080Lg=c0P2;Rh/20:JVYP80RXZ:0P25QHD207MgM`80T92@00<0PH6106MW
I`1WIfL00P1hN7P209:BTP80JVYZ0P2MWId20:JVYP80Shn?0P21PH4207UiN@80S8b<0P20P80207]k
N`80Vi^K0P2GUiL206e]K@0308Z:RP1aLG40LG5a0080PX:20P1kNg/208Z:RP80TY:B0P22PX8206a/
K080JFUY0`38h=P205eMG@80ZZZZ0P1gMgL205mOG`80X:2P0P1ZJVX209:BTP0304a<C02i^KT0^KVi
0080NGUi0P1IFET2069RHP80Ng]k0P2VYZH208n?S`80Kfm_0P24Q8@202l_;`80K6a/0P2h^;P208j>
SP80Rh^;0P1bLW800`2CTi<0JFUY06UYJ@0206][J`80LW9b0P2EUID209fMW@80U9BD0P2>SXh209RH
V0d0b>3H000;0<SPf080Jf][0P23Ph<206e]K@80L71`0P1oOgl208V9R@80OWin0`1iNGT2075aL@80
Y:BT101aLG4207IfMP80R8R80P1mOGd207MgM`80PX:20P1oOgl207QhN080KVi^0P1bLW8206UYJ@03
0820P026QXH0QXJ60080Lg=c0P25QHD208Z:RP80Lg=c0P22PX8208F5Q@80Jf][0`38h=P206UYJ@80
`L710P26QXH2075aL@80PX:20P23Ph<20:FUY@0308J6QP2;Rh/0Rh^;0080W9bL0P1BDU8205MGE`80
RXZ:0P2>SXh208>3P`80Kfm_0P2KVi/20:FUY@80De=C0P1hN7P208^;R`80KFe]0P1mOGd00`1iNGT0
MGEe07EeM@0206YZJP80RXZ:0P1fMWH206i^KP80SXj>0P1gMgL207alO0X0b>3H0P1cLg<208^;R`80
YZJV0P2:RXX208F5Q@80MgMg0P2@T9000`21PH40IfMW06MWI`0207QhN080TY:B0P1ZJVX209fMW@80
YZJV0P2?Shl20861P@80NGUi0P2<S8`20820P080Ng]k0P2KVi/209NGU`80KFe]00<0RXZ:075aL@1a
LG400P22PX8207]kN`80RXZ:0P2BTY8208:2PP80K6a/0P1YJFT30<SPf080GEeM0P2ZZZX207MgM`80
GemO0P2PX:0206YZJP80TY:B00<0C4a<0;Vi^@2i^KT00P1iNGT205UIF@80HV9R0P1kNg/20:JVYP80
Shn?0P1_Kfl208B4Q080;bl_0P1/K6`20;Rh^080SXj>0P2;Rh/2079bLP0309>CT`1YJFT0JFUY0080
Jf][0P1bLW8209FEU@80WIfM0P2DU9@208j>SP80V9RH3@38h=P000/0b>3H0P1fMWH207emO@80I6AT
101kNg/208R8R080RHV900<0UiNG09>CT`2CTi<00P22PX8207YjNP80UYJF0P1[Jf/207moO`80O7al
101kNg/208V9R@80LG5a0P2WYjL207EeM@80OWin0P20P8000`24Q8@0P8200820P00208:2PP80Rh^;
1025QHD208V9R@80NWYj0P20P8030<SPf080_Kfm0P2@T90206YZJP80/;2`0P1OGel208B4Q080P820
00<0Ng]k05QHF01HF5P00P1jNWX209bLW080QHF50P1YJFT208F5Q@80M7Ad0P1NGUh408J6QP80L71`
0P21PH4208n?S`80[jn_0P2=SHd308F5Q@80T92@0P20P80207alO080NGUi0P2;Rh/2096AT@80N7Qh
2P38h=P209NGU`80U9BD0P1cLg<208B4Q080PX:20P1/K6`208J6QP0307alO01RHV80HV9R0080Ti>C
0P2BTY8209jNWP80MgMg0P1]KFd208:2PP80LG5a0P1lO7`2069RHP80EEEE0P1bLW8207inOP80K6a/
0P2;Rh/00`1eMGD0QXJ608J6QP0208F5Q@80PX:20P23Ph<208V9R@80Q8B40P1oOgl206YZJP<0b>3H
0P2^[Zh207IfMP80I6AT0P1RHV8208b<S080SXj>0P1HF5P00`00000092@T02@T9002092@T080Hf=S
0P2@T90204Q8B080f=SH0P15ADD207inOP80YjNW0P0000020=SHf080Ng]k0P1EEED204E5A@80RXZ:
00<0Kfm_08:2PP22PX800P2ATI4207QhN080JVYZ0P1QHF4206e]K@80NWYj0P25QHD=0<SPf0002`38
h=P207IfMP80OGem0P1TI6@407]kN`80R8R80P29RHT00`2GUiL0Ti>C09>CT`0208:2PP80NWYj0P2F
UYH206][J`80Ogmo0P1lO7`407]kN`80RHV90P1aLG420:NWY`80MGEe0P1nOWh20820P00308B4Q020
P800P8200080PX:20P2;Rh/408F5Q@80RHV90P1jNWX20820P0<0b>3H0P2m_Kd2092@T080JVYZ0P2`
/;0205mOG`80Q8B40P20P8000`1kNg/0F5QH05QHF00207YjNP80W9bL0P25QHD206UYJ@80QHF50P1d
M7@205iNGP@0QXJ60P1`L7020861P@80Shn?0P2_[jl208f=S@<0QHF50P2@T9020820P080O7al0P1i
NGT208^;R`80TI6A0P1hN7P:0<SPf080UiNG0P2DU9@207=cL`80Q8B40P22PX8206a/K080QXJ600<0
O7al069RHP1RHV800P2CTi<209:BTP80WYjN0P1gMgL206e]K@80PX:20P1aLG4207alO080HV9R0P1E
EED2079bLP80OWin0P1/K6`208^;R`0307EeM@26QXH0QXJ60080QHF50P22PX8208>3P`80RHV90P24
Q8@207moO`80JVYZ0`38h=P20:j^[P80MWIf0P1TI6@2069RHP80S8b<0P2>SXh205QHF0030000000T
92@092@T0080T92@0P1SHf<2092@T080B4Q80P3Hf=P204E5A@80OWin0P2WYjL200000080f=SH0P1k
Ng/205EEE@80ADE50P2:RXX00`1_Kfl0PX:208:2PP02096AT@80N7Qh0P1ZJVX2065QH@80KFe]0P1j
NWX208F5Q@d0b>3H003o0<SPf240b>3H003o0<SPf240b>3H003o0<SPf240b>3H000;0<SPf080YJFU
0P2OWil209bLW080VIVI0P2BTY8209nOW`80[:b/00<0W9bL096AT@2ATI400P2][Jd208b<S080ZZZZ
0P2;Rh/209>CT`80R8R80P29RHT208R8R080QHF50P28R8P208b<S080RHV90P24Q8@208n?S`0308B4
Q02:RXX0RXZ:0080Rh^;0P2:RXX208b<S080QhN70P23Ph<209^KV`80UYJF0`38h=P207AdM080OGem
0P1iNGT209fMW@80MgMg0P26QXH206UYJ@0307]kN`1_Kfl0Kfm_0080MGEe0P20P80207YjNP80Ng]k
0P2:RXX208B4Q080P820101kNg/208:2PP80RHV90P1fMWH208V9R@80M7Ad00<0Q8B407emO@1mOGd0
0P24Q8@207YjNP80Ng]k0P24Q8@20861P@80OWin0P20P80:0<SPf080Xj>S0P3=cLd20:BTY080UiNG
0P2UYJD208b<S080WinO00<0RHV909BDU02DU9@00P2ATI4208V9R@80UiNG0P2:RXX4092@T080VIVI
0P26QXH208B4Q080SXj>0P28R8P408f=S@80R8R800<0Ph>308F5Q@25QHD00P2@T90208^;R`80TI6A
0P2<S8`209:BTP80SXj>0P2;Rh/30<SPf080UYJF0P2EUID204m?C`80VIVI0P1YJFT2096AT@80M7Ad
00<0NWYj0861P@21PH400P2?Shl207alO080QXJ60P1^KVh207MgM`80OWin0P1eMGD207IfMP80RHV9
0P2:RXX207emO@80OWin0P1cLg<208V9R@0308>3P`26QXH0QXJ60080KVi^0P1mOGd206i^KP80S8b<
0P20P80207]kN`80PH613@38h=P000/0b>3H0P2UYJD209nOW`80W9bL0P2IVIT209:BTP80WinO0P2/
[:`00`2LW9`0TI6A096AT@020:f][@80S8b<0P2ZZZX208^;R`80Ti>C0P28R8P208V9R@80R8R80P25
QHD208R8R080S8b<0P29RHT208B4Q080Shn?00<0Q8B408Z:RP2:RXX00P2;Rh/208Z:RP80S8b<0P27
QhL208>3P`80Vi^K0P2FUYH30<SPf080M7Ad0P1mOGd207UiN@80WIfM0P1gMgL208J6QP80JFUY00<0
Ng]k06m_K`1_Kfl00P1eMGD20820P080NWYj0P1kNg/208Z:RP80Q8B40P20P80407]kN`80PX:20P29
RHT207IfMP80RHV90P1dM7@00`24Q8@0OGem07emO@0208B4Q080NWYj0P1kNg/208B4Q080PH610P1n
OWh20820P0X0b>3H0P2SXj<20<g=c@80Y:BT0P2GUiL20:FUY@80S8b<0P2OWil00`29RHT0U9BD09BD
U002096AT@80RHV90P2GUiL208Z:RP@0T92@0P2IVIT208J6QP80Q8B40P2>SXh208R8R0@0SHf=0P28
R8P00`23Ph<0QHF508F5Q@02092@T080Rh^;0P2ATI4208b<S080TY:B0P2>SXh208^;R`<0b>3H0P2F
UYH209FEU@80Cdm?0P2IVIT206UYJ@80TI6A0P1dM7@00`1jNWX0PH610861P@0208n?S`80O7al0P26
QXH206i^KP80MgMg0P1nOWh207EeM@80MWIf0P29RHT208Z:RP80OGem0P1nOWh207=cL`80RHV900<0
Ph>308J6QP26QXH00P1^KVh207emO@80KVi^0P2<S8`20820P080Ng]k0P21PH4=0<SPf0002`38h=P2
08n?S`80ZJVY0P2IVIT208N7Q`80Rh^;0P29RHT209ZJVP0309nOW`2<S8`0S8b<0080Xj>S0P2@T902
09JFUP80Ph>30P2:RXX208N7Q`80R8R80P2<S8`208Z:RP80SXj>0P2:RXX208^;R`80RXZ:0P28R8P0
0`22PX80Rh^;08^;R`0208N7Q`80R8R80P2:RXX208R8R080RXZ:0P2GUiL209>CT`<0b>3H0P1eMGD2
06][J`80Ogmo0P1`L702075aL@80Ph>30P1lO7`00`1gMgL0Ph>308>3P`0207IfMP80PX:20P23Ph<2
07emO@80NGUi0P23Ph<20861P@80P8200P21PH4207moO`80Ph>30P21PH4208>3P`80Q8B400<0NGUi
07QhN01hN7P00P22PX8207moO`80Ng]k0P27QhL20861P@80TI6A0P28R8P:0<SPf080[Zj^0P2LW9`2
0;^k^`80Shn?0P2QXJ4208J6QP80SXj>00<0S8b<08f=S@2=SHd00P2<S8`208f=S@80Rh^;0P29RHT2
08n?S`80Rh^;0P2CTi<208j>SP80Ti>C0P2;Rh/208j>SP@0RHV90P28R8P00`2BTY80RHV908V9R@02
08b<S080R8R80P25QHD2092@T080SXj>0P28R8P208F5Q@<0b>3H0P1oOgl2096AT@80?clo0P2LW9`2
0861P@80Ogmo0P20P8000`23Ph<0Q8B408B4Q00208>3P`80PX:20P25QHD208^;R`80KVi^0P1_Kfl2
0861P@80MWIf0P26QXH208Z:RP80SHf=0P1nOWh207emO@80RXZ:00<0PX:207inOP1nOWh00P1nOWh2
08>3P`80NWYj0P27QhL208B4Q080O7al0P1oOgl=0<SPf0002`38h=P208n?S`80ZJVY0P2IVIT208N7
Q`80Rh^;0P29RHT209ZJVP0309nOW`2<S8`0S8b<0080Xj>S0P2@T90209JFUP80Ph>30P2:RXX208N7
Q`80R8R80P2<S8`208Z:RP80SXj>0P2:RXX208^;R`80RXZ:0P28R8P00`22PX80Rh^;08^;R`0208N7
Q`80R8R80P2:RXX208R8R080RXZ:0P2GUiL209>CT`<0b>3H0P1eMGD206][J`80Ogmo0P1`L702075a
L@80Ph>30P1lO7`00`1gMgL0Ph>308>3P`0207IfMP80PX:20P23Ph<207emO@80NGUi0P23Ph<20861
P@80P8200P21PH4207moO`80Ph>30P21PH4208>3P`80Q8B400<0NGUi07QhN01hN7P00P22PX8207mo
O`80Ng]k0P27QhL20861P@80TI6A0P28R8P:0<SPf080[Zj^0P2LW9`20;^k^`80Shn?0P2QXJ4208J6
QP80SXj>00<0S8b<08f=S@2=SHd00P2<S8`208f=S@80Rh^;0P29RHT208n?S`80Rh^;0P2CTi<208j>
SP80Ti>C0P2;Rh/208j>SP@0RHV90P28R8P00`2BTY80RHV908V9R@0208b<S080R8R80P25QHD2092@
T080SXj>0P28R8P208F5Q@<0b>3H0P1oOgl2096AT@80?clo0P2LW9`20861P@80Ogmo0P20P8000`23
Ph<0Q8B408B4Q00208>3P`80PX:20P25QHD208^;R`80KVi^0P1_Kfl20861P@80MWIf0P26QXH208Z:
RP80SHf=0P1nOWh207emO@80RXZ:00<0PX:207inOP1nOWh00P1nOWh208>3P`80NWYj0P27QhL208B4
Q080O7al0P1oOgl=0<SPf0002`38h=P20:FUY@80W9bL0P2NWYh209ZJVP@0S8b<0P2GUiL00`29RHT0
TY:B09:BTP020:f][@80XZ:R0P2JVYX208B4Q080S8b<1027QhL208F5Q@80SXj>0P27QhL20861P@80
QhN70P2<S8`208J6QP0308B4Q02<S8`0S8b<0080Ph>30P27QhL208F5Q@80QhN70P21PH4208V9R@80
WIfM0`38h=P208Z:RP80R8R80P2<S8`2071`L080QHF50P1mOGd208n?S`0307inOP2DU9@0U9BD0080
Ng]k0P2HV9P407]kN`80S8b<0P23Ph<208B4Q080Ph>30P1lO7`207emO@80QXJ60P1cLg<208V9R@80
R8R800<0NWYj07moO`1oOgl00P23Ph<20861P@80PX:20P1jNWX208>3P`80OGem0P1/K6`:0<SPf080
Shn?0P29RHT20:f][@80][Jf102>SXh20:JVYP0308V9R@2DU9@0U9BD0080RXZ:102GUiL208j>SPH0
RXZ:0P2<S8`208J6QP80SHf=0P2>SXh2096AT@80RHV90P2ATI400`21PH40Rh^;08^;R`0208B4Q0@0
RXZ:0P27QhL208f=S@80Rh^;0P26QXH30<SPf080WYjN0P2?Shl205IFEP80Rh^;0P1_Kfl208f=S@80
E5AD00<0ZJVY07EeM@1eMGD00P2<S8`208:2PP80RHV90P1hN7P208>3P`80OGem0P1lO7`206][J`@0
MgMg0P1mOGd208>3P`80MgMg0P1kNg/00`23Ph<0RHV908V9R@0208:2PP80OGem0P24Q8@207YjNP80
PH610P24Q8@207emO@d0b>3H000;0<SPf080YJFU0P2LW9`209jNWP80VYZJ102<S8`209NGU`0308V9
R@2BTY80TY:B0080[Jf]0P2RXZ8209ZJVP80Q8B40P2<S8`408N7Q`80QHF50P2>SXh208N7Q`80PH61
0P27QhL208b<S080QXJ600<0Q8B408b<S02<S8`00P23Ph<208N7Q`80QHF50P27QhL20861P@80RHV9
0P2MWId30<SPf080RXZ:0P28R8P208b<S080L71`0P25QHD207emO@80Shn?00<0OWin09BDU02DU9@0
0P1kNg/209RHV0@0Ng]k0P2<S8`208>3P`80Q8B40P23Ph<207alO080OGem0P26QXH207=cL`80RHV9
0P28R8P00`1jNWX0Ogmo07moO`0208>3P`80PH610P22PX8207YjNP80Ph>30P1mOGd206a/K0X0b>3H
0P2?Shl208V9R@80[Jf]0P2f][H408j>SP80YZJV00<0RHV909BDU02DU9@00P2:RXX409NGU`80SXj>
1P2:RXX208b<S080QXJ60P2=SHd208j>SP80TI6A0P29RHT2096AT@030861P@2;Rh/0Rh^;0080Q8B4
102:RXX208N7Q`80SHf=0P2;Rh/208J6QP<0b>3H0P2NWYh208n?S`80EUIF0P2;Rh/206m_K`80SHf=
0P1DE5@00`2YZJT0MGEe07EeM@0208b<S080PX:20P29RHT207QhN080Ph>30P1mOGd207alO080Jf][
101gMgL207emO@80Ph>30P1gMgL207]kN`0308>3P`29RHT0RHV90080PX:20P1mOGd208B4Q080NWYj
0P21PH4208B4Q080OGem3@38h=P000/0b>3H0P2[Zj/209FEU@80WYjN0P2KVi/209:BTP80QXJ60P2A
TI400`2EUID0TI6A096AT@0209jNWP80YjNW0P2@T90208:2PP80RHV90P21PH4208N7Q`80RXZ:0P2;
Rh/208V9R@80QhN70P28R8P208b<S080SHf=00<0QHF508Z:RP2:RXX00P27QhL208V9R@80S8b<0P27
QhL208n?S`80R8R80P2BTY830<SPf080QhN70P1aLG4208N7Q`80GemO0P2DU9@207moO`80PX:200<0
NWYj06i^KP1^KVh00P1]KFd208R8R080Q8B41026QXH208B4Q080NGUi0P25QHD207MgM`80QHF50P1h
N7P207EeM@80Ogmo0P1eMGD00`27QhL0MGEe07EeM@0208Z:RP80PX:20P25QHD208:2PP80QhN70P1o
Ogl208:2PPX0b>3H0P2_[jl20:f][@80XJ6Q0P2TY:@20;2`/080S8b<0P2[Zj/00`2WYjL0TY:B09:B
TP0209^KV`80SHf=102>SXh208^;R`80RHV90P2GUiL208f=S@80QhN70P2CTi<208j>SP80QhN70P29
RHT208B4Q00308b<S02=SHd0SHf=0080TI6A0P2=SHd208V9R@80UYJF0P2:RXX408F5Q@<0b>3H0P26
QXH20:VYZ@80TY:B0P1eMGD20410@080R8R80P1RHV800`2ATI40SXj>08j>SP0208f=S@80NGUi0P1h
N7P206YZJP80Rh^;0P1dM7@207YjNP80R8R80P1aLG4206m_K`80NGUi0P23Ph<207]kN`80PH6100<0
PX:207IfMP1fMWH00P1mOGd207inOP80Q8B40P25QHD208N7Q`80Ng]k0P20P80=0<SPf0002`38h=P2
0:^[Z`80UIFE0P2NWYh209^KV`80TY:B0P26QXH2096AT@0309FEU@2ATI40TI6A0080WYjN0P2WYjL2
092@T080PX:20P29RHT20861P@80QhN70P2:RXX208^;R`80RHV90P27QhL208R8R080S8b<0P2=SHd0
0`25QHD0RXZ:08Z:RP0208N7Q`80RHV90P2<S8`208N7Q`80Shn?0P28R8P209:BTP<0b>3H0P27QhL2
075aL@80QhN70P1OGel209BDU080Ogmo0P22PX800`1jNWX0KVi^06i^KP0206e]K@80R8R80P24Q8@4
08J6QP80Q8B40P1iNGT208F5Q@80MgMg0P25QHD207QhN080MGEe0P1oOgl207EeM@0308N7Q`1eMGD0
MGEe0080RXZ:0P22PX8208F5Q@80PX:20P27QhL207moO`80PX:22P38h=P20:n_[`80[Jf]0P2QXJ42
0:BTY080/;2`0P2<S8`20:^[Z`030:NWY`2BTY80TY:B0080Vi^K0P2=SHd408j>SP80Rh^;0P29RHT2
09NGU`80SHf=0P27QhL209>CT`80SXj>0P27QhL208V9R@80Q8B400<0S8b<08f=S@2=SHd00P2ATI42
08f=S@80RHV90P2FUYH208Z:RP@0QHF50`38h=P208J6QP80ZJVY0P2BTY8207EeM@80@4100P28R8P2
069RHP03096AT@2>SXh0SXj>0080SHf=0P1iNGT207QhN080JVYZ0P2;Rh/207AdM080NWYj0P28R8P2
075aL@80Kfm_0P1iNGT208>3P`80Ng]k0P21PH400`22PX80MWIf07IfMP0207emO@80OWin0P24Q8@2
08F5Q@80QhN70P1kNg/20820P0d0b>3H000;0<SPf080SXj>0P2OWil208^;R`80TI6A0P2KVi/208F5
Q@80RHV900<0S8b<09FEU@2EUID00P2FUYH2092@T080SXj>102<S8`208B4Q080R8R80P29RHT208J6
QP80R8R80P27QhL208V9R@80SXj>0P2:RXX00`29RHT0QHF508F5Q@0208J6QP80PX:20P29RHT408N7
Q`80RHV90P27QhL30<SPf080S8b<0P26QXH207QhN080M7Ad101mOGd208:2PP0307QhN02IVIT0VIVI
0080OWin0P21PH4208Z:RP80SHf=0P28R8P207moO`80Q8B40P21PH4207YjNP80PH610P1gMgL208Z:
RP80Ogmo0P24Q8@00`1kNg/0QXJ608J6QP0207=cL`80S8b<0P2CTi<207]kN`80OWin0P1jNWX207Qh
N0X0b>3H0P2HV9P209NGU`80T92@0P2=SHd20;jn_P80P8200P2CTi<00`28R8P0Ti>C09>CT`0208b<
S080TI6A0P2BTY8209BDU080SXj>0P2;Rh/208B4Q080QHF50P2@T902096AT@80Rh^;0P2BTY8208^;
R`80RXZ:00<0QXJ608V9R@29RHT00P2GUiL408Z:RP80R8R80P2ATI4208f=S@80SXj>0`38h=P208>3
P`80SHf=0P1_Kfl207inOP80F5QH0P2SXj<207]kN`0307inOP1^KVh0KVi^0080QhN70P1kNg/206QX
J080Ph>30P1kNg/207emO@80R8R80P26QXH208j>SP80Lg=c0P21PH4208R8R080P8200P1hN7P00`20
P800MGEe07EeM@0209FEU@80Q8B40P2;Rh/2096AT@80NGUi0P1jNWX206m_K`d0b>3H000;0<SPf080
SXj>0P2OWil208^;R`80TI6A0P2KVi/208F5Q@80RHV900<0S8b<09FEU@2EUID00P2FUYH2092@T080
SXj>102<S8`208B4Q080R8R80P29RHT208J6QP80R8R80P27QhL208V9R@80SXj>0P2:RXX00`29RHT0
QHF508F5Q@0208J6QP80PX:20P29RHT408N7Q`80RHV90P27QhL30<SPf080S8b<0P26QXH207QhN080
M7Ad101mOGd208:2PP0307QhN02IVIT0VIVI0080OWin0P21PH4208Z:RP80SHf=0P28R8P207moO`80
Q8B40P21PH4207YjNP80PH610P1gMgL208Z:RP80Ogmo0P24Q8@00`1kNg/0QXJ608J6QP0207=cL`80
S8b<0P2CTi<207]kN`80OWin0P1jNWX207QhN0X0b>3H0P2HV9P209NGU`80T92@0P2=SHd20;jn_P80
P8200P2CTi<00`28R8P0Ti>C09>CT`0208b<S080TI6A0P2BTY8209BDU080SXj>0P2;Rh/208B4Q080
QHF50P2@T902096AT@80Rh^;0P2BTY8208^;R`80RXZ:00<0QXJ608V9R@29RHT00P2GUiL408Z:RP80
R8R80P2ATI4208f=S@80SXj>0`38h=P208>3P`80SHf=0P1_Kfl207inOP80F5QH0P2SXj<207]kN`03
07inOP1^KVh0KVi^0080QhN70P1kNg/206QXJ080Ph>30P1kNg/207emO@80R8R80P26QXH208j>SP80
Lg=c0P21PH4208R8R080P8200P1hN7P00`20P800MGEe07EeM@0209FEU@80Q8B40P2;Rh/2096AT@80
NGUi0P1jNWX206m_K`d0b>3H000;0<SPf080RXZ:0P2_[jl20:2PX080Rh^;0P2GUiL2092@T080QHF5
00<0T92@08b<S02<S8`00P2WYjL20:FUY@80RXZ:0P27QhL208^;R`80QhN70P25QHD208J6QP80R8R8
0P2:RXX208j>SP80RXZ:0P27QhL208V9R@<0Q8B40P27QhL2092@T080UIFE0P2@T90209:BTP80Rh^;
0P2ATI430<SPf080NGUi0P2?Shl208J6QP80PH610P22PX8207MgM`80SXj>00<0Jf][09nOW`2OWil0
1029RHT207YjNP80Ph>30P27QhL407]kN`80Lg=c0P1nOWh206EUI@80Ng]k1026QXH308N7Q`80PH61
0P1oOgl207YjNP80SXj>0P1mOGd207inOP80MgMg0P1mOGd:0<SPf080QHF50P2ZZZX209FEU@80T92@
0P2EUID20;Ng]`80RXZ:00<0W9bL08Z:RP2:RXX00P2<S8`209^KV`80XZ:R0P29RHT2092@T080RHV9
0P2<S8`208Z:RP80SXj>0P2<S8`2092@T080S8b<0P2;Rh/208b<S00308R8R02:RXX0RXZ:0080T92@
0P2EUID408j>SP80WinO0P2<S8`209ZJVP<0b>3H0P25QHD2069RHP80Ogmo0P1hN7P208n?S`80Xj>S
0P1oOgl00`1[Jf/0TI6A096AT@0208f=S@80KVi^0P1YJFT208n?S`80Lg=c0P1aLG4208R8R080QXJ6
0P29RHT207]kN`80NGUi0P1dM7@206ATI080Ph>300<0Kfm_08:2PP22PX800P29RHT206i^KP80Q8B4
0P1eMGD208j>SP80M7Ad0P27QhL=0<SPf0002`38h=P208Z:RP80[jn_0P2PX:0208^;R`80UiNG0P2@
T90208F5Q@03092@T02<S8`0S8b<0080YjNW0P2UYJD208Z:RP80QhN70P2;Rh/208N7Q`80QHF50P26
QXH208R8R080RXZ:0P2>SXh208Z:RP80QhN70P29RHT308B4Q080QhN70P2@T90209FEU@80T92@0P2B
TY8208^;R`80TI6A0`38h=P207UiN@80Shn?0P26QXH20861P@80PX:20P1gMgL208j>SP0306][J`2O
Wil0WinO00@0RHV90P1jNWX208>3P`80QhN7101kNg/207=cL`80OWin0P1UIFD207]kN`@0QXJ60`27
QhL20861P@80Ogmo0P1jNWX208j>SP80OGem0P1nOWh207MgM`80OGem2P38h=P208F5Q@80ZZZZ0P2E
UID2092@T080UIFE0P2g]kL208Z:RP0309bLW02:RXX0RXZ:0080S8b<0P2KVi/20::RXP80RHV90P2@
T90208V9R@80S8b<0P2:RXX208j>SP80S8b<0P2@T90208b<S080Rh^;0P2<S8`00`28R8P0RXZ:08Z:
RP02092@T080UIFE102>SXh209nOW`80S8b<0P2JVYX30<SPf080QHF50P1RHV8207moO`80N7Qh0P2?
Shl20:>SX`80Ogmo00<0Jf][096AT@2ATI400P2=SHd206i^KP80JFUY0P2?Shl207=cL`80LG5a0P28
R8P208J6QP80RHV90P1kNg/207UiN@80M7Ad0P1TI6@208>3P`0306m_K`22PX80PX:20080RHV90P1^
KVh208B4Q080MGEe0P2>SXh207AdM080QhN73@38h=P000/0b>3H0P2LW9`208Z:RP80RHV90P2NWYh2
08^;R`80VIVI0P2SXj<00`2:RXX0WIfM09fMW@020;6a/@80UIFE0P2?Shl408Z:RP80S8b<0P29RHT2
08J6QP80RXZ:0P2>SXh208J6QP80Rh^;0P2:RXX208J6QP0308R8R025QHD0QHF50080QhN70P26QXH2
09:BTP80QXJ60P25QHD208n?S`80QXJ60`38h=P208J6QP80T92@0P2?Shl20861P@80V9RH0P1bLW82
07IfMP0308V9R@1mOGd0OGem0080O7al0P1kNg/208F5Q@80P8200P1nOWh2071`L080PH610P24Q8@2
08V9R@80MGEe0P1kNg/20861P@80Ng]k0P1]KFd00`27QhL0PX:208:2PP0207moO`80PX:20P27QhL2
07inOP80QHF5101mOGd:0<SPf080SXj>0P2WYjL20:>SX`80RHV90P2CTi<208V9R@80U9BD00<0RHV9
0:j^[P2^[Zh00P2RXZ8209FEU@80VIVI0P2:RXX209RHV080Ti>C0P29RHT2092@T080R8R80P2<S8`2
09BDU080Ph>30P2>SXh208^;R`0308Z:RP29RHT0RHV90080QhN70P2CTi<208:2PP80QXJ60P20P802
09JFUP80RHV90`38h=P208N7Q`80VIVI0P1jNWX206i^KP80O7al0P1OGel206EUI@0307AdM02MWId0
WIfM00@0Q8B40P2DU9@207moO`80SXj>0P2<S8`207emO@@0R8R80P1kNg/2092@T080PH610P22PX82
08>3P`030820P024Q8@0Q8B40080Q8B40P25QHD208:2PP80Ng]k0P1nOWh407YjNPd0b>3H000;0<SP
f080W9bL0P2:RXX208V9R@80WYjN0P2;Rh/209VIV@80Xj>S00<0RXZ:09fMW@2MWId00P2a/K4209FE
U@80Shn?102:RXX208b<S080RHV90P26QXH208Z:RP80SXj>0P26QXH208^;R`80RXZ:0P26QXH00`28
R8P0QHF508F5Q@0208N7Q`80QXJ60P2BTY8208J6QP80QHF50P2?Shl208J6QP<0b>3H0P26QXH2092@
T080Shn?0P21PH4209RHV080LW9b0P1fMWH00`29RHT0OGem07emO@0207alO080Ng]k0P25QHD20820
P080OWin0P1`L7020861P@80Q8B40P29RHT207EeM@80Ng]k0P21PH4207]kN`80KFe]00<0QhN708:2
PP22PX800P1oOgl208:2PP80QhN70P1nOWh208F5Q@@0OGem2P38h=P208j>SP80YjNW0P2SXj<208V9
R@80Ti>C0P29RHT209BDU00308V9R@2^[Zh0[Zj^0080XZ:R0P2EUID209VIV@80RXZ:0P2HV9P209>C
T`80RHV90P2@T90208R8R080S8b<0P2DU9@208>3P`80SXj>0P2;Rh/00`2:RXX0RHV908V9R@0208N7
Q`80Ti>C0P22PX8208J6QP80P8200P2FUYH208V9R@<0b>3H0P27QhL209VIV@80NWYj0P1^KVh207al
O080GemO0P1UIFD00`1dM7@0WIfM09fMW@0408B4Q080U9BD0P1oOgl208j>SP80S8b<0P1mOGd408R8
R080Ng]k0P2@T9020861P@80PX:20P23Ph<00`20P800Q8B408B4Q00208B4Q080QHF50P22PX8207]k
N`80OWin101jNWX=0<SPf0002`38h=P209ZJVP80UIFE0P2GUiL20:BTY080XZ:R0P2VYZH20:BTY003
096AT@2;Rh/0Rh^;0080Xj>S0P2g]kL208R8R080Rh^;0P29RHT408N7Q`80T92@0P27QhL208j>SP80
QHF50P28R8P208Z:RP80QhN700<0SXj>08>3P`23Ph<00P28R8P208V9R@80QHF50P26QXH2092@T080
RHV90P2=SHd30<SPf080L71`0P2JVYX20820P080Q8B40P2f][H208n?S`80KVi^00<0LG5a0861P@21
PH400P1hN7P207moO`80QXJ60P21PH4208f=S@@0O7al0P1nOWh207MgM`80NWYj0P27QhL207moO`80
M7Ad0P24Q8@00`2<S8`0Ph>308>3P`0208B4Q080Ng]k0P1oOgl207alO080NWYj0P1kNg/206m_K`X0
b>3H0P2HV9P20:j^[P80WinO0P2BTY8208F5Q@80VIVI0P2JVYX00`2CTi<0TY:B09:BTP0208n?S`80
WinO0P2@T90208b<S080RXZ:0P28R8P208^;R`80SHf=0P2CTi<208N7Q`80RXZ:1P2;Rh/00`26QXH0
Rh^;08^;R`0208b<S080SHf=0P29RHT208:2PP80Shn?0P2;Rh/208n?S`<0b>3H0P2:RXX20:>SX`80
Ogmo0P22PX8208R8R080Ti>C0P1nOWh00`2=SHd0NWYj07YjNP02071`L080T92@0P2?Shl208F5Q@80
NWYj0P1gMgL2096AT@80Ogmo0P1`L70207QhN080Ph>30P27QhL207alO080RHV900<0MGEe07inOP1n
OWh00P1jNWX20861P@80O7al0P21PH4207inOP80MWIf0P20P80=0<SPf0002`38h=P209ZJVP80UIFE
0P2GUiL20:BTY080XZ:R0P2VYZH20:BTY003096AT@2;Rh/0Rh^;0080Xj>S0P2g]kL208R8R080Rh^;
0P29RHT408N7Q`80T92@0P27QhL208j>SP80QHF50P28R8P208Z:RP80QhN700<0SXj>08>3P`23Ph<0
0P28R8P208V9R@80QHF50P26QXH2092@T080RHV90P2=SHd30<SPf080L71`0P2JVYX20820P080Q8B4
0P2f][H208n?S`80KVi^00<0LG5a0861P@21PH400P1hN7P207moO`80QXJ60P21PH4208f=S@@0O7al
0P1nOWh207MgM`80NWYj0P27QhL207moO`80M7Ad0P24Q8@00`2<S8`0Ph>308>3P`0208B4Q080Ng]k
0P1oOgl207alO080NWYj0P1kNg/206m_K`X0b>3H0P2HV9P20:j^[P80WinO0P2BTY8208F5Q@80VIVI
0P2JVYX00`2CTi<0TY:B09:BTP0208n?S`80WinO0P2@T90208b<S080RXZ:0P28R8P208^;R`80SHf=
0P2CTi<208N7Q`80RXZ:1P2;Rh/00`26QXH0Rh^;08^;R`0208b<S080SHf=0P29RHT208:2PP80Shn?
0P2;Rh/208n?S`<0b>3H0P2:RXX20:>SX`80Ogmo0P22PX8208R8R080Ti>C0P1nOWh00`2=SHd0NWYj
07YjNP02071`L080T92@0P2?Shl208F5Q@80NWYj0P1gMgL2096AT@80Ogmo0P1`L70207QhN080Ph>3
0P27QhL207alO080RHV900<0MGEe07inOP1nOWh00P1jNWX20861P@80O7al0P21PH4207inOP80MWIf
0P20P80=0<SPf0002`38h=P209NGU`80Vi^K0P2CTi<20;Bd]080Y:BT0P2PX:0209jNWP0309:BTP23
Ph<0Ph>30080Zj^[0P2ZZZX2096AT@80QhN7102<S8`208R8R080Q8B40P2IVIT208Z:RP80S8b<1027
QhL208Z:RP0308B4Q029RHT0RHV90080RXZ:1026QXH208F5Q@80S8b<0P24Q8@208N7Q`<0b>3H0P1Y
JFT208>3P`80Rh^;0P22PX82096AT@80R8R80P1oOgl00`1PH600QHF508F5Q@0207inOP80V9RH0P1b
LW8207moO`80R8R80P2:RXX20820P080N7Qh0P25QHD2079bLP80Q8B40P1oOgl207]kN`80Q8B400<0
OWin08J6QP26QXH00P22PX8207]kN`80Q8B40P1oOgl20861P@80OWin0P1lO7`:0<SPf080VYZJ0P28
R8P208N7Q`80U9BD0P2CTi<2096AT@80WIfM00<0Xj>S09bLW02LW9`00P2KVi/208n?S`80RXZ:0P2<
S8`208n?S`80R8R80P2?Shl208j>SP80RHV90P2:RXX2092@T080Ti>C0P24Q8@208Z:RP0308^;R`28
R8P0R8R80080QHF50P2DU9@208Z:RP80R8R80P27QhL408V9R@<0b>3H0P2KVi/208R8R080QhN70P1i
NGT20:BTY080Rh^;0P1lO7`00`1ZJVX0RXZ:08Z:RP0206YZJP80OGem0P1HF5P208N7Q`80U9BD0P29
RHT208J6QP80Ogmo0P23Ph<206QXJ080PX:20P1lO7`207emO@80O7al00<0Shn?071`L01`L7000P1m
OGd206i^KP80LW9b0P1lO7`408:2PP80N7Qh3@38h=P000/0b>3H0P2FUYH20:BTY080RHV90P2HV9P2
0::RXP80U9BD0P2GUiL00`2HV9P0S8b<08b<S0020:BTY080Ti>C0P2;Rh/208f=S@80SXj>0P2<S8`2
08:2PP80QhN70P24Q8@208N7Q`80S8b<0P27QhL208j>SP80R8R800<0Q8B408Z:RP2:RXX00P2;Rh/2
08>3P`@0QXJ60P2;Rh/208B4Q080RHV90`38h=P208F5Q@80G5aL0P1gMgL209fMW@80MgMg0P2GUiL2
08>3P`03075aL@2FUYH0UYJF0080QHF50P1mOGd208>3P`80Ng]k0P1nOWh207emO@80Ogmo0P24Q8@2
08R8R080QXJ60P1fMWH20861P@80O7al0P24Q8@00`20P800MWIf07IfMP0208F5Q@80Ph>30P1gMgL2
08B4Q080PX:20P1oOgl208B4Q0X0b>3H102?Shl209ZJVP80Ti>C0P2SXj<209>CT`80RXZ:00<0^KVi
09^KV`2KVi/00P2GUiL208J6QP80Rh^;0P2:RXX208f=S@80SXj>0P28R8P408f=S@80QhN70P2BTY82
09JFUP80TI6A0P26QXH00`2>SXh0Shn?08n?S`0208^;R`80RXZ:0P29RHT208F5Q@80UiNG0P2;Rh/2
08n?S`<0b>3H0P1gMgL206i^KP80Ogmo0P22PX8208N7Q`80SHf=0P1hN7P00`2JVYX0`<300<30`002
06UYJ@80T92@0P26QXH207UiN@80RHV90P1eMGD207inOP80Lg=c0P1]KFd2092@T080QhN70P2CTi<2
08Z:RP80N7Qh00<0Q8B408:2PP22PX800P1mOGd207]kN`80OGem0P1gMgL20861P@80OGem0P2?Shl=
0<SPf0002`38h=P209JFUP80Y:BT0P29RHT209RHV080XZ:R0P2DU9@209NGU`0309RHV02<S8`0S8b<
0080Y:BT0P2CTi<208^;R`80SHf=0P2>SXh208b<S080PX:20P27QhL208B4Q080QhN70P2<S8`208N7
Q`80SXj>0P28R8P00`24Q8@0RXZ:08Z:RP0208^;R`80Ph>31026QXH208^;R`80Q8B40P29RHT30<SP
f080QHF50P1LG5`207MgM`80WIfM0P1gMgL209NGU`80Ph>300<0LG5a09JFUP2FUYH00P25QHD207em
O@80Ph>30P1kNg/207inOP80OGem0P1oOgl208B4Q080R8R80P26QXH207IfMP80PH610P1lO7`208B4
Q0030820P01fMWH0MWIf0080QHF50P23Ph<207MgM`80Q8B40P22PX8207moO`80Q8B42P38h=P408n?
S`80VYZJ0P2CTi<20:>SX`80Ti>C0P2:RXX00`2i^KT0Vi^K09^KV`0209NGU`80QXJ60P2;Rh/208Z:
RP80SHf=0P2>SXh208R8R0@0SHf=0P27QhL209:BTP80UYJF0P2ATI4208J6QP0308j>SP2?Shl0Shn?
0080Rh^;0P2:RXX208V9R@80QHF50P2GUiL208^;R`80Shn?0`38h=P207MgM`80KVi^0P1oOgl208:2
PP80QhN70P2=SHd207QhN00309ZJVP30`<00`<300080JFUY0P2@T90208J6QP80NGUi0P29RHT207Ee
M@80OWin0P1cLg<206e]K@80T92@0P27QhL209>CT`80RXZ:0P1hN7P00`24Q8@0PX:208:2PP0207em
O@80Ng]k0P1mOGd207MgM`80PH610P1mOGd208n?S`d0b>3H000;0<SPf080RXZ:0P2ATI4208V9R@80
Shn?0P2WYjL209^KV`80X:2P00<0V9RH09>CT`2CTi<00P2RXZ8209^KV`80Rh^;0P27QhL208F5Q@80
RHV90P25QHD208R8R080Rh^;0P2=SHd208N7Q`80Shn?0P26QXH208N7Q`0308B4Q028R8P0R8R80080
Ph>30P29RHT208B4Q080S8b<0P29RHT208^;R`80SXj>0`38h=P209VIV@80Q8B40P2;Rh/208R8R080
WYjN0P2>SXh208J6QP030861P@1`L700L71`0080Ti>C0P1]KFd208^;R`80QhN70P20P8040861P@@0
QHF50P24Q8@207AdM080RXZ:0P1_Kfl208B4Q00307UiN@1oOgl0Ogmo0080QHF50P1lO7`207emO@80
Ph>30P1oOgl208Z:RP80PH612P38h=P209FEU@80Shn?0P2@T90209:BTP80UIFE0P2IVIT209JFUP03
08:2PP2n_[h0_[jn0080XZ:R0P2ATI42092@T080RHV90P28R8P209BDU080PH610P2@T90208n?S`80
TY:B0P2=SHd208j>SP80Rh^;0P2:RXX00`28R8P0RXZ:08Z:RP0208B4Q080UYJF0P20P80208b<S080
SHf=0P2CTi<209FEU@<0b>3H0P2?Shl209RHV080Ogmo0P24Q8@2069RHP80NWYj0P1cLg<00`1bLW80
_;bl0;bl_00208^;R`80UYJF0P22PX8208N7Q`80P8200P1iNGT208:2PP@0NGUi0P2ATI4207QhN080
P8200P1lO7`207AdM00308>3P`1cLg<0Lg=c0080MWIf0P29RHT407emO@80Lg=c0P1jNWX208^;R`d0
b>3H000;0<SPf080RXZ:0P2ATI4208V9R@80Shn?0P2WYjL209^KV`80X:2P00<0V9RH09>CT`2CTi<0
0P2RXZ8209^KV`80Rh^;0P27QhL208F5Q@80RHV90P25QHD208R8R080Rh^;0P2=SHd208N7Q`80Shn?
0P26QXH208N7Q`0308B4Q028R8P0R8R80080Ph>30P29RHT208B4Q080S8b<0P29RHT208^;R`80SXj>
0`38h=P209VIV@80Q8B40P2;Rh/208R8R080WYjN0P2>SXh208J6QP030861P@1`L700L71`0080Ti>C
0P1]KFd208^;R`80QhN70P20P8040861P@@0QHF50P24Q8@207AdM080RXZ:0P1_Kfl208B4Q00307Ui
N@1oOgl0Ogmo0080QHF50P1lO7`207emO@80Ph>30P1oOgl208Z:RP80PH612P38h=P209FEU@80Shn?
0P2@T90209:BTP80UIFE0P2IVIT209JFUP0308:2PP2n_[h0_[jn0080XZ:R0P2ATI42092@T080RHV9
0P28R8P209BDU080PH610P2@T90208n?S`80TY:B0P2=SHd208j>SP80Rh^;0P2:RXX00`28R8P0RXZ:
08Z:RP0208B4Q080UYJF0P20P80208b<S080SHf=0P2CTi<209FEU@<0b>3H0P2?Shl209RHV080Ogmo
0P24Q8@2069RHP80NWYj0P1cLg<00`1bLW80_;bl0;bl_00208^;R`80UYJF0P22PX8208N7Q`80P820
0P1iNGT208:2PP@0NGUi0P2ATI4207QhN080P8200P1lO7`207AdM00308>3P`1cLg<0Lg=c0080MWIf
0P29RHT407emO@80Lg=c0P1jNWX208^;R`d0b>3H000;0<SPf080X:2P0P27QhL209>CT`80SXj>0P2O
Wil20:VYZ@80TI6A00<0UYJF09NGU`2GUiL00P2@T90209JFUP80QXJ60P2<S8`208J6QP80UYJF0P22
PX8208R8R080QXJ60P24Q8@208R8R080Ph>30P2;Rh/208B4Q003092@T027QhL0QhN70080SHf=0P23
Ph<208^;R`80SXj>0P24Q8@208V9R@80QXJ60`38h=P206m_K`80K6a/0P21PH4208B4Q080SXj>0P2D
U9@20820P00309NGU`1PH600H61P0080MGEe0P1iNGT207emO@80U9BD0P1oOgl208B4Q080S8b<0P1l
O7`207emO@80Ogmo0P1mOGd208B4Q080P8200P1nOWh00`1cLg<0OGem07emO@0207QhN080QHF50P20
P80207moO`80RXZ:0P1lO7`208:2PPX0b>3H0P2;Rh/209JFUP80QHF50P2JVYX208b<S080WYjN0P2J
VYX00`2?Shl0WYjN09jNWP020:ZZZP80TY:B0P2=SHd208Z:RP80SHf=0P27QhL208R8R080QXJ60P25
QHD208^;R`80QhN70P2<S8`209FEU@80Rh^;00<0SXj>08V9R@29RHT00P2HV9P208f=S@80TI6A0P26
QXH209:BTP80Shn?0P2;Rh/30<SPf080QhN70P24Q8@2075aL@80Ng]k0P1lO7`209JFUP80N7Qh00<0
P82008J6QP26QXH00P1ADE4207AdM080O7al101jNWX208j>SP80NWYj0P1gMgL208Z:RP80PX:20P1k
Ng/208b<S080NGUi0P1mOGd00`1hN7P0PH610861P@0208Z:RP80PH610P22PX8208V9R@80SHf=0P1]
KFd207YjNPd0b>3H000;0<SPf080X:2P0P27QhL209>CT`80SXj>0P2OWil20:VYZ@80TI6A00<0UYJF
09NGU`2GUiL00P2@T90209JFUP80QXJ60P2<S8`208J6QP80UYJF0P22PX8208R8R080QXJ60P24Q8@2
08R8R080Ph>30P2;Rh/208B4Q003092@T027QhL0QhN70080SHf=0P23Ph<208^;R`80SXj>0P24Q8@2
08V9R@80QXJ60`38h=P206m_K`80K6a/0P21PH4208B4Q080SXj>0P2DU9@20820P00309NGU`1PH600
H61P0080MGEe0P1iNGT207emO@80U9BD0P1oOgl208B4Q080S8b<0P1lO7`207emO@80Ogmo0P1mOGd2
08B4Q080P8200P1nOWh00`1cLg<0OGem07emO@0207QhN080QHF50P20P80207moO`80RXZ:0P1lO7`2
08:2PPX0b>3H0P2;Rh/209JFUP80QHF50P2JVYX208b<S080WYjN0P2JVYX00`2?Shl0WYjN09jNWP02
0:ZZZP80TY:B0P2=SHd208Z:RP80SHf=0P27QhL208R8R080QXJ60P25QHD208^;R`80QhN70P2<S8`2
09FEU@80Rh^;00<0SXj>08V9R@29RHT00P2HV9P208f=S@80TI6A0P26QXH209:BTP80Shn?0P2;Rh/3
0<SPf080QhN70P24Q8@2075aL@80Ng]k0P1lO7`209JFUP80N7Qh00<0P82008J6QP26QXH00P1ADE42
07AdM080O7al101jNWX208j>SP80NWYj0P1gMgL208Z:RP80PX:20P1kNg/208b<S080NGUi0P1mOGd0
0`1hN7P0PH610861P@0208Z:RP80PH610P22PX8208V9R@80SHf=0P1]KFd207YjNPd0b>3H000;0<SP
f080UiNG0P2ATI4408J6QP80Shn?0P2WYjL209bLW00309fMW@2BTY80TY:B0080Shn?0P2LW9`208>3
P`80RHV90P24Q8@208Z:RP80SHf=1028R8P208V9R@80QXJ60P25QHD408V9R@0308J6QP28R8P0R8R8
0080QHF50P28R8P208b<S080R8R80P2BTY8408R8R0<0b>3H0P1`L70207MgM`80Ph>30P1jNWX208V9
R@80/K6a0P2CTi<00`28R8P0QHF508F5Q@0206YZJP80IFEU0P2<S8`207inOP80PX:20P2;Rh/208>3
P`80QHF51021PH4208V9R@80OGem0P1oOgl207alO0<0QHF50P1kNg/207emO@80QhN70P2:RXX208N7
Q`80OGem0P23Ph<:0<SPf080QhN70P2IVIT208f=S@80RHV90P2:RXX20:2PX0<0Ti>C0P25QHD20<W9
b@80Y:BT0P2;Rh/2096AT@80Q8B40P2GUiL208J6QP@0SHf=0P29RHT208Z:RP80Rh^;0P29RHT208n?
S`0308Z:RP2<S8`0S8b<0080PH610P27QhL208n?S`80R8R80P22PX8208j>SP80RHV90`38h=P208F5
Q@80IfMW0P1nOWh208>3P`80Shn?0P1iNGT208n?S`0307QhN028R8P0R8R80080Z:RX0P2;Rh/208V9
R@80N7Qh0P24Q8@208R8R080PH610P1nOWh208^;R`@0MGEe0P1jNWX208B4Q080RHV900<0P82007al
O01lO7`00P27QhL207emO@80P8200P1kNg/208b<S080J6QX0P28R8P=0<SPf0002`38h=P209NGU`80
TI6A1026QXH208n?S`80YjNW0P2LW9`00`2MWId0TY:B09:BTP0208n?S`80W9bL0P23Ph<208V9R@80
Q8B40P2:RXX208f=S@@0R8R80P29RHT208J6QP80QHF51029RHT00`26QXH0R8R808R8R00208F5Q@80
R8R80P2<S8`208R8R080TY:B1028R8P30<SPf080L71`0P1gMgL208>3P`80NWYj0P29RHT20;6a/@80
Ti>C00<0R8R808F5Q@25QHD00P1ZJVX206EUI@80S8b<0P1nOWh208:2PP80Rh^;0P23Ph<208F5Q@@0
PH610P29RHT207emO@80Ogmo0P1lO7`308F5Q@80Ng]k0P1mOGd208N7Q`80RXZ:0P27QhL207emO@80
Ph>32P38h=P208N7Q`80VIVI0P2=SHd208V9R@80RXZ:0P2PX:0309>CT`80QHF50P39bLT20:BTY080
Rh^;0P2ATI4208B4Q080UiNG0P26QXH408f=S@80RHV90P2:RXX208^;R`80RHV90P2?Shl00`2:RXX0
S8b<08b<S0020861P@80QhN70P2?Shl208R8R080PX:20P2>SXh208V9R@<0b>3H0P25QHD206MWI`80
OWin0P23Ph<208n?S`80NGUi0P2?Shl00`1hN7P0R8R808R8R0020:RXZ080Rh^;0P29RHT207QhN080
Q8B40P28R8P20861P@80OWin0P2;Rh/407EeM@80NWYj0P24Q8@208V9R@030820P01lO7`0O7al0080
QhN70P1mOGd20820P080Ng]k0P2<S8`206QXJ080R8R83@38h=P000/0b>3H0P2OWil208F5Q@80Shn?
0P28R8P208^;R`80W9bL0P2SXj<00`2QXJ40TY:B09:BTP0208f=S@80UIFE0P2?Shl408V9R@80RXZ:
0P24Q8@208R8R080RXZ:0P26QXH208j>SP80Shn?0P24Q8@208N7Q`0308^;R`29RHT0RHV90080S8b<
0P24Q8@208N7Q`80RXZ:0P28R8P208f=S@80VIVI0`38h=P209>CT`80NGUi0P2@T9020820P080LG5a
0P2?Shl209BDU00307MgM`28R8P0R8R80080MgMg0P1MGEd206e]K@80PH610P1fMWH207AdM080OGem
0P1oOgl208>3P`80LG5a0P1oOgl207]kN`80N7Qh0P29RHT00`2;Rh/0QHF508F5Q@020861P@80RXZ:
0P27QhL208:2PP80R8R80P1iNGT207emO@X0b>3H0P29RHT209FEU@80RHV90P2DU9@2092@T080Vi^K
0P2SXj<00`2UYJD0V9RH09RHV00207emO@80];Bd0P2QXJ4209VIV@80RXZ:0P2;Rh/208F5Q@80PX:2
0P2BTY8208f=S@80T92@0P27QhL408V9R@0308N7Q`2;Rh/0Rh^;0080TY:B0P2>SXh208b<S080Shn?
0P2CTi<208Z:RP80T92@0`38h=P208R8R080O7al0P2<S8`208F5Q@80QhN70P1iNGT207QhN00309NG
U`1jNWX0NWYj0080PH610P1]KFd206UYJ@80T92@0P24Q8@2061PH080RHV90P24Q8@207EeM@80RXZ:
0P1oOgl207UiN@80LG5a0P1/K6`00`21PH40M7Ad07AdM00208f=S@80LG5a0P1kNg/207alO080Shn?
0P1bLW8207moO`d0b>3H000;0<SPf080WinO0P25QHD208n?S`80R8R80P2;Rh/209bLW080Xj>S00<0
XJ6Q09:BTP2BTY800P2=SHd209FEU@80Shn?1029RHT208Z:RP80Q8B40P28R8P208Z:RP80QXJ60P2>
SXh208n?S`80Q8B40P27QhL00`2;Rh/0RHV908V9R@0208b<S080Q8B40P27QhL208Z:RP80R8R80P2=
SHd209VIV@<0b>3H0P2CTi<207UiN@80T92@0P20P802075aL@80Shn?0P2DU9@00`1gMgL0R8R808R8
R00207MgM`80GEeM0P1]KFd20861P@80MWIf0P1dM7@207emO@80Ogmo0P23Ph<2075aL@80Ogmo0P1k
Ng/207QhN080RHV900<0Rh^;08F5Q@25QHD00P21PH4208Z:RP80QhN70P22PX8208R8R080NGUi0P1m
OGd:0<SPf080RHV90P2EUID208V9R@80U9BD0P2@T90209^KV`80Xj>S00<0YJFU09RHV02HV9P00P1m
OGd20;Bd]080XJ6Q0P2IVIT208Z:RP80Rh^;0P25QHD208:2PP80TY:B0P2=SHd2092@T080QhN71029
RHT00`27QhL0Rh^;08^;R`0209:BTP80SXj>0P2<S8`208n?S`80Ti>C0P2:RXX2092@T0<0b>3H0P28
R8P207alO080S8b<0P25QHD208N7Q`80NGUi0P1hN7P00`2GUiL0NWYj07YjNP020861P@80KFe]0P1Y
JFT2092@T080Q8B40P1PH60208V9R@80Q8B40P1eMGD208Z:RP80Ogmo0P1iNGT2075aL@80K6a/00<0
PH6107AdM01dM7@00P2=SHd2075aL@80Ng]k0P1lO7`208n?S`80LW9b0P1oOgl=0<SPf0002`38h=P2
08Z:RP80SXj>0P2;Rh/209^KV`80QXJ60P2EUID20:n_[`030:6QX@2][Jd0[Jf]0080Ph>30P2HV9P2
0:2PX080SHf=1029RHT2096AT@80QHF50P2=SHd208R8R080RHV90P2:RXX208V9R@80QhN700<0RXZ:
08N7Q`27QhL00P2;Rh/209^KV`80SHf=0P27QhL208V9R@80PX:20P2?Shl30<SPf080Q8B40P2:RXX2
07emO@80QHF50P24Q8@208^;R`80XZ:R00<0IFEU07UiN@1iNGT00P27QhL208V9R@80Q8B40P2FUYH2
07]kN`80Ph>30P1iNGT207moO`80PX:20P1nOWh207EeM@80QXJ60P1kNg/207MgM`<0NGUi0P27QhL2
08>3P`80M7Ad0P24Q8@207alO080Q8B40P25QHD:0<SPf080Q8B4102=SHd208:2PP80S8b<0P2?Shl2
09JFUP0309^KV`2^[Zh0[Zj^0080QhN70P2KVi/20<K6aP80WinO0P29RHT208j>SP@0RHV90P2GUiL2
08n?S`80SHf=0P24Q8@2092@T080Shn?0`2>SXh2096AT@80R8R80P26QXH208Z:RP80PH610P2@T902
096AT@<0b>3H0P1kNg/208j>SP80R8R80P23Ph<20820P080WIfM0P1bLW800`2RXZ80MGEe07EeM@02
08N7Q`80Ti>C0P1WIfL206UYJ@80OWin0P1iNGT207moO`80Q8B40P1bLW8208:2PP80QHF50P2:RXX2
079bLP80RHV900<0Jf][09FEU@2EUID00P1iNGT208b<S080Q8B40P26QXH207moO`80QHF50P1nOWh=
0<SPf0002`38h=P208Z:RP80SXj>0P2;Rh/209^KV`80QXJ60P2EUID20:n_[`030:6QX@2][Jd0[Jf]
0080Ph>30P2HV9P20:2PX080SHf=1029RHT2096AT@80QHF50P2=SHd208R8R080RHV90P2:RXX208V9
R@80QhN700<0RXZ:08N7Q`27QhL00P2;Rh/209^KV`80SHf=0P27QhL208V9R@80PX:20P2?Shl30<SP
f080Q8B40P2:RXX207emO@80QHF50P24Q8@208^;R`80XZ:R00<0IFEU07UiN@1iNGT00P27QhL208V9
R@80Q8B40P2FUYH207]kN`80Ph>30P1iNGT207moO`80PX:20P1nOWh207EeM@80QXJ60P1kNg/207Mg
M`<0NGUi0P27QhL208>3P`80M7Ad0P24Q8@207alO080Q8B40P25QHD:0<SPf080Q8B4102=SHd208:2
PP80S8b<0P2?Shl209JFUP0309^KV`2^[Zh0[Zj^0080QhN70P2KVi/20<K6aP80WinO0P29RHT208j>
SP@0RHV90P2GUiL208n?S`80SHf=0P24Q8@2092@T080Shn?0`2>SXh2096AT@80R8R80P26QXH208Z:
RP80PH610P2@T902096AT@<0b>3H0P1kNg/208j>SP80R8R80P23Ph<20820P080WIfM0P1bLW800`2R
XZ80MGEe07EeM@0208N7Q`80Ti>C0P1WIfL206UYJ@80OWin0P1iNGT207moO`80Q8B40P1bLW8208:2
PP80QHF50P2:RXX2079bLP80RHV900<0Jf][09FEU@2EUID00P1iNGT208b<S080Q8B40P26QXH207mo
O`80QHF50P1nOWh=0<SPf0002`38h=P208f=S@80R8R80P2>SXh208R8R080SXj>0P23Ph<209RHV003
09NGU`2d];@0];Bd0080Shn?0P2=SHd209RHV080ZZZZ0P24Q8@208V9R@80QhN70P28R8P208N7Q`80
T92@0P29RHT208^;R`80QXJ60`28R8P408^;R`80QHF50P2=SHd208N7Q`80RXZ:0P2<S8`2092@T0<0
b>3H0P1OGel207MgM`80OGem0P1nOWh208:2PP80Ogmo0P25QHD00`1fMWH0LW9b079bLP0207YjNP80
RHV90P2?Shl407alO080NGUi0P27QhL207YjNP80NGUi0P1oOgl208V9R@80M7Ad0P29RHT207AdM003
08V9R@1bLW80LW9b0080Ng]k0P27QhL207YjNP80Ph>30P1nOWh407alO0X0b>3H0P2LW9`209>CT`80
TY:B0P2GUiL2096AT@80W9bL0P2EUID00`2WYjL0VIVI09VIV@0208b<S080RXZ:0P2>SXh20<o?c`80
Vi^K0P2JVYX208f=S@80S8b<0P2=SHd209RHV080PX:20P2@T90208^;R`80RXZ:00<0VIVI09:BTP2B
TY800P2:RXX208f=S@80SXj>0P24Q8@209:BTP80Shn?0P24Q8@30<SPf080Cdm?0P1XJ6P207inOP80
PH610P26QXH209FEU@80LW9b00<0J6QX08N7Q`27QhL00P1oOgl208^;R`80PH610P23Ph<208:2PP80
Ogmo0P21PH4206EUI@80QHF50P1iNGT208B4Q080R8R80P2CTi<208F5Q@0307EeM@2<S8`0S8b<0080
Kfm_0P21PH42075aL@80Ph>30P27QhL207emO@80PX:23@38h=P000/0b>3H0P2=SHd208R8R080SXj>
0P28R8P208j>SP80Ph>30P2HV9P00`2GUiL0];Bd0;Bd]00208n?S`80SHf=0P2HV9P20:ZZZP80Q8B4
0P29RHT208N7Q`80R8R80P27QhL2092@T080RHV90P2;Rh/208J6QP<0R8R8102;Rh/208F5Q@80SHf=
0P27QhL208Z:RP80S8b<0P2@T9030<SPf080GemO0P1gMgL207emO@80OWin0P22PX8207moO`80QHF5
00<0MWIf079bLP1bLW800P1jNWX208V9R@80Shn?101lO7`207UiN@80QhN70P1jNWX207UiN@80Ogmo
0P29RHT207AdM080RHV90P1dM7@00`29RHT0LW9b079bLP0207]kN`80QhN70P1jNWX208>3P`80OWin
101lO7`:0<SPf080W9bL0P2CTi<209:BTP80UiNG0P2ATI4209bLW080UIFE00<0YjNW09VIV@2IVIT0
0P2<S8`208Z:RP80SXj>0P3?cll209^KV`80VYZJ0P2=SHd208b<S080SHf=0P2HV9P208:2PP80T92@
0P2;Rh/208Z:RP0309VIV@2BTY80TY:B0080RXZ:0P2=SHd208j>SP80Q8B40P2BTY8208n?S`80Q8B4
0`38h=P204m?C`80J6QX0P1nOWh20861P@80QXJ60P2EUID2079bLP0306QXJ027QhL0QhN70080Ogmo
0P2;Rh/20861P@80Ph>30P22PX8207moO`80PH610P1UIFD208F5Q@80NGUi0P24Q8@208R8R080Ti>C
0P25QHD00`1eMGD0S8b<08b<S00206m_K`80PH610P1aLG4208>3P`80QhN70P1mOGd208:2PPd0b>3H
000;0<SPf080S8b<0P2?Shl208R8R080RHV9102<S8`208n?S`030:FUY@2ZZZX0ZZZZ0080Zj^[0P2>
SXh208Z:RP80Rh^;0P2JVYX208V9R@80Shn?0P2DU9@208R8R080RHV9102<S8`209ZJVP80VIVI00<0
ZJVY0:f][@2][Jd00P2IVIT208^;R`80RXZ:0P24Q8@208V9R@80QXJ60P27QhL30<SPf080MgMg0P1m
OGd207alO080QhN70P1/K6`208:2PP80RXZ:00<0HF5Q09:BTP2BTY800P1MGEd208J6QP80PH610P20
P80208N7Q`80NWYj0P1^KVh206m_K`80MgMg0P2=SHd207YjNP80WinO0P1fMWH207AdM00307YjNP21
PH40PH610080PH610P1gMgL207moO`80Lg=c0P1nOWh408:2PPX0b>3H0P2MWId209JFUP80S8b<0P2:
RXX20:^[Z`80X:2P0P2?Shl30:RXZ080VYZJ0P2:RXX208^;R`80VIVI0P3Kfm/208j>SP80Rh^;0P29
RHT208F5Q@80Q8B40P2?Shl208V9R@80WIfM0P2EUID00`2BTY80SXj>08j>SP0209^KV`@0RHV90P2<
S8`208f=S@80Rh^;0P28R8P30<SPf080RHV90P2;Rh/207]kN`80IFEU0P1cLg<207]kN`80I6AT00<0
_[jn04i>CP1>CTh00P2HV9P207IfMP80QhN70P2BTY8205aLG080RHV9101oOgl208J6QP80Ph>30P1i
NGT208Z:RP80TI6A0P26QXH00`1QHF40PH610861P@02075aL@80RXZ:0P1fMWH209:BTP80LW9b0P23
Ph<208f=S@d0b>3H000;0<SPf080S8b<0P2?Shl208R8R080RHV9102<S8`208n?S`030:FUY@2ZZZX0
ZZZZ0080Zj^[0P2>SXh208Z:RP80Rh^;0P2JVYX208V9R@80Shn?0P2DU9@208R8R080RHV9102<S8`2
09ZJVP80VIVI00<0ZJVY0:f][@2][Jd00P2IVIT208^;R`80RXZ:0P24Q8@208V9R@80QXJ60P27QhL3
0<SPf080MgMg0P1mOGd207alO080QhN70P1/K6`208:2PP80RXZ:00<0HF5Q09:BTP2BTY800P1MGEd2
08J6QP80PH610P20P80208N7Q`80NWYj0P1^KVh206m_K`80MgMg0P2=SHd207YjNP80WinO0P1fMWH2
07AdM00307YjNP21PH40PH610080PH610P1gMgL207moO`80Lg=c0P1nOWh408:2PPX0b>3H0P2MWId2
09JFUP80S8b<0P2:RXX20:^[Z`80X:2P0P2?Shl30:RXZ080VYZJ0P2:RXX208^;R`80VIVI0P3Kfm/2
08j>SP80Rh^;0P29RHT208F5Q@80Q8B40P2?Shl208V9R@80WIfM0P2EUID00`2BTY80SXj>08j>SP02
09^KV`@0RHV90P2<S8`208f=S@80Rh^;0P28R8P30<SPf080RHV90P2;Rh/207]kN`80IFEU0P1cLg<2
07]kN`80I6AT00<0_[jn04i>CP1>CTh00P2HV9P207IfMP80QhN70P2BTY8205aLG080RHV9101oOgl2
08J6QP80Ph>30P1iNGT208Z:RP80TI6A0P26QXH00`1QHF40PH610861P@02075aL@80RXZ:0P1fMWH2
09:BTP80LW9b0P23Ph<208f=S@d0b>3H000;0<SPf080RHV90P2=SHd208^;R`80SXj>0P2=SHd209ZJ
VP80QXJ600<0UYJF0:^[Z`2[Zj/00P2IVIT209JFUP80Rh^;0P27QhL208:2PP80UIFE0P2<S8`208j>
SP80SHf=0P2<S8`209:BTP80XJ6Q0P24Q8@208f=S@0308b<S027QhL0QhN70080S8b<0P29RHT208n?
S`80TI6A102:RXX208n?S`<0b>3H0P2:RXX207emO@80Ogmo0P1IFET208N7Q`80GUiN0P1mOGd00`1[
Jf/0IVIV06IVIP0206MWI`80F5QH0P22PX8407inOP80OGem0P1oOgl207=cL`80KFe]0P27QhL208>3
P`80W9bL0P27QhL207]kN`<0P8200P1bLW8206e]K@80LW9b0P1gMgL207inOP80OGem0P1oOgl:0<SP
f080UYJF0P2CTi<208b<S080Rh^;0P2EUID20:>SX`80RHV900<0][Jf09jNWP2NWYh00P2BTY8208R8
R080TY:B0P1oOgl20:VYZ@80dm?C0P2;Rh/408N7Q`80Shn?0P2;Rh/20:RXZ080S8b<0P2@T9000`2A
TI40Ph>308>3P`0208j>SP80Ti>C0P2<S8`208f=S@80Ti>C0P2>SXh209FEU@<0b>3H0P1HF5P206QX
J080OWin0P1iNGT208:2PP80UIFE0P2<S8`00`2JVYX0KFe]06e]K@0208f=S@80M7Ad0P24Q8@207If
MP80QHF50P1lO7`207EeM@80PX:20P2;Rh/20861P@80Kfm_0P2RXZ820820P080M7Ad00<0QXJ607al
O01lO7`00P1dM7@208V9R@80MgMg0P2;Rh/208B4Q080K6a/0P2:RXX=0<SPf0002`38h=P208V9R@80
SHf=0P2;Rh/208j>SP80SHf=0P2JVYX208J6QP0309JFUP2[Zj/0Zj^[0080VIVI0P2FUYH208^;R`80
QhN70P22PX8209FEU@80S8b<0P2>SXh208f=S@80S8b<0P2BTY820:6QX@80Q8B40P2=SHd00`2<S8`0
QhN708N7Q`0208b<S080RHV90P2?Shl2096AT@@0RXZ:0P2?Shl30<SPf080RXZ:0P1mOGd207moO`80
FEUI0P27QhL205iNGP80OGem00<0Jf][06IVIP1VIVH00P1WIfL205QHF080PX:2101nOWh207emO@80
Ogmo0P1cLg<206e]K@80QhN70P23Ph<209bLW080QhN70P1kNg/30820P080LW9b0P1]KFd2079bLP80
MgMg0P1nOWh207emO@80Ogmo2P38h=P209JFUP80Ti>C0P2<S8`208^;R`80UIFE0P2SXj<208V9R@03
0;Jf]P2NWYh0WYjN0080TY:B0P28R8P209:BTP80Ogmo0P2YZJT20=?Cd`80Rh^;1027QhL208n?S`80
Rh^;0P2XZ:P208b<S080T92@00<0TI6A08>3P`23Ph<00P2>SXh209>CT`80S8b<0P2=SHd209>CT`80
SXj>0P2EUID30<SPf080F5QH0P1XJ6P207inOP80NGUi0P22PX8209FEU@80S8b<00<0VYZJ06e]K@1]
KFd00P2=SHd207AdM080Q8B40P1fMWH208F5Q@80O7al0P1eMGD208:2PP80Rh^;0P21PH4206m_K`80
XZ:R0P20P80207AdM00308J6QP1lO7`0O7al0080M7Ad0P29RHT207MgM`80Rh^;0P24Q8@206a/K080
RXZ:3@38h=P000/0b>3H0P2?Shl209BDU080Ti>C0P2IVIT208B4Q080TY:B0P2:RXX00`2ATI40X:2P
0:2PX0020:BTY080WinO0P27QhL208f=S@80QhN70P2:RXX209BDU0@0SHf=0P2EUID209>CT`80T92@
0P2JVYX208J6QP0309>CT`29RHT0RHV90080R8R80P2ATI420:b/[080SXj>0P29RHT208F5Q@80Rh^;
0`38h=P40820P080QHF50P20P80208:2PP80O7al0P29RHT00`2:RXX0XJ6Q0:6QX@020:2PX080HV9R
0P2@T90207moO`80NWYj0P1iNGT208^;R`80K6a/0P21PH4208b<S080GemO0P1]KFd207moO`80TI6A
00<0OGem06i^KP1^KVh00P2:RXX20861P@80G5aL0P1ZJVX208^;R`80PX:20P27QhL:0<SPf080WIfM
0P2HV9P208Z:RP80UIFE0P2RXZ8209BDU080Ti>C0`2>SXh20;Ng]`80UIFE0P2<S8`208Z:RP80Rh^;
0P2FUYH20>?Sh`80QhN70P2EUID208^;R`80TY:B0P2PX:0209RHV080YZJV00<0V9RH08F5Q@25QHD0
0P28R8P2092@T080Rh^;0P27QhL208Z:RP80S8b<0P25QHD30<SPf080GEeM0P1oOgl207inOP80NGUi
0P1YJFT207YjNP<0MWIf0P1XJ6P206YZJP80WinO0P2=SHd206a/K080NGUi0P2BTY82071`L080RHV9
0P1IFET207UiN@80Ng]k0P25QHD207emO@80PH6100<0T92@08f=S@2=SHd00P1nOWh408V9R@80QhN7
0P20P80208b<S080QXJ63@38h=P000/0b>3H0P2?Shl209BDU080Ti>C0P2IVIT208B4Q080TY:B0P2:
RXX00`2ATI40X:2P0:2PX0020:BTY080WinO0P27QhL208f=S@80QhN70P2:RXX209BDU0@0SHf=0P2E
UID209>CT`80T92@0P2JVYX208J6QP0309>CT`29RHT0RHV90080R8R80P2ATI420:b/[080SXj>0P29
RHT208F5Q@80Rh^;0`38h=P40820P080QHF50P20P80208:2PP80O7al0P29RHT00`2:RXX0XJ6Q0:6Q
X@020:2PX080HV9R0P2@T90207moO`80NWYj0P1iNGT208^;R`80K6a/0P21PH4208b<S080GemO0P1]
KFd207moO`80TI6A00<0OGem06i^KP1^KVh00P2:RXX20861P@80G5aL0P1ZJVX208^;R`80PX:20P27
QhL:0<SPf080WIfM0P2HV9P208Z:RP80UIFE0P2RXZ8209BDU080Ti>C0`2>SXh20;Ng]`80UIFE0P2<
S8`208Z:RP80Rh^;0P2FUYH20>?Sh`80QhN70P2EUID208^;R`80TY:B0P2PX:0209RHV080YZJV00<0
V9RH08F5Q@25QHD00P28R8P2092@T080Rh^;0P27QhL208Z:RP80S8b<0P25QHD30<SPf080GEeM0P1o
Ogl207inOP80NGUi0P1YJFT207YjNP<0MWIf0P1XJ6P206YZJP80WinO0P2=SHd206a/K080NGUi0P2B
TY82071`L080RHV90P1IFET207UiN@80Ng]k0P25QHD207emO@80PH6100<0T92@08f=S@2=SHd00P1n
OWh408V9R@80QhN70P20P80208b<S080QXJ63@38h=P000/0b>3H0P2CTi<209:BTP80VIVI0P27QhL2
08J6QP@0TI6A00<0UYJF0:6QX@2QXJ400P2KVi/20:b/[080ZJVY0P2>SXh208^;R`80S8b<0P2EUID2
09fMW@80PX:20P29RHT208b<S080/k>c0P2MWId20:>SX`030:VYZ@2DU9@0U9BD00@0U9BD0P2MWId2
09BDU080Shn?0P29RHT209NGU`<0b>3H0P2>SXh20861P@80QHF50P21PH4208>3P`80OGem0P1[Jf/0
0`1XJ6P0UIFE09FEU@0208J6QP80Hf=S0P2<S8`407IfMP80Ogmo0P1eMGD208N7Q`80U9BD0P2;Rh/2
07EeM@80QHF50P27QhL206m_K`0308B4Q02<S8`0S8b<0080LW9b0P21PH42059BDP80P8200P23Ph<2
0820P080QXJ62P38h=P209RHV080T92@0P2RXZ8208^;R`80V9RH0P2EUID20:BTY00309VIV@2>SXh0
SXj>0080UIFE0P2MWId20:2PX080TI6A0P2@T90208V9R@80a/K60P2/[:`208b<S080V9RH0P2>SXh2
08f=S@80Vi^K0P2VYZH00`2IVIT0WIfM09fMW@0208Z:RP80WIfM0P2BTY8208R8R080SHf=0P2@T902
096AT@<0b>3H0P2h^;P207IfMP80S8b<0P1oOgl20:BTY080Kfm_0P1CDe<00`1XJ6P0Shn?08n?S`02
08j>SP80Ph>30P1aLG4207inOP80PX:20P1kNg/208>3P`80IVIV0P2QXJ4208J6QP80N7Qh0P1mOGd2
0861P@80Kfm_00<0UYJF06m_K`1_Kfl00P1mOGd208f=S@80QXJ60P2:RXX208J6QP80KVi^0P1oOgl=
0<SPf0002`38h=P209>CT`80TY:B0P2IVIT208N7Q`80QXJ6102ATI400`2FUYH0XJ6Q0:6QX@0209^K
V`80[:b/0P2YZJT208j>SP80Rh^;0P2<S8`209FEU@80WIfM0P22PX8208V9R@80S8b<0P2c/k<209fM
W@80Xj>S00<0ZJVY09BDU02DU9@0102DU9@209fMW@80U9BD0P2?Shl208V9R@80UiNG0`38h=P208j>
SP80PH610P25QHD20861P@80Ph>30P1mOGd206][J`0306QXJ02EUID0UIFE0080QXJ60P1SHf<208b<
S0@0MWIf0P1oOgl207EeM@80QhN70P2DU9@208^;R`80MGEe0P25QHD208N7Q`80Kfm_00<0Q8B408b<
S02<S8`00P1bLW820861P@80DU9B0P20P80208>3P`80P8200P26QXH:0<SPf080V9RH0P2@T9020::R
XP80Rh^;0P2HV9P209FEU@80Y:BT00<0VIVI08j>SP2>SXh00P2EUID209fMW@80X:2P0P2ATI42092@
T080RHV90P36a/H20:b/[080S8b<0P2HV9P208j>SP80SHf=0P2KVi/20:JVYP0309VIV@2MWId0WIfM
0080RXZ:0P2MWId209:BTP80R8R80P2=SHd2092@T080TI6A0`38h=P20;Rh^080MWIf0P2<S8`207mo
O`80Y:BT0P1_Kfl205=CD`0306QXJ02?Shl0Shn?0080SXj>0P23Ph<2075aL@80OWin0P22PX8207]k
N`80Ph>30P1VIVH20:6QX@80QXJ60P1hN7P207emO@80PH610P1_Kfl00`2FUYH0Kfm_06m_K`0207em
O@80SHf=0P26QXH208Z:RP80QXJ60P1^KVh207moO`d0b>3H000;0<SPf080Xj>S0P2RXZ8209VIV@80
QhN70P2ATI4209bLW080VYZJ00<0Shn?08R8R028R8P00P2RXZ820:FUY@80[Jf]0P2=SHd2092@T080
SHf=0P2:RXX20;6a/@80Xj>S0P2CTi<208F5Q@80SHf=0P2:RXX208^;R`0309ZJVP2ATI40TI6A0080
SHf=0P29RHT209RHV080QHF51026QXH208R8R0<0b>3H0P2EUID207moO`80MGEe0P2<S8`206e]K@80
Rh^;0P2>SXh00`25QHD0Hf=S06=SH`0209jNWP80TI6A0P2;Rh/208N7Q`80M7Ad0P27QhL207MgM`80
LW9b0P20P80208F5Q@80OWin0P28R8P20861P@80Ogmo00<0Jf][08V9R@29RHT00P1hN7P208:2PP80
QhN70P1iNGT407moO`80N7Qh2P38h=P20:ZZZP80YjNW0P2<S8`209JFUP80[Jf]0P2d];@20<?3``03
09FEU@2GUiL0UiNG0080T92@0P2YZJT209VIV@80UIFE0P27QhL208j>SP80PX:20P3:b/X20:b/[080
UiNG0P2FUYH208B4Q080VIVI0P25QHD00`2h^;P0WYjN09jNWP0209>CT`80WYjN0P25QHD208b<S080
TI6A0P2HV9P208Z:RP<0b>3H0P24Q8@207EeM@80JVYZ0P1fMWH208B4Q080X:2P0P2FUYH00`21PH40
WinO09nOW`020:6QX@80J6QX0P2PX:0208Z:RP80NWYj0P28R8P2079bLP80Xj>S0P1]KFd208N7Q`80
Q8B40P2:RXX208^;R`80KFe]00<0RHV9051@D01@D5000P1XJ6P207moO`80MWIf0P1gMgL204m?C`80
L71`0P20P80=0<SPf0002`38h=P20:>SX`80XZ:R0P2IVIT208N7Q`80TI6A0P2LW9`209ZJVP0308n?
S`28R8P0R8R80080XZ:R0P2UYJD20:f][@80SHf=0P2@T90208f=S@80RXZ:0P2a/K420:>SX`80Ti>C
0P25QHD208f=S@80RXZ:0P2;Rh/00`2JVYX0TI6A096AT@0208f=S@80RHV90P2HV9P208F5Q@@0QXJ6
0P28R8P30<SPf080UIFE0P1oOgl207EeM@80S8b<0P1]KFd208^;R`80SXj>00<0QHF506=SH`1SHf<0
0P2NWYh2096AT@80Rh^;0P27QhL207AdM080QhN70P1gMgL2079bLP80P8200P25QHD207inOP80R8R8
0P21PH4207moO`0306][J`29RHT0RHV90080N7Qh0P22PX8208N7Q`80NGUi101oOgl207QhN0X0b>3H
0P2ZZZX20:NWY`80S8b<0P2FUYH20:f][@80];Bd0P33`l<00`2EUID0UiNG09NGU`02092@T080ZJVY
0P2IVIT209FEU@80QhN70P2>SXh208:2PP80b/[:0P2/[:`209NGU`80UYJF0P24Q8@209VIV@80QHF5
00<0^;Rh09jNWP2NWYh00P2CTi<209jNWP80QHF50P2<S8`2096AT@80V9RH0P2:RXX30<SPf080Q8B4
0P1eMGD206YZJP80MWIf0P24Q8@20:2PX080UYJF00<0PH6109nOW`2OWil00P2QXJ4206QXJ080X:2P
0P2:RXX207YjNP80R8R80P1bLW820:>SX`80KFe]0P27QhL208B4Q080RXZ:0P2;Rh/206e]K@0308V9
R@1@D500D51@0080J6QX0P1oOgl207IfMP80MgMg0P1?Cdl2071`L080P8203@38h=P000/0b>3H0P2K
Vi/209jNWP80T92@0P28R8P20:2PX080Rh^;0P2:RXX00`2<S8`0VYZJ09ZJVP020:ZZZP80Xj>S0P2Y
ZJT20:^[Z`80RHV90P27QhL208V9R@80T92@0P2][Jd20:2PX080R8R80P2ATI4209FEU@80SXj>00<0
U9BD08n?S`2?Shl00P2;Rh/209nOW`80RHV90P2?Shl208f=S@80QhN70P2<S8`30<SPf080Shn?0P28
R8P207IfMP80UiNG0P1RHV8206=SH`80Ng]k00<0QXJ607YjNP1jNWX00P23Ph<2075aL@80NWYj0P1U
IFD207EeM@80PH610P1hN7P206][J`80S8b<0P1XJ6P209>CT`80MGEe0P22PX8207YjNP03079bLP1X
J6P0J6QX0080JVYZ0P23Ph<206IVIP80UIFE0P28R8P208F5Q@80P8202P38h=P208Z:RP80Ti>C0P2;
Rh/208n?S`80VIVI0P2ATI4208J6QP0309^KV`2IVIT0VIVI0080/K6a0P2l_;`20;2`/080U9BD0P2R
XZ8208>3P`80SXj>0P26QXH20<g=c@80alO70P24Q8@209bLW080SHf=0P2IVIT00`2EUID0WinO09nO
W`0209ZJVP80bl_;0P26QXH209NGU`80UIFE0P2BTY8208J6QP<0b>3H0P25QHD2055AD@80QhN70P2K
Vi/208R8R080HV9R0P1oOgl00`1YJFT0P8200820P00205aLG080[:b/0P1BDU8208F5Q@80IVIV0P1i
NGT207]kN`80PX:20P2IVIT204A4A080YjNW0P21PH4207QhN080OGem00<0N7Qh06e]K@1]KFd00P19
BDT207emO@80FEUI0P28R8P207emO@80NWYj0P23Ph<=0<SPf0002`38h=P209^KV`80WYjN0P2@T902
08R8R080X:2P0P2;Rh/208Z:RP0308b<S02JVYX0VYZJ0080ZZZZ0P2SXj<20:VYZ@80Zj^[0P29RHT2
08N7Q`80RHV90P2@T9020:f][@80X:2P0P28R8P2096AT@80UIFE0P2>SXh00`2DU9@0Shn?08n?S`02
08^;R`80WinO0P29RHT208n?S`80SHf=0P27QhL208b<S0<0b>3H0P2?Shl208R8R080MWIf0P2GUiL2
069RHP80Hf=S0P1kNg/00`26QXH0NWYj07YjNP0208>3P`80LG5a0P1jNWX206EUI@80MGEe0P21PH42
07QhN080Jf][0P2<S8`206QXJ080Ti>C0P1eMGD208:2PP80NWYj00<0LW9b06QXJ01XJ6P00P1ZJVX2
08>3P`80IVIV0P2EUID208R8R080QHF50P20P80:0<SPf080RXZ:0P2CTi<208^;R`80Shn?0P2IVIT2
096AT@80QXJ600<0Vi^K09VIV@2IVIT00P2a/K420;bl_080/;2`0P2DU9@20::RXP80Ph>30P2>SXh2
08J6QP80cLg=0P37alL208B4Q080W9bL0P2=SHd209VIV@0309FEU@2OWil0WinO0080VYZJ0P3;bl/2
08J6QP80UiNG0P2EUID209:BTP80QXJ60`38h=P208F5Q@80DE5A0P27QhL209^KV`80R8R80P1RHV82
07moO`0306UYJ@20P800P8200080G5aL0P2/[:`2059BDP80QHF50P1VIVH207UiN@80Ng]k0P22PX82
09VIV@80A4A40P2WYjL20861P@80N7Qh0P1mOGd00`1hN7P0KFe]06e]K@0204U9B@80OGem0P1IFET2
08R8R080OGem0P1jNWX208>3P`d0b>3H000;0<SPf080RXZ:0P2d];@208f=S@80XJ6Q0P2TY:@208Z:
RP80QhN700<0UIFE09jNWP2NWYh00P2VYZH20:6QX@80YjNW0P2LW9`209:BTP80PH610P29RHT208J6
QP80VYZJ0P2SXj<209JFUP80Rh^;0P2BTY820:6QX@0309NGU`2YZJT0ZJVY0080XZ:R0P2DU9@2096A
T@80S8b<0P25QHD208J6QP80Rh^;0`38h=P206EUI@80QXJ60P27QhL207UiN@80U9BD0P23Ph<209NG
U`0305IFEP23Ph<0Ph>30080RHV90P2:RXX208N7Q`80Ng]k0P2QXJ4208Z:RP80Ng]k0P23Ph<207Ad
M080R8R80P27QhL207IfMP80T92@0P21PH400`25QHD0PH610861P@0206ATI080LW9b0P25QHD407al
O080PX:20P20P80:0<SPf080TY:B0P2GUiL208n?S`80[:b/0P27QhL209NGU`80UIFE00<0UiNG0:6Q
X@2QXJ400P2n_[h208Z:RP80[Jf]0P2:RXX20:6QX@80QhN70P2:RXX209>CT`80QXJ60P2][Jd20<[:
bP80SHf=0P2JVYX209bLW0030:NWY`2IVIT0VIVI0080XZ:R0P2>SXh209JFUP80Rh^;0P2IVIT408Z:
RP<0b>3H0P28R8P209FEU@80UiNG0P1dM7@208N7Q`80PH610P1oOgl00`2b/[80DE5A055AD@020:2P
X080P8200P22PX8207]kN`80T92@0P1eMGD407YjNP80OWin0P2MWId2096AT@80EEEE0P25QHD207in
OP030820P028R8P0R8R80080TI6A0P21PH420820P080Jf][0P2ATI4206e]K@80OWin3@38h=P000/0
b>3H0P2:RXX20;Bd]080SHf=0P2QXJ420:BTY080RXZ:0P27QhL00`2EUID0WYjN09jNWP020:JVYP80
XJ6Q0P2WYjL209bLW080TY:B0P21PH4208V9R@80QXJ60P2JVYX20:>SX`80UYJF0P2;Rh/209:BTP80
XJ6Q00<0UiNG0:VYZ@2YZJT00P2RXZ8209BDU080TI6A0P2<S8`208F5Q@80QXJ60P2;Rh/30<SPf080
IFEU0P26QXH208N7Q`80NGUi0P2DU9@208>3P`80UiNG00<0EUIF08>3P`23Ph<00P29RHT208Z:RP80
QhN70P1kNg/20:6QX@80RXZ:0P1kNg/208>3P`80M7Ad0P28R8P208N7Q`80MWIf0P2@T9020861P@03
08F5Q@21PH40PH610080I6AT0P1bLW8208F5Q@@0O7al0P22PX820820P0X0b>3H0P2BTY8209NGU`80
Shn?0P2/[:`208N7Q`80UiNG0P2EUID00`2GUiL0XJ6Q0:6QX@020;jn_P80RXZ:0P2][Jd208Z:RP80
XJ6Q0P27QhL208Z:RP80Ti>C0P26QXH20:f][@80b/[:0P2=SHd209ZJVP80W9bL00<0YjNW09VIV@2I
VIT00P2RXZ8208j>SP80UYJF0P2;Rh/209VIV@@0RXZ:0`38h=P208R8R080UIFE0P2GUiL207AdM080
QhN70P21PH4207moO`030;:b/P1ADE40DE5A0080X:2P0P20P80208:2PP80Ng]k0P2@T90207EeM@@0
NWYj0P1nOWh209fMW@80TI6A0P1EEED208F5Q@80OWin00<0P82008R8R028R8P00P2ATI420861P@80
P8200P1[Jf/2096AT@80KFe]0P1nOWh=0<SPf0002`38h=P208j>SP80Z:RX0P2BTY820:RXZ080Zj^[
102FUYH00`2NWYh0UYJF09JFUP020:b/[080[jn_0P2QXJ4209jNWP80YZJV0P2EUID208N7Q`80SXj>
0P2<S8`2092@T080RHV90P2LW9`208:2PP80S8b<00<0TY:B08N7Q`27QhL00P2@T90208n?S`80QHF5
0P2?Shl208R8R080Rh^;0P26QXH30<SPf080T92@0P1^KVh208N7Q`80Rh^;0P2GUiL206MWI`80Ph>3
00<0JVYZ08b<S02<S8`00P2IVIT2071`L080LG5a0P2IVIT207IfMP80QHF50P24Q8@207UiN@80MWIf
0P1cLg<207]kN`80OGem0P1oOgl20820P0<0S8b<0P27QhL208F5Q@80PH610P2;Rh/20861P@80Ogmo
0P27QhL:0<SPf080V9RH0P2YZJT20<W9b@80YJFU0P2SXj<208:2PP80Shn?00<0/[:b0;Vi^@2i^KT0
0P29RHT209RHV080ZJVY0P2WYjL208^;R`80WinO102;Rh/208j>SP80UiNG0P2=SHd20;:b/P80Ph>3
0P2;Rh/00`2=SHd0QXJ608J6QP0209ZJVP80WIfM0P2GUiL208R8R080RHV90P2=SHd208Z:RP<0b>3H
0P1VIVH208f=S@80VYZJ0P1XJ6P207emO@80SHf=0P1TI6@00`2c/k<0Ti>C09>CT`0207alO080UIFE
0P2SXj<20;Vi^@80VIVI0P1hN7P208b<S080QHF50P2?Shl207]kN`80QXJ60P23Ph<20;>c/`80RHV9
00<0S8b<0820P020P8000P1jNWX209jNWP80S8b<0P1kNg/207QhN080QHF50P1dM7@=0<SPf0002`38
h=P208j>SP80Z:RX0P2BTY820:RXZ080Zj^[102FUYH00`2NWYh0UYJF09JFUP020:b/[080[jn_0P2Q
XJ4209jNWP80YZJV0P2EUID208N7Q`80SXj>0P2<S8`2092@T080RHV90P2LW9`208:2PP80S8b<00<0
TY:B08N7Q`27QhL00P2@T90208n?S`80QHF50P2?Shl208R8R080Rh^;0P26QXH30<SPf080T92@0P1^
KVh208N7Q`80Rh^;0P2GUiL206MWI`80Ph>300<0JVYZ08b<S02<S8`00P2IVIT2071`L080LG5a0P2I
VIT207IfMP80QHF50P24Q8@207UiN@80MWIf0P1cLg<207]kN`80OGem0P1oOgl20820P0<0S8b<0P27
QhL208F5Q@80PH610P2;Rh/20861P@80Ogmo0P27QhL:0<SPf080V9RH0P2YZJT20<W9b@80YJFU0P2S
Xj<208:2PP80Shn?00<0/[:b0;Vi^@2i^KT00P29RHT209RHV080ZJVY0P2WYjL208^;R`80WinO102;
Rh/208j>SP80UiNG0P2=SHd20;:b/P80Ph>30P2;Rh/00`2=SHd0QXJ608J6QP0209ZJVP80WIfM0P2G
UiL208R8R080RHV90P2=SHd208Z:RP<0b>3H0P1VIVH208f=S@80VYZJ0P1XJ6P207emO@80SHf=0P1T
I6@00`2c/k<0Ti>C09>CT`0207alO080UIFE0P2SXj<20;Vi^@80VIVI0P1hN7P208b<S080QHF50P2?
Shl207]kN`80QXJ60P23Ph<20;>c/`80RHV900<0S8b<0820P020P8000P1jNWX209jNWP80S8b<0P1k
Ng/207QhN080QHF50P1dM7@=0<SPf0002`38h=P209bLW080TI6A0P2<S8`209nOW`80QHF50P28R8P2
09jNWP0309nOW`2VYZH0YZJV0080X:2P0P2SXj<2092@T080Zj^[0P2FUYH20:BTY080QXJ60P2;Rh/4
08j>SP80Ph>30P2ATI4208^;R`80S8b<00<0SXj>096AT@2ATI400P2>SXh20861P@80Q8B40P27QhL2
08>3P`80QHF50P29RHT30<SPf080UIFE0P1lO7`208^;R`80J6QX0P1iNGT20820P080OWin00<0Vi^K
08:2PP22PX800P21PH42079bLP80Rh^;0P1kNg/207alO080TI6A0P2BTY8208>3P`80OWin0P21PH42
07IfMP80QhN70P1hN7P2075aL@0306MWI`23Ph<0Ph>30080Ogmo0P24Q8@207inOP80NGUi0P20P802
0861P@80N7Qh2P38h=P209^KV`80V9RH0P2JVYX209FEU@80U9BD0P2GUiL209RHV00309NGU`2KVi/0
Vi^K0080Vi^K0P2ATI4208^;R`80e]KF0P2HV9P20;fm_@80V9RH0P28R8P208n?S`80SXj>0P27QhL2
08n?S`80`l?30P2JVYX00`2HV9P0Rh^;08^;R`0209JFUP80RHV90P2HV9P208Z:RP80Shn?0P2<S8`2
08Z:RP<0b>3H0P1ADE4208>3P`80LW9b0P2FUYH208R8R080WIfM0P2:RXX00`1]KFd0O7al07alO002
06e]K@80QHF50P1_Kfl208:2PP80T92@0P2NWYh206a/K080Rh^;0P1VIVH208F5Q@80Ogmo0P1nOWh2
0:b/[080RXZ:00<0T92@08J6QP26QXH0101oOgl20820P080QhN7101hN7P208^;R`d0b>3H000;0<SP
f080WYjN0P2JVYX209FEU@80ZZZZ0P29RHT208j>SP80W9bL00<0YJFU09^KV`2KVi/00P2SXj<20:JV
YP80VIVI0P2BTY820:FUY@80UiNG0P2LW9`408f=S@80RHV90P27QhL208n?S`80Rh^;0P28R8P00`2B
TY80S8b<08b<S00208F5Q@80SXj>1028R8P208>3P`80Rh^;0P29RHT30<SPf080QhN70P1nOWh208:2
PP80KVi^0P25QHD206][J`80O7al00<0M7Ad0861P@21PH400P1eMGD208j>SP80HF5Q0P1dM7@206QX
J080R8R80P1GEeL209fMW@80Ph>30P21PH4207alO080KFe]0P1kNg/207YjNP030820P01nOWh0OWin
0080NGUi0P21PH4208Z:RP80MWIf0P1mOGd208R8R080Ng]k2P38h=P208^;R`80X:2P0P2RXZ820<S8
b080UIFE0P2GUiL208j>SP030:JVYP2FUYH0UYJF0080XZ:R0P2i^KT20;6a/@80S8b<0P2][Jd2092@
T080VYZJ0P2;Rh/2096AT@80R8R80P2=SHd208Z:RP80QHF50P29RHT00`2DU9@0P8200820P00208j>
SP80RHV90P2;Rh/209:BTP80QhN70P2<S8`208V9R@<0b>3H0P2IVIT2092@T080JFUY0P29RHT20861
P@80MWIf0P1dM7@00`1ZJVX0WIfM09fMW@0206IVIP80]kNg0P1`L70207IfMP80YJFU0P2KVi/206][
J`80TY:B0P1fMWH20820P080Ogmo0P1jNWX208^;R`80R8R800<0QHF508>3P`23Ph<00P1iNGT206UY
J@80QhN70P23Ph<207inOP80S8b<0P25QHD=0<SPf0002`38h=P209jNWP80VYZJ0P2EUID20:ZZZP80
RHV90P2>SXh209bLW0030:FUY@2KVi/0Vi^K0080Xj>S0P2VYZH209VIV@80TY:B0P2UYJD209NGU`80
W9bL102=SHd208V9R@80QhN70P2?Shl208^;R`80R8R800<0TY:B08b<S02<S8`00P25QHD208j>SP@0
R8R80P23Ph<208^;R`80RHV90`38h=P208N7Q`80OWin0P22PX8206i^KP80QHF50P1[Jf/207alO003
07AdM021PH40PH610080MGEe0P2>SXh2065QH@80M7Ad0P1XJ6P208R8R080EeMG0P2MWId208>3P`80
PH610P1lO7`206e]K@80Ng]k0P1jNWX00`20P800OWin07inOP0207UiN@80PH610P2:RXX207IfMP80
OGem0P28R8P207]kN`X0b>3H0P2;Rh/20:2PX080XZ:R0P38b<P209FEU@80UiNG0P2>SXh00`2VYZH0
UYJF09JFUP020::RXP80^KVi0P2a/K4208b<S080[Jf]0P2@T90209ZJVP80Rh^;0P2ATI4208R8R080
SHf=0P2:RXX208F5Q@80RHV900<0U9BD0820P020P8000P2>SXh208V9R@80Rh^;0P2BTY8208N7Q`80
S8b<0P29RHT30<SPf080VIVI0P2@T90206UYJ@80RHV90P21PH4207IfMP80M7Ad00<0JVYZ09fMW@2M
WId00P1VIVH20;Ng]`80L71`0P1fMWH20:FUY@80Vi^K0P1[Jf/209:BTP80MWIf0P20P80207moO`80
NWYj0P2;Rh/208R8R00308F5Q@23Ph<0Ph>30080NGUi0P1YJFT208N7Q`80Ph>30P1nOWh208b<S080
QHF53@38h=P000/0b>3H0P2NWYh20:f][@80Rh^;0P2CTi<20:ZZZP80T92@0P2DU9@00`2EUID0WIfM
09fMW@0209jNWP80U9BD0P2@T90208R8R080WIfM0P2IVIT209fMW@80YjNW0P27QhL208b<S080SHf=
0P24Q8@20:VYZ@80UIFE00<0RXZ:08F5Q@25QHD00P27QhL208J6QP80QhN70P2<S8`208B4Q080R8R8
0P2:RXX30<SPf080OWin0P2;Rh/207inOP80PH610P29RHT207moO`80LG5a00<0K6a/09bLW02LW9`0
0P1PH60206i^KP80R8R80P1/K6`207=cL`80G5aL0P2MWId206a/K080PX:20P1kNg/208J6QP80OWin
0P22PX8208R8R00308J6QP1hN7P0N7Qh0080RXZ:0P1mOGd208J6QP80NGUi0P22PX8208>3P`80PH61
2P38h=P20:RXZ080U9BD0P2KVi/409fMW@80WinO0P2;Rh/00`2PX:00RHV908V9R@0209nOW`80ZJVY
0P2SXj<208V9R@80YjNW0P2l_;`208Z:RP80YZJV0P24Q8@208V9R@80QHF50P2;Rh/209JFUP80TI6A
00<0QXJ6092@T02@T9000P25QHD2096AT@80UiNG0P2;Rh/208b<S080SXj>0P27QhL30<SPf080PX:2
0P1nOWh204];B`80FEUI0P1dM7@206m_K`<0OGem0P1hN7P20820P080L71`0P1nOWh208^;R`80QHF5
0P2<S8`20;Vi^@80@D510P2ATI4207alO080R8R80P1cLg<2096AT@80QXJ600<0PH6107EeM@1eMGD0
0P2;Rh/206m_K`80Ogmo0P27QhL207emO@80R8R80P1mOGd=0<SPf0002`38h=P209jNWP80[Jf]0P2;
Rh/209>CT`80ZZZZ0P2@T90209BDU00309FEU@2MWId0WIfM0080WYjN0P2DU9@2092@T080R8R80P2M
WId209VIV@80WIfM0P2WYjL208N7Q`80S8b<0P2=SHd208B4Q080ZJVY0P2EUID00`2:RXX0QHF508F5
Q@0208N7Q`80QXJ60P27QhL208b<S080Q8B40P28R8P208Z:RP<0b>3H0P1nOWh208^;R`80OWin0P21
PH4208V9R@80Ogmo0P1aLG400`1/K6`0W9bL09bLW002061PH080KVi^0P28R8P206a/K080Lg=c0P1L
G5`209fMW@80K6a/0P22PX8207]kN`80QXJ60P1nOWh208:2PP80R8R800<0QXJ607QhN01hN7P00P2:
RXX207emO@80QXJ60P1iNGT208:2PP80Ph>30P21PH4:0<SPf080Z:RX0P2DU9@209^KV`@0WIfM0P2O
Wil208^;R`030:2PX029RHT0RHV90080WinO0P2YZJT20:>SX`80RHV90P2WYjL20;bl_080RXZ:0P2V
YZH208B4Q080RHV90P25QHD208^;R`80UYJF0P2ATI400`26QXH0T92@092@T00208F5Q@80TI6A0P2G
UiL208^;R`80S8b<0P2>SXh208N7Q`<0b>3H0P22PX8207inOP80Bd];0P1IFET207AdM080Kfm_0`1m
OGd207QhN080P8200P1`L70207inOP80Rh^;0P25QHD208b<S080^KVi0P11@D42096AT@80O7al0P28
R8P207=cL`80TI6A0P26QXH00`21PH40MGEe07EeM@0208^;R`80Kfm_0P1oOgl208N7Q`80OGem0P28
R8P207emO@d0b>3H000;0<SPf080TI6A0P2?Shl20;2`/080UiNG0P2EUID208Z:RP80WYjN00<0YJFU
09BDU02DU9@00P2JVYX20::RXP80WYjN0P2ATI440:JVYP80YJFU0P2?Shl408b<S080SHf=0P2GUiL2
0:VYZ@80SXj>00<0QhN708:2PP22PX800P2HV9P208b<S080TI6A1029RHT208b<S080Shn?0`38h=P2
08B4Q080Lg=c0P2@T90207=cL`80N7Qh0P1iNGT208F5Q@0308Z:RP1fMWH0MWIf0080Shn?0P1]KFd2
05eMG@80Jf][0P2:RXX207QhN080Rh^;0P20P802092@T080Lg=c0P22PX8206][J`80Ng]k0P1XJ6P0
0`2;Rh/0OGem07emO@0208b<S080SXj>0P21PH42071`L080OGem1024Q8@:0<SPf080UIFE0P2FUYH2
0:JVYP80Ti>C0P2YZJT209bLW080YJFU00<0R8R808n?S`2?Shl00P2?Shl209JFUP80SHf=0P2EUID2
0::RXP80]KFe0P2d];@20<O7a`80^;Rh0P28R8P209BDU080Q8B40P2@T90208N7Q`03092@T02:RXX0
RXZ:0080VYZJ0P2HV9P208b<S080QXJ60P29RHT409BDU0<0b>3H0P1XJ6P208R8R080T92@0P21PH42
07emO@80MGEe0P1fMWH00`25QHD0WIfM09fMW@0208j>SP80VYZJ0P1iNGT206i^KP80QhN70P28R8P2
07UiN@80KFe]0P1QHF4207UiN@80OWin0P25QHD2079bLP80SXj>00<0RHV908:2PP22PX800P25QHD2
04Q8B080T92@0P24Q8@208:2PP80Ph>30P2<S8`=0<SPf0002`38h=P2096AT@80Shn?0P2`/;0209NG
U`80UIFE0P2:RXX209jNWP030:FUY@2DU9@0U9BD0080VYZJ0P2RXZ8209jNWP80TI6A102VYZH20:FU
Y@80Shn?102<S8`208f=S@80UiNG0P2YZJT208j>SP0308N7Q`22PX80PX:20080V9RH0P2<S8`2096A
T@@0RHV90P2<S8`208n?S`<0b>3H0P24Q8@207=cL`80T92@0P1cLg<207QhN080NGUi0P25QHD00`2:
RXX0MWIf07IfMP0208n?S`80KFe]0P1MGEd206][J`80RXZ:0P1hN7P208^;R`80P8200P2@T90207=c
L`80PX:20P1[Jf/207]kN`80J6QX00<0Rh^;07emO@1mOGd00P2<S8`208j>SP80PH610P1`L70207em
O@@0Q8B42P38h=P209FEU@80UYJF0P2VYZH209>CT`80ZJVY0P2LW9`20:FUY@0308R8R02?Shl0Shn?
0080Shn?0P2FUYH208f=S@80UIFE0P2RXZ820;Fe]@80];Bd0P37alL20;Rh^080R8R80P2DU9@208B4
Q080T92@0P27QhL00`2@T900RXZ:08Z:RP0209ZJVP80V9RH0P2<S8`208J6QP80RHV9102DU9@30<SP
f080J6QX0P28R8P2092@T080PH610P1mOGd207EeM@80MWIf00<0QHF509fMW@2MWId00P2>SXh209ZJ
VP80NGUi0P1^KVh208N7Q`80R8R80P1iNGT206e]K@80HF5Q0P1iNGT207inOP80QHF50P1bLW8208j>
SP0308V9R@22PX80PX:20080QHF50P18B4P2092@T080Q8B40P22PX8208>3P`80S8b<3@38h=P000/0
b>3H0P2?Shl208f=S@80[Jf]0P2IVIT209RHV080UIFE0P29RHT00`2<S8`0WIfM09fMW@0209>CT`80
Y:BT0P2DU9@208b<S080WinO0P2IVIT20::RXP80T92@0P2FUYH208n?S`80Ti>C0P2<S8`209JFUP80
TY:B00<0RHV908f=S@2=SHd0102;Rh/208j>SP80QHF50P21PH4208N7Q`80Ph>30`38h=P206EUI@80
L71`0P1kNg/207MgM`80U9BD0P1UIFD207IfMP0308N7Q`20P800P8200080Q8B40P2:RXX206MWI`80
QXJ60P1PH60207YjNP80Rh^;0P2<S8`406YZJP80MGEe0P1/K6`2079bLP80MWIf00<0Ph>308N7Q`27
QhL0101kNg/207YjNP80R8R80P23Ph<207UiN@80Ng]k2P38h=P209BDU080WinO0P2=SHd209RHV080
Rh^;0P2NWYh20:2PX0030:ZZZP2GUiL0UiNG00@0Vi^K0P2IVIT209^KV`80UYJF0P2ATI420:BTY080
Ti>C0P2MWId209>CT`80QHF50P2LW9`208Z:RP80U9BD00<0RHV908F5Q@25QHD00P27QhL209FEU@80
V9RH0P2;Rh/208R8R080Q8B40P2:RXX30<SPf080MGEe0P1kNg/20820P080PH610P20P8020:^[Z`80
HF5Q00<0KFe]09jNWP2NWYh00P2EUID206QXJ080KVi^0P23Ph<209FEU@80P8200P1XJ6P207IfMP80
Q8B40P1jNWX20861P@80IfMW0P28R8P209ZJVP0306IVIP2:RXX0RXZ:0080OGem0P22PX8207MgM`80
Lg=c0P1nOWh207YjNP80Ph>33@38h=P000/0b>3H0P2?Shl208f=S@80[Jf]0P2IVIT209RHV080UIFE
0P29RHT00`2<S8`0WIfM09fMW@0209>CT`80Y:BT0P2DU9@208b<S080WinO0P2IVIT20::RXP80T92@
0P2FUYH208n?S`80Ti>C0P2<S8`209JFUP80TY:B00<0RHV908f=S@2=SHd0102;Rh/208j>SP80QHF5
0P21PH4208N7Q`80Ph>30`38h=P206EUI@80L71`0P1kNg/207MgM`80U9BD0P1UIFD207IfMP0308N7
Q`20P800P8200080Q8B40P2:RXX206MWI`80QXJ60P1PH60207YjNP80Rh^;0P2<S8`406YZJP80MGEe
0P1/K6`2079bLP80MWIf00<0Ph>308N7Q`27QhL0101kNg/207YjNP80R8R80P23Ph<207UiN@80Ng]k
2P38h=P209BDU080WinO0P2=SHd209RHV080Rh^;0P2NWYh20:2PX0030:ZZZP2GUiL0UiNG00@0Vi^K
0P2IVIT209^KV`80UYJF0P2ATI420:BTY080Ti>C0P2MWId209>CT`80QHF50P2LW9`208Z:RP80U9BD
00<0RHV908F5Q@25QHD00P27QhL209FEU@80V9RH0P2;Rh/208R8R080Q8B40P2:RXX30<SPf080MGEe
0P1kNg/20820P080PH610P20P8020:^[Z`80HF5Q00<0KFe]09jNWP2NWYh00P2EUID206QXJ080KVi^
0P23Ph<209FEU@80P8200P1XJ6P207IfMP80Q8B40P1jNWX20861P@80IfMW0P28R8P209ZJVP0306IV
IP2:RXX0RXZ:0080OGem0P22PX8207MgM`80Lg=c0P1nOWh207YjNP80Ph>33@38h=P000/0b>3H0P2D
U9@209RHV080ZJVY0P26QXH209NGU`80WinO0P2?Shl00`2>SXh0Vi^K09^KV`0209:BTP80[:b/0P2S
Xj<209jNWP80VIVI0P25QHD209FEU@80Zj^[0P2<S8`209fMW@80R8R80P25QHD20:6QX@80TI6A00<0
T92@09>CT`2CTi<01P2:RXX209>CT`80SXj>0P2;Rh/208f=S@<0b>3H0P29RHT208j>SP80KFe]0P25
QHD208Z:RP80OWin0P2<S8`00`2:RXX0LG5a075aL@0208B4Q080Jf][0P2@T902061PH080O7al0P2;
Rh/208V9R@80L71`0P1FEUH208n?S`80RHV90P2ATI4206IVIP80QhN700<0Jf][07alO01lO7`00P1h
N7P206UYJ@80KVi^0P1YJFT208F5Q@80MGEe0P1nOWh:0<SPf080Rh^;0P2IVIT20:RXZ080RXZ:0P2<
S8`209bLW080TI6A00<0XJ6Q09:BTP2BTY800P2DU9@20::RXP80T92@0P2EUID208n?S`80QXJ60P2D
U9@209jNWP80RXZ:102HV9P2092@T080PX:20P2?Shl00`26QXH0W9bL09bLW00208>3P`80PX:20P2:
RXX208b<S080SXj>102=SHd30<SPf080PH610P2BTY8208F5Q@80OWin0P29RHT2096AT@80Jf][00<0
O7al07]kN`1kNg/00P20P80209BDU080JFUY0P2:RXX20861P@80S8b<0P2?Shl207alO080VIVI0P2R
XZ8206m_K`80Ogmo0P2ATI4207QhN0030820P01nOWh0OWin0080Ogmo0P1mOGd208^;R`80QHF50P1f
MWH208J6QP80QHF53@38h=P000/0b>3H0P2DU9@209RHV080ZJVY0P26QXH209NGU`80WinO0P2?Shl0
0`2>SXh0Vi^K09^KV`0209:BTP80[:b/0P2SXj<209jNWP80VIVI0P25QHD209FEU@80Zj^[0P2<S8`2
09fMW@80R8R80P25QHD20:6QX@80TI6A00<0T92@09>CT`2CTi<01P2:RXX209>CT`80SXj>0P2;Rh/2
08f=S@<0b>3H0P29RHT208j>SP80KFe]0P25QHD208Z:RP80OWin0P2<S8`00`2:RXX0LG5a075aL@02
08B4Q080Jf][0P2@T902061PH080O7al0P2;Rh/208V9R@80L71`0P1FEUH208n?S`80RHV90P2ATI42
06IVIP80QhN700<0Jf][07alO01lO7`00P1hN7P206UYJ@80KVi^0P1YJFT208F5Q@80MGEe0P1nOWh:
0<SPf080Rh^;0P2IVIT20:RXZ080RXZ:0P2<S8`209bLW080TI6A00<0XJ6Q09:BTP2BTY800P2DU9@2
0::RXP80T92@0P2EUID208n?S`80QXJ60P2DU9@209jNWP80RXZ:102HV9P2092@T080PX:20P2?Shl0
0`26QXH0W9bL09bLW00208>3P`80PX:20P2:RXX208b<S080SXj>102=SHd30<SPf080PH610P2BTY82
08F5Q@80OWin0P29RHT2096AT@80Jf][00<0O7al07]kN`1kNg/00P20P80209BDU080JFUY0P2:RXX2
0861P@80S8b<0P2?Shl207alO080VIVI0P2RXZ8206m_K`80Ogmo0P2ATI4207QhN0030820P01nOWh0
OWin0080Ogmo0P1mOGd208^;R`80QHF50P1fMWH208J6QP80QHF53@38h=P000/0b>3H0P2KVi/209:B
TP80WinO0P2?Shl408^;R`80Shn?00<0VYZJ08f=S@2=SHd00P2OWil20;Rh^080X:2P0P2NWYh209bL
W080Ti>C0P29RHT208^;R`80UIFE0P2<S8`20:JVYP80W9bL0P2QXJ4209bLW00309FEU@29RHT0RHV9
0080SXj>0P2=SHd408n?S`80QXJ60P2:RXX2092@T0<0b>3H0P2PX:0208>3P`80QhN70P2CTi<208V9
R@80QXJ60P1dM7@00`1fMWH0MGEe07EeM@0208J6QP80KFe]0P2DU9@207]kN`80M7Ad0P26QXH2079b
LP80OWin0P21PH42079bLP80X:2P0P1gMgL206a/K080U9BD00<0T92@08>3P`23Ph<01021PH4208N7
Q`@0O7al0P27QhL207inOPX0b>3H0P2b/[8209:BTP80U9BD0P2NWYh208Z:RP80Shn?0P2ATI400`2a
/K40SXj>08j>SP0209RHV080TI6A0P2GUiL209>CT`80XJ6Q0P2GUiL209^KV`80SHf=0P2_[jl209bL
W080SXj>0P2MWId209VIV@80T92@00<0UiNG08F5Q@25QHD00P2:RXX408j>SP80S8b<0P2FUYH208Z:
RP80Shn?0`38h=P20:JVYP80PX:20P2KVi/207AdM080SHf=0P26QXH208j>SP0309jNWP26QXH0QXJ6
0080PX:20P1cLg<208^;R`80U9BD0P1cLg<208F5Q@80KVi^0P1nOWh2065QH@80QHF50P1dM7@207em
O@80XJ6Q0P2=SHd00`2HV9P0PH610861P@0407UiN@80RHV90P2?Shl208R8R080NGUi0P1jNWX=0<SP
f0002`38h=P209^KV`80TY:B0P2OWil208n?S`@0Rh^;0P2?Shl00`2JVYX0SHf=08f=S@0209nOW`80
^;Rh0P2PX:0209jNWP80W9bL0P2CTi<208V9R@80Rh^;0P2EUID208b<S080YZJV0P2LW9`20:6QX@80
W9bL00<0UIFE08V9R@29RHT00P2>SXh208f=S@@0Shn?0P26QXH208Z:RP80T92@0`38h=P20:2PX080
Ph>30P27QhL209>CT`80RHV90P26QXH207AdM00307IfMP1eMGD0MGEe0080QXJ60P1]KFd209BDU080
Ng]k0P1dM7@208J6QP80LW9b0P1nOWh20861P@80LW9b0P2PX:0207MgM`80K6a/0P2DU9@00`2@T900
Ph>308>3P`040861P@80QhN7101lO7`208N7Q`80OWin2P38h=P20;:b/P80TY:B0P2DU9@209jNWP80
RXZ:0P2?Shl2096AT@030;6a/@2>SXh0SXj>0080V9RH0P2ATI4209NGU`80Ti>C0P2QXJ4209NGU`80
Vi^K0P2=SHd20:n_[`80W9bL0P2>SXh209fMW@80VIVI0P2@T9000`2GUiL0QHF508F5Q@0208Z:RP@0
SXj>0P2<S8`209JFUP80RXZ:0P2?Shl30<SPf080YZJV0P22PX8209^KV`80M7Ad0P2=SHd208J6QP80
SXj>00<0WYjN08J6QP26QXH00P22PX8207=cL`80Rh^;0P2DU9@207=cL`80QHF50P1^KVh207inOP80
HF5Q0P25QHD207AdM080OGem0P2QXJ4208f=S@0309RHV021PH40PH6100@0NGUi0P29RHT208n?S`80
R8R80P1iNGT207YjNPd0b>3H000;0<SPf080U9BD0P2FUYH409ZJVP80Ti>C0P2;Rh/208n?S`<0UYJF
0P2DU9@209RHV080XJ6Q0P2a/K4209BDU080Q8B40P29RHT208^;R`80TY:B0P2CTi<20:>SX`80XZ:R
0P2QXJ4209BDU00308R8R024Q8@0Q8B40080QXJ60P2;Rh/608J6QP80T92@0P2=SHd30<SPf080Hf=S
0P26QXH208N7Q`80SXj>0P2?Shl207moO`80U9BD00<0IFEU08V9R@29RHT00P1MGEd207MgM`80Kfm_
0P25QHD209BDU080N7Qh0P25QHD207=cL`80Ogmo0P20P80208^;R`80KFe]0P2CTi<206e]K@0307em
O@23Ph<0Ph>30080Ogmo0P23Ph<207alO080NGUi0P1`L70208>3P`80NGUi2P38h=P208N7Q`80V9RH
0P2JVYX2096AT@80U9BD0P2<S8`209BDU0030:f][@2SXj<0Xj>S0080VIVI0P2KVi/20;Rh^080Shn?
0P2CTi<20:2PX080U9BD0P2?Shl20:NWY`80X:2P0P2NWYh208b<S080UYJF0P27QhL00`2>SXh0Rh^;
08^;R`0208V9R@80R8R81029RHT208R8R080U9BD0P2<S8`30<SPf080O7al0P2KVi/2051@D080Ph>3
0P20P80207]kN`80OWin00<0E5AD08>3P`23Ph<00P2RXZ8208^;R`80_[jn0P2ATI4206MWI`80QXJ6
0P1ZJVX205iNGP80LG5a0P1gMgL205UIF@80KVi^0P1MGEd20820P00308F5Q@2<S8`0S8b<0080NGUi
0P1dM7@206EUI@80QXJ60P1OGel206i^KP80OWin3@38h=P000/0b>3H0P2DU9@209JFUP@0VYZJ0P2C
Ti<208^;R`80Shn?0`2FUYH209BDU080V9RH0P2QXJ420;6a/@80U9BD0P24Q8@208V9R@80Rh^;0P2B
TY8209>CT`80Xj>S0P2RXZ820:6QX@80U9BD00<0R8R808B4Q024Q8@00P26QXH208^;R`H0QXJ60P2@
T90208f=S@<0b>3H0P1SHf<208J6QP80QhN70P2>SXh208n?S`80Ogmo0P2DU9@00`1UIFD0RHV908V9
R@0205eMG@80MgMg0P1_Kfl208F5Q@80U9BD0P1hN7P208F5Q@80Lg=c0P1oOgl20820P080Rh^;0P1]
KFd209>CT`80KFe]00<0OGem08>3P`23Ph<00P1oOgl208>3P`80O7al0P1iNGT2071`L080Ph>30P1i
NGT:0<SPf080QhN70P2HV9P209ZJVP80TI6A0P2DU9@208b<S080U9BD00<0[Jf]0:>SX`2SXj<00P2I
VIT209^KV`80^;Rh0P2?Shl209>CT`80X:2P0P2DU9@208n?S`80YjNW0P2PX:0209jNWP80S8b<0P2F
UYH208N7Q`0308j>SP2;Rh/0Rh^;0080RHV90P28R8P408V9R@80R8R80P2DU9@208b<S0<0b>3H0P1l
O7`209^KV`80D51@0P23Ph<20820P080Ng]k0P1nOWh00`1DE5@0Ph>308>3P`020::RXP80Rh^;0P2n
_[h2096AT@80IfMW0P26QXH206YZJP80GUiN0P1aLG4207MgM`80FEUI0P1^KVh205eMG@80P82000<0
QHF508b<S02<S8`00P1iNGT207AdM080IFEU0P26QXH205mOG`80KVi^0P1nOWh=0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf0002`38h=Pn
0820P0<0b>3H?P20P80:0<SPf080Lg=c0P24Q8@209fMW@80RHV90P22PX8207MgM`80SHf=00<0S8b<
07alO01lO7`00P20P80207QhN080Ph>30P1nOWh208^;R`80QXJ60P1oOgl208F5Q@80Ng]k0P21PH44
08:2PP80MWIf0P25QHD00`2;Rh/0Ogmo07moO`0208:2PP80QHF50P1mOGd208B4Q080M7Ad0P1lO7`2
07moO`<0b>3H0P1cLg<206e]K@@0L71`0P2=SHd208B4Q080IVIV00<0KVi^092@T02@T9000P21PH42
08:2PP80LW9b0P1_Kfl20820P080M7Ad0P1eMGD208J6QP80QhN70P1lO7`207UiN@80MGEe0P20P802
08:2PP0307]kN`2@T900T92@0080QhN70P1kNg/208Z:RP80QhN70P1kNg/207inOP80KFe]3@38h=P0
00/0b>3H?P20P8030<SPf3h0P8202P38h=P207=cL`80Q8B40P2MWId208V9R@80PX:20P1gMgL208f=
S@0308b<S01lO7`0O7al0080P8200P1hN7P208>3P`80OWin0P2;Rh/208J6QP80Ogmo0P25QHD207]k
N`80PH611022PX8207IfMP80QHF500<0Rh^;07moO`1oOgl00P22PX8208F5Q@80OGem0P24Q8@207Ad
M080O7al0P1oOgl30<SPf080Lg=c0P1]KFd4071`L080SHf=0P24Q8@206IVIP0306i^KP2@T900T92@
0080PH610P22PX82079bLP80Kfm_0P20P80207AdM080MGEe0P26QXH208N7Q`80O7al0P1iNGT207Ee
M@80P8200P22PX800`1kNg/0T92@092@T00208N7Q`80Ng]k0P2:RXX208N7Q`80Ng]k0P1nOWh206e]
K@d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P21PH4208:2PP80PH610P1iNGT408B4Q080
IfMW00<0Hf=S09BDU02DU9@00P2=SHd207QhN080NWYj0P29RHT207]kN`80N7Qh0P1fMWH207moO`80
PH610P1jNWX208B4Q080PX:20P1mOGd207inOP0307alO01iNGT0NGUi0080QHF50P22PX820820P080
RXZ:0P28R8P20820P080OWin0`38h=P208Z:RP80QHF50P1WIfL208:2PP80N7Qh0P2ATI4208N7Q`03
071`L01]KFd0KFe]0080WYjN0P23Ph<206e]K@80SXj>0P1UIFD208B4Q080PH610P23Ph<208J6QP80
UYJF0P23Ph<206i^KP80OWin0P2=SHd00`24Q8@0PX:208:2PP0207QhN080PH610P25QHD207=cL`80
OWin0P29RHT207inOPd0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P21PH4208:2PP80PH61
0P1iNGT408B4Q080IfMW00<0Hf=S09BDU02DU9@00P2=SHd207QhN080NWYj0P29RHT207]kN`80N7Qh
0P1fMWH207moO`80PH610P1jNWX208B4Q080PX:20P1mOGd207inOP0307alO01iNGT0NGUi0080QHF5
0P22PX820820P080RXZ:0P28R8P20820P080OWin0`38h=P208Z:RP80QHF50P1WIfL208:2PP80N7Qh
0P2ATI4208N7Q`03071`L01]KFd0KFe]0080WYjN0P23Ph<206e]K@80SXj>0P1UIFD208B4Q080PH61
0P23Ph<208J6QP80UYJF0P23Ph<206i^KP80OWin0P2=SHd00`24Q8@0PX:208:2PP0207QhN080PH61
0P25QHD207=cL`80OWin0P29RHT207inOPd0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P1e
MGD207inOP80Rh^;0P2GUiL206YZJP80P8200P2BTY800`24Q8@0Ph>308>3P`0208:2PP80RHV90P20
P80207]kN`80MGEe0P1nOWh207emO@80LG5a0P1gMgL208J6QP80QhN70P1hN7P207alO080OWin00<0
S8b<08>3P`23Ph<00P25QHD207moO`80NGUi0P1oOgl20861P@80O7al0P1mOGd30<SPf080MWIf0P2N
WYh209BDU080[Jf]0P1aLG4205mOG`80EeMG00<0QhN707QhN01hN7P00P1UIFD207YjNP80QhN70P1c
Lg<209BDU080N7Qh0P1dM7@208B4Q080Ti>C0P1hN7P207moO`80Ng]k0P2=SHd20861P@0307EeM@2:
RXX0RXZ:0080MWIf0P1dM7@206YZJP80I6AT101fMWH20820P0d0b>3H000;0<SPf3h0P8200`38h=Pn
0820P0X0b>3H0P1eMGD207inOP80Rh^;0P2GUiL206YZJP80P8200P2BTY800`24Q8@0Ph>308>3P`02
08:2PP80RHV90P20P80207]kN`80MGEe0P1nOWh207emO@80LG5a0P1gMgL208J6QP80QhN70P1hN7P2
07alO080OWin00<0S8b<08>3P`23Ph<00P25QHD207moO`80NGUi0P1oOgl20861P@80O7al0P1mOGd3
0<SPf080MWIf0P2NWYh209BDU080[Jf]0P1aLG4205mOG`80EeMG00<0QhN707QhN01hN7P00P1UIFD2
07YjNP80QhN70P1cLg<209BDU080N7Qh0P1dM7@208B4Q080Ti>C0P1hN7P207moO`80Ng]k0P2=SHd2
0861P@0307EeM@2:RXX0RXZ:0080MWIf0P1dM7@206YZJP80I6AT101fMWH20820P0d0b>3H000;0<SP
f3h0P8200`38h=Pn0820P0X0b>3H0P1^KVh2096AT@80SXj>0P1OGel207moO`80Ng]k0P1VIVH00`2=
SHd0MgMg07MgM`0206][J`80P8200P1dM7@207QhN080QHF50P1gMgL407emO@80Ph>30P1mOGd207Yj
NP80MgMg0P20P80208>3P`0307AdM01nOWh0OWin0080O7al0P1dM7@407]kN`@0PH610P1dM7@30<SP
f080;Rh^0P2?Shl2069RHP80FEUI0P1DE5@205mOG`80OWin00<0MWIf08:2PP22PX800P27QhL407in
OP80UIFE101lO7`40820P080PH610P28R8P207emO@80[:b/0P2HV9P208F5Q@0307IfMP1mOGd0OGem
0080PH610P1eMGD208:2PP80LG5a0P27QhL207AdM080SHf=3@38h=P000/0b>3H?P20P8030<SPf3h0
P8202P38h=P206i^KP80TI6A0P2>SXh205mOG`80Ogmo0P1kNg/206IVIP0308f=S@1gMgL0MgMg0080
Jf][0P20P80207AdM080N7Qh0P25QHD207MgM`@0OGem0P23Ph<207emO@80NWYj0P1gMgL20820P080
Ph>300<0M7Ad07inOP1nOWh00P1lO7`207AdM0@0Ng]k1021PH4207AdM0<0b>3H0P0^;Rh208n?S`80
HV9R0P1IFET205ADE080GemO0P1nOWh00`1fMWH0PX:208:2PP0208N7Q`@0OWin0P2EUID407alO0@0
P8200P21PH4208R8R080OGem0P2/[:`209RHV080QHF500<0MWIf07emO@1mOGd00P21PH4207EeM@80
PX:20P1aLG4208N7Q`80M7Ad0P2=SHd=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080P820
0P2GUiL208^;R`80Q8B40P1lO7`208Z:RP80N7Qh00<0PX:208N7Q`27QhL00P27QhL207QhN080PH61
0P1eMGD207QhN080Ogmo0P1nOWh207alO080OGem0P1eMGD208:2PP80KFe]1020P8000`22PX80O7al
07alO00208N7Q`80PH610P20P80208R8R080OWin0P1cLg<208b<S0<0b>3H0P1KFe/209RHV080PH61
0P1ZJVX209VIV@80NWYj0P2DU9@00`2:RXX0TY:B09:BTP0208b<S080O7al0P20P802075aL@80NWYj
0P1hN7P207YjNP80MgMg0P1oOgl2079bLP80QHF50P1ZJVX207=cL`80Rh^;00<0QXJ608R8R028R8P0
0P26QXH208B4Q080QhN70P1hN7P208F5Q@80PX:20P1lO7`=0<SPf0002`38h=Pn0820P0<0b>3H?P20
P80:0<SPf080P8200P2GUiL208^;R`80Q8B40P1lO7`208Z:RP80N7Qh00<0PX:208N7Q`27QhL00P27
QhL207QhN080PH610P1eMGD207QhN080Ogmo0P1nOWh207alO080OGem0P1eMGD208:2PP80KFe]1020
P8000`22PX80O7al07alO00208N7Q`80PH610P20P80208R8R080OWin0P1cLg<208b<S0<0b>3H0P1K
Fe/209RHV080PH610P1ZJVX209VIV@80NWYj0P2DU9@00`2:RXX0TY:B09:BTP0208b<S080O7al0P20
P802075aL@80NWYj0P1hN7P207YjNP80MgMg0P1oOgl2079bLP80QHF50P1ZJVX207=cL`80Rh^;00<0
QXJ608R8R028R8P00P26QXH208B4Q080QhN70P1hN7P208F5Q@80PX:20P1lO7`=0<SPf0002`38h=Pn
0820P0<0b>3H?P20P80:0<SPf080O7al0P26QXH208B4Q080Kfm_0P1bLW8209BDU080Shn?00<0QXJ6
07inOP1nOWh00P20P80208F5Q@80Q8B40P1lO7`207inOP80PH61101mOGd208N7Q`80QHF50P21PH42
07alO0@0OGem00<0P82007IfMP1fMWH00P1kNg/20861P@80N7Qh0P24Q8@208>3P`80IVIV0P2ATI43
0<SPf080PX:20P2=SHd20:2PX080Vi^K0P2`/;0209FEU@80>3Ph00<0SHf=06ATI01TI6@00P1kNg/2
09nOW`80OWin0P1^KVh20861P@80PX:20P1nOWh208N7Q`80S8b<0P1fMWH208Z:RP80TY:B0P21PH42
0820P00308N7Q`2:RXX0RXZ:0080QHF50P23Ph<207AdM080Vi^K0P2SXj<2071`L080PX:23@38h=P0
00/0b>3H?P20P8030<SPf3h0P8202P38h=P207alO080QXJ60P24Q8@206m_K`80LW9b0P2DU9@208n?
S`0308J6QP1nOWh0OWin0080P8200P25QHD208B4Q080O7al0P1nOWh20861P@@0OGem0P27QhL208F5
Q@80PH610P1lO7`407emO@030820P01fMWH0MWIf0080Ng]k0P21PH4207QhN080Q8B40P23Ph<206IV
IP80TI6A0`38h=P208:2PP80SHf=0P2PX:0209^KV`80/;2`0P2EUID203Ph>00308f=S@1TI6@0I6AT
0080Ng]k0P2OWil207inOP80KVi^0P21PH4208:2PP80OWin0P27QhL208b<S080MWIf0P2:RXX209:B
TP80PH610P20P8000`27QhL0RXZ:08Z:RP0208F5Q@80Ph>30P1dM7@209^KV`80Xj>S0P1`L70208:2
PPd0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P29RHT208f=S@80S8b<0P1hN7P207MgM`80
NGUi0P1^KVh00`1[Jf/0JFUY06UYJ@02092@T080Ogmo0P2FUYH207YjNP@0PX:20P1jNWX208B4Q080
PH610P1nOWh20861P@80PX:20P20P80207inOP030861P@1lO7`0O7al0080M7Ad0P26QXH20820P080
PH610P1iNGT208>3P`80NWYj0`38h=P207IfMP80O7al0P1cLg<20861P@80Xj>S0P1`L70209bLW003
07alO01fMWH0MWIf0080Shn?0P27QhL207alO080RXZ:0P24Q8@208J6QP80PH610P20P80209:BTP80
M7Ad0P1`L7020861P@80OWin0P1/K6`00`1nOWh0QhN708N7Q`0206i^KP80Ng]k0P2<S8`206=SH`80
LG5a0P1hN7P207IfMPd0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P29RHT208f=S@80S8b<
0P1hN7P207MgM`80NGUi0P1^KVh00`1[Jf/0JFUY06UYJ@02092@T080Ogmo0P2FUYH207YjNP@0PX:2
0P1jNWX208B4Q080PH610P1nOWh20861P@80PX:20P20P80207inOP030861P@1lO7`0O7al0080M7Ad
0P26QXH20820P080PH610P1iNGT208>3P`80NWYj0`38h=P207IfMP80O7al0P1cLg<20861P@80Xj>S
0P1`L70209bLW00307alO01fMWH0MWIf0080Shn?0P27QhL207alO080RXZ:0P24Q8@208J6QP80PH61
0P20P80209:BTP80M7Ad0P1`L7020861P@80OWin0P1/K6`00`1nOWh0QhN708N7Q`0206i^KP80Ng]k
0P2<S8`206=SH`80LG5a0P1hN7P207IfMPd0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P20
P802079bLP80KFe]0P22PX8207EeM@80Ph>30P25QHD00`21PH40SXj>08j>SP0208b<S080Lg=c0P29
RHT208:2PP80M7Ad0P1_Kfl207moO`80OWin0P22PX8208B4Q080PH610P22PX8208>3P`80Q8B400<0
PH6108:2PP22PX801023Ph<207emO@80O7al1023Ph<20861P@<0b>3H101cLg<2069RHP80Ogmo0P1a
LG4207alO080TY:B00<0N7Qh08N7Q`27QhL00P1iNGT207QhN080UYJF0P25QHD206e]K@@0PX:20P29
RHT20820P080OWin0P1kNg/207UiN@80PX:20P29RHT00`1mOGd0M7Ad07AdM00207moO`80RXZ:0P2;
Rh/207UiN@80PX:20P20P80208V9R@d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P20P802
079bLP80KFe]0P22PX8207EeM@80Ph>30P25QHD00`21PH40SXj>08j>SP0208b<S080Lg=c0P29RHT2
08:2PP80M7Ad0P1_Kfl207moO`80OWin0P22PX8208B4Q080PH610P22PX8208>3P`80Q8B400<0PH61
08:2PP22PX801023Ph<207emO@80O7al1023Ph<20861P@<0b>3H101cLg<2069RHP80Ogmo0P1aLG42
07alO080TY:B00<0N7Qh08N7Q`27QhL00P1iNGT207QhN080UYJF0P25QHD206e]K@@0PX:20P29RHT2
0820P080OWin0P1kNg/207UiN@80PX:20P29RHT00`1mOGd0M7Ad07AdM00207moO`80RXZ:0P2;Rh/2
07UiN@80PX:20P20P80208V9R@d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2IVIT209nO
W`80OWin0P1aLG42071`L080PH610P27QhL00`2CTi<0KFe]06e]K@0207inOP80SHf=0P29RHT207al
O080NWYj0P26QXH207]kN`80O7al0P1oOgl207alO080NWYj0P1mOGd20861P@80RHV900<0Ph>307Ee
M@1eMGD00P20P80207inOP80P8200P21PH4208>3P`80PH610P20P8030<SPf080QHF50P1TI6@207Ui
N@80P8200P1SHf<208F5Q@80NWYj00<0OWin08n?S`2?Shl00P20P80207alO080OWin0P1eMGD207Yj
NP80KFe]0P1bLW8208:2PP80Q8B40P1`L70208R8R080Q8B40P23Ph<20861P@0307UiN@2=SHd0SHf=
0080Ogmo0P1nOWh207IfMP80QXJ60P29RHT208:2PP80NGUi3@38h=P000/0b>3H?P20P8030<SPf3h0
P8202P38h=P208F5Q@80Ph>30P1lO7`2071`L080Ph>30P1dM7@208Z:RP<0QhN70P23Ph<207alO080
QXJ60P20P80407inOP80Q8B40P1cLg<207IfMP80Rh^;101oOgl208>3P`80P82000<0R8R807inOP1n
OWh00P22PX8208F5Q@80OGem0P23Ph<207alO080N7Qh0P24Q8@30<SPf080JVYZ0P1XJ6P207MgM`80
QXJ60P20P8040861P@0307QhN02FUYH0UYJF0080S8b<0P24Q8@207=cL`80O7al0P2?Shl207AdM0@0
MgMg0P1cLg<20861P@80RXZ:0P25QHD207inOP80KVi^00<0LW9b08>3P`23Ph<00P1oOgl2096AT@80
PH610P1dM7@2079bLP80KFe]0P1kNg/=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080QHF5
0P23Ph<207alO080L71`0P23Ph<207AdM080RXZ:0`27QhL208>3P`80O7al0P26QXH20820P0@0OWin
0P24Q8@207=cL`80MWIf0P2;Rh/407moO`80Ph>30P20P8000`28R8P0OWin07inOP0208:2PP80QHF5
0P1mOGd208>3P`80O7al0P1hN7P208B4Q0<0b>3H0P1ZJVX206QXJ080MgMg0P26QXH20820P0@0PH61
00<0N7Qh09JFUP2FUYH00P2<S8`208B4Q080Lg=c0P1lO7`208n?S`80M7Ad101gMgL207=cL`80PH61
0P2:RXX208F5Q@80OWin0P1^KVh00`1bLW80Ph>308>3P`0207moO`80TI6A0P21PH4207AdM080LW9b
0P1]KFd207]kN`d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P20P80205mOG`80Rh^;0P29
RHT207UiN@80PH610P1hN7P00`2@T900Ph>308>3P`0206i^KP80PX:2101fMWH407]kN`80Q8B40P1o
Ogl207inOP80QXJ60P28R8P207moO`80Q8B40P21PH400`20P800MgMg07MgM`0207UiN@80QHF51027
QhL20820P080OWin0P2;Rh/30<SPf080YJFU0P25QHD20861P@80OGem0P1JFUX207MgM`80Rh^;00<0
R8R806EUI@1UIFD00P1iNGT207emO@80NGUi0P2>SXh207MgM`80Ogmo0P1bLW8208^;R`80Lg=c0P1d
M7@208B4Q080Ng]k0P20P80208B4Q00307MgM`22PX80PX:20080KFe]101mOGd2071`L080MWIf0P1h
N7P208>3P`d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P20P80205mOG`80Rh^;0P29RHT2
07UiN@80PH610P1hN7P00`2@T900Ph>308>3P`0206i^KP80PX:2101fMWH407]kN`80Q8B40P1oOgl2
07inOP80QXJ60P28R8P207moO`80Q8B40P21PH400`20P800MgMg07MgM`0207UiN@80QHF51027QhL2
0820P080OWin0P2;Rh/30<SPf080YJFU0P25QHD20861P@80OGem0P1JFUX207MgM`80Rh^;00<0R8R8
06EUI@1UIFD00P1iNGT207emO@80NGUi0P2>SXh207MgM`80Ogmo0P1bLW8208^;R`80Lg=c0P1dM7@2
08B4Q080Ng]k0P20P80208B4Q00307MgM`22PX80PX:20080KFe]101mOGd2071`L080MWIf0P1hN7P2
08>3P`d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2:RXX208j>SP80Ph>30P1eMGD20861
P@80SHf=0`1gMgL208V9R@80Ogmo0P21PH4207emO@80OWin101mOGd207]kN`80Ogmo0P28R8P207]k
N`80NGUi0P1jNWX208B4Q080OWin00<0OGem07moO`1oOgl00P22PX820861P@80Ogmo0P1gMgL207Yj
NP80OWin0P20P8030<SPf080UIFE0P29RHT206YZJP80VYZJ0P20P80209^KV`80R8R800<0NWYj07=c
L`1cLg<00P2KVi/207MgM`80Kfm_0P23Ph<207emO@80O7al0P2ATI4207inOP80P8200P1_Kfl20861
P@80QXJ60P1lO7`207IfMP0308Z:RP1jNWX0NWYj0080RXZ:0P1oOgl208Z:RP80R8R80P1nOWh208n?
S`80NWYj3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P208Z:RP80SXj>0P23Ph<207EeM@80
PH610P2=SHd307MgM`80RHV90P1oOgl20861P@80OGem0P1nOWh407emO@80Ng]k0P1oOgl208R8R080
Ng]k0P1iNGT207YjNP80Q8B40P1nOWh00`1mOGd0Ogmo07moO`0208:2PP80PH610P1oOgl207MgM`80
NWYj0P1nOWh20820P0<0b>3H0P2EUID208V9R@80JVYZ0P2JVYX20820P080Vi^K0P28R8P00`1jNWX0
Lg=c07=cL`0209^KV`80MgMg0P1_Kfl208>3P`80OGem0P1lO7`2096AT@80OWin0P20P80206m_K`80
PH610P26QXH207alO080MWIf00<0RXZ:07YjNP1jNWX00P2:RXX207moO`80RXZ:0P28R8P207inOP80
Shn?0P1jNWX=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080R8R80P20P80208F5Q@80Ph>3
0P2@T90207=cL`80NGUi00<0N7Qh08Z:RP2:RXX00P1cLg<208N7Q`80MGEe0P26QXH207alO080PX:2
0P1nOWh207QhN080Ogmo0P21PH4207]kN`80QhN70P1gMgL207]kN`0307EeM@25QHD0QHF50080PH61
0P27QhL208V9R@80OGem0P21PH4207inOP80NWYj0`38h=P206i^KP80TY:B0P1UIFD208B4Q080Ti>C
0P1fMWH207EeM@0307]kN`21PH40PH610080N7Qh0P1]KFd209RHV080LG5a0P26QXH207inOP80Shn?
0P20P80208:2PP80O7al0P2;Rh/208B4Q080WIfM0P1fMWH00`27QhL0Lg=c07=cL`0208:2PP80QXJ6
0P20P80208>3P`80M7Ad0P1`L70207]kN`d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P28
R8P20820P080QHF50P23Ph<2092@T080Lg=c0P1iNGT00`1hN7P0RXZ:08Z:RP0207=cL`80QhN70P1e
MGD208J6QP80O7al0P22PX8207inOP80N7Qh0P1oOgl20861P@80Ng]k0P27QhL207MgM`80Ng]k00<0
MGEe08F5Q@25QHD00P21PH4208N7Q`80RHV90P1mOGd20861P@80OWin0P1jNWX30<SPf080KVi^0P2B
TY8206EUI@80Q8B40P2CTi<207IfMP80MGEe00<0Ng]k0861P@21PH400P1hN7P206e]K@80V9RH0P1a
LG4208J6QP80OWin0P2?Shl20820P080PX:20P1lO7`208^;R`80Q8B40P2MWId207IfMP0308N7Q`1c
Lg<0Lg=c0080PX:20P26QXH20820P080Ph>30P1dM7@2071`L080Ng]k3@38h=P000/0b>3H?P20P803
0<SPf3h0P8202P38h=P208j>SP80MWIf0P2<S8`2096AT@80R8R80P1hN7P20820P00307inOP1lO7`0
O7al0080RXZ:0P1UIFD207inOP80R8R80P21PH4207]kN`80OWin0P20P80208N7Q`80Ph>30P25QHD2
08B4Q080NWYj0P22PX800`1nOWh0Q8B408B4Q00207moO`80NWYj0P1nOWh207QhN080Ph>30P1hN7P2
07inOP<0b>3H0P29RHT209RHV080R8R80P1oOgl207emO@80Kfm_0P2<S8`00`20P800R8R808R8R002
06YZJP80Ph>30P1cLg<209:BTP80QhN70P1lO7`208R8R080MWIf0P1kNg/207alO080Ogmo0P1nOWh2
08F5Q@80Q8B400<0O7al07IfMP1fMWH00P2JVYX208N7Q`80PX:20P27QhL406i^KP80Rh^;3@38h=P0
00/0b>3H?P20P8030<SPf3h0P8202P38h=P208j>SP80MWIf0P2<S8`2096AT@80R8R80P1hN7P20820
P00307inOP1lO7`0O7al0080RXZ:0P1UIFD207inOP80R8R80P21PH4207]kN`80OWin0P20P80208N7
Q`80Ph>30P25QHD208B4Q080NWYj0P22PX800`1nOWh0Q8B408B4Q00207moO`80NWYj0P1nOWh207Qh
N080Ph>30P1hN7P207inOP<0b>3H0P29RHT209RHV080R8R80P1oOgl207emO@80Kfm_0P2<S8`00`20
P800R8R808R8R00206YZJP80Ph>30P1cLg<209:BTP80QhN70P1lO7`208R8R080MWIf0P1kNg/207al
O080Ogmo0P1nOWh208F5Q@80Q8B400<0O7al07IfMP1fMWH00P2JVYX208N7Q`80PX:20P27QhL406i^
KP80Rh^;3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P208N7Q`80N7Qh0P1bLW8208J6QP80
R8R80P25QHD207=cL`0308N7Q`24Q8@0Q8B40080MGEe0P25QHD207UiN@80Q8B40P1hN7P208J6QP80
QHF50P20P80207]kN`80P8200P1oOgl207emO@@0PX:200<0QhN70861P@21PH400P1nOWh208:2PP80
Ogmo0P21PH4208B4Q080PH610P1kNg/30<SPf080N7Qh0P29RHT206a/K080M7Ad0P2ATI4206UYJ@80
Ogmo00<0PX:206a/K01/K6`00P28R8P2096AT@80XJ6Q0P1WIfL207]kN`80R8R80P1aLG4406IVIP80
Ph>30P2FUYH207UiN@80OWin0`29RHT208^;R`80MgMg1023Ph<207UiN@80QHF50P2>SXh2079bLPd0
b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P27QhL207QhN080LW9b0P26QXH208R8R080QHF5
0P1cLg<00`27QhL0Q8B408B4Q00207EeM@80QHF50P1iNGT208B4Q080N7Qh0P26QXH208F5Q@80P820
0P1kNg/20820P080Ogmo0P1mOGd408:2PP0308N7Q`21PH40PH610080OWin0P22PX8207moO`80PH61
0P24Q8@20861P@80Ng]k0`38h=P207QhN080RHV90P1/K6`207AdM080TI6A0P1YJFT207moO`0308:2
PP1/K6`0K6a/0080R8R80P2ATI420:6QX@80IfMW0P1kNg/208R8R080LG5a101VIVH208>3P`80UYJF
0P1iNGT207inOP<0RHV90P2;Rh/207MgM`@0Ph>30P1iNGT208F5Q@80SXj>0P1bLW8=0<SPf0002`38
h=Pn0820P0<0b>3H?P20P80:0<SPf080Ng]k0P2:RXX407YjNP80Q8B40P1gMgL208R8R0030861P@27
QhL0QhN70080OGem0P1hN7P208F5Q@80Lg=c0P23Ph<207IfMP80Ng]k0P1iNGT20820P080SHf=0P1n
OWh207UiN@80L71`0P1lO7`00`1hN7P0LW9b079bLP0207EeM@@0PH610P1iNGT207alO080PH610P27
QhL30<SPf080_[jn0P2@T90208j>SP80MWIf0P1dM7@206ATI080PX:200<0KVi^06m_K`1_Kfl00P1/
K6`208^;R`80QHF50P2CTi<20861P@80Jf][0P1jNWX208f=S@80Ogmo0P21PH4208R8R080NGUi0P23
Ph<207QhN00307YjNP2KVi/0Vi^K0080OGem0P1VIVH20861P@80SXj>0P22PX8207YjNP80Ph>33@38
h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P207]kN`80RXZ:101jNWX208B4Q080MgMg0P28R8P0
0`21PH40QhN708N7Q`0207emO@80N7Qh0P25QHD207=cL`80Ph>30P1fMWH207]kN`80NGUi0P20P802
08f=S@80OWin0P1iNGT2071`L080O7al00<0N7Qh079bLP1bLW800P1eMGD40861P@80NGUi0P1lO7`2
0861P@80QhN70`38h=P20;jn_P80T92@0P2>SXh207IfMP80M7Ad0P1TI6@208:2PP0306i^KP1_Kfl0
Kfm_0080K6a/0P2;Rh/208F5Q@80Ti>C0P21PH4206][J`80NWYj0P2=SHd207moO`80PH610P28R8P2
07UiN@80Ph>30P1hN7P00`1jNWX0Vi^K09^KV`0207emO@80IVIV0P21PH4208j>SP80PX:20P1jNWX2
08>3P`d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P1jNWX20820P080OGem0P1jNWX207Ad
M080Ogmo0P22PX800`1kNg/0L71`071`L00207AdM080Ng]k0P1jNWX208R8R080RXZ:0P1lO7`208:2
PP@0P8200P1oOgl207inOP80Ph>30P28R8P2096AT@0307alO01bLW80LW9b0080P8200P24Q8@208>3
P`80Ng]k0P22PX8207UiN@80Ogmo0`38h=P407]kN`80PH610P1lO7`209NGU`80M7Ad0P2?Shl00`2>
SXh0W9bL09bLW00207emO@80QhN70P1eMGD20820P080UYJF0P1OGel208>3P`80QhN70P1gMgL208j>
SP80OGem0P1FEUH206UYJ@80Ogmo00<0YZJV05EEE@1EEED00P23Ph<207AdM080RHV9102LW9`208F5
Q@80IfMW3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P207YjNP80P8200P1mOGd207YjNP80
M7Ad0P1oOgl208:2PP0307]kN`1`L700L71`0080M7Ad0P1kNg/207YjNP80R8R80P2:RXX207alO080
PX:21020P80207moO`80OWin0P23Ph<208R8R080TI6A00<0O7al079bLP1bLW800P20P80208B4Q080
Ph>30P1kNg/208:2PP80NGUi0P1oOgl30<SPf0@0Ng]k0P21PH4207alO080UiNG0P1dM7@208n?S`03
08j>SP2LW9`0W9bL0080OGem0P27QhL207EeM@80P8200P2FUYH205mOG`80Ph>30P27QhL207MgM`80
SXj>0P1mOGd205IFEP80JFUY0P1oOgl00`2VYZH0EEEE05EEE@0208>3P`80M7Ad0P29RHT409bLW080
QHF50P1WIfL=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080Rh^;0P2?Shl209RHV080T92@
1024Q8@208:2PP0307YjNP1lO7`0O7al0080RHV90P2?Shl20820P080OWin0P1mOGd207AdM080Rh^;
0P1hN7P2071`L0@0R8R80P1WIfL208n?S`80MGEe00<0OWin096AT@2ATI400P1/K6`2069RHP80PX:2
0P1mOGd207moO`80PX:20P28R8P30<SPf080P820101iNGT208>3P`80PH610P1^KVh207QhN00308>3
P`2FUYH0UYJF0080K6a/0P1_Kfl408B4Q080M7Ad0P21PH4208f=S@80Shn?0P1nOWh207YjNP80KVi^
0P2IVIT207emO@80Ogmo00<0JFUY07]kN`1kNg/00P1PH60206MWI`80N7Qh0P1gMgL206i^KP80Ph>3
0P1jNWX=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080Rh^;0P2?Shl209RHV080T92@1024
Q8@208:2PP0307YjNP1lO7`0O7al0080RHV90P2?Shl20820P080OWin0P1mOGd207AdM080Rh^;0P1h
N7P2071`L0@0R8R80P1WIfL208n?S`80MGEe00<0OWin096AT@2ATI400P1/K6`2069RHP80PX:20P1m
OGd207moO`80PX:20P28R8P30<SPf080P820101iNGT208>3P`80PH610P1^KVh207QhN00308>3P`2F
UYH0UYJF0080K6a/0P1_Kfl408B4Q080M7Ad0P21PH4208f=S@80Shn?0P1nOWh207YjNP80KVi^0P2I
VIT207emO@80Ogmo00<0JFUY07]kN`1kNg/00P1PH60206MWI`80N7Qh0P1gMgL206i^KP80Ph>30P1j
NWX=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080RHV90P2ATI4208^;R`80MGEe0P1mOGd2
08N7Q`80MGEe00<0OWin06IVIP1VIVH00P2MWId207moO`80NWYj0P28R8P207alO080OWin0P1lO7`4
08V9R@80Ti>C0P1dM7@20861P@80YjNW0P2OWil00`2=SHd0NWYj07YjNP040861P@80R8R80P1oOgl4
07inOP80M7Ad0`38h=P206e]K@80G5aL0P1QHF4209bLW080NWYj0P1`L7020:JVYP0307AdM029RHT0
RHV90080MgMg0P2DU9@20:>SX`80MWIf0P1nOWh208F5Q@80IFEU0P1kNg/206QXJ080Rh^;0P1`L702
06m_K`80KFe]0P31`L400`1FEUH0PX:208:2PP0207YjNP80Ogmo0P1jNWX207UiN@80Z:RX0P1mOGd2
07alO0d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P29RHT2096AT@80Rh^;0P1eMGD207em
O@80QhN70P1eMGD00`1nOWh0IVIV06IVIP0209fMW@80Ogmo0P1jNWX208R8R080O7al0P1nOWh207al
O0@0RHV90P2CTi<207AdM080PH610P2WYjL209nOW`0308f=S@1jNWX0NWYj00@0PH610P28R8P207mo
O`@0OWin0P1dM7@30<SPf080KFe]0P1LG5`2065QH@80W9bL0P1jNWX2071`L080YZJV00<0M7Ad08V9
R@29RHT00P1gMgL209BDU080Xj>S0P1fMWH207inOP80QHF50P1UIFD207]kN`80J6QX0P2;Rh/2071`
L080Kfm_0P1]KFd20<71`@0305IFEP22PX80PX:20080NWYj0P1oOgl207YjNP80NGUi0P2XZ:P207em
O@80O7al3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P2079bLP@0QHF50P22PX8207moO`80
Lg=c0P1/K6`00`1lO7`0LG5a075aL@0207EeM@80Ogmo0P1mOGd206m_K`80Ng]k0P1oOgl207UiN@80
RXZ:0P2>SXh208R8R080P8200P1aLG4206m_K`80JVYZ00<0KVi^08J6QP26QXH00P1mOGd207moO`80
QHF50P2:RXX207moO`80PX:20P23Ph<30<SPf080ZZZZ0P28R8P209BDU080SHf=0P1LG5`209fMW@<0
De=C0P1jNWX2092@T080Kfm_0P21PH4207emO@80PH610P1jNWX207EeM@80SXj>0P1fMWH206a/K080
MWIf0P1YJFT207EeM@80NGUi00<0ZJVY08j>SP2>SXh00P2^[Zh209:BTP80QHF50P1nOWh207alO080
L71`0P2HV9P=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080LW9b1025QHD208:2PP80Ogmo
0P1cLg<206a/K00307alO01aLG40LG5a0080MGEe0P1oOgl207emO@80Kfm_0P1kNg/207moO`80NGUi
0P2:RXX208j>SP80R8R80P20P802075aL@80Kfm_0P1ZJVX00`1^KVh0QXJ608J6QP0207emO@80Ogmo
0P25QHD208Z:RP80Ogmo0P22PX8208>3P`<0b>3H0P2ZZZX208R8R080U9BD0P2=SHd205aLG080WIfM
0`1CDe<207YjNP80T92@0P1_Kfl20861P@80OGem0P21PH4207YjNP80MGEe0P2>SXh207IfMP80K6a/
0P1fMWH206UYJ@80MGEe0P1iNGT00`2YZJT0SXj>08j>SP020:j^[P80TY:B0P25QHD207inOP80O7al
0P1`L70209RHV0d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2>SXh208V9R@80Lg=c1027
QhL2079bLP80JFUY00<0QXJ607YjNP1jNWX00P1nOWh207QhN080RHV90P22PX8207MgM`80PX:20P25
QHD206ATI080T92@0P20P80208^;R`80SXj>0P29RHT208R8R00307YjNP1MGEd0GEeM0080N7Qh0P2;
Rh/208Z:RP80NWYj0P21PH4207AdM080Ogmo0`38h=P208B4Q080LW9b0P2HV9P206EUI@80>CTi0P2O
Wil204i>CP0307inOP2TY:@0Y:BT0080QXJ60P2[Zj/208>3P`80R8R80P21PH4207AdM080Rh^;0P1T
I6@207]kN`80W9bL0P20P802096AT@80SXj>0P2?Shl00`25QHD0`/;20<;2`P0207=cL`80EEEE0P1Z
JVX40820P080K6a/0P1nOWh=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080SXj>0P29RHT2
07=cL`@0QhN70P1bLW8206UYJ@0308J6QP1jNWX0NWYj0080OWin0P1hN7P208V9R@80PX:20P1gMgL2
08:2PP80QHF50P1TI6@2092@T080P8200P2;Rh/208j>SP80RHV90P28R8P00`1jNWX0GEeM05eMG@02
07QhN080Rh^;0P2:RXX207YjNP80PH610P1dM7@207moO`<0b>3H0P24Q8@2079bLP80V9RH0P1UIFD2
03Ti>@80WinO0P1>CTh00`1nOWh0Y:BT0:BTY00208J6QP80Zj^[0P23Ph<208R8R080PH610P1dM7@2
08^;R`80I6AT0P1kNg/209bLW080P8200P2ATI4208j>SP80Shn?00<0QHF50<;2`P32`/800P1cLg<2
05EEE@80JVYZ1020P80206a/K080OWin3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P208N7
Q`80Q8B40P28R8P206i^KP80MGEe0P23Ph<207]kN`0308B4Q01lO7`0O7al0080OGem0P1kNg/207Ee
M@80NGUi0P26QXH20820P080QHF50P2BTY8208F5Q@80UYJF0P1gMgL2061PH080P8200P2FUYH00`1d
M7@0R8R808R8R0020861P@80QHF50P2:RXX408J6QP80P8200P23Ph<30<SPf080Ng]k0P1aLG4207mo
O`80F5QH0P29RHT208b<S080SXj>00<0IfMW0;6a/@2a/K400P1^KVh208J6QP80V9RH0P24Q8@207]k
N`80M7Ad0P1eMGD207YjNP80QhN70P2?Shl206i^KP80[:b/0P2<S8`206UYJ@03075aL@1DE5@0E5AD
0080R8R80P27QhL20861P@80K6a/0P1dM7@2096AT@80NGUi3@38h=P000/0b>3H?P20P8030<SPf3h0
P8202P38h=P208N7Q`80Q8B40P28R8P206i^KP80MGEe0P23Ph<207]kN`0308B4Q01lO7`0O7al0080
OGem0P1kNg/207EeM@80NGUi0P26QXH20820P080QHF50P2BTY8208F5Q@80UYJF0P1gMgL2061PH080
P8200P2FUYH00`1dM7@0R8R808R8R0020861P@80QHF50P2:RXX408J6QP80P8200P23Ph<30<SPf080
Ng]k0P1aLG4207moO`80F5QH0P29RHT208b<S080SXj>00<0IfMW0;6a/@2a/K400P1^KVh208J6QP80
V9RH0P24Q8@207]kN`80M7Ad0P1eMGD207YjNP80QhN70P2?Shl206i^KP80[:b/0P2<S8`206UYJ@03
075aL@1DE5@0E5AD0080R8R80P27QhL20861P@80K6a/0P1dM7@2096AT@80NGUi3@38h=P000/0b>3H
?P20P8030<SPf3h0P8202P38h=P208R8R080MgMg0P1mOGd208V9R@80MWIf0P1aLG4207alO00306YZ
JP1dM7@0M7Ad0080GemO0P1gMgL209BDU080PH610P29RHT208Z:RP80PH610P1kNg/207moO`80KFe]
0P1nOWh208F5Q@80Q8B40P1/K6`00`1jNWX0Rh^;08^;R`020820P080PX:20P26QXH2075aL@80PH61
0P1nOWh208:2PP<0b>3H0P1kNg/2092@T080emOG0P2OWil2075aL@80OGem0P1ZJVX00`2CTi<0MWIf
07IfMP0209JFUP80L71`0P1^KVh208R8R080M7Ad0P1cLg<208B4Q080RXZ:0P1nOWh206e]K@80/K6a
0P1OGel208^;R`80UYJF00<0M7Ad06MWI`1WIfL00P1DE5@205eMG@80N7Qh0P1gMgL2096AT@80N7Qh
0P1YJFT=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080R8R80P1gMgL207emO@80RHV90P1f
MWH2075aL@80O7al00<0JVYZ07AdM01dM7@00P1OGel207MgM`80U9BD0P21PH4208V9R@80RXZ:0P21
PH4207]kN`80Ogmo0P1]KFd207inOP80QHF50P24Q8@206a/K00307YjNP2;Rh/0Rh^;0080P8200P22
PX8208J6QP80LG5a0P21PH4207inOP80PX:20`38h=P207]kN`80T92@0P3GemL209nOW`80LG5a0P1m
OGd206YZJP0309>CT`1fMWH0MWIf0080UYJF0P1`L70206i^KP80R8R80P1dM7@207=cL`80Q8B40P2:
RXX207inOP80KFe]0P2a/K4205mOG`80Rh^;0P2FUYH00`1dM7@0IfMW06MWI`0205ADE080GEeM0P1h
N7P207MgM`80TI6A0P1hN7P206UYJ@d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P22PX82
075aL@80U9BD0P2CTi<208R8R080M7Ad0P1gMgL00`2:RXX0SHf=08f=S@020861P@80QHF50P1gMgL2
07]kN`80Ph>30P22PX8208F5Q@80PX:20P26QXH208B4Q080Rh^;0P25QHD208n?S`80Ogmo00<0Jf][
0820P020P8000P1bLW8206YZJP80QXJ60P25QHD20861P@80P8200P1lO7`30<SPf080UiNG0P1fMWH2
07UiN@80Lg=c0P2BTY82092@T080QHF500<0VIVI096AT@2ATI400P2@T90208n?S`80K6a/0P1mOGd4
07YjNP80K6a/0P1cLg<207emO@80Ti>C0P1gMgL209bLW080JFUY0P1TI6@00`26QXH0XJ6Q0:6QX@02
0820P080UYJF0P2;Rh/207UiN@80Lg=c0P1ZJVX207AdM0d0b>3H000;0<SPf3h0P8200`38h=Pn0820
P0X0b>3H0P22PX82075aL@80U9BD0P2CTi<208R8R080M7Ad0P1gMgL00`2:RXX0SHf=08f=S@020861
P@80QHF50P1gMgL207]kN`80Ph>30P22PX8208F5Q@80PX:20P26QXH208B4Q080Rh^;0P25QHD208n?
S`80Ogmo00<0Jf][0820P020P8000P1bLW8206YZJP80QXJ60P25QHD20861P@80P8200P1lO7`30<SP
f080UiNG0P1fMWH207UiN@80Lg=c0P2BTY82092@T080QHF500<0VIVI096AT@2ATI400P2@T90208n?
S`80K6a/0P1mOGd407YjNP80K6a/0P1cLg<207emO@80Ti>C0P1gMgL209bLW080JFUY0P1TI6@00`26
QXH0XJ6Q0:6QX@020820P080UYJF0P2;Rh/207UiN@80Lg=c0P1ZJVX207AdM0d0b>3H000;0<SPf3h0
P8200`38h=Pn0820P0X0b>3H0P1lO7`209JFUP80RXZ:0P1dM7@20820P080M7Ad0P25QHD00`2ATI40
KFe]06e]K@0208Z:RP80OWin0P2ATI4207inOP80SHf=0P22PX8207=cL`80OGem0P25QHD207moO`80
PX:20P1^KVh209FEU@80LW9b00<0M7Ad07UiN@1iNGT00P28R8P20820P080OGem0P1nOWh207MgM`80
OGem0P1nOWh30<SPf080Q8B40P2LW9`209ZJVP80Shn?0P2<S8`2092@T080QXJ600<0MgMg071`L01`
L7000P1dM7@20<K6aP80/[:b0P1LG5`206ATI080Ph>30P1jNWX20820P080RHV90P1mOGd2075aL@80
Shn?0P2FUYH206IVIP030820P02:RXX0RXZ:0080UYJF0P1bLW8208F5Q@80Q8B40P1lO7`207YjNP80
Rh^;3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P207YjNP80Ng]k0P2GUiL20:2PX080T92@
0P1^KVh208J6QP0307IfMP24Q8@0Q8B40080Q8B40P1WIfL209BDU080PX:20P1MGEd2079bLP80O7al
0P22PX8208B4Q080PH610P20P80207emO@80Shn?0P26QXH00`2JVYX0PX:208:2PP0207QhN0@0Ph>3
0P1lO7`207MgM`80OGem0P23Ph<30<SPf080I6AT0P2d];@207moO`80N7Qh0P25QHD206QXJ080T92@
00<0RXZ:07MgM`1gMgL00P2PX:0206i^KP80QHF50P23Ph<209ZJVP80V9RH0P1SHf<207=cL`80QXJ6
0P1kNg/207inOP80Ng]k0P1oOgl208>3P`0308V9R@21PH40PH610080PH610P23Ph<207]kN`80QXJ6
0P1iNGT207]kN`80PH613@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P207YjNP80Ng]k0P2G
UiL20:2PX080T92@0P1^KVh208J6QP0307IfMP24Q8@0Q8B40080Q8B40P1WIfL209BDU080PX:20P1M
GEd2079bLP80O7al0P22PX8208B4Q080PH610P20P80207emO@80Shn?0P26QXH00`2JVYX0PX:208:2
PP0207QhN0@0Ph>30P1lO7`207MgM`80OGem0P23Ph<30<SPf080I6AT0P2d];@207moO`80N7Qh0P25
QHD206QXJ080T92@00<0RXZ:07MgM`1gMgL00P2PX:0206i^KP80QHF50P23Ph<209ZJVP80V9RH0P1S
Hf<207=cL`80QXJ60P1kNg/207inOP80Ng]k0P1oOgl208>3P`0308V9R@21PH40PH610080PH610P23
Ph<207]kN`80QXJ60P1iNGT207]kN`80PH613@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P2
07EeM@80PX:20P2>SXh208:2PP80QhN70P1/K6`208F5Q@030820P028R8P0R8R80080OGem0P28R8P2
08^;R`80PX:20P1gMgL208b<S080MWIf0P24Q8@207alO080QHF50P28R8P20820P080QHF50P1jNWX0
0`1nOWh0NGUi07UiN@0208j>SP@0P8200P1gMgL208>3P`80Ogmo0P1nOWh30<SPf080OWin0P1WIfL2
08V9R@80TY:B0P2VYZH208n?S`80O7al00<0QXJ606e]K@1]KFd00P1RHV8207inOP80MgMg0P1^KVh2
08V9R@80OWin0P1OGel208^;R`80MGEe0P1mOGd20861P@80QhN7101gMgL00`21PH40Jf][06][J`02
06m_K`80P8200P1`L70208F5Q@80RXZ:0P2=SHd207]kN`d0b>3H000;0<SPf3h0P8200`38h=Pn0820
P0X0b>3H0P1eMGD208:2PP80SXj>0P22PX8208N7Q`80K6a/0P25QHD00`20P800R8R808R8R00207em
O@80R8R80P2;Rh/208:2PP80MgMg0P2<S8`207IfMP80Q8B40P1lO7`208F5Q@80R8R80P20P80208F5
Q@80NWYj00<0OWin07UiN@1iNGT00P2>SXh40820P080MgMg0P23Ph<207moO`80OWin0`38h=P207in
OP80IfMW0P29RHT209:BTP80YZJV0P2?Shl207alO00308J6QP1]KFd0KFe]0080HV9R0P1nOWh207Mg
M`80KVi^0P29RHT207inOP80GemO0P2;Rh/207EeM@80OGem0P21PH4208N7Q`@0MgMg00<0PH6106][
J`1[Jf/00P1_Kfl20820P080L71`0P25QHD208Z:RP80SHf=0P1kNg/=0<SPf0002`38h=Pn0820P0<0
b>3H?P20P80:0<SPf080OWin0P1fMWH207UiN@80Vi^K0P2DU9@207=cL`80OWin00<0Ogmo08>3P`23
Ph<00P2<S8`20:2PX080Ng]k0P1YJFT2071`L080OWin0P1mOGd208N7Q`80NGUi0P22PX8207emO@80
QHF50P1oOgl207emO@0307alO027QhL0QhN70080N7Qh0P21PH4207emO@@0Ng]k0P25QHD208N7Q`<0
b>3H1029RHT206=SH`80RXZ:0P24Q8@208:2PP80P82000<0PH6106MWI`1WIfL00P1QHF4205aLG080
Ti>C0P1`L7020820P080S8b<0P1jNWX208V9R@80PX:20P2=SHd208n?S`80Ph>30P28R8P209:BTP03
079bLP28R8P0R8R80080RXZ:0P2BTY8208>3P`@0QhN70P1eMGD208f=S@d0b>3H000;0<SPf3h0P820
0`38h=Pn0820P0X0b>3H0P1nOWh207IfMP80NGUi0P2KVi/209BDU080Lg=c0P1nOWh00`1oOgl0Ph>3
08>3P`0208b<S080X:2P0P1kNg/206UYJ@80L71`0P1nOWh207emO@80QhN70P1iNGT208:2PP80OGem
0P25QHD207moO`80OGem00<0O7al08N7Q`27QhL00P1hN7P20861P@80OGem101kNg/208F5Q@80QhN7
0`38h=P408V9R@80Hf=S0P2:RXX208B4Q080PX:20P20P8000`21PH40IfMW06MWI`02065QH@80G5aL
0P2CTi<2071`L080P8200P2<S8`207YjNP80RHV90P22PX8208f=S@80Shn?0P23Ph<208R8R080TY:B
00<0LW9b08R8R028R8P00P2:RXX209:BTP80Ph>31027QhL207EeM@80SHf=3@38h=P000/0b>3H?P20
P8030<SPf3h0P8202P38h=P207YjNP80Ogmo0P2:RXX208f=S@80W9bL0P2FUYH20820P00307alO021
PH40PH610080PH610P1fMWH20820P080QhN70P1eMGD208V9R@80M7Ad0P2<S8`208V9R@80PH610P22
PX8208F5Q@80RHV90P1nOWh00`1eMGD0QHF508F5Q@0407emO@80RXZ:0P29RHT207UiN@80OGem0P1h
N7P30<SPf080^KVi0P23Ph<2092@T080QXJ60P1hN7P207moO`80NWYj00<0P82006i^KP1^KVh00P1]
KFd20:f][@80RHV90P2?Shl207AdM080O7al0P2VYZH207YjNP80LW9b0P1eMGD208b<S080Ti>C0P1l
O7`2079bLP03075aL@28R8P0R8R80080Rh^;0P1oOgl20820P080L71`1024Q8@207IfMPd0b>3H000;
0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P1jNWX207moO`80RXZ:0P2=SHd209bLW080UYJF0P20P800
0`1lO7`0PH610861P@020861P@80MWIf0P20P80208N7Q`80MGEe0P29RHT207AdM080S8b<0P29RHT2
0861P@80PX:20P25QHD208V9R@80OWin00<0MGEe08F5Q@25QHD0101mOGd208Z:RP80RHV90P1iNGT2
07emO@80N7Qh0`38h=P20;Vi^@80Ph>30P2@T90208J6QP80N7Qh0P1oOgl207YjNP030820P01^KVh0
KVi^0080KFe]0P2][Jd208V9R@80Shn?0P1dM7@207alO080YZJV0P1jNWX2079bLP80MGEe0P2<S8`2
09>CT`80O7al0P1bLW800`1aLG40R8R808R8R00208^;R`80Ogmo0P20P802071`L0@0Q8B40P1fMWH=
0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080LW9b0P27QhL207AdM080PX:20P25QHD208:2
PP80S8b<00<0PX:207moO`1oOgl0101kNg/207moO`80P8200P26QXH208N7Q`80NWYj0P1mOGd209>C
T`80M7Ad0P24Q8@206UYJ@@0Ogmo00<0OWin08V9R@29RHT00P1nOWh208>3P`80QHF50P1KFe/208J6
QP80QHF50P26QXH30<SPf080Jf][0P2b/[8206YZJP80SXj>0P1YJFT407=cL`0307UiN@1YJFT0JFUY
0080RXZ:0P1nOWh20:JVYP80SXj>0P1HF5P204U9B@80R8R80P22PX82061PH080DE5A0P1cLg<20:BT
Y080Rh^;0P1VIVH00`1aLG40QHF508F5Q@020:>SX`80LW9b0P1oOgl20861P@80LG5a0P25QHD207Ad
M0d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P1bLW8208N7Q`80M7Ad0P22PX8208F5Q@80
PX:20P2<S8`00`22PX80Ogmo07moO`0407]kN`80Ogmo0P20P80208J6QP80QhN70P1jNWX207emO@80
Ti>C0P1dM7@208B4Q080JFUY101oOgl00`1nOWh0RHV908V9R@0207inOP80Ph>30P25QHD205]KF`80
QXJ60P25QHD208J6QP<0b>3H0P1[Jf/20;:b/P80JVYZ0P2>SXh206UYJ@@0Lg=c00<0NGUi06UYJ@1Y
JFT00P2:RXX207inOP80YZJV0P2>SXh205QHF080BDU90P28R8P208:2PP80H61P0P1ADE4207=cL`80
Y:BT0P2;Rh/206IVIP03075aL@25QHD0QHF50080Xj>S0P1bLW8207moO`80PH610P1aLG4208F5Q@80
M7Ad3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P205QHF080Jf][0P1oOgl2092@T080NGUi
0P20P80206e]K@0307inOP23Ph<0Ph>30080M7Ad0P1cLg<207AdM080LW9b0P1HF5P206m_K`80OWin
0P26QXH2079bLP80Shn?0P1oOgl20:>SX`80Q8B40P28R8P00`1lO7`0RXZ:08Z:RP0207EeM@80MgMg
0P21PH4208>3P`80QXJ60P25QHD20820P0<0b>3H0P2PX:0209BDU080R8R80P27QhL205iNGP80UIFE
0P1XJ6P00`2<S8`0NGUi07UiN@0207alO080Ogmo0P2EUID20<C4a080KVi^0P1FEUH208:2PP80SXj>
0P1SHf<208B4Q080K6a/0P1dM7@209:BTP80O7al00<0MGEe08:2PP22PX800P1mOGd208j>SP80QHF5
0P1mOGd207IfMP80L71`0P1_Kfl=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080F5QH0P1[
Jf/207moO`80T92@0P1iNGT20820P080KFe]00<0OWin08>3P`23Ph<00P1dM7@207=cL`80M7Ad0P1b
LW8205QHF080Kfm_0P1nOWh208J6QP80LW9b0P2?Shl207moO`80Xj>S0P24Q8@208R8R00307alO02:
RXX0RXZ:0080MGEe0P1gMgL20861P@80Ph>30P26QXH208F5Q@80P8200`38h=P20:2PX080U9BD0P28
R8P208N7Q`80GUiN0P2EUID206QXJ00308b<S01iNGT0NGUi0080O7al0P1oOgl209FEU@80a<C40P1^
KVh205IFEP80PX:20P2>SXh206=SH`80Q8B40P1/K6`207AdM080TY:B0P1lO7`00`1eMGD0PX:208:2
PP0207emO@80SXj>0P25QHD207emO@80MWIf0P1`L70206m_K`d0b>3H000;0<SPf3h0P8200`38h=Pn
0820P0X0b>3H0P21PH4207moO`80X:2P0P2<S8`207UiN@80PX:20P2RXZ800`26QXH0MWIf07IfMP02
08J6QP80PX:20P2@T90207]kN`80Ogmo0P2DU9@207QhN080Ogmo0P1jNWX207alO080P8200P1ZJVX2
08:2PP80OGem00<0Ogmo07emO@1mOGd00P21PH4207AdM080QhN70P1kNg/208:2PP80Ng]k0P1eMGD3
0<SPf080ADE50P1OGel209FEU@80IfMW0P1fMWH208:2PP80_;bl00<0V9RH07inOP1nOWh00P2<S8`2
06IVIP80L71`0P1_Kfl208J6QP80bl_;0P2?Shl206i^KP80>3Ph0P1lO7`20<k>cP80VYZJ0P14A4@2
09RHV00308b<S02GUiL0UiNG0080KVi^0P2BTY8209VIV@80M7Ad0P1oOgl208Z:RP80Ng]k3@38h=P0
00/0b>3H?P20P8030<SPf3h0P8202P38h=P20861P@80Ogmo0P2PX:0208b<S080NGUi0P22PX820::R
XP0308J6QP1fMWH0MWIf0080QXJ60P22PX82092@T080Ng]k0P1oOgl209BDU080N7Qh0P1oOgl207Yj
NP80O7al0P20P80206YZJP80PX:20P1mOGd00`1oOgl0OGem07emO@020861P@80M7Ad0P27QhL207]k
N`80PX:20P1kNg/207EeM@<0b>3H0P15ADD205mOG`80UIFE0P1WIfL207IfMP80PX:20P2l_;`00`2H
V9P0OWin07inOP0208b<S080IVIV0P1`L70206m_K`80QXJ60P3;bl/208n?S`80KVi^0P0h>3P207al
O080c/k>0P2JVYX204A4A080V9RH00<0S8b<09NGU`2GUiL00P1^KVh209:BTP80VIVI0P1dM7@207mo
O`80RXZ:0P1kNg/=0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf0002`38h=Pn
0820P0<0b>3H?P20P80:0<SPf080UIFE0P2WYjL20:2PX080U9BD0P2ATI4208F5Q@80QXJ600<0R8R8
0820P020P8000P26QXH208j>SP80QhN70P2=SHd208J6QP80S8b<0P26QXH208N7Q`80QHF50P21PH42
08>3P`80QHF50P2:RXX208:2PP<0RHV90P24Q8@208V9R@80Ph>31028R8P408N7Q`<0b>3H0P22PX82
07alO080Ng]k0P2=SHd207EeM@80OWin0P1mOGd00`28R8P0S8b<08b<S00208>3P`80OGem0P20P802
08J6QP80OGem0P25QHD208R8R080PH611020P80208B4Q080Ng]k0P1oOgl20820P0<0OGem0P1oOgl2
07alO080Ogmo0P20P80208B4Q080PX:20P1lO7`=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SP
f080UIFE0P2WYjL20:2PX080U9BD0P2ATI4208F5Q@80QXJ600<0R8R80820P020P8000P26QXH208j>
SP80QhN70P2=SHd208J6QP80S8b<0P26QXH208N7Q`80QHF50P21PH4208>3P`80QHF50P2:RXX208:2
PP<0RHV90P24Q8@208V9R@80Ph>31028R8P408N7Q`<0b>3H0P22PX8207alO080Ng]k0P2=SHd207Ee
M@80OWin0P1mOGd00`28R8P0S8b<08b<S00208>3P`80OGem0P20P80208J6QP80OGem0P25QHD208R8
R080PH611020P80208B4Q080Ng]k0P1oOgl20820P0<0OGem0P1oOgl207alO080Ogmo0P20P80208B4
Q080PX:20P1lO7`=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080QXJ60P2>SXh209ZJVP80
U9BD0P2<S8`208f=S@80XZ:R00<0Vi^K09JFUP2FUYH00P2KVi/208b<S080Ti>C0P2<S8`208N7Q`80
R8R80P2:RXX208V9R@@0QXJ60P22PX8208F5Q@80Ph>30P27QhL308B4Q080RXZ:0P27QhL208R8R080
Ph>31028R8P208F5Q@<0b>3H0P2GUiL206ATI080UIFE0P1hN7P206][J`80OGem0P1ZJVX00`1OGel0
EeMG05MGE`0205EEE@80Lg=c0P1bLW8207inOP80MGEe0P1lO7`206UYJ@80Ph>30P1kNg/208>3P`80
OWin0P24Q8@207inOP80OGem00<0Ogmo08R8R028R8P00P20P80207emO@80PX:20P1oOgl207alO080
Ph>30P20P80=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080QXJ60P2>SXh209ZJVP80U9BD
0P2<S8`208f=S@80XZ:R00<0Vi^K09JFUP2FUYH00P2KVi/208b<S080Ti>C0P2<S8`208N7Q`80R8R8
0P2:RXX208V9R@@0QXJ60P22PX8208F5Q@80Ph>30P27QhL308B4Q080RXZ:0P27QhL208R8R080Ph>3
1028R8P208F5Q@<0b>3H0P2GUiL206ATI080UIFE0P1hN7P206][J`80OGem0P1ZJVX00`1OGel0EeMG
05MGE`0205EEE@80Lg=c0P1bLW8207inOP80MGEe0P1lO7`206UYJ@80Ph>30P1kNg/208>3P`80OWin
0P24Q8@207inOP80OGem00<0Ogmo08R8R028R8P00P20P80207emO@80PX:20P1oOgl207alO080Ph>3
0P20P80=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080[Jf]0P2FUYH208F5Q@80XJ6Q0P2G
UiL209RHV080Xj>S00<0SHf=08j>SP2>SXh00P2@T90208b<S080R8R80P24Q8@208^;R`80QhN70P2;
Rh/208V9R@80R8R80P29RHT208F5Q@80RXZ:0P25QHD208:2PP0308N7Q`28R8P0R8R80080Ph>30P24
Q8@208N7Q`80RXZ:0P24Q8@208F5Q@80PX:20`38h=P208n?S`80QhN70P25QHD20::RXP80QHF50P2O
Wil207emO@0308f=S@21PH40PH610080Shn?0P1kNg/207moO`80PX:20P1oOgl208>3P`80QHF50P1^
KVh207moO`@0OGem0P25QHD208>3P`80PX:200<0OWin08>3P`23Ph<00P1iNGT408V9R@80Ogmo0P24
Q8@207QhN080PX:23@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P20:f][@80UYJF0P25QHD2
0:6QX@80UiNG0P2HV9P20:>SX`0308f=S@2>SXh0SXj>0080T92@0P2<S8`208R8R080Q8B40P2;Rh/2
08N7Q`80Rh^;0P29RHT208R8R080RHV90P25QHD208Z:RP80QHF50P22PX800`27QhL0R8R808R8R002
08>3P`80Q8B40P27QhL208Z:RP80Q8B40P25QHD208:2PP<0b>3H0P2?Shl208N7Q`80QHF50P2RXZ82
08F5Q@80WinO0P1mOGd00`2=SHd0PH610861P@0208n?S`80Ng]k0P1oOgl208:2PP80Ogmo0P23Ph<2
08F5Q@80KVi^0P1oOgl407emO@80QHF50P23Ph<208:2PP0307inOP23Ph<0Ph>30080NGUi1029RHT2
07moO`80Q8B40P1hN7P208:2PPd0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2XZ:P209ZJ
VP80U9BD0P2VYZH209jNWP80S8b<0P2HV9P00`2QXJ40Q8B408B4Q002096AT@80SHf=0P2<S8`208^;
R`80RHV90P2:RXX208b<S0@0R8R80P26QXH208V9R@80QHF50P28R8P208Z:RP0308F5Q@27QhL0QhN7
0080QhN70P26QXH208N7Q`@0RHV90P2>SXh208f=S@<0b>3H0P2;Rh/207moO`80U9BD0P1ZJVX206UY
J@80QHF50P1ZJVX00`1YJFT0R8R808R8R00207=cL`80N7Qh0P1jNWX20861P@80QHF50P1lO7`407]k
N`80Ph>30P1lO7`207emO@80MgMg0P1dM7@207YjNP030861P@23Ph<0Ph>30080QhN70P25QHD20820
P080OWin0P2;Rh/209:BTP80Q8B43@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P20:RXZ080
VYZJ0P2DU9@20:JVYP80WYjN0P2<S8`209RHV0030:6QX@24Q8@0Q8B40080TI6A0P2=SHd208b<S080
Rh^;0P29RHT208Z:RP80S8b<1028R8P208J6QP80RHV90P25QHD208R8R080RXZ:00<0QHF508N7Q`27
QhL00P27QhL208J6QP80QhN71029RHT208j>SP80SHf=0`38h=P208^;R`80Ogmo0P2DU9@206YZJP80
JFUY0P25QHD206YZJP0306UYJ@28R8P0R8R80080Lg=c0P1hN7P207YjNP80PH610P25QHD207alO0@0
Ng]k0P23Ph<207alO080OGem0P1gMgL207AdM080NWYj00<0PH6108>3P`23Ph<00P27QhL208F5Q@80
P8200P1nOWh208^;R`80TY:B0P24Q8@=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080WinO
0P2EUID2092@T080TY:B0P2KVi/208f=S@80Rh^;00<0SHf=08N7Q`27QhL00P2HV9P208F5Q@80Q8B4
0P25QHD208R8R080RHV91025QHD208>3P`80Rh^;0P24Q8@208R8R080RHV90`25QHD208>3P`80R8R8
0P23Ph<20861P@80QhN7102@T90209:BTP<0b>3H0P1oOgl208J6QP80PH610P2<S8`207QhN080O7al
0P1fMWH00`1kNg/0RHV908V9R@0207EeM@80QXJ60P28R8P207]kN`80Q8B40P1mOGd20861P@80Ph>3
101mOGd20861P@80P8200P1nOWh207]kN`0307MgM`1lO7`0O7al0080PH610P1bLW8208N7Q`80P820
0P1VIVH207alO080Ogmo3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P209nOW`80UIFE0P2@
T90209:BTP80Vi^K0P2=SHd208^;R`0308f=S@27QhL0QhN70080V9RH0P25QHD208B4Q080QHF50P28
R8P208V9R@@0QHF50P23Ph<208^;R`80Q8B40P28R8P208V9R@<0QHF50P23Ph<208R8R080Ph>30P21
PH4208N7Q`@0T92@0P2BTY830<SPf080Ogmo0P26QXH20861P@80S8b<0P1hN7P207alO080MWIf00<0
Ng]k08V9R@29RHT00P1eMGD208J6QP80R8R80P1kNg/208B4Q080OGem0P21PH4208>3P`@0OGem0P21
PH420820P080OWin0P1kNg/00`1gMgL0O7al07alO0020861P@80LW9b0P27QhL20820P080IVIV0P1l
O7`207moO`d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2?Shl208Z:RP80SHf=102ATI42
0:RXZ080S8b<00<0SXj>08Z:RP2:RXX00P26QXH209VIV@80S8b<0P24Q8@208F5Q@@0Q8B40P22PX82
08R8R080QXJ60P23Ph<208Z:RP@0QXJ600<0Ph>308R8R028R8P00P23Ph<208R8R080T92@0P24Q8@2
09^KV`80X:2P0P2FUYH30<SPf080Ph>30P1cLg<207]kN`80LG5a0P1VIVH207QhN080JVYZ00<0P820
08R8R028R8P00P2ATI4208R8R080Ogmo0P22PX8207QhN080Q8B4101mOGd208F5Q@80QXJ60P1eMGD2
08>3P`80OGem0P1lO7`00`1oOgl0QXJ608J6QP0207alO080NGUi0P29RHT207UiN@80PX:20P2ATI42
092@T0d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2?Shl208Z:RP80SHf=102ATI420:RX
Z080S8b<00<0SXj>08Z:RP2:RXX00P26QXH209VIV@80S8b<0P24Q8@208F5Q@@0Q8B40P22PX8208R8
R080QXJ60P23Ph<208Z:RP@0QXJ600<0Ph>308R8R028R8P00P23Ph<208R8R080T92@0P24Q8@209^K
V`80X:2P0P2FUYH30<SPf080Ph>30P1cLg<207]kN`80LG5a0P1VIVH207QhN080JVYZ00<0P82008R8
R028R8P00P2ATI4208R8R080Ogmo0P22PX8207QhN080Q8B4101mOGd208F5Q@80QXJ60P1eMGD208>3
P`80OGem0P1lO7`00`1oOgl0QXJ608J6QP0207alO080NGUi0P29RHT207UiN@80PX:20P2ATI42092@
T0d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2;Rh/208J6QP80W9bL0P2GUiL209jNWP80
Zj^[0P2a/K400`2GUiL0TI6A096AT@0209bLW080QHF50P2ATI4208V9R@@0QXJ60P24Q8@208:2PP80
QhN70P2:RXX208N7Q`80QHF51026QXH00`25QHD0QhN708N7Q`0208N7Q`80SHf=0P24Q8@608F5Q@80
PX:20`38h=P207QhN0@0QHF50P1lO7`208V9R@80IFEU0P1aLG400`1iNGT0Ph>308>3P`0209VIV@80
O7al0P25QHD207moO`80NGUi0P1mOGd40820P080Ogmo0P20P80207emO@80PX:20P23Ph<207YjNP03
07moO`24Q8@0Q8B40080O7al0P1hN7P208:2PP80MGEe0P1fMWH207=cL`80OGem3@38h=P000/0b>3H
?P20P8030<SPf3h0P8202P38h=P208^;R`80QXJ60P2LW9`209NGU`80WYjN0P2[Zj/20;6a/@0309NG
U`2ATI40TI6A0080W9bL0P25QHD2096AT@80RHV91026QXH208B4Q080PX:20P27QhL208Z:RP80QhN7
0P25QHD408J6QP0308F5Q@27QhL0QhN70080QhN70P2=SHd208B4Q0H0QHF50P22PX830<SPf080N7Qh
1025QHD207alO080RHV90P1UIFD2075aL@0307UiN@23Ph<0Ph>30080VIVI0P1lO7`208F5Q@80Ogmo
0P1iNGT207emO@@0P8200P1oOgl20820P080OGem0P22PX8208>3P`80NWYj00<0Ogmo08B4Q024Q8@0
0P1lO7`207QhN080PX:20P1eMGD207IfMP80Lg=c0P1mOGd=0<SPf0002`38h=Pn0820P0<0b>3H?P20
P80:0<SPf080RHV90P2>SXh209>CT`80T92@0P25QHD209fMW@80YZJV00<0T92@08Z:RP2:RXX00P28
R8P208V9R@80Shn?0P2=SHd208B4Q080R8R80P26QXH208>3P`80QhN70P23Ph<208R8R080QXJ60P25
QHD308J6QP80RXZ:0P22PX8408B4Q080QXJ60P28R8P208J6QP80Ph>30`38h=P208>3P`@0R8R80P22
PX820861P@80R8R80P27QhL00`1/K6`0QhN708N7Q`0207UiN@80P8200P1gMgL208F5Q@80Q8B40P27
QhL207IfMP80OWin0P22PX8207EeM@80NWYj0P23Ph<208J6QP80S8b<00<0OGem08F5Q@25QHD0101m
OGd207alO080Ogmo0P1jNWX207UiN@80OWin3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P2
08V9R@80SXj>0P2CTi<2092@T080QHF50P2MWId20:JVYP03092@T02:RXX0RXZ:0080R8R80P29RHT2
08n?S`80SHf=0P24Q8@208R8R080QXJ60P23Ph<208N7Q`80Ph>30P28R8P208J6QP80QHF50`26QXH2
08Z:RP80PX:21024Q8@208J6QP80R8R80P26QXH208>3P`<0b>3H0P23Ph<408R8R080PX:20P21PH42
08R8R080QhN700<0K6a/08N7Q`27QhL00P1iNGT20820P080MgMg0P25QHD208B4Q080QhN70P1fMWH2
07inOP80PX:20P1eMGD207YjNP80Ph>30P26QXH208b<S00307emO@25QHD0QHF500@0OGem0P1lO7`2
07moO`80NWYj0P1iNGT207inOPd0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P1oOgl20:FU
Y@80PX:20P29RHT208f=S@80R8R80P29RHT00`2IVIT0S8b<08b<S00208b<S080QXJ60P2;Rh/208J6
QP80R8R80P29RHT208F5Q@80PX:20P27QhL608V9R@80QhN70P2>SXh308B4Q080RXZ:0P24Q8@208V9
R@80QXJ60P28R8P208B4Q080Ph>30`38h=P209:BTP80K6a/0P24Q8@207moO`80PX:20P1fMWH20820
P00306IVIP1bLW80LW9b0080OWin0P1mOGd207inOP80QhN70P28R8P20861P@80O7al0P27QhL207mo
O`80OWin0P1fMWH207inOP80Q8B40P23Ph<00`1`L700PH610861P@0207]kN`80OWin0P1gMgL207in
OP80P8200P1kNg/207moO`d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2IVIT208n?S`80
QhN70P2<S8`408R8R080Ph>300<0T92@08^;R`2;Rh/00P2?Shl208J6QP80RXZ:0P29RHT208F5Q@80
QXJ60P2:RXX208^;R`80RHV90P26QXH208R8R080PX:20P23Ph<208J6QP0308R8R024Q8@0Q8B40080
QHF50P2<S8`408N7Q`80PX:20P28R8P208N7Q`<0b>3H0P25QHD208V9R@80Ogmo0P23Ph<208:2PP80
NWYj0P21PH400`26QXH0OWin07inOP0207emO@80L71`0P1RHV8208f=S@80Q8B40P20P802071`L080
R8R80P1lO7`208B4Q080OGem0P22PX8207moO`80R8R800<0N7Qh08J6QP26QXH00P25QHD208>3P`80
Lg=c0P1hN7P207emO@80Ph>30P1oOgl=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080VIVI
0P2?Shl208N7Q`80S8b<1028R8P208>3P`03092@T02;Rh/0Rh^;0080Shn?0P26QXH208Z:RP80RHV9
0P25QHD208J6QP80RXZ:0P2;Rh/208V9R@80QXJ60P28R8P208:2PP80Ph>30P26QXH00`28R8P0Q8B4
08B4Q00208F5Q@80S8b<1027QhL208:2PP80R8R80P27QhL30<SPf080QHF50P29RHT207moO`80Ph>3
0P22PX8207YjNP80PH6100<0QXJ607inOP1nOWh00P1mOGd2071`L080HV9R0P2=SHd208B4Q080P820
0P1`L70208R8R080O7al0P24Q8@207emO@80PX:20P1oOgl208R8R00307QhN026QXH0QXJ60080QHF5
0P23Ph<207=cL`80N7Qh0P1mOGd208>3P`80Ogmo3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38
h=P208n?S`80R8R80P2<S8`208^;R`80Ph>30P2=SHd208J6QP030861P@2JVYX0VYZJ0080TI6A0P2=
SHd208n?S`80R8R80P29RHT208Z:RP80RHV90P24Q8@408J6QP80SHf=0P25QHD208J6QP80SHf=00<0
QHF508Z:RP2:RXX00P27QhL208R8R080QhN70P26QXH208R8R080QHF50P28R8P30<SPf080Ng]k0P2>
SXh207EeM@80QhN70P28R8P207alO080PH6100<0NGUi08n?S`2?Shl00P1lO7`208:2PP80QHF50P1o
Ogl207inOP80MGEe0P1kNg/607emO@80Ogmo0P26QXH207QhN080NWYj00<0PH6107UiN@1iNGT00P1o
Ogl207]kN`80QhN71020P80208>3P`80Q8B43@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P2
08n?S`80R8R80P2<S8`208^;R`80Ph>30P2=SHd208J6QP030861P@2JVYX0VYZJ0080TI6A0P2=SHd2
08n?S`80R8R80P29RHT208Z:RP80RHV90P24Q8@408J6QP80SHf=0P25QHD208J6QP80SHf=00<0QHF5
08Z:RP2:RXX00P27QhL208R8R080QhN70P26QXH208R8R080QHF50P28R8P30<SPf080Ng]k0P2>SXh2
07EeM@80QhN70P28R8P207alO080PH6100<0NGUi08n?S`2?Shl00P1lO7`208:2PP80QHF50P1oOgl2
07inOP80MGEe0P1kNg/607emO@80Ogmo0P26QXH207QhN080NWYj00<0PH6107UiN@1iNGT00P1oOgl2
07]kN`80QhN71020P80208>3P`80Q8B43@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P208B4
Q080V9RH0P28R8P208j>SP80QXJ60P2HV9P208V9R@0308^;R`23Ph<0Ph>30080WinO0P29RHT208>3
P`80QXJ60P25QHD208V9R@80QhN70P28R8P208B4Q080R8R80P26QXH208N7Q`80RXZ:0P2=SHd00`24
Q8@0QXJ608J6QP0208B4Q080QHF50P28R8P208J6QP80QhN70P25QHD208>3P`<0b>3H0P1`L7020::R
XP80NGUi0P1oOgl208J6QP80SXj>0P1lO7`00`24Q8@0Ph>308>3P`0206i^KP80Ogmo0P1mOGd408F5
Q@80Ph>30P20P80207inOP80Ng]k0P1mOGd207inOP80P8200P29RHT207MgM`0307UiN@20P800P820
0080M7Ad0P1nOWh207]kN`80OGem101gMgL20820P0d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0
b>3H0P24Q8@209RHV080R8R80P2>SXh208J6QP80V9RH0P29RHT00`2;Rh/0Ph>308>3P`0209nOW`80
RHV90P23Ph<208J6QP80QHF50P29RHT208N7Q`80R8R80P24Q8@208R8R080QXJ60P27QhL208Z:RP80
SHf=00<0Q8B408J6QP26QXH00P24Q8@208F5Q@80R8R80P26QXH208N7Q`80QHF50P23Ph<30<SPf080
L71`0P2RXZ8207UiN@80Ogmo0P26QXH208j>SP80O7al00<0Q8B408>3P`23Ph<00P1^KVh207moO`80
OGem1025QHD208>3P`80P8200P1nOWh207]kN`80OGem0P1nOWh20820P080RHV90P1gMgL00`1iNGT0
P8200820P00207AdM080OWin0P1kNg/207emO@@0MgMg0P20P80=0<SPf0002`38h=Pn0820P0<0b>3H
?P20P80:0<SPf080S8b<102:RXX208R8R080Rh^;0P2BTY8208f=S@0308N7Q`23Ph<0Ph>30080UIFE
0P2CTi<208Z:RP80QXJ60P27QhL20861P@80Q8B40P28R8P208B4Q080PX:20P24Q8@208F5Q@@0R8R8
00<0S8b<08J6QP26QXH00P26QXH208R8R080QXJ60P2;Rh/208:2PP80Rh^;0P25QHD30<SPf080Lg=c
0P25QHD207MgM`80KVi^0P2=SHd208j>SP80Ph>300<0P82007moO`1oOgl00P2:RXX2092@T080PX:2
0P1eMGD207inOP80P8200P1nOWh20861P@80Ph>30P21PH4207moO`80P8200P1hN7P207UiN@0307Ee
M@1mOGd0OGem0080OGem0P24Q8@207YjNP80P8200P26QXH207emO@80QXJ63@38h=P000/0b>3H?P20
P8030<SPf3h0P8202P38h=P208b<S0@0RXZ:0P28R8P208^;R`80TY:B0P2=SHd00`27QhL0Ph>308>3
P`0209FEU@80Ti>C0P2:RXX208J6QP80QhN70P21PH4208B4Q080R8R80P24Q8@208:2PP80Q8B40P25
QHD408R8R00308b<S026QXH0QXJ60080QXJ60P28R8P208J6QP80Rh^;0P22PX8208^;R`80QHF50`38
h=P207=cL`80QHF50P1gMgL206i^KP80SHf=0P2>SXh208>3P`030820P01oOgl0Ogmo0080RXZ:0P2@
T90208:2PP80MGEe0P1nOWh20820P080OWin0P21PH4208>3P`80PH610P1oOgl20820P080N7Qh0P1i
NGT00`1eMGD0OGem07emO@0207emO@80Q8B40P1jNWX20820P080QXJ60P1mOGd208J6QPd0b>3H000;
0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2GUiL208>3P`80RHV90P2:RXX208b<S080R8R80P2BTY80
0`24Q8@0QXJ608J6QP020820P080VYZJ0P2DU9@208V9R@80S8b<0P26QXH208N7Q`80R8R80P26QXH2
08B4Q0@0QHF50P23Ph<208B4Q00308J6QP28R8P0R8R80080S8b<0P24Q8@208^;R`80Q8B40P28R8P2
08Z:RP80QHF50`38h=P208b<S080NGUi0P1jNWX407alO080M7Ad0P2;Rh/00`23Ph<0O7al07alO002
07YjNP80N7Qh0P1_Kfl208N7Q`80QHF50P23Ph<207inOP80PH611026QXH207alO080Ph>30P1mOGd2
08F5Q@0307inOP1gMgL0MgMg0080QhN70P1`L70207AdM080OGem0P20P80207inOP80QHF53@38h=P0
00/0b>3H?P20P8030<SPf3h0P8202P38h=P209NGU`80Ph>30P29RHT208Z:RP80S8b<0P28R8P209:B
TP0308B4Q026QXH0QXJ60080P8200P2JVYX209BDU080RHV90P2<S8`208J6QP80QhN70P28R8P208J6
QP80Q8B41025QHD208>3P`80Q8B400<0QXJ608R8R028R8P00P2<S8`208B4Q080Rh^;0P24Q8@208R8
R080RXZ:0P25QHD30<SPf080S8b<0P1iNGT207YjNP@0O7al0P1dM7@208^;R`0308>3P`1lO7`0O7al
0080NWYj0P1hN7P206m_K`80QhN70P25QHD208>3P`80OWin0P21PH4408J6QP80O7al0P23Ph<207em
O@80QHF500<0OWin07MgM`1gMgL00P27QhL2071`L080M7Ad0P1mOGd20820P080OWin0P25QHD=0<SP
f0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080QHF50P2<S8`208^;R`80RHV90P2:RXX408R8R003
08N7Q`29RHT0RHV90080QhN70P29RHT20:b/[080WYjN0P26QXH208b<S080PX:20P28R8P208N7Q`80
QHF50P23Ph<208B4Q080QhN70P29RHT00`2<S8`0SXj>08j>SP0208Z:RP80QhN71P26QXH208B4Q080
RHV90`38h=P2092@T080Ogmo0P1fMWH207YjNP80QhN70P1lO7`208F5Q@0308^;R`1_Kfl0Kfm_0080
NWYj0P1kNg/208b<S080LG5a0P1oOgl208F5Q@80NWYj0P26QXH20861P@80OWin0P22PX8207moO`80
P8200P1hN7P00`27QhL0Ogmo07moO`0207QhN080QXJ60P23Ph<206m_K`80QHF50P1mOGd207moO`d0
b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P25QHD208b<S080Rh^;0P29RHT208Z:RP@0R8R8
00<0QhN708V9R@29RHT00P27QhL208V9R@80[:b/0P2NWYh208J6QP80S8b<0P22PX8208R8R080QhN7
0P25QHD208>3P`80Q8B40P27QhL208V9R@0308b<S02>SXh0SXj>0080RXZ:0P27QhL608J6QP80Q8B4
0P29RHT30<SPf080T92@0P1oOgl207IfMP80NWYj0P27QhL207alO080QHF500<0Rh^;06m_K`1_Kfl0
0P1jNWX207]kN`80S8b<0P1aLG4207moO`80QHF50P1jNWX208J6QP80PH610P1nOWh208:2PP80Ogmo
0P20P80207QhN00308N7Q`1oOgl0Ogmo0080N7Qh0P26QXH208>3P`80Kfm_0P25QHD207emO@80Ogmo
3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P209RHV080TI6A0P2CTi<2092@T080SHf=0P28
R8P208^;R`0308R8R027QhL0QhN70080QhN70P28R8P208B4Q080WinO0P2=SHd208>3P`80QhN70P2:
RXX408N7Q`80RHV90P25QHD208f=S@80Rh^;00<0SXj>08Z:RP2:RXX00P28R8P208N7Q`80RHV90P2;
Rh/208>3P`80PH610P26QXH30<SPf080IfMW0P1hN7P207alO080Q8B40P1hN7P408B4Q0030820P01o
Ogl0Ogmo0080QXJ60P1fMWH207moO`80TI6A0P23Ph<20820P0@0PX:20P21PH4208F5Q@80PH610P1o
Ogl408B4Q00308R8R02<S8`0S8b<0080Ph>30P25QHD207IfMP80P8200P1kNg/208V9R@80NWYj3@38
h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P209RHV080TI6A0P2CTi<2092@T080SHf=0P28R8P2
08^;R`0308R8R027QhL0QhN70080QhN70P28R8P208B4Q080WinO0P2=SHd208>3P`80QhN70P2:RXX4
08N7Q`80RHV90P25QHD208f=S@80Rh^;00<0SXj>08Z:RP2:RXX00P28R8P208N7Q`80RHV90P2;Rh/2
08>3P`80PH610P26QXH30<SPf080IfMW0P1hN7P207alO080Q8B40P1hN7P408B4Q0030820P01oOgl0
Ogmo0080QXJ60P1fMWH207moO`80TI6A0P23Ph<20820P0@0PX:20P21PH4208F5Q@80PH610P1oOgl4
08B4Q00308R8R02<S8`0S8b<0080Ph>30P25QHD207IfMP80P8200P1kNg/208V9R@80NWYj3@38h=P0
00/0b>3H?P20P8030<SPf3h0P8202P38h=P2096AT@80RXZ:0P29RHT208b<S080SHf=0P2<S8`508V9
R@80RXZ:0P24Q8@208R8R080QHF50P2EUID208b<S080Ph>30P27QhL408J6QP80Q8B40P29RHT208b<
S080TY:B00<0UYJF0:2PX02PX:000P2LW9`209BDU080QhN70P29RHT208J6QP80SXj>0P2;Rh/30<SP
f080MgMg0P26QXH208:2PP80RXZ:0P1oOgl207MgM`80LW9b00<0O7al07QhN01hN7P00P1iNGT209:B
TP80NWYj0P22PX820861P@80Kfm_0P2<S8`207YjNPH0Ogmo0P1kNg/2075aL@80JFUY00<0SXj>09bL
W02LW9`00P1`L70208b<S080PH610P1kNg/207UiN@80MWIf0P1iNGT=0<SPf0002`38h=Pn0820P0<0
b>3H?P20P80:0<SPf080TI6A0P2:RXX208V9R@80S8b<0P2=SHd208b<S0D0RHV90P2:RXX208B4Q080
R8R80P25QHD209FEU@80S8b<0P23Ph<208N7Q`@0QXJ60P24Q8@208V9R@80S8b<0P2BTY800`2FUYH0
X:2P0:2PX00209bLW080U9BD0P27QhL208V9R@80QXJ60P2>SXh208^;R`<0b>3H0P1gMgL208J6QP80
PX:20P2:RXX207moO`80MgMg0P1bLW800`1lO7`0N7Qh07QhN00207UiN@80TY:B0P1jNWX208:2PP80
PH610P1_Kfl208b<S080NWYj1P1oOgl207]kN`80LG5a0P1YJFT00`2>SXh0W9bL09bLW002071`L080
S8b<0P21PH4207]kN`80NGUi0P1fMWH207UiN@d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H
0P2KVi/208f=S@80TI6A0P2<S8`209fMW@80Shn?0P2ATI400`2;Rh/0WYjN09jNWP0208J6QP80VIVI
0P29RHT208:2PP80R8R80P2>SXh209bLW080QHF50P27QhL208F5Q@80RHV90P2:RXX209BDU080Vi^K
00<0T92@08N7Q`27QhL00P2YZJT209:BTP80S8b<0P23Ph<208^;R`80RXZ:0P2;Rh/30<SPf080NGUi
0P2>SXh207YjNP80Q8B40P2CTi<208>3P`80LG5a00<0M7Ad07emO@1mOGd00P25QHD206a/K080Ph>3
0P29RHT207moO`80OGem101hN7P208>3P`80PX:20P26QXH207moO`80TI6A0P1bLW800`1lO7`0MgMg
07MgM`020820P080SXj>0P21PH4207MgM`80PH610P1jNWX207EeM@d0b>3H000;0<SPf3h0P8200`38
h=Pn0820P0X0b>3H0P2KVi/208f=S@80TI6A0P2<S8`209fMW@80Shn?0P2ATI400`2;Rh/0WYjN09jN
WP0208J6QP80VIVI0P29RHT208:2PP80R8R80P2>SXh209bLW080QHF50P27QhL208F5Q@80RHV90P2:
RXX209BDU080Vi^K00<0T92@08N7Q`27QhL00P2YZJT209:BTP80S8b<0P23Ph<208^;R`80RXZ:0P2;
Rh/30<SPf080NGUi0P2>SXh207YjNP80Q8B40P2CTi<208>3P`80LG5a00<0M7Ad07emO@1mOGd00P25
QHD206a/K080Ph>30P29RHT207moO`80OGem101hN7P208>3P`80PX:20P26QXH207moO`80TI6A0P1b
LW800`1lO7`0MgMg07MgM`020820P080SXj>0P21PH4207MgM`80PH610P1jNWX207EeM@d0b>3H000;
0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2FUYH208N7Q`80TI6A0P27QhL408J6QP80RHV900<0S8b<
08Z:RP2:RXX00P2UYJD209>CT`80YZJV0P2DU9@208:2PP80QXJ60P28R8P208J6QP80S8b<0P2?Shl2
09RHV080SXj>0P2LW9`209fMW@030:>SX`2;Rh/0Rh^;0080R8R80P20P80208>3P`80QHF50P2:RXX2
08F5Q@80QXJ60`38h=P208n?S`80OWin0P1aLG4207QhN080Ng]k0P28R8P207EeM@0308>3P`2EUID0
UIFE0080GUiN0P1lO7`208F5Q@80KFe]0P1nOWh207MgM`80O7al0P25QHD20820P080MGEe0P2GUiL2
08:2PP80NGUi0P2CTi<00`27QhL0TI6A096AT@0208Z:RP80QHF50P2=SHd207emO@80PH610P1hN7P2
08F5Q@d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2FUYH208N7Q`80TI6A0P27QhL408J6
QP80RHV900<0S8b<08Z:RP2:RXX00P2UYJD209>CT`80YZJV0P2DU9@208:2PP80QXJ60P28R8P208J6
QP80S8b<0P2?Shl209RHV080SXj>0P2LW9`209fMW@030:>SX`2;Rh/0Rh^;0080R8R80P20P80208>3
P`80QHF50P2:RXX208F5Q@80QXJ60`38h=P208n?S`80OWin0P1aLG4207QhN080Ng]k0P28R8P207Ee
M@0308>3P`2EUID0UIFE0080GUiN0P1lO7`208F5Q@80KFe]0P1nOWh207MgM`80O7al0P25QHD20820
P080MGEe0P2GUiL208:2PP80NGUi0P2CTi<00`27QhL0TI6A096AT@0208Z:RP80QHF50P2=SHd207em
O@80PH610P1hN7P208F5Q@d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P29RHT208b<S080
TI6A102<S8`208Z:RP80Shn?00<0V9RH0:JVYP2VYZH00P2IVIT208^;R`@0RHV90P27QhL208J6QP80
Shn?0P2XZ:P208>3P`80VIVI0P2;Rh/208j>SP80V9RH0P2ATI400`2`/;00SHf=08f=S@02096AT@80
T92@0P2MWId208B4Q080S8b<0P29RHT208J6QP<0b>3H0P1nOWh208F5Q@80RXZ:0P23Ph<207MgM`80
Q8B40P26QXH00`27QhL0UYJF09JFUP0208>3P`80NWYj0P1oOgl208>3P`80OGem0P1gMgL207alO080
JFUY0P2<S8`206][J`80Ng]k0P1gMgL208J6QP80O7al00<0OWin05aLG01LG5`00P1kNg/207IfMP80
Fe]K0P26QXH20820P080PH610P24Q8@=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080RHV9
0P2<S8`2096AT@@0S8b<0P2:RXX208n?S`0309RHV02VYZH0YZJV0080VIVI0P2;Rh/408V9R@80QhN7
0P26QXH208n?S`80Z:RX0P23Ph<209VIV@80Rh^;0P2>SXh209RHV080TI6A00<0/;2`08f=S@2=SHd0
0P2ATI42092@T080WIfM0P24Q8@208b<S080RHV90P26QXH30<SPf080OWin0P25QHD208Z:RP80Ph>3
0P1gMgL208B4Q080QXJ600<0QhN709JFUP2FUYH00P23Ph<207YjNP80Ogmo0P23Ph<207emO@80MgMg
0P1lO7`206UYJ@80S8b<0P1[Jf/207]kN`80MgMg0P26QXH207alO00307inOP1LG5`0G5aL0080Ng]k
0P1fMWH205]KF`80QXJ60P20P8020861P@80Q8B43@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38
h=P209nOW`80TY:B0P2;Rh/208N7Q`80RXZ:0P2JVYX209NGU`0309>CT`28R8P0R8R80080QhN70P2:
RXX208f=S@80QHF50P24Q8@208J6QP80Q8B40P2RXZ820:6QX@80SXj>0P26QXH208j>SP80QXJ60P29
RHT00`2?Shl0T92@092@T00208Z:RP80S8b<0P2FUYH208V9R@80QHF50P29RHT208N7Q`<0b>3H0P2M
WId20820P080QXJ60P25QHD208B4Q080IfMW0P1kNg/00`23Ph<0M7Ad07AdM00206e]K@80QhN70P1i
NGT208:2PP80O7al0P24Q8@207UiN@80QXJ60P1TI6@208J6QP80Ogmo0P2=SHd208>3P`80T92@00<0
PH6108j>SP2>SXh00P1eMGD2096AT@80G5aL101nOWh207YjNP80QXJ63@38h=P000/0b>3H?P20P803
0<SPf3h0P8202P38h=P209nOW`80TY:B0P2;Rh/208N7Q`80RXZ:0P2JVYX209NGU`0309>CT`28R8P0
R8R80080QhN70P2:RXX208f=S@80QHF50P24Q8@208J6QP80Q8B40P2RXZ820:6QX@80SXj>0P26QXH2
08j>SP80QXJ60P29RHT00`2?Shl0T92@092@T00208Z:RP80S8b<0P2FUYH208V9R@80QHF50P29RHT2
08N7Q`<0b>3H0P2MWId20820P080QXJ60P25QHD208B4Q080IfMW0P1kNg/00`23Ph<0M7Ad07AdM002
06e]K@80QhN70P1iNGT208:2PP80O7al0P24Q8@207UiN@80QXJ60P1TI6@208J6QP80Ogmo0P2=SHd2
08>3P`80T92@00<0PH6108j>SP2>SXh00P1eMGD2096AT@80G5aL101nOWh207YjNP80QXJ63@38h=P0
00/0b>3H?P20P8030<SPf3h0P8202P38h=P2096AT@80S8b<0P2?Shl208f=S@80V9RH0P2[Zj/209JF
UP0308Z:RP2@T900T92@0080UIFE0P2BTY8208J6QP80TY:B0P29RHT208J6QP80RXZ:0P23Ph<209^K
V`80[Zj^0P29RHT209NGU`80Shn?0P2@T9000`2<S8`0ZZZZ0:ZZZP0209JFUP80T92@0P2CTi<208B4
Q080QhN70P25QHD208R8R0<0b>3H0P1oOgl206i^KP80Q8B40P1eMGD207UiN@80SXj>0P28R8P00`2;
Rh/0Ph>308>3P`020861P@80RXZ:0P1iNGT408:2PP80MGEe0P20P80207emO@80P8200P1UIFD208V9
R@80OWin0P1/K6`207EeM@0308V9R@1]KFd0KFe]0080LW9b0P2<S8`208F5Q@80Ogmo0P1kNg/207al
O080P8203@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P2096AT@80S8b<0P2?Shl208f=S@80
V9RH0P2[Zj/209JFUP0308Z:RP2@T900T92@0080UIFE0P2BTY8208J6QP80TY:B0P29RHT208J6QP80
RXZ:0P23Ph<209^KV`80[Zj^0P29RHT209NGU`80Shn?0P2@T9000`2<S8`0ZZZZ0:ZZZP0209JFUP80
T92@0P2CTi<208B4Q080QhN70P25QHD208R8R0<0b>3H0P1oOgl206i^KP80Q8B40P1eMGD207UiN@80
SXj>0P28R8P00`2;Rh/0Ph>308>3P`020861P@80RXZ:0P1iNGT408:2PP80MGEe0P20P80207emO@80
P8200P1UIFD208V9R@80OWin0P1/K6`207EeM@0308V9R@1]KFd0KFe]0080LW9b0P2<S8`208F5Q@80
Ogmo0P1kNg/207alO080P8203@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P208f=S@80UiNG
102@T90208Z:RP80TY:B0P26QXH00`2BTY80YJFU0:FUY@020:^[Z`@0T92@0P2ATI4208F5Q@80S8b<
0P25QHD208^;R`80QXJ60P2KVi/208^;R`80UYJF0P24Q8@209JFUP0308Z:RP2BTY80TY:B0080S8b<
0P2?Shl208J6QP80TY:B0P2>SXh208>3P`80RXZ:0`38h=P208^;R`80I6AT0P1WIfL207UiN@80KVi^
0P20P80208J6QP0306e]K@1TI6@0I6AT0080Q8B41021PH4208F5Q@80LG5a0P20P80207emO@80PH61
0P1lO7`208V9R@80OGem0P1WIfL209JFUP80NWYj00<0N7Qh0861P@21PH400P1dM7@207=cL`80PH61
0P1^KVh207emO@80Ng]k0P22PX8=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080SHf=0P2G
UiL4092@T080RXZ:0P2BTY8208J6QP0309:BTP2UYJD0YJFU0080Zj^[102@T902096AT@80QHF50P2<
S8`208F5Q@80Rh^;0P26QXH209^KV`80Rh^;0P2FUYH208B4Q080UYJF00<0RXZ:09:BTP2BTY800P2<
S8`208n?S`80QXJ60P2BTY8208j>SP80Ph>30P2:RXX30<SPf080Rh^;0P1TI6@206MWI`80NGUi0P1^
KVh20820P080QXJ600<0KFe]06ATI01TI6@00P24Q8@40861P@80QHF50P1aLG420820P080OGem0P21
PH4207alO080RHV90P1mOGd206MWI`80UYJF0P1jNWX00`1hN7P0PH610861P@0207AdM080Lg=c0P21
PH4206i^KP80OGem0P1kNg/208:2PPd0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P26QXH2
09bLW080XZ:R0P2OWil209>CT`80T92@0P2<S8`00`2:RXX0Zj^[0:^[Z`0208V9R@80SXj>0P2FUYH2
08J6QP80Rh^;0P2?Shl208N7Q`80R8R80P25QHD208J6QP80Ph>30P2d];@209RHV080S8b<00<0RHV9
092@T02@T9000P2:RXX20:>SX`80SXj>0P2PX:0208F5Q@80QXJ60P25QHD30<SPf080Ng]k0P2>SXh2
07MgM`80PH610P29RHT2079bLP80NGUi00<0M7Ad05QHF01HF5P00P1cLg<208N7Q`80OWin0P24Q8@2
08f=S@80KVi^1020P80207alO080PX:20P27QhL20820P080N7Qh0P1gMgL00`26QXH0LW9b079bLP02
08V9R@80J6QX0P1aLG4208:2PP80Ph>30P1nOWh208>3P`d0b>3H000;0<SPf3h0P8200`38h=Pn0820
P0X0b>3H0P26QXH209bLW080XZ:R0P2OWil209>CT`80T92@0P2<S8`00`2:RXX0Zj^[0:^[Z`0208V9
R@80SXj>0P2FUYH208J6QP80Rh^;0P2?Shl208N7Q`80R8R80P25QHD208J6QP80Ph>30P2d];@209RH
V080S8b<00<0RHV9092@T02@T9000P2:RXX20:>SX`80SXj>0P2PX:0208F5Q@80QXJ60P25QHD30<SP
f080Ng]k0P2>SXh207MgM`80PH610P29RHT2079bLP80NGUi00<0M7Ad05QHF01HF5P00P1cLg<208N7
Q`80OWin0P24Q8@208f=S@80KVi^1020P80207alO080PX:20P27QhL20820P080N7Qh0P1gMgL00`26
QXH0LW9b079bLP0208V9R@80J6QX0P1aLG4208:2PP80Ph>30P1nOWh208>3P`d0b>3H000;0<SPf3h0
P8200`38h=Pn0820P0X0b>3H0P2<S8`208V9R@80YJFU0P2ATI4208N7Q`@0R8R800<0WIfM08n?S`2?
Shl00P2DU9@208b<S080W9bL0P2=SHd208b<S080Rh^;0P24Q8@208Z:RP80QHF50P26QXH208R8R080
RHV90P2JVYX208n?S`03096AT@27QhL0QhN70080U9BD0P28R8P208f=S@80Ph>30P26QXH208R8R080
RHV90`38h=P207moO`80LW9b0P1KFe/207]kN`80T92@0P1jNWX208J6QP0308V9R@25QHD0QHF50080
LW9b0P1hN7P207inOP80PH61101jNWX208b<S080QXJ60P29RHT208:2PP80Ph>30P1iNGT208J6QP80
L71`00<0RXZ:08N7Q`27QhL00P1iNGT207=cL`80NGUi0P1jNWX20861P@80PX:20P25QHD=0<SPf000
2`38h=Pn0820P0<0b>3H?P20P80:0<SPf080Ti>C0P2=SHd209VIV@80XZ:R0P2HV9P208N7Q`80S8b<
00<0T92@08Z:RP2:RXX00P2BTY82092@T080YJFU0P2GUiL209FEU@80V9RH0P2KVi/208j>SP80RHV9
0P24Q8@208>3P`80QhN70P2;Rh/209^KV`0309VIV@2:RXX0RXZ:0080R8R80P26QXH208N7Q`P0Q8B4
0`38h=P209nOW`80Rh^;0P22PX8407moO`80MgMg0P2;Rh/00`27QhL0NWYj07YjNP0206i^KP80N7Qh
1027QhL20820P080OGem0P27QhL20861P@80PX:20P1iNGT60820P080RHV900<0QXJ60820P020P800
0P1dM7@207UiN@80MWIf0P21PH420820P080QXJ60P21PH4=0<SPf0002`38h=Pn0820P0<0b>3H?P20
P80:0<SPf080Ti>C0P2=SHd209VIV@80XZ:R0P2HV9P208N7Q`80S8b<00<0T92@08Z:RP2:RXX00P2B
TY82092@T080YJFU0P2GUiL209FEU@80V9RH0P2KVi/208j>SP80RHV90P24Q8@208>3P`80QhN70P2;
Rh/209^KV`0309VIV@2:RXX0RXZ:0080R8R80P26QXH208N7Q`P0Q8B40`38h=P209nOW`80Rh^;0P22
PX8407moO`80MgMg0P2;Rh/00`27QhL0NWYj07YjNP0206i^KP80N7Qh1027QhL20820P080OGem0P27
QhL20861P@80PX:20P1iNGT60820P080RHV900<0QXJ60820P020P8000P1dM7@207UiN@80MWIf0P21
PH420820P080QXJ60P21PH4=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080YZJV0P2GUiL2
08Z:RP80Zj^[0P2IVIT209FEU@80Rh^;00<0QhN708F5Q@25QHD00P2ATI4209FEU@80SXj>0P25QHD2
08N7Q`80WIfM0P26QXH208Z:RP80P8200P29RHT208B4Q080QhN70P2>SXh208^;R`0308>3P`28R8P0
R8R80080TY:B0P23Ph<208J6QP80Q8B40P25QHD208J6QP80Ph>30`38h=P20:2PX080UIFE0P1^KVh2
08R8R080QhN70P1dM7@207=cL`0308^;R`1kNg/0Ng]k0080QHF50P20P80208n?S`80UiNG0P28R8P2
09JFUP80NWYj0P2?Shl208:2PP80QHF50P21PH4208N7Q`80T92@0P1oOgl00`1mOGd0PX:208:2PP02
079bLP80Rh^;0P1iNGT20861P@80Ogmo0P22PX8207UiN@d0b>3H000;0<SPf3h0P8200`38h=Pn0820
P0X0b>3H0P2VYZH209NGU`80RXZ:0P2[Zj/209VIV@80UIFE0P2;Rh/00`27QhL0QHF508F5Q@02096A
T@80UIFE0P2>SXh208F5Q@80QhN70P2MWId208J6QP80RXZ:0P20P80208V9R@80Q8B40P27QhL208j>
SP80Rh^;00<0Ph>308R8R028R8P00P2BTY8208>3P`80QXJ60P24Q8@208F5Q@80QXJ60P23Ph<30<SP
f080X:2P0P2EUID206i^KP80R8R80P27QhL207AdM080Lg=c00<0Rh^;07]kN`1kNg/00P25QHD20820
P080Shn?0P2GUiL208R8R080UYJF0P1jNWX208n?S`80PX:20P25QHD20861P@80QhN70P2@T90207mo
O`0307emO@22PX80PX:20080LW9b0P2;Rh/207UiN@80PH610P1oOgl208:2PP80NGUi3@38h=P000/0
b>3H?P20P8030<SPf3h0P8202P38h=P208R8R080PX:20P29RHT208R8R080W9bL0P29RHT2092@T003
08^;R`27QhL0QhN70080Rh^;0P2<S8`209RHV080WinO0P2@T90208N7Q`80TY:B1028R8P20861P@80
RHV90P24Q8@208F5Q@80Q8B400<0PX:208>3P`23Ph<00P2?Shl208^;R`80Ph>30P26QXH208B4Q0@0
R8R80`38h=P208n?S`80Ng]k0P2=SHd205iNGP80U9BD0P1gMgL209BDU00308:2PP28R8P0R8R80080
LW9b0P27QhL207MgM`80Ph>30P2<S8`207YjNP80UYJF0P22PX8208J6QP80R8R80P1jNWX207moO`80
P8200P21PH400`22PX80PH610861P@0208R8R080PH610P1oOgl207alO080NGUi0P1lO7`208:2PPd0
b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P28R8P208:2PP80RHV90P28R8P209bLW080RHV9
0P2@T9000`2;Rh/0QhN708N7Q`0208^;R`80S8b<0P2HV9P209nOW`80T92@0P27QhL209:BTP@0R8R8
0P21PH4208V9R@80Q8B40P25QHD208B4Q00308:2PP23Ph<0Ph>30080Shn?0P2;Rh/208>3P`80QXJ6
0P24Q8@408R8R0<0b>3H0P2?Shl207]kN`80SHf=0P1NGUh209BDU080MgMg0P2DU9@00`22PX80R8R8
08R8R002079bLP80QhN70P1gMgL208>3P`80S8b<0P1jNWX209JFUP80PX:20P26QXH208R8R080NWYj
0P1oOgl20820P080PH6100<0PX:20861P@21PH400P28R8P20861P@80Ogmo0P1lO7`207UiN@80O7al
0P22PX8=0<SPf0002`38h=Pn0820P0<0b>3H?P20P80:0<SPf080UYJF0P29RHT208^;R`80RXZ:0P2C
Ti<2092@T0<0S8b<0P28R8P208j>SP80Vi^K0P2GUiL20:6QX@80Vi^K0P2<S8`209JFUP80RHV90P2>
SXh209FEU@80QHF50P2;Rh/208>3P`80SXj>00<0RXZ:08J6QP26QXH00P25QHD208N7Q`@0RHV90P25
QHD208Z:RP80Q8B40`38h=P207EeM@80P8200P22PX82071`L080OGem0P21PH4207MgM`0307emO@26
QXH0QXJ60080Q8B40P2;Rh/207emO@80V9RH0P2?Shl208B4Q080IfMW0P22PX8209NGU`80KFe]0P23
Ph<20861P@80OWin0P2=SHd00`27QhL0Ogmo07moO`0208F5Q@80Ng]k0P23Ph<208R8R080QhN70P28
R8P20820P0d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2FUYH208V9R@80Rh^;0P2:RXX2
09>CT`80T92@0`2<S8`208R8R080SXj>0P2KVi/209NGU`80XJ6Q0P2KVi/208b<S080UYJF0P29RHT2
08j>SP80UIFE0P25QHD208^;R`80Ph>30P2>SXh00`2:RXX0QXJ608J6QP0208F5Q@80QhN71029RHT2
08F5Q@80RXZ:0P24Q8@30<SPf080MGEe0P20P80208:2PP80L71`0P1mOGd20861P@80MgMg00<0OGem
08J6QP26QXH00P24Q8@208^;R`80OGem0P2HV9P208n?S`80Q8B40P1WIfL208:2PP80UiNG0P1]KFd2
08>3P`80PH610P1nOWh208f=S@0308N7Q`1oOgl0Ogmo0080QHF50P1kNg/208>3P`80R8R80P27QhL2
08R8R080P8203@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P20:ZZZP80UiNG1027QhL208V9
R@80QhN70P28R8P00`2<S8`0R8R808R8R00208J6QP80R8R80P2CTi<208b<S080QHF50P2@T90208b<
S080XJ6Q0P2<S8`208n?S`80S8b<0P24Q8@208F5Q@80TY:B00<0QhN708R8R028R8P00P28R8P208B4
Q080QhN70P2GUiL209:BTP80QXJ60P24Q8@30<SPf080QXJ60P2@T90207YjNP80Ogmo0P2<S8`208V9
R@80MWIf00<0QhN707inOP1nOWh00P2=SHd207MgM`80PH610P1PH60207emO@80GUiN0P1lO7`209BD
U080P8200P25QHD207EeM@80Shn?0P2:RXX207UiN@0308R8R01mOGd0OGem0080QhN70P1kNg/207in
OP80Ogmo0P1dM7@208R8R080Ng]k3@38h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P20:ZZZP80
UiNG1027QhL208V9R@80QhN70P28R8P00`2<S8`0R8R808R8R00208J6QP80R8R80P2CTi<208b<S080
QHF50P2@T90208b<S080XJ6Q0P2<S8`208n?S`80S8b<0P24Q8@208F5Q@80TY:B00<0QhN708R8R028
R8P00P28R8P208B4Q080QhN70P2GUiL209:BTP80QXJ60P24Q8@30<SPf080QXJ60P2@T90207YjNP80
Ogmo0P2<S8`208V9R@80MWIf00<0QhN707inOP1nOWh00P2=SHd207MgM`80PH610P1PH60207emO@80
GUiN0P1lO7`209BDU080P8200P25QHD207EeM@80Shn?0P2:RXX207UiN@0308R8R01mOGd0OGem0080
QhN70P1kNg/207inOP80Ogmo0P1dM7@208R8R080Ng]k3@38h=P000/0b>3H?P20P8030<SPf3h0P820
2P38h=P209ZJVP80U9BD0P2;Rh/209:BTP@0T92@0P2<S8`00`29RHT0TY:B09:BTP0209:BTP80RXZ:
0P2@T90208f=S@80VYZJ0P2ZZZX209:BTP80PX:20P2LW9`208n?S`80Ti>C0P2QXJ4209>CT`80SXj>
00<0QHF508B4Q024Q8@00P2<S8`208R8R080QhN70P29RHT208N7Q`80RHV90P28R8P30<SPf080MGEe
0P1iNGT209BDU080RHV90P2@T90207]kN`80OGem00<0OWin07alO01lO7`00P1oOgl208B4Q080P820
0P1bLW8206a/K080Kfm_0P2EUID2079bLP80S8b<0P1kNg/207YjNP80PH610P1mOGd207moO`0307Mg
M`24Q8@0Q8B40080Q8B40P1hN7P20861P@80QHF50P1nOWh20820P080LW9b3@38h=P000/0b>3H?P20
P8030<SPf3h0P8202P38h=P209ZJVP80U9BD0P2;Rh/209:BTP@0T92@0P2<S8`00`29RHT0TY:B09:B
TP0209:BTP80RXZ:0P2@T90208f=S@80VYZJ0P2ZZZX209:BTP80PX:20P2LW9`208n?S`80Ti>C0P2Q
XJ4209>CT`80SXj>00<0QHF508B4Q024Q8@00P2<S8`208R8R080QhN70P29RHT208N7Q`80RHV90P28
R8P30<SPf080MGEe0P1iNGT209BDU080RHV90P2@T90207]kN`80OGem00<0OWin07alO01lO7`00P1o
Ogl208B4Q080P8200P1bLW8206a/K080Kfm_0P2EUID2079bLP80S8b<0P1kNg/207YjNP80PH610P1m
OGd207moO`0307MgM`24Q8@0Q8B40080Q8B40P1hN7P20861P@80QHF50P1nOWh20820P080LW9b3@38
h=P000/0b>3H?P20P8030<SPf3h0P8202P38h=P209jNWP80VYZJ0P2LW9`209ZJVP80T92@0P29RHT2
09JFUP0309fMW@2FUYH0UYJF00@0RXZ:0P2ATI4209RHV080Rh^;0P2EUID208n?S`@0Rh^;0P2ATI42
08^;R`80WIfM0P2DU9@208b<S00308N7Q`26QXH0QXJ60080QhN70P29RHT208J6QP80RHV90P27QhL2
08J6QP80SHf=0`38h=P207UiN@80H61P0P1/K6`206UYJ@80GUiN0P1bLW8206YZJP0308Z:RP1gMgL0
MgMg0080M7Ad0P2@T90206=SH`80N7Qh0P20P80208f=S@80OWin0P1dM7@207moO`80K6a/0P1PH602
07=cL`80MGEe0P1SHf<00`1cLg<0IfMW06MWI`0208:2PP80L71`0P1lO7`208b<S080N7Qh0P1cLg<2
071`L0d0b>3H000;0<SPf3h0P8200`38h=Pn0820P0X0b>3H0P2NWYh209ZJVP80W9bL0P2JVYX2092@
T080RHV90P2FUYH00`2MWId0UYJF09JFUP0408Z:RP80TI6A0P2HV9P208^;R`80UIFE0P2?Shl408^;
R`80TI6A0P2;Rh/209fMW@80U9BD0P2<S8`00`27QhL0QXJ608J6QP0208N7Q`80RHV90P26QXH208V9
R@80QhN70P26QXH208f=S@<0b>3H0P1iNGT2061PH080K6a/0P1YJFT205iNGP80LW9b0P1ZJVX00`2:
RXX0MgMg07MgM`0207AdM080T92@0P1SHf<207QhN080P8200P2=SHd207inOP80M7Ad0P1oOgl206a/
K080H61P0P1cLg<207EeM@80Hf=S00<0Lg=c06MWI`1WIfL00P22PX82071`L080O7al0P2<S8`207Qh
N080Lg=c0P1`L70=0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000o`38h=PQ
0<SPf000o`38h=PQ0<SPf000o`38h=PQ0<SPf000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500105, -0.0500105, \
0.00731715, 0.00731715}, {{6.8125, 143.5}, {280.125, 143.5}} -> {-0.155204, \
-0.155684, 0.0153707, 0.0153707}, {{10.0625, 75.125}, {276.813, 211.813}} -> \
{-6.01791, -6.06637, 0.516928, 0.516928}, {{75.125, 140.188}, {276.813, \
211.813}} -> {-39.6506, -6.06637, 0.516928, 0.516928}, {{10.0625, 75.125}, \
{211.813, 146.75}} -> {-5.99676, -39.6294, 0.516432, 0.516432}, {{75.125, \
140.188}, {211.813, 146.75}} -> {-39.5971, -39.6294, 0.516432, 0.516432}, \
{{143.5, 280.125}, {280.125, 143.5}} -> {-2.25571, -0.155684, 0.0153707, \
0.0153707}, {{146.75, 211.813}, {276.813, 211.813}} -> {-76.6756, -6.06637, \
0.516928, 0.516928}, {{211.813, 276.813}, {276.813, 211.813}} -> {-110.292, \
-6.06637, 0.516928, 0.516928}, {{146.75, 211.813}, {211.813, 146.75}} -> \
{-76.5865, -39.6294, 0.516432, 0.516432}, {{211.813, 276.813}, {211.813, \
146.75}} -> {-110.292, -39.6829, 0.516928, 0.516928}, {{6.8125, 143.5}, \
{143.5, 6.8125}} -> {-0.154676, -2.2547, 0.0153637, 0.0153637}, {{10.0625, \
75.125}, {140.188, 75.125}} -> {-5.99676, -76.6188, 0.516432, 0.516432}, \
{{75.125, 140.188}, {140.188, 75.125}} -> {-39.5971, -76.6188, 0.516432, \
0.516432}, {{10.0625, 75.125}, {75.125, 10.0625}} -> {-5.99676, -110.219, \
0.516432, 0.516432}, {{75.125, 140.188}, {75.125, 10.0625}} -> {-39.5971, \
-110.219, 0.516432, 0.516432}, {{143.5, 280.125}, {143.5, 6.8125}} -> \
{-2.25571, -2.25619, 0.0153707, 0.0153707}, {{146.75, 211.813}, {140.188, \
75.125}} -> {-76.5865, -76.6188, 0.516432, 0.516432}, {{211.813, 276.813}, \
{140.188, 75.125}} -> {-110.292, -76.7079, 0.516928, 0.516928}, {{146.75, \
211.813}, {75.125, 10.0625}} -> {-76.5865, -110.219, 0.516432, 0.516432}, \
{{211.813, 276.813}, {75.125, 10.0625}} -> {-110.292, -110.341, 0.516928, \
0.516928}}]
}, Open  ]],

Cell["\<\
One interesting approach would be discarding the noisy high-pass subband of \
variance and quantizing the low-pass subbands of variance.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 730}},
WindowSize->{1016, 706},
WindowMargins->{{-7, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 64, 0, 105, "Title"],
Cell[1806, 53, 84, 3, 95, "Subtitle"],
Cell[1893, 58, 347, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[2265, 68, 36, 0, 53, "Section"],
Cell[2304, 70, 136, 2, 50, "Input"],
Cell[2443, 74, 194, 4, 33, "Text"],
Cell[2640, 80, 3124, 66, 410, "Input"],
Cell[5767, 148, 221, 4, 33, "Text"],
Cell[5991, 154, 497, 10, 90, "Input"],
Cell[6491, 166, 103, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[6619, 173, 74, 1, 30, "Input"],
Cell[6696, 176, 90, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6823, 182, 68, 1, 30, "Input"],
Cell[6894, 185, 111, 2, 29, "Output"]
}, Open  ]],
Cell[7020, 190, 96, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[7141, 196, 65, 1, 30, "Input"],
Cell[7209, 199, 229, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7475, 207, 62, 1, 30, "Input"],
Cell[7540, 210, 214, 3, 29, "Output"]
}, Open  ]],
Cell[7769, 216, 184, 4, 33, "Text"],
Cell[7956, 222, 323, 8, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8316, 235, 37, 0, 53, "Section"],
Cell[8356, 237, 307, 5, 52, "Text"],
Cell[8666, 244, 523, 15, 50, "Input"],
Cell[9192, 261, 195, 4, 50, "Input"],
Cell[9390, 267, 88, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[9503, 273, 159, 2, 50, "Input"],
Cell[9665, 277, 1957343, 25322, 552, 532758, 7731, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1967023, 25602, 306, 5, 52, "Text"],
Cell[1967332, 25609, 111, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[1967468, 25615, 113, 2, 30, "Input"],
Cell[1967584, 25619, 260529, 3363, 296, 34048, 562, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2228128, 28985, 85, 2, 33, "Text"],
Cell[2228216, 28989, 303, 8, 50, "Input"],
Cell[2228522, 28999, 161, 3, 33, "Text"],
Cell[2228686, 29004, 682, 13, 110, "Input"],
Cell[2229371, 29019, 121, 3, 33, "Text"],
Cell[2229495, 29024, 133, 2, 50, "Input"],
Cell[2229631, 29028, 45, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2229701, 29032, 197, 4, 30, "Input"],
Cell[2229901, 29038, 502679, 6471, 628, 36208, 708, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2732595, 35512, 65, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2732685, 35516, 138, 2, 30, "Input"],
Cell[2732826, 35520, 260529, 3363, 296, 34048, 562, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2993404, 38889, 28, 0, 53, "Section"],
Cell[2993435, 38891, 338, 6, 52, "Text"],
Cell[2993776, 38899, 359, 6, 90, "Input"],

Cell[CellGroupData[{
Cell[2994160, 38909, 149, 3, 30, "Input"],
Cell[2994312, 38914, 254312, 3286, 296, 34048, 562, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3248639, 42203, 145, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[3248809, 42210, 784, 15, 130, "Input"],
Cell[3249596, 42227, 254397, 3287, 296, 34048, 562, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3504042, 45520, 31, 0, 53, "Section"],
Cell[3504076, 45522, 549, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[3504650, 45534, 803, 16, 170, "Input"],
Cell[3505456, 45552, 606092, 7783, 376, 68372, 1140, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4111563, 53338, 219, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[4111807, 53346, 68, 1, 30, "Input"],
Cell[4111878, 53349, 41, 1, 29, "Output"]
}, Open  ]],
Cell[4111934, 53353, 516, 9, 90, "Text"],

Cell[CellGroupData[{
Cell[4112475, 53366, 219, 5, 30, "Input"],
Cell[4112697, 53373, 133364, 1912, 398, 36208, 708, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4246076, 55288, 215, 4, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4246328, 55297, 39, 0, 53, "Section"],
Cell[4246370, 55299, 690, 10, 90, "Text"],
Cell[4247063, 55311, 92, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4247180, 55316, 387, 8, 90, "Input"],
Cell[4247570, 55326, 398766, 5666, 494, 44916, 1292, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4646351, 60995, 1111, 19, 185, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4647499, 61019, 48, 0, 53, "Section"],
Cell[4647550, 61021, 290, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[4647865, 61030, 210, 4, 30, "Input"],
Cell[4648078, 61036, 200823, 2745, 296, 36208, 708, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4848916, 63784, 72, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[4849013, 63788, 290, 4, 50, "Input"],
Cell[4849306, 63794, 358967, 8254, 476, 57043, 4522, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5208276, 72050, 135, 3, 29, "Output"]
}, Open  ]],
Cell[5208426, 72056, 754, 13, 128, "Text"],
Cell[5209183, 72071, 360, 6, 70, "Input"],
Cell[5209546, 72079, 221, 4, 33, "Text"],
Cell[5209770, 72085, 87, 1, 30, "Input"],
Cell[5209860, 72088, 62, 0, 33, "Text"],
Cell[5209925, 72090, 312, 6, 50, "Input"],
Cell[5210240, 72098, 148, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[5210413, 72105, 400, 8, 70, "Input"],
Cell[5210816, 72115, 738390, 9550, 287, 102255, 1692, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5949221, 81668, 687, 10, 90, "Text"],
Cell[5949911, 81680, 477, 7, 71, "Text"],
Cell[5950391, 81689, 84, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5950512, 81695, 31, 0, 53, "Section"],
Cell[5950546, 81697, 155, 3, 33, "Text"],
Cell[5950704, 81702, 91, 2, 33, "Text"],
Cell[5950798, 81706, 644, 15, 110, "Input"],

Cell[CellGroupData[{
Cell[5951467, 81725, 490, 10, 130, "Input"],
Cell[5951960, 81737, 125972, 2616, 160, 28293, 1404, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6077947, 84356, 413, 7, 52, "Text"],
Cell[6078363, 84365, 404, 8, 70, "Input"],
Cell[6078770, 84375, 104, 2, 30, "Input"],
Cell[6078877, 84379, 284, 5, 70, "Input"],
Cell[6079164, 84386, 78, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[6079267, 84391, 407, 8, 70, "Input"],
Cell[6079677, 84401, 734854, 9506, 297, 102255, 1692, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6814546, 93910, 335, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[6814906, 93920, 56, 0, 47, "Subsection"],
Cell[6814965, 93922, 256, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[6815246, 93931, 188, 4, 50, "Input"],
Cell[6815437, 93937, 224157, 3511, 296, 44916, 1292, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7039609, 97451, 160, 3, 33, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

